(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  19025982,     954988]*)
(*NotebookOutlinePosition[  19116536,     957999]*)
(*  CellTagsIndexPosition[  19116449,     957993]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell[" Discrete Maps", "Subsection",
  TextAlignment->Center],

Cell[TextData[{
  "A brief study of discrete 1-D maps provides a good example for some of the \
basic numerical computation, data manipulation, and plotting features of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  Most of the examples shown will be generic to maps of the unit interval \
to itself."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Some\ maps\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
Here are some example parametrized maps of the unit interval onto \
itself.\
\>", "Text"],

Cell[BoxData[
    \(LogisticMap[r_]\  := \ 4\ r\ #\ \((1\  - \ #)\) &\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(SinMap[r_]\  := \ \ r\ Sin[#\ \[Pi]] &\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \(CircleMap[r_]\  := \ r\ Sqrt[1\  - \ \((2\ #\  - \ 1)\)^2] &\)], "Input",\

  CellLabel->"In[38]:="],

Cell[BoxData[
    \(HatMap[r_]\  := \ r\ \((1\  - \ Abs[2\ #\  - \ 1])\) &\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \(ShiftMap[r_]\  := \ r\ Mod[2\ #, \ 1] &\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \(WildMap[r_]\  := \ 
      r \((1\  - \ 
              Abs[2\ #\  - \ 1]\  + \  .1  Sin[11\ \[Pi]\ #])\) &\)], "Input",\

  CellLabel->"In[41]:="],

Cell[BoxData[
    \(\(Plot[{\(LogisticMap[1]\)[x], \ \(SinMap[1]\)[x], \ \(CircleMap[1]\)[
            x], \ \(HatMap[1]\)[x], \ \(ShiftMap[1]\)[x], \ \(WildMap[1]\)[
            x]}, \ {x, 0, 1}, \ 
        PlotStyle \[Rule] {Black, \ Red, \ Green, \ Blue, \ Cyan, \ 
            Yellow}];\)\)], "Input",
  CellLabel->"In[70]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Cobweb\ diagrams\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
Cobweb diagrams are not my favorite, but they are trivial to \
produce and do provide some illustration of iterates.  Here is a simple \
function that provides a cobweb diagram.\
\>", "Text"],

Cell[BoxData[
    \(Cobweb[map_, \ x0_, \ n_, \ 
        k_]\  := \ \[IndentingNewLine]Module[{iterates, \ segments, \ s, \ 
          x}, \[IndentingNewLine]iterates\  = \ 
          NestList[map, \ x0, \ n]; \[IndentingNewLine]If[k\  > \ 1, \ 
          iterates\  = \ 
            Take[iterates, \ {1, \(-1\), 
                k}]]; \[IndentingNewLine]iterates\  = \ 
          Partition[iterates, \ 2, \ 1]; \[IndentingNewLine]segments\  = \ 
          Apply[{{#1, \ #1}, {#1, \ #2}, \ {#2, \ #2}} &, \ 
            iterates, \ {1}]; \[IndentingNewLine]s\  = \ 
          N[Length[segments]]; \[IndentingNewLine]segments\  = \ 
          MapIndexed[{Hue[ .8\ #2[\([1]\)]/s], \ Line[#1]} &, \ 
            segments]; \[IndentingNewLine]Plot[
          Nest[map, \ x, \ k], \ {x, 0, 1}, \ 
          PlotStyle \[Rule] Thickness[ .01], 
          Epilog \[Rule] Reverse[segments], \ 
          PlotRange \[Rule] {{0, 1}, {0, 1}}]]\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \(\(Cobweb[LogisticMap[ .7], \  .01, \ 100, 1];\)\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \(\(Cobweb[ShiftMap[ .8], \  .01, \ 100, 1];\)\)], "Input",
  CellLabel->"In[44]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Cobweb\ diagrams\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["An animation is quite illustrative.", "Text"],

Cell[BoxData[
    \(Do[Cobweb[LogisticMap[r], \  .01, \ 100, \ 1], \ {r, \  .5, \ 
        1, \  .01}]\)], "Input",
  CellLabel->"In[45]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Bifurcation\ Diagrams\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
To improve ease of use, many settings are made into options.  The \
default values are good choices for a generic case.\
\>", "Text"],

Cell[BoxData[
    \(\(Options[BifuractionDiagram]\  = \ {PlotPoints \[Rule] 500, \ 
          StartingIterations \[Rule] 10000, \ Iterations \[Rule] 1000, \ 
          PlotRange \[Rule] All, \ 
          StartingValue \[Rule] 1. /\[Pi]};\)\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(BifuractionDiagram[map_, \ {r_, \ rmin_, \ rmax_}, \ 
        opts___] := \[IndentingNewLine]Module[{R, \ pp, \ tol\  = \ 2. ^32, \ 
          Cycles}, \[IndentingNewLine]{pp, \ ns, \ n, \ pr, \ 
            x0}\  = \ {PlotPoints, \ StartingIterations, \ Iterations, \ 
              PlotRange, \ StartingValue}\  /. \ 
            Flatten[{opts, \ 
                Options[BifuractionDiagram]}]; \[IndentingNewLine]R\  = \ 
          rmin\  + \ \((rmax\  - \ rmin)\)*
              N[Range[0, pp]]/pp; \[IndentingNewLine]rmap\  = \ 
          map\  /. \ r \[Rule] R; \[IndentingNewLine]x1\  = \ 
          Nest[rmap, \ x0\  + \ 0. \ R, \ ns]; \[IndentingNewLine]data\  = \ 
          Transpose[NestList[rmap, \ x1, \ n]]; \[IndentingNewLine]Cycles[
            rr_, \ points_]\  := \ 
          Module[{u}, \[IndentingNewLine]u\  = \ 
              Union[Round[points\ tol]/
                  tol]; \[IndentingNewLine]Transpose[{rr\  + 0. \ u, \ 
                u}]]; \[IndentingNewLine]data\  = \ 
          MapThread[Cycles, \ {R, \ data}]; \[IndentingNewLine]ListPlot[
          Flatten[data, 1], \ PlotStyle \[Rule] PointSize[0.001], \ 
          PlotRange \[Rule] {{rmin, \ rmax}, 
              pr}]\[IndentingNewLine]]\)], "Input",
  CellLabel->"In[47]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BifuractionDiagram[LogisticMap[r], \ {r,  .8, 1}];\)\)], "Input",
  CellLabel->"In[49]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-4 5 0.0147132 0.588606 [
[0 .00221 -9 -9 ]
[0 .00221 9 0 ]
[.125 .00221 -15 -9 ]
[.125 .00221 15 0 ]
[.25 .00221 -12 -9 ]
[.25 .00221 12 0 ]
[.375 .00221 -15 -9 ]
[.375 .00221 15 0 ]
[.5 .00221 -9 -9 ]
[.5 .00221 9 0 ]
[.625 .00221 -15 -9 ]
[.625 .00221 15 0 ]
[.75 .00221 -12 -9 ]
[.75 .00221 12 0 ]
[.875 .00221 -15 -9 ]
[.875 .00221 15 0 ]
[.9875 .13243 -18 -4.5 ]
[.9875 .13243 0 4.5 ]
[.9875 .25016 -18 -4.5 ]
[.9875 .25016 0 4.5 ]
[.9875 .36788 -18 -4.5 ]
[.9875 .36788 0 4.5 ]
[.9875 .4856 -18 -4.5 ]
[.9875 .4856 0 4.5 ]
[.9875 .60332 -6 -4.5 ]
[.9875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1.00625 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .01471 m
0 .02096 L
s
[(0.8)] 0 .00221 0 1 Mshowa
.125 .01471 m
.125 .02096 L
s
[(0.825)] .125 .00221 0 1 Mshowa
.25 .01471 m
.25 .02096 L
s
[(0.85)] .25 .00221 0 1 Mshowa
.375 .01471 m
.375 .02096 L
s
[(0.875)] .375 .00221 0 1 Mshowa
.5 .01471 m
.5 .02096 L
s
[(0.9)] .5 .00221 0 1 Mshowa
.625 .01471 m
.625 .02096 L
s
[(0.925)] .625 .00221 0 1 Mshowa
.75 .01471 m
.75 .02096 L
s
[(0.95)] .75 .00221 0 1 Mshowa
.875 .01471 m
.875 .02096 L
s
[(0.975)] .875 .00221 0 1 Mshowa
.125 Mabswid
.025 .01471 m
.025 .01846 L
s
.05 .01471 m
.05 .01846 L
s
.075 .01471 m
.075 .01846 L
s
.1 .01471 m
.1 .01846 L
s
.15 .01471 m
.15 .01846 L
s
.175 .01471 m
.175 .01846 L
s
.2 .01471 m
.2 .01846 L
s
.225 .01471 m
.225 .01846 L
s
.275 .01471 m
.275 .01846 L
s
.3 .01471 m
.3 .01846 L
s
.325 .01471 m
.325 .01846 L
s
.35 .01471 m
.35 .01846 L
s
.4 .01471 m
.4 .01846 L
s
.425 .01471 m
.425 .01846 L
s
.45 .01471 m
.45 .01846 L
s
.475 .01471 m
.475 .01846 L
s
.525 .01471 m
.525 .01846 L
s
.55 .01471 m
.55 .01846 L
s
.575 .01471 m
.575 .01846 L
s
.6 .01471 m
.6 .01846 L
s
.65 .01471 m
.65 .01846 L
s
.675 .01471 m
.675 .01846 L
s
.7 .01471 m
.7 .01846 L
s
.725 .01471 m
.725 .01846 L
s
.775 .01471 m
.775 .01846 L
s
.8 .01471 m
.8 .01846 L
s
.825 .01471 m
.825 .01846 L
s
.85 .01471 m
.85 .01846 L
s
.9 .01471 m
.9 .01846 L
s
.925 .01471 m
.925 .01846 L
s
.95 .01471 m
.95 .01846 L
s
.975 .01471 m
.975 .01846 L
s
.25 Mabswid
0 .01471 m
1 .01471 L
s
1 .13243 m
1.00625 .13243 L
s
[(0.2)] .9875 .13243 1 0 Mshowa
1 .25016 m
1.00625 .25016 L
s
[(0.4)] .9875 .25016 1 0 Mshowa
1 .36788 m
1.00625 .36788 L
s
[(0.6)] .9875 .36788 1 0 Mshowa
1 .4856 m
1.00625 .4856 L
s
[(0.8)] .9875 .4856 1 0 Mshowa
1 .60332 m
1.00625 .60332 L
s
[(1)] .9875 .60332 1 0 Mshowa
.125 Mabswid
1 .04414 m
1.00375 .04414 L
s
1 .07357 m
1.00375 .07357 L
s
1 .103 m
1.00375 .103 L
s
1 .16186 m
1.00375 .16186 L
s
1 .1913 m
1.00375 .1913 L
s
1 .22073 m
1.00375 .22073 L
s
1 .27959 m
1.00375 .27959 L
s
1 .30902 m
1.00375 .30902 L
s
1 .33845 m
1.00375 .33845 L
s
1 .39731 m
1.00375 .39731 L
s
1 .42674 m
1.00375 .42674 L
s
1 .45617 m
1.00375 .45617 L
s
1 .51503 m
1.00375 .51503 L
s
1 .54446 m
1.00375 .54446 L
s
1 .57389 m
1.00375 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
0 .31669 Mdot
0 .48528 Mdot
.002 .31634 Mdot
.002 .48554 Mdot
.004 .31598 Mdot
.004 .4858 Mdot
.006 .31563 Mdot
.006 .48607 Mdot
.008 .31528 Mdot
.008 .48633 Mdot
.01 .31493 Mdot
.01 .48658 Mdot
.012 .31458 Mdot
.012 .48684 Mdot
.014 .31423 Mdot
.014 .4871 Mdot
.016 .31389 Mdot
.016 .48735 Mdot
.018 .31354 Mdot
.018 .48761 Mdot
.02 .3132 Mdot
.02 .48786 Mdot
.022 .31286 Mdot
.022 .48811 Mdot
.024 .31252 Mdot
.024 .48836 Mdot
.026 .31218 Mdot
.026 .4886 Mdot
.028 .31184 Mdot
.028 .48885 Mdot
.03 .31151 Mdot
.03 .4891 Mdot
.032 .31117 Mdot
.032 .48934 Mdot
.034 .31084 Mdot
.034 .48958 Mdot
.036 .31051 Mdot
.036 .48982 Mdot
.038 .31018 Mdot
.038 .49006 Mdot
.04 .30985 Mdot
.04 .4903 Mdot
.042 .30952 Mdot
.042 .49054 Mdot
.044 .30919 Mdot
.044 .49078 Mdot
.046 .30887 Mdot
.046 .49101 Mdot
.048 .30854 Mdot
.048 .49125 Mdot
.05 .30822 Mdot
.05 .49148 Mdot
.052 .3079 Mdot
.052 .49171 Mdot
.054 .30758 Mdot
.054 .49194 Mdot
.056 .30726 Mdot
.056 .49217 Mdot
.058 .30694 Mdot
.058 .4924 Mdot
.06 .30662 Mdot
.06 .49263 Mdot
.062 .30631 Mdot
.062 .49286 Mdot
.064 .30599 Mdot
.064 .49308 Mdot
.066 .30568 Mdot
.066 .49331 Mdot
.068 .30537 Mdot
.068 .49353 Mdot
.07 .30506 Mdot
.07 .49375 Mdot
.072 .30475 Mdot
.072 .49397 Mdot
.074 .30444 Mdot
.074 .49419 Mdot
.076 .30413 Mdot
.076 .49441 Mdot
.078 .30382 Mdot
.078 .49463 Mdot
.08 .30352 Mdot
.08 .49485 Mdot
.082 .30321 Mdot
.082 .49506 Mdot
.084 .30291 Mdot
.084 .49528 Mdot
.086 .30261 Mdot
.086 .49549 Mdot
.088 .30231 Mdot
.088 .49571 Mdot
.09 .302 Mdot
.09 .49592 Mdot
.092 .30171 Mdot
.092 .49613 Mdot
.094 .30141 Mdot
.094 .49634 Mdot
.096 .30111 Mdot
.096 .49655 Mdot
.098 .30081 Mdot
.098 .49676 Mdot
.1 .30052 Mdot
.1 .49697 Mdot
.102 .30022 Mdot
.102 .49717 Mdot
.104 .29993 Mdot
.104 .49738 Mdot
.106 .29964 Mdot
.106 .49759 Mdot
.108 .29935 Mdot
.108 .49779 Mdot
.11 .29906 Mdot
.11 .49799 Mdot
.112 .29877 Mdot
.112 .4982 Mdot
.114 .29848 Mdot
.114 .4984 Mdot
.116 .29819 Mdot
.116 .4986 Mdot
.118 .2979 Mdot
.118 .4988 Mdot
.12 .29762 Mdot
.12 .499 Mdot
.122 .29733 Mdot
.122 .4992 Mdot
.124 .29705 Mdot
.124 .49939 Mdot
.126 .29677 Mdot
.126 .49959 Mdot
.128 .29648 Mdot
.128 .49979 Mdot
.13 .2962 Mdot
.13 .49998 Mdot
.132 .29592 Mdot
.132 .50017 Mdot
.134 .29564 Mdot
.134 .50037 Mdot
.136 .29536 Mdot
.136 .50056 Mdot
.138 .29509 Mdot
.138 .50075 Mdot
.14 .29481 Mdot
.14 .50094 Mdot
.142 .29453 Mdot
.142 .50113 Mdot
.144 .29426 Mdot
.144 .50132 Mdot
.146 .29398 Mdot
.146 .50151 Mdot
.148 .29371 Mdot
.148 .5017 Mdot
.15 .29344 Mdot
.15 .50189 Mdot
.152 .29316 Mdot
.152 .50207 Mdot
.154 .29289 Mdot
.154 .50226 Mdot
.156 .29262 Mdot
.156 .50244 Mdot
.158 .29235 Mdot
.158 .50263 Mdot
.16 .29208 Mdot
.16 .50281 Mdot
.162 .29182 Mdot
.162 .503 Mdot
.164 .29155 Mdot
.164 .50318 Mdot
.166 .29128 Mdot
.166 .50336 Mdot
.168 .29102 Mdot
.168 .50354 Mdot
.17 .29075 Mdot
.17 .50372 Mdot
.172 .29049 Mdot
.172 .5039 Mdot
.174 .29023 Mdot
.174 .50408 Mdot
.176 .28996 Mdot
.176 .50426 Mdot
.178 .2897 Mdot
.178 .50443 Mdot
.18 .28944 Mdot
.18 .50461 Mdot
.182 .28918 Mdot
.182 .50479 Mdot
.184 .28892 Mdot
.184 .50496 Mdot
.186 .28866 Mdot
.186 .50514 Mdot
.188 .2884 Mdot
.188 .50531 Mdot
.19 .28815 Mdot
.19 .50548 Mdot
.192 .28789 Mdot
.192 .50566 Mdot
.194 .28763 Mdot
.194 .50583 Mdot
.196 .28738 Mdot
.196 .506 Mdot
.198 .28712 Mdot
.198 .50617 Mdot
.2 .28687 Mdot
.2 .50634 Mdot
.202 .28662 Mdot
.202 .50651 Mdot
.204 .28636 Mdot
.204 .50668 Mdot
.206 .28611 Mdot
.206 .50685 Mdot
.208 .28586 Mdot
.208 .50702 Mdot
.21 .28561 Mdot
.21 .50719 Mdot
.212 .28536 Mdot
.212 .50735 Mdot
.214 .28511 Mdot
.214 .50752 Mdot
.216 .28486 Mdot
.216 .50768 Mdot
.218 .28462 Mdot
.218 .50785 Mdot
.22 .28437 Mdot
.22 .50801 Mdot
.222 .28412 Mdot
.222 .50818 Mdot
.224 .28388 Mdot
.224 .50834 Mdot
.226 .28363 Mdot
.226 .5085 Mdot
.228 .28339 Mdot
.228 .50866 Mdot
.23 .28314 Mdot
.23 .50883 Mdot
.232 .2829 Mdot
.232 .50899 Mdot
.234 .28266 Mdot
.234 .50915 Mdot
.236 .28242 Mdot
.236 .50931 Mdot
.238 .28218 Mdot
.238 .50947 Mdot
.24 .28194 Mdot
.24 .50962 Mdot
.242 .2817 Mdot
.242 .50978 Mdot
.244 .28146 Mdot
.244 .50994 Mdot
.246 .28122 Mdot
.246 .5101 Mdot
.248 .28098 Mdot
.248 .51025 Mdot
.25 .28074 Mdot
.25 .51041 Mdot
.252 .2805 Mdot
.252 .51057 Mdot
.254 .28027 Mdot
.254 .51072 Mdot
.256 .28003 Mdot
.256 .51088 Mdot
.258 .2798 Mdot
.258 .51103 Mdot
.26 .27956 Mdot
.26 .51118 Mdot
.262 .27933 Mdot
.262 .51134 Mdot
.264 .2791 Mdot
.264 .51149 Mdot
.266 .27886 Mdot
.266 .51164 Mdot
.268 .27863 Mdot
.268 .51179 Mdot
.27 .2784 Mdot
.27 .51194 Mdot
.272 .27817 Mdot
.272 .51209 Mdot
.274 .27794 Mdot
.274 .51224 Mdot
.276 .27771 Mdot
.276 .51239 Mdot
.278 .27748 Mdot
.278 .51254 Mdot
.28 .27725 Mdot
.28 .51269 Mdot
.282 .27702 Mdot
.282 .51284 Mdot
.284 .27679 Mdot
.284 .51299 Mdot
.286 .27657 Mdot
.286 .51313 Mdot
.288 .27634 Mdot
.288 .51328 Mdot
.29 .27611 Mdot
.29 .51342 Mdot
.292 .27589 Mdot
.292 .51357 Mdot
.294 .27566 Mdot
.294 .51372 Mdot
.296 .27544 Mdot
.296 .51386 Mdot
.298 .27521 Mdot
.298 .514 Mdot
.3 .27499 Mdot
.3 .51415 Mdot
.302 .27477 Mdot
.302 .51429 Mdot
.304 .27455 Mdot
.304 .51443 Mdot
.306 .27432 Mdot
.306 .51458 Mdot
.308 .2741 Mdot
.308 .51472 Mdot
.31 .27388 Mdot
.31 .51486 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27204 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .27532 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51431 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.312 .51567 Mdot
.314 .26726 Mdot
.314 .28017 Mdot
.314 .51234 Mdot
.314 .51768 Mdot
.316 .26478 Mdot
.316 .28272 Mdot
.316 .51132 Mdot
.316 .51874 Mdot
.318 .26286 Mdot
.318 .28471 Mdot
.318 .51053 Mdot
.318 .51957 Mdot
.32 .26125 Mdot
.32 .2864 Mdot
.32 .50987 Mdot
.32 .52027 Mdot
.322 .25983 Mdot
.322 .28789 Mdot
.322 .50929 Mdot
.322 .52088 Mdot
.324 .25854 Mdot
.324 .28924 Mdot
.324 .50877 Mdot
.324 .52144 Mdot
.326 .25737 Mdot
.326 .29049 Mdot
.326 .50829 Mdot
.326 .52196 Mdot
.328 .25628 Mdot
.328 .29165 Mdot
.328 .50785 Mdot
.328 .52244 Mdot
.33 .25525 Mdot
.33 .29275 Mdot
.33 .50744 Mdot
.33 .52289 Mdot
.332 .25429 Mdot
.332 .29378 Mdot
.332 .50705 Mdot
.332 .52332 Mdot
.334 .25337 Mdot
.334 .29477 Mdot
.334 .50668 Mdot
.334 .52372 Mdot
.336 .2525 Mdot
.336 .29571 Mdot
.336 .50633 Mdot
.336 .52411 Mdot
.338 .25167 Mdot
.338 .29662 Mdot
.338 .506 Mdot
.338 .52448 Mdot
.34 .25086 Mdot
.34 .29749 Mdot
.34 .50568 Mdot
.34 .52484 Mdot
.342 .25009 Mdot
.342 .29834 Mdot
.342 .50537 Mdot
.342 .52519 Mdot
.344 .24935 Mdot
.344 .29915 Mdot
.344 .50507 Mdot
.344 .52552 Mdot
.346 .24863 Mdot
.346 .29994 Mdot
.346 .50479 Mdot
.346 .52584 Mdot
.348 .24793 Mdot
.348 .30071 Mdot
.348 .50451 Mdot
.348 .52616 Mdot
.35 .24725 Mdot
.35 .30146 Mdot
.35 .50425 Mdot
.35 .52646 Mdot
.352 .24659 Mdot
.352 .30219 Mdot
.352 .50399 Mdot
.352 .52676 Mdot
.354 .24595 Mdot
.354 .3029 Mdot
.354 .50374 Mdot
.354 .52705 Mdot
.356 .24533 Mdot
.356 .30359 Mdot
.356 .50349 Mdot
.356 .52733 Mdot
.358 .24472 Mdot
.358 .30427 Mdot
.358 .50325 Mdot
.358 .52761 Mdot
.36 .24412 Mdot
.36 .30494 Mdot
.36 .50302 Mdot
.36 .52788 Mdot
.362 .24354 Mdot
.362 .30559 Mdot
.362 .5028 Mdot
.362 .52814 Mdot
.364 .24297 Mdot
.364 .30622 Mdot
.364 .50258 Mdot
.364 .5284 Mdot
.366 .24242 Mdot
.366 .30685 Mdot
.366 .50236 Mdot
.366 .52866 Mdot
.368 .24187 Mdot
.368 .30747 Mdot
.368 .50215 Mdot
.368 .52891 Mdot
.37 .24134 Mdot
.37 .30807 Mdot
.37 .50195 Mdot
.37 .52915 Mdot
.372 .24081 Mdot
.372 .30866 Mdot
.372 .50175 Mdot
.372 .52939 Mdot
.374 .2403 Mdot
.374 .30925 Mdot
.374 .50155 Mdot
.374 .52963 Mdot
.376 .23979 Mdot
.376 .30982 Mdot
.376 .50136 Mdot
.376 .52986 Mdot
.378 .23929 Mdot
.378 .31039 Mdot
.378 .50117 Mdot
.378 .53009 Mdot
.38 .23881 Mdot
.38 .31095 Mdot
.38 .50099 Mdot
.38 .53031 Mdot
.382 .23833 Mdot
.382 .3115 Mdot
.382 .50081 Mdot
.382 .53053 Mdot
.384 .23785 Mdot
.384 .31204 Mdot
.384 .50063 Mdot
.384 .53075 Mdot
.386 .23739 Mdot
.386 .31257 Mdot
.386 .50045 Mdot
.386 .53096 Mdot
.388 .23693 Mdot
.388 .3131 Mdot
.388 .50028 Mdot
.388 .53117 Mdot
.39 .23648 Mdot
.39 .31362 Mdot
.39 .50011 Mdot
.39 .53138 Mdot
.392 .23603 Mdot
.392 .31413 Mdot
.392 .49995 Mdot
.392 .53159 Mdot
.394 .23559 Mdot
.394 .31464 Mdot
.394 .49979 Mdot
.394 .53179 Mdot
.396 .23516 Mdot
.396 .31514 Mdot
.396 .49963 Mdot
.396 .53199 Mdot
.398 .23473 Mdot
.398 .31564 Mdot
.398 .49947 Mdot
.398 .53219 Mdot
.4 .23431 Mdot
.4 .31612 Mdot
.4 .49931 Mdot
.4 .53238 Mdot
.402 .2339 Mdot
.402 .31661 Mdot
.402 .49916 Mdot
.402 .53258 Mdot
.404 .23349 Mdot
.404 .31709 Mdot
.404 .49901 Mdot
.404 .53277 Mdot
.406 .23308 Mdot
.406 .31756 Mdot
.406 .49886 Mdot
.406 .53296 Mdot
.408 .23268 Mdot
.408 .31803 Mdot
.408 .49872 Mdot
.408 .53314 Mdot
.41 .23229 Mdot
.41 .31849 Mdot
.41 .49858 Mdot
.41 .53333 Mdot
.412 .2319 Mdot
.412 .31895 Mdot
.412 .49843 Mdot
.412 .53351 Mdot
.414 .23151 Mdot
.414 .3194 Mdot
.414 .4983 Mdot
.414 .53369 Mdot
.416 .23113 Mdot
.416 .31985 Mdot
.416 .49816 Mdot
.416 .53387 Mdot
.418 .23075 Mdot
.418 .3203 Mdot
.418 .49802 Mdot
.418 .53404 Mdot
.42 .23038 Mdot
.42 .32074 Mdot
.42 .49789 Mdot
.42 .53422 Mdot
.422 .23001 Mdot
.422 .32117 Mdot
.422 .49776 Mdot
.422 .53439 Mdot
.424 .22964 Mdot
.424 .32161 Mdot
.424 .49763 Mdot
.424 .53456 Mdot
.426 .22928 Mdot
.426 .32203 Mdot
.426 .4975 Mdot
.426 .53473 Mdot
.428 .22892 Mdot
.428 .32246 Mdot
.428 .49738 Mdot
.428 .5349 Mdot
.43 .22856 Mdot
.43 .22856 Mdot
.43 .22856 Mdot
.43 .22856 Mdot
.43 .22856 Mdot
.43 .22856 Mdot
.43 .22856 Mdot
.43 .22856 Mdot
.43 .22856 Mdot
.43 .22856 Mdot
.43 .22856 Mdot
.43 .22856 Mdot
.43 .22856 Mdot
.43 .22856 Mdot
.43 .22856 Mdot
.43 .22856 Mdot
.43 .22856 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .22857 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32287 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32288 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .32289 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .49725 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.43 .53506 Mdot
.432 .22611 Mdot
.432 .23077 Mdot
.432 .31772 Mdot
.432 .32798 Mdot
.432 .49505 Mdot
.432 .49957 Mdot
.432 .53429 Mdot
.432 .536 Mdot
.434 .22499 Mdot
.434 .23166 Mdot
.434 .31544 Mdot
.434 .33016 Mdot
.434 .49414 Mdot
.434 .50062 Mdot
.434 .534 Mdot
.434 .53644 Mdot
.436 .22412 Mdot
.436 .2323 Mdot
.436 .31369 Mdot
.436 .3318 Mdot
.436 .49347 Mdot
.436 .50144 Mdot
.436 .5338 Mdot
.436 .53679 Mdot
.438 .22337 Mdot
.438 .23281 Mdot
.438 .31222 Mdot
.438 .33316 Mdot
.438 .49292 Mdot
.438 .50213 Mdot
.438 .53364 Mdot
.438 .5371 Mdot
.44 .22271 Mdot
.44 .23324 Mdot
.44 .31091 Mdot
.44 .33436 Mdot
.44 .49244 Mdot
.44 .50274 Mdot
.44 .53352 Mdot
.44 .53737 Mdot
.442 .2221 Mdot
.442 .23361 Mdot
.442 .30973 Mdot
.442 .33543 Mdot
.442 .49202 Mdot
.442 .50331 Mdot
.442 .53342 Mdot
.442 .53763 Mdot
.444 .22154 Mdot
.444 .23394 Mdot
.444 .30865 Mdot
.444 .33641 Mdot
.444 .49165 Mdot
.444 .50382 Mdot
.444 .53333 Mdot
.444 .53787 Mdot
.446 .22101 Mdot
.446 .23424 Mdot
.446 .30763 Mdot
.446 .33732 Mdot
.446 .4913 Mdot
.446 .50431 Mdot
.446 .53326 Mdot
.446 .53809 Mdot
.448 .22051 Mdot
.448 .2345 Mdot
.448 .30668 Mdot
.448 .33817 Mdot
.448 .49098 Mdot
.448 .50477 Mdot
.448 .5332 Mdot
.448 .5383 Mdot
.45 .22003 Mdot
.45 .23474 Mdot
.45 .30577 Mdot
.45 .33897 Mdot
.45 .49068 Mdot
.45 .50521 Mdot
.45 .53315 Mdot
.45 .53851 Mdot
.452 .21958 Mdot
.452 .23496 Mdot
.452 .30491 Mdot
.452 .33972 Mdot
.452 .49041 Mdot
.452 .50562 Mdot
.452 .5331 Mdot
.452 .53871 Mdot
.454 .21914 Mdot
.454 .23516 Mdot
.454 .30409 Mdot
.454 .34044 Mdot
.454 .49014 Mdot
.454 .50602 Mdot
.454 .53307 Mdot
.454 .5389 Mdot
.456 .21835 Mdot
.456 .21918 Mdot
.456 .2342 Mdot
.456 .23631 Mdot
.456 .30126 Mdot
.456 .30576 Mdot
.456 .34002 Mdot
.456 .34202 Mdot
.456 .48949 Mdot
.456 .4904 Mdot
.456 .50538 Mdot
.456 .50726 Mdot
.456 .53268 Mdot
.456 .53346 Mdot
.456 .53891 Mdot
.456 .53921 Mdot
.458 .2176 Mdot
.458 .21945 Mdot
.458 .23268 Mdot
.458 .2374 Mdot
.458 .29854 Mdot
.458 .30867 Mdot
.458 .33904 Mdot
.458 .34349 Mdot
.458 .48888 Mdot
.458 .49091 Mdot
.458 .50421 Mdot
.458 .50844 Mdot
.458 .53231 Mdot
.458 .53405 Mdot
.458 .53885 Mdot
.458 .53951 Mdot
.46 .21707 Mdot
.46 .21952 Mdot
.46 .23167 Mdot
.46 .23799 Mdot
.46 .2969 Mdot
.46 .3105 Mdot
.46 .33857 Mdot
.46 .34447 Mdot
.46 .4885 Mdot
.46 .49119 Mdot
.46 .50349 Mdot
.46 .50917 Mdot
.46 .53213 Mdot
.46 .53446 Mdot
.46 .53886 Mdot
.46 .53974 Mdot
.462 .21647 Mdot
.462 .21688 Mdot
.462 .21881 Mdot
.462 .21989 Mdot
.462 .22994 Mdot
.462 .2325 Mdot
.462 .23763 Mdot
.462 .23881 Mdot
.462 .29479 Mdot
.462 .29724 Mdot
.462 .30829 Mdot
.462 .31397 Mdot
.462 .33733 Mdot
.462 .33993 Mdot
.462 .34461 Mdot
.462 .3456 Mdot
.462 .48805 Mdot
.462 .4885 Mdot
.462 .49064 Mdot
.462 .49182 Mdot
.462 .50207 Mdot
.462 .50448 Mdot
.462 .50908 Mdot
.462 .51009 Mdot
.462 .53187 Mdot
.462 .5323 Mdot
.462 .53419 Mdot
.462 .53512 Mdot
.462 .53876 Mdot
.462 .53914 Mdot
.462 .53984 Mdot
.462 .53998 Mdot
.464 .21589 Mdot
.464 .21648 Mdot
.464 .21691 Mdot
.464 .21731 Mdot
.464 .21763 Mdot
.464 .21865 Mdot
.464 .22042 Mdot
.464 .22794 Mdot
.464 .23203 Mdot
.464 .23467 Mdot
.464 .23554 Mdot
.464 .23665 Mdot
.464 .2379 Mdot
.464 .23962 Mdot
.464 .29268 Mdot
.464 .29628 Mdot
.464 .29891 Mdot
.464 .30129 Mdot
.464 .30317 Mdot
.464 .30894 Mdot
.464 .31814 Mdot
.464 .33574 Mdot
.464 .34 Mdot
.464 .34247 Mdot
.464 .34325 Mdot
.464 .34422 Mdot
.464 .34528 Mdot
.464 .34671 Mdot
.464 .48761 Mdot
.464 .48826 Mdot
.464 .48875 Mdot
.464 .4892 Mdot
.464 .48955 Mdot
.464 .49068 Mdot
.464 .4926 Mdot
.464 .50034 Mdot
.464 .50426 Mdot
.464 .50668 Mdot
.464 .50746 Mdot
.464 .50845 Mdot
.464 .50953 Mdot
.464 .51101 Mdot
.464 .5316 Mdot
.464 .53224 Mdot
.464 .5327 Mdot
.464 .53311 Mdot
.464 .53343 Mdot
.464 .5344 Mdot
.464 .53589 Mdot
.464 .5386 Mdot
.464 .53924 Mdot
.464 .5396 Mdot
.464 .53972 Mdot
.464 .53986 Mdot
.464 .54001 Mdot
.464 .54022 Mdot
.466 .21532 Mdot
.466 .21532 Mdot
.466 .21532 Mdot
.466 .21532 Mdot
.466 .21532 Mdot
.466 .21532 Mdot
.466 .21532 Mdot
.466 .21532 Mdot
.466 .21532 Mdot
.466 .21533 Mdot
.466 .21533 Mdot
.466 .21533 Mdot
.466 .21533 Mdot
.466 .21533 Mdot
.466 .21533 Mdot
.466 .21533 Mdot
.466 .21533 Mdot
.466 .21533 Mdot
.466 .21533 Mdot
.466 .21536 Mdot
.466 .21536 Mdot
.466 .21536 Mdot
.466 .21536 Mdot
.466 .21536 Mdot
.466 .21536 Mdot
.466 .21536 Mdot
.466 .21536 Mdot
.466 .21536 Mdot
.466 .21536 Mdot
.466 .21536 Mdot
.466 .21537 Mdot
.466 .21537 Mdot
.466 .21537 Mdot
.466 .21537 Mdot
.466 .21537 Mdot
.466 .21537 Mdot
.466 .21537 Mdot
.466 .21537 Mdot
.466 .21537 Mdot
.466 .21537 Mdot
.466 .21828 Mdot
.466 .21828 Mdot
.466 .21828 Mdot
.466 .21828 Mdot
.466 .21828 Mdot
.466 .21828 Mdot
.466 .21828 Mdot
.466 .21828 Mdot
.466 .21828 Mdot
.466 .21828 Mdot
.466 .2184 Mdot
.466 .2184 Mdot
.466 .2184 Mdot
.466 .2184 Mdot
.466 .2184 Mdot
.466 .2184 Mdot
.466 .2184 Mdot
.466 .2184 Mdot
.466 .2184 Mdot
.466 .2184 Mdot
.466 .2184 Mdot
.466 .21864 Mdot
.466 .21864 Mdot
.466 .21864 Mdot
.466 .21864 Mdot
.466 .21864 Mdot
.466 .21864 Mdot
.466 .21864 Mdot
.466 .21864 Mdot
.466 .21864 Mdot
.466 .21864 Mdot
.466 .21869 Mdot
.466 .21869 Mdot
.466 .21869 Mdot
.466 .21869 Mdot
.466 .21869 Mdot
.466 .21869 Mdot
.466 .21869 Mdot
.466 .21869 Mdot
.466 .21869 Mdot
.466 .21869 Mdot
.466 .22094 Mdot
.466 .22094 Mdot
.466 .22094 Mdot
.466 .22094 Mdot
.466 .22094 Mdot
.466 .22094 Mdot
.466 .22094 Mdot
.466 .22094 Mdot
.466 .22094 Mdot
.466 .22094 Mdot
.466 .221 Mdot
.466 .221 Mdot
.466 .221 Mdot
.466 .221 Mdot
.466 .221 Mdot
.466 .221 Mdot
.466 .221 Mdot
.466 .221 Mdot
.466 .221 Mdot
.466 .221 Mdot
.466 .221 Mdot
.466 .22111 Mdot
.466 .22111 Mdot
.466 .22111 Mdot
.466 .22111 Mdot
.466 .22111 Mdot
.466 .22111 Mdot
.466 .22111 Mdot
.466 .22111 Mdot
.466 .22111 Mdot
.466 .22111 Mdot
.466 .22113 Mdot
.466 .22113 Mdot
.466 .22113 Mdot
.466 .22113 Mdot
.466 .22113 Mdot
.466 .22113 Mdot
.466 .22113 Mdot
.466 .22113 Mdot
.466 .22113 Mdot
.466 .22113 Mdot
.466 .22113 Mdot
.466 .22564 Mdot
.466 .22564 Mdot
.466 .22564 Mdot
.466 .22564 Mdot
.466 .22564 Mdot
.466 .22564 Mdot
.466 .22564 Mdot
.466 .22564 Mdot
.466 .22564 Mdot
.466 .22564 Mdot
.466 .22568 Mdot
.466 .22568 Mdot
.466 .22568 Mdot
.466 .22568 Mdot
.466 .22568 Mdot
.466 .22568 Mdot
.466 .22568 Mdot
.466 .22568 Mdot
.466 .22568 Mdot
.466 .22568 Mdot
.466 .2259 Mdot
.466 .2259 Mdot
.466 .2259 Mdot
.466 .2259 Mdot
.466 .2259 Mdot
.466 .2259 Mdot
.466 .2259 Mdot
.466 .2259 Mdot
.466 .2259 Mdot
.466 .2259 Mdot
.466 .2259 Mdot
.466 .22602 Mdot
.466 .22602 Mdot
.466 .22602 Mdot
.466 .22602 Mdot
.466 .22602 Mdot
.466 .22602 Mdot
.466 .22602 Mdot
.466 .22602 Mdot
.466 .22602 Mdot
.466 .22602 Mdot
.466 .23107 Mdot
.466 .23107 Mdot
.466 .23107 Mdot
.466 .23107 Mdot
.466 .23107 Mdot
.466 .23107 Mdot
.466 .23107 Mdot
.466 .23107 Mdot
.466 .23107 Mdot
.466 .23107 Mdot
.466 .23119 Mdot
.466 .23119 Mdot
.466 .23119 Mdot
.466 .23119 Mdot
.466 .23119 Mdot
.466 .23119 Mdot
.466 .23119 Mdot
.466 .23119 Mdot
.466 .23119 Mdot
.466 .23119 Mdot
.466 .23119 Mdot
.466 .23177 Mdot
.466 .23177 Mdot
.466 .23177 Mdot
.466 .23177 Mdot
.466 .23177 Mdot
.466 .23177 Mdot
.466 .23177 Mdot
.466 .23177 Mdot
.466 .23177 Mdot
.466 .23177 Mdot
.466 .23177 Mdot
.466 .23209 Mdot
.466 .23209 Mdot
.466 .23209 Mdot
.466 .23209 Mdot
.466 .23209 Mdot
.466 .23209 Mdot
.466 .23209 Mdot
.466 .23209 Mdot
.466 .23209 Mdot
.466 .23209 Mdot
.466 .24032 Mdot
.466 .24032 Mdot
.466 .24032 Mdot
.466 .24032 Mdot
.466 .24032 Mdot
.466 .24032 Mdot
.466 .24032 Mdot
.466 .24032 Mdot
.466 .24032 Mdot
.466 .24032 Mdot
.466 .24037 Mdot
.466 .24037 Mdot
.466 .24037 Mdot
.466 .24037 Mdot
.466 .24037 Mdot
.466 .24037 Mdot
.466 .24037 Mdot
.466 .24037 Mdot
.466 .24037 Mdot
.466 .24037 Mdot
.466 .24037 Mdot
.466 .24045 Mdot
.466 .24045 Mdot
.466 .24045 Mdot
.466 .24045 Mdot
.466 .24045 Mdot
.466 .24045 Mdot
.466 .24045 Mdot
.466 .24045 Mdot
.466 .24045 Mdot
.466 .24045 Mdot
.466 .24047 Mdot
.466 .24047 Mdot
.466 .24047 Mdot
.466 .24047 Mdot
.466 .24047 Mdot
.466 .24047 Mdot
.466 .24047 Mdot
.466 .24047 Mdot
.466 .24047 Mdot
.466 .24047 Mdot
.466 .24047 Mdot
.466 .29052 Mdot
.466 .29052 Mdot
.466 .29052 Mdot
.466 .29052 Mdot
.466 .29052 Mdot
.466 .29052 Mdot
.466 .29052 Mdot
.466 .29052 Mdot
.466 .29052 Mdot
.466 .29052 Mdot
.466 .29052 Mdot
.466 .29056 Mdot
.466 .29056 Mdot
.466 .29056 Mdot
.466 .29056 Mdot
.466 .29056 Mdot
.466 .29056 Mdot
.466 .29056 Mdot
.466 .29056 Mdot
.466 .29056 Mdot
.466 .29056 Mdot
.466 .29073 Mdot
.466 .29073 Mdot
.466 .29073 Mdot
.466 .29073 Mdot
.466 .29073 Mdot
.466 .29073 Mdot
.466 .29073 Mdot
.466 .29073 Mdot
.466 .29073 Mdot
.466 .29073 Mdot
.466 .29073 Mdot
.466 .29083 Mdot
.466 .29083 Mdot
.466 .29083 Mdot
.466 .29083 Mdot
.466 .29083 Mdot
.466 .29083 Mdot
.466 .29083 Mdot
.466 .29083 Mdot
.466 .29083 Mdot
.466 .29083 Mdot
.466 .30842 Mdot
.466 .30842 Mdot
.466 .30842 Mdot
.466 .30842 Mdot
.466 .30842 Mdot
.466 .30842 Mdot
.466 .30842 Mdot
.466 .30842 Mdot
.466 .30842 Mdot
.466 .30842 Mdot
.466 .30912 Mdot
.466 .30912 Mdot
.466 .30912 Mdot
.466 .30912 Mdot
.466 .30912 Mdot
.466 .30912 Mdot
.466 .30912 Mdot
.466 .30912 Mdot
.466 .30912 Mdot
.466 .30912 Mdot
.466 .30912 Mdot
.466 .31041 Mdot
.466 .31041 Mdot
.466 .31041 Mdot
.466 .31041 Mdot
.466 .31041 Mdot
.466 .31041 Mdot
.466 .31041 Mdot
.466 .31041 Mdot
.466 .31041 Mdot
.466 .31041 Mdot
.466 .31041 Mdot
.466 .31069 Mdot
.466 .31069 Mdot
.466 .31069 Mdot
.466 .31069 Mdot
.466 .31069 Mdot
.466 .31069 Mdot
.466 .31069 Mdot
.466 .31069 Mdot
.466 .31069 Mdot
.466 .31069 Mdot
.466 .3222 Mdot
.466 .3222 Mdot
.466 .3222 Mdot
.466 .3222 Mdot
.466 .3222 Mdot
.466 .3222 Mdot
.466 .3222 Mdot
.466 .3222 Mdot
.466 .3222 Mdot
.466 .3222 Mdot
.466 .32247 Mdot
.466 .32247 Mdot
.466 .32247 Mdot
.466 .32247 Mdot
.466 .32247 Mdot
.466 .32247 Mdot
.466 .32247 Mdot
.466 .32247 Mdot
.466 .32247 Mdot
.466 .32247 Mdot
.466 .32247 Mdot
.466 .32297 Mdot
.466 .32297 Mdot
.466 .32297 Mdot
.466 .32297 Mdot
.466 .32297 Mdot
.466 .32297 Mdot
.466 .32297 Mdot
.466 .32297 Mdot
.466 .32297 Mdot
.466 .32297 Mdot
.466 .32308 Mdot
.466 .32308 Mdot
.466 .32308 Mdot
.466 .32308 Mdot
.466 .32308 Mdot
.466 .32308 Mdot
.466 .32308 Mdot
.466 .32308 Mdot
.466 .32308 Mdot
.466 .32308 Mdot
.466 .33371 Mdot
.466 .33371 Mdot
.466 .33371 Mdot
.466 .33371 Mdot
.466 .33371 Mdot
.466 .33371 Mdot
.466 .33371 Mdot
.466 .33371 Mdot
.466 .33371 Mdot
.466 .33371 Mdot
.466 .33371 Mdot
.466 .33376 Mdot
.466 .33376 Mdot
.466 .33376 Mdot
.466 .33376 Mdot
.466 .33376 Mdot
.466 .33376 Mdot
.466 .33376 Mdot
.466 .33376 Mdot
.466 .33376 Mdot
.466 .33376 Mdot
.466 .33402 Mdot
.466 .33402 Mdot
.466 .33402 Mdot
.466 .33402 Mdot
.466 .33402 Mdot
.466 .33402 Mdot
.466 .33402 Mdot
.466 .33402 Mdot
.466 .33402 Mdot
.466 .33402 Mdot
.466 .33402 Mdot
.466 .33416 Mdot
.466 .33416 Mdot
.466 .33416 Mdot
.466 .33416 Mdot
.466 .33416 Mdot
.466 .33416 Mdot
.466 .33416 Mdot
.466 .33416 Mdot
.466 .33416 Mdot
.466 .33416 Mdot
.466 .33959 Mdot
.466 .33959 Mdot
.466 .33959 Mdot
.466 .33959 Mdot
.466 .33959 Mdot
.466 .33959 Mdot
.466 .33959 Mdot
.466 .33959 Mdot
.466 .33959 Mdot
.466 .33959 Mdot
.466 .33971 Mdot
.466 .33971 Mdot
.466 .33971 Mdot
.466 .33971 Mdot
.466 .33971 Mdot
.466 .33971 Mdot
.466 .33971 Mdot
.466 .33971 Mdot
.466 .33971 Mdot
.466 .33971 Mdot
.466 .33971 Mdot
.466 .34027 Mdot
.466 .34027 Mdot
.466 .34027 Mdot
.466 .34027 Mdot
.466 .34027 Mdot
.466 .34027 Mdot
.466 .34027 Mdot
.466 .34027 Mdot
.466 .34027 Mdot
.466 .34027 Mdot
.466 .34027 Mdot
.466 .34057 Mdot
.466 .34057 Mdot
.466 .34057 Mdot
.466 .34057 Mdot
.466 .34057 Mdot
.466 .34057 Mdot
.466 .34057 Mdot
.466 .34057 Mdot
.466 .34057 Mdot
.466 .34057 Mdot
.466 .34768 Mdot
.466 .34768 Mdot
.466 .34768 Mdot
.466 .34768 Mdot
.466 .34768 Mdot
.466 .34768 Mdot
.466 .34768 Mdot
.466 .34768 Mdot
.466 .34768 Mdot
.466 .34768 Mdot
.466 .34772 Mdot
.466 .34772 Mdot
.466 .34772 Mdot
.466 .34772 Mdot
.466 .34772 Mdot
.466 .34772 Mdot
.466 .34772 Mdot
.466 .34772 Mdot
.466 .34772 Mdot
.466 .34772 Mdot
.466 .34772 Mdot
.466 .34778 Mdot
.466 .34778 Mdot
.466 .34778 Mdot
.466 .34778 Mdot
.466 .34778 Mdot
.466 .34778 Mdot
.466 .34778 Mdot
.466 .34778 Mdot
.466 .34778 Mdot
.466 .34778 Mdot
.466 .3478 Mdot
.466 .3478 Mdot
.466 .3478 Mdot
.466 .3478 Mdot
.466 .3478 Mdot
.466 .3478 Mdot
.466 .3478 Mdot
.466 .3478 Mdot
.466 .3478 Mdot
.466 .3478 Mdot
.466 .3478 Mdot
.466 .48717 Mdot
.466 .48717 Mdot
.466 .48717 Mdot
.466 .48717 Mdot
.466 .48717 Mdot
.466 .48717 Mdot
.466 .48717 Mdot
.466 .48717 Mdot
.466 .48718 Mdot
.466 .48718 Mdot
.466 .48718 Mdot
.466 .48718 Mdot
.466 .48718 Mdot
.466 .48718 Mdot
.466 .48718 Mdot
.466 .48718 Mdot
.466 .48718 Mdot
.466 .48718 Mdot
.466 .48721 Mdot
.466 .48721 Mdot
.466 .48721 Mdot
.466 .48721 Mdot
.466 .48721 Mdot
.466 .48721 Mdot
.466 .48721 Mdot
.466 .48721 Mdot
.466 .48721 Mdot
.466 .48721 Mdot
.466 .48721 Mdot
.466 .48723 Mdot
.466 .48723 Mdot
.466 .48723 Mdot
.466 .48723 Mdot
.466 .48723 Mdot
.466 .48723 Mdot
.466 .48723 Mdot
.466 .48723 Mdot
.466 .48723 Mdot
.466 .48723 Mdot
.466 .49048 Mdot
.466 .49048 Mdot
.466 .49048 Mdot
.466 .49048 Mdot
.466 .49048 Mdot
.466 .49048 Mdot
.466 .49048 Mdot
.466 .49048 Mdot
.466 .49048 Mdot
.466 .49048 Mdot
.466 .49062 Mdot
.466 .49062 Mdot
.466 .49062 Mdot
.466 .49062 Mdot
.466 .49062 Mdot
.466 .49062 Mdot
.466 .49062 Mdot
.466 .49062 Mdot
.466 .49062 Mdot
.466 .49062 Mdot
.466 .49062 Mdot
.466 .49087 Mdot
.466 .49087 Mdot
.466 .49087 Mdot
.466 .49087 Mdot
.466 .49087 Mdot
.466 .49087 Mdot
.466 .49087 Mdot
.466 .49087 Mdot
.466 .49087 Mdot
.466 .49087 Mdot
.466 .49093 Mdot
.466 .49093 Mdot
.466 .49093 Mdot
.466 .49093 Mdot
.466 .49093 Mdot
.466 .49093 Mdot
.466 .49093 Mdot
.466 .49093 Mdot
.466 .49093 Mdot
.466 .49093 Mdot
.466 .49337 Mdot
.466 .49337 Mdot
.466 .49337 Mdot
.466 .49337 Mdot
.466 .49337 Mdot
.466 .49337 Mdot
.466 .49337 Mdot
.466 .49337 Mdot
.466 .49337 Mdot
.466 .49337 Mdot
.466 .49343 Mdot
.466 .49343 Mdot
.466 .49343 Mdot
.466 .49343 Mdot
.466 .49343 Mdot
.466 .49343 Mdot
.466 .49343 Mdot
.466 .49343 Mdot
.466 .49343 Mdot
.466 .49343 Mdot
.466 .49343 Mdot
.466 .49355 Mdot
.466 .49355 Mdot
.466 .49355 Mdot
.466 .49355 Mdot
.466 .49355 Mdot
.466 .49355 Mdot
.466 .49355 Mdot
.466 .49355 Mdot
.466 .49355 Mdot
.466 .49355 Mdot
.466 .49357 Mdot
.466 .49357 Mdot
.466 .49357 Mdot
.466 .49357 Mdot
.466 .49357 Mdot
.466 .49357 Mdot
.466 .49357 Mdot
.466 .49357 Mdot
.466 .49357 Mdot
.466 .49357 Mdot
.466 .49357 Mdot
.466 .49826 Mdot
.466 .49826 Mdot
.466 .49826 Mdot
.466 .49826 Mdot
.466 .49826 Mdot
.466 .49826 Mdot
.466 .49826 Mdot
.466 .49826 Mdot
.466 .49826 Mdot
.466 .49826 Mdot
.466 .4983 Mdot
.466 .4983 Mdot
.466 .4983 Mdot
.466 .4983 Mdot
.466 .4983 Mdot
.466 .4983 Mdot
.466 .4983 Mdot
.466 .4983 Mdot
.466 .4983 Mdot
.466 .4983 Mdot
.466 .49852 Mdot
.466 .49852 Mdot
.466 .49852 Mdot
.466 .49852 Mdot
.466 .49852 Mdot
.466 .49852 Mdot
.466 .49852 Mdot
.466 .49852 Mdot
.466 .49852 Mdot
.466 .49852 Mdot
.466 .49852 Mdot
.466 .49864 Mdot
.466 .49864 Mdot
.466 .49864 Mdot
.466 .49864 Mdot
.466 .49864 Mdot
.466 .49864 Mdot
.466 .49864 Mdot
.466 .49864 Mdot
.466 .49864 Mdot
.466 .49864 Mdot
.466 .50357 Mdot
.466 .50357 Mdot
.466 .50357 Mdot
.466 .50357 Mdot
.466 .50357 Mdot
.466 .50357 Mdot
.466 .50357 Mdot
.466 .50357 Mdot
.466 .50357 Mdot
.466 .50357 Mdot
.466 .50369 Mdot
.466 .50369 Mdot
.466 .50369 Mdot
.466 .50369 Mdot
.466 .50369 Mdot
.466 .50369 Mdot
.466 .50369 Mdot
.466 .50369 Mdot
.466 .50369 Mdot
.466 .50369 Mdot
.466 .50369 Mdot
.466 .50424 Mdot
.466 .50424 Mdot
.466 .50424 Mdot
.466 .50424 Mdot
.466 .50424 Mdot
.466 .50424 Mdot
.466 .50424 Mdot
.466 .50424 Mdot
.466 .50424 Mdot
.466 .50424 Mdot
.466 .50424 Mdot
.466 .50453 Mdot
.466 .50453 Mdot
.466 .50453 Mdot
.466 .50453 Mdot
.466 .50453 Mdot
.466 .50453 Mdot
.466 .50453 Mdot
.466 .50453 Mdot
.466 .50453 Mdot
.466 .50453 Mdot
.466 .51181 Mdot
.466 .51181 Mdot
.466 .51181 Mdot
.466 .51181 Mdot
.466 .51181 Mdot
.466 .51181 Mdot
.466 .51181 Mdot
.466 .51181 Mdot
.466 .51181 Mdot
.466 .51181 Mdot
.466 .51185 Mdot
.466 .51185 Mdot
.466 .51185 Mdot
.466 .51185 Mdot
.466 .51185 Mdot
.466 .51185 Mdot
.466 .51185 Mdot
.466 .51185 Mdot
.466 .51185 Mdot
.466 .51185 Mdot
.466 .51185 Mdot
.466 .51192 Mdot
.466 .51192 Mdot
.466 .51192 Mdot
.466 .51192 Mdot
.466 .51192 Mdot
.466 .51192 Mdot
.466 .51192 Mdot
.466 .51192 Mdot
.466 .51192 Mdot
.466 .51192 Mdot
.466 .51193 Mdot
.466 .51193 Mdot
.466 .51193 Mdot
.466 .51193 Mdot
.466 .51193 Mdot
.466 .51193 Mdot
.466 .51193 Mdot
.466 .51193 Mdot
.466 .51193 Mdot
.466 .51193 Mdot
.466 .51193 Mdot
.466 .53133 Mdot
.466 .53133 Mdot
.466 .53133 Mdot
.466 .53133 Mdot
.466 .53133 Mdot
.466 .53133 Mdot
.466 .53133 Mdot
.466 .53133 Mdot
.466 .53133 Mdot
.466 .53133 Mdot
.466 .53133 Mdot
.466 .53133 Mdot
.466 .53133 Mdot
.466 .53133 Mdot
.466 .53133 Mdot
.466 .53133 Mdot
.466 .53133 Mdot
.466 .53133 Mdot
.466 .53133 Mdot
.466 .53136 Mdot
.466 .53136 Mdot
.466 .53136 Mdot
.466 .53136 Mdot
.466 .53136 Mdot
.466 .53136 Mdot
.466 .53136 Mdot
.466 .53136 Mdot
.466 .53136 Mdot
.466 .53136 Mdot
.466 .53136 Mdot
.466 .53138 Mdot
.466 .53138 Mdot
.466 .53138 Mdot
.466 .53138 Mdot
.466 .53138 Mdot
.466 .53138 Mdot
.466 .53138 Mdot
.466 .53138 Mdot
.466 .53138 Mdot
.466 .53138 Mdot
.466 .53441 Mdot
.466 .53441 Mdot
.466 .53441 Mdot
.466 .53441 Mdot
.466 .53441 Mdot
.466 .53441 Mdot
.466 .53441 Mdot
.466 .53441 Mdot
.466 .53441 Mdot
.466 .53441 Mdot
.466 .53453 Mdot
.466 .53453 Mdot
.466 .53453 Mdot
.466 .53453 Mdot
.466 .53453 Mdot
.466 .53453 Mdot
.466 .53453 Mdot
.466 .53453 Mdot
.466 .53453 Mdot
.466 .53453 Mdot
.466 .53453 Mdot
.466 .53474 Mdot
.466 .53474 Mdot
.466 .53474 Mdot
.466 .53474 Mdot
.466 .53474 Mdot
.466 .53474 Mdot
.466 .53474 Mdot
.466 .53474 Mdot
.466 .53474 Mdot
.466 .53474 Mdot
.466 .53474 Mdot
.466 .53478 Mdot
.466 .53478 Mdot
.466 .53478 Mdot
.466 .53478 Mdot
.466 .53478 Mdot
.466 .53478 Mdot
.466 .53478 Mdot
.466 .53478 Mdot
.466 .53478 Mdot
.466 .53478 Mdot
.466 .53662 Mdot
.466 .53662 Mdot
.466 .53662 Mdot
.466 .53662 Mdot
.466 .53662 Mdot
.466 .53662 Mdot
.466 .53662 Mdot
.466 .53662 Mdot
.466 .53662 Mdot
.466 .53662 Mdot
.466 .53666 Mdot
.466 .53666 Mdot
.466 .53666 Mdot
.466 .53666 Mdot
.466 .53666 Mdot
.466 .53666 Mdot
.466 .53666 Mdot
.466 .53666 Mdot
.466 .53666 Mdot
.466 .53666 Mdot
.466 .53666 Mdot
.466 .53674 Mdot
.466 .53674 Mdot
.466 .53674 Mdot
.466 .53674 Mdot
.466 .53674 Mdot
.466 .53674 Mdot
.466 .53674 Mdot
.466 .53674 Mdot
.466 .53674 Mdot
.466 .53674 Mdot
.466 .53676 Mdot
.466 .53676 Mdot
.466 .53676 Mdot
.466 .53676 Mdot
.466 .53676 Mdot
.466 .53676 Mdot
.466 .53676 Mdot
.466 .53676 Mdot
.466 .53676 Mdot
.466 .53676 Mdot
.466 .53838 Mdot
.466 .53838 Mdot
.466 .53838 Mdot
.466 .53838 Mdot
.466 .53838 Mdot
.466 .53838 Mdot
.466 .53838 Mdot
.466 .53838 Mdot
.466 .53838 Mdot
.466 .53838 Mdot
.466 .53838 Mdot
.466 .53839 Mdot
.466 .53839 Mdot
.466 .53839 Mdot
.466 .53839 Mdot
.466 .53839 Mdot
.466 .53839 Mdot
.466 .53839 Mdot
.466 .53839 Mdot
.466 .53839 Mdot
.466 .53839 Mdot
.466 .53843 Mdot
.466 .53843 Mdot
.466 .53843 Mdot
.466 .53843 Mdot
.466 .53843 Mdot
.466 .53843 Mdot
.466 .53843 Mdot
.466 .53843 Mdot
.466 .53843 Mdot
.466 .53843 Mdot
.466 .53843 Mdot
.466 .53845 Mdot
.466 .53845 Mdot
.466 .53845 Mdot
.466 .53845 Mdot
.466 .53845 Mdot
.466 .53845 Mdot
.466 .53845 Mdot
.466 .53845 Mdot
.466 .53845 Mdot
.466 .53845 Mdot
.466 .53926 Mdot
.466 .53926 Mdot
.466 .53926 Mdot
.466 .53926 Mdot
.466 .53926 Mdot
.466 .53926 Mdot
.466 .53926 Mdot
.466 .53926 Mdot
.466 .53926 Mdot
.466 .53926 Mdot
.466 .53927 Mdot
.466 .53927 Mdot
.466 .53927 Mdot
.466 .53927 Mdot
.466 .53927 Mdot
.466 .53927 Mdot
.466 .53927 Mdot
.466 .53927 Mdot
.466 .53927 Mdot
.466 .53927 Mdot
.466 .53936 Mdot
.466 .53936 Mdot
.466 .53936 Mdot
.466 .53936 Mdot
.466 .53936 Mdot
.466 .53936 Mdot
.466 .53936 Mdot
.466 .53936 Mdot
.466 .53936 Mdot
.466 .53936 Mdot
.466 .53936 Mdot
.466 .5394 Mdot
.466 .5394 Mdot
.466 .5394 Mdot
.466 .5394 Mdot
.466 .5394 Mdot
.466 .5394 Mdot
.466 .5394 Mdot
.466 .5394 Mdot
.466 .5394 Mdot
.466 .5394 Mdot
.466 .54044 Mdot
.466 .54044 Mdot
.466 .54044 Mdot
.466 .54044 Mdot
.466 .54044 Mdot
.466 .54044 Mdot
.466 .54044 Mdot
.466 .54044 Mdot
.466 .54044 Mdot
.466 .54044 Mdot
.466 .54044 Mdot
.466 .54044 Mdot
.466 .54044 Mdot
.466 .54044 Mdot
.466 .54044 Mdot
.466 .54044 Mdot
.466 .54044 Mdot
.466 .54044 Mdot
.466 .54044 Mdot
.466 .54045 Mdot
.466 .54045 Mdot
.466 .54045 Mdot
.466 .54045 Mdot
.466 .54045 Mdot
.466 .54045 Mdot
.466 .54045 Mdot
.466 .54046 Mdot
.466 .54046 Mdot
.466 .54046 Mdot
.466 .54046 Mdot
.468 .21475 Mdot
.468 .21475 Mdot
.468 .21476 Mdot
.468 .21477 Mdot
.468 .21478 Mdot
.468 .21481 Mdot
.468 .21482 Mdot
.468 .21482 Mdot
.468 .21483 Mdot
.468 .21484 Mdot
.468 .21484 Mdot
.468 .21486 Mdot
.468 .21486 Mdot
.468 .21487 Mdot
.468 .2149 Mdot
.468 .21497 Mdot
.468 .215 Mdot
.468 .215 Mdot
.468 .21503 Mdot
.468 .21503 Mdot
.468 .21517 Mdot
.468 .2152 Mdot
.468 .21528 Mdot
.468 .21532 Mdot
.468 .21535 Mdot
.468 .21541 Mdot
.468 .21544 Mdot
.468 .21546 Mdot
.468 .21547 Mdot
.468 .21558 Mdot
.468 .21564 Mdot
.468 .21577 Mdot
.468 .2158 Mdot
.468 .21585 Mdot
.468 .21587 Mdot
.468 .2159 Mdot
.468 .2159 Mdot
.468 .21591 Mdot
.468 .21594 Mdot
.468 .21604 Mdot
.468 .2161 Mdot
.468 .2163 Mdot
.468 .21636 Mdot
.468 .21642 Mdot
.468 .21645 Mdot
.468 .21648 Mdot
.468 .21661 Mdot
.468 .21672 Mdot
.468 .21672 Mdot
.468 .21675 Mdot
.468 .2168 Mdot
.468 .21703 Mdot
.468 .21705 Mdot
.468 .21716 Mdot
.468 .21723 Mdot
.468 .21741 Mdot
.468 .21745 Mdot
.468 .21749 Mdot
.468 .21768 Mdot
.468 .21771 Mdot
.468 .21775 Mdot
.468 .21775 Mdot
.468 .21777 Mdot
.468 .21778 Mdot
.468 .21787 Mdot
.468 .21792 Mdot
.468 .21808 Mdot
.468 .21818 Mdot
.468 .21821 Mdot
.468 .21851 Mdot
.468 .21855 Mdot
.468 .21858 Mdot
.468 .21863 Mdot
.468 .21879 Mdot
.468 .21883 Mdot
.468 .219 Mdot
.468 .21915 Mdot
.468 .21918 Mdot
.468 .21928 Mdot
.468 .21929 Mdot
.468 .21937 Mdot
.468 .21942 Mdot
.468 .21954 Mdot
.468 .21959 Mdot
.468 .21961 Mdot
.468 .21964 Mdot
.468 .2197 Mdot
.468 .21987 Mdot
.468 .21996 Mdot
.468 .22011 Mdot
.468 .22011 Mdot
.468 .22016 Mdot
.468 .22028 Mdot
.468 .22029 Mdot
.468 .22034 Mdot
.468 .22048 Mdot
.468 .2205 Mdot
.468 .22061 Mdot
.468 .22062 Mdot
.468 .22083 Mdot
.468 .22096 Mdot
.468 .22098 Mdot
.468 .22101 Mdot
.468 .22109 Mdot
.468 .22116 Mdot
.468 .22128 Mdot
.468 .22133 Mdot
.468 .22138 Mdot
.468 .22141 Mdot
.468 .22142 Mdot
.468 .22154 Mdot
.468 .2216 Mdot
.468 .2216 Mdot
.468 .22166 Mdot
.468 .22168 Mdot
.468 .22174 Mdot
.468 .22174 Mdot
.468 .22178 Mdot
.468 .22179 Mdot
.468 .22193 Mdot
.468 .22198 Mdot
.468 .22203 Mdot
.468 .22205 Mdot
.468 .22206 Mdot
.468 .22207 Mdot
.468 .22305 Mdot
.468 .22306 Mdot
.468 .22309 Mdot
.468 .22313 Mdot
.468 .2232 Mdot
.468 .2233 Mdot
.468 .22356 Mdot
.468 .22357 Mdot
.468 .22364 Mdot
.468 .22365 Mdot
.468 .22375 Mdot
.468 .22379 Mdot
.468 .22391 Mdot
.468 .22391 Mdot
.468 .22402 Mdot
.468 .22425 Mdot
.468 .22427 Mdot
.468 .22432 Mdot
.468 .22441 Mdot
.468 .22452 Mdot
.468 .22474 Mdot
.468 .22488 Mdot
.468 .22504 Mdot
.468 .22511 Mdot
.468 .22515 Mdot
.468 .2254 Mdot
.468 .22583 Mdot
.468 .22586 Mdot
.468 .22608 Mdot
.468 .22612 Mdot
.468 .22642 Mdot
.468 .22654 Mdot
.468 .22656 Mdot
.468 .22681 Mdot
.468 .22691 Mdot
.468 .22692 Mdot
.468 .22724 Mdot
.468 .22744 Mdot
.468 .22781 Mdot
.468 .22796 Mdot
.468 .22801 Mdot
.468 .22806 Mdot
.468 .22817 Mdot
.468 .22844 Mdot
.468 .22856 Mdot
.468 .22876 Mdot
.468 .22878 Mdot
.468 .22902 Mdot
.468 .22908 Mdot
.468 .22944 Mdot
.468 .22985 Mdot
.468 .22994 Mdot
.468 .23034 Mdot
.468 .23047 Mdot
.468 .23054 Mdot
.468 .23064 Mdot
.468 .23137 Mdot
.468 .23147 Mdot
.468 .23172 Mdot
.468 .23212 Mdot
.468 .23226 Mdot
.468 .23251 Mdot
.468 .23252 Mdot
.468 .23257 Mdot
.468 .23258 Mdot
.468 .23268 Mdot
.468 .23276 Mdot
.468 .23327 Mdot
.468 .23338 Mdot
.468 .23348 Mdot
.468 .23397 Mdot
.468 .23416 Mdot
.468 .23446 Mdot
.468 .23452 Mdot
.468 .23516 Mdot
.468 .2353 Mdot
.468 .23539 Mdot
.468 .2354 Mdot
.468 .23571 Mdot
.468 .23609 Mdot
.468 .23617 Mdot
.468 .23625 Mdot
.468 .23642 Mdot
.468 .23661 Mdot
.468 .23718 Mdot
.468 .23739 Mdot
.468 .23768 Mdot
.468 .23775 Mdot
.468 .23778 Mdot
.468 .23778 Mdot
.468 .23788 Mdot
.468 .23793 Mdot
.468 .23809 Mdot
.468 .23819 Mdot
.468 .23857 Mdot
.468 .23877 Mdot
.468 .23909 Mdot
.468 .23912 Mdot
.468 .23921 Mdot
.468 .23929 Mdot
.468 .23947 Mdot
.468 .23956 Mdot
.468 .2397 Mdot
.468 .23993 Mdot
.468 .24003 Mdot
.468 .24046 Mdot
.468 .24056 Mdot
.468 .24057 Mdot
.468 .24066 Mdot
.468 .2409 Mdot
.468 .24099 Mdot
.468 .24103 Mdot
.468 .24103 Mdot
.468 .24108 Mdot
.468 .24109 Mdot
.468 .24113 Mdot
.468 .24113 Mdot
.468 .24116 Mdot
.468 .24117 Mdot
.468 .24127 Mdot
.468 .24131 Mdot
.468 .24133 Mdot
.468 .24135 Mdot
.468 .24136 Mdot
.468 .24137 Mdot
.468 .28826 Mdot
.468 .28827 Mdot
.468 .2883 Mdot
.468 .28832 Mdot
.468 .28838 Mdot
.468 .28846 Mdot
.468 .28867 Mdot
.468 .28868 Mdot
.468 .28873 Mdot
.468 .28874 Mdot
.468 .28882 Mdot
.468 .28885 Mdot
.468 .28895 Mdot
.468 .28895 Mdot
.468 .28903 Mdot
.468 .28921 Mdot
.468 .2897 Mdot
.468 .28988 Mdot
.468 .28991 Mdot
.468 .29011 Mdot
.468 .291 Mdot
.468 .2912 Mdot
.468 .29168 Mdot
.468 .29196 Mdot
.468 .29215 Mdot
.468 .29254 Mdot
.468 .29271 Mdot
.468 .29289 Mdot
.468 .29294 Mdot
.468 .29362 Mdot
.468 .29403 Mdot
.468 .29484 Mdot
.468 .29504 Mdot
.468 .29538 Mdot
.468 .29549 Mdot
.468 .29569 Mdot
.468 .2957 Mdot
.468 .29575 Mdot
.468 .29591 Mdot
.468 .29653 Mdot
.468 .29696 Mdot
.468 .29819 Mdot
.468 .29858 Mdot
.468 .29895 Mdot
.468 .29912 Mdot
.468 .2993 Mdot
.468 .30012 Mdot
.468 .30077 Mdot
.468 .3008 Mdot
.468 .30098 Mdot
.468 .3013 Mdot
.468 .30269 Mdot
.468 .30281 Mdot
.468 .30347 Mdot
.468 .30388 Mdot
.468 .30495 Mdot
.468 .30517 Mdot
.468 .30542 Mdot
.468 .30653 Mdot
.468 .30671 Mdot
.468 .30693 Mdot
.468 .30696 Mdot
.468 .30708 Mdot
.468 .3071 Mdot
.468 .30766 Mdot
.468 .30795 Mdot
.468 .30885 Mdot
.468 .30941 Mdot
.468 .30962 Mdot
.468 .31126 Mdot
.468 .3115 Mdot
.468 .31165 Mdot
.468 .31194 Mdot
.468 .31283 Mdot
.468 .31303 Mdot
.468 .31397 Mdot
.468 .31479 Mdot
.468 .31494 Mdot
.468 .31548 Mdot
.468 .31551 Mdot
.468 .31597 Mdot
.468 .31624 Mdot
.468 .31686 Mdot
.468 .31711 Mdot
.468 .31724 Mdot
.468 .31735 Mdot
.468 .31769 Mdot
.468 .31854 Mdot
.468 .31899 Mdot
.468 .31975 Mdot
.468 .31977 Mdot
.468 .31999 Mdot
.468 .32058 Mdot
.468 .32063 Mdot
.468 .32091 Mdot
.468 .32159 Mdot
.468 .32169 Mdot
.468 .32219 Mdot
.468 .32227 Mdot
.468 .32327 Mdot
.468 .32386 Mdot
.468 .32395 Mdot
.468 .3241 Mdot
.468 .32448 Mdot
.468 .32481 Mdot
.468 .32534 Mdot
.468 .32558 Mdot
.468 .32579 Mdot
.468 .32592 Mdot
.468 .32596 Mdot
.468 .32651 Mdot
.468 .32676 Mdot
.468 .32676 Mdot
.468 .32705 Mdot
.468 .32714 Mdot
.468 .32737 Mdot
.468 .3274 Mdot
.468 .32757 Mdot
.468 .3276 Mdot
.468 .3282 Mdot
.468 .32844 Mdot
.468 .32861 Mdot
.468 .32869 Mdot
.468 .32876 Mdot
.468 .3288 Mdot
.468 .33112 Mdot
.468 .33114 Mdot
.468 .33118 Mdot
.468 .33123 Mdot
.468 .33133 Mdot
.468 .33146 Mdot
.468 .3318 Mdot
.468 .33181 Mdot
.468 .3319 Mdot
.468 .33192 Mdot
.468 .33204 Mdot
.468 .33209 Mdot
.468 .33225 Mdot
.468 .33225 Mdot
.468 .33239 Mdot
.468 .33268 Mdot
.468 .33271 Mdot
.468 .33277 Mdot
.468 .33288 Mdot
.468 .33301 Mdot
.468 .33329 Mdot
.468 .33346 Mdot
.468 .33366 Mdot
.468 .33374 Mdot
.468 .33378 Mdot
.468 .33408 Mdot
.468 .33459 Mdot
.468 .33463 Mdot
.468 .33488 Mdot
.468 .33493 Mdot
.468 .33526 Mdot
.468 .3354 Mdot
.468 .33542 Mdot
.468 .33571 Mdot
.468 .33582 Mdot
.468 .33582 Mdot
.468 .33619 Mdot
.468 .3364 Mdot
.468 .3368 Mdot
.468 .33696 Mdot
.468 .33702 Mdot
.468 .33707 Mdot
.468 .33719 Mdot
.468 .33748 Mdot
.468 .3376 Mdot
.468 .33781 Mdot
.468 .33782 Mdot
.468 .33807 Mdot
.468 .33814 Mdot
.468 .3385 Mdot
.468 .33892 Mdot
.468 .33901 Mdot
.468 .3394 Mdot
.468 .33953 Mdot
.468 .3396 Mdot
.468 .3397 Mdot
.468 .34041 Mdot
.468 .3405 Mdot
.468 .34074 Mdot
.468 .34112 Mdot
.468 .34124 Mdot
.468 .34148 Mdot
.468 .34148 Mdot
.468 .34154 Mdot
.468 .34155 Mdot
.468 .34164 Mdot
.468 .34171 Mdot
.468 .34218 Mdot
.468 .34228 Mdot
.468 .34237 Mdot
.468 .34281 Mdot
.468 .34297 Mdot
.468 .34324 Mdot
.468 .34329 Mdot
.468 .34385 Mdot
.468 .34398 Mdot
.468 .34405 Mdot
.468 .34406 Mdot
.468 .34433 Mdot
.468 .34465 Mdot
.468 .34472 Mdot
.468 .34479 Mdot
.468 .34494 Mdot
.468 .34509 Mdot
.468 .34557 Mdot
.468 .34574 Mdot
.468 .34598 Mdot
.468 .34604 Mdot
.468 .34606 Mdot
.468 .34606 Mdot
.468 .34614 Mdot
.468 .34619 Mdot
.468 .34631 Mdot
.468 .34639 Mdot
.468 .3467 Mdot
.468 .34686 Mdot
.468 .34712 Mdot
.468 .34714 Mdot
.468 .34721 Mdot
.468 .34728 Mdot
.468 .34742 Mdot
.468 .3475 Mdot
.468 .34761 Mdot
.468 .34779 Mdot
.468 .34787 Mdot
.468 .3482 Mdot
.468 .34822 Mdot
.468 .34828 Mdot
.468 .34829 Mdot
.468 .34836 Mdot
.468 .34854 Mdot
.468 .34861 Mdot
.468 .34864 Mdot
.468 .34864 Mdot
.468 .34868 Mdot
.468 .34869 Mdot
.468 .34872 Mdot
.468 .34872 Mdot
.468 .34874 Mdot
.468 .34875 Mdot
.468 .34882 Mdot
.468 .34885 Mdot
.468 .34888 Mdot
.468 .34889 Mdot
.468 .3489 Mdot
.468 .3489 Mdot
.468 .48673 Mdot
.468 .48673 Mdot
.468 .48674 Mdot
.468 .48675 Mdot
.468 .48677 Mdot
.468 .4868 Mdot
.468 .4868 Mdot
.468 .48681 Mdot
.468 .48682 Mdot
.468 .48683 Mdot
.468 .48683 Mdot
.468 .48685 Mdot
.468 .48685 Mdot
.468 .48687 Mdot
.468 .4869 Mdot
.468 .48698 Mdot
.468 .48702 Mdot
.468 .48702 Mdot
.468 .48705 Mdot
.468 .48705 Mdot
.468 .48721 Mdot
.468 .48725 Mdot
.468 .48733 Mdot
.468 .48738 Mdot
.468 .48741 Mdot
.468 .48748 Mdot
.468 .48751 Mdot
.468 .48754 Mdot
.468 .48755 Mdot
.468 .48767 Mdot
.468 .48775 Mdot
.468 .48789 Mdot
.468 .48793 Mdot
.468 .48798 Mdot
.468 .488 Mdot
.468 .48804 Mdot
.468 .48804 Mdot
.468 .48805 Mdot
.468 .48808 Mdot
.468 .48819 Mdot
.468 .48827 Mdot
.468 .48849 Mdot
.468 .48856 Mdot
.468 .48863 Mdot
.468 .48866 Mdot
.468 .48869 Mdot
.468 .48884 Mdot
.468 .48896 Mdot
.468 .48896 Mdot
.468 .489 Mdot
.468 .48906 Mdot
.468 .48931 Mdot
.468 .48933 Mdot
.468 .48946 Mdot
.468 .48953 Mdot
.468 .48973 Mdot
.468 .48977 Mdot
.468 .48982 Mdot
.468 .49003 Mdot
.468 .49007 Mdot
.468 .49011 Mdot
.468 .49011 Mdot
.468 .49013 Mdot
.468 .49014 Mdot
.468 .49024 Mdot
.468 .4903 Mdot
.468 .49047 Mdot
.468 .49058 Mdot
.468 .49062 Mdot
.468 .49094 Mdot
.468 .49099 Mdot
.468 .49102 Mdot
.468 .49108 Mdot
.468 .49126 Mdot
.468 .4913 Mdot
.468 .49148 Mdot
.468 .49165 Mdot
.468 .49168 Mdot
.468 .49179 Mdot
.468 .4918 Mdot
.468 .49189 Mdot
.468 .49195 Mdot
.468 .49208 Mdot
.468 .49213 Mdot
.468 .49216 Mdot
.468 .49218 Mdot
.468 .49225 Mdot
.468 .49243 Mdot
.468 .49253 Mdot
.468 .49269 Mdot
.468 .49269 Mdot
.468 .49274 Mdot
.468 .49287 Mdot
.468 .49288 Mdot
.468 .49294 Mdot
.468 .49309 Mdot
.468 .49311 Mdot
.468 .49323 Mdot
.468 .49324 Mdot
.468 .49347 Mdot
.468 .4936 Mdot
.468 .49362 Mdot
.468 .49366 Mdot
.468 .49375 Mdot
.468 .49382 Mdot
.468 .49395 Mdot
.468 .494 Mdot
.468 .49405 Mdot
.468 .49408 Mdot
.468 .49409 Mdot
.468 .49422 Mdot
.468 .49428 Mdot
.468 .49428 Mdot
.468 .49435 Mdot
.468 .49438 Mdot
.468 .49443 Mdot
.468 .49444 Mdot
.468 .49448 Mdot
.468 .49449 Mdot
.468 .49464 Mdot
.468 .49469 Mdot
.468 .49474 Mdot
.468 .49476 Mdot
.468 .49478 Mdot
.468 .49479 Mdot
.468 .49581 Mdot
.468 .49583 Mdot
.468 .49586 Mdot
.468 .4959 Mdot
.468 .49597 Mdot
.468 .49608 Mdot
.468 .49634 Mdot
.468 .49635 Mdot
.468 .49643 Mdot
.468 .49644 Mdot
.468 .49654 Mdot
.468 .49658 Mdot
.468 .49671 Mdot
.468 .49671 Mdot
.468 .49682 Mdot
.468 .49706 Mdot
.468 .49708 Mdot
.468 .49713 Mdot
.468 .49722 Mdot
.468 .49733 Mdot
.468 .49756 Mdot
.468 .4977 Mdot
.468 .49787 Mdot
.468 .49794 Mdot
.468 .49798 Mdot
.468 .49823 Mdot
.468 .49867 Mdot
.468 .4987 Mdot
.468 .49892 Mdot
.468 .49896 Mdot
.468 .49926 Mdot
.468 .49938 Mdot
.468 .4994 Mdot
.468 .49966 Mdot
.468 .49975 Mdot
.468 .49976 Mdot
.468 .50009 Mdot
.468 .50028 Mdot
.468 .50065 Mdot
.468 .50079 Mdot
.468 .50084 Mdot
.468 .50089 Mdot
.468 .501 Mdot
.468 .50127 Mdot
.468 .50138 Mdot
.468 .50158 Mdot
.468 .50159 Mdot
.468 .50183 Mdot
.468 .50189 Mdot
.468 .50224 Mdot
.468 .50264 Mdot
.468 .50272 Mdot
.468 .5031 Mdot
.468 .50323 Mdot
.468 .50329 Mdot
.468 .50339 Mdot
.468 .50408 Mdot
.468 .50417 Mdot
.468 .50441 Mdot
.468 .50479 Mdot
.468 .50491 Mdot
.468 .50514 Mdot
.468 .50515 Mdot
.468 .5052 Mdot
.468 .50521 Mdot
.468 .50531 Mdot
.468 .50538 Mdot
.468 .50585 Mdot
.468 .50595 Mdot
.468 .50605 Mdot
.468 .50649 Mdot
.468 .50666 Mdot
.468 .50694 Mdot
.468 .50699 Mdot
.468 .50756 Mdot
.468 .5077 Mdot
.468 .50777 Mdot
.468 .50778 Mdot
.468 .50805 Mdot
.468 .50839 Mdot
.468 .50847 Mdot
.468 .50853 Mdot
.468 .50869 Mdot
.468 .50885 Mdot
.468 .50936 Mdot
.468 .50953 Mdot
.468 .50979 Mdot
.468 .50985 Mdot
.468 .50987 Mdot
.468 .50988 Mdot
.468 .50996 Mdot
.468 .51001 Mdot
.468 .51014 Mdot
.468 .51023 Mdot
.468 .51055 Mdot
.468 .51072 Mdot
.468 .511 Mdot
.468 .51102 Mdot
.468 .5111 Mdot
.468 .51116 Mdot
.468 .51132 Mdot
.468 .5114 Mdot
.468 .51152 Mdot
.468 .51171 Mdot
.468 .51179 Mdot
.468 .51215 Mdot
.468 .51223 Mdot
.468 .51224 Mdot
.468 .51232 Mdot
.468 .51251 Mdot
.468 .51259 Mdot
.468 .51262 Mdot
.468 .51262 Mdot
.468 .51266 Mdot
.468 .51267 Mdot
.468 .51271 Mdot
.468 .51271 Mdot
.468 .51273 Mdot
.468 .51274 Mdot
.468 .51282 Mdot
.468 .51285 Mdot
.468 .51287 Mdot
.468 .51289 Mdot
.468 .51289 Mdot
.468 .5129 Mdot
.468 .53103 Mdot
.468 .53103 Mdot
.468 .53104 Mdot
.468 .53104 Mdot
.468 .53105 Mdot
.468 .53107 Mdot
.468 .53111 Mdot
.468 .53111 Mdot
.468 .53112 Mdot
.468 .53112 Mdot
.468 .53113 Mdot
.468 .53114 Mdot
.468 .53116 Mdot
.468 .53116 Mdot
.468 .53117 Mdot
.468 .5312 Mdot
.468 .53129 Mdot
.468 .53133 Mdot
.468 .53133 Mdot
.468 .53137 Mdot
.468 .53153 Mdot
.468 .53156 Mdot
.468 .53165 Mdot
.468 .5317 Mdot
.468 .53173 Mdot
.468 .5318 Mdot
.468 .53183 Mdot
.468 .53186 Mdot
.468 .53187 Mdot
.468 .53199 Mdot
.468 .53207 Mdot
.468 .53221 Mdot
.468 .53224 Mdot
.468 .5323 Mdot
.468 .53232 Mdot
.468 .53236 Mdot
.468 .53236 Mdot
.468 .53237 Mdot
.468 .5324 Mdot
.468 .5325 Mdot
.468 .53258 Mdot
.468 .53279 Mdot
.468 .53286 Mdot
.468 .53292 Mdot
.468 .53295 Mdot
.468 .53298 Mdot
.468 .53312 Mdot
.468 .53323 Mdot
.468 .53324 Mdot
.468 .53327 Mdot
.468 .53332 Mdot
.468 .53356 Mdot
.468 .53358 Mdot
.468 .53369 Mdot
.468 .53376 Mdot
.468 .53394 Mdot
.468 .53397 Mdot
.468 .53401 Mdot
.468 .5342 Mdot
.468 .53423 Mdot
.468 .53427 Mdot
.468 .53427 Mdot
.468 .53429 Mdot
.468 .53429 Mdot
.468 .53438 Mdot
.468 .53443 Mdot
.468 .53458 Mdot
.468 .53467 Mdot
.468 .53471 Mdot
.468 .53497 Mdot
.468 .53501 Mdot
.468 .53504 Mdot
.468 .53508 Mdot
.468 .53523 Mdot
.468 .53526 Mdot
.468 .53541 Mdot
.468 .53554 Mdot
.468 .53557 Mdot
.468 .53565 Mdot
.468 .53566 Mdot
.468 .53573 Mdot
.468 .53577 Mdot
.468 .53587 Mdot
.468 .53591 Mdot
.468 .53593 Mdot
.468 .53595 Mdot
.468 .536 Mdot
.468 .53614 Mdot
.468 .53621 Mdot
.468 .53633 Mdot
.468 .53633 Mdot
.468 .53636 Mdot
.468 .53646 Mdot
.468 .53647 Mdot
.468 .53651 Mdot
.468 .53661 Mdot
.468 .53663 Mdot
.468 .53671 Mdot
.468 .53672 Mdot
.468 .53688 Mdot
.468 .53697 Mdot
.468 .53698 Mdot
.468 .537 Mdot
.468 .53706 Mdot
.468 .53711 Mdot
.468 .53719 Mdot
.468 .53723 Mdot
.468 .53726 Mdot
.468 .53728 Mdot
.468 .53729 Mdot
.468 .53737 Mdot
.468 .53741 Mdot
.468 .53741 Mdot
.468 .53746 Mdot
.468 .53747 Mdot
.468 .53751 Mdot
.468 .53751 Mdot
.468 .53754 Mdot
.468 .53754 Mdot
.468 .53763 Mdot
.468 .53767 Mdot
.468 .5377 Mdot
.468 .53771 Mdot
.468 .53772 Mdot
.468 .53772 Mdot
.468 .53808 Mdot
.468 .53808 Mdot
.468 .53808 Mdot
.468 .53809 Mdot
.468 .53811 Mdot
.468 .53813 Mdot
.468 .53818 Mdot
.468 .53818 Mdot
.468 .53819 Mdot
.468 .5382 Mdot
.468 .53821 Mdot
.468 .53822 Mdot
.468 .53825 Mdot
.468 .53825 Mdot
.468 .53827 Mdot
.468 .53831 Mdot
.468 .53831 Mdot
.468 .53832 Mdot
.468 .53834 Mdot
.468 .53836 Mdot
.468 .5384 Mdot
.468 .53843 Mdot
.468 .53846 Mdot
.468 .53847 Mdot
.468 .53848 Mdot
.468 .53852 Mdot
.468 .5386 Mdot
.468 .5386 Mdot
.468 .53864 Mdot
.468 .53865 Mdot
.468 .5387 Mdot
.468 .53872 Mdot
.468 .53872 Mdot
.468 .53876 Mdot
.468 .53878 Mdot
.468 .53878 Mdot
.468 .53883 Mdot
.468 .53887 Mdot
.468 .53893 Mdot
.468 .53895 Mdot
.468 .53896 Mdot
.468 .53897 Mdot
.468 .53898 Mdot
.468 .53902 Mdot
.468 .53904 Mdot
.468 .53907 Mdot
.468 .53908 Mdot
.468 .53911 Mdot
.468 .53912 Mdot
.468 .53918 Mdot
.468 .53924 Mdot
.468 .53925 Mdot
.468 .53931 Mdot
.468 .53933 Mdot
.468 .53934 Mdot
.468 .53935 Mdot
.468 .53946 Mdot
.468 .53947 Mdot
.468 .53951 Mdot
.468 .53956 Mdot
.468 .53958 Mdot
.468 .53961 Mdot
.468 .53962 Mdot
.468 .53962 Mdot
.468 .53962 Mdot
.468 .53964 Mdot
.468 .53965 Mdot
.468 .53972 Mdot
.468 .53973 Mdot
.468 .53974 Mdot
.468 .53981 Mdot
.468 .53983 Mdot
.468 .53987 Mdot
.468 .53988 Mdot
.468 .53996 Mdot
.468 .53998 Mdot
.468 .53999 Mdot
.468 .53999 Mdot
.468 .54003 Mdot
.468 .54008 Mdot
.468 .54009 Mdot
.468 .5401 Mdot
.468 .54012 Mdot
.468 .54014 Mdot
.468 .54021 Mdot
.468 .54023 Mdot
.468 .54027 Mdot
.468 .54028 Mdot
.468 .54028 Mdot
.468 .54028 Mdot
.468 .54029 Mdot
.468 .5403 Mdot
.468 .54032 Mdot
.468 .54033 Mdot
.468 .54037 Mdot
.468 .5404 Mdot
.468 .54044 Mdot
.468 .54044 Mdot
.468 .54045 Mdot
.468 .54046 Mdot
.468 .54048 Mdot
.468 .54049 Mdot
.468 .54051 Mdot
.468 .54053 Mdot
.468 .54054 Mdot
.468 .54059 Mdot
.468 .54059 Mdot
.468 .5406 Mdot
.468 .5406 Mdot
.468 .54061 Mdot
.468 .54064 Mdot
.468 .54065 Mdot
.468 .54065 Mdot
.468 .54065 Mdot
.468 .54066 Mdot
.468 .54066 Mdot
.468 .54067 Mdot
.468 .54067 Mdot
.468 .54067 Mdot
.468 .54067 Mdot
.468 .54068 Mdot
.468 .54068 Mdot
.468 .54069 Mdot
.468 .54069 Mdot
.468 .54069 Mdot
.47 .21418 Mdot
.47 .21418 Mdot
.47 .21419 Mdot
.47 .21419 Mdot
.47 .2142 Mdot
.47 .21421 Mdot
.47 .21421 Mdot
.47 .21422 Mdot
.47 .21423 Mdot
.47 .21423 Mdot
.47 .21425 Mdot
.47 .21427 Mdot
.47 .21429 Mdot
.47 .21433 Mdot
.47 .21436 Mdot
.47 .21446 Mdot
.47 .21446 Mdot
.47 .21448 Mdot
.47 .21456 Mdot
.47 .21456 Mdot
.47 .21457 Mdot
.47 .21459 Mdot
.47 .21465 Mdot
.47 .21466 Mdot
.47 .21475 Mdot
.47 .21482 Mdot
.47 .21482 Mdot
.47 .21494 Mdot
.47 .21512 Mdot
.47 .21529 Mdot
.47 .21537 Mdot
.47 .2154 Mdot
.47 .21545 Mdot
.47 .21553 Mdot
.47 .21555 Mdot
.47 .21573 Mdot
.47 .21576 Mdot
.47 .21595 Mdot
.47 .21598 Mdot
.47 .21599 Mdot
.47 .21607 Mdot
.47 .21614 Mdot
.47 .21616 Mdot
.47 .21635 Mdot
.47 .21636 Mdot
.47 .21643 Mdot
.47 .21645 Mdot
.47 .2165 Mdot
.47 .21694 Mdot
.47 .21696 Mdot
.47 .21701 Mdot
.47 .21703 Mdot
.47 .21704 Mdot
.47 .21713 Mdot
.47 .21714 Mdot
.47 .21732 Mdot
.47 .2174 Mdot
.47 .21744 Mdot
.47 .21754 Mdot
.47 .21758 Mdot
.47 .21761 Mdot
.47 .21763 Mdot
.47 .21767 Mdot
.47 .2177 Mdot
.47 .21784 Mdot
.47 .21788 Mdot
.47 .21805 Mdot
.47 .21815 Mdot
.47 .21819 Mdot
.47 .21841 Mdot
.47 .21855 Mdot
.47 .21866 Mdot
.47 .21886 Mdot
.47 .21892 Mdot
.47 .21892 Mdot
.47 .21902 Mdot
.47 .21916 Mdot
.47 .21939 Mdot
.47 .21956 Mdot
.47 .21957 Mdot
.47 .2197 Mdot
.47 .21975 Mdot
.47 .2198 Mdot
.47 .21994 Mdot
.47 .21997 Mdot
.47 .22022 Mdot
.47 .22022 Mdot
.47 .22027 Mdot
.47 .22028 Mdot
.47 .22036 Mdot
.47 .22039 Mdot
.47 .22041 Mdot
.47 .22047 Mdot
.47 .22049 Mdot
.47 .22051 Mdot
.47 .22052 Mdot
.47 .22058 Mdot
.47 .22067 Mdot
.47 .22072 Mdot
.47 .22086 Mdot
.47 .22091 Mdot
.47 .22098 Mdot
.47 .22101 Mdot
.47 .22101 Mdot
.47 .2211 Mdot
.47 .22118 Mdot
.47 .22124 Mdot
.47 .22125 Mdot
.47 .2213 Mdot
.47 .22133 Mdot
.47 .22138 Mdot
.47 .22139 Mdot
.47 .22155 Mdot
.47 .22176 Mdot
.47 .22179 Mdot
.47 .22184 Mdot
.47 .22185 Mdot
.47 .22233 Mdot
.47 .22247 Mdot
.47 .22262 Mdot
.47 .22265 Mdot
.47 .22269 Mdot
.47 .22274 Mdot
.47 .2228 Mdot
.47 .2228 Mdot
.47 .22289 Mdot
.47 .22298 Mdot
.47 .22301 Mdot
.47 .22307 Mdot
.47 .22312 Mdot
.47 .22313 Mdot
.47 .22314 Mdot
.47 .22318 Mdot
.47 .22319 Mdot
.47 .22321 Mdot
.47 .22327 Mdot
.47 .22327 Mdot
.47 .22347 Mdot
.47 .22349 Mdot
.47 .22359 Mdot
.47 .22365 Mdot
.47 .22374 Mdot
.47 .22376 Mdot
.47 .22388 Mdot
.47 .22404 Mdot
.47 .22421 Mdot
.47 .22422 Mdot
.47 .22426 Mdot
.47 .22441 Mdot
.47 .2245 Mdot
.47 .22478 Mdot
.47 .2249 Mdot
.47 .22508 Mdot
.47 .2252 Mdot
.47 .22522 Mdot
.47 .22526 Mdot
.47 .22531 Mdot
.47 .22543 Mdot
.47 .22547 Mdot
.47 .22554 Mdot
.47 .22571 Mdot
.47 .22572 Mdot
.47 .22582 Mdot
.47 .22584 Mdot
.47 .22637 Mdot
.47 .22643 Mdot
.47 .22674 Mdot
.47 .22685 Mdot
.47 .22696 Mdot
.47 .22725 Mdot
.47 .22729 Mdot
.47 .22767 Mdot
.47 .22819 Mdot
.47 .22853 Mdot
.47 .22875 Mdot
.47 .22876 Mdot
.47 .22891 Mdot
.47 .22938 Mdot
.47 .22967 Mdot
.47 .23001 Mdot
.47 .23055 Mdot
.47 .23066 Mdot
.47 .2309 Mdot
.47 .23136 Mdot
.47 .23146 Mdot
.47 .23183 Mdot
.47 .23189 Mdot
.47 .23201 Mdot
.47 .23206 Mdot
.47 .23214 Mdot
.47 .23223 Mdot
.47 .23251 Mdot
.47 .23262 Mdot
.47 .23283 Mdot
.47 .23331 Mdot
.47 .23337 Mdot
.47 .2336 Mdot
.47 .23363 Mdot
.47 .23368 Mdot
.47 .23383 Mdot
.47 .23388 Mdot
.47 .23514 Mdot
.47 .23526 Mdot
.47 .23531 Mdot
.47 .23552 Mdot
.47 .23555 Mdot
.47 .23611 Mdot
.47 .23616 Mdot
.47 .23636 Mdot
.47 .23662 Mdot
.47 .23664 Mdot
.47 .23674 Mdot
.47 .2373 Mdot
.47 .23732 Mdot
.47 .23741 Mdot
.47 .23792 Mdot
.47 .23799 Mdot
.47 .23825 Mdot
.47 .2384 Mdot
.47 .2385 Mdot
.47 .23873 Mdot
.47 .23926 Mdot
.47 .23986 Mdot
.47 .24022 Mdot
.47 .24022 Mdot
.47 .24044 Mdot
.47 .24073 Mdot
.47 .24078 Mdot
.47 .24097 Mdot
.47 .24103 Mdot
.47 .24107 Mdot
.47 .24107 Mdot
.47 .24132 Mdot
.47 .24138 Mdot
.47 .24139 Mdot
.47 .24171 Mdot
.47 .24181 Mdot
.47 .24195 Mdot
.47 .24202 Mdot
.47 .24208 Mdot
.47 .24214 Mdot
.47 .24216 Mdot
.47 .2422 Mdot
.47 .24222 Mdot
.47 .24223 Mdot
.47 .24224 Mdot
.47 .24227 Mdot
.47 .24229 Mdot
.47 .24232 Mdot
.47 .24232 Mdot
.47 .28589 Mdot
.47 .28589 Mdot
.47 .28596 Mdot
.47 .28599 Mdot
.47 .28605 Mdot
.47 .28607 Mdot
.47 .28609 Mdot
.47 .28615 Mdot
.47 .28622 Mdot
.47 .28627 Mdot
.47 .28638 Mdot
.47 .2865 Mdot
.47 .28664 Mdot
.47 .28694 Mdot
.47 .28713 Mdot
.47 .28778 Mdot
.47 .2878 Mdot
.47 .28792 Mdot
.47 .28843 Mdot
.47 .28844 Mdot
.47 .28852 Mdot
.47 .28863 Mdot
.47 .28902 Mdot
.47 .28914 Mdot
.47 .28972 Mdot
.47 .29018 Mdot
.47 .29019 Mdot
.47 .29093 Mdot
.47 .29217 Mdot
.47 .29327 Mdot
.47 .29376 Mdot
.47 .29396 Mdot
.47 .29429 Mdot
.47 .29484 Mdot
.47 .29497 Mdot
.47 .29607 Mdot
.47 .29626 Mdot
.47 .2963 Mdot
.47 .29748 Mdot
.47 .29771 Mdot
.47 .29774 Mdot
.47 .29829 Mdot
.47 .29873 Mdot
.47 .29885 Mdot
.47 .30004 Mdot
.47 .30011 Mdot
.47 .30057 Mdot
.47 .30067 Mdot
.47 .30094 Mdot
.47 .30369 Mdot
.47 .30378 Mdot
.47 .30412 Mdot
.47 .30422 Mdot
.47 .30429 Mdot
.47 .30481 Mdot
.47 .30493 Mdot
.47 .30599 Mdot
.47 .30646 Mdot
.47 .30671 Mdot
.47 .30732 Mdot
.47 .30752 Mdot
.47 .3077 Mdot
.47 .30781 Mdot
.47 .30807 Mdot
.47 .30821 Mdot
.47 .30904 Mdot
.47 .30927 Mdot
.47 .31028 Mdot
.47 .31083 Mdot
.47 .31109 Mdot
.47 .3123 Mdot
.47 .31308 Mdot
.47 .31373 Mdot
.47 .31481 Mdot
.47 .31515 Mdot
.47 .31516 Mdot
.47 .31567 Mdot
.47 .31645 Mdot
.47 .31764 Mdot
.47 .31853 Mdot
.47 .31862 Mdot
.47 .31929 Mdot
.47 .31955 Mdot
.47 .31979 Mdot
.47 .32051 Mdot
.47 .32066 Mdot
.47 .3219 Mdot
.47 .32194 Mdot
.47 .32215 Mdot
.47 .3222 Mdot
.47 .32259 Mdot
.47 .32275 Mdot
.47 .32284 Mdot
.47 .32313 Mdot
.47 .32323 Mdot
.47 .32332 Mdot
.47 .32337 Mdot
.47 .32366 Mdot
.47 .32408 Mdot
.47 .32436 Mdot
.47 .32502 Mdot
.47 .32523 Mdot
.47 .32558 Mdot
.47 .32569 Mdot
.47 .3257 Mdot
.47 .32611 Mdot
.47 .32649 Mdot
.47 .32678 Mdot
.47 .32681 Mdot
.47 .32702 Mdot
.47 .32718 Mdot
.47 .3274 Mdot
.47 .32745 Mdot
.47 .32792 Mdot
.47 .32794 Mdot
.47 .32806 Mdot
.47 .32811 Mdot
.47 .32814 Mdot
.47 .32823 Mdot
.47 .32826 Mdot
.47 .32829 Mdot
.47 .3284 Mdot
.47 .32853 Mdot
.47 .32862 Mdot
.47 .32883 Mdot
.47 .32904 Mdot
.47 .32904 Mdot
.47 .32918 Mdot
.47 .3293 Mdot
.47 .32939 Mdot
.47 .32947 Mdot
.47 .32983 Mdot
.47 .33016 Mdot
.47 .3313 Mdot
.47 .33134 Mdot
.47 .33146 Mdot
.47 .33153 Mdot
.47 .33203 Mdot
.47 .3324 Mdot
.47 .33242 Mdot
.47 .33255 Mdot
.47 .33263 Mdot
.47 .33274 Mdot
.47 .33276 Mdot
.47 .33291 Mdot
.47 .33311 Mdot
.47 .33332 Mdot
.47 .33332 Mdot
.47 .33338 Mdot
.47 .33356 Mdot
.47 .33367 Mdot
.47 .33401 Mdot
.47 .33415 Mdot
.47 .33436 Mdot
.47 .3345 Mdot
.47 .33453 Mdot
.47 .33457 Mdot
.47 .33462 Mdot
.47 .33477 Mdot
.47 .33481 Mdot
.47 .33489 Mdot
.47 .33508 Mdot
.47 .3351 Mdot
.47 .33521 Mdot
.47 .33523 Mdot
.47 .33582 Mdot
.47 .3359 Mdot
.47 .33624 Mdot
.47 .33635 Mdot
.47 .33647 Mdot
.47 .33679 Mdot
.47 .33683 Mdot
.47 .33724 Mdot
.47 .33778 Mdot
.47 .33813 Mdot
.47 .33836 Mdot
.47 .33837 Mdot
.47 .33852 Mdot
.47 .33899 Mdot
.47 .33928 Mdot
.47 .33962 Mdot
.47 .34014 Mdot
.47 .34025 Mdot
.47 .34048 Mdot
.47 .34091 Mdot
.47 .341 Mdot
.47 .34135 Mdot
.47 .34141 Mdot
.47 .34152 Mdot
.47 .34156 Mdot
.47 .34164 Mdot
.47 .34172 Mdot
.47 .34197 Mdot
.47 .34208 Mdot
.47 .34226 Mdot
.47 .3427 Mdot
.47 .34275 Mdot
.47 .34296 Mdot
.47 .34298 Mdot
.47 .34303 Mdot
.47 .34316 Mdot
.47 .3432 Mdot
.47 .34429 Mdot
.47 .3444 Mdot
.47 .34444 Mdot
.47 .34462 Mdot
.47 .34465 Mdot
.47 .34511 Mdot
.47 .34516 Mdot
.47 .34533 Mdot
.47 .34555 Mdot
.47 .34556 Mdot
.47 .34565 Mdot
.47 .3461 Mdot
.47 .34612 Mdot
.47 .34619 Mdot
.47 .34661 Mdot
.47 .34666 Mdot
.47 .34687 Mdot
.47 .34699 Mdot
.47 .34707 Mdot
.47 .34726 Mdot
.47 .34767 Mdot
.47 .34814 Mdot
.47 .34842 Mdot
.47 .34842 Mdot
.47 .34859 Mdot
.47 .34881 Mdot
.47 .34885 Mdot
.47 .349 Mdot
.47 .34904 Mdot
.47 .34907 Mdot
.47 .34908 Mdot
.47 .34927 Mdot
.47 .34931 Mdot
.47 .34932 Mdot
.47 .34956 Mdot
.47 .34963 Mdot
.47 .34974 Mdot
.47 .34979 Mdot
.47 .34984 Mdot
.47 .34988 Mdot
.47 .34989 Mdot
.47 .34992 Mdot
.47 .34994 Mdot
.47 .34995 Mdot
.47 .34996 Mdot
.47 .34998 Mdot
.47 .34999 Mdot
.47 .35001 Mdot
.47 .35002 Mdot
.47 .48628 Mdot
.47 .48628 Mdot
.47 .4863 Mdot
.47 .4863 Mdot
.47 .48631 Mdot
.47 .48631 Mdot
.47 .48632 Mdot
.47 .48633 Mdot
.47 .48634 Mdot
.47 .48635 Mdot
.47 .48637 Mdot
.47 .48639 Mdot
.47 .48641 Mdot
.47 .48646 Mdot
.47 .4865 Mdot
.47 .48661 Mdot
.47 .48661 Mdot
.47 .48663 Mdot
.47 .48672 Mdot
.47 .48672 Mdot
.47 .48674 Mdot
.47 .48676 Mdot
.47 .48682 Mdot
.47 .48684 Mdot
.47 .48694 Mdot
.47 .48702 Mdot
.47 .48702 Mdot
.47 .48715 Mdot
.47 .48737 Mdot
.47 .48756 Mdot
.47 .48765 Mdot
.47 .48768 Mdot
.47 .48774 Mdot
.47 .48784 Mdot
.47 .48786 Mdot
.47 .48805 Mdot
.47 .48809 Mdot
.47 .4883 Mdot
.47 .48834 Mdot
.47 .48835 Mdot
.47 .48845 Mdot
.47 .48852 Mdot
.47 .48854 Mdot
.47 .48876 Mdot
.47 .48877 Mdot
.47 .48885 Mdot
.47 .48887 Mdot
.47 .48892 Mdot
.47 .48942 Mdot
.47 .48944 Mdot
.47 .4895 Mdot
.47 .48952 Mdot
.47 .48953 Mdot
.47 .48963 Mdot
.47 .48965 Mdot
.47 .48985 Mdot
.47 .48993 Mdot
.47 .48998 Mdot
.47 .49009 Mdot
.47 .49013 Mdot
.47 .49017 Mdot
.47 .49019 Mdot
.47 .49024 Mdot
.47 .49026 Mdot
.47 .49042 Mdot
.47 .49046 Mdot
.47 .49066 Mdot
.47 .49076 Mdot
.47 .49081 Mdot
.47 .49105 Mdot
.47 .4912 Mdot
.47 .49133 Mdot
.47 .49155 Mdot
.47 .49161 Mdot
.47 .49161 Mdot
.47 .49172 Mdot
.47 .49188 Mdot
.47 .49212 Mdot
.47 .4923 Mdot
.47 .49232 Mdot
.47 .49246 Mdot
.47 .49252 Mdot
.47 .49257 Mdot
.47 .49272 Mdot
.47 .49275 Mdot
.47 .49302 Mdot
.47 .49303 Mdot
.47 .49308 Mdot
.47 .49309 Mdot
.47 .49317 Mdot
.47 .49321 Mdot
.47 .49323 Mdot
.47 .49329 Mdot
.47 .49331 Mdot
.47 .49333 Mdot
.47 .49335 Mdot
.47 .49341 Mdot
.47 .4935 Mdot
.47 .49357 Mdot
.47 .49372 Mdot
.47 .49376 Mdot
.47 .49385 Mdot
.47 .49387 Mdot
.47 .49387 Mdot
.47 .49397 Mdot
.47 .49406 Mdot
.47 .49412 Mdot
.47 .49413 Mdot
.47 .49418 Mdot
.47 .49422 Mdot
.47 .49427 Mdot
.47 .49428 Mdot
.47 .49445 Mdot
.47 .49467 Mdot
.47 .4947 Mdot
.47 .49475 Mdot
.47 .49477 Mdot
.47 .49527 Mdot
.47 .49542 Mdot
.47 .49558 Mdot
.47 .49561 Mdot
.47 .49565 Mdot
.47 .49571 Mdot
.47 .49577 Mdot
.47 .49577 Mdot
.47 .49586 Mdot
.47 .49595 Mdot
.47 .49599 Mdot
.47 .49605 Mdot
.47 .4961 Mdot
.47 .49611 Mdot
.47 .49612 Mdot
.47 .49616 Mdot
.47 .49618 Mdot
.47 .4962 Mdot
.47 .49625 Mdot
.47 .49626 Mdot
.47 .49647 Mdot
.47 .49649 Mdot
.47 .49659 Mdot
.47 .49666 Mdot
.47 .49675 Mdot
.47 .49676 Mdot
.47 .49689 Mdot
.47 .49705 Mdot
.47 .49724 Mdot
.47 .49724 Mdot
.47 .49729 Mdot
.47 .49744 Mdot
.47 .49753 Mdot
.47 .49782 Mdot
.47 .49794 Mdot
.47 .49812 Mdot
.47 .49825 Mdot
.47 .49827 Mdot
.47 .49831 Mdot
.47 .49836 Mdot
.47 .49848 Mdot
.47 .49852 Mdot
.47 .49859 Mdot
.47 .49876 Mdot
.47 .49878 Mdot
.47 .49887 Mdot
.47 .49889 Mdot
.47 .49942 Mdot
.47 .49949 Mdot
.47 .4998 Mdot
.47 .49991 Mdot
.47 .50002 Mdot
.47 .5003 Mdot
.47 .50034 Mdot
.47 .50073 Mdot
.47 .50124 Mdot
.47 .50157 Mdot
.47 .50179 Mdot
.47 .50179 Mdot
.47 .50194 Mdot
.47 .5024 Mdot
.47 .50268 Mdot
.47 .50301 Mdot
.47 .50352 Mdot
.47 .50363 Mdot
.47 .50386 Mdot
.47 .50429 Mdot
.47 .50438 Mdot
.47 .50473 Mdot
.47 .50479 Mdot
.47 .5049 Mdot
.47 .50495 Mdot
.47 .50502 Mdot
.47 .50511 Mdot
.47 .50536 Mdot
.47 .50547 Mdot
.47 .50566 Mdot
.47 .50611 Mdot
.47 .50616 Mdot
.47 .50637 Mdot
.47 .5064 Mdot
.47 .50645 Mdot
.47 .50659 Mdot
.47 .50663 Mdot
.47 .50777 Mdot
.47 .50788 Mdot
.47 .50792 Mdot
.47 .50811 Mdot
.47 .50814 Mdot
.47 .50863 Mdot
.47 .50868 Mdot
.47 .50886 Mdot
.47 .50909 Mdot
.47 .5091 Mdot
.47 .50919 Mdot
.47 .50968 Mdot
.47 .50969 Mdot
.47 .50977 Mdot
.47 .51022 Mdot
.47 .51028 Mdot
.47 .5105 Mdot
.47 .51063 Mdot
.47 .51072 Mdot
.47 .51092 Mdot
.47 .51136 Mdot
.47 .51187 Mdot
.47 .51217 Mdot
.47 .51217 Mdot
.47 .51236 Mdot
.47 .5126 Mdot
.47 .51264 Mdot
.47 .5128 Mdot
.47 .51285 Mdot
.47 .51288 Mdot
.47 .51288 Mdot
.47 .51309 Mdot
.47 .51313 Mdot
.47 .51314 Mdot
.47 .51341 Mdot
.47 .51348 Mdot
.47 .5136 Mdot
.47 .51366 Mdot
.47 .51371 Mdot
.47 .51375 Mdot
.47 .51377 Mdot
.47 .5138 Mdot
.47 .51382 Mdot
.47 .51383 Mdot
.47 .51384 Mdot
.47 .51386 Mdot
.47 .51388 Mdot
.47 .5139 Mdot
.47 .5139 Mdot
.47 .53071 Mdot
.47 .53072 Mdot
.47 .53073 Mdot
.47 .53073 Mdot
.47 .53074 Mdot
.47 .53075 Mdot
.47 .53075 Mdot
.47 .53076 Mdot
.47 .53077 Mdot
.47 .53078 Mdot
.47 .5308 Mdot
.47 .53083 Mdot
.47 .53085 Mdot
.47 .53091 Mdot
.47 .53094 Mdot
.47 .53106 Mdot
.47 .53106 Mdot
.47 .53108 Mdot
.47 .53118 Mdot
.47 .53118 Mdot
.47 .53119 Mdot
.47 .53122 Mdot
.47 .53129 Mdot
.47 .53131 Mdot
.47 .53141 Mdot
.47 .53149 Mdot
.47 .5315 Mdot
.47 .53163 Mdot
.47 .53185 Mdot
.47 .53204 Mdot
.47 .53213 Mdot
.47 .53216 Mdot
.47 .53222 Mdot
.47 .53232 Mdot
.47 .53234 Mdot
.47 .53253 Mdot
.47 .53257 Mdot
.47 .53257 Mdot
.47 .53278 Mdot
.47 .53282 Mdot
.47 .53282 Mdot
.47 .53292 Mdot
.47 .53299 Mdot
.47 .53301 Mdot
.47 .53321 Mdot
.47 .53323 Mdot
.47 .5333 Mdot
.47 .53332 Mdot
.47 .53337 Mdot
.47 .53383 Mdot
.47 .53384 Mdot
.47 .5339 Mdot
.47 .53392 Mdot
.47 .53393 Mdot
.47 .53401 Mdot
.47 .53403 Mdot
.47 .53421 Mdot
.47 .53429 Mdot
.47 .53433 Mdot
.47 .53443 Mdot
.47 .53446 Mdot
.47 .53449 Mdot
.47 .53451 Mdot
.47 .53455 Mdot
.47 .53458 Mdot
.47 .53471 Mdot
.47 .53475 Mdot
.47 .53491 Mdot
.47 .535 Mdot
.47 .53504 Mdot
.47 .53524 Mdot
.47 .53536 Mdot
.47 .53547 Mdot
.47 .53564 Mdot
.47 .53569 Mdot
.47 .5357 Mdot
.47 .53578 Mdot
.47 .5359 Mdot
.47 .53609 Mdot
.47 .53623 Mdot
.47 .53624 Mdot
.47 .53635 Mdot
.47 .53639 Mdot
.47 .53642 Mdot
.47 .53654 Mdot
.47 .53656 Mdot
.47 .53675 Mdot
.47 .53676 Mdot
.47 .53679 Mdot
.47 .5368 Mdot
.47 .53686 Mdot
.47 .53689 Mdot
.47 .5369 Mdot
.47 .53694 Mdot
.47 .53696 Mdot
.47 .53697 Mdot
.47 .53698 Mdot
.47 .53703 Mdot
.47 .53709 Mdot
.47 .53713 Mdot
.47 .53723 Mdot
.47 .53727 Mdot
.47 .53732 Mdot
.47 .53734 Mdot
.47 .53734 Mdot
.47 .5374 Mdot
.47 .53746 Mdot
.47 .5375 Mdot
.47 .53751 Mdot
.47 .53754 Mdot
.47 .53756 Mdot
.47 .5376 Mdot
.47 .53761 Mdot
.47 .53768 Mdot
.47 .53768 Mdot
.47 .5377 Mdot
.47 .53771 Mdot
.47 .53771 Mdot
.47 .53772 Mdot
.47 .53773 Mdot
.47 .53773 Mdot
.47 .53775 Mdot
.47 .53777 Mdot
.47 .53778 Mdot
.47 .53781 Mdot
.47 .53785 Mdot
.47 .53785 Mdot
.47 .53787 Mdot
.47 .53789 Mdot
.47 .5379 Mdot
.47 .53791 Mdot
.47 .53797 Mdot
.47 .53802 Mdot
.47 .53819 Mdot
.47 .53819 Mdot
.47 .53821 Mdot
.47 .53822 Mdot
.47 .5383 Mdot
.47 .53835 Mdot
.47 .53836 Mdot
.47 .53837 Mdot
.47 .53839 Mdot
.47 .5384 Mdot
.47 .53841 Mdot
.47 .53843 Mdot
.47 .53846 Mdot
.47 .53849 Mdot
.47 .53849 Mdot
.47 .5385 Mdot
.47 .53853 Mdot
.47 .53854 Mdot
.47 .53859 Mdot
.47 .53861 Mdot
.47 .53864 Mdot
.47 .53867 Mdot
.47 .53867 Mdot
.47 .53868 Mdot
.47 .53868 Mdot
.47 .53871 Mdot
.47 .53871 Mdot
.47 .53872 Mdot
.47 .53875 Mdot
.47 .53876 Mdot
.47 .53877 Mdot
.47 .53877 Mdot
.47 .53886 Mdot
.47 .53887 Mdot
.47 .53892 Mdot
.47 .53894 Mdot
.47 .53896 Mdot
.47 .539 Mdot
.47 .53901 Mdot
.47 .53907 Mdot
.47 .53915 Mdot
.47 .5392 Mdot
.47 .53924 Mdot
.47 .53924 Mdot
.47 .53926 Mdot
.47 .53933 Mdot
.47 .53937 Mdot
.47 .53942 Mdot
.47 .5395 Mdot
.47 .53951 Mdot
.47 .53955 Mdot
.47 .53961 Mdot
.47 .53962 Mdot
.47 .53967 Mdot
.47 .53968 Mdot
.47 .5397 Mdot
.47 .53971 Mdot
.47 .53972 Mdot
.47 .53973 Mdot
.47 .53977 Mdot
.47 .53978 Mdot
.47 .53981 Mdot
.47 .53987 Mdot
.47 .53988 Mdot
.47 .53991 Mdot
.47 .53991 Mdot
.47 .53992 Mdot
.47 .53994 Mdot
.47 .53994 Mdot
.47 .5401 Mdot
.47 .54012 Mdot
.47 .54012 Mdot
.47 .54015 Mdot
.47 .54015 Mdot
.47 .54022 Mdot
.47 .54023 Mdot
.47 .54025 Mdot
.47 .54028 Mdot
.47 .54029 Mdot
.47 .5403 Mdot
.47 .54037 Mdot
.47 .54038 Mdot
.47 .54044 Mdot
.47 .54045 Mdot
.47 .54048 Mdot
.47 .54049 Mdot
.47 .5405 Mdot
.47 .54053 Mdot
.47 .54059 Mdot
.47 .54066 Mdot
.47 .5407 Mdot
.47 .5407 Mdot
.47 .54072 Mdot
.47 .54075 Mdot
.47 .54076 Mdot
.47 .54078 Mdot
.47 .54079 Mdot
.47 .54079 Mdot
.47 .54079 Mdot
.47 .54082 Mdot
.47 .54083 Mdot
.47 .54083 Mdot
.47 .54086 Mdot
.47 .54087 Mdot
.47 .54089 Mdot
.47 .54089 Mdot
.47 .5409 Mdot
.47 .54091 Mdot
.47 .54091 Mdot
.47 .54091 Mdot
.47 .54092 Mdot
.47 .54092 Mdot
.47 .54092 Mdot
.47 .54092 Mdot
.47 .54092 Mdot
.47 .54093 Mdot
.47 .54093 Mdot
.472 .21361 Mdot
.472 .2175 Mdot
.472 .22473 Mdot
.472 .23146 Mdot
.472 .24333 Mdot
.472 .28343 Mdot
.472 .30866 Mdot
.472 .32411 Mdot
.472 .34151 Mdot
.472 .35114 Mdot
.472 .48583 Mdot
.472 .49026 Mdot
.472 .49799 Mdot
.472 .5046 Mdot
.472 .51494 Mdot
.472 .53038 Mdot
.472 .53475 Mdot
.472 .53718 Mdot
.472 .53978 Mdot
.472 .54116 Mdot
.474 .21303 Mdot
.474 .21303 Mdot
.474 .21303 Mdot
.474 .21305 Mdot
.474 .21307 Mdot
.474 .21308 Mdot
.474 .21312 Mdot
.474 .21312 Mdot
.474 .21318 Mdot
.474 .21318 Mdot
.474 .21321 Mdot
.474 .21353 Mdot
.474 .21358 Mdot
.474 .21366 Mdot
.474 .21366 Mdot
.474 .21367 Mdot
.474 .21371 Mdot
.474 .21371 Mdot
.474 .21378 Mdot
.474 .21379 Mdot
.474 .21394 Mdot
.474 .21395 Mdot
.474 .214 Mdot
.474 .21402 Mdot
.474 .2141 Mdot
.474 .21423 Mdot
.474 .21425 Mdot
.474 .21426 Mdot
.474 .21433 Mdot
.474 .21435 Mdot
.474 .21435 Mdot
.474 .21439 Mdot
.474 .21441 Mdot
.474 .21444 Mdot
.474 .21453 Mdot
.474 .21454 Mdot
.474 .21456 Mdot
.474 .21456 Mdot
.474 .21472 Mdot
.474 .21477 Mdot
.474 .21491 Mdot
.474 .21494 Mdot
.474 .21497 Mdot
.474 .21497 Mdot
.474 .21509 Mdot
.474 .2151 Mdot
.474 .21513 Mdot
.474 .21524 Mdot
.474 .21525 Mdot
.474 .21526 Mdot
.474 .21529 Mdot
.474 .21529 Mdot
.474 .21548 Mdot
.474 .21548 Mdot
.474 .2158 Mdot
.474 .2158 Mdot
.474 .21584 Mdot
.474 .21587 Mdot
.474 .21589 Mdot
.474 .2159 Mdot
.474 .21594 Mdot
.474 .21594 Mdot
.474 .21595 Mdot
.474 .21602 Mdot
.474 .21607 Mdot
.474 .21608 Mdot
.474 .21612 Mdot
.474 .21627 Mdot
.474 .21627 Mdot
.474 .21632 Mdot
.474 .21638 Mdot
.474 .21641 Mdot
.474 .2168 Mdot
.474 .21681 Mdot
.474 .21691 Mdot
.474 .217 Mdot
.474 .21719 Mdot
.474 .2172 Mdot
.474 .21732 Mdot
.474 .2175 Mdot
.474 .21757 Mdot
.474 .21768 Mdot
.474 .21784 Mdot
.474 .21833 Mdot
.474 .21834 Mdot
.474 .21842 Mdot
.474 .21843 Mdot
.474 .21855 Mdot
.474 .21881 Mdot
.474 .21885 Mdot
.474 .21893 Mdot
.474 .21893 Mdot
.474 .21902 Mdot
.474 .21905 Mdot
.474 .21912 Mdot
.474 .21922 Mdot
.474 .21923 Mdot
.474 .21928 Mdot
.474 .21929 Mdot
.474 .2196 Mdot
.474 .21961 Mdot
.474 .21964 Mdot
.474 .21968 Mdot
.474 .21975 Mdot
.474 .21976 Mdot
.474 .22011 Mdot
.474 .22011 Mdot
.474 .22015 Mdot
.474 .22025 Mdot
.474 .22034 Mdot
.474 .22069 Mdot
.474 .22076 Mdot
.474 .22078 Mdot
.474 .22084 Mdot
.474 .22112 Mdot
.474 .22115 Mdot
.474 .22197 Mdot
.474 .22203 Mdot
.474 .22229 Mdot
.474 .22234 Mdot
.474 .22237 Mdot
.474 .22237 Mdot
.474 .22258 Mdot
.474 .22266 Mdot
.474 .22268 Mdot
.474 .22288 Mdot
.474 .22299 Mdot
.474 .22304 Mdot
.474 .22311 Mdot
.474 .22317 Mdot
.474 .22337 Mdot
.474 .22388 Mdot
.474 .22408 Mdot
.474 .22427 Mdot
.474 .22437 Mdot
.474 .22437 Mdot
.474 .22511 Mdot
.474 .22515 Mdot
.474 .22529 Mdot
.474 .22533 Mdot
.474 .22538 Mdot
.474 .22545 Mdot
.474 .22546 Mdot
.474 .22553 Mdot
.474 .22555 Mdot
.474 .22592 Mdot
.474 .22592 Mdot
.474 .22616 Mdot
.474 .22616 Mdot
.474 .22618 Mdot
.474 .2263 Mdot
.474 .22633 Mdot
.474 .22635 Mdot
.474 .22648 Mdot
.474 .22649 Mdot
.474 .22652 Mdot
.474 .22655 Mdot
.474 .22672 Mdot
.474 .22678 Mdot
.474 .22699 Mdot
.474 .227 Mdot
.474 .22719 Mdot
.474 .22728 Mdot
.474 .22791 Mdot
.474 .22821 Mdot
.474 .22823 Mdot
.474 .22843 Mdot
.474 .22846 Mdot
.474 .22968 Mdot
.474 .2301 Mdot
.474 .23039 Mdot
.474 .23057 Mdot
.474 .23105 Mdot
.474 .23138 Mdot
.474 .23139 Mdot
.474 .23192 Mdot
.474 .23215 Mdot
.474 .23244 Mdot
.474 .23246 Mdot
.474 .23356 Mdot
.474 .23367 Mdot
.474 .23384 Mdot
.474 .23396 Mdot
.474 .23396 Mdot
.474 .23441 Mdot
.474 .23452 Mdot
.474 .23455 Mdot
.474 .23469 Mdot
.474 .2349 Mdot
.474 .23493 Mdot
.474 .23495 Mdot
.474 .23506 Mdot
.474 .23508 Mdot
.474 .23515 Mdot
.474 .23523 Mdot
.474 .23536 Mdot
.474 .23536 Mdot
.474 .23634 Mdot
.474 .23634 Mdot
.474 .23691 Mdot
.474 .23691 Mdot
.474 .23701 Mdot
.474 .23701 Mdot
.474 .23707 Mdot
.474 .2374 Mdot
.474 .2375 Mdot
.474 .23754 Mdot
.474 .23791 Mdot
.474 .23792 Mdot
.474 .23801 Mdot
.474 .23809 Mdot
.474 .23853 Mdot
.474 .23868 Mdot
.474 .23921 Mdot
.474 .23922 Mdot
.474 .23929 Mdot
.474 .2393 Mdot
.474 .23959 Mdot
.474 .23968 Mdot
.474 .23975 Mdot
.474 .2399 Mdot
.474 .23991 Mdot
.474 .23995 Mdot
.474 .24018 Mdot
.474 .24024 Mdot
.474 .24028 Mdot
.474 .24071 Mdot
.474 .24099 Mdot
.474 .24104 Mdot
.474 .24123 Mdot
.474 .24125 Mdot
.474 .24178 Mdot
.474 .24181 Mdot
.474 .24203 Mdot
.474 .24203 Mdot
.474 .24216 Mdot
.474 .24221 Mdot
.474 .24222 Mdot
.474 .24248 Mdot
.474 .24264 Mdot
.474 .24376 Mdot
.474 .24387 Mdot
.474 .24388 Mdot
.474 .24408 Mdot
.474 .24408 Mdot
.474 .24421 Mdot
.474 .24431 Mdot
.474 .24439 Mdot
.474 .24439 Mdot
.474 .24441 Mdot
.474 .28085 Mdot
.474 .28088 Mdot
.474 .28089 Mdot
.474 .28103 Mdot
.474 .28123 Mdot
.474 .28149 Mdot
.474 .28149 Mdot
.474 .28189 Mdot
.474 .28191 Mdot
.474 .28213 Mdot
.474 .28438 Mdot
.474 .28469 Mdot
.474 .28523 Mdot
.474 .28525 Mdot
.474 .28535 Mdot
.474 .28561 Mdot
.474 .28561 Mdot
.474 .28605 Mdot
.474 .28612 Mdot
.474 .28721 Mdot
.474 .28725 Mdot
.474 .28763 Mdot
.474 .28774 Mdot
.474 .28832 Mdot
.474 .28919 Mdot
.474 .28929 Mdot
.474 .2894 Mdot
.474 .28989 Mdot
.474 .28997 Mdot
.474 .28999 Mdot
.474 .29029 Mdot
.474 .29044 Mdot
.474 .29063 Mdot
.474 .29125 Mdot
.474 .29126 Mdot
.474 .2914 Mdot
.474 .29142 Mdot
.474 .29253 Mdot
.474 .29285 Mdot
.474 .29379 Mdot
.474 .29396 Mdot
.474 .29416 Mdot
.474 .29417 Mdot
.474 .29496 Mdot
.474 .29504 Mdot
.474 .29525 Mdot
.474 .29567 Mdot
.474 .29595 Mdot
.474 .29608 Mdot
.474 .29609 Mdot
.474 .2963 Mdot
.474 .29631 Mdot
.474 .29753 Mdot
.474 .29753 Mdot
.474 .29964 Mdot
.474 .29964 Mdot
.474 .29993 Mdot
.474 .30009 Mdot
.474 .30025 Mdot
.474 .30029 Mdot
.474 .30053 Mdot
.474 .30059 Mdot
.474 .30064 Mdot
.474 .30109 Mdot
.474 .30141 Mdot
.474 .30147 Mdot
.474 .30171 Mdot
.474 .3027 Mdot
.474 .3027 Mdot
.474 .30297 Mdot
.474 .30335 Mdot
.474 .30358 Mdot
.474 .30603 Mdot
.474 .30607 Mdot
.474 .30671 Mdot
.474 .30722 Mdot
.474 .30842 Mdot
.474 .30844 Mdot
.474 .30917 Mdot
.474 .31027 Mdot
.474 .31067 Mdot
.474 .31133 Mdot
.474 .31229 Mdot
.474 .31509 Mdot
.474 .31515 Mdot
.474 .31562 Mdot
.474 .31566 Mdot
.474 .31634 Mdot
.474 .31779 Mdot
.474 .31801 Mdot
.474 .31846 Mdot
.474 .31847 Mdot
.474 .31896 Mdot
.474 .3191 Mdot
.474 .3195 Mdot
.474 .31956 Mdot
.474 .31965 Mdot
.474 .31965 Mdot
.474 .31997 Mdot
.474 .32 Mdot
.474 .32009 Mdot
.474 .32036 Mdot
.474 .32041 Mdot
.474 .32042 Mdot
.474 .32096 Mdot
.474 .32096 Mdot
.474 .32183 Mdot
.474 .32189 Mdot
.474 .32204 Mdot
.474 .32206 Mdot
.474 .32223 Mdot
.474 .32234 Mdot
.474 .32245 Mdot
.474 .32278 Mdot
.474 .32287 Mdot
.474 .32461 Mdot
.474 .32462 Mdot
.474 .32484 Mdot
.474 .3253 Mdot
.474 .32578 Mdot
.474 .32698 Mdot
.474 .32746 Mdot
.474 .3276 Mdot
.474 .32778 Mdot
.474 .32789 Mdot
.474 .32816 Mdot
.474 .32863 Mdot
.474 .32868 Mdot
.474 .32887 Mdot
.474 .32937 Mdot
.474 .32937 Mdot
.474 .32944 Mdot
.474 .32957 Mdot
.474 .3302 Mdot
.474 .33033 Mdot
.474 .33231 Mdot
.474 .33238 Mdot
.474 .33305 Mdot
.474 .33319 Mdot
.474 .33324 Mdot
.474 .33341 Mdot
.474 .33425 Mdot
.474 .33449 Mdot
.474 .33471 Mdot
.474 .33482 Mdot
.474 .33482 Mdot
.474 .33566 Mdot
.474 .3357 Mdot
.474 .33586 Mdot
.474 .33596 Mdot
.474 .33604 Mdot
.474 .33605 Mdot
.474 .3368 Mdot
.474 .33682 Mdot
.474 .33695 Mdot
.474 .33699 Mdot
.474 .33722 Mdot
.474 .3374 Mdot
.474 .33746 Mdot
.474 .33768 Mdot
.474 .33768 Mdot
.474 .33788 Mdot
.474 .33798 Mdot
.474 .33862 Mdot
.474 .33891 Mdot
.474 .33893 Mdot
.474 .33913 Mdot
.474 .33916 Mdot
.474 .34035 Mdot
.474 .34075 Mdot
.474 .34102 Mdot
.474 .34118 Mdot
.474 .34163 Mdot
.474 .34193 Mdot
.474 .34194 Mdot
.474 .34242 Mdot
.474 .34263 Mdot
.474 .34288 Mdot
.474 .3429 Mdot
.474 .34386 Mdot
.474 .34395 Mdot
.474 .3441 Mdot
.474 .3442 Mdot
.474 .3442 Mdot
.474 .34459 Mdot
.474 .34468 Mdot
.474 .3447 Mdot
.474 .34483 Mdot
.474 .345 Mdot
.474 .34502 Mdot
.474 .34504 Mdot
.474 .34513 Mdot
.474 .34515 Mdot
.474 .34521 Mdot
.474 .34527 Mdot
.474 .34538 Mdot
.474 .34538 Mdot
.474 .34618 Mdot
.474 .34618 Mdot
.474 .34664 Mdot
.474 .34664 Mdot
.474 .34672 Mdot
.474 .34673 Mdot
.474 .34678 Mdot
.474 .34704 Mdot
.474 .34712 Mdot
.474 .34715 Mdot
.474 .34744 Mdot
.474 .34745 Mdot
.474 .34752 Mdot
.474 .34758 Mdot
.474 .34793 Mdot
.474 .34805 Mdot
.474 .34846 Mdot
.474 .34846 Mdot
.474 .34851 Mdot
.474 .34852 Mdot
.474 .34875 Mdot
.474 .34882 Mdot
.474 .34887 Mdot
.474 .34898 Mdot
.474 .34899 Mdot
.474 .34902 Mdot
.474 .3492 Mdot
.474 .34924 Mdot
.474 .34927 Mdot
.474 .34959 Mdot
.474 .3498 Mdot
.474 .34984 Mdot
.474 .34998 Mdot
.474 .34999 Mdot
.474 .35039 Mdot
.474 .35041 Mdot
.474 .35057 Mdot
.474 .35057 Mdot
.474 .35066 Mdot
.474 .3507 Mdot
.474 .35071 Mdot
.474 .3509 Mdot
.474 .35101 Mdot
.474 .35182 Mdot
.474 .3519 Mdot
.474 .35191 Mdot
.474 .35205 Mdot
.474 .35205 Mdot
.474 .35214 Mdot
.474 .35216 Mdot
.474 .35221 Mdot
.474 .35227 Mdot
.474 .35227 Mdot
.474 .35228 Mdot
.474 .48537 Mdot
.474 .48538 Mdot
.474 .48538 Mdot
.474 .4854 Mdot
.474 .48542 Mdot
.474 .48543 Mdot
.474 .48548 Mdot
.474 .48548 Mdot
.474 .48554 Mdot
.474 .48555 Mdot
.474 .48558 Mdot
.474 .48596 Mdot
.474 .48601 Mdot
.474 .4861 Mdot
.474 .48611 Mdot
.474 .48612 Mdot
.474 .48617 Mdot
.474 .48617 Mdot
.474 .48624 Mdot
.474 .48625 Mdot
.474 .48643 Mdot
.474 .48644 Mdot
.474 .4865 Mdot
.474 .48652 Mdot
.474 .48662 Mdot
.474 .48677 Mdot
.474 .48678 Mdot
.474 .4868 Mdot
.474 .48689 Mdot
.474 .4869 Mdot
.474 .4869 Mdot
.474 .48695 Mdot
.474 .48698 Mdot
.474 .48701 Mdot
.474 .48712 Mdot
.474 .48712 Mdot
.474 .48714 Mdot
.474 .48714 Mdot
.474 .48733 Mdot
.474 .48739 Mdot
.474 .48755 Mdot
.474 .48758 Mdot
.474 .48761 Mdot
.474 .48761 Mdot
.474 .48775 Mdot
.474 .48776 Mdot
.474 .4878 Mdot
.474 .48792 Mdot
.474 .48794 Mdot
.474 .48794 Mdot
.474 .48798 Mdot
.474 .48798 Mdot
.474 .48819 Mdot
.474 .48819 Mdot
.474 .48856 Mdot
.474 .48856 Mdot
.474 .48861 Mdot
.474 .48864 Mdot
.474 .48866 Mdot
.474 .48867 Mdot
.474 .48871 Mdot
.474 .48872 Mdot
.474 .48873 Mdot
.474 .48881 Mdot
.474 .48887 Mdot
.474 .48888 Mdot
.474 .48892 Mdot
.474 .4891 Mdot
.474 .4891 Mdot
.474 .48914 Mdot
.474 .48921 Mdot
.474 .48925 Mdot
.474 .48969 Mdot
.474 .4897 Mdot
.474 .48981 Mdot
.474 .48991 Mdot
.474 .49013 Mdot
.474 .49013 Mdot
.474 .49027 Mdot
.474 .49047 Mdot
.474 .49055 Mdot
.474 .49067 Mdot
.474 .49085 Mdot
.474 .49139 Mdot
.474 .4914 Mdot
.474 .49149 Mdot
.474 .4915 Mdot
.474 .49163 Mdot
.474 .49192 Mdot
.474 .49196 Mdot
.474 .49205 Mdot
.474 .49205 Mdot
.474 .49215 Mdot
.474 .49218 Mdot
.474 .49226 Mdot
.474 .49236 Mdot
.474 .49238 Mdot
.474 .49244 Mdot
.474 .49245 Mdot
.474 .49278 Mdot
.474 .49279 Mdot
.474 .49282 Mdot
.474 .49287 Mdot
.474 .49294 Mdot
.474 .49296 Mdot
.474 .49333 Mdot
.474 .49333 Mdot
.474 .49338 Mdot
.474 .49348 Mdot
.474 .49359 Mdot
.474 .49396 Mdot
.474 .49403 Mdot
.474 .49406 Mdot
.474 .49412 Mdot
.474 .49442 Mdot
.474 .49445 Mdot
.474 .49533 Mdot
.474 .49538 Mdot
.474 .49566 Mdot
.474 .49572 Mdot
.474 .49575 Mdot
.474 .49575 Mdot
.474 .49597 Mdot
.474 .49605 Mdot
.474 .49607 Mdot
.474 .49628 Mdot
.474 .4964 Mdot
.474 .49645 Mdot
.474 .49653 Mdot
.474 .49658 Mdot
.474 .4968 Mdot
.474 .49732 Mdot
.474 .49753 Mdot
.474 .49773 Mdot
.474 .49783 Mdot
.474 .49783 Mdot
.474 .49859 Mdot
.474 .49863 Mdot
.474 .49877 Mdot
.474 .49882 Mdot
.474 .49886 Mdot
.474 .49894 Mdot
.474 .49895 Mdot
.474 .49901 Mdot
.474 .49904 Mdot
.474 .49941 Mdot
.474 .49941 Mdot
.474 .49965 Mdot
.474 .49965 Mdot
.474 .49967 Mdot
.474 .49979 Mdot
.474 .49983 Mdot
.474 .49984 Mdot
.474 .49998 Mdot
.474 .49998 Mdot
.474 .50002 Mdot
.474 .50005 Mdot
.474 .50022 Mdot
.474 .50028 Mdot
.474 .50049 Mdot
.474 .50049 Mdot
.474 .50068 Mdot
.474 .50078 Mdot
.474 .5014 Mdot
.474 .50169 Mdot
.474 .50171 Mdot
.474 .50191 Mdot
.474 .50193 Mdot
.474 .50312 Mdot
.474 .50353 Mdot
.474 .50381 Mdot
.474 .50398 Mdot
.474 .50444 Mdot
.474 .50475 Mdot
.474 .50475 Mdot
.474 .50526 Mdot
.474 .50547 Mdot
.474 .50574 Mdot
.474 .50576 Mdot
.474 .50678 Mdot
.474 .50687 Mdot
.474 .50703 Mdot
.474 .50714 Mdot
.474 .50714 Mdot
.474 .50755 Mdot
.474 .50765 Mdot
.474 .50768 Mdot
.474 .50781 Mdot
.474 .508 Mdot
.474 .50802 Mdot
.474 .50804 Mdot
.474 .50814 Mdot
.474 .50816 Mdot
.474 .50822 Mdot
.474 .50829 Mdot
.474 .50841 Mdot
.474 .50841 Mdot
.474 .50928 Mdot
.474 .50928 Mdot
.474 .50978 Mdot
.474 .50978 Mdot
.474 .50987 Mdot
.474 .50987 Mdot
.474 .50992 Mdot
.474 .51021 Mdot
.474 .5103 Mdot
.474 .51033 Mdot
.474 .51065 Mdot
.474 .51066 Mdot
.474 .51074 Mdot
.474 .51081 Mdot
.474 .51119 Mdot
.474 .51132 Mdot
.474 .51177 Mdot
.474 .51178 Mdot
.474 .51183 Mdot
.474 .51184 Mdot
.474 .51209 Mdot
.474 .51217 Mdot
.474 .51223 Mdot
.474 .51235 Mdot
.474 .51236 Mdot
.474 .51239 Mdot
.474 .51259 Mdot
.474 .51263 Mdot
.474 .51267 Mdot
.474 .51302 Mdot
.474 .51326 Mdot
.474 .5133 Mdot
.474 .51345 Mdot
.474 .51347 Mdot
.474 .51391 Mdot
.474 .51394 Mdot
.474 .51411 Mdot
.474 .51411 Mdot
.474 .51422 Mdot
.474 .51426 Mdot
.474 .51427 Mdot
.474 .51448 Mdot
.474 .51461 Mdot
.474 .5155 Mdot
.474 .51559 Mdot
.474 .5156 Mdot
.474 .51576 Mdot
.474 .51576 Mdot
.474 .51586 Mdot
.474 .51594 Mdot
.474 .516 Mdot
.474 .516 Mdot
.474 .51601 Mdot
.474 .53002 Mdot
.474 .53002 Mdot
.474 .53002 Mdot
.474 .53005 Mdot
.474 .53009 Mdot
.474 .53014 Mdot
.474 .53014 Mdot
.474 .53021 Mdot
.474 .53022 Mdot
.474 .53026 Mdot
.474 .53067 Mdot
.474 .53073 Mdot
.474 .53083 Mdot
.474 .53083 Mdot
.474 .53085 Mdot
.474 .5309 Mdot
.474 .5309 Mdot
.474 .53098 Mdot
.474 .53099 Mdot
.474 .53119 Mdot
.474 .5312 Mdot
.474 .53126 Mdot
.474 .53128 Mdot
.474 .53139 Mdot
.474 .53154 Mdot
.474 .53156 Mdot
.474 .53158 Mdot
.474 .53167 Mdot
.474 .53168 Mdot
.474 .53169 Mdot
.474 .53174 Mdot
.474 .53177 Mdot
.474 .5318 Mdot
.474 .53191 Mdot
.474 .53191 Mdot
.474 .53194 Mdot
.474 .53194 Mdot
.474 .53214 Mdot
.474 .53219 Mdot
.474 .53235 Mdot
.474 .53238 Mdot
.474 .53242 Mdot
.474 .53242 Mdot
.474 .53256 Mdot
.474 .53257 Mdot
.474 .53261 Mdot
.474 .53273 Mdot
.474 .53275 Mdot
.474 .53275 Mdot
.474 .53279 Mdot
.474 .53279 Mdot
.474 .533 Mdot
.474 .533 Mdot
.474 .53336 Mdot
.474 .53336 Mdot
.474 .53341 Mdot
.474 .53343 Mdot
.474 .53346 Mdot
.474 .53347 Mdot
.474 .53351 Mdot
.474 .53352 Mdot
.474 .53352 Mdot
.474 .5336 Mdot
.474 .53365 Mdot
.474 .53366 Mdot
.474 .5337 Mdot
.474 .53387 Mdot
.474 .53387 Mdot
.474 .53391 Mdot
.474 .53398 Mdot
.474 .53401 Mdot
.474 .53442 Mdot
.474 .53442 Mdot
.474 .53453 Mdot
.474 .53461 Mdot
.474 .53481 Mdot
.474 .53481 Mdot
.474 .53493 Mdot
.474 .53511 Mdot
.474 .53517 Mdot
.474 .53528 Mdot
.474 .53543 Mdot
.474 .53587 Mdot
.474 .53588 Mdot
.474 .53596 Mdot
.474 .53596 Mdot
.474 .53607 Mdot
.474 .5363 Mdot
.474 .53633 Mdot
.474 .5364 Mdot
.474 .5364 Mdot
.474 .53648 Mdot
.474 .5365 Mdot
.474 .53656 Mdot
.474 .53657 Mdot
.474 .53659 Mdot
.474 .53659 Mdot
.474 .53664 Mdot
.474 .53664 Mdot
.474 .53665 Mdot
.474 .5367 Mdot
.474 .5367 Mdot
.474 .5367 Mdot
.474 .53679 Mdot
.474 .53679 Mdot
.474 .53692 Mdot
.474 .53693 Mdot
.474 .53696 Mdot
.474 .53696 Mdot
.474 .53698 Mdot
.474 .537 Mdot
.474 .53702 Mdot
.474 .53707 Mdot
.474 .53708 Mdot
.474 .53735 Mdot
.474 .53735 Mdot
.474 .53738 Mdot
.474 .53745 Mdot
.474 .53753 Mdot
.474 .53771 Mdot
.474 .53778 Mdot
.474 .5378 Mdot
.474 .53783 Mdot
.474 .53785 Mdot
.474 .53789 Mdot
.474 .53796 Mdot
.474 .53796 Mdot
.474 .53799 Mdot
.474 .53807 Mdot
.474 .53807 Mdot
.474 .53808 Mdot
.474 .5381 Mdot
.474 .53819 Mdot
.474 .53821 Mdot
.474 .53851 Mdot
.474 .53852 Mdot
.474 .53862 Mdot
.474 .53864 Mdot
.474 .53865 Mdot
.474 .53867 Mdot
.474 .53879 Mdot
.474 .53883 Mdot
.474 .53886 Mdot
.474 .53888 Mdot
.474 .53888 Mdot
.474 .539 Mdot
.474 .53901 Mdot
.474 .53903 Mdot
.474 .53905 Mdot
.474 .53906 Mdot
.474 .53906 Mdot
.474 .53917 Mdot
.474 .53917 Mdot
.474 .53919 Mdot
.474 .5392 Mdot
.474 .53923 Mdot
.474 .53926 Mdot
.474 .53927 Mdot
.474 .5393 Mdot
.474 .5393 Mdot
.474 .53933 Mdot
.474 .53934 Mdot
.474 .53944 Mdot
.474 .53948 Mdot
.474 .53948 Mdot
.474 .53951 Mdot
.474 .53952 Mdot
.474 .53969 Mdot
.474 .53975 Mdot
.474 .53979 Mdot
.474 .53981 Mdot
.474 .53987 Mdot
.474 .53992 Mdot
.474 .53992 Mdot
.474 .53999 Mdot
.474 .54002 Mdot
.474 .54006 Mdot
.474 .54006 Mdot
.474 .5402 Mdot
.474 .54021 Mdot
.474 .54023 Mdot
.474 .54025 Mdot
.474 .54025 Mdot
.474 .5403 Mdot
.474 .54031 Mdot
.474 .54032 Mdot
.474 .54034 Mdot
.474 .54036 Mdot
.474 .54036 Mdot
.474 .54037 Mdot
.474 .54038 Mdot
.474 .54038 Mdot
.474 .54039 Mdot
.474 .5404 Mdot
.474 .54042 Mdot
.474 .54042 Mdot
.474 .54053 Mdot
.474 .54053 Mdot
.474 .5406 Mdot
.474 .5406 Mdot
.474 .54061 Mdot
.474 .54061 Mdot
.474 .54062 Mdot
.474 .54065 Mdot
.474 .54066 Mdot
.474 .54067 Mdot
.474 .54071 Mdot
.474 .54071 Mdot
.474 .54072 Mdot
.474 .54073 Mdot
.474 .54078 Mdot
.474 .5408 Mdot
.474 .54086 Mdot
.474 .54086 Mdot
.474 .54086 Mdot
.474 .54086 Mdot
.474 .5409 Mdot
.474 .54091 Mdot
.474 .54091 Mdot
.474 .54093 Mdot
.474 .54093 Mdot
.474 .54093 Mdot
.474 .54096 Mdot
.474 .54097 Mdot
.474 .54097 Mdot
.474 .54102 Mdot
.474 .54105 Mdot
.474 .54105 Mdot
.474 .54107 Mdot
.474 .54107 Mdot
.474 .54113 Mdot
.474 .54113 Mdot
.474 .54116 Mdot
.474 .54116 Mdot
.474 .54117 Mdot
.474 .54117 Mdot
.474 .54118 Mdot
.474 .5412 Mdot
.474 .54122 Mdot
.474 .54133 Mdot
.474 .54134 Mdot
.474 .54135 Mdot
.474 .54137 Mdot
.474 .54137 Mdot
.474 .54138 Mdot
.474 .54138 Mdot
.474 .54139 Mdot
.474 .5414 Mdot
.474 .5414 Mdot
.474 .5414 Mdot
.476 .21245 Mdot
.476 .21245 Mdot
.476 .21246 Mdot
.476 .21246 Mdot
.476 .21246 Mdot
.476 .21248 Mdot
.476 .21251 Mdot
.476 .21254 Mdot
.476 .21259 Mdot
.476 .21268 Mdot
.476 .21269 Mdot
.476 .21274 Mdot
.476 .2128 Mdot
.476 .21286 Mdot
.476 .21293 Mdot
.476 .21294 Mdot
.476 .21295 Mdot
.476 .21295 Mdot
.476 .21296 Mdot
.476 .21296 Mdot
.476 .21303 Mdot
.476 .21303 Mdot
.476 .21315 Mdot
.476 .21316 Mdot
.476 .21323 Mdot
.476 .21328 Mdot
.476 .21329 Mdot
.476 .2133 Mdot
.476 .21334 Mdot
.476 .21348 Mdot
.476 .21357 Mdot
.476 .21359 Mdot
.476 .21373 Mdot
.476 .21376 Mdot
.476 .21384 Mdot
.476 .21384 Mdot
.476 .21386 Mdot
.476 .21387 Mdot
.476 .21391 Mdot
.476 .21392 Mdot
.476 .21396 Mdot
.476 .21398 Mdot
.476 .21404 Mdot
.476 .21413 Mdot
.476 .21415 Mdot
.476 .21419 Mdot
.476 .21423 Mdot
.476 .21426 Mdot
.476 .21426 Mdot
.476 .21455 Mdot
.476 .21465 Mdot
.476 .21483 Mdot
.476 .21491 Mdot
.476 .21542 Mdot
.476 .21543 Mdot
.476 .21547 Mdot
.476 .21548 Mdot
.476 .21555 Mdot
.476 .21555 Mdot
.476 .21558 Mdot
.476 .21561 Mdot
.476 .21566 Mdot
.476 .21567 Mdot
.476 .21593 Mdot
.476 .2161 Mdot
.476 .21616 Mdot
.476 .21625 Mdot
.476 .21637 Mdot
.476 .21643 Mdot
.476 .21656 Mdot
.476 .21693 Mdot
.476 .21693 Mdot
.476 .21701 Mdot
.476 .21708 Mdot
.476 .21714 Mdot
.476 .21724 Mdot
.476 .21734 Mdot
.476 .21739 Mdot
.476 .21762 Mdot
.476 .21777 Mdot
.476 .21809 Mdot
.476 .2181 Mdot
.476 .21819 Mdot
.476 .21821 Mdot
.476 .21824 Mdot
.476 .21839 Mdot
.476 .2184 Mdot
.476 .21855 Mdot
.476 .21856 Mdot
.476 .21866 Mdot
.476 .21878 Mdot
.476 .21897 Mdot
.476 .21905 Mdot
.476 .21934 Mdot
.476 .21941 Mdot
.476 .21964 Mdot
.476 .21969 Mdot
.476 .21971 Mdot
.476 .21989 Mdot
.476 .21992 Mdot
.476 .22 Mdot
.476 .22003 Mdot
.476 .22005 Mdot
.476 .22013 Mdot
.476 .22044 Mdot
.476 .22057 Mdot
.476 .2208 Mdot
.476 .22092 Mdot
.476 .22112 Mdot
.476 .22133 Mdot
.476 .22143 Mdot
.476 .2215 Mdot
.476 .22188 Mdot
.476 .22193 Mdot
.476 .22213 Mdot
.476 .22258 Mdot
.476 .2227 Mdot
.476 .22284 Mdot
.476 .22295 Mdot
.476 .22305 Mdot
.476 .22308 Mdot
.476 .22337 Mdot
.476 .22347 Mdot
.476 .22364 Mdot
.476 .22368 Mdot
.476 .22375 Mdot
.476 .22383 Mdot
.476 .22387 Mdot
.476 .22392 Mdot
.476 .22398 Mdot
.476 .22437 Mdot
.476 .22442 Mdot
.476 .22452 Mdot
.476 .2246 Mdot
.476 .22465 Mdot
.476 .22503 Mdot
.476 .22508 Mdot
.476 .22511 Mdot
.476 .22513 Mdot
.476 .22514 Mdot
.476 .2252 Mdot
.476 .22521 Mdot
.476 .22524 Mdot
.476 .22525 Mdot
.476 .22576 Mdot
.476 .22584 Mdot
.476 .22604 Mdot
.476 .22615 Mdot
.476 .22649 Mdot
.476 .22657 Mdot
.476 .22676 Mdot
.476 .22693 Mdot
.476 .227 Mdot
.476 .227 Mdot
.476 .22704 Mdot
.476 .2274 Mdot
.476 .22743 Mdot
.476 .22757 Mdot
.476 .2278 Mdot
.476 .22787 Mdot
.476 .2279 Mdot
.476 .228 Mdot
.476 .22814 Mdot
.476 .22816 Mdot
.476 .22841 Mdot
.476 .22856 Mdot
.476 .22858 Mdot
.476 .22858 Mdot
.476 .22861 Mdot
.476 .22863 Mdot
.476 .22897 Mdot
.476 .22936 Mdot
.476 .22997 Mdot
.476 .23011 Mdot
.476 .23038 Mdot
.476 .23064 Mdot
.476 .23079 Mdot
.476 .23099 Mdot
.476 .23121 Mdot
.476 .23121 Mdot
.476 .23224 Mdot
.476 .2326 Mdot
.476 .23277 Mdot
.476 .23312 Mdot
.476 .23338 Mdot
.476 .23356 Mdot
.476 .23407 Mdot
.476 .23483 Mdot
.476 .23487 Mdot
.476 .235 Mdot
.476 .2351 Mdot
.476 .23518 Mdot
.476 .2352 Mdot
.476 .2354 Mdot
.476 .23544 Mdot
.476 .23554 Mdot
.476 .23557 Mdot
.476 .23716 Mdot
.476 .23742 Mdot
.476 .23801 Mdot
.476 .23833 Mdot
.476 .23927 Mdot
.476 .23928 Mdot
.476 .23936 Mdot
.476 .2395 Mdot
.476 .23962 Mdot
.476 .2397 Mdot
.476 .23999 Mdot
.476 .24019 Mdot
.476 .24024 Mdot
.476 .2404 Mdot
.476 .24043 Mdot
.476 .24057 Mdot
.476 .24059 Mdot
.476 .24064 Mdot
.476 .24067 Mdot
.476 .24094 Mdot
.476 .24103 Mdot
.476 .24151 Mdot
.476 .24158 Mdot
.476 .24189 Mdot
.476 .24235 Mdot
.476 .2425 Mdot
.476 .24256 Mdot
.476 .24258 Mdot
.476 .24275 Mdot
.476 .24301 Mdot
.476 .24303 Mdot
.476 .24344 Mdot
.476 .24347 Mdot
.476 .2437 Mdot
.476 .24372 Mdot
.476 .24373 Mdot
.476 .24374 Mdot
.476 .24377 Mdot
.476 .24379 Mdot
.476 .2438 Mdot
.476 .24407 Mdot
.476 .24428 Mdot
.476 .2445 Mdot
.476 .24468 Mdot
.476 .24472 Mdot
.476 .24501 Mdot
.476 .24523 Mdot
.476 .24543 Mdot
.476 .24551 Mdot
.476 .24552 Mdot
.476 .24552 Mdot
.476 .24553 Mdot
.476 .24554 Mdot
.476 .27817 Mdot
.476 .27819 Mdot
.476 .27821 Mdot
.476 .27821 Mdot
.476 .27823 Mdot
.476 .27838 Mdot
.476 .27878 Mdot
.476 .27921 Mdot
.476 .27979 Mdot
.476 .27986 Mdot
.476 .28022 Mdot
.476 .28066 Mdot
.476 .28107 Mdot
.476 .28161 Mdot
.476 .28162 Mdot
.476 .28166 Mdot
.476 .28174 Mdot
.476 .28174 Mdot
.476 .28177 Mdot
.476 .2818 Mdot
.476 .28227 Mdot
.476 .28233 Mdot
.476 .28315 Mdot
.476 .2832 Mdot
.476 .28373 Mdot
.476 .28407 Mdot
.476 .2841 Mdot
.476 .28423 Mdot
.476 .28452 Mdot
.476 .28547 Mdot
.476 .28609 Mdot
.476 .28623 Mdot
.476 .28723 Mdot
.476 .28741 Mdot
.476 .28797 Mdot
.476 .28802 Mdot
.476 .28813 Mdot
.476 .28817 Mdot
.476 .28846 Mdot
.476 .28852 Mdot
.476 .28885 Mdot
.476 .28896 Mdot
.476 .28938 Mdot
.476 .28997 Mdot
.476 .29015 Mdot
.476 .2904 Mdot
.476 .29069 Mdot
.476 .29086 Mdot
.476 .29087 Mdot
.476 .29286 Mdot
.476 .29354 Mdot
.476 .29479 Mdot
.476 .29535 Mdot
.476 .29877 Mdot
.476 .29884 Mdot
.476 .29907 Mdot
.476 .29914 Mdot
.476 .29958 Mdot
.476 .29963 Mdot
.476 .29981 Mdot
.476 .30001 Mdot
.476 .3003 Mdot
.476 .30038 Mdot
.476 .30207 Mdot
.476 .30318 Mdot
.476 .30359 Mdot
.476 .30415 Mdot
.476 .30493 Mdot
.476 .30531 Mdot
.476 .30611 Mdot
.476 .30842 Mdot
.476 .30844 Mdot
.476 .30892 Mdot
.476 .30938 Mdot
.476 .30972 Mdot
.476 .31031 Mdot
.476 .31093 Mdot
.476 .31125 Mdot
.476 .31265 Mdot
.476 .31352 Mdot
.476 .31432 Mdot
.476 .31435 Mdot
.476 .31441 Mdot
.476 .31442 Mdot
.476 .31446 Mdot
.476 .31481 Mdot
.476 .3154 Mdot
.476 .31543 Mdot
.476 .31576 Mdot
.476 .31599 Mdot
.476 .31606 Mdot
.476 .31623 Mdot
.476 .31676 Mdot
.476 .31708 Mdot
.476 .31715 Mdot
.476 .318 Mdot
.476 .31807 Mdot
.476 .31809 Mdot
.476 .31825 Mdot
.476 .31864 Mdot
.476 .31907 Mdot
.476 .31927 Mdot
.476 .32006 Mdot
.476 .32032 Mdot
.476 .32078 Mdot
.476 .32099 Mdot
.476 .32217 Mdot
.476 .3222 Mdot
.476 .32227 Mdot
.476 .3223 Mdot
.476 .32244 Mdot
.476 .32246 Mdot
.476 .32252 Mdot
.476 .32258 Mdot
.476 .32271 Mdot
.476 .3236 Mdot
.476 .32372 Mdot
.476 .32389 Mdot
.476 .32413 Mdot
.476 .32425 Mdot
.476 .32517 Mdot
.476 .32532 Mdot
.476 .32545 Mdot
.476 .32555 Mdot
.476 .32572 Mdot
.476 .3259 Mdot
.476 .32599 Mdot
.476 .32639 Mdot
.476 .32663 Mdot
.476 .32732 Mdot
.476 .32739 Mdot
.476 .32765 Mdot
.476 .3279 Mdot
.476 .32823 Mdot
.476 .32852 Mdot
.476 .32961 Mdot
.476 .33009 Mdot
.476 .3302 Mdot
.476 .33111 Mdot
.476 .33127 Mdot
.476 .33153 Mdot
.476 .33203 Mdot
.476 .3325 Mdot
.476 .33281 Mdot
.476 .33337 Mdot
.476 .33368 Mdot
.476 .33443 Mdot
.476 .33462 Mdot
.476 .33466 Mdot
.476 .33475 Mdot
.476 .33494 Mdot
.476 .33501 Mdot
.476 .33545 Mdot
.476 .33551 Mdot
.476 .33562 Mdot
.476 .33617 Mdot
.476 .33636 Mdot
.476 .33705 Mdot
.476 .33726 Mdot
.476 .33773 Mdot
.476 .33801 Mdot
.476 .33825 Mdot
.476 .33829 Mdot
.476 .33865 Mdot
.476 .33868 Mdot
.476 .33905 Mdot
.476 .33912 Mdot
.476 .33916 Mdot
.476 .33939 Mdot
.476 .3394 Mdot
.476 .34019 Mdot
.476 .34056 Mdot
.476 .34113 Mdot
.476 .34126 Mdot
.476 .34151 Mdot
.476 .34175 Mdot
.476 .34189 Mdot
.476 .34207 Mdot
.476 .34226 Mdot
.476 .34227 Mdot
.476 .34318 Mdot
.476 .3435 Mdot
.476 .34365 Mdot
.476 .34395 Mdot
.476 .34416 Mdot
.476 .34432 Mdot
.476 .34475 Mdot
.476 .34539 Mdot
.476 .34542 Mdot
.476 .34553 Mdot
.476 .34561 Mdot
.476 .34567 Mdot
.476 .34569 Mdot
.476 .34586 Mdot
.476 .34588 Mdot
.476 .34597 Mdot
.476 .346 Mdot
.476 .34727 Mdot
.476 .34747 Mdot
.476 .34793 Mdot
.476 .34818 Mdot
.476 .3489 Mdot
.476 .34891 Mdot
.476 .34897 Mdot
.476 .34907 Mdot
.476 .34916 Mdot
.476 .34923 Mdot
.476 .34944 Mdot
.476 .34959 Mdot
.476 .34963 Mdot
.476 .34975 Mdot
.476 .34978 Mdot
.476 .34988 Mdot
.476 .34989 Mdot
.476 .34993 Mdot
.476 .34995 Mdot
.476 .35015 Mdot
.476 .35021 Mdot
.476 .35057 Mdot
.476 .35062 Mdot
.476 .35085 Mdot
.476 .35118 Mdot
.476 .35129 Mdot
.476 .35133 Mdot
.476 .35135 Mdot
.476 .35147 Mdot
.476 .35165 Mdot
.476 .35167 Mdot
.476 .35196 Mdot
.476 .35198 Mdot
.476 .35215 Mdot
.476 .35216 Mdot
.476 .35217 Mdot
.476 .35217 Mdot
.476 .3522 Mdot
.476 .35221 Mdot
.476 .35222 Mdot
.476 .35241 Mdot
.476 .35255 Mdot
.476 .35271 Mdot
.476 .35284 Mdot
.476 .35286 Mdot
.476 .35307 Mdot
.476 .35322 Mdot
.476 .35327 Mdot
.476 .35336 Mdot
.476 .35341 Mdot
.476 .35342 Mdot
.476 .35342 Mdot
.476 .35343 Mdot
.476 .35343 Mdot
.476 .4849 Mdot
.476 .48491 Mdot
.476 .48491 Mdot
.476 .48491 Mdot
.476 .48491 Mdot
.476 .48494 Mdot
.476 .48498 Mdot
.476 .485 Mdot
.476 .48507 Mdot
.476 .48517 Mdot
.476 .48518 Mdot
.476 .48524 Mdot
.476 .48531 Mdot
.476 .48538 Mdot
.476 .48547 Mdot
.476 .48548 Mdot
.476 .48549 Mdot
.476 .48549 Mdot
.476 .4855 Mdot
.476 .4855 Mdot
.476 .48558 Mdot
.476 .48559 Mdot
.476 .48572 Mdot
.476 .48573 Mdot
.476 .48582 Mdot
.476 .48588 Mdot
.476 .48588 Mdot
.476 .4859 Mdot
.476 .48595 Mdot
.476 .48611 Mdot
.476 .48621 Mdot
.476 .48623 Mdot
.476 .4864 Mdot
.476 .48643 Mdot
.476 .48652 Mdot
.476 .48653 Mdot
.476 .48655 Mdot
.476 .48656 Mdot
.476 .4866 Mdot
.476 .48661 Mdot
.476 .48667 Mdot
.476 .48669 Mdot
.476 .48676 Mdot
.476 .48686 Mdot
.476 .48689 Mdot
.476 .48693 Mdot
.476 .48698 Mdot
.476 .48701 Mdot
.476 .48701 Mdot
.476 .48734 Mdot
.476 .48746 Mdot
.476 .48767 Mdot
.476 .48776 Mdot
.476 .48834 Mdot
.476 .48836 Mdot
.476 .4884 Mdot
.476 .48841 Mdot
.476 .48848 Mdot
.476 .48849 Mdot
.476 .48852 Mdot
.476 .48856 Mdot
.476 .48861 Mdot
.476 .48862 Mdot
.476 .48892 Mdot
.476 .48911 Mdot
.476 .48918 Mdot
.476 .48928 Mdot
.476 .48942 Mdot
.476 .48949 Mdot
.476 .48963 Mdot
.476 .49004 Mdot
.476 .49005 Mdot
.476 .49013 Mdot
.476 .49022 Mdot
.476 .49028 Mdot
.476 .49039 Mdot
.476 .4905 Mdot
.476 .49056 Mdot
.476 .49082 Mdot
.476 .49098 Mdot
.476 .49134 Mdot
.476 .49135 Mdot
.476 .49145 Mdot
.476 .49147 Mdot
.476 .4915 Mdot
.476 .49166 Mdot
.476 .49168 Mdot
.476 .49184 Mdot
.476 .49186 Mdot
.476 .49197 Mdot
.476 .49209 Mdot
.476 .4923 Mdot
.476 .4924 Mdot
.476 .49271 Mdot
.476 .49279 Mdot
.476 .49304 Mdot
.476 .49309 Mdot
.476 .49311 Mdot
.476 .49331 Mdot
.476 .49334 Mdot
.476 .49343 Mdot
.476 .49346 Mdot
.476 .49348 Mdot
.476 .49357 Mdot
.476 .4939 Mdot
.476 .49404 Mdot
.476 .49429 Mdot
.476 .49442 Mdot
.476 .49464 Mdot
.476 .49485 Mdot
.476 .49497 Mdot
.476 .49504 Mdot
.476 .49544 Mdot
.476 .49549 Mdot
.476 .4957 Mdot
.476 .49618 Mdot
.476 .49631 Mdot
.476 .49645 Mdot
.476 .49657 Mdot
.476 .49668 Mdot
.476 .49671 Mdot
.476 .49701 Mdot
.476 .49712 Mdot
.476 .49729 Mdot
.476 .49733 Mdot
.476 .49741 Mdot
.476 .49748 Mdot
.476 .49753 Mdot
.476 .49758 Mdot
.476 .49765 Mdot
.476 .49805 Mdot
.476 .4981 Mdot
.476 .4982 Mdot
.476 .49828 Mdot
.476 .49833 Mdot
.476 .49872 Mdot
.476 .49877 Mdot
.476 .4988 Mdot
.476 .49882 Mdot
.476 .49883 Mdot
.476 .4989 Mdot
.476 .49891 Mdot
.476 .49894 Mdot
.476 .49895 Mdot
.476 .49946 Mdot
.476 .49955 Mdot
.476 .49975 Mdot
.476 .49986 Mdot
.476 .5002 Mdot
.476 .50029 Mdot
.476 .50047 Mdot
.476 .50064 Mdot
.476 .50071 Mdot
.476 .50072 Mdot
.476 .50075 Mdot
.476 .50111 Mdot
.476 .50114 Mdot
.476 .50128 Mdot
.476 .5015 Mdot
.476 .50158 Mdot
.476 .50161 Mdot
.476 .5017 Mdot
.476 .50184 Mdot
.476 .50186 Mdot
.476 .50211 Mdot
.476 .50226 Mdot
.476 .50228 Mdot
.476 .50228 Mdot
.476 .5023 Mdot
.476 .50232 Mdot
.476 .50266 Mdot
.476 .50303 Mdot
.476 .50362 Mdot
.476 .50375 Mdot
.476 .50401 Mdot
.476 .50426 Mdot
.476 .50441 Mdot
.476 .5046 Mdot
.476 .5048 Mdot
.476 .50481 Mdot
.476 .50578 Mdot
.476 .50611 Mdot
.476 .50627 Mdot
.476 .5066 Mdot
.476 .50683 Mdot
.476 .507 Mdot
.476 .50746 Mdot
.476 .50816 Mdot
.476 .50819 Mdot
.476 .50831 Mdot
.476 .50839 Mdot
.476 .50847 Mdot
.476 .50849 Mdot
.476 .50867 Mdot
.476 .5087 Mdot
.476 .50879 Mdot
.476 .50882 Mdot
.476 .51022 Mdot
.476 .51045 Mdot
.476 .51096 Mdot
.476 .51124 Mdot
.476 .51204 Mdot
.476 .51205 Mdot
.476 .51212 Mdot
.476 .51223 Mdot
.476 .51233 Mdot
.476 .51241 Mdot
.476 .51265 Mdot
.476 .51281 Mdot
.476 .51286 Mdot
.476 .51299 Mdot
.476 .51302 Mdot
.476 .51313 Mdot
.476 .51315 Mdot
.476 .5132 Mdot
.476 .51322 Mdot
.476 .51344 Mdot
.476 .51351 Mdot
.476 .51391 Mdot
.476 .51397 Mdot
.476 .51422 Mdot
.476 .5146 Mdot
.476 .51472 Mdot
.476 .51477 Mdot
.476 .51478 Mdot
.476 .51492 Mdot
.476 .51513 Mdot
.476 .51514 Mdot
.476 .51547 Mdot
.476 .51549 Mdot
.476 .51568 Mdot
.476 .51569 Mdot
.476 .5157 Mdot
.476 .51571 Mdot
.476 .51574 Mdot
.476 .51575 Mdot
.476 .51576 Mdot
.476 .51597 Mdot
.476 .51614 Mdot
.476 .51631 Mdot
.476 .51645 Mdot
.476 .51648 Mdot
.476 .51671 Mdot
.476 .51688 Mdot
.476 .51704 Mdot
.476 .5171 Mdot
.476 .5171 Mdot
.476 .5171 Mdot
.476 .51711 Mdot
.476 .51712 Mdot
.476 .52963 Mdot
.476 .52964 Mdot
.476 .52964 Mdot
.476 .52964 Mdot
.476 .52964 Mdot
.476 .52967 Mdot
.476 .52975 Mdot
.476 .52983 Mdot
.476 .52994 Mdot
.476 .52995 Mdot
.476 .53002 Mdot
.476 .5301 Mdot
.476 .53018 Mdot
.476 .53028 Mdot
.476 .53028 Mdot
.476 .53029 Mdot
.476 .5303 Mdot
.476 .5303 Mdot
.476 .53031 Mdot
.476 .53032 Mdot
.476 .5304 Mdot
.476 .53041 Mdot
.476 .53057 Mdot
.476 .53057 Mdot
.476 .53067 Mdot
.476 .53073 Mdot
.476 .53074 Mdot
.476 .53076 Mdot
.476 .53082 Mdot
.476 .53099 Mdot
.476 .5311 Mdot
.476 .53113 Mdot
.476 .53131 Mdot
.476 .53134 Mdot
.476 .53144 Mdot
.476 .53145 Mdot
.476 .53147 Mdot
.476 .53148 Mdot
.476 .53153 Mdot
.476 .53154 Mdot
.476 .5316 Mdot
.476 .53162 Mdot
.476 .53169 Mdot
.476 .5318 Mdot
.476 .53183 Mdot
.476 .53187 Mdot
.476 .53192 Mdot
.476 .53195 Mdot
.476 .53195 Mdot
.476 .5323 Mdot
.476 .53242 Mdot
.476 .53264 Mdot
.476 .53273 Mdot
.476 .53331 Mdot
.476 .53333 Mdot
.476 .53336 Mdot
.476 .53338 Mdot
.476 .53345 Mdot
.476 .53346 Mdot
.476 .53349 Mdot
.476 .53352 Mdot
.476 .53357 Mdot
.476 .53359 Mdot
.476 .53387 Mdot
.476 .53405 Mdot
.476 .53412 Mdot
.476 .53421 Mdot
.476 .53434 Mdot
.476 .5344 Mdot
.476 .53453 Mdot
.476 .53491 Mdot
.476 .53491 Mdot
.476 .53499 Mdot
.476 .53506 Mdot
.476 .53512 Mdot
.476 .53521 Mdot
.476 .53531 Mdot
.476 .53536 Mdot
.476 .53558 Mdot
.476 .53572 Mdot
.476 .53585 Mdot
.476 .53585 Mdot
.476 .53586 Mdot
.476 .53586 Mdot
.476 .53587 Mdot
.476 .53592 Mdot
.476 .53602 Mdot
.476 .53602 Mdot
.476 .53607 Mdot
.476 .53611 Mdot
.476 .53612 Mdot
.476 .53615 Mdot
.476 .53623 Mdot
.476 .53628 Mdot
.476 .53629 Mdot
.476 .53642 Mdot
.476 .53643 Mdot
.476 .53644 Mdot
.476 .53646 Mdot
.476 .53652 Mdot
.476 .53659 Mdot
.476 .53662 Mdot
.476 .53674 Mdot
.476 .53678 Mdot
.476 .53685 Mdot
.476 .53688 Mdot
.476 .53707 Mdot
.476 .53707 Mdot
.476 .53708 Mdot
.476 .53708 Mdot
.476 .53711 Mdot
.476 .53711 Mdot
.476 .53712 Mdot
.476 .53713 Mdot
.476 .53715 Mdot
.476 .53728 Mdot
.476 .5373 Mdot
.476 .53733 Mdot
.476 .53736 Mdot
.476 .53738 Mdot
.476 .53752 Mdot
.476 .53754 Mdot
.476 .53756 Mdot
.476 .53758 Mdot
.476 .5376 Mdot
.476 .53763 Mdot
.476 .53764 Mdot
.476 .5377 Mdot
.476 .53774 Mdot
.476 .53785 Mdot
.476 .53786 Mdot
.476 .53789 Mdot
.476 .53793 Mdot
.476 .53798 Mdot
.476 .53803 Mdot
.476 .53819 Mdot
.476 .53826 Mdot
.476 .53828 Mdot
.476 .53841 Mdot
.476 .53844 Mdot
.476 .53848 Mdot
.476 .53855 Mdot
.476 .53862 Mdot
.476 .53866 Mdot
.476 .53875 Mdot
.476 .53879 Mdot
.476 .5389 Mdot
.476 .53893 Mdot
.476 .53894 Mdot
.476 .53895 Mdot
.476 .53898 Mdot
.476 .53899 Mdot
.476 .53905 Mdot
.476 .53906 Mdot
.476 .53908 Mdot
.476 .53916 Mdot
.476 .53919 Mdot
.476 .53929 Mdot
.476 .53932 Mdot
.476 .53939 Mdot
.476 .53943 Mdot
.476 .53946 Mdot
.476 .53947 Mdot
.476 .53952 Mdot
.476 .53953 Mdot
.476 .53958 Mdot
.476 .53959 Mdot
.476 .53959 Mdot
.476 .53963 Mdot
.476 .53963 Mdot
.476 .53975 Mdot
.476 .5398 Mdot
.476 .53988 Mdot
.476 .5399 Mdot
.476 .53994 Mdot
.476 .53997 Mdot
.476 .53999 Mdot
.476 .54002 Mdot
.476 .54004 Mdot
.476 .54005 Mdot
.476 .54018 Mdot
.476 .54022 Mdot
.476 .54024 Mdot
.476 .54029 Mdot
.476 .54032 Mdot
.476 .54034 Mdot
.476 .5404 Mdot
.476 .54049 Mdot
.476 .5405 Mdot
.476 .54051 Mdot
.476 .54052 Mdot
.476 .54053 Mdot
.476 .54054 Mdot
.476 .54056 Mdot
.476 .54056 Mdot
.476 .54058 Mdot
.476 .54058 Mdot
.476 .54076 Mdot
.476 .54079 Mdot
.476 .54086 Mdot
.476 .54089 Mdot
.476 .54099 Mdot
.476 .54099 Mdot
.476 .541 Mdot
.476 .54102 Mdot
.476 .54103 Mdot
.476 .54104 Mdot
.476 .54107 Mdot
.476 .54109 Mdot
.476 .5411 Mdot
.476 .54111 Mdot
.476 .54112 Mdot
.476 .54113 Mdot
.476 .54113 Mdot
.476 .54114 Mdot
.476 .54114 Mdot
.476 .54117 Mdot
.476 .54118 Mdot
.476 .54123 Mdot
.476 .54124 Mdot
.476 .54127 Mdot
.476 .54132 Mdot
.476 .54133 Mdot
.476 .54134 Mdot
.476 .54134 Mdot
.476 .54136 Mdot
.476 .54138 Mdot
.476 .54139 Mdot
.476 .54143 Mdot
.476 .54143 Mdot
.476 .54145 Mdot
.476 .54145 Mdot
.476 .54146 Mdot
.476 .54146 Mdot
.476 .54146 Mdot
.476 .54146 Mdot
.476 .54149 Mdot
.476 .54151 Mdot
.476 .54153 Mdot
.476 .54155 Mdot
.476 .54155 Mdot
.476 .54158 Mdot
.476 .5416 Mdot
.476 .54161 Mdot
.476 .54162 Mdot
.476 .54163 Mdot
.476 .54163 Mdot
.476 .54163 Mdot
.476 .54163 Mdot
.476 .54163 Mdot
.478 .21188 Mdot
.478 .23103 Mdot
.478 .24671 Mdot
.478 .27544 Mdot
.478 .30845 Mdot
.478 .35458 Mdot
.478 .48444 Mdot
.478 .50485 Mdot
.478 .51824 Mdot
.478 .52923 Mdot
.478 .53501 Mdot
.478 .54187 Mdot
.48 .21129 Mdot
.48 .21129 Mdot
.48 .21129 Mdot
.48 .21129 Mdot
.48 .21129 Mdot
.48 .21129 Mdot
.48 .2113 Mdot
.48 .2113 Mdot
.48 .21132 Mdot
.48 .21133 Mdot
.48 .21136 Mdot
.48 .21136 Mdot
.48 .21139 Mdot
.48 .21139 Mdot
.48 .2114 Mdot
.48 .21143 Mdot
.48 .21144 Mdot
.48 .21147 Mdot
.48 .21155 Mdot
.48 .21159 Mdot
.48 .21163 Mdot
.48 .21164 Mdot
.48 .21165 Mdot
.48 .21165 Mdot
.48 .21167 Mdot
.48 .21178 Mdot
.48 .2118 Mdot
.48 .2118 Mdot
.48 .21184 Mdot
.48 .21191 Mdot
.48 .21192 Mdot
.48 .21192 Mdot
.48 .21204 Mdot
.48 .21205 Mdot
.48 .21208 Mdot
.48 .21208 Mdot
.48 .21211 Mdot
.48 .21218 Mdot
.48 .21219 Mdot
.48 .21222 Mdot
.48 .21222 Mdot
.48 .21222 Mdot
.48 .21223 Mdot
.48 .21223 Mdot
.48 .21223 Mdot
.48 .21225 Mdot
.48 .21227 Mdot
.48 .21239 Mdot
.48 .21246 Mdot
.48 .21268 Mdot
.48 .21278 Mdot
.48 .21281 Mdot
.48 .21297 Mdot
.48 .21298 Mdot
.48 .213 Mdot
.48 .21303 Mdot
.48 .21303 Mdot
.48 .21304 Mdot
.48 .21305 Mdot
.48 .21316 Mdot
.48 .2133 Mdot
.48 .21403 Mdot
.48 .21403 Mdot
.48 .21408 Mdot
.48 .21427 Mdot
.48 .21432 Mdot
.48 .21451 Mdot
.48 .21453 Mdot
.48 .21461 Mdot
.48 .21461 Mdot
.48 .21497 Mdot
.48 .21514 Mdot
.48 .21585 Mdot
.48 .21604 Mdot
.48 .21605 Mdot
.48 .21619 Mdot
.48 .21649 Mdot
.48 .2165 Mdot
.48 .21654 Mdot
.48 .21671 Mdot
.48 .2174 Mdot
.48 .21747 Mdot
.48 .21783 Mdot
.48 .21879 Mdot
.48 .21879 Mdot
.48 .21882 Mdot
.48 .21938 Mdot
.48 .21948 Mdot
.48 .21949 Mdot
.48 .21954 Mdot
.48 .21976 Mdot
.48 .22016 Mdot
.48 .22016 Mdot
.48 .22017 Mdot
.48 .22033 Mdot
.48 .22087 Mdot
.48 .22095 Mdot
.48 .22095 Mdot
.48 .22095 Mdot
.48 .22117 Mdot
.48 .22129 Mdot
.48 .22133 Mdot
.48 .22138 Mdot
.48 .2217 Mdot
.48 .22171 Mdot
.48 .22172 Mdot
.48 .22229 Mdot
.48 .22252 Mdot
.48 .22256 Mdot
.48 .22302 Mdot
.48 .22314 Mdot
.48 .22316 Mdot
.48 .22317 Mdot
.48 .22339 Mdot
.48 .22465 Mdot
.48 .22465 Mdot
.48 .22472 Mdot
.48 .22473 Mdot
.48 .22513 Mdot
.48 .22595 Mdot
.48 .22611 Mdot
.48 .22626 Mdot
.48 .22626 Mdot
.48 .22626 Mdot
.48 .22631 Mdot
.48 .22633 Mdot
.48 .22634 Mdot
.48 .22654 Mdot
.48 .22659 Mdot
.48 .22705 Mdot
.48 .22715 Mdot
.48 .22734 Mdot
.48 .22738 Mdot
.48 .22762 Mdot
.48 .22766 Mdot
.48 .22773 Mdot
.48 .22797 Mdot
.48 .22814 Mdot
.48 .22857 Mdot
.48 .22861 Mdot
.48 .22867 Mdot
.48 .2292 Mdot
.48 .22953 Mdot
.48 .22957 Mdot
.48 .22973 Mdot
.48 .23002 Mdot
.48 .23049 Mdot
.48 .23059 Mdot
.48 .23062 Mdot
.48 .23063 Mdot
.48 .23076 Mdot
.48 .23076 Mdot
.48 .2309 Mdot
.48 .23093 Mdot
.48 .23127 Mdot
.48 .23148 Mdot
.48 .23166 Mdot
.48 .23187 Mdot
.48 .2319 Mdot
.48 .23231 Mdot
.48 .23246 Mdot
.48 .23259 Mdot
.48 .23263 Mdot
.48 .23296 Mdot
.48 .23301 Mdot
.48 .23302 Mdot
.48 .23327 Mdot
.48 .23329 Mdot
.48 .23354 Mdot
.48 .23361 Mdot
.48 .23381 Mdot
.48 .23382 Mdot
.48 .23387 Mdot
.48 .23387 Mdot
.48 .23388 Mdot
.48 .23389 Mdot
.48 .23389 Mdot
.48 .23389 Mdot
.48 .23461 Mdot
.48 .23513 Mdot
.48 .23628 Mdot
.48 .23628 Mdot
.48 .23653 Mdot
.48 .23658 Mdot
.48 .23721 Mdot
.48 .23736 Mdot
.48 .23799 Mdot
.48 .23815 Mdot
.48 .23815 Mdot
.48 .24064 Mdot
.48 .24112 Mdot
.48 .2415 Mdot
.48 .24155 Mdot
.48 .24155 Mdot
.48 .24155 Mdot
.48 .24168 Mdot
.48 .24175 Mdot
.48 .24177 Mdot
.48 .24233 Mdot
.48 .24246 Mdot
.48 .24283 Mdot
.48 .24362 Mdot
.48 .24387 Mdot
.48 .2443 Mdot
.48 .24438 Mdot
.48 .24445 Mdot
.48 .24445 Mdot
.48 .24445 Mdot
.48 .24448 Mdot
.48 .24449 Mdot
.48 .24449 Mdot
.48 .24459 Mdot
.48 .24462 Mdot
.48 .2449 Mdot
.48 .24499 Mdot
.48 .245 Mdot
.48 .24512 Mdot
.48 .24515 Mdot
.48 .24558 Mdot
.48 .2456 Mdot
.48 .24563 Mdot
.48 .24588 Mdot
.48 .24603 Mdot
.48 .24605 Mdot
.48 .24613 Mdot
.48 .24654 Mdot
.48 .2466 Mdot
.48 .2466 Mdot
.48 .24666 Mdot
.48 .24667 Mdot
.48 .24683 Mdot
.48 .24701 Mdot
.48 .24729 Mdot
.48 .24742 Mdot
.48 .24744 Mdot
.48 .24758 Mdot
.48 .2476 Mdot
.48 .24761 Mdot
.48 .24772 Mdot
.48 .24772 Mdot
.48 .24783 Mdot
.48 .24786 Mdot
.48 .24795 Mdot
.48 .24795 Mdot
.48 .24798 Mdot
.48 .24798 Mdot
.48 .24798 Mdot
.48 .24798 Mdot
.48 .24798 Mdot
.48 .24798 Mdot
.48 .27254 Mdot
.48 .27254 Mdot
.48 .27254 Mdot
.48 .27255 Mdot
.48 .27255 Mdot
.48 .27255 Mdot
.48 .2726 Mdot
.48 .27261 Mdot
.48 .27277 Mdot
.48 .27283 Mdot
.48 .27304 Mdot
.48 .27305 Mdot
.48 .27326 Mdot
.48 .27327 Mdot
.48 .27331 Mdot
.48 .27358 Mdot
.48 .27362 Mdot
.48 .27386 Mdot
.48 .27441 Mdot
.48 .27475 Mdot
.48 .27505 Mdot
.48 .27508 Mdot
.48 .2752 Mdot
.48 .2752 Mdot
.48 .27532 Mdot
.48 .27612 Mdot
.48 .27627 Mdot
.48 .2763 Mdot
.48 .2766 Mdot
.48 .2771 Mdot
.48 .27715 Mdot
.48 .27719 Mdot
.48 .27798 Mdot
.48 .27804 Mdot
.48 .27809 Mdot
.48 .27832 Mdot
.48 .27836 Mdot
.48 .27854 Mdot
.48 .27909 Mdot
.48 .27914 Mdot
.48 .27934 Mdot
.48 .27935 Mdot
.48 .27937 Mdot
.48 .27942 Mdot
.48 .27942 Mdot
.48 .27942 Mdot
.48 .27956 Mdot
.48 .27973 Mdot
.48 .28057 Mdot
.48 .28108 Mdot
.48 .28268 Mdot
.48 .28342 Mdot
.48 .28368 Mdot
.48 .28483 Mdot
.48 .28487 Mdot
.48 .28502 Mdot
.48 .28528 Mdot
.48 .28528 Mdot
.48 .28529 Mdot
.48 .28539 Mdot
.48 .28617 Mdot
.48 .28717 Mdot
.48 .29239 Mdot
.48 .2924 Mdot
.48 .29274 Mdot
.48 .29408 Mdot
.48 .29441 Mdot
.48 .29577 Mdot
.48 .29587 Mdot
.48 .29641 Mdot
.48 .29641 Mdot
.48 .29892 Mdot
.48 .30006 Mdot
.48 .30165 Mdot
.48 .30165 Mdot
.48 .30165 Mdot
.48 .30168 Mdot
.48 .30169 Mdot
.48 .30169 Mdot
.48 .3018 Mdot
.48 .30183 Mdot
.48 .30227 Mdot
.48 .30243 Mdot
.48 .30299 Mdot
.48 .30302 Mdot
.48 .30357 Mdot
.48 .3036 Mdot
.48 .30371 Mdot
.48 .30444 Mdot
.48 .30455 Mdot
.48 .30484 Mdot
.48 .30518 Mdot
.48 .3061 Mdot
.48 .30615 Mdot
.48 .30663 Mdot
.48 .30704 Mdot
.48 .30751 Mdot
.48 .30829 Mdot
.48 .30835 Mdot
.48 .30866 Mdot
.48 .30868 Mdot
.48 .30897 Mdot
.48 .30899 Mdot
.48 .30907 Mdot
.48 .30929 Mdot
.48 .31036 Mdot
.48 .31102 Mdot
.48 .31139 Mdot
.48 .31147 Mdot
.48 .31224 Mdot
.48 .31347 Mdot
.48 .3136 Mdot
.48 .31369 Mdot
.48 .31467 Mdot
.48 .31507 Mdot
.48 .31563 Mdot
.48 .31579 Mdot
.48 .31589 Mdot
.48 .31646 Mdot
.48 .31655 Mdot
.48 .31698 Mdot
.48 .31723 Mdot
.48 .31829 Mdot
.48 .31841 Mdot
.48 .31888 Mdot
.48 .3189 Mdot
.48 .31896 Mdot
.48 .31907 Mdot
.48 .31907 Mdot
.48 .31907 Mdot
.48 .31941 Mdot
.48 .3198 Mdot
.48 .32173 Mdot
.48 .32269 Mdot
.48 .32272 Mdot
.48 .32288 Mdot
.48 .32288 Mdot
.48 .32588 Mdot
.48 .3264 Mdot
.48 .32642 Mdot
.48 .32648 Mdot
.48 .32676 Mdot
.48 .32787 Mdot
.48 .32797 Mdot
.48 .32852 Mdot
.48 .3299 Mdot
.48 .32991 Mdot
.48 .32995 Mdot
.48 .33071 Mdot
.48 .33085 Mdot
.48 .33094 Mdot
.48 .33122 Mdot
.48 .33175 Mdot
.48 .33175 Mdot
.48 .33176 Mdot
.48 .33196 Mdot
.48 .33327 Mdot
.48 .33365 Mdot
.48 .33367 Mdot
.48 .33368 Mdot
.48 .33466 Mdot
.48 .33519 Mdot
.48 .33532 Mdot
.48 .33535 Mdot
.48 .3356 Mdot
.48 .33696 Mdot
.48 .33703 Mdot
.48 .33704 Mdot
.48 .33939 Mdot
.48 .34029 Mdot
.48 .34045 Mdot
.48 .34217 Mdot
.48 .34259 Mdot
.48 .34268 Mdot
.48 .34271 Mdot
.48 .34346 Mdot
.48 .3438 Mdot
.48 .34382 Mdot
.48 .3443 Mdot
.48 .34608 Mdot
.48 .3465 Mdot
.48 .34741 Mdot
.48 .34741 Mdot
.48 .34761 Mdot
.48 .34764 Mdot
.48 .34813 Mdot
.48 .34825 Mdot
.48 .34873 Mdot
.48 .34885 Mdot
.48 .34885 Mdot
.48 .3507 Mdot
.48 .35105 Mdot
.48 .35132 Mdot
.48 .35135 Mdot
.48 .35136 Mdot
.48 .35136 Mdot
.48 .35145 Mdot
.48 .3515 Mdot
.48 .35152 Mdot
.48 .35191 Mdot
.48 .35201 Mdot
.48 .35226 Mdot
.48 .35282 Mdot
.48 .35299 Mdot
.48 .35329 Mdot
.48 .35334 Mdot
.48 .35339 Mdot
.48 .35339 Mdot
.48 .35339 Mdot
.48 .35341 Mdot
.48 .35342 Mdot
.48 .35342 Mdot
.48 .35349 Mdot
.48 .35351 Mdot
.48 .3537 Mdot
.48 .35376 Mdot
.48 .35377 Mdot
.48 .35385 Mdot
.48 .35387 Mdot
.48 .35416 Mdot
.48 .35418 Mdot
.48 .35419 Mdot
.48 .35436 Mdot
.48 .35447 Mdot
.48 .35448 Mdot
.48 .35453 Mdot
.48 .35481 Mdot
.48 .35485 Mdot
.48 .35485 Mdot
.48 .35489 Mdot
.48 .3549 Mdot
.48 .355 Mdot
.48 .35512 Mdot
.48 .35531 Mdot
.48 .35539 Mdot
.48 .3554 Mdot
.48 .3555 Mdot
.48 .35551 Mdot
.48 .35552 Mdot
.48 .35559 Mdot
.48 .35559 Mdot
.48 .35566 Mdot
.48 .35569 Mdot
.48 .35574 Mdot
.48 .35574 Mdot
.48 .35576 Mdot
.48 .35576 Mdot
.48 .35576 Mdot
.48 .35576 Mdot
.48 .35576 Mdot
.48 .35576 Mdot
.48 .48395 Mdot
.48 .48395 Mdot
.48 .48395 Mdot
.48 .48395 Mdot
.48 .48396 Mdot
.48 .48396 Mdot
.48 .48396 Mdot
.48 .48396 Mdot
.48 .48399 Mdot
.48 .484 Mdot
.48 .48403 Mdot
.48 .48404 Mdot
.48 .48407 Mdot
.48 .48407 Mdot
.48 .48408 Mdot
.48 .48412 Mdot
.48 .48413 Mdot
.48 .48417 Mdot
.48 .48426 Mdot
.48 .48431 Mdot
.48 .48436 Mdot
.48 .48436 Mdot
.48 .48438 Mdot
.48 .48438 Mdot
.48 .4844 Mdot
.48 .48453 Mdot
.48 .48456 Mdot
.48 .48456 Mdot
.48 .48461 Mdot
.48 .48469 Mdot
.48 .4847 Mdot
.48 .4847 Mdot
.48 .48484 Mdot
.48 .48485 Mdot
.48 .48489 Mdot
.48 .48489 Mdot
.48 .48492 Mdot
.48 .48501 Mdot
.48 .48502 Mdot
.48 .48505 Mdot
.48 .48505 Mdot
.48 .48506 Mdot
.48 .48506 Mdot
.48 .48506 Mdot
.48 .48506 Mdot
.48 .48509 Mdot
.48 .48511 Mdot
.48 .48525 Mdot
.48 .48533 Mdot
.48 .48559 Mdot
.48 .48571 Mdot
.48 .48575 Mdot
.48 .48594 Mdot
.48 .48594 Mdot
.48 .48597 Mdot
.48 .48601 Mdot
.48 .48601 Mdot
.48 .48601 Mdot
.48 .48603 Mdot
.48 .48615 Mdot
.48 .48632 Mdot
.48 .48717 Mdot
.48 .48717 Mdot
.48 .48722 Mdot
.48 .48744 Mdot
.48 .4875 Mdot
.48 .48772 Mdot
.48 .48774 Mdot
.48 .48783 Mdot
.48 .48783 Mdot
.48 .48825 Mdot
.48 .48844 Mdot
.48 .48926 Mdot
.48 .48947 Mdot
.48 .48948 Mdot
.48 .48964 Mdot
.48 .48998 Mdot
.48 .48999 Mdot
.48 .49003 Mdot
.48 .49022 Mdot
.48 .491 Mdot
.48 .49107 Mdot
.48 .49148 Mdot
.48 .49253 Mdot
.48 .49254 Mdot
.48 .49257 Mdot
.48 .49318 Mdot
.48 .49329 Mdot
.48 .4933 Mdot
.48 .49336 Mdot
.48 .49359 Mdot
.48 .49403 Mdot
.48 .49403 Mdot
.48 .49404 Mdot
.48 .49421 Mdot
.48 .49479 Mdot
.48 .49488 Mdot
.48 .49488 Mdot
.48 .49488 Mdot
.48 .49512 Mdot
.48 .49524 Mdot
.48 .49528 Mdot
.48 .49534 Mdot
.48 .49568 Mdot
.48 .4957 Mdot
.48 .4957 Mdot
.48 .49631 Mdot
.48 .49655 Mdot
.48 .49659 Mdot
.48 .49708 Mdot
.48 .4972 Mdot
.48 .49723 Mdot
.48 .49723 Mdot
.48 .49746 Mdot
.48 .49876 Mdot
.48 .49876 Mdot
.48 .49883 Mdot
.48 .49885 Mdot
.48 .49926 Mdot
.48 .50009 Mdot
.48 .50026 Mdot
.48 .5004 Mdot
.48 .5004 Mdot
.48 .50041 Mdot
.48 .50045 Mdot
.48 .50048 Mdot
.48 .50048 Mdot
.48 .50069 Mdot
.48 .50074 Mdot
.48 .50119 Mdot
.48 .5013 Mdot
.48 .50148 Mdot
.48 .50152 Mdot
.48 .50176 Mdot
.48 .50181 Mdot
.48 .50188 Mdot
.48 .50211 Mdot
.48 .50228 Mdot
.48 .5027 Mdot
.48 .50274 Mdot
.48 .50279 Mdot
.48 .50331 Mdot
.48 .50364 Mdot
.48 .50367 Mdot
.48 .50383 Mdot
.48 .50411 Mdot
.48 .50456 Mdot
.48 .50465 Mdot
.48 .50468 Mdot
.48 .50469 Mdot
.48 .50481 Mdot
.48 .50482 Mdot
.48 .50495 Mdot
.48 .50497 Mdot
.48 .5053 Mdot
.48 .5055 Mdot
.48 .50567 Mdot
.48 .50587 Mdot
.48 .50589 Mdot
.48 .50627 Mdot
.48 .50641 Mdot
.48 .50654 Mdot
.48 .50658 Mdot
.48 .50689 Mdot
.48 .50693 Mdot
.48 .50694 Mdot
.48 .50717 Mdot
.48 .50718 Mdot
.48 .50741 Mdot
.48 .50748 Mdot
.48 .50766 Mdot
.48 .50767 Mdot
.48 .50772 Mdot
.48 .50772 Mdot
.48 .50773 Mdot
.48 .50774 Mdot
.48 .50774 Mdot
.48 .50774 Mdot
.48 .50839 Mdot
.48 .50886 Mdot
.48 .50989 Mdot
.48 .50989 Mdot
.48 .51011 Mdot
.48 .51015 Mdot
.48 .51071 Mdot
.48 .51084 Mdot
.48 .51139 Mdot
.48 .51152 Mdot
.48 .51153 Mdot
.48 .51363 Mdot
.48 .51404 Mdot
.48 .51435 Mdot
.48 .51439 Mdot
.48 .51439 Mdot
.48 .51439 Mdot
.48 .5145 Mdot
.48 .51455 Mdot
.48 .51457 Mdot
.48 .51503 Mdot
.48 .51513 Mdot
.48 .51543 Mdot
.48 .51606 Mdot
.48 .51627 Mdot
.48 .5166 Mdot
.48 .51666 Mdot
.48 .51672 Mdot
.48 .51672 Mdot
.48 .51672 Mdot
.48 .51674 Mdot
.48 .51675 Mdot
.48 .51675 Mdot
.48 .51683 Mdot
.48 .51685 Mdot
.48 .51707 Mdot
.48 .51714 Mdot
.48 .51715 Mdot
.48 .51725 Mdot
.48 .51726 Mdot
.48 .5176 Mdot
.48 .51762 Mdot
.48 .51764 Mdot
.48 .51783 Mdot
.48 .51795 Mdot
.48 .51796 Mdot
.48 .51802 Mdot
.48 .51834 Mdot
.48 .51838 Mdot
.48 .51838 Mdot
.48 .51843 Mdot
.48 .51844 Mdot
.48 .51856 Mdot
.48 .51869 Mdot
.48 .51891 Mdot
.48 .519 Mdot
.48 .51902 Mdot
.48 .51912 Mdot
.48 .51914 Mdot
.48 .51914 Mdot
.48 .51922 Mdot
.48 .51923 Mdot
.48 .51931 Mdot
.48 .51933 Mdot
.48 .5194 Mdot
.48 .5194 Mdot
.48 .51942 Mdot
.48 .51942 Mdot
.48 .51942 Mdot
.48 .51942 Mdot
.48 .51942 Mdot
.48 .51942 Mdot
.48 .5288 Mdot
.48 .5288 Mdot
.48 .5288 Mdot
.48 .5288 Mdot
.48 .5288 Mdot
.48 .5288 Mdot
.48 .52881 Mdot
.48 .52881 Mdot
.48 .52884 Mdot
.48 .52885 Mdot
.48 .5289 Mdot
.48 .5289 Mdot
.48 .52894 Mdot
.48 .52894 Mdot
.48 .52895 Mdot
.48 .529 Mdot
.48 .52901 Mdot
.48 .52906 Mdot
.48 .52916 Mdot
.48 .52923 Mdot
.48 .52929 Mdot
.48 .52929 Mdot
.48 .52931 Mdot
.48 .52932 Mdot
.48 .52934 Mdot
.48 .52949 Mdot
.48 .52952 Mdot
.48 .52953 Mdot
.48 .52958 Mdot
.48 .52968 Mdot
.48 .52969 Mdot
.48 .52969 Mdot
.48 .52986 Mdot
.48 .52986 Mdot
.48 .52991 Mdot
.48 .52991 Mdot
.48 .52995 Mdot
.48 .53005 Mdot
.48 .53006 Mdot
.48 .5301 Mdot
.48 .5301 Mdot
.48 .5301 Mdot
.48 .53011 Mdot
.48 .53011 Mdot
.48 .53011 Mdot
.48 .53014 Mdot
.48 .53017 Mdot
.48 .53033 Mdot
.48 .53042 Mdot
.48 .53072 Mdot
.48 .53085 Mdot
.48 .5309 Mdot
.48 .53111 Mdot
.48 .53111 Mdot
.48 .53114 Mdot
.48 .53119 Mdot
.48 .53119 Mdot
.48 .53119 Mdot
.48 .53121 Mdot
.48 .53135 Mdot
.48 .53153 Mdot
.48 .53244 Mdot
.48 .53244 Mdot
.48 .5325 Mdot
.48 .53273 Mdot
.48 .53279 Mdot
.48 .53302 Mdot
.48 .53304 Mdot
.48 .53313 Mdot
.48 .53313 Mdot
.48 .53355 Mdot
.48 .53374 Mdot
.48 .534 Mdot
.48 .534 Mdot
.48 .534 Mdot
.48 .53401 Mdot
.48 .53401 Mdot
.48 .53401 Mdot
.48 .53403 Mdot
.48 .53403 Mdot
.48 .5341 Mdot
.48 .53413 Mdot
.48 .53422 Mdot
.48 .53423 Mdot
.48 .53432 Mdot
.48 .53432 Mdot
.48 .53434 Mdot
.48 .53446 Mdot
.48 .53448 Mdot
.48 .53453 Mdot
.48 .53458 Mdot
.48 .53473 Mdot
.48 .53474 Mdot
.48 .53481 Mdot
.48 .53488 Mdot
.48 .53495 Mdot
.48 .53508 Mdot
.48 .53509 Mdot
.48 .53514 Mdot
.48 .53514 Mdot
.48 .53519 Mdot
.48 .53519 Mdot
.48 .5352 Mdot
.48 .53524 Mdot
.48 .53541 Mdot
.48 .53552 Mdot
.48 .53557 Mdot
.48 .53559 Mdot
.48 .53571 Mdot
.48 .5359 Mdot
.48 .53592 Mdot
.48 .53594 Mdot
.48 .53609 Mdot
.48 .53615 Mdot
.48 .53624 Mdot
.48 .53626 Mdot
.48 .53628 Mdot
.48 .53637 Mdot
.48 .53638 Mdot
.48 .53645 Mdot
.48 .53649 Mdot
.48 .53665 Mdot
.48 .53667 Mdot
.48 .53674 Mdot
.48 .53674 Mdot
.48 .53675 Mdot
.48 .53677 Mdot
.48 .53677 Mdot
.48 .53677 Mdot
.48 .53682 Mdot
.48 .53688 Mdot
.48 .53718 Mdot
.48 .53732 Mdot
.48 .53733 Mdot
.48 .53735 Mdot
.48 .53735 Mdot
.48 .5378 Mdot
.48 .53788 Mdot
.48 .53788 Mdot
.48 .53789 Mdot
.48 .53793 Mdot
.48 .5381 Mdot
.48 .53811 Mdot
.48 .5382 Mdot
.48 .5384 Mdot
.48 .5384 Mdot
.48 .53841 Mdot
.48 .53852 Mdot
.48 .53854 Mdot
.48 .53855 Mdot
.48 .5386 Mdot
.48 .53867 Mdot
.48 .53868 Mdot
.48 .53868 Mdot
.48 .53871 Mdot
.48 .5389 Mdot
.48 .53895 Mdot
.48 .53896 Mdot
.48 .53896 Mdot
.48 .5391 Mdot
.48 .53918 Mdot
.48 .5392 Mdot
.48 .5392 Mdot
.48 .53924 Mdot
.48 .53944 Mdot
.48 .53945 Mdot
.48 .53945 Mdot
.48 .53979 Mdot
.48 .53992 Mdot
.48 .53994 Mdot
.48 .54019 Mdot
.48 .54025 Mdot
.48 .54026 Mdot
.48 .54026 Mdot
.48 .54037 Mdot
.48 .54042 Mdot
.48 .54042 Mdot
.48 .54049 Mdot
.48 .54075 Mdot
.48 .5408 Mdot
.48 .54093 Mdot
.48 .54093 Mdot
.48 .54096 Mdot
.48 .54097 Mdot
.48 .54104 Mdot
.48 .54105 Mdot
.48 .54112 Mdot
.48 .54114 Mdot
.48 .54114 Mdot
.48 .5414 Mdot
.48 .54145 Mdot
.48 .54148 Mdot
.48 .54149 Mdot
.48 .54149 Mdot
.48 .54149 Mdot
.48 .5415 Mdot
.48 .54151 Mdot
.48 .54151 Mdot
.48 .54157 Mdot
.48 .54158 Mdot
.48 .54162 Mdot
.48 .54169 Mdot
.48 .54172 Mdot
.48 .54176 Mdot
.48 .54177 Mdot
.48 .54177 Mdot
.48 .54177 Mdot
.48 .54177 Mdot
.48 .54178 Mdot
.48 .54178 Mdot
.48 .54178 Mdot
.48 .54179 Mdot
.48 .54179 Mdot
.48 .54182 Mdot
.48 .54183 Mdot
.48 .54183 Mdot
.48 .54184 Mdot
.48 .54184 Mdot
.48 .54188 Mdot
.48 .54188 Mdot
.48 .54189 Mdot
.48 .54191 Mdot
.48 .54192 Mdot
.48 .54193 Mdot
.48 .54193 Mdot
.48 .54197 Mdot
.48 .54198 Mdot
.48 .54198 Mdot
.48 .54198 Mdot
.48 .54198 Mdot
.48 .542 Mdot
.48 .54201 Mdot
.48 .54204 Mdot
.48 .54205 Mdot
.48 .54205 Mdot
.48 .54207 Mdot
.48 .54207 Mdot
.48 .54207 Mdot
.48 .54208 Mdot
.48 .54208 Mdot
.48 .54209 Mdot
.48 .54209 Mdot
.48 .5421 Mdot
.48 .5421 Mdot
.48 .5421 Mdot
.48 .5421 Mdot
.48 .5421 Mdot
.48 .5421 Mdot
.48 .5421 Mdot
.48 .5421 Mdot
.482 .21071 Mdot
.482 .21072 Mdot
.482 .21073 Mdot
.482 .21073 Mdot
.482 .21075 Mdot
.482 .21075 Mdot
.482 .21075 Mdot
.482 .21077 Mdot
.482 .21077 Mdot
.482 .21083 Mdot
.482 .21096 Mdot
.482 .21096 Mdot
.482 .21102 Mdot
.482 .21107 Mdot
.482 .21108 Mdot
.482 .21109 Mdot
.482 .21116 Mdot
.482 .21124 Mdot
.482 .21134 Mdot
.482 .21136 Mdot
.482 .21139 Mdot
.482 .21146 Mdot
.482 .21149 Mdot
.482 .21152 Mdot
.482 .21153 Mdot
.482 .21157 Mdot
.482 .21164 Mdot
.482 .21168 Mdot
.482 .2117 Mdot
.482 .21192 Mdot
.482 .212 Mdot
.482 .2121 Mdot
.482 .21218 Mdot
.482 .21221 Mdot
.482 .21228 Mdot
.482 .21229 Mdot
.482 .21234 Mdot
.482 .21243 Mdot
.482 .21259 Mdot
.482 .21259 Mdot
.482 .21277 Mdot
.482 .21286 Mdot
.482 .21289 Mdot
.482 .21293 Mdot
.482 .21313 Mdot
.482 .21318 Mdot
.482 .21321 Mdot
.482 .21323 Mdot
.482 .21325 Mdot
.482 .21326 Mdot
.482 .21334 Mdot
.482 .21337 Mdot
.482 .21347 Mdot
.482 .21358 Mdot
.482 .21378 Mdot
.482 .21385 Mdot
.482 .21385 Mdot
.482 .21385 Mdot
.482 .2139 Mdot
.482 .21401 Mdot
.482 .21404 Mdot
.482 .21408 Mdot
.482 .2141 Mdot
.482 .21425 Mdot
.482 .21427 Mdot
.482 .21434 Mdot
.482 .21437 Mdot
.482 .21444 Mdot
.482 .21445 Mdot
.482 .21456 Mdot
.482 .21458 Mdot
.482 .21469 Mdot
.482 .21475 Mdot
.482 .21485 Mdot
.482 .2151 Mdot
.482 .21522 Mdot
.482 .21525 Mdot
.482 .21529 Mdot
.482 .21531 Mdot
.482 .21533 Mdot
.482 .21554 Mdot
.482 .21559 Mdot
.482 .21607 Mdot
.482 .21648 Mdot
.482 .21697 Mdot
.482 .21732 Mdot
.482 .21743 Mdot
.482 .21762 Mdot
.482 .21771 Mdot
.482 .21779 Mdot
.482 .218 Mdot
.482 .21805 Mdot
.482 .21816 Mdot
.482 .21818 Mdot
.482 .21819 Mdot
.482 .21826 Mdot
.482 .21841 Mdot
.482 .2187 Mdot
.482 .21893 Mdot
.482 .21957 Mdot
.482 .21981 Mdot
.482 .21981 Mdot
.482 .22001 Mdot
.482 .22018 Mdot
.482 .2207 Mdot
.482 .22083 Mdot
.482 .22117 Mdot
.482 .22159 Mdot
.482 .2216 Mdot
.482 .22182 Mdot
.482 .22187 Mdot
.482 .22211 Mdot
.482 .22292 Mdot
.482 .22329 Mdot
.482 .22351 Mdot
.482 .22353 Mdot
.482 .22382 Mdot
.482 .22389 Mdot
.482 .22405 Mdot
.482 .22444 Mdot
.482 .22461 Mdot
.482 .22473 Mdot
.482 .2251 Mdot
.482 .22522 Mdot
.482 .22527 Mdot
.482 .2253 Mdot
.482 .22535 Mdot
.482 .2256 Mdot
.482 .22573 Mdot
.482 .22594 Mdot
.482 .22625 Mdot
.482 .22646 Mdot
.482 .22657 Mdot
.482 .22671 Mdot
.482 .2272 Mdot
.482 .22747 Mdot
.482 .22823 Mdot
.482 .2284 Mdot
.482 .22842 Mdot
.482 .22878 Mdot
.482 .22931 Mdot
.482 .22961 Mdot
.482 .22973 Mdot
.482 .22976 Mdot
.482 .22995 Mdot
.482 .23026 Mdot
.482 .23082 Mdot
.482 .2309 Mdot
.482 .23109 Mdot
.482 .23126 Mdot
.482 .23212 Mdot
.482 .2323 Mdot
.482 .23245 Mdot
.482 .23289 Mdot
.482 .23311 Mdot
.482 .23315 Mdot
.482 .23322 Mdot
.482 .23335 Mdot
.482 .23342 Mdot
.482 .2335 Mdot
.482 .23357 Mdot
.482 .23368 Mdot
.482 .2338 Mdot
.482 .23415 Mdot
.482 .23458 Mdot
.482 .23469 Mdot
.482 .2347 Mdot
.482 .23488 Mdot
.482 .23509 Mdot
.482 .23543 Mdot
.482 .2355 Mdot
.482 .23585 Mdot
.482 .23587 Mdot
.482 .23596 Mdot
.482 .2361 Mdot
.482 .23622 Mdot
.482 .23642 Mdot
.482 .23649 Mdot
.482 .23649 Mdot
.482 .2365 Mdot
.482 .23665 Mdot
.482 .23668 Mdot
.482 .23671 Mdot
.482 .23688 Mdot
.482 .2369 Mdot
.482 .23696 Mdot
.482 .23699 Mdot
.482 .23706 Mdot
.482 .23707 Mdot
.482 .23718 Mdot
.482 .23728 Mdot
.482 .23764 Mdot
.482 .2378 Mdot
.482 .23782 Mdot
.482 .23783 Mdot
.482 .23805 Mdot
.482 .23874 Mdot
.482 .2391 Mdot
.482 .23942 Mdot
.482 .23956 Mdot
.482 .23982 Mdot
.482 .23986 Mdot
.482 .23993 Mdot
.482 .23999 Mdot
.482 .2401 Mdot
.482 .24029 Mdot
.482 .24099 Mdot
.482 .24111 Mdot
.482 .24121 Mdot
.482 .24152 Mdot
.482 .24217 Mdot
.482 .2422 Mdot
.482 .24278 Mdot
.482 .24309 Mdot
.482 .24326 Mdot
.482 .2433 Mdot
.482 .24358 Mdot
.482 .24367 Mdot
.482 .24398 Mdot
.482 .24434 Mdot
.482 .24465 Mdot
.482 .24545 Mdot
.482 .24554 Mdot
.482 .24571 Mdot
.482 .24595 Mdot
.482 .24609 Mdot
.482 .24615 Mdot
.482 .24624 Mdot
.482 .24638 Mdot
.482 .24663 Mdot
.482 .24676 Mdot
.482 .24683 Mdot
.482 .24721 Mdot
.482 .24755 Mdot
.482 .24781 Mdot
.482 .24784 Mdot
.482 .24788 Mdot
.482 .24808 Mdot
.482 .24831 Mdot
.482 .24832 Mdot
.482 .24884 Mdot
.482 .24906 Mdot
.482 .24906 Mdot
.482 .24912 Mdot
.482 .24913 Mdot
.482 .24915 Mdot
.482 .24922 Mdot
.482 .24922 Mdot
.482 .24925 Mdot
.482 .24929 Mdot
.482 .26961 Mdot
.482 .26968 Mdot
.482 .26973 Mdot
.482 .26974 Mdot
.482 .26987 Mdot
.482 .2699 Mdot
.482 .26992 Mdot
.482 .27004 Mdot
.482 .27004 Mdot
.482 .27045 Mdot
.482 .27144 Mdot
.482 .27146 Mdot
.482 .27189 Mdot
.482 .27227 Mdot
.482 .27236 Mdot
.482 .27242 Mdot
.482 .27292 Mdot
.482 .27356 Mdot
.482 .27429 Mdot
.482 .27444 Mdot
.482 .27468 Mdot
.482 .27516 Mdot
.482 .27543 Mdot
.482 .27563 Mdot
.482 .27573 Mdot
.482 .27601 Mdot
.482 .27648 Mdot
.482 .27682 Mdot
.482 .27699 Mdot
.482 .27857 Mdot
.482 .27919 Mdot
.482 .27991 Mdot
.482 .28054 Mdot
.482 .28071 Mdot
.482 .28129 Mdot
.482 .28137 Mdot
.482 .28169 Mdot
.482 .28193 Mdot
.482 .28234 Mdot
.482 .28352 Mdot
.482 .28358 Mdot
.482 .2849 Mdot
.482 .28554 Mdot
.482 .28575 Mdot
.482 .28601 Mdot
.482 .28747 Mdot
.482 .28786 Mdot
.482 .28808 Mdot
.482 .28822 Mdot
.482 .28836 Mdot
.482 .28844 Mdot
.482 .28899 Mdot
.482 .28927 Mdot
.482 .28996 Mdot
.482 .29073 Mdot
.482 .29219 Mdot
.482 .29266 Mdot
.482 .29269 Mdot
.482 .29273 Mdot
.482 .29307 Mdot
.482 .29384 Mdot
.482 .29404 Mdot
.482 .2943 Mdot
.482 .29431 Mdot
.482 .29446 Mdot
.482 .29453 Mdot
.482 .29465 Mdot
.482 .2947 Mdot
.482 .29506 Mdot
.482 .29513 Mdot
.482 .29519 Mdot
.482 .29552 Mdot
.482 .29554 Mdot
.482 .29554 Mdot
.482 .29569 Mdot
.482 .29614 Mdot
.482 .29638 Mdot
.482 .29669 Mdot
.482 .29689 Mdot
.482 .29694 Mdot
.482 .29769 Mdot
.482 .29786 Mdot
.482 .2986 Mdot
.482 .29905 Mdot
.482 .29944 Mdot
.482 .29948 Mdot
.482 .29972 Mdot
.482 .30067 Mdot
.482 .30144 Mdot
.482 .3017 Mdot
.482 .30196 Mdot
.482 .30211 Mdot
.482 .30228 Mdot
.482 .30244 Mdot
.482 .30273 Mdot
.482 .30288 Mdot
.482 .30298 Mdot
.482 .30346 Mdot
.482 .30446 Mdot
.482 .30479 Mdot
.482 .30521 Mdot
.482 .30714 Mdot
.482 .30753 Mdot
.482 .30797 Mdot
.482 .30815 Mdot
.482 .30942 Mdot
.482 .31013 Mdot
.482 .31057 Mdot
.482 .31062 Mdot
.482 .3109 Mdot
.482 .31161 Mdot
.482 .31281 Mdot
.482 .31365 Mdot
.482 .3137 Mdot
.482 .3141 Mdot
.482 .31586 Mdot
.482 .31651 Mdot
.482 .31765 Mdot
.482 .31797 Mdot
.482 .31824 Mdot
.482 .31872 Mdot
.482 .31946 Mdot
.482 .31995 Mdot
.482 .32025 Mdot
.482 .32084 Mdot
.482 .32097 Mdot
.482 .32104 Mdot
.482 .32116 Mdot
.482 .32143 Mdot
.482 .32231 Mdot
.482 .32261 Mdot
.482 .32302 Mdot
.482 .32395 Mdot
.482 .32432 Mdot
.482 .3245 Mdot
.482 .32519 Mdot
.482 .32523 Mdot
.482 .32576 Mdot
.482 .32665 Mdot
.482 .3286 Mdot
.482 .32918 Mdot
.482 .3293 Mdot
.482 .32984 Mdot
.482 .32986 Mdot
.482 .33087 Mdot
.482 .33171 Mdot
.482 .33202 Mdot
.482 .33328 Mdot
.482 .3337 Mdot
.482 .33419 Mdot
.482 .33419 Mdot
.482 .33479 Mdot
.482 .33636 Mdot
.482 .33691 Mdot
.482 .33763 Mdot
.482 .33801 Mdot
.482 .33817 Mdot
.482 .3382 Mdot
.482 .33826 Mdot
.482 .33851 Mdot
.482 .33864 Mdot
.482 .33915 Mdot
.482 .33935 Mdot
.482 .3396 Mdot
.482 .34007 Mdot
.482 .34033 Mdot
.482 .3412 Mdot
.482 .34243 Mdot
.482 .34343 Mdot
.482 .34462 Mdot
.482 .34475 Mdot
.482 .3453 Mdot
.482 .34533 Mdot
.482 .34539 Mdot
.482 .34549 Mdot
.482 .34555 Mdot
.482 .34586 Mdot
.482 .34649 Mdot
.482 .34673 Mdot
.482 .34689 Mdot
.482 .34716 Mdot
.482 .34722 Mdot
.482 .34749 Mdot
.482 .34751 Mdot
.482 .34769 Mdot
.482 .34778 Mdot
.482 .34794 Mdot
.482 .348 Mdot
.482 .34837 Mdot
.482 .34843 Mdot
.482 .34852 Mdot
.482 .34859 Mdot
.482 .34887 Mdot
.482 .34899 Mdot
.482 .349 Mdot
.482 .34901 Mdot
.482 .34917 Mdot
.482 .34969 Mdot
.482 .34996 Mdot
.482 .3502 Mdot
.482 .35029 Mdot
.482 .35049 Mdot
.482 .35051 Mdot
.482 .35056 Mdot
.482 .35061 Mdot
.482 .35069 Mdot
.482 .35082 Mdot
.482 .35133 Mdot
.482 .35142 Mdot
.482 .35149 Mdot
.482 .35171 Mdot
.482 .35217 Mdot
.482 .35219 Mdot
.482 .35259 Mdot
.482 .35281 Mdot
.482 .35293 Mdot
.482 .35295 Mdot
.482 .35315 Mdot
.482 .35321 Mdot
.482 .35342 Mdot
.482 .35367 Mdot
.482 .35388 Mdot
.482 .35442 Mdot
.482 .35448 Mdot
.482 .35459 Mdot
.482 .35476 Mdot
.482 .35485 Mdot
.482 .35489 Mdot
.482 .35495 Mdot
.482 .35505 Mdot
.482 .35521 Mdot
.482 .35529 Mdot
.482 .35534 Mdot
.482 .35559 Mdot
.482 .35581 Mdot
.482 .35598 Mdot
.482 .356 Mdot
.482 .35603 Mdot
.482 .35616 Mdot
.482 .35631 Mdot
.482 .35631 Mdot
.482 .35665 Mdot
.482 .35679 Mdot
.482 .35679 Mdot
.482 .35683 Mdot
.482 .35684 Mdot
.482 .35685 Mdot
.482 .35689 Mdot
.482 .3569 Mdot
.482 .35691 Mdot
.482 .35694 Mdot
.482 .48347 Mdot
.482 .48348 Mdot
.482 .48349 Mdot
.482 .48349 Mdot
.482 .48351 Mdot
.482 .48352 Mdot
.482 .48352 Mdot
.482 .48354 Mdot
.482 .48354 Mdot
.482 .48361 Mdot
.482 .48377 Mdot
.482 .48377 Mdot
.482 .48384 Mdot
.482 .4839 Mdot
.482 .48391 Mdot
.482 .48392 Mdot
.482 .484 Mdot
.482 .48411 Mdot
.482 .48422 Mdot
.482 .48425 Mdot
.482 .48428 Mdot
.482 .48436 Mdot
.482 .4844 Mdot
.482 .48444 Mdot
.482 .48445 Mdot
.482 .4845 Mdot
.482 .48457 Mdot
.482 .48463 Mdot
.482 .48465 Mdot
.482 .4849 Mdot
.482 .485 Mdot
.482 .48512 Mdot
.482 .48522 Mdot
.482 .48525 Mdot
.482 .48534 Mdot
.482 .48535 Mdot
.482 .4854 Mdot
.482 .48551 Mdot
.482 .48569 Mdot
.482 .4857 Mdot
.482 .48592 Mdot
.482 .48602 Mdot
.482 .48605 Mdot
.482 .48609 Mdot
.482 .48633 Mdot
.482 .48639 Mdot
.482 .48642 Mdot
.482 .48645 Mdot
.482 .48647 Mdot
.482 .48648 Mdot
.482 .48657 Mdot
.482 .48662 Mdot
.482 .48673 Mdot
.482 .48685 Mdot
.482 .48709 Mdot
.482 .48716 Mdot
.482 .48717 Mdot
.482 .48718 Mdot
.482 .48723 Mdot
.482 .48736 Mdot
.482 .48739 Mdot
.482 .48743 Mdot
.482 .48746 Mdot
.482 .48763 Mdot
.482 .48766 Mdot
.482 .48773 Mdot
.482 .48777 Mdot
.482 .48786 Mdot
.482 .48786 Mdot
.482 .48799 Mdot
.482 .48801 Mdot
.482 .48814 Mdot
.482 .48821 Mdot
.482 .48832 Mdot
.482 .48861 Mdot
.482 .48875 Mdot
.482 .48878 Mdot
.482 .48883 Mdot
.482 .48885 Mdot
.482 .48887 Mdot
.482 .48912 Mdot
.482 .48917 Mdot
.482 .48972 Mdot
.482 .49017 Mdot
.482 .49073 Mdot
.482 .49112 Mdot
.482 .49124 Mdot
.482 .49145 Mdot
.482 .49156 Mdot
.482 .49165 Mdot
.482 .49188 Mdot
.482 .49194 Mdot
.482 .49205 Mdot
.482 .49208 Mdot
.482 .49209 Mdot
.482 .49216 Mdot
.482 .49233 Mdot
.482 .49265 Mdot
.482 .4929 Mdot
.482 .4936 Mdot
.482 .49386 Mdot
.482 .49387 Mdot
.482 .49409 Mdot
.482 .49427 Mdot
.482 .49483 Mdot
.482 .49496 Mdot
.482 .49533 Mdot
.482 .49578 Mdot
.482 .49579 Mdot
.482 .49603 Mdot
.482 .49608 Mdot
.482 .49633 Mdot
.482 .49718 Mdot
.482 .49757 Mdot
.482 .4978 Mdot
.482 .49782 Mdot
.482 .49812 Mdot
.482 .4982 Mdot
.482 .49836 Mdot
.482 .49876 Mdot
.482 .49894 Mdot
.482 .49907 Mdot
.482 .49945 Mdot
.482 .49956 Mdot
.482 .49961 Mdot
.482 .49965 Mdot
.482 .4997 Mdot
.482 .49996 Mdot
.482 .50009 Mdot
.482 .5003 Mdot
.482 .50061 Mdot
.482 .50082 Mdot
.482 .50093 Mdot
.482 .50107 Mdot
.482 .50156 Mdot
.482 .50183 Mdot
.482 .50258 Mdot
.482 .50275 Mdot
.482 .50277 Mdot
.482 .50313 Mdot
.482 .50364 Mdot
.482 .50393 Mdot
.482 .50405 Mdot
.482 .50407 Mdot
.482 .50426 Mdot
.482 .50456 Mdot
.482 .50509 Mdot
.482 .50517 Mdot
.482 .50535 Mdot
.482 .50551 Mdot
.482 .50632 Mdot
.482 .50649 Mdot
.482 .50663 Mdot
.482 .50704 Mdot
.482 .50724 Mdot
.482 .50728 Mdot
.482 .50734 Mdot
.482 .50746 Mdot
.482 .50753 Mdot
.482 .5076 Mdot
.482 .50766 Mdot
.482 .50777 Mdot
.482 .50788 Mdot
.482 .5082 Mdot
.482 .50859 Mdot
.482 .50869 Mdot
.482 .5087 Mdot
.482 .50886 Mdot
.482 .50905 Mdot
.482 .50935 Mdot
.482 .50942 Mdot
.482 .50973 Mdot
.482 .50974 Mdot
.482 .50983 Mdot
.482 .50996 Mdot
.482 .51005 Mdot
.482 .51024 Mdot
.482 .5103 Mdot
.482 .5103 Mdot
.482 .5103 Mdot
.482 .51044 Mdot
.482 .51046 Mdot
.482 .51049 Mdot
.482 .51064 Mdot
.482 .51066 Mdot
.482 .51071 Mdot
.482 .51074 Mdot
.482 .5108 Mdot
.482 .5108 Mdot
.482 .51091 Mdot
.482 .51099 Mdot
.482 .5113 Mdot
.482 .51144 Mdot
.482 .51146 Mdot
.482 .51147 Mdot
.482 .51166 Mdot
.482 .51225 Mdot
.482 .51256 Mdot
.482 .51284 Mdot
.482 .51295 Mdot
.482 .51317 Mdot
.482 .5132 Mdot
.482 .51326 Mdot
.482 .51332 Mdot
.482 .5134 Mdot
.482 .51356 Mdot
.482 .51415 Mdot
.482 .51425 Mdot
.482 .51433 Mdot
.482 .51459 Mdot
.482 .51512 Mdot
.482 .51514 Mdot
.482 .51561 Mdot
.482 .51587 Mdot
.482 .516 Mdot
.482 .51603 Mdot
.482 .51626 Mdot
.482 .51633 Mdot
.482 .51657 Mdot
.482 .51686 Mdot
.482 .5171 Mdot
.482 .51772 Mdot
.482 .51779 Mdot
.482 .51792 Mdot
.482 .51811 Mdot
.482 .51822 Mdot
.482 .51826 Mdot
.482 .51834 Mdot
.482 .51844 Mdot
.482 .51863 Mdot
.482 .51873 Mdot
.482 .51878 Mdot
.482 .51907 Mdot
.482 .51932 Mdot
.482 .51952 Mdot
.482 .51954 Mdot
.482 .51957 Mdot
.482 .51972 Mdot
.482 .51989 Mdot
.482 .51989 Mdot
.482 .52028 Mdot
.482 .52044 Mdot
.482 .52044 Mdot
.482 .52049 Mdot
.482 .5205 Mdot
.482 .52051 Mdot
.482 .52056 Mdot
.482 .52056 Mdot
.482 .52058 Mdot
.482 .52061 Mdot
.482 .52835 Mdot
.482 .52836 Mdot
.482 .52837 Mdot
.482 .52838 Mdot
.482 .5284 Mdot
.482 .52841 Mdot
.482 .52841 Mdot
.482 .52844 Mdot
.482 .52844 Mdot
.482 .52852 Mdot
.482 .52871 Mdot
.482 .52872 Mdot
.482 .5288 Mdot
.482 .52887 Mdot
.482 .52889 Mdot
.482 .5289 Mdot
.482 .529 Mdot
.482 .52913 Mdot
.482 .52927 Mdot
.482 .52929 Mdot
.482 .52934 Mdot
.482 .52943 Mdot
.482 .52949 Mdot
.482 .52952 Mdot
.482 .52954 Mdot
.482 .5296 Mdot
.482 .52968 Mdot
.482 .52975 Mdot
.482 .52978 Mdot
.482 .53008 Mdot
.482 .53019 Mdot
.482 .53033 Mdot
.482 .53044 Mdot
.482 .53048 Mdot
.482 .53058 Mdot
.482 .5306 Mdot
.482 .53065 Mdot
.482 .53077 Mdot
.482 .53099 Mdot
.482 .531 Mdot
.482 .53124 Mdot
.482 .53135 Mdot
.482 .53139 Mdot
.482 .53143 Mdot
.482 .53169 Mdot
.482 .53176 Mdot
.482 .5318 Mdot
.482 .53183 Mdot
.482 .53185 Mdot
.482 .53186 Mdot
.482 .53196 Mdot
.482 .53201 Mdot
.482 .53213 Mdot
.482 .53226 Mdot
.482 .53252 Mdot
.482 .5326 Mdot
.482 .5326 Mdot
.482 .53261 Mdot
.482 .53267 Mdot
.482 .5328 Mdot
.482 .53283 Mdot
.482 .53288 Mdot
.482 .53288 Mdot
.482 .5329 Mdot
.482 .53292 Mdot
.482 .53294 Mdot
.482 .53294 Mdot
.482 .53301 Mdot
.482 .53302 Mdot
.482 .53303 Mdot
.482 .53308 Mdot
.482 .53309 Mdot
.482 .53309 Mdot
.482 .53311 Mdot
.482 .53319 Mdot
.482 .53323 Mdot
.482 .53328 Mdot
.482 .53332 Mdot
.482 .53332 Mdot
.482 .53345 Mdot
.482 .53348 Mdot
.482 .5336 Mdot
.482 .53368 Mdot
.482 .53374 Mdot
.482 .53375 Mdot
.482 .53379 Mdot
.482 .53394 Mdot
.482 .53407 Mdot
.482 .53411 Mdot
.482 .53415 Mdot
.482 .53418 Mdot
.482 .53421 Mdot
.482 .53423 Mdot
.482 .53428 Mdot
.482 .53431 Mdot
.482 .53432 Mdot
.482 .5344 Mdot
.482 .53456 Mdot
.482 .53462 Mdot
.482 .53468 Mdot
.482 .53499 Mdot
.482 .53506 Mdot
.482 .53513 Mdot
.482 .53516 Mdot
.482 .53536 Mdot
.482 .53547 Mdot
.482 .53554 Mdot
.482 .53555 Mdot
.482 .53559 Mdot
.482 .5357 Mdot
.482 .53589 Mdot
.482 .53602 Mdot
.482 .53603 Mdot
.482 .53609 Mdot
.482 .53637 Mdot
.482 .53647 Mdot
.482 .53664 Mdot
.482 .53669 Mdot
.482 .53673 Mdot
.482 .53681 Mdot
.482 .53692 Mdot
.482 .53699 Mdot
.482 .53704 Mdot
.482 .53713 Mdot
.482 .53715 Mdot
.482 .53716 Mdot
.482 .53718 Mdot
.482 .53722 Mdot
.482 .53735 Mdot
.482 .5374 Mdot
.482 .53746 Mdot
.482 .5376 Mdot
.482 .53766 Mdot
.482 .53768 Mdot
.482 .53779 Mdot
.482 .53779 Mdot
.482 .53787 Mdot
.482 .538 Mdot
.482 .53829 Mdot
.482 .53838 Mdot
.482 .5384 Mdot
.482 .53848 Mdot
.482 .53848 Mdot
.482 .53863 Mdot
.482 .53875 Mdot
.482 .5388 Mdot
.482 .53898 Mdot
.482 .53904 Mdot
.482 .53911 Mdot
.482 .53912 Mdot
.482 .5392 Mdot
.482 .53943 Mdot
.482 .53951 Mdot
.482 .53961 Mdot
.482 .53967 Mdot
.482 .53969 Mdot
.482 .5397 Mdot
.482 .53971 Mdot
.482 .53974 Mdot
.482 .53976 Mdot
.482 .53983 Mdot
.482 .53986 Mdot
.482 .5399 Mdot
.482 .53997 Mdot
.482 .54 Mdot
.482 .54013 Mdot
.482 .5403 Mdot
.482 .54045 Mdot
.482 .54061 Mdot
.482 .54063 Mdot
.482 .54071 Mdot
.482 .54072 Mdot
.482 .54072 Mdot
.482 .54074 Mdot
.482 .54075 Mdot
.482 .54079 Mdot
.482 .54088 Mdot
.482 .54091 Mdot
.482 .54094 Mdot
.482 .54097 Mdot
.482 .54098 Mdot
.482 .54102 Mdot
.482 .54102 Mdot
.482 .54105 Mdot
.482 .54106 Mdot
.482 .54108 Mdot
.482 .54109 Mdot
.482 .54114 Mdot
.482 .54115 Mdot
.482 .54117 Mdot
.482 .54118 Mdot
.482 .54121 Mdot
.482 .54123 Mdot
.482 .54123 Mdot
.482 .54123 Mdot
.482 .54126 Mdot
.482 .54133 Mdot
.482 .54137 Mdot
.482 .5414 Mdot
.482 .54141 Mdot
.482 .54144 Mdot
.482 .54144 Mdot
.482 .54145 Mdot
.482 .54146 Mdot
.482 .54147 Mdot
.482 .54149 Mdot
.482 .54156 Mdot
.482 .54157 Mdot
.482 .54158 Mdot
.482 .54161 Mdot
.482 .54168 Mdot
.482 .54168 Mdot
.482 .54174 Mdot
.482 .54177 Mdot
.482 .54178 Mdot
.482 .54179 Mdot
.482 .54181 Mdot
.482 .54182 Mdot
.482 .54185 Mdot
.482 .54189 Mdot
.482 .54191 Mdot
.482 .54199 Mdot
.482 .542 Mdot
.482 .54201 Mdot
.482 .54204 Mdot
.482 .54205 Mdot
.482 .54205 Mdot
.482 .54206 Mdot
.482 .54208 Mdot
.482 .5421 Mdot
.482 .54211 Mdot
.482 .54212 Mdot
.482 .54215 Mdot
.482 .54218 Mdot
.482 .54221 Mdot
.482 .54221 Mdot
.482 .54221 Mdot
.482 .54223 Mdot
.482 .54225 Mdot
.482 .54225 Mdot
.482 .5423 Mdot
.482 .54232 Mdot
.482 .54232 Mdot
.482 .54232 Mdot
.482 .54233 Mdot
.482 .54233 Mdot
.482 .54233 Mdot
.482 .54233 Mdot
.482 .54234 Mdot
.482 .54234 Mdot
.484 .21014 Mdot
.484 .21019 Mdot
.484 .21019 Mdot
.484 .2102 Mdot
.484 .21023 Mdot
.484 .21024 Mdot
.484 .21024 Mdot
.484 .21026 Mdot
.484 .21035 Mdot
.484 .21036 Mdot
.484 .2104 Mdot
.484 .2104 Mdot
.484 .21044 Mdot
.484 .21047 Mdot
.484 .2105 Mdot
.484 .2105 Mdot
.484 .21069 Mdot
.484 .21076 Mdot
.484 .21077 Mdot
.484 .2108 Mdot
.484 .21083 Mdot
.484 .21084 Mdot
.484 .21088 Mdot
.484 .21089 Mdot
.484 .21092 Mdot
.484 .21098 Mdot
.484 .21099 Mdot
.484 .21099 Mdot
.484 .21108 Mdot
.484 .21108 Mdot
.484 .2113 Mdot
.484 .21133 Mdot
.484 .21139 Mdot
.484 .21141 Mdot
.484 .21153 Mdot
.484 .21157 Mdot
.484 .21157 Mdot
.484 .21159 Mdot
.484 .21165 Mdot
.484 .21189 Mdot
.484 .21198 Mdot
.484 .21207 Mdot
.484 .21211 Mdot
.484 .21212 Mdot
.484 .21241 Mdot
.484 .21243 Mdot
.484 .21256 Mdot
.484 .21273 Mdot
.484 .21279 Mdot
.484 .21285 Mdot
.484 .213 Mdot
.484 .21301 Mdot
.484 .21305 Mdot
.484 .21332 Mdot
.484 .21356 Mdot
.484 .21374 Mdot
.484 .21377 Mdot
.484 .21383 Mdot
.484 .21385 Mdot
.484 .21385 Mdot
.484 .21386 Mdot
.484 .21389 Mdot
.484 .21394 Mdot
.484 .21409 Mdot
.484 .21417 Mdot
.484 .21419 Mdot
.484 .21425 Mdot
.484 .2143 Mdot
.484 .21441 Mdot
.484 .2145 Mdot
.484 .2146 Mdot
.484 .21493 Mdot
.484 .215 Mdot
.484 .21504 Mdot
.484 .21508 Mdot
.484 .21508 Mdot
.484 .21529 Mdot
.484 .21538 Mdot
.484 .21557 Mdot
.484 .21566 Mdot
.484 .21568 Mdot
.484 .21609 Mdot
.484 .21654 Mdot
.484 .21703 Mdot
.484 .21728 Mdot
.484 .21732 Mdot
.484 .21741 Mdot
.484 .21742 Mdot
.484 .21761 Mdot
.484 .21767 Mdot
.484 .21781 Mdot
.484 .21798 Mdot
.484 .21804 Mdot
.484 .21816 Mdot
.484 .21843 Mdot
.484 .21849 Mdot
.484 .21854 Mdot
.484 .21881 Mdot
.484 .21893 Mdot
.484 .21918 Mdot
.484 .21972 Mdot
.484 .22002 Mdot
.484 .22017 Mdot
.484 .22032 Mdot
.484 .22094 Mdot
.484 .22099 Mdot
.484 .22114 Mdot
.484 .2221 Mdot
.484 .22267 Mdot
.484 .22292 Mdot
.484 .22307 Mdot
.484 .22317 Mdot
.484 .22341 Mdot
.484 .22356 Mdot
.484 .22368 Mdot
.484 .22381 Mdot
.484 .22407 Mdot
.484 .22446 Mdot
.484 .22474 Mdot
.484 .22475 Mdot
.484 .2249 Mdot
.484 .22532 Mdot
.484 .22568 Mdot
.484 .22582 Mdot
.484 .22632 Mdot
.484 .22635 Mdot
.484 .22657 Mdot
.484 .22659 Mdot
.484 .22668 Mdot
.484 .22707 Mdot
.484 .22723 Mdot
.484 .22725 Mdot
.484 .22734 Mdot
.484 .22757 Mdot
.484 .22856 Mdot
.484 .22868 Mdot
.484 .22871 Mdot
.484 .22918 Mdot
.484 .22944 Mdot
.484 .22994 Mdot
.484 .23113 Mdot
.484 .23119 Mdot
.484 .23133 Mdot
.484 .23138 Mdot
.484 .23146 Mdot
.484 .23202 Mdot
.484 .23214 Mdot
.484 .23222 Mdot
.484 .23231 Mdot
.484 .23231 Mdot
.484 .23278 Mdot
.484 .23293 Mdot
.484 .23295 Mdot
.484 .23307 Mdot
.484 .2331 Mdot
.484 .23318 Mdot
.484 .2332 Mdot
.484 .23339 Mdot
.484 .23355 Mdot
.484 .23391 Mdot
.484 .23425 Mdot
.484 .23431 Mdot
.484 .23442 Mdot
.484 .23475 Mdot
.484 .23498 Mdot
.484 .23504 Mdot
.484 .23538 Mdot
.484 .23556 Mdot
.484 .23574 Mdot
.484 .23581 Mdot
.484 .23608 Mdot
.484 .23657 Mdot
.484 .23674 Mdot
.484 .23683 Mdot
.484 .23685 Mdot
.484 .23685 Mdot
.484 .23686 Mdot
.484 .23688 Mdot
.484 .23693 Mdot
.484 .23714 Mdot
.484 .23716 Mdot
.484 .23725 Mdot
.484 .23742 Mdot
.484 .23783 Mdot
.484 .23786 Mdot
.484 .2379 Mdot
.484 .23828 Mdot
.484 .23837 Mdot
.484 .23867 Mdot
.484 .23934 Mdot
.484 .23951 Mdot
.484 .23954 Mdot
.484 .2396 Mdot
.484 .23961 Mdot
.484 .23974 Mdot
.484 .23977 Mdot
.484 .23987 Mdot
.484 .23998 Mdot
.484 .24002 Mdot
.484 .2403 Mdot
.484 .24051 Mdot
.484 .24058 Mdot
.484 .24074 Mdot
.484 .24133 Mdot
.484 .2418 Mdot
.484 .24189 Mdot
.484 .24294 Mdot
.484 .24299 Mdot
.484 .24312 Mdot
.484 .24346 Mdot
.484 .2438 Mdot
.484 .2447 Mdot
.484 .24493 Mdot
.484 .24501 Mdot
.484 .24501 Mdot
.484 .24517 Mdot
.484 .24562 Mdot
.484 .24569 Mdot
.484 .24591 Mdot
.484 .24602 Mdot
.484 .24686 Mdot
.484 .24688 Mdot
.484 .24722 Mdot
.484 .24725 Mdot
.484 .24729 Mdot
.484 .24749 Mdot
.484 .24762 Mdot
.484 .24766 Mdot
.484 .24781 Mdot
.484 .24787 Mdot
.484 .24797 Mdot
.484 .24811 Mdot
.484 .24813 Mdot
.484 .24841 Mdot
.484 .24917 Mdot
.484 .24917 Mdot
.484 .24929 Mdot
.484 .2494 Mdot
.484 .24956 Mdot
.484 .24959 Mdot
.484 .24974 Mdot
.484 .24978 Mdot
.484 .25016 Mdot
.484 .25023 Mdot
.484 .25024 Mdot
.484 .25026 Mdot
.484 .25036 Mdot
.484 .25041 Mdot
.484 .25042 Mdot
.484 .25064 Mdot
.484 .26662 Mdot
.484 .26702 Mdot
.484 .26705 Mdot
.484 .26713 Mdot
.484 .26732 Mdot
.484 .26737 Mdot
.484 .26739 Mdot
.484 .26751 Mdot
.484 .26823 Mdot
.484 .26829 Mdot
.484 .26857 Mdot
.484 .26862 Mdot
.484 .26893 Mdot
.484 .26913 Mdot
.484 .26936 Mdot
.484 .26936 Mdot
.484 .2708 Mdot
.484 .27133 Mdot
.484 .27138 Mdot
.484 .27165 Mdot
.484 .27183 Mdot
.484 .27194 Mdot
.484 .27223 Mdot
.484 .2723 Mdot
.484 .27256 Mdot
.484 .27295 Mdot
.484 .27302 Mdot
.484 .27309 Mdot
.484 .27373 Mdot
.484 .27377 Mdot
.484 .27541 Mdot
.484 .27564 Mdot
.484 .27605 Mdot
.484 .27619 Mdot
.484 .2771 Mdot
.484 .2774 Mdot
.484 .27741 Mdot
.484 .27756 Mdot
.484 .27801 Mdot
.484 .27983 Mdot
.484 .28051 Mdot
.484 .2812 Mdot
.484 .28146 Mdot
.484 .28157 Mdot
.484 .28371 Mdot
.484 .28389 Mdot
.484 .28487 Mdot
.484 .28609 Mdot
.484 .28642 Mdot
.484 .28657 Mdot
.484 .287 Mdot
.484 .28759 Mdot
.484 .28767 Mdot
.484 .28791 Mdot
.484 .28811 Mdot
.484 .28819 Mdot
.484 .28846 Mdot
.484 .28847 Mdot
.484 .28859 Mdot
.484 .28865 Mdot
.484 .28902 Mdot
.484 .29044 Mdot
.484 .29109 Mdot
.484 .29127 Mdot
.484 .29158 Mdot
.484 .29209 Mdot
.484 .29216 Mdot
.484 .29222 Mdot
.484 .29311 Mdot
.484 .29348 Mdot
.484 .29368 Mdot
.484 .29372 Mdot
.484 .29417 Mdot
.484 .29427 Mdot
.484 .29432 Mdot
.484 .29434 Mdot
.484 .29435 Mdot
.484 .29438 Mdot
.484 .29457 Mdot
.484 .29494 Mdot
.484 .29602 Mdot
.484 .29661 Mdot
.484 .29676 Mdot
.484 .29716 Mdot
.484 .29754 Mdot
.484 .29829 Mdot
.484 .29842 Mdot
.484 .29893 Mdot
.484 .29965 Mdot
.484 .2999 Mdot
.484 .30003 Mdot
.484 .30079 Mdot
.484 .30159 Mdot
.484 .30194 Mdot
.484 .30238 Mdot
.484 .30243 Mdot
.484 .3026 Mdot
.484 .30266 Mdot
.484 .30294 Mdot
.484 .30297 Mdot
.484 .30331 Mdot
.484 .30437 Mdot
.484 .30438 Mdot
.484 .30457 Mdot
.484 .30475 Mdot
.484 .30503 Mdot
.484 .3063 Mdot
.484 .30648 Mdot
.484 .30659 Mdot
.484 .3069 Mdot
.484 .30705 Mdot
.484 .30977 Mdot
.484 .31092 Mdot
.484 .31152 Mdot
.484 .3126 Mdot
.484 .31267 Mdot
.484 .31295 Mdot
.484 .31526 Mdot
.484 .3158 Mdot
.484 .31601 Mdot
.484 .31605 Mdot
.484 .31643 Mdot
.484 .31735 Mdot
.484 .31754 Mdot
.484 .3176 Mdot
.484 .31813 Mdot
.484 .3182 Mdot
.484 .31936 Mdot
.484 .31971 Mdot
.484 .32055 Mdot
.484 .32156 Mdot
.484 .3219 Mdot
.484 .32192 Mdot
.484 .3226 Mdot
.484 .32353 Mdot
.484 .32415 Mdot
.484 .32446 Mdot
.484 .32475 Mdot
.484 .32511 Mdot
.484 .32569 Mdot
.484 .32594 Mdot
.484 .32629 Mdot
.484 .32691 Mdot
.484 .32828 Mdot
.484 .3306 Mdot
.484 .33096 Mdot
.484 .33111 Mdot
.484 .33262 Mdot
.484 .33298 Mdot
.484 .33334 Mdot
.484 .33408 Mdot
.484 .3354 Mdot
.484 .33603 Mdot
.484 .3363 Mdot
.484 .33699 Mdot
.484 .33712 Mdot
.484 .33725 Mdot
.484 .33792 Mdot
.484 .33821 Mdot
.484 .33836 Mdot
.484 .33878 Mdot
.484 .33913 Mdot
.484 .33928 Mdot
.484 .33975 Mdot
.484 .33978 Mdot
.484 .33999 Mdot
.484 .3401 Mdot
.484 .34072 Mdot
.484 .34195 Mdot
.484 .34307 Mdot
.484 .34409 Mdot
.484 .34414 Mdot
.484 .34437 Mdot
.484 .34484 Mdot
.484 .34508 Mdot
.484 .34559 Mdot
.484 .3456 Mdot
.484 .34571 Mdot
.484 .34579 Mdot
.484 .34597 Mdot
.484 .34679 Mdot
.484 .34705 Mdot
.484 .34728 Mdot
.484 .34754 Mdot
.484 .34768 Mdot
.484 .34782 Mdot
.484 .34787 Mdot
.484 .34808 Mdot
.484 .34846 Mdot
.484 .34859 Mdot
.484 .34866 Mdot
.484 .34868 Mdot
.484 .3487 Mdot
.484 .34873 Mdot
.484 .34889 Mdot
.484 .34897 Mdot
.484 .34943 Mdot
.484 .35003 Mdot
.484 .35071 Mdot
.484 .35081 Mdot
.484 .35083 Mdot
.484 .35121 Mdot
.484 .35136 Mdot
.484 .35152 Mdot
.484 .35194 Mdot
.484 .35228 Mdot
.484 .35234 Mdot
.484 .35306 Mdot
.484 .3531 Mdot
.484 .35319 Mdot
.484 .35342 Mdot
.484 .35365 Mdot
.484 .35427 Mdot
.484 .35442 Mdot
.484 .35447 Mdot
.484 .35448 Mdot
.484 .35458 Mdot
.484 .35488 Mdot
.484 .35493 Mdot
.484 .35507 Mdot
.484 .35515 Mdot
.484 .3557 Mdot
.484 .35571 Mdot
.484 .35593 Mdot
.484 .35595 Mdot
.484 .35598 Mdot
.484 .35611 Mdot
.484 .3562 Mdot
.484 .35622 Mdot
.484 .35632 Mdot
.484 .35636 Mdot
.484 .35642 Mdot
.484 .35651 Mdot
.484 .35652 Mdot
.484 .3567 Mdot
.484 .35719 Mdot
.484 .35719 Mdot
.484 .35727 Mdot
.484 .35734 Mdot
.484 .35744 Mdot
.484 .35746 Mdot
.484 .35755 Mdot
.484 .35757 Mdot
.484 .35782 Mdot
.484 .35786 Mdot
.484 .35786 Mdot
.484 .35788 Mdot
.484 .35794 Mdot
.484 .35797 Mdot
.484 .35798 Mdot
.484 .35812 Mdot
.484 .48299 Mdot
.484 .48305 Mdot
.484 .48306 Mdot
.484 .48307 Mdot
.484 .4831 Mdot
.484 .48311 Mdot
.484 .48311 Mdot
.484 .48313 Mdot
.484 .48325 Mdot
.484 .48326 Mdot
.484 .4833 Mdot
.484 .48331 Mdot
.484 .48336 Mdot
.484 .48339 Mdot
.484 .48343 Mdot
.484 .48343 Mdot
.484 .48366 Mdot
.484 .48374 Mdot
.484 .48375 Mdot
.484 .48379 Mdot
.484 .48382 Mdot
.484 .48384 Mdot
.484 .48388 Mdot
.484 .48389 Mdot
.484 .48394 Mdot
.484 .484 Mdot
.484 .48401 Mdot
.484 .48402 Mdot
.484 .48412 Mdot
.484 .48413 Mdot
.484 .48438 Mdot
.484 .48442 Mdot
.484 .48449 Mdot
.484 .48451 Mdot
.484 .48465 Mdot
.484 .4847 Mdot
.484 .4847 Mdot
.484 .48472 Mdot
.484 .4848 Mdot
.484 .48508 Mdot
.484 .48519 Mdot
.484 .4853 Mdot
.484 .48534 Mdot
.484 .48536 Mdot
.484 .4857 Mdot
.484 .48572 Mdot
.484 .48588 Mdot
.484 .48607 Mdot
.484 .48615 Mdot
.484 .48622 Mdot
.484 .48639 Mdot
.484 .4864 Mdot
.484 .48645 Mdot
.484 .48676 Mdot
.484 .48704 Mdot
.484 .48725 Mdot
.484 .48729 Mdot
.484 .48736 Mdot
.484 .48738 Mdot
.484 .48739 Mdot
.484 .48739 Mdot
.484 .48743 Mdot
.484 .48748 Mdot
.484 .48766 Mdot
.484 .48776 Mdot
.484 .48778 Mdot
.484 .48784 Mdot
.484 .48791 Mdot
.484 .48803 Mdot
.484 .48813 Mdot
.484 .48825 Mdot
.484 .48863 Mdot
.484 .48871 Mdot
.484 .48875 Mdot
.484 .48879 Mdot
.484 .4888 Mdot
.484 .48903 Mdot
.484 .48914 Mdot
.484 .48936 Mdot
.484 .48946 Mdot
.484 .48948 Mdot
.484 .48995 Mdot
.484 .49045 Mdot
.484 .49101 Mdot
.484 .49129 Mdot
.484 .49134 Mdot
.484 .49143 Mdot
.484 .49144 Mdot
.484 .49166 Mdot
.484 .49172 Mdot
.484 .49188 Mdot
.484 .49207 Mdot
.484 .49214 Mdot
.484 .49227 Mdot
.484 .49257 Mdot
.484 .49263 Mdot
.484 .49268 Mdot
.484 .49299 Mdot
.484 .49311 Mdot
.484 .49339 Mdot
.484 .49398 Mdot
.484 .4943 Mdot
.484 .49446 Mdot
.484 .49463 Mdot
.484 .49529 Mdot
.484 .49536 Mdot
.484 .49552 Mdot
.484 .49653 Mdot
.484 .49713 Mdot
.484 .4974 Mdot
.484 .49756 Mdot
.484 .49766 Mdot
.484 .49792 Mdot
.484 .49807 Mdot
.484 .4982 Mdot
.484 .49833 Mdot
.484 .4986 Mdot
.484 .499 Mdot
.484 .49929 Mdot
.484 .4993 Mdot
.484 .49945 Mdot
.484 .49989 Mdot
.484 .50025 Mdot
.484 .5004 Mdot
.484 .50089 Mdot
.484 .50092 Mdot
.484 .50115 Mdot
.484 .50117 Mdot
.484 .50125 Mdot
.484 .50165 Mdot
.484 .50181 Mdot
.484 .50183 Mdot
.484 .50192 Mdot
.484 .50215 Mdot
.484 .50312 Mdot
.484 .50324 Mdot
.484 .50327 Mdot
.484 .50373 Mdot
.484 .50398 Mdot
.484 .50447 Mdot
.484 .5056 Mdot
.484 .50566 Mdot
.484 .5058 Mdot
.484 .50584 Mdot
.484 .50592 Mdot
.484 .50644 Mdot
.484 .50656 Mdot
.484 .50663 Mdot
.484 .50671 Mdot
.484 .50672 Mdot
.484 .50716 Mdot
.484 .5073 Mdot
.484 .50731 Mdot
.484 .50743 Mdot
.484 .50745 Mdot
.484 .50752 Mdot
.484 .50754 Mdot
.484 .50772 Mdot
.484 .50787 Mdot
.484 .5082 Mdot
.484 .50851 Mdot
.484 .50856 Mdot
.484 .50867 Mdot
.484 .50896 Mdot
.484 .50917 Mdot
.484 .50923 Mdot
.484 .50953 Mdot
.484 .50969 Mdot
.484 .50985 Mdot
.484 .50991 Mdot
.484 .51015 Mdot
.484 .51059 Mdot
.484 .51074 Mdot
.484 .51082 Mdot
.484 .51083 Mdot
.484 .51084 Mdot
.484 .51084 Mdot
.484 .51087 Mdot
.484 .51091 Mdot
.484 .51109 Mdot
.484 .5111 Mdot
.484 .51119 Mdot
.484 .51134 Mdot
.484 .5117 Mdot
.484 .51172 Mdot
.484 .51175 Mdot
.484 .51208 Mdot
.484 .51216 Mdot
.484 .51242 Mdot
.484 .51299 Mdot
.484 .51314 Mdot
.484 .51316 Mdot
.484 .51321 Mdot
.484 .51321 Mdot
.484 .51332 Mdot
.484 .51336 Mdot
.484 .51343 Mdot
.484 .51353 Mdot
.484 .51356 Mdot
.484 .5138 Mdot
.484 .51397 Mdot
.484 .51403 Mdot
.484 .51416 Mdot
.484 .51465 Mdot
.484 .51504 Mdot
.484 .51511 Mdot
.484 .51596 Mdot
.484 .51601 Mdot
.484 .51611 Mdot
.484 .51638 Mdot
.484 .51665 Mdot
.484 .51737 Mdot
.484 .51755 Mdot
.484 .5176 Mdot
.484 .51761 Mdot
.484 .51773 Mdot
.484 .51808 Mdot
.484 .51814 Mdot
.484 .5183 Mdot
.484 .51839 Mdot
.484 .51903 Mdot
.484 .51905 Mdot
.484 .5193 Mdot
.484 .51932 Mdot
.484 .51935 Mdot
.484 .5195 Mdot
.484 .5196 Mdot
.484 .51964 Mdot
.484 .51975 Mdot
.484 .51979 Mdot
.484 .51986 Mdot
.484 .51997 Mdot
.484 .51998 Mdot
.484 .52019 Mdot
.484 .52075 Mdot
.484 .52075 Mdot
.484 .52084 Mdot
.484 .52091 Mdot
.484 .52103 Mdot
.484 .52105 Mdot
.484 .52116 Mdot
.484 .52119 Mdot
.484 .52146 Mdot
.484 .52151 Mdot
.484 .52152 Mdot
.484 .52154 Mdot
.484 .52161 Mdot
.484 .52164 Mdot
.484 .52165 Mdot
.484 .52181 Mdot
.484 .52788 Mdot
.484 .52796 Mdot
.484 .52797 Mdot
.484 .52799 Mdot
.484 .52802 Mdot
.484 .52803 Mdot
.484 .52804 Mdot
.484 .52806 Mdot
.484 .52821 Mdot
.484 .52822 Mdot
.484 .52828 Mdot
.484 .52828 Mdot
.484 .52835 Mdot
.484 .52839 Mdot
.484 .52843 Mdot
.484 .52843 Mdot
.484 .52872 Mdot
.484 .52882 Mdot
.484 .52883 Mdot
.484 .52888 Mdot
.484 .52892 Mdot
.484 .52894 Mdot
.484 .52899 Mdot
.484 .52901 Mdot
.484 .52906 Mdot
.484 .52914 Mdot
.484 .52915 Mdot
.484 .52916 Mdot
.484 .52929 Mdot
.484 .52929 Mdot
.484 .52961 Mdot
.484 .52965 Mdot
.484 .52973 Mdot
.484 .52975 Mdot
.484 .52992 Mdot
.484 .52998 Mdot
.484 .52998 Mdot
.484 .53001 Mdot
.484 .5301 Mdot
.484 .53043 Mdot
.484 .53056 Mdot
.484 .53068 Mdot
.484 .53073 Mdot
.484 .53075 Mdot
.484 .53114 Mdot
.484 .53117 Mdot
.484 .53135 Mdot
.484 .53156 Mdot
.484 .53162 Mdot
.484 .53165 Mdot
.484 .53172 Mdot
.484 .53183 Mdot
.484 .53184 Mdot
.484 .53188 Mdot
.484 .53192 Mdot
.484 .53193 Mdot
.484 .53198 Mdot
.484 .53198 Mdot
.484 .532 Mdot
.484 .53201 Mdot
.484 .53208 Mdot
.484 .53232 Mdot
.484 .53244 Mdot
.484 .53247 Mdot
.484 .53261 Mdot
.484 .53262 Mdot
.484 .53263 Mdot
.484 .53278 Mdot
.484 .53284 Mdot
.484 .53288 Mdot
.484 .53289 Mdot
.484 .53296 Mdot
.484 .53298 Mdot
.484 .53299 Mdot
.484 .53299 Mdot
.484 .53299 Mdot
.484 .533 Mdot
.484 .53303 Mdot
.484 .53309 Mdot
.484 .53327 Mdot
.484 .53337 Mdot
.484 .5334 Mdot
.484 .53346 Mdot
.484 .53353 Mdot
.484 .53365 Mdot
.484 .53367 Mdot
.484 .53376 Mdot
.484 .53388 Mdot
.484 .53392 Mdot
.484 .53394 Mdot
.484 .53406 Mdot
.484 .5342 Mdot
.484 .53425 Mdot
.484 .53433 Mdot
.484 .53433 Mdot
.484 .53436 Mdot
.484 .53437 Mdot
.484 .53442 Mdot
.484 .53442 Mdot
.484 .53448 Mdot
.484 .53465 Mdot
.484 .53465 Mdot
.484 .53468 Mdot
.484 .53471 Mdot
.484 .53475 Mdot
.484 .53496 Mdot
.484 .53499 Mdot
.484 .535 Mdot
.484 .53505 Mdot
.484 .53508 Mdot
.484 .53551 Mdot
.484 .53569 Mdot
.484 .53578 Mdot
.484 .53595 Mdot
.484 .53596 Mdot
.484 .53601 Mdot
.484 .53637 Mdot
.484 .53645 Mdot
.484 .53648 Mdot
.484 .53649 Mdot
.484 .53655 Mdot
.484 .53669 Mdot
.484 .53672 Mdot
.484 .53673 Mdot
.484 .53681 Mdot
.484 .53682 Mdot
.484 .53699 Mdot
.484 .53705 Mdot
.484 .53718 Mdot
.484 .53733 Mdot
.484 .53738 Mdot
.484 .53738 Mdot
.484 .53748 Mdot
.484 .53762 Mdot
.484 .53772 Mdot
.484 .53776 Mdot
.484 .53781 Mdot
.484 .53786 Mdot
.484 .53795 Mdot
.484 .53798 Mdot
.484 .53804 Mdot
.484 .53813 Mdot
.484 .53833 Mdot
.484 .53867 Mdot
.484 .53873 Mdot
.484 .53875 Mdot
.484 .53897 Mdot
.484 .53902 Mdot
.484 .53907 Mdot
.484 .53918 Mdot
.484 .53937 Mdot
.484 .53946 Mdot
.484 .5395 Mdot
.484 .5396 Mdot
.484 .53962 Mdot
.484 .53964 Mdot
.484 .53974 Mdot
.484 .53978 Mdot
.484 .5398 Mdot
.484 .53986 Mdot
.484 .53991 Mdot
.484 .53993 Mdot
.484 .54 Mdot
.484 .54 Mdot
.484 .54003 Mdot
.484 .54005 Mdot
.484 .54014 Mdot
.484 .54031 Mdot
.484 .54047 Mdot
.484 .54062 Mdot
.484 .54062 Mdot
.484 .54066 Mdot
.484 .54072 Mdot
.484 .54076 Mdot
.484 .54083 Mdot
.484 .54083 Mdot
.484 .54084 Mdot
.484 .54086 Mdot
.484 .54088 Mdot
.484 .541 Mdot
.484 .54103 Mdot
.484 .54107 Mdot
.484 .5411 Mdot
.484 .54112 Mdot
.484 .54114 Mdot
.484 .54115 Mdot
.484 .54118 Mdot
.484 .54123 Mdot
.484 .54125 Mdot
.484 .54126 Mdot
.484 .54126 Mdot
.484 .54126 Mdot
.484 .54127 Mdot
.484 .54129 Mdot
.484 .5413 Mdot
.484 .54137 Mdot
.484 .54145 Mdot
.484 .54155 Mdot
.484 .54156 Mdot
.484 .54156 Mdot
.484 .54162 Mdot
.484 .54164 Mdot
.484 .54166 Mdot
.484 .54172 Mdot
.484 .54176 Mdot
.484 .54177 Mdot
.484 .54187 Mdot
.484 .54188 Mdot
.484 .54189 Mdot
.484 .54192 Mdot
.484 .54196 Mdot
.484 .54204 Mdot
.484 .54206 Mdot
.484 .54207 Mdot
.484 .54207 Mdot
.484 .54208 Mdot
.484 .54213 Mdot
.484 .54213 Mdot
.484 .54215 Mdot
.484 .54216 Mdot
.484 .54224 Mdot
.484 .54224 Mdot
.484 .54227 Mdot
.484 .54227 Mdot
.484 .54228 Mdot
.484 .54229 Mdot
.484 .54231 Mdot
.484 .54231 Mdot
.484 .54232 Mdot
.484 .54233 Mdot
.484 .54234 Mdot
.484 .54235 Mdot
.484 .54235 Mdot
.484 .54238 Mdot
.484 .54244 Mdot
.484 .54244 Mdot
.484 .54245 Mdot
.484 .54246 Mdot
.484 .54248 Mdot
.484 .54248 Mdot
.484 .54249 Mdot
.484 .5425 Mdot
.484 .54253 Mdot
.484 .54254 Mdot
.484 .54254 Mdot
.484 .54254 Mdot
.484 .54255 Mdot
.484 .54255 Mdot
.484 .54255 Mdot
.484 .54257 Mdot
.486 .20954 Mdot
.486 .20955 Mdot
.486 .20955 Mdot
.486 .20959 Mdot
.486 .20961 Mdot
.486 .20964 Mdot
.486 .20964 Mdot
.486 .20964 Mdot
.486 .20965 Mdot
.486 .20969 Mdot
.486 .2097 Mdot
.486 .20975 Mdot
.486 .20975 Mdot
.486 .20984 Mdot
.486 .20988 Mdot
.486 .20994 Mdot
.486 .20994 Mdot
.486 .20994 Mdot
.486 .20997 Mdot
.486 .20999 Mdot
.486 .21001 Mdot
.486 .21074 Mdot
.486 .21075 Mdot
.486 .21078 Mdot
.486 .21081 Mdot
.486 .21086 Mdot
.486 .21099 Mdot
.486 .2111 Mdot
.486 .21112 Mdot
.486 .21121 Mdot
.486 .21145 Mdot
.486 .21146 Mdot
.486 .21147 Mdot
.486 .21155 Mdot
.486 .21163 Mdot
.486 .21171 Mdot
.486 .21173 Mdot
.486 .21175 Mdot
.486 .21177 Mdot
.486 .21187 Mdot
.486 .21195 Mdot
.486 .21198 Mdot
.486 .21202 Mdot
.486 .21204 Mdot
.486 .21227 Mdot
.486 .21229 Mdot
.486 .21236 Mdot
.486 .21271 Mdot
.486 .21272 Mdot
.486 .2129 Mdot
.486 .21291 Mdot
.486 .213 Mdot
.486 .21304 Mdot
.486 .21321 Mdot
.486 .2133 Mdot
.486 .2134 Mdot
.486 .21363 Mdot
.486 .21379 Mdot
.486 .214 Mdot
.486 .21402 Mdot
.486 .21411 Mdot
.486 .21415 Mdot
.486 .21421 Mdot
.486 .21452 Mdot
.486 .21452 Mdot
.486 .21502 Mdot
.486 .21537 Mdot
.486 .21574 Mdot
.486 .2158 Mdot
.486 .21597 Mdot
.486 .21601 Mdot
.486 .21608 Mdot
.486 .21617 Mdot
.486 .21623 Mdot
.486 .21639 Mdot
.486 .21649 Mdot
.486 .2165 Mdot
.486 .21713 Mdot
.486 .21735 Mdot
.486 .21736 Mdot
.486 .21739 Mdot
.486 .21748 Mdot
.486 .21753 Mdot
.486 .21756 Mdot
.486 .21769 Mdot
.486 .21822 Mdot
.486 .21828 Mdot
.486 .21829 Mdot
.486 .21833 Mdot
.486 .21889 Mdot
.486 .21923 Mdot
.486 .21924 Mdot
.486 .21928 Mdot
.486 .21944 Mdot
.486 .21961 Mdot
.486 .22003 Mdot
.486 .22013 Mdot
.486 .22014 Mdot
.486 .22031 Mdot
.486 .22066 Mdot
.486 .22102 Mdot
.486 .22111 Mdot
.486 .22113 Mdot
.486 .22169 Mdot
.486 .22179 Mdot
.486 .22183 Mdot
.486 .22188 Mdot
.486 .22195 Mdot
.486 .22209 Mdot
.486 .22233 Mdot
.486 .22291 Mdot
.486 .22291 Mdot
.486 .22318 Mdot
.486 .22321 Mdot
.486 .22327 Mdot
.486 .22328 Mdot
.486 .22345 Mdot
.486 .22357 Mdot
.486 .22376 Mdot
.486 .22391 Mdot
.486 .22405 Mdot
.486 .22408 Mdot
.486 .22417 Mdot
.486 .22417 Mdot
.486 .22434 Mdot
.486 .22466 Mdot
.486 .22474 Mdot
.486 .22499 Mdot
.486 .22507 Mdot
.486 .22515 Mdot
.486 .22525 Mdot
.486 .22528 Mdot
.486 .22532 Mdot
.486 .22549 Mdot
.486 .22559 Mdot
.486 .2256 Mdot
.486 .2259 Mdot
.486 .22602 Mdot
.486 .22604 Mdot
.486 .22618 Mdot
.486 .22635 Mdot
.486 .22643 Mdot
.486 .22648 Mdot
.486 .22787 Mdot
.486 .2279 Mdot
.486 .22805 Mdot
.486 .22819 Mdot
.486 .22862 Mdot
.486 .2288 Mdot
.486 .22885 Mdot
.486 .22904 Mdot
.486 .22906 Mdot
.486 .22927 Mdot
.486 .22937 Mdot
.486 .22985 Mdot
.486 .22994 Mdot
.486 .23002 Mdot
.486 .2311 Mdot
.486 .23114 Mdot
.486 .23161 Mdot
.486 .2319 Mdot
.486 .23218 Mdot
.486 .23219 Mdot
.486 .23228 Mdot
.486 .23376 Mdot
.486 .23377 Mdot
.486 .23475 Mdot
.486 .23496 Mdot
.486 .23508 Mdot
.486 .23537 Mdot
.486 .23543 Mdot
.486 .23613 Mdot
.486 .23667 Mdot
.486 .23746 Mdot
.486 .23781 Mdot
.486 .2381 Mdot
.486 .23868 Mdot
.486 .23882 Mdot
.486 .23916 Mdot
.486 .23917 Mdot
.486 .23959 Mdot
.486 .23974 Mdot
.486 .23982 Mdot
.486 .23985 Mdot
.486 .23995 Mdot
.486 .24032 Mdot
.486 .24033 Mdot
.486 .24035 Mdot
.486 .24093 Mdot
.486 .24112 Mdot
.486 .24136 Mdot
.486 .24142 Mdot
.486 .24143 Mdot
.486 .24228 Mdot
.486 .24233 Mdot
.486 .24236 Mdot
.486 .24242 Mdot
.486 .2425 Mdot
.486 .24262 Mdot
.486 .24292 Mdot
.486 .24293 Mdot
.486 .24308 Mdot
.486 .24326 Mdot
.486 .24336 Mdot
.486 .24344 Mdot
.486 .24351 Mdot
.486 .24352 Mdot
.486 .24356 Mdot
.486 .24357 Mdot
.486 .24365 Mdot
.486 .24381 Mdot
.486 .24397 Mdot
.486 .2441 Mdot
.486 .24413 Mdot
.486 .24441 Mdot
.486 .24447 Mdot
.486 .24448 Mdot
.486 .24463 Mdot
.486 .24466 Mdot
.486 .24468 Mdot
.486 .24541 Mdot
.486 .24578 Mdot
.486 .24586 Mdot
.486 .24626 Mdot
.486 .24676 Mdot
.486 .24698 Mdot
.486 .2471 Mdot
.486 .24722 Mdot
.486 .24726 Mdot
.486 .25021 Mdot
.486 .25026 Mdot
.486 .25034 Mdot
.486 .25049 Mdot
.486 .25049 Mdot
.486 .2505 Mdot
.486 .25072 Mdot
.486 .25091 Mdot
.486 .25126 Mdot
.486 .25128 Mdot
.486 .25147 Mdot
.486 .25153 Mdot
.486 .25169 Mdot
.486 .25171 Mdot
.486 .25171 Mdot
.486 .25174 Mdot
.486 .25186 Mdot
.486 .25192 Mdot
.486 .2521 Mdot
.486 .25212 Mdot
.486 .25212 Mdot
.486 .26343 Mdot
.486 .26345 Mdot
.486 .26347 Mdot
.486 .2638 Mdot
.486 .26391 Mdot
.486 .26413 Mdot
.486 .26418 Mdot
.486 .26418 Mdot
.486 .26421 Mdot
.486 .26452 Mdot
.486 .26462 Mdot
.486 .26497 Mdot
.486 .26501 Mdot
.486 .26566 Mdot
.486 .266 Mdot
.486 .26641 Mdot
.486 .26643 Mdot
.486 .26643 Mdot
.486 .2667 Mdot
.486 .26685 Mdot
.486 .26695 Mdot
.486 .27253 Mdot
.486 .27261 Mdot
.486 .27285 Mdot
.486 .27308 Mdot
.486 .27351 Mdot
.486 .27449 Mdot
.486 .27527 Mdot
.486 .27544 Mdot
.486 .27616 Mdot
.486 .2776 Mdot
.486 .27764 Mdot
.486 .27772 Mdot
.486 .27801 Mdot
.486 .27804 Mdot
.486 .27815 Mdot
.486 .27871 Mdot
.486 .27878 Mdot
.486 .27903 Mdot
.486 .27935 Mdot
.486 .27968 Mdot
.486 .27985 Mdot
.486 .27985 Mdot
.486 .27993 Mdot
.486 .27997 Mdot
.486 .28011 Mdot
.486 .28027 Mdot
.486 .28046 Mdot
.486 .28084 Mdot
.486 .28114 Mdot
.486 .28115 Mdot
.486 .28176 Mdot
.486 .28202 Mdot
.486 .28218 Mdot
.486 .28231 Mdot
.486 .28235 Mdot
.486 .28245 Mdot
.486 .28423 Mdot
.486 .28423 Mdot
.486 .28436 Mdot
.486 .28486 Mdot
.486 .28526 Mdot
.486 .28646 Mdot
.486 .28651 Mdot
.486 .28652 Mdot
.486 .2873 Mdot
.486 .28752 Mdot
.486 .28759 Mdot
.486 .28775 Mdot
.486 .28807 Mdot
.486 .28896 Mdot
.486 .28897 Mdot
.486 .28969 Mdot
.486 .28999 Mdot
.486 .29123 Mdot
.486 .29186 Mdot
.486 .2926 Mdot
.486 .2943 Mdot
.486 .29548 Mdot
.486 .29643 Mdot
.486 .29702 Mdot
.486 .29716 Mdot
.486 .29779 Mdot
.486 .29805 Mdot
.486 .29853 Mdot
.486 .30069 Mdot
.486 .30073 Mdot
.486 .30405 Mdot
.486 .30425 Mdot
.486 .30426 Mdot
.486 .30491 Mdot
.486 .30556 Mdot
.486 .30662 Mdot
.486 .30672 Mdot
.486 .30918 Mdot
.486 .30938 Mdot
.486 .30958 Mdot
.486 .3107 Mdot
.486 .31093 Mdot
.486 .31141 Mdot
.486 .31145 Mdot
.486 .31188 Mdot
.486 .31202 Mdot
.486 .31243 Mdot
.486 .31343 Mdot
.486 .31376 Mdot
.486 .3141 Mdot
.486 .31418 Mdot
.486 .31745 Mdot
.486 .31755 Mdot
.486 .31774 Mdot
.486 .31815 Mdot
.486 .31847 Mdot
.486 .31853 Mdot
.486 .31882 Mdot
.486 .31952 Mdot
.486 .31956 Mdot
.486 .31978 Mdot
.486 .32019 Mdot
.486 .32029 Mdot
.486 .32036 Mdot
.486 .32058 Mdot
.486 .32078 Mdot
.486 .32098 Mdot
.486 .32156 Mdot
.486 .32175 Mdot
.486 .32253 Mdot
.486 .32294 Mdot
.486 .32294 Mdot
.486 .32314 Mdot
.486 .32322 Mdot
.486 .32356 Mdot
.486 .32392 Mdot
.486 .32437 Mdot
.486 .32467 Mdot
.486 .32506 Mdot
.486 .32509 Mdot
.486 .32525 Mdot
.486 .32532 Mdot
.486 .32596 Mdot
.486 .32597 Mdot
.486 .32736 Mdot
.486 .32795 Mdot
.486 .32829 Mdot
.486 .32845 Mdot
.486 .32859 Mdot
.486 .32868 Mdot
.486 .32891 Mdot
.486 .33027 Mdot
.486 .33033 Mdot
.486 .33056 Mdot
.486 .33143 Mdot
.486 .33229 Mdot
.486 .3327 Mdot
.486 .33272 Mdot
.486 .33297 Mdot
.486 .33401 Mdot
.486 .33441 Mdot
.486 .33482 Mdot
.486 .33493 Mdot
.486 .33495 Mdot
.486 .33578 Mdot
.486 .33717 Mdot
.486 .33726 Mdot
.486 .33728 Mdot
.486 .33745 Mdot
.486 .33876 Mdot
.486 .33908 Mdot
.486 .33916 Mdot
.486 .33928 Mdot
.486 .33949 Mdot
.486 .33958 Mdot
.486 .3396 Mdot
.486 .34015 Mdot
.486 .34171 Mdot
.486 .34174 Mdot
.486 .342 Mdot
.486 .34239 Mdot
.486 .34254 Mdot
.486 .34278 Mdot
.486 .34296 Mdot
.486 .34304 Mdot
.486 .34346 Mdot
.486 .34361 Mdot
.486 .34456 Mdot
.486 .34542 Mdot
.486 .34669 Mdot
.486 .3467 Mdot
.486 .34747 Mdot
.486 .34763 Mdot
.486 .34772 Mdot
.486 .34795 Mdot
.486 .34799 Mdot
.486 .34853 Mdot
.486 .34894 Mdot
.486 .34953 Mdot
.486 .34978 Mdot
.486 .35 Mdot
.486 .35042 Mdot
.486 .35053 Mdot
.486 .35077 Mdot
.486 .35078 Mdot
.486 .35124 Mdot
.486 .35126 Mdot
.486 .35216 Mdot
.486 .35233 Mdot
.486 .35238 Mdot
.486 .35297 Mdot
.486 .35301 Mdot
.486 .35312 Mdot
.486 .35321 Mdot
.486 .35341 Mdot
.486 .35364 Mdot
.486 .35371 Mdot
.486 .35376 Mdot
.486 .35381 Mdot
.486 .35401 Mdot
.486 .35421 Mdot
.486 .35442 Mdot
.486 .35445 Mdot
.486 .35446 Mdot
.486 .35508 Mdot
.486 .35532 Mdot
.486 .35538 Mdot
.486 .35564 Mdot
.486 .35597 Mdot
.486 .35611 Mdot
.486 .35619 Mdot
.486 .35627 Mdot
.486 .35629 Mdot
.486 .35816 Mdot
.486 .3582 Mdot
.486 .35825 Mdot
.486 .35834 Mdot
.486 .35834 Mdot
.486 .35834 Mdot
.486 .35848 Mdot
.486 .3586 Mdot
.486 .35882 Mdot
.486 .35883 Mdot
.486 .35895 Mdot
.486 .35898 Mdot
.486 .35908 Mdot
.486 .35909 Mdot
.486 .35909 Mdot
.486 .35911 Mdot
.486 .35919 Mdot
.486 .35922 Mdot
.486 .35933 Mdot
.486 .35934 Mdot
.486 .35935 Mdot
.486 .48248 Mdot
.486 .48248 Mdot
.486 .48249 Mdot
.486 .48254 Mdot
.486 .48256 Mdot
.486 .48259 Mdot
.486 .4826 Mdot
.486 .4826 Mdot
.486 .48261 Mdot
.486 .48265 Mdot
.486 .48267 Mdot
.486 .48273 Mdot
.486 .48273 Mdot
.486 .48284 Mdot
.486 .48289 Mdot
.486 .48295 Mdot
.486 .48296 Mdot
.486 .48296 Mdot
.486 .483 Mdot
.486 .48302 Mdot
.486 .48304 Mdot
.486 .48392 Mdot
.486 .48393 Mdot
.486 .48397 Mdot
.486 .48401 Mdot
.486 .48407 Mdot
.486 .48423 Mdot
.486 .48435 Mdot
.486 .48437 Mdot
.486 .48449 Mdot
.486 .48478 Mdot
.486 .48478 Mdot
.486 .4848 Mdot
.486 .48489 Mdot
.486 .48498 Mdot
.486 .48508 Mdot
.486 .4851 Mdot
.486 .48513 Mdot
.486 .48516 Mdot
.486 .48526 Mdot
.486 .48536 Mdot
.486 .4854 Mdot
.486 .48545 Mdot
.486 .48547 Mdot
.486 .48575 Mdot
.486 .48577 Mdot
.486 .48584 Mdot
.486 .48626 Mdot
.486 .48627 Mdot
.486 .48649 Mdot
.486 .48649 Mdot
.486 .4866 Mdot
.486 .48665 Mdot
.486 .48685 Mdot
.486 .48695 Mdot
.486 .48706 Mdot
.486 .48733 Mdot
.486 .48752 Mdot
.486 .48777 Mdot
.486 .48779 Mdot
.486 .48789 Mdot
.486 .48793 Mdot
.486 .48801 Mdot
.486 .48836 Mdot
.486 .48837 Mdot
.486 .48894 Mdot
.486 .48934 Mdot
.486 .48977 Mdot
.486 .48984 Mdot
.486 .49003 Mdot
.486 .49006 Mdot
.486 .49015 Mdot
.486 .49025 Mdot
.486 .49032 Mdot
.486 .4905 Mdot
.486 .49061 Mdot
.486 .49063 Mdot
.486 .49133 Mdot
.486 .49158 Mdot
.486 .49159 Mdot
.486 .49163 Mdot
.486 .49172 Mdot
.486 .49178 Mdot
.486 .49181 Mdot
.486 .49196 Mdot
.486 .49254 Mdot
.486 .49262 Mdot
.486 .49262 Mdot
.486 .49267 Mdot
.486 .49328 Mdot
.486 .49365 Mdot
.486 .49367 Mdot
.486 .49371 Mdot
.486 .49389 Mdot
.486 .49407 Mdot
.486 .49453 Mdot
.486 .49464 Mdot
.486 .49465 Mdot
.486 .49483 Mdot
.486 .49521 Mdot
.486 .4956 Mdot
.486 .4957 Mdot
.486 .49572 Mdot
.486 .49632 Mdot
.486 .49642 Mdot
.486 .49646 Mdot
.486 .49652 Mdot
.486 .49659 Mdot
.486 .49674 Mdot
.486 .497 Mdot
.486 .4976 Mdot
.486 .49761 Mdot
.486 .49789 Mdot
.486 .49791 Mdot
.486 .49798 Mdot
.486 .498 Mdot
.486 .49817 Mdot
.486 .4983 Mdot
.486 .49849 Mdot
.486 .49865 Mdot
.486 .49879 Mdot
.486 .49883 Mdot
.486 .49891 Mdot
.486 .49892 Mdot
.486 .49909 Mdot
.486 .49943 Mdot
.486 .49951 Mdot
.486 .49976 Mdot
.486 .49984 Mdot
.486 .49993 Mdot
.486 .50003 Mdot
.486 .50005 Mdot
.486 .5001 Mdot
.486 .50027 Mdot
.486 .50037 Mdot
.486 .50039 Mdot
.486 .50069 Mdot
.486 .50081 Mdot
.486 .50084 Mdot
.486 .50097 Mdot
.486 .50115 Mdot
.486 .50123 Mdot
.486 .50127 Mdot
.486 .50266 Mdot
.486 .50269 Mdot
.486 .50284 Mdot
.486 .50298 Mdot
.486 .5034 Mdot
.486 .50357 Mdot
.486 .50363 Mdot
.486 .50381 Mdot
.486 .50383 Mdot
.486 .50403 Mdot
.486 .50413 Mdot
.486 .5046 Mdot
.486 .50468 Mdot
.486 .50476 Mdot
.486 .5058 Mdot
.486 .50583 Mdot
.486 .50628 Mdot
.486 .50655 Mdot
.486 .50682 Mdot
.486 .50682 Mdot
.486 .50691 Mdot
.486 .50828 Mdot
.486 .50829 Mdot
.486 .50918 Mdot
.486 .50937 Mdot
.486 .50948 Mdot
.486 .50974 Mdot
.486 .50979 Mdot
.486 .51042 Mdot
.486 .5109 Mdot
.486 .51159 Mdot
.486 .51189 Mdot
.486 .51215 Mdot
.486 .51265 Mdot
.486 .51277 Mdot
.486 .51306 Mdot
.486 .51306 Mdot
.486 .51342 Mdot
.486 .51355 Mdot
.486 .51361 Mdot
.486 .51364 Mdot
.486 .51373 Mdot
.486 .51404 Mdot
.486 .51404 Mdot
.486 .51406 Mdot
.486 .51454 Mdot
.486 .5147 Mdot
.486 .5149 Mdot
.486 .51495 Mdot
.486 .51496 Mdot
.486 .51566 Mdot
.486 .5157 Mdot
.486 .51572 Mdot
.486 .51577 Mdot
.486 .51583 Mdot
.486 .51594 Mdot
.486 .51618 Mdot
.486 .51618 Mdot
.486 .5163 Mdot
.486 .51645 Mdot
.486 .51653 Mdot
.486 .51659 Mdot
.486 .51664 Mdot
.486 .51666 Mdot
.486 .51669 Mdot
.486 .51669 Mdot
.486 .51676 Mdot
.486 .51689 Mdot
.486 .51701 Mdot
.486 .51711 Mdot
.486 .51714 Mdot
.486 .51736 Mdot
.486 .51741 Mdot
.486 .51742 Mdot
.486 .51753 Mdot
.486 .51756 Mdot
.486 .51758 Mdot
.486 .51814 Mdot
.486 .51843 Mdot
.486 .51849 Mdot
.486 .51879 Mdot
.486 .51918 Mdot
.486 .51935 Mdot
.486 .51944 Mdot
.486 .51953 Mdot
.486 .51956 Mdot
.486 .52172 Mdot
.486 .52176 Mdot
.486 .52182 Mdot
.486 .52192 Mdot
.486 .52193 Mdot
.486 .52193 Mdot
.486 .52209 Mdot
.486 .52222 Mdot
.486 .52247 Mdot
.486 .52249 Mdot
.486 .52262 Mdot
.486 .52266 Mdot
.486 .52278 Mdot
.486 .52279 Mdot
.486 .52279 Mdot
.486 .52281 Mdot
.486 .52289 Mdot
.486 .52293 Mdot
.486 .52306 Mdot
.486 .52307 Mdot
.486 .52308 Mdot
.486 .52737 Mdot
.486 .52737 Mdot
.486 .52737 Mdot
.486 .52744 Mdot
.486 .52746 Mdot
.486 .52751 Mdot
.486 .52752 Mdot
.486 .52752 Mdot
.486 .52753 Mdot
.486 .52759 Mdot
.486 .52761 Mdot
.486 .52768 Mdot
.486 .52769 Mdot
.486 .52782 Mdot
.486 .52789 Mdot
.486 .52797 Mdot
.486 .52798 Mdot
.486 .52798 Mdot
.486 .52803 Mdot
.486 .52806 Mdot
.486 .52808 Mdot
.486 .52918 Mdot
.486 .5292 Mdot
.486 .52924 Mdot
.486 .52929 Mdot
.486 .52937 Mdot
.486 .52956 Mdot
.486 .52971 Mdot
.486 .52974 Mdot
.486 .52987 Mdot
.486 .53014 Mdot
.486 .53015 Mdot
.486 .53016 Mdot
.486 .53022 Mdot
.486 .53022 Mdot
.486 .53024 Mdot
.486 .53035 Mdot
.486 .53036 Mdot
.486 .53041 Mdot
.486 .53047 Mdot
.486 .53052 Mdot
.486 .53056 Mdot
.486 .53056 Mdot
.486 .53057 Mdot
.486 .53058 Mdot
.486 .5306 Mdot
.486 .53063 Mdot
.486 .53067 Mdot
.486 .53074 Mdot
.486 .53079 Mdot
.486 .53079 Mdot
.486 .5309 Mdot
.486 .53095 Mdot
.486 .53098 Mdot
.486 .531 Mdot
.486 .53101 Mdot
.486 .53103 Mdot
.486 .53135 Mdot
.486 .53135 Mdot
.486 .53137 Mdot
.486 .53146 Mdot
.486 .53153 Mdot
.486 .53174 Mdot
.486 .53175 Mdot
.486 .53175 Mdot
.486 .53189 Mdot
.486 .53193 Mdot
.486 .53194 Mdot
.486 .53197 Mdot
.486 .53202 Mdot
.486 .53218 Mdot
.486 .53218 Mdot
.486 .5323 Mdot
.486 .53236 Mdot
.486 .53257 Mdot
.486 .53268 Mdot
.486 .5328 Mdot
.486 .53309 Mdot
.486 .53329 Mdot
.486 .53355 Mdot
.486 .53357 Mdot
.486 .53367 Mdot
.486 .53372 Mdot
.486 .5338 Mdot
.486 .53415 Mdot
.486 .53416 Mdot
.486 .5347 Mdot
.486 .53473 Mdot
.486 .53473 Mdot
.486 .53483 Mdot
.486 .53494 Mdot
.486 .53511 Mdot
.486 .53512 Mdot
.486 .53551 Mdot
.486 .53554 Mdot
.486 .53558 Mdot
.486 .53575 Mdot
.486 .53579 Mdot
.486 .53586 Mdot
.486 .53587 Mdot
.486 .53594 Mdot
.486 .53596 Mdot
.486 .53602 Mdot
.486 .53618 Mdot
.486 .53623 Mdot
.486 .53628 Mdot
.486 .53629 Mdot
.486 .53679 Mdot
.486 .53681 Mdot
.486 .53684 Mdot
.486 .5369 Mdot
.486 .53695 Mdot
.486 .53696 Mdot
.486 .537 Mdot
.486 .53711 Mdot
.486 .53711 Mdot
.486 .53715 Mdot
.486 .53721 Mdot
.486 .53723 Mdot
.486 .53724 Mdot
.486 .53727 Mdot
.486 .5373 Mdot
.486 .53733 Mdot
.486 .53742 Mdot
.486 .53745 Mdot
.486 .53756 Mdot
.486 .53762 Mdot
.486 .53762 Mdot
.486 .53765 Mdot
.486 .53767 Mdot
.486 .53772 Mdot
.486 .53777 Mdot
.486 .53784 Mdot
.486 .53788 Mdot
.486 .53794 Mdot
.486 .53795 Mdot
.486 .53797 Mdot
.486 .53798 Mdot
.486 .53807 Mdot
.486 .53808 Mdot
.486 .53828 Mdot
.486 .53837 Mdot
.486 .53842 Mdot
.486 .53844 Mdot
.486 .53846 Mdot
.486 .53848 Mdot
.486 .53851 Mdot
.486 .53871 Mdot
.486 .53872 Mdot
.486 .53875 Mdot
.486 .53888 Mdot
.486 .539 Mdot
.486 .53906 Mdot
.486 .53907 Mdot
.486 .5391 Mdot
.486 .53925 Mdot
.486 .53931 Mdot
.486 .53937 Mdot
.486 .53939 Mdot
.486 .53939 Mdot
.486 .53951 Mdot
.486 .53971 Mdot
.486 .53972 Mdot
.486 .53972 Mdot
.486 .53975 Mdot
.486 .53994 Mdot
.486 .53998 Mdot
.486 .53999 Mdot
.486 .54001 Mdot
.486 .54004 Mdot
.486 .54005 Mdot
.486 .54006 Mdot
.486 .54013 Mdot
.486 .54036 Mdot
.486 .54036 Mdot
.486 .5404 Mdot
.486 .54045 Mdot
.486 .54047 Mdot
.486 .54051 Mdot
.486 .54053 Mdot
.486 .54055 Mdot
.486 .5406 Mdot
.486 .54063 Mdot
.486 .54076 Mdot
.486 .54088 Mdot
.486 .54106 Mdot
.486 .54106 Mdot
.486 .54117 Mdot
.486 .54119 Mdot
.486 .5412 Mdot
.486 .54123 Mdot
.486 .54124 Mdot
.486 .54132 Mdot
.486 .54137 Mdot
.486 .54146 Mdot
.486 .54149 Mdot
.486 .54152 Mdot
.486 .54158 Mdot
.486 .54159 Mdot
.486 .54163 Mdot
.486 .54163 Mdot
.486 .54169 Mdot
.486 .5417 Mdot
.486 .54182 Mdot
.486 .54185 Mdot
.486 .54185 Mdot
.486 .54193 Mdot
.486 .54194 Mdot
.486 .54195 Mdot
.486 .54197 Mdot
.486 .54199 Mdot
.486 .54203 Mdot
.486 .54204 Mdot
.486 .54204 Mdot
.486 .54205 Mdot
.486 .54208 Mdot
.486 .5421 Mdot
.486 .54213 Mdot
.486 .54214 Mdot
.486 .54214 Mdot
.486 .54223 Mdot
.486 .54226 Mdot
.486 .54227 Mdot
.486 .5423 Mdot
.486 .54235 Mdot
.486 .54237 Mdot
.486 .54238 Mdot
.486 .54239 Mdot
.486 .54239 Mdot
.486 .54265 Mdot
.486 .54265 Mdot
.486 .54266 Mdot
.486 .54267 Mdot
.486 .54267 Mdot
.486 .54267 Mdot
.486 .54269 Mdot
.486 .54271 Mdot
.486 .54274 Mdot
.486 .54274 Mdot
.486 .54276 Mdot
.486 .54276 Mdot
.486 .54277 Mdot
.486 .54278 Mdot
.486 .54278 Mdot
.486 .54278 Mdot
.486 .54279 Mdot
.486 .54279 Mdot
.486 .54281 Mdot
.486 .54281 Mdot
.486 .54281 Mdot
.488 .20896 Mdot
.488 .20896 Mdot
.488 .20898 Mdot
.488 .20899 Mdot
.488 .20899 Mdot
.488 .209 Mdot
.488 .20902 Mdot
.488 .2091 Mdot
.488 .20912 Mdot
.488 .20922 Mdot
.488 .20922 Mdot
.488 .20926 Mdot
.488 .20932 Mdot
.488 .20933 Mdot
.488 .20942 Mdot
.488 .20967 Mdot
.488 .20975 Mdot
.488 .2098 Mdot
.488 .20987 Mdot
.488 .2099 Mdot
.488 .20992 Mdot
.488 .20997 Mdot
.488 .20998 Mdot
.488 .21003 Mdot
.488 .2101 Mdot
.488 .21016 Mdot
.488 .21036 Mdot
.488 .21057 Mdot
.488 .21074 Mdot
.488 .2108 Mdot
.488 .21082 Mdot
.488 .21095 Mdot
.488 .2111 Mdot
.488 .21111 Mdot
.488 .21125 Mdot
.488 .21126 Mdot
.488 .21126 Mdot
.488 .21132 Mdot
.488 .21133 Mdot
.488 .21135 Mdot
.488 .21145 Mdot
.488 .21147 Mdot
.488 .21169 Mdot
.488 .21171 Mdot
.488 .21177 Mdot
.488 .21195 Mdot
.488 .21197 Mdot
.488 .21203 Mdot
.488 .21207 Mdot
.488 .21228 Mdot
.488 .21234 Mdot
.488 .21239 Mdot
.488 .21247 Mdot
.488 .21258 Mdot
.488 .21259 Mdot
.488 .21305 Mdot
.488 .21307 Mdot
.488 .21313 Mdot
.488 .21316 Mdot
.488 .2133 Mdot
.488 .21344 Mdot
.488 .21369 Mdot
.488 .21382 Mdot
.488 .21385 Mdot
.488 .21406 Mdot
.488 .2141 Mdot
.488 .21419 Mdot
.488 .21437 Mdot
.488 .21438 Mdot
.488 .2148 Mdot
.488 .2148 Mdot
.488 .21503 Mdot
.488 .21506 Mdot
.488 .21553 Mdot
.488 .21573 Mdot
.488 .21648 Mdot
.488 .21651 Mdot
.488 .21657 Mdot
.488 .2171 Mdot
.488 .21716 Mdot
.488 .21723 Mdot
.488 .2173 Mdot
.488 .2174 Mdot
.488 .21761 Mdot
.488 .21786 Mdot
.488 .21798 Mdot
.488 .21826 Mdot
.488 .21826 Mdot
.488 .21898 Mdot
.488 .21901 Mdot
.488 .21903 Mdot
.488 .21944 Mdot
.488 .21953 Mdot
.488 .21957 Mdot
.488 .21962 Mdot
.488 .21982 Mdot
.488 .21983 Mdot
.488 .2202 Mdot
.488 .22034 Mdot
.488 .22071 Mdot
.488 .22075 Mdot
.488 .22082 Mdot
.488 .2216 Mdot
.488 .22202 Mdot
.488 .22218 Mdot
.488 .22246 Mdot
.488 .22247 Mdot
.488 .22313 Mdot
.488 .22342 Mdot
.488 .2238 Mdot
.488 .224 Mdot
.488 .22406 Mdot
.488 .22428 Mdot
.488 .22459 Mdot
.488 .22481 Mdot
.488 .22483 Mdot
.488 .22496 Mdot
.488 .22503 Mdot
.488 .22503 Mdot
.488 .2252 Mdot
.488 .22537 Mdot
.488 .22552 Mdot
.488 .22554 Mdot
.488 .22561 Mdot
.488 .22645 Mdot
.488 .22657 Mdot
.488 .22675 Mdot
.488 .22677 Mdot
.488 .22683 Mdot
.488 .22694 Mdot
.488 .22703 Mdot
.488 .22814 Mdot
.488 .22826 Mdot
.488 .22914 Mdot
.488 .2293 Mdot
.488 .2293 Mdot
.488 .22933 Mdot
.488 .22945 Mdot
.488 .22973 Mdot
.488 .23002 Mdot
.488 .23116 Mdot
.488 .23124 Mdot
.488 .23161 Mdot
.488 .23193 Mdot
.488 .23194 Mdot
.488 .23218 Mdot
.488 .23272 Mdot
.488 .23327 Mdot
.488 .2333 Mdot
.488 .23359 Mdot
.488 .23388 Mdot
.488 .23417 Mdot
.488 .23429 Mdot
.488 .235 Mdot
.488 .23509 Mdot
.488 .23512 Mdot
.488 .23551 Mdot
.488 .23557 Mdot
.488 .23576 Mdot
.488 .23578 Mdot
.488 .23587 Mdot
.488 .23618 Mdot
.488 .23625 Mdot
.488 .23636 Mdot
.488 .23679 Mdot
.488 .23685 Mdot
.488 .23687 Mdot
.488 .23699 Mdot
.488 .23731 Mdot
.488 .23741 Mdot
.488 .23744 Mdot
.488 .23761 Mdot
.488 .23764 Mdot
.488 .2377 Mdot
.488 .23817 Mdot
.488 .23833 Mdot
.488 .23869 Mdot
.488 .23933 Mdot
.488 .23935 Mdot
.488 .23939 Mdot
.488 .23977 Mdot
.488 .23992 Mdot
.488 .24005 Mdot
.488 .24021 Mdot
.488 .24045 Mdot
.488 .24087 Mdot
.488 .24121 Mdot
.488 .24135 Mdot
.488 .24156 Mdot
.488 .24164 Mdot
.488 .24232 Mdot
.488 .24254 Mdot
.488 .24262 Mdot
.488 .24344 Mdot
.488 .24354 Mdot
.488 .24367 Mdot
.488 .24393 Mdot
.488 .244 Mdot
.488 .24403 Mdot
.488 .24427 Mdot
.488 .24427 Mdot
.488 .24431 Mdot
.488 .2447 Mdot
.488 .24476 Mdot
.488 .24484 Mdot
.488 .24488 Mdot
.488 .24547 Mdot
.488 .24552 Mdot
.488 .24598 Mdot
.488 .24598 Mdot
.488 .24599 Mdot
.488 .24605 Mdot
.488 .2463 Mdot
.488 .24697 Mdot
.488 .24721 Mdot
.488 .24744 Mdot
.488 .24779 Mdot
.488 .24841 Mdot
.488 .24859 Mdot
.488 .24866 Mdot
.488 .24867 Mdot
.488 .24871 Mdot
.488 .24883 Mdot
.488 .24886 Mdot
.488 .24907 Mdot
.488 .2491 Mdot
.488 .24915 Mdot
.488 .24932 Mdot
.488 .24939 Mdot
.488 .24961 Mdot
.488 .24967 Mdot
.488 .24981 Mdot
.488 .25008 Mdot
.488 .25028 Mdot
.488 .25064 Mdot
.488 .25168 Mdot
.488 .25205 Mdot
.488 .25207 Mdot
.488 .25235 Mdot
.488 .25252 Mdot
.488 .25252 Mdot
.488 .25296 Mdot
.488 .25304 Mdot
.488 .25339 Mdot
.488 .25348 Mdot
.488 .25348 Mdot
.488 .25349 Mdot
.488 .25355 Mdot
.488 .25362 Mdot
.488 .25363 Mdot
.488 .26024 Mdot
.488 .26026 Mdot
.488 .2604 Mdot
.488 .26049 Mdot
.488 .26051 Mdot
.488 .26052 Mdot
.488 .26068 Mdot
.488 .2613 Mdot
.488 .26144 Mdot
.488 .26223 Mdot
.488 .26224 Mdot
.488 .26254 Mdot
.488 .26304 Mdot
.488 .26308 Mdot
.488 .26376 Mdot
.488 .26568 Mdot
.488 .26634 Mdot
.488 .26672 Mdot
.488 .26722 Mdot
.488 .26748 Mdot
.488 .2676 Mdot
.488 .26801 Mdot
.488 .26813 Mdot
.488 .26846 Mdot
.488 .26855 Mdot
.488 .26861 Mdot
.488 .26901 Mdot
.488 .26906 Mdot
.488 .26929 Mdot
.488 .26937 Mdot
.488 .26938 Mdot
.488 .26952 Mdot
.488 .26987 Mdot
.488 .27105 Mdot
.488 .27174 Mdot
.488 .27218 Mdot
.488 .27263 Mdot
.488 .27396 Mdot
.488 .27444 Mdot
.488 .27455 Mdot
.488 .27457 Mdot
.488 .27458 Mdot
.488 .27548 Mdot
.488 .27559 Mdot
.488 .27676 Mdot
.488 .27684 Mdot
.488 .277 Mdot
.488 .27711 Mdot
.488 .2779 Mdot
.488 .27797 Mdot
.488 .27799 Mdot
.488 .27845 Mdot
.488 .27851 Mdot
.488 .27867 Mdot
.488 .27919 Mdot
.488 .27946 Mdot
.488 .27966 Mdot
.488 .28133 Mdot
.488 .2815 Mdot
.488 .28195 Mdot
.488 .28334 Mdot
.488 .2835 Mdot
.488 .28393 Mdot
.488 .28423 Mdot
.488 .28494 Mdot
.488 .28583 Mdot
.488 .28633 Mdot
.488 .28666 Mdot
.488 .28694 Mdot
.488 .28725 Mdot
.488 .28805 Mdot
.488 .28813 Mdot
.488 .28818 Mdot
.488 .28954 Mdot
.488 .2903 Mdot
.488 .29066 Mdot
.488 .29165 Mdot
.488 .2918 Mdot
.488 .29186 Mdot
.488 .29223 Mdot
.488 .29228 Mdot
.488 .2925 Mdot
.488 .2932 Mdot
.488 .29345 Mdot
.488 .29351 Mdot
.488 .29363 Mdot
.488 .29456 Mdot
.488 .29481 Mdot
.488 .29497 Mdot
.488 .29564 Mdot
.488 .29584 Mdot
.488 .29589 Mdot
.488 .29629 Mdot
.488 .29643 Mdot
.488 .2973 Mdot
.488 .29735 Mdot
.488 .29755 Mdot
.488 .29913 Mdot
.488 .2994 Mdot
.488 .30004 Mdot
.488 .30069 Mdot
.488 .30134 Mdot
.488 .3014 Mdot
.488 .30264 Mdot
.488 .30388 Mdot
.488 .3044 Mdot
.488 .30443 Mdot
.488 .30515 Mdot
.488 .306 Mdot
.488 .30619 Mdot
.488 .3088 Mdot
.488 .30946 Mdot
.488 .31011 Mdot
.488 .3104 Mdot
.488 .31046 Mdot
.488 .31047 Mdot
.488 .31084 Mdot
.488 .31289 Mdot
.488 .31317 Mdot
.488 .31577 Mdot
.488 .31598 Mdot
.488 .31624 Mdot
.488 .31637 Mdot
.488 .31643 Mdot
.488 .31685 Mdot
.488 .31713 Mdot
.488 .31913 Mdot
.488 .3193 Mdot
.488 .31935 Mdot
.488 .31971 Mdot
.488 .32011 Mdot
.488 .32014 Mdot
.488 .32051 Mdot
.488 .32052 Mdot
.488 .32067 Mdot
.488 .32098 Mdot
.488 .32105 Mdot
.488 .32155 Mdot
.488 .32231 Mdot
.488 .32284 Mdot
.488 .32298 Mdot
.488 .32346 Mdot
.488 .32437 Mdot
.488 .32508 Mdot
.488 .32668 Mdot
.488 .32669 Mdot
.488 .32738 Mdot
.488 .32777 Mdot
.488 .32879 Mdot
.488 .3307 Mdot
.488 .33087 Mdot
.488 .33097 Mdot
.488 .33186 Mdot
.488 .33221 Mdot
.488 .33313 Mdot
.488 .33315 Mdot
.488 .33364 Mdot
.488 .33376 Mdot
.488 .33386 Mdot
.488 .33409 Mdot
.488 .3351 Mdot
.488 .33515 Mdot
.488 .33523 Mdot
.488 .337 Mdot
.488 .33701 Mdot
.488 .33769 Mdot
.488 .33799 Mdot
.488 .33863 Mdot
.488 .33916 Mdot
.488 .33939 Mdot
.488 .33958 Mdot
.488 .33974 Mdot
.488 .3399 Mdot
.488 .34122 Mdot
.488 .34137 Mdot
.488 .34145 Mdot
.488 .34332 Mdot
.488 .34383 Mdot
.488 .34502 Mdot
.488 .34509 Mdot
.488 .34566 Mdot
.488 .34567 Mdot
.488 .34673 Mdot
.488 .34676 Mdot
.488 .34721 Mdot
.488 .34743 Mdot
.488 .34753 Mdot
.488 .34808 Mdot
.488 .34815 Mdot
.488 .34847 Mdot
.488 .34911 Mdot
.488 .34947 Mdot
.488 .34981 Mdot
.488 .34989 Mdot
.488 .35005 Mdot
.488 .3501 Mdot
.488 .35127 Mdot
.488 .35129 Mdot
.488 .35158 Mdot
.488 .35178 Mdot
.488 .35189 Mdot
.488 .35206 Mdot
.488 .35259 Mdot
.488 .35269 Mdot
.488 .35284 Mdot
.488 .35289 Mdot
.488 .35335 Mdot
.488 .3535 Mdot
.488 .35356 Mdot
.488 .35411 Mdot
.488 .35418 Mdot
.488 .35444 Mdot
.488 .35449 Mdot
.488 .35451 Mdot
.488 .35467 Mdot
.488 .35467 Mdot
.488 .3547 Mdot
.488 .35505 Mdot
.488 .35507 Mdot
.488 .35546 Mdot
.488 .3558 Mdot
.488 .35584 Mdot
.488 .356 Mdot
.488 .35644 Mdot
.488 .35696 Mdot
.488 .35747 Mdot
.488 .35762 Mdot
.488 .35782 Mdot
.488 .35793 Mdot
.488 .35797 Mdot
.488 .35811 Mdot
.488 .35815 Mdot
.488 .35823 Mdot
.488 .3584 Mdot
.488 .35852 Mdot
.488 .35874 Mdot
.488 .35938 Mdot
.488 .35961 Mdot
.488 .35962 Mdot
.488 .35979 Mdot
.488 .35989 Mdot
.488 .3599 Mdot
.488 .36016 Mdot
.488 .36021 Mdot
.488 .36042 Mdot
.488 .36047 Mdot
.488 .36047 Mdot
.488 .36048 Mdot
.488 .36051 Mdot
.488 .36056 Mdot
.488 .36056 Mdot
.488 .48198 Mdot
.488 .48198 Mdot
.488 .482 Mdot
.488 .48202 Mdot
.488 .48202 Mdot
.488 .48202 Mdot
.488 .48205 Mdot
.488 .48215 Mdot
.488 .48217 Mdot
.488 .48229 Mdot
.488 .4823 Mdot
.488 .48234 Mdot
.488 .48242 Mdot
.488 .48243 Mdot
.488 .48254 Mdot
.488 .48284 Mdot
.488 .48294 Mdot
.488 .483 Mdot
.488 .48308 Mdot
.488 .48312 Mdot
.488 .48314 Mdot
.488 .4832 Mdot
.488 .48322 Mdot
.488 .48327 Mdot
.488 .48337 Mdot
.488 .48344 Mdot
.488 .48368 Mdot
.488 .48392 Mdot
.488 .48413 Mdot
.488 .4842 Mdot
.488 .48422 Mdot
.488 .48438 Mdot
.488 .48456 Mdot
.488 .48457 Mdot
.488 .48474 Mdot
.488 .48475 Mdot
.488 .48475 Mdot
.488 .48482 Mdot
.488 .48483 Mdot
.488 .48486 Mdot
.488 .48498 Mdot
.488 .48501 Mdot
.488 .48527 Mdot
.488 .48529 Mdot
.488 .48536 Mdot
.488 .48558 Mdot
.488 .4856 Mdot
.488 .48567 Mdot
.488 .48572 Mdot
.488 .48596 Mdot
.488 .48604 Mdot
.488 .48609 Mdot
.488 .48618 Mdot
.488 .48632 Mdot
.488 .48633 Mdot
.488 .48687 Mdot
.488 .48689 Mdot
.488 .48697 Mdot
.488 .487 Mdot
.488 .48716 Mdot
.488 .48733 Mdot
.488 .48762 Mdot
.488 .48777 Mdot
.488 .4878 Mdot
.488 .48805 Mdot
.488 .48809 Mdot
.488 .48819 Mdot
.488 .4884 Mdot
.488 .48841 Mdot
.488 .4889 Mdot
.488 .4889 Mdot
.488 .48916 Mdot
.488 .48919 Mdot
.488 .48973 Mdot
.488 .48997 Mdot
.488 .49081 Mdot
.488 .49085 Mdot
.488 .49092 Mdot
.488 .49151 Mdot
.488 .49158 Mdot
.488 .49165 Mdot
.488 .49174 Mdot
.488 .49184 Mdot
.488 .49208 Mdot
.488 .49236 Mdot
.488 .4925 Mdot
.488 .4928 Mdot
.488 .4928 Mdot
.488 .4936 Mdot
.488 .49363 Mdot
.488 .49365 Mdot
.488 .4941 Mdot
.488 .4942 Mdot
.488 .49425 Mdot
.488 .4943 Mdot
.488 .49451 Mdot
.488 .49452 Mdot
.488 .49493 Mdot
.488 .49509 Mdot
.488 .49547 Mdot
.488 .49552 Mdot
.488 .4956 Mdot
.488 .49643 Mdot
.488 .49688 Mdot
.488 .49705 Mdot
.488 .49735 Mdot
.488 .49735 Mdot
.488 .49805 Mdot
.488 .49836 Mdot
.488 .49875 Mdot
.488 .49896 Mdot
.488 .49902 Mdot
.488 .49924 Mdot
.488 .49957 Mdot
.488 .49979 Mdot
.488 .49982 Mdot
.488 .49995 Mdot
.488 .50002 Mdot
.488 .50002 Mdot
.488 .50019 Mdot
.488 .50036 Mdot
.488 .50052 Mdot
.488 .50054 Mdot
.488 .50061 Mdot
.488 .50146 Mdot
.488 .50158 Mdot
.488 .50176 Mdot
.488 .50179 Mdot
.488 .50184 Mdot
.488 .50196 Mdot
.488 .50204 Mdot
.488 .50314 Mdot
.488 .50326 Mdot
.488 .50412 Mdot
.488 .50428 Mdot
.488 .50428 Mdot
.488 .50431 Mdot
.488 .50443 Mdot
.488 .5047 Mdot
.488 .50498 Mdot
.488 .50607 Mdot
.488 .50615 Mdot
.488 .5065 Mdot
.488 .5068 Mdot
.488 .50681 Mdot
.488 .50703 Mdot
.488 .50754 Mdot
.488 .50805 Mdot
.488 .50808 Mdot
.488 .50834 Mdot
.488 .50861 Mdot
.488 .50887 Mdot
.488 .50898 Mdot
.488 .50963 Mdot
.488 .50971 Mdot
.488 .50973 Mdot
.488 .51009 Mdot
.488 .51014 Mdot
.488 .51031 Mdot
.488 .51033 Mdot
.488 .51041 Mdot
.488 .51068 Mdot
.488 .51075 Mdot
.488 .51085 Mdot
.488 .51123 Mdot
.488 .51128 Mdot
.488 .5113 Mdot
.488 .5114 Mdot
.488 .51168 Mdot
.488 .51177 Mdot
.488 .51179 Mdot
.488 .51194 Mdot
.488 .51197 Mdot
.488 .51203 Mdot
.488 .51243 Mdot
.488 .51257 Mdot
.488 .51288 Mdot
.488 .51342 Mdot
.488 .51344 Mdot
.488 .51348 Mdot
.488 .5138 Mdot
.488 .51392 Mdot
.488 .51403 Mdot
.488 .51417 Mdot
.488 .51437 Mdot
.488 .51472 Mdot
.488 .515 Mdot
.488 .51512 Mdot
.488 .51529 Mdot
.488 .51536 Mdot
.488 .51591 Mdot
.488 .51609 Mdot
.488 .51615 Mdot
.488 .51681 Mdot
.488 .51689 Mdot
.488 .517 Mdot
.488 .5172 Mdot
.488 .51726 Mdot
.488 .51729 Mdot
.488 .51747 Mdot
.488 .51748 Mdot
.488 .51751 Mdot
.488 .51782 Mdot
.488 .51786 Mdot
.488 .51792 Mdot
.488 .51795 Mdot
.488 .51841 Mdot
.488 .51845 Mdot
.488 .51881 Mdot
.488 .51881 Mdot
.488 .51882 Mdot
.488 .51886 Mdot
.488 .51905 Mdot
.488 .51957 Mdot
.488 .51974 Mdot
.488 .51991 Mdot
.488 .52018 Mdot
.488 .52064 Mdot
.488 .52077 Mdot
.488 .52083 Mdot
.488 .52083 Mdot
.488 .52086 Mdot
.488 .52095 Mdot
.488 .52097 Mdot
.488 .52113 Mdot
.488 .52115 Mdot
.488 .52118 Mdot
.488 .52131 Mdot
.488 .52136 Mdot
.488 .52152 Mdot
.488 .52156 Mdot
.488 .52166 Mdot
.488 .52186 Mdot
.488 .522 Mdot
.488 .52226 Mdot
.488 .52299 Mdot
.488 .52325 Mdot
.488 .52327 Mdot
.488 .52346 Mdot
.488 .52357 Mdot
.488 .52358 Mdot
.488 .52388 Mdot
.488 .52393 Mdot
.488 .52417 Mdot
.488 .52423 Mdot
.488 .52423 Mdot
.488 .52424 Mdot
.488 .52428 Mdot
.488 .52433 Mdot
.488 .52434 Mdot
.488 .52684 Mdot
.488 .52684 Mdot
.488 .52687 Mdot
.488 .52689 Mdot
.488 .52689 Mdot
.488 .5269 Mdot
.488 .52693 Mdot
.488 .52706 Mdot
.488 .52709 Mdot
.488 .52725 Mdot
.488 .52726 Mdot
.488 .52732 Mdot
.488 .52742 Mdot
.488 .52743 Mdot
.488 .52757 Mdot
.488 .52796 Mdot
.488 .5281 Mdot
.488 .52817 Mdot
.488 .52827 Mdot
.488 .52832 Mdot
.488 .52835 Mdot
.488 .52843 Mdot
.488 .52845 Mdot
.488 .52852 Mdot
.488 .52854 Mdot
.488 .52855 Mdot
.488 .52863 Mdot
.488 .52864 Mdot
.488 .52868 Mdot
.488 .5287 Mdot
.488 .5287 Mdot
.488 .52873 Mdot
.488 .52879 Mdot
.488 .52902 Mdot
.488 .52916 Mdot
.488 .52924 Mdot
.488 .52933 Mdot
.488 .52958 Mdot
.488 .52967 Mdot
.488 .52969 Mdot
.488 .5297 Mdot
.488 .5297 Mdot
.488 .52987 Mdot
.488 .52989 Mdot
.488 .53011 Mdot
.488 .53012 Mdot
.488 .53015 Mdot
.488 .53017 Mdot
.488 .53032 Mdot
.488 .53033 Mdot
.488 .53033 Mdot
.488 .53042 Mdot
.488 .53043 Mdot
.488 .53046 Mdot
.488 .53055 Mdot
.488 .5306 Mdot
.488 .53064 Mdot
.488 .53094 Mdot
.488 .53097 Mdot
.488 .53106 Mdot
.488 .5313 Mdot
.488 .53133 Mdot
.488 .53141 Mdot
.488 .53146 Mdot
.488 .53159 Mdot
.488 .53174 Mdot
.488 .53183 Mdot
.488 .53189 Mdot
.488 .53194 Mdot
.488 .53199 Mdot
.488 .53213 Mdot
.488 .53215 Mdot
.488 .53215 Mdot
.488 .53239 Mdot
.488 .53252 Mdot
.488 .53258 Mdot
.488 .53275 Mdot
.488 .53278 Mdot
.488 .53279 Mdot
.488 .53285 Mdot
.488 .53286 Mdot
.488 .53289 Mdot
.488 .53301 Mdot
.488 .53306 Mdot
.488 .53307 Mdot
.488 .53309 Mdot
.488 .53324 Mdot
.488 .53328 Mdot
.488 .53331 Mdot
.488 .53342 Mdot
.488 .53346 Mdot
.488 .53346 Mdot
.488 .53353 Mdot
.488 .53355 Mdot
.488 .5337 Mdot
.488 .53371 Mdot
.488 .53374 Mdot
.488 .534 Mdot
.488 .53404 Mdot
.488 .53415 Mdot
.488 .53425 Mdot
.488 .53436 Mdot
.488 .53437 Mdot
.488 .53457 Mdot
.488 .53477 Mdot
.488 .53485 Mdot
.488 .53486 Mdot
.488 .53497 Mdot
.488 .53511 Mdot
.488 .53514 Mdot
.488 .53555 Mdot
.488 .53565 Mdot
.488 .53575 Mdot
.488 .5358 Mdot
.488 .53581 Mdot
.488 .53581 Mdot
.488 .53587 Mdot
.488 .53619 Mdot
.488 .53623 Mdot
.488 .53663 Mdot
.488 .53666 Mdot
.488 .5367 Mdot
.488 .53672 Mdot
.488 .53673 Mdot
.488 .53679 Mdot
.488 .53684 Mdot
.488 .53714 Mdot
.488 .53717 Mdot
.488 .53717 Mdot
.488 .53723 Mdot
.488 .53729 Mdot
.488 .53735 Mdot
.488 .53735 Mdot
.488 .53737 Mdot
.488 .53742 Mdot
.488 .53743 Mdot
.488 .5375 Mdot
.488 .53762 Mdot
.488 .5377 Mdot
.488 .53772 Mdot
.488 .53779 Mdot
.488 .53792 Mdot
.488 .53803 Mdot
.488 .53827 Mdot
.488 .53827 Mdot
.488 .53837 Mdot
.488 .53843 Mdot
.488 .53858 Mdot
.488 .53885 Mdot
.488 .53888 Mdot
.488 .53889 Mdot
.488 .53902 Mdot
.488 .53907 Mdot
.488 .53921 Mdot
.488 .53921 Mdot
.488 .53928 Mdot
.488 .5393 Mdot
.488 .53931 Mdot
.488 .53935 Mdot
.488 .53949 Mdot
.488 .5395 Mdot
.488 .53951 Mdot
.488 .53976 Mdot
.488 .53977 Mdot
.488 .53986 Mdot
.488 .53991 Mdot
.488 .54 Mdot
.488 .54007 Mdot
.488 .54011 Mdot
.488 .54013 Mdot
.488 .54016 Mdot
.488 .54018 Mdot
.488 .54036 Mdot
.488 .54039 Mdot
.488 .5404 Mdot
.488 .54066 Mdot
.488 .54073 Mdot
.488 .5409 Mdot
.488 .54091 Mdot
.488 .54099 Mdot
.488 .54099 Mdot
.488 .54114 Mdot
.488 .54114 Mdot
.488 .54121 Mdot
.488 .54124 Mdot
.488 .54125 Mdot
.488 .54133 Mdot
.488 .54134 Mdot
.488 .54138 Mdot
.488 .54147 Mdot
.488 .54152 Mdot
.488 .54157 Mdot
.488 .54158 Mdot
.488 .5416 Mdot
.488 .54161 Mdot
.488 .54177 Mdot
.488 .54177 Mdot
.488 .54181 Mdot
.488 .54184 Mdot
.488 .54186 Mdot
.488 .54188 Mdot
.488 .54195 Mdot
.488 .54197 Mdot
.488 .54199 Mdot
.488 .542 Mdot
.488 .54206 Mdot
.488 .54208 Mdot
.488 .54209 Mdot
.488 .54216 Mdot
.488 .54217 Mdot
.488 .54221 Mdot
.488 .54222 Mdot
.488 .54222 Mdot
.488 .54224 Mdot
.488 .54224 Mdot
.488 .54224 Mdot
.488 .54229 Mdot
.488 .5423 Mdot
.488 .54235 Mdot
.488 .54239 Mdot
.488 .5424 Mdot
.488 .54242 Mdot
.488 .54248 Mdot
.488 .54255 Mdot
.488 .54262 Mdot
.488 .54264 Mdot
.488 .54267 Mdot
.488 .54269 Mdot
.488 .54269 Mdot
.488 .54271 Mdot
.488 .54272 Mdot
.488 .54273 Mdot
.488 .54275 Mdot
.488 .54277 Mdot
.488 .5428 Mdot
.488 .54288 Mdot
.488 .54292 Mdot
.488 .54292 Mdot
.488 .54294 Mdot
.488 .54295 Mdot
.488 .54295 Mdot
.488 .54299 Mdot
.488 .543 Mdot
.488 .54303 Mdot
.488 .54303 Mdot
.488 .54303 Mdot
.488 .54303 Mdot
.488 .54304 Mdot
.488 .54304 Mdot
.488 .54305 Mdot
.49 .20838 Mdot
.49 .2084 Mdot
.49 .20847 Mdot
.49 .20847 Mdot
.49 .20851 Mdot
.49 .20851 Mdot
.49 .20853 Mdot
.49 .20854 Mdot
.49 .20855 Mdot
.49 .20856 Mdot
.49 .20859 Mdot
.49 .2086 Mdot
.49 .20861 Mdot
.49 .20862 Mdot
.49 .20863 Mdot
.49 .20864 Mdot
.49 .20871 Mdot
.49 .20871 Mdot
.49 .20879 Mdot
.49 .20882 Mdot
.49 .20883 Mdot
.49 .20886 Mdot
.49 .20891 Mdot
.49 .20893 Mdot
.49 .20901 Mdot
.49 .20905 Mdot
.49 .2092 Mdot
.49 .20925 Mdot
.49 .20934 Mdot
.49 .20941 Mdot
.49 .20977 Mdot
.49 .20996 Mdot
.49 .21004 Mdot
.49 .2102 Mdot
.49 .21021 Mdot
.49 .21025 Mdot
.49 .21039 Mdot
.49 .21049 Mdot
.49 .2107 Mdot
.49 .21101 Mdot
.49 .21105 Mdot
.49 .21112 Mdot
.49 .21118 Mdot
.49 .21145 Mdot
.49 .21156 Mdot
.49 .21161 Mdot
.49 .21164 Mdot
.49 .21182 Mdot
.49 .21264 Mdot
.49 .21265 Mdot
.49 .21278 Mdot
.49 .21302 Mdot
.49 .21332 Mdot
.49 .21337 Mdot
.49 .21388 Mdot
.49 .21433 Mdot
.49 .21446 Mdot
.49 .21452 Mdot
.49 .2147 Mdot
.49 .21477 Mdot
.49 .21481 Mdot
.49 .21488 Mdot
.49 .21555 Mdot
.49 .21568 Mdot
.49 .21569 Mdot
.49 .21573 Mdot
.49 .21596 Mdot
.49 .21603 Mdot
.49 .21631 Mdot
.49 .21667 Mdot
.49 .21674 Mdot
.49 .21762 Mdot
.49 .21782 Mdot
.49 .2182 Mdot
.49 .21846 Mdot
.49 .21853 Mdot
.49 .21896 Mdot
.49 .21904 Mdot
.49 .21921 Mdot
.49 .21932 Mdot
.49 .21944 Mdot
.49 .21965 Mdot
.49 .21981 Mdot
.49 .22 Mdot
.49 .2201 Mdot
.49 .22056 Mdot
.49 .2206 Mdot
.49 .22079 Mdot
.49 .22095 Mdot
.49 .22112 Mdot
.49 .22115 Mdot
.49 .22115 Mdot
.49 .22123 Mdot
.49 .22169 Mdot
.49 .22174 Mdot
.49 .22197 Mdot
.49 .22265 Mdot
.49 .22313 Mdot
.49 .22314 Mdot
.49 .22399 Mdot
.49 .22403 Mdot
.49 .22437 Mdot
.49 .2245 Mdot
.49 .22453 Mdot
.49 .22508 Mdot
.49 .22535 Mdot
.49 .22539 Mdot
.49 .2254 Mdot
.49 .2256 Mdot
.49 .22647 Mdot
.49 .22658 Mdot
.49 .22738 Mdot
.49 .22757 Mdot
.49 .22758 Mdot
.49 .22786 Mdot
.49 .2281 Mdot
.49 .22815 Mdot
.49 .22823 Mdot
.49 .22835 Mdot
.49 .22838 Mdot
.49 .22876 Mdot
.49 .22917 Mdot
.49 .23009 Mdot
.49 .23077 Mdot
.49 .23097 Mdot
.49 .23099 Mdot
.49 .23105 Mdot
.49 .23111 Mdot
.49 .23132 Mdot
.49 .23136 Mdot
.49 .23147 Mdot
.49 .23167 Mdot
.49 .23188 Mdot
.49 .23206 Mdot
.49 .23222 Mdot
.49 .23241 Mdot
.49 .23249 Mdot
.49 .23277 Mdot
.49 .23286 Mdot
.49 .23369 Mdot
.49 .23395 Mdot
.49 .2345 Mdot
.49 .23485 Mdot
.49 .23531 Mdot
.49 .23564 Mdot
.49 .23583 Mdot
.49 .236 Mdot
.49 .23684 Mdot
.49 .23704 Mdot
.49 .23732 Mdot
.49 .23771 Mdot
.49 .23814 Mdot
.49 .23818 Mdot
.49 .23838 Mdot
.49 .23843 Mdot
.49 .23916 Mdot
.49 .24069 Mdot
.49 .24102 Mdot
.49 .24117 Mdot
.49 .24135 Mdot
.49 .2416 Mdot
.49 .24185 Mdot
.49 .24187 Mdot
.49 .24197 Mdot
.49 .24216 Mdot
.49 .24216 Mdot
.49 .2422 Mdot
.49 .24244 Mdot
.49 .24258 Mdot
.49 .24316 Mdot
.49 .24358 Mdot
.49 .2436 Mdot
.49 .24376 Mdot
.49 .24382 Mdot
.49 .24384 Mdot
.49 .24409 Mdot
.49 .24422 Mdot
.49 .24424 Mdot
.49 .24474 Mdot
.49 .24523 Mdot
.49 .24536 Mdot
.49 .24546 Mdot
.49 .24549 Mdot
.49 .24593 Mdot
.49 .24632 Mdot
.49 .24669 Mdot
.49 .24673 Mdot
.49 .24685 Mdot
.49 .2469 Mdot
.49 .24699 Mdot
.49 .24721 Mdot
.49 .24729 Mdot
.49 .24743 Mdot
.49 .24747 Mdot
.49 .24781 Mdot
.49 .24813 Mdot
.49 .24827 Mdot
.49 .24845 Mdot
.49 .24872 Mdot
.49 .24913 Mdot
.49 .24924 Mdot
.49 .24964 Mdot
.49 .24966 Mdot
.49 .24994 Mdot
.49 .25051 Mdot
.49 .25063 Mdot
.49 .25076 Mdot
.49 .25085 Mdot
.49 .25095 Mdot
.49 .25105 Mdot
.49 .25107 Mdot
.49 .25116 Mdot
.49 .25142 Mdot
.49 .25157 Mdot
.49 .25164 Mdot
.49 .25166 Mdot
.49 .2518 Mdot
.49 .25199 Mdot
.49 .25217 Mdot
.49 .25221 Mdot
.49 .25225 Mdot
.49 .25242 Mdot
.49 .25275 Mdot
.49 .25276 Mdot
.49 .25279 Mdot
.49 .25287 Mdot
.49 .25308 Mdot
.49 .25323 Mdot
.49 .25325 Mdot
.49 .2534 Mdot
.49 .25355 Mdot
.49 .25373 Mdot
.49 .25373 Mdot
.49 .25383 Mdot
.49 .25403 Mdot
.49 .25407 Mdot
.49 .25414 Mdot
.49 .25418 Mdot
.49 .25422 Mdot
.49 .25425 Mdot
.49 .25439 Mdot
.49 .25442 Mdot
.49 .25447 Mdot
.49 .25454 Mdot
.49 .2546 Mdot
.49 .25462 Mdot
.49 .2548 Mdot
.49 .2548 Mdot
.49 .25507 Mdot
.49 .25517 Mdot
.49 .25705 Mdot
.49 .25722 Mdot
.49 .25769 Mdot
.49 .2577 Mdot
.49 .25802 Mdot
.49 .25805 Mdot
.49 .25815 Mdot
.49 .25827 Mdot
.49 .25835 Mdot
.49 .25841 Mdot
.49 .25866 Mdot
.49 .25871 Mdot
.49 .25879 Mdot
.49 .25885 Mdot
.49 .25898 Mdot
.49 .25906 Mdot
.49 .25941 Mdot
.49 .25958 Mdot
.49 .25959 Mdot
.49 .25991 Mdot
.49 .26016 Mdot
.49 .26044 Mdot
.49 .26047 Mdot
.49 .26074 Mdot
.49 .26112 Mdot
.49 .26126 Mdot
.49 .26131 Mdot
.49 .26134 Mdot
.49 .26143 Mdot
.49 .26194 Mdot
.49 .26224 Mdot
.49 .26231 Mdot
.49 .26239 Mdot
.49 .26271 Mdot
.49 .26305 Mdot
.49 .26332 Mdot
.49 .26336 Mdot
.49 .26348 Mdot
.49 .26376 Mdot
.49 .26424 Mdot
.49 .2644 Mdot
.49 .26443 Mdot
.49 .26463 Mdot
.49 .26481 Mdot
.49 .26498 Mdot
.49 .26521 Mdot
.49 .26544 Mdot
.49 .26651 Mdot
.49 .26702 Mdot
.49 .26706 Mdot
.49 .26783 Mdot
.49 .26803 Mdot
.49 .2688 Mdot
.49 .26932 Mdot
.49 .26966 Mdot
.49 .26993 Mdot
.49 .27055 Mdot
.49 .2712 Mdot
.49 .27127 Mdot
.49 .27156 Mdot
.49 .27171 Mdot
.49 .27214 Mdot
.49 .27231 Mdot
.49 .2724 Mdot
.49 .27265 Mdot
.49 .27272 Mdot
.49 .27344 Mdot
.49 .27421 Mdot
.49 .27509 Mdot
.49 .27514 Mdot
.49 .27534 Mdot
.49 .27559 Mdot
.49 .27659 Mdot
.49 .27758 Mdot
.49 .27762 Mdot
.49 .27788 Mdot
.49 .2784 Mdot
.49 .27843 Mdot
.49 .27855 Mdot
.49 .27888 Mdot
.49 .27892 Mdot
.49 .27977 Mdot
.49 .28096 Mdot
.49 .28125 Mdot
.49 .28174 Mdot
.49 .28182 Mdot
.49 .28183 Mdot
.49 .28221 Mdot
.49 .28242 Mdot
.49 .28247 Mdot
.49 .28297 Mdot
.49 .28349 Mdot
.49 .28386 Mdot
.49 .28419 Mdot
.49 .28488 Mdot
.49 .28811 Mdot
.49 .28966 Mdot
.49 .28976 Mdot
.49 .2902 Mdot
.49 .29029 Mdot
.49 .29121 Mdot
.49 .29205 Mdot
.49 .29266 Mdot
.49 .2931 Mdot
.49 .29494 Mdot
.49 .29532 Mdot
.49 .29573 Mdot
.49 .29646 Mdot
.49 .29747 Mdot
.49 .29825 Mdot
.49 .29947 Mdot
.49 .30006 Mdot
.49 .30193 Mdot
.49 .30214 Mdot
.49 .30276 Mdot
.49 .30295 Mdot
.49 .30337 Mdot
.49 .30373 Mdot
.49 .30415 Mdot
.49 .30461 Mdot
.49 .30508 Mdot
.49 .30534 Mdot
.49 .30542 Mdot
.49 .30591 Mdot
.49 .30605 Mdot
.49 .30619 Mdot
.49 .30622 Mdot
.49 .30669 Mdot
.49 .30825 Mdot
.49 .31037 Mdot
.49 .31132 Mdot
.49 .31222 Mdot
.49 .31229 Mdot
.49 .31256 Mdot
.49 .31275 Mdot
.49 .31288 Mdot
.49 .31343 Mdot
.49 .3141 Mdot
.49 .31412 Mdot
.49 .31456 Mdot
.49 .31645 Mdot
.49 .31671 Mdot
.49 .31879 Mdot
.49 .31926 Mdot
.49 .31928 Mdot
.49 .31938 Mdot
.49 .32003 Mdot
.49 .32133 Mdot
.49 .32142 Mdot
.49 .32171 Mdot
.49 .32254 Mdot
.49 .32265 Mdot
.49 .32469 Mdot
.49 .32471 Mdot
.49 .32589 Mdot
.49 .32754 Mdot
.49 .3281 Mdot
.49 .32821 Mdot
.49 .32935 Mdot
.49 .32953 Mdot
.49 .32955 Mdot
.49 .3296 Mdot
.49 .33002 Mdot
.49 .33041 Mdot
.49 .33089 Mdot
.49 .33099 Mdot
.49 .33211 Mdot
.49 .33237 Mdot
.49 .33283 Mdot
.49 .33324 Mdot
.49 .33374 Mdot
.49 .33404 Mdot
.49 .33431 Mdot
.49 .33473 Mdot
.49 .33494 Mdot
.49 .336 Mdot
.49 .33618 Mdot
.49 .33683 Mdot
.49 .33777 Mdot
.49 .33827 Mdot
.49 .34046 Mdot
.49 .34064 Mdot
.49 .34155 Mdot
.49 .34226 Mdot
.49 .34243 Mdot
.49 .34301 Mdot
.49 .34311 Mdot
.49 .34314 Mdot
.49 .34347 Mdot
.49 .34515 Mdot
.49 .34533 Mdot
.49 .34543 Mdot
.49 .3456 Mdot
.49 .34605 Mdot
.49 .3462 Mdot
.49 .34654 Mdot
.49 .34768 Mdot
.49 .34897 Mdot
.49 .34911 Mdot
.49 .34985 Mdot
.49 .35049 Mdot
.49 .3508 Mdot
.49 .35083 Mdot
.49 .35293 Mdot
.49 .35339 Mdot
.49 .35348 Mdot
.49 .3536 Mdot
.49 .35389 Mdot
.49 .35457 Mdot
.49 .35473 Mdot
.49 .3549 Mdot
.49 .35499 Mdot
.49 .35581 Mdot
.49 .35635 Mdot
.49 .35659 Mdot
.49 .35697 Mdot
.49 .35706 Mdot
.49 .35708 Mdot
.49 .3575 Mdot
.49 .3577 Mdot
.49 .35819 Mdot
.49 .35913 Mdot
.49 .35931 Mdot
.49 .35953 Mdot
.49 .35966 Mdot
.49 .36004 Mdot
.49 .36014 Mdot
.49 .36036 Mdot
.49 .36041 Mdot
.49 .36053 Mdot
.49 .36062 Mdot
.49 .36063 Mdot
.49 .36073 Mdot
.49 .36092 Mdot
.49 .36092 Mdot
.49 .3611 Mdot
.49 .36112 Mdot
.49 .36117 Mdot
.49 .36119 Mdot
.49 .36121 Mdot
.49 .36123 Mdot
.49 .36131 Mdot
.49 .36133 Mdot
.49 .36136 Mdot
.49 .3614 Mdot
.49 .36143 Mdot
.49 .36144 Mdot
.49 .36155 Mdot
.49 .36156 Mdot
.49 .36171 Mdot
.49 .36177 Mdot
.49 .48148 Mdot
.49 .48151 Mdot
.49 .48158 Mdot
.49 .48158 Mdot
.49 .48163 Mdot
.49 .48164 Mdot
.49 .48166 Mdot
.49 .48167 Mdot
.49 .48169 Mdot
.49 .4817 Mdot
.49 .48174 Mdot
.49 .48174 Mdot
.49 .48176 Mdot
.49 .48177 Mdot
.49 .48179 Mdot
.49 .4818 Mdot
.49 .48188 Mdot
.49 .48188 Mdot
.49 .48197 Mdot
.49 .48202 Mdot
.49 .48202 Mdot
.49 .48207 Mdot
.49 .48212 Mdot
.49 .48215 Mdot
.49 .48225 Mdot
.49 .4823 Mdot
.49 .48248 Mdot
.49 .48254 Mdot
.49 .48264 Mdot
.49 .48273 Mdot
.49 .48317 Mdot
.49 .4834 Mdot
.49 .4835 Mdot
.49 .48369 Mdot
.49 .4837 Mdot
.49 .48375 Mdot
.49 .48392 Mdot
.49 .48404 Mdot
.49 .48429 Mdot
.49 .48467 Mdot
.49 .48471 Mdot
.49 .48479 Mdot
.49 .48487 Mdot
.49 .48518 Mdot
.49 .48532 Mdot
.49 .48538 Mdot
.49 .48542 Mdot
.49 .48563 Mdot
.49 .4866 Mdot
.49 .48662 Mdot
.49 .48676 Mdot
.49 .48705 Mdot
.49 .48739 Mdot
.49 .48746 Mdot
.49 .48805 Mdot
.49 .48857 Mdot
.49 .48872 Mdot
.49 .48879 Mdot
.49 .489 Mdot
.49 .48908 Mdot
.49 .48912 Mdot
.49 .4892 Mdot
.49 .48997 Mdot
.49 .49012 Mdot
.49 .49013 Mdot
.49 .49017 Mdot
.49 .49043 Mdot
.49 .49051 Mdot
.49 .49083 Mdot
.49 .49124 Mdot
.49 .49132 Mdot
.49 .4923 Mdot
.49 .49253 Mdot
.49 .49295 Mdot
.49 .49324 Mdot
.49 .49332 Mdot
.49 .49378 Mdot
.49 .49388 Mdot
.49 .49407 Mdot
.49 .49418 Mdot
.49 .49432 Mdot
.49 .49454 Mdot
.49 .49472 Mdot
.49 .49492 Mdot
.49 .49504 Mdot
.49 .49553 Mdot
.49 .49557 Mdot
.49 .49578 Mdot
.49 .49596 Mdot
.49 .49614 Mdot
.49 .49616 Mdot
.49 .49617 Mdot
.49 .49625 Mdot
.49 .49675 Mdot
.49 .49679 Mdot
.49 .49704 Mdot
.49 .49776 Mdot
.49 .49827 Mdot
.49 .49828 Mdot
.49 .49916 Mdot
.49 .4992 Mdot
.49 .49956 Mdot
.49 .49969 Mdot
.49 .49973 Mdot
.49 .50028 Mdot
.49 .50056 Mdot
.49 .5006 Mdot
.49 .50061 Mdot
.49 .50081 Mdot
.49 .5017 Mdot
.49 .50181 Mdot
.49 .50261 Mdot
.49 .5028 Mdot
.49 .50281 Mdot
.49 .50309 Mdot
.49 .50332 Mdot
.49 .50338 Mdot
.49 .50346 Mdot
.49 .50357 Mdot
.49 .5036 Mdot
.49 .50398 Mdot
.49 .50438 Mdot
.49 .50526 Mdot
.49 .50591 Mdot
.49 .50611 Mdot
.49 .50612 Mdot
.49 .50618 Mdot
.49 .50624 Mdot
.49 .50644 Mdot
.49 .50648 Mdot
.49 .50658 Mdot
.49 .50678 Mdot
.49 .50697 Mdot
.49 .50714 Mdot
.49 .50729 Mdot
.49 .50747 Mdot
.49 .50754 Mdot
.49 .5078 Mdot
.49 .50789 Mdot
.49 .50865 Mdot
.49 .5089 Mdot
.49 .5094 Mdot
.49 .50972 Mdot
.49 .51013 Mdot
.49 .51042 Mdot
.49 .51059 Mdot
.49 .51074 Mdot
.49 .51149 Mdot
.49 .51167 Mdot
.49 .51191 Mdot
.49 .51225 Mdot
.49 .51263 Mdot
.49 .51266 Mdot
.49 .51284 Mdot
.49 .51288 Mdot
.49 .5135 Mdot
.49 .51479 Mdot
.49 .51507 Mdot
.49 .51519 Mdot
.49 .51534 Mdot
.49 .51555 Mdot
.49 .51575 Mdot
.49 .51577 Mdot
.49 .51585 Mdot
.49 .516 Mdot
.49 .516 Mdot
.49 .51604 Mdot
.49 .51623 Mdot
.49 .51635 Mdot
.49 .51682 Mdot
.49 .51715 Mdot
.49 .51717 Mdot
.49 .5173 Mdot
.49 .51734 Mdot
.49 .51736 Mdot
.49 .51756 Mdot
.49 .51766 Mdot
.49 .51768 Mdot
.49 .51807 Mdot
.49 .51846 Mdot
.49 .51855 Mdot
.49 .51863 Mdot
.49 .51865 Mdot
.49 .51899 Mdot
.49 .5193 Mdot
.49 .51958 Mdot
.49 .5196 Mdot
.49 .5197 Mdot
.49 .51974 Mdot
.49 .5198 Mdot
.49 .51997 Mdot
.49 .52003 Mdot
.49 .52014 Mdot
.49 .52017 Mdot
.49 .52042 Mdot
.49 .52066 Mdot
.49 .52076 Mdot
.49 .5209 Mdot
.49 .5211 Mdot
.49 .52139 Mdot
.49 .52147 Mdot
.49 .52177 Mdot
.49 .52178 Mdot
.49 .52198 Mdot
.49 .52239 Mdot
.49 .52248 Mdot
.49 .52257 Mdot
.49 .52263 Mdot
.49 .5227 Mdot
.49 .52278 Mdot
.49 .52279 Mdot
.49 .52285 Mdot
.49 .52304 Mdot
.49 .52314 Mdot
.49 .52319 Mdot
.49 .5232 Mdot
.49 .52331 Mdot
.49 .52344 Mdot
.49 .52356 Mdot
.49 .52359 Mdot
.49 .52362 Mdot
.49 .52373 Mdot
.49 .52396 Mdot
.49 .52397 Mdot
.49 .52399 Mdot
.49 .52405 Mdot
.49 .52419 Mdot
.49 .52429 Mdot
.49 .5243 Mdot
.49 .52441 Mdot
.49 .5245 Mdot
.49 .52463 Mdot
.49 .52463 Mdot
.49 .52469 Mdot
.49 .52483 Mdot
.49 .52486 Mdot
.49 .52491 Mdot
.49 .52493 Mdot
.49 .52496 Mdot
.49 .52498 Mdot
.49 .52507 Mdot
.49 .52509 Mdot
.49 .52513 Mdot
.49 .52517 Mdot
.49 .52521 Mdot
.49 .52522 Mdot
.49 .52534 Mdot
.49 .52535 Mdot
.49 .52552 Mdot
.49 .52559 Mdot
.49 .5263 Mdot
.49 .52634 Mdot
.49 .52644 Mdot
.49 .52644 Mdot
.49 .52651 Mdot
.49 .52651 Mdot
.49 .52654 Mdot
.49 .52656 Mdot
.49 .52658 Mdot
.49 .52659 Mdot
.49 .52665 Mdot
.49 .52666 Mdot
.49 .52667 Mdot
.49 .52669 Mdot
.49 .52671 Mdot
.49 .52673 Mdot
.49 .5268 Mdot
.49 .52684 Mdot
.49 .52684 Mdot
.49 .52691 Mdot
.49 .52696 Mdot
.49 .52702 Mdot
.49 .52703 Mdot
.49 .52708 Mdot
.49 .52716 Mdot
.49 .52719 Mdot
.49 .5272 Mdot
.49 .52721 Mdot
.49 .52733 Mdot
.49 .5274 Mdot
.49 .52741 Mdot
.49 .52743 Mdot
.49 .52749 Mdot
.49 .52756 Mdot
.49 .52762 Mdot
.49 .52763 Mdot
.49 .52765 Mdot
.49 .52771 Mdot
.49 .52781 Mdot
.49 .52784 Mdot
.49 .52785 Mdot
.49 .52789 Mdot
.49 .52792 Mdot
.49 .52796 Mdot
.49 .528 Mdot
.49 .52805 Mdot
.49 .52826 Mdot
.49 .52837 Mdot
.49 .52837 Mdot
.49 .52852 Mdot
.49 .52856 Mdot
.49 .52872 Mdot
.49 .52882 Mdot
.49 .52888 Mdot
.49 .52894 Mdot
.49 .52906 Mdot
.49 .52918 Mdot
.49 .5292 Mdot
.49 .52925 Mdot
.49 .52928 Mdot
.49 .52936 Mdot
.49 .52939 Mdot
.49 .52941 Mdot
.49 .52946 Mdot
.49 .52947 Mdot
.49 .52961 Mdot
.49 .52976 Mdot
.49 .52992 Mdot
.49 .52993 Mdot
.49 .52997 Mdot
.49 .53001 Mdot
.49 .5302 Mdot
.49 .53038 Mdot
.49 .53039 Mdot
.49 .53044 Mdot
.49 .53053 Mdot
.49 .53054 Mdot
.49 .53056 Mdot
.49 .53062 Mdot
.49 .53063 Mdot
.49 .53078 Mdot
.49 .531 Mdot
.49 .53105 Mdot
.49 .53114 Mdot
.49 .53115 Mdot
.49 .53115 Mdot
.49 .53122 Mdot
.49 .53126 Mdot
.49 .53127 Mdot
.49 .53136 Mdot
.49 .53145 Mdot
.49 .53151 Mdot
.49 .53157 Mdot
.49 .53169 Mdot
.49 .53225 Mdot
.49 .53252 Mdot
.49 .53254 Mdot
.49 .53261 Mdot
.49 .53263 Mdot
.49 .53279 Mdot
.49 .53293 Mdot
.49 .53303 Mdot
.49 .5331 Mdot
.49 .53341 Mdot
.49 .53347 Mdot
.49 .53354 Mdot
.49 .53366 Mdot
.49 .53383 Mdot
.49 .53396 Mdot
.49 .53416 Mdot
.49 .53425 Mdot
.49 .53455 Mdot
.49 .53459 Mdot
.49 .53469 Mdot
.49 .53472 Mdot
.49 .53479 Mdot
.49 .53484 Mdot
.49 .53491 Mdot
.49 .53498 Mdot
.49 .53506 Mdot
.49 .5351 Mdot
.49 .53511 Mdot
.49 .53519 Mdot
.49 .53521 Mdot
.49 .53523 Mdot
.49 .53524 Mdot
.49 .53531 Mdot
.49 .53556 Mdot
.49 .53589 Mdot
.49 .53604 Mdot
.49 .53618 Mdot
.49 .53619 Mdot
.49 .53623 Mdot
.49 .53626 Mdot
.49 .53628 Mdot
.49 .53636 Mdot
.49 .53646 Mdot
.49 .53647 Mdot
.49 .53654 Mdot
.49 .53682 Mdot
.49 .53686 Mdot
.49 .53718 Mdot
.49 .53725 Mdot
.49 .53725 Mdot
.49 .53727 Mdot
.49 .53736 Mdot
.49 .53756 Mdot
.49 .53757 Mdot
.49 .53762 Mdot
.49 .53774 Mdot
.49 .53776 Mdot
.49 .53806 Mdot
.49 .53806 Mdot
.49 .53823 Mdot
.49 .53848 Mdot
.49 .53856 Mdot
.49 .53858 Mdot
.49 .53874 Mdot
.49 .53877 Mdot
.49 .53877 Mdot
.49 .53878 Mdot
.49 .53884 Mdot
.49 .5389 Mdot
.49 .53897 Mdot
.49 .53898 Mdot
.49 .53914 Mdot
.49 .53918 Mdot
.49 .53925 Mdot
.49 .53931 Mdot
.49 .53938 Mdot
.49 .53942 Mdot
.49 .53946 Mdot
.49 .53952 Mdot
.49 .53955 Mdot
.49 .5397 Mdot
.49 .53973 Mdot
.49 .53982 Mdot
.49 .53995 Mdot
.49 .54003 Mdot
.49 .54034 Mdot
.49 .54036 Mdot
.49 .54049 Mdot
.49 .54059 Mdot
.49 .54061 Mdot
.49 .54069 Mdot
.49 .54071 Mdot
.49 .54071 Mdot
.49 .54076 Mdot
.49 .54099 Mdot
.49 .54102 Mdot
.49 .54103 Mdot
.49 .54106 Mdot
.49 .54112 Mdot
.49 .54114 Mdot
.49 .54119 Mdot
.49 .54135 Mdot
.49 .54153 Mdot
.49 .54154 Mdot
.49 .54165 Mdot
.49 .54174 Mdot
.49 .54178 Mdot
.49 .54178 Mdot
.49 .54207 Mdot
.49 .54214 Mdot
.49 .54215 Mdot
.49 .54216 Mdot
.49 .5422 Mdot
.49 .5423 Mdot
.49 .54232 Mdot
.49 .54234 Mdot
.49 .54236 Mdot
.49 .54247 Mdot
.49 .54254 Mdot
.49 .54257 Mdot
.49 .54263 Mdot
.49 .54264 Mdot
.49 .54264 Mdot
.49 .5427 Mdot
.49 .54273 Mdot
.49 .54279 Mdot
.49 .54292 Mdot
.49 .54294 Mdot
.49 .54297 Mdot
.49 .54299 Mdot
.49 .54304 Mdot
.49 .54306 Mdot
.49 .54309 Mdot
.49 .54309 Mdot
.49 .54311 Mdot
.49 .54312 Mdot
.49 .54312 Mdot
.49 .54314 Mdot
.49 .54316 Mdot
.49 .54316 Mdot
.49 .54319 Mdot
.49 .54319 Mdot
.49 .5432 Mdot
.49 .5432 Mdot
.49 .5432 Mdot
.49 .5432 Mdot
.49 .54322 Mdot
.49 .54322 Mdot
.49 .54322 Mdot
.49 .54323 Mdot
.49 .54323 Mdot
.49 .54323 Mdot
.49 .54325 Mdot
.49 .54325 Mdot
.49 .54327 Mdot
.49 .54328 Mdot
.492 .20779 Mdot
.492 .20779 Mdot
.492 .2078 Mdot
.492 .2078 Mdot
.492 .20782 Mdot
.492 .20782 Mdot
.492 .20783 Mdot
.492 .20784 Mdot
.492 .20786 Mdot
.492 .20786 Mdot
.492 .20794 Mdot
.492 .20796 Mdot
.492 .20797 Mdot
.492 .208 Mdot
.492 .20805 Mdot
.492 .20805 Mdot
.492 .20814 Mdot
.492 .20824 Mdot
.492 .2083 Mdot
.492 .20836 Mdot
.492 .2084 Mdot
.492 .20852 Mdot
.492 .20854 Mdot
.492 .20874 Mdot
.492 .20884 Mdot
.492 .20944 Mdot
.492 .20957 Mdot
.492 .20966 Mdot
.492 .20995 Mdot
.492 .21024 Mdot
.492 .21026 Mdot
.492 .21031 Mdot
.492 .21036 Mdot
.492 .2105 Mdot
.492 .2106 Mdot
.492 .21078 Mdot
.492 .21082 Mdot
.492 .2109 Mdot
.492 .21098 Mdot
.492 .21114 Mdot
.492 .21114 Mdot
.492 .21143 Mdot
.492 .21157 Mdot
.492 .21168 Mdot
.492 .21215 Mdot
.492 .2126 Mdot
.492 .21269 Mdot
.492 .21272 Mdot
.492 .21307 Mdot
.492 .21308 Mdot
.492 .21312 Mdot
.492 .21314 Mdot
.492 .2142 Mdot
.492 .21451 Mdot
.492 .21466 Mdot
.492 .21468 Mdot
.492 .21492 Mdot
.492 .21519 Mdot
.492 .21522 Mdot
.492 .21546 Mdot
.492 .21569 Mdot
.492 .21582 Mdot
.492 .2159 Mdot
.492 .21603 Mdot
.492 .21639 Mdot
.492 .21645 Mdot
.492 .21676 Mdot
.492 .21681 Mdot
.492 .21721 Mdot
.492 .21809 Mdot
.492 .21827 Mdot
.492 .2183 Mdot
.492 .21832 Mdot
.492 .21855 Mdot
.492 .21885 Mdot
.492 .21909 Mdot
.492 .21936 Mdot
.492 .21988 Mdot
.492 .22004 Mdot
.492 .22008 Mdot
.492 .22056 Mdot
.492 .22061 Mdot
.492 .22068 Mdot
.492 .22112 Mdot
.492 .22126 Mdot
.492 .22135 Mdot
.492 .22224 Mdot
.492 .22227 Mdot
.492 .22293 Mdot
.492 .22329 Mdot
.492 .22349 Mdot
.492 .22402 Mdot
.492 .22405 Mdot
.492 .22422 Mdot
.492 .22431 Mdot
.492 .22445 Mdot
.492 .22487 Mdot
.492 .2252 Mdot
.492 .2253 Mdot
.492 .22545 Mdot
.492 .22645 Mdot
.492 .22678 Mdot
.492 .22682 Mdot
.492 .22705 Mdot
.492 .22713 Mdot
.492 .22741 Mdot
.492 .22766 Mdot
.492 .22793 Mdot
.492 .2281 Mdot
.492 .22819 Mdot
.492 .2288 Mdot
.492 .22889 Mdot
.492 .22902 Mdot
.492 .22915 Mdot
.492 .22947 Mdot
.492 .22972 Mdot
.492 .22998 Mdot
.492 .23018 Mdot
.492 .23046 Mdot
.492 .23051 Mdot
.492 .23086 Mdot
.492 .23097 Mdot
.492 .23128 Mdot
.492 .23195 Mdot
.492 .23298 Mdot
.492 .2348 Mdot
.492 .23483 Mdot
.492 .23488 Mdot
.492 .23548 Mdot
.492 .23557 Mdot
.492 .23571 Mdot
.492 .23572 Mdot
.492 .23611 Mdot
.492 .23697 Mdot
.492 .23704 Mdot
.492 .23706 Mdot
.492 .23734 Mdot
.492 .23739 Mdot
.492 .23816 Mdot
.492 .23848 Mdot
.492 .23883 Mdot
.492 .23885 Mdot
.492 .239 Mdot
.492 .23937 Mdot
.492 .23959 Mdot
.492 .23982 Mdot
.492 .24059 Mdot
.492 .24071 Mdot
.492 .24072 Mdot
.492 .24085 Mdot
.492 .24115 Mdot
.492 .24157 Mdot
.492 .24168 Mdot
.492 .24229 Mdot
.492 .24234 Mdot
.492 .24278 Mdot
.492 .24279 Mdot
.492 .24312 Mdot
.492 .24339 Mdot
.492 .24364 Mdot
.492 .24365 Mdot
.492 .24373 Mdot
.492 .24403 Mdot
.492 .24418 Mdot
.492 .24489 Mdot
.492 .24505 Mdot
.492 .24528 Mdot
.492 .2454 Mdot
.492 .24551 Mdot
.492 .24587 Mdot
.492 .24592 Mdot
.492 .24606 Mdot
.492 .24627 Mdot
.492 .24635 Mdot
.492 .24664 Mdot
.492 .24681 Mdot
.492 .2475 Mdot
.492 .24822 Mdot
.492 .24823 Mdot
.492 .24825 Mdot
.492 .24873 Mdot
.492 .24908 Mdot
.492 .2492 Mdot
.492 .24951 Mdot
.492 .24963 Mdot
.492 .24976 Mdot
.492 .24977 Mdot
.492 .24996 Mdot
.492 .25004 Mdot
.492 .25012 Mdot
.492 .25041 Mdot
.492 .25046 Mdot
.492 .25051 Mdot
.492 .25077 Mdot
.492 .25103 Mdot
.492 .25105 Mdot
.492 .25133 Mdot
.492 .25152 Mdot
.492 .25152 Mdot
.492 .25202 Mdot
.492 .25215 Mdot
.492 .25218 Mdot
.492 .25233 Mdot
.492 .25258 Mdot
.492 .25264 Mdot
.492 .25313 Mdot
.492 .25314 Mdot
.492 .25314 Mdot
.492 .25347 Mdot
.492 .25358 Mdot
.492 .25367 Mdot
.492 .25367 Mdot
.492 .25374 Mdot
.492 .25376 Mdot
.492 .25379 Mdot
.492 .25389 Mdot
.492 .25391 Mdot
.492 .25392 Mdot
.492 .25401 Mdot
.492 .2541 Mdot
.492 .25411 Mdot
.492 .25421 Mdot
.492 .25427 Mdot
.492 .25427 Mdot
.492 .25444 Mdot
.492 .25448 Mdot
.492 .25455 Mdot
.492 .25463 Mdot
.492 .25482 Mdot
.492 .25482 Mdot
.492 .25482 Mdot
.492 .25502 Mdot
.492 .25509 Mdot
.492 .25526 Mdot
.492 .25528 Mdot
.492 .25533 Mdot
.492 .25539 Mdot
.492 .25556 Mdot
.492 .25558 Mdot
.492 .25564 Mdot
.492 .25565 Mdot
.492 .25566 Mdot
.492 .25567 Mdot
.492 .25569 Mdot
.492 .2557 Mdot
.492 .2557 Mdot
.492 .25573 Mdot
.492 .25575 Mdot
.492 .25584 Mdot
.492 .25588 Mdot
.492 .25591 Mdot
.492 .25602 Mdot
.492 .25606 Mdot
.492 .25617 Mdot
.492 .25618 Mdot
.492 .25629 Mdot
.492 .25637 Mdot
.492 .2564 Mdot
.492 .2565 Mdot
.492 .25654 Mdot
.492 .25659 Mdot
.492 .25665 Mdot
.492 .2567 Mdot
.492 .25671 Mdot
.492 .25672 Mdot
.492 .25678 Mdot
.492 .2568 Mdot
.492 .25681 Mdot
.492 .25685 Mdot
.492 .25685 Mdot
.492 .25716 Mdot
.492 .25717 Mdot
.492 .25717 Mdot
.492 .2575 Mdot
.492 .25765 Mdot
.492 .25776 Mdot
.492 .25783 Mdot
.492 .25813 Mdot
.492 .25814 Mdot
.492 .25825 Mdot
.492 .25842 Mdot
.492 .25843 Mdot
.492 .25859 Mdot
.492 .25875 Mdot
.492 .25878 Mdot
.492 .25881 Mdot
.492 .25898 Mdot
.492 .25903 Mdot
.492 .25908 Mdot
.492 .2592 Mdot
.492 .25921 Mdot
.492 .25936 Mdot
.492 .25955 Mdot
.492 .26014 Mdot
.492 .26015 Mdot
.492 .26016 Mdot
.492 .26105 Mdot
.492 .26115 Mdot
.492 .26161 Mdot
.492 .26187 Mdot
.492 .26195 Mdot
.492 .26217 Mdot
.492 .26309 Mdot
.492 .2631 Mdot
.492 .26344 Mdot
.492 .26396 Mdot
.492 .26399 Mdot
.492 .26447 Mdot
.492 .26497 Mdot
.492 .26506 Mdot
.492 .26514 Mdot
.492 .26568 Mdot
.492 .26583 Mdot
.492 .26599 Mdot
.492 .26635 Mdot
.492 .26637 Mdot
.492 .26662 Mdot
.492 .26684 Mdot
.492 .26743 Mdot
.492 .26764 Mdot
.492 .26832 Mdot
.492 .26923 Mdot
.492 .26928 Mdot
.492 .26929 Mdot
.492 .27068 Mdot
.492 .27203 Mdot
.492 .27236 Mdot
.492 .27292 Mdot
.492 .27308 Mdot
.492 .27351 Mdot
.492 .27377 Mdot
.492 .27388 Mdot
.492 .27458 Mdot
.492 .2748 Mdot
.492 .27504 Mdot
.492 .2755 Mdot
.492 .27582 Mdot
.492 .27725 Mdot
.492 .27755 Mdot
.492 .27816 Mdot
.492 .27832 Mdot
.492 .27835 Mdot
.492 .27886 Mdot
.492 .27941 Mdot
.492 .28007 Mdot
.492 .2801 Mdot
.492 .28101 Mdot
.492 .28111 Mdot
.492 .28237 Mdot
.492 .28259 Mdot
.492 .28348 Mdot
.492 .2841 Mdot
.492 .28437 Mdot
.492 .28439 Mdot
.492 .28465 Mdot
.492 .28628 Mdot
.492 .28676 Mdot
.492 .28723 Mdot
.492 .28801 Mdot
.492 .28833 Mdot
.492 .28837 Mdot
.492 .28913 Mdot
.492 .28981 Mdot
.492 .29147 Mdot
.492 .29159 Mdot
.492 .29219 Mdot
.492 .29224 Mdot
.492 .2924 Mdot
.492 .29428 Mdot
.492 .29514 Mdot
.492 .29515 Mdot
.492 .29547 Mdot
.492 .29566 Mdot
.492 .29699 Mdot
.492 .29712 Mdot
.492 .29717 Mdot
.492 .30124 Mdot
.492 .30358 Mdot
.492 .30512 Mdot
.492 .30583 Mdot
.492 .30607 Mdot
.492 .30688 Mdot
.492 .30699 Mdot
.492 .30765 Mdot
.492 .30812 Mdot
.492 .3087 Mdot
.492 .3093 Mdot
.492 .31003 Mdot
.492 .31034 Mdot
.492 .31065 Mdot
.492 .31085 Mdot
.492 .31228 Mdot
.492 .31249 Mdot
.492 .31288 Mdot
.492 .31353 Mdot
.492 .31412 Mdot
.492 .31477 Mdot
.492 .31496 Mdot
.492 .31551 Mdot
.492 .31561 Mdot
.492 .31639 Mdot
.492 .31876 Mdot
.492 .31913 Mdot
.492 .31937 Mdot
.492 .32016 Mdot
.492 .32116 Mdot
.492 .3215 Mdot
.492 .32172 Mdot
.492 .32212 Mdot
.492 .32221 Mdot
.492 .32347 Mdot
.492 .32397 Mdot
.492 .32484 Mdot
.492 .32645 Mdot
.492 .32652 Mdot
.492 .32869 Mdot
.492 .32892 Mdot
.492 .32927 Mdot
.492 .33035 Mdot
.492 .33052 Mdot
.492 .33063 Mdot
.492 .33182 Mdot
.492 .33192 Mdot
.492 .33231 Mdot
.492 .33361 Mdot
.492 .33428 Mdot
.492 .33486 Mdot
.492 .33562 Mdot
.492 .33618 Mdot
.492 .33623 Mdot
.492 .3363 Mdot
.492 .33677 Mdot
.492 .33897 Mdot
.492 .33996 Mdot
.492 .34009 Mdot
.492 .34088 Mdot
.492 .34102 Mdot
.492 .34192 Mdot
.492 .34225 Mdot
.492 .34246 Mdot
.492 .34277 Mdot
.492 .34337 Mdot
.492 .34397 Mdot
.492 .34404 Mdot
.492 .34474 Mdot
.492 .34535 Mdot
.492 .34539 Mdot
.492 .34576 Mdot
.492 .34654 Mdot
.492 .34925 Mdot
.492 .34931 Mdot
.492 .34942 Mdot
.492 .34942 Mdot
.492 .35034 Mdot
.492 .35041 Mdot
.492 .35064 Mdot
.492 .35179 Mdot
.492 .35298 Mdot
.492 .35327 Mdot
.492 .35363 Mdot
.492 .35437 Mdot
.492 .35438 Mdot
.492 .35477 Mdot
.492 .355 Mdot
.492 .3552 Mdot
.492 .3553 Mdot
.492 .35576 Mdot
.492 .35601 Mdot
.492 .35639 Mdot
.492 .35651 Mdot
.492 .35664 Mdot
.492 .3567 Mdot
.492 .35742 Mdot
.492 .35819 Mdot
.492 .35841 Mdot
.492 .35875 Mdot
.492 .3603 Mdot
.492 .36057 Mdot
.492 .36106 Mdot
.492 .36113 Mdot
.492 .36144 Mdot
.492 .36154 Mdot
.492 .3617 Mdot
.492 .36186 Mdot
.492 .36211 Mdot
.492 .36235 Mdot
.492 .36236 Mdot
.492 .36249 Mdot
.492 .36255 Mdot
.492 .36257 Mdot
.492 .36264 Mdot
.492 .36283 Mdot
.492 .36285 Mdot
.492 .36288 Mdot
.492 .36291 Mdot
.492 .36295 Mdot
.492 .36296 Mdot
.492 .36299 Mdot
.492 .363 Mdot
.492 .36303 Mdot
.492 .36303 Mdot
.492 .48095 Mdot
.492 .48095 Mdot
.492 .48097 Mdot
.492 .48097 Mdot
.492 .48099 Mdot
.492 .48099 Mdot
.492 .48101 Mdot
.492 .48102 Mdot
.492 .48104 Mdot
.492 .48105 Mdot
.492 .48114 Mdot
.492 .48117 Mdot
.492 .48118 Mdot
.492 .48121 Mdot
.492 .48127 Mdot
.492 .48128 Mdot
.492 .48139 Mdot
.492 .48151 Mdot
.492 .48159 Mdot
.492 .48166 Mdot
.492 .48171 Mdot
.492 .48186 Mdot
.492 .48189 Mdot
.492 .48212 Mdot
.492 .48225 Mdot
.492 .48298 Mdot
.492 .48314 Mdot
.492 .48324 Mdot
.492 .4836 Mdot
.492 .48394 Mdot
.492 .48397 Mdot
.492 .48403 Mdot
.492 .48409 Mdot
.492 .48427 Mdot
.492 .48438 Mdot
.492 .4846 Mdot
.492 .48465 Mdot
.492 .48474 Mdot
.492 .48484 Mdot
.492 .48503 Mdot
.492 .48503 Mdot
.492 .48537 Mdot
.492 .48554 Mdot
.492 .48568 Mdot
.492 .48623 Mdot
.492 .48676 Mdot
.492 .48687 Mdot
.492 .4869 Mdot
.492 .48732 Mdot
.492 .48732 Mdot
.492 .48737 Mdot
.492 .4874 Mdot
.492 .48864 Mdot
.492 .48899 Mdot
.492 .48916 Mdot
.492 .48918 Mdot
.492 .48946 Mdot
.492 .48977 Mdot
.492 .48981 Mdot
.492 .49008 Mdot
.492 .49035 Mdot
.492 .49049 Mdot
.492 .49058 Mdot
.492 .49073 Mdot
.492 .49113 Mdot
.492 .4912 Mdot
.492 .49155 Mdot
.492 .49161 Mdot
.492 .49205 Mdot
.492 .49304 Mdot
.492 .49324 Mdot
.492 .49328 Mdot
.492 .4933 Mdot
.492 .49355 Mdot
.492 .49389 Mdot
.492 .49414 Mdot
.492 .49444 Mdot
.492 .49501 Mdot
.492 .49518 Mdot
.492 .49523 Mdot
.492 .49575 Mdot
.492 .4958 Mdot
.492 .49587 Mdot
.492 .49635 Mdot
.492 .4965 Mdot
.492 .4966 Mdot
.492 .49754 Mdot
.492 .49758 Mdot
.492 .49827 Mdot
.492 .49865 Mdot
.492 .49886 Mdot
.492 .49941 Mdot
.492 .49944 Mdot
.492 .49962 Mdot
.492 .49971 Mdot
.492 .49986 Mdot
.492 .50028 Mdot
.492 .50062 Mdot
.492 .50073 Mdot
.492 .50089 Mdot
.492 .50189 Mdot
.492 .50222 Mdot
.492 .50227 Mdot
.492 .5025 Mdot
.492 .50258 Mdot
.492 .50286 Mdot
.492 .50311 Mdot
.492 .50338 Mdot
.492 .50354 Mdot
.492 .50363 Mdot
.492 .50423 Mdot
.492 .50432 Mdot
.492 .50445 Mdot
.492 .50458 Mdot
.492 .50488 Mdot
.492 .50513 Mdot
.492 .50537 Mdot
.492 .50557 Mdot
.492 .50584 Mdot
.492 .50589 Mdot
.492 .50623 Mdot
.492 .50633 Mdot
.492 .50662 Mdot
.492 .50726 Mdot
.492 .50822 Mdot
.492 .50989 Mdot
.492 .50991 Mdot
.492 .50996 Mdot
.492 .5105 Mdot
.492 .51058 Mdot
.492 .51071 Mdot
.492 .51071 Mdot
.492 .51106 Mdot
.492 .51183 Mdot
.492 .51189 Mdot
.492 .51191 Mdot
.492 .51215 Mdot
.492 .5122 Mdot
.492 .51287 Mdot
.492 .51314 Mdot
.492 .51344 Mdot
.492 .51346 Mdot
.492 .51359 Mdot
.492 .5139 Mdot
.492 .51409 Mdot
.492 .51428 Mdot
.492 .51493 Mdot
.492 .51503 Mdot
.492 .51504 Mdot
.492 .51515 Mdot
.492 .51539 Mdot
.492 .51575 Mdot
.492 .51583 Mdot
.492 .51633 Mdot
.492 .51637 Mdot
.492 .51673 Mdot
.492 .51674 Mdot
.492 .517 Mdot
.492 .51722 Mdot
.492 .51742 Mdot
.492 .51743 Mdot
.492 .51749 Mdot
.492 .51773 Mdot
.492 .51785 Mdot
.492 .51841 Mdot
.492 .51854 Mdot
.492 .51872 Mdot
.492 .51881 Mdot
.492 .5189 Mdot
.492 .51917 Mdot
.492 .51921 Mdot
.492 .51932 Mdot
.492 .51948 Mdot
.492 .51954 Mdot
.492 .51976 Mdot
.492 .51989 Mdot
.492 .52041 Mdot
.492 .52095 Mdot
.492 .52096 Mdot
.492 .52097 Mdot
.492 .52132 Mdot
.492 .52159 Mdot
.492 .52167 Mdot
.492 .5219 Mdot
.492 .52198 Mdot
.492 .52208 Mdot
.492 .52208 Mdot
.492 .52222 Mdot
.492 .52228 Mdot
.492 .52234 Mdot
.492 .52255 Mdot
.492 .52258 Mdot
.492 .52262 Mdot
.492 .5228 Mdot
.492 .52299 Mdot
.492 .523 Mdot
.492 .5232 Mdot
.492 .52333 Mdot
.492 .52334 Mdot
.492 .52368 Mdot
.492 .52377 Mdot
.492 .5238 Mdot
.492 .5239 Mdot
.492 .52407 Mdot
.492 .52411 Mdot
.492 .52445 Mdot
.492 .52445 Mdot
.492 .52446 Mdot
.492 .52468 Mdot
.492 .52475 Mdot
.492 .52481 Mdot
.492 .52481 Mdot
.492 .52486 Mdot
.492 .52488 Mdot
.492 .5249 Mdot
.492 .52496 Mdot
.492 .52497 Mdot
.492 .52499 Mdot
.492 .52505 Mdot
.492 .52511 Mdot
.492 .52511 Mdot
.492 .52518 Mdot
.492 .52522 Mdot
.492 .52522 Mdot
.492 .52533 Mdot
.492 .52536 Mdot
.492 .5254 Mdot
.492 .52546 Mdot
.492 .52558 Mdot
.492 .52559 Mdot
.492 .52559 Mdot
.492 .5257 Mdot
.492 .5257 Mdot
.492 .52572 Mdot
.492 .52573 Mdot
.492 .52573 Mdot
.492 .52575 Mdot
.492 .52576 Mdot
.492 .52576 Mdot
.492 .52578 Mdot
.492 .5258 Mdot
.492 .52582 Mdot
.492 .52584 Mdot
.492 .52588 Mdot
.492 .52589 Mdot
.492 .52592 Mdot
.492 .52596 Mdot
.492 .52596 Mdot
.492 .526 Mdot
.492 .52602 Mdot
.492 .52606 Mdot
.492 .52607 Mdot
.492 .52608 Mdot
.492 .52612 Mdot
.492 .52613 Mdot
.492 .52614 Mdot
.492 .52614 Mdot
.492 .52614 Mdot
.492 .52615 Mdot
.492 .52615 Mdot
.492 .52616 Mdot
.492 .52616 Mdot
.492 .52618 Mdot
.492 .52619 Mdot
.492 .52626 Mdot
.492 .52628 Mdot
.492 .5263 Mdot
.492 .5263 Mdot
.492 .52637 Mdot
.492 .52639 Mdot
.492 .52647 Mdot
.492 .52647 Mdot
.492 .52647 Mdot
.492 .52654 Mdot
.492 .52657 Mdot
.492 .5266 Mdot
.492 .52661 Mdot
.492 .52668 Mdot
.492 .52668 Mdot
.492 .5267 Mdot
.492 .52674 Mdot
.492 .52674 Mdot
.492 .52677 Mdot
.492 .52681 Mdot
.492 .52681 Mdot
.492 .52682 Mdot
.492 .52686 Mdot
.492 .52687 Mdot
.492 .52688 Mdot
.492 .5269 Mdot
.492 .5269 Mdot
.492 .52694 Mdot
.492 .52698 Mdot
.492 .5271 Mdot
.492 .5271 Mdot
.492 .52711 Mdot
.492 .52729 Mdot
.492 .52731 Mdot
.492 .52741 Mdot
.492 .52746 Mdot
.492 .52748 Mdot
.492 .52752 Mdot
.492 .52771 Mdot
.492 .52771 Mdot
.492 .52778 Mdot
.492 .52789 Mdot
.492 .52789 Mdot
.492 .52799 Mdot
.492 .52809 Mdot
.492 .52811 Mdot
.492 .52813 Mdot
.492 .52823 Mdot
.492 .52826 Mdot
.492 .52829 Mdot
.492 .52837 Mdot
.492 .52837 Mdot
.492 .52842 Mdot
.492 .52846 Mdot
.492 .52858 Mdot
.492 .52862 Mdot
.492 .52875 Mdot
.492 .52893 Mdot
.492 .52894 Mdot
.492 .52894 Mdot
.492 .52921 Mdot
.492 .52947 Mdot
.492 .52953 Mdot
.492 .52964 Mdot
.492 .52967 Mdot
.492 .52975 Mdot
.492 .5298 Mdot
.492 .52982 Mdot
.492 .52995 Mdot
.492 .52999 Mdot
.492 .53003 Mdot
.492 .53012 Mdot
.492 .53018 Mdot
.492 .53044 Mdot
.492 .5305 Mdot
.492 .53061 Mdot
.492 .53064 Mdot
.492 .53064 Mdot
.492 .53073 Mdot
.492 .53083 Mdot
.492 .53095 Mdot
.492 .53096 Mdot
.492 .53112 Mdot
.492 .53114 Mdot
.492 .53136 Mdot
.492 .5314 Mdot
.492 .53156 Mdot
.492 .53167 Mdot
.492 .53172 Mdot
.492 .53172 Mdot
.492 .53177 Mdot
.492 .53205 Mdot
.492 .53213 Mdot
.492 .53221 Mdot
.492 .53235 Mdot
.492 .5324 Mdot
.492 .53241 Mdot
.492 .53254 Mdot
.492 .53266 Mdot
.492 .53294 Mdot
.492 .53296 Mdot
.492 .53306 Mdot
.492 .53307 Mdot
.492 .53309 Mdot
.492 .53341 Mdot
.492 .53355 Mdot
.492 .53355 Mdot
.492 .5336 Mdot
.492 .53364 Mdot
.492 .53385 Mdot
.492 .53388 Mdot
.492 .53388 Mdot
.492 .53454 Mdot
.492 .53492 Mdot
.492 .53516 Mdot
.492 .53528 Mdot
.492 .53531 Mdot
.492 .53544 Mdot
.492 .53546 Mdot
.492 .53556 Mdot
.492 .53563 Mdot
.492 .53573 Mdot
.492 .53582 Mdot
.492 .53593 Mdot
.492 .53598 Mdot
.492 .53603 Mdot
.492 .53606 Mdot
.492 .53628 Mdot
.492 .53631 Mdot
.492 .53637 Mdot
.492 .53647 Mdot
.492 .53656 Mdot
.492 .53666 Mdot
.492 .53669 Mdot
.492 .53677 Mdot
.492 .53679 Mdot
.492 .53691 Mdot
.492 .53726 Mdot
.492 .53732 Mdot
.492 .53735 Mdot
.492 .53747 Mdot
.492 .53762 Mdot
.492 .53767 Mdot
.492 .53771 Mdot
.492 .53776 Mdot
.492 .53778 Mdot
.492 .53796 Mdot
.492 .53804 Mdot
.492 .53817 Mdot
.492 .5384 Mdot
.492 .53841 Mdot
.492 .53873 Mdot
.492 .53876 Mdot
.492 .53881 Mdot
.492 .53897 Mdot
.492 .53899 Mdot
.492 .53901 Mdot
.492 .53918 Mdot
.492 .5392 Mdot
.492 .53925 Mdot
.492 .53944 Mdot
.492 .53954 Mdot
.492 .53962 Mdot
.492 .53973 Mdot
.492 .53981 Mdot
.492 .53981 Mdot
.492 .53983 Mdot
.492 .53989 Mdot
.492 .5402 Mdot
.492 .54034 Mdot
.492 .54036 Mdot
.492 .54049 Mdot
.492 .54062 Mdot
.492 .54067 Mdot
.492 .54069 Mdot
.492 .54074 Mdot
.492 .54082 Mdot
.492 .54091 Mdot
.492 .54092 Mdot
.492 .54101 Mdot
.492 .5411 Mdot
.492 .5411 Mdot
.492 .54115 Mdot
.492 .54126 Mdot
.492 .54164 Mdot
.492 .54165 Mdot
.492 .54166 Mdot
.492 .54166 Mdot
.492 .54179 Mdot
.492 .5418 Mdot
.492 .54183 Mdot
.492 .54199 Mdot
.492 .54215 Mdot
.492 .54219 Mdot
.492 .54224 Mdot
.492 .54234 Mdot
.492 .54234 Mdot
.492 .5424 Mdot
.492 .54243 Mdot
.492 .54245 Mdot
.492 .54247 Mdot
.492 .54253 Mdot
.492 .54257 Mdot
.492 .54262 Mdot
.492 .54263 Mdot
.492 .54265 Mdot
.492 .54266 Mdot
.492 .54276 Mdot
.492 .54286 Mdot
.492 .54289 Mdot
.492 .54294 Mdot
.492 .54315 Mdot
.492 .54318 Mdot
.492 .54325 Mdot
.492 .54326 Mdot
.492 .5433 Mdot
.492 .54331 Mdot
.492 .54334 Mdot
.492 .54336 Mdot
.492 .54339 Mdot
.492 .54342 Mdot
.492 .54343 Mdot
.492 .54344 Mdot
.492 .54345 Mdot
.492 .54345 Mdot
.492 .54346 Mdot
.492 .54349 Mdot
.492 .54349 Mdot
.492 .5435 Mdot
.492 .5435 Mdot
.492 .54351 Mdot
.492 .54351 Mdot
.492 .54351 Mdot
.492 .54351 Mdot
.492 .54352 Mdot
.492 .54352 Mdot
.494 .2072 Mdot
.494 .20721 Mdot
.494 .20722 Mdot
.494 .20724 Mdot
.494 .2074 Mdot
.494 .2075 Mdot
.494 .20762 Mdot
.494 .20765 Mdot
.494 .20765 Mdot
.494 .20769 Mdot
.494 .2077 Mdot
.494 .20773 Mdot
.494 .20799 Mdot
.494 .208 Mdot
.494 .208 Mdot
.494 .20801 Mdot
.494 .20807 Mdot
.494 .20814 Mdot
.494 .20821 Mdot
.494 .20833 Mdot
.494 .20835 Mdot
.494 .20842 Mdot
.494 .20888 Mdot
.494 .20897 Mdot
.494 .20907 Mdot
.494 .20942 Mdot
.494 .2095 Mdot
.494 .20983 Mdot
.494 .21031 Mdot
.494 .21038 Mdot
.494 .21069 Mdot
.494 .21083 Mdot
.494 .21089 Mdot
.494 .21091 Mdot
.494 .21091 Mdot
.494 .21124 Mdot
.494 .21127 Mdot
.494 .21139 Mdot
.494 .21148 Mdot
.494 .21162 Mdot
.494 .2118 Mdot
.494 .21201 Mdot
.494 .21217 Mdot
.494 .21222 Mdot
.494 .21233 Mdot
.494 .21245 Mdot
.494 .21247 Mdot
.494 .21259 Mdot
.494 .21262 Mdot
.494 .21267 Mdot
.494 .21277 Mdot
.494 .21278 Mdot
.494 .21282 Mdot
.494 .21331 Mdot
.494 .21335 Mdot
.494 .21357 Mdot
.494 .21362 Mdot
.494 .21379 Mdot
.494 .21401 Mdot
.494 .21401 Mdot
.494 .21414 Mdot
.494 .21424 Mdot
.494 .2145 Mdot
.494 .21459 Mdot
.494 .21471 Mdot
.494 .2154 Mdot
.494 .21568 Mdot
.494 .21576 Mdot
.494 .21587 Mdot
.494 .21635 Mdot
.494 .21638 Mdot
.494 .21686 Mdot
.494 .21696 Mdot
.494 .21718 Mdot
.494 .21727 Mdot
.494 .2173 Mdot
.494 .21734 Mdot
.494 .21734 Mdot
.494 .21759 Mdot
.494 .2177 Mdot
.494 .21775 Mdot
.494 .21784 Mdot
.494 .2181 Mdot
.494 .21813 Mdot
.494 .21824 Mdot
.494 .21837 Mdot
.494 .21845 Mdot
.494 .21882 Mdot
.494 .21916 Mdot
.494 .21922 Mdot
.494 .2194 Mdot
.494 .21943 Mdot
.494 .21947 Mdot
.494 .21958 Mdot
.494 .21987 Mdot
.494 .22013 Mdot
.494 .22019 Mdot
.494 .22083 Mdot
.494 .22103 Mdot
.494 .22117 Mdot
.494 .22117 Mdot
.494 .22143 Mdot
.494 .22159 Mdot
.494 .22193 Mdot
.494 .22194 Mdot
.494 .22204 Mdot
.494 .22206 Mdot
.494 .22214 Mdot
.494 .22215 Mdot
.494 .22224 Mdot
.494 .22246 Mdot
.494 .22261 Mdot
.494 .22303 Mdot
.494 .22329 Mdot
.494 .22329 Mdot
.494 .2238 Mdot
.494 .22457 Mdot
.494 .22466 Mdot
.494 .22527 Mdot
.494 .22598 Mdot
.494 .2263 Mdot
.494 .22641 Mdot
.494 .22652 Mdot
.494 .22653 Mdot
.494 .22654 Mdot
.494 .22713 Mdot
.494 .22733 Mdot
.494 .22941 Mdot
.494 .2298 Mdot
.494 .22991 Mdot
.494 .23007 Mdot
.494 .23089 Mdot
.494 .23121 Mdot
.494 .23162 Mdot
.494 .23163 Mdot
.494 .23172 Mdot
.494 .23182 Mdot
.494 .23235 Mdot
.494 .23273 Mdot
.494 .23292 Mdot
.494 .23307 Mdot
.494 .23382 Mdot
.494 .23394 Mdot
.494 .23481 Mdot
.494 .23536 Mdot
.494 .23565 Mdot
.494 .23578 Mdot
.494 .23583 Mdot
.494 .23616 Mdot
.494 .23626 Mdot
.494 .23634 Mdot
.494 .23645 Mdot
.494 .2369 Mdot
.494 .23694 Mdot
.494 .23728 Mdot
.494 .23739 Mdot
.494 .23777 Mdot
.494 .23796 Mdot
.494 .23808 Mdot
.494 .23832 Mdot
.494 .23855 Mdot
.494 .23869 Mdot
.494 .23913 Mdot
.494 .2393 Mdot
.494 .2397 Mdot
.494 .24 Mdot
.494 .24026 Mdot
.494 .24028 Mdot
.494 .24042 Mdot
.494 .24051 Mdot
.494 .24071 Mdot
.494 .24072 Mdot
.494 .24078 Mdot
.494 .24085 Mdot
.494 .2409 Mdot
.494 .2411 Mdot
.494 .24128 Mdot
.494 .24131 Mdot
.494 .24142 Mdot
.494 .24144 Mdot
.494 .24231 Mdot
.494 .24252 Mdot
.494 .24269 Mdot
.494 .24269 Mdot
.494 .24279 Mdot
.494 .24301 Mdot
.494 .24333 Mdot
.494 .24357 Mdot
.494 .24424 Mdot
.494 .24475 Mdot
.494 .2448 Mdot
.494 .2448 Mdot
.494 .24506 Mdot
.494 .24623 Mdot
.494 .24697 Mdot
.494 .24701 Mdot
.494 .24737 Mdot
.494 .24819 Mdot
.494 .2484 Mdot
.494 .24874 Mdot
.494 .24912 Mdot
.494 .24942 Mdot
.494 .24965 Mdot
.494 .24981 Mdot
.494 .25002 Mdot
.494 .25023 Mdot
.494 .25023 Mdot
.494 .25029 Mdot
.494 .25039 Mdot
.494 .25039 Mdot
.494 .25042 Mdot
.494 .25046 Mdot
.494 .25053 Mdot
.494 .2506 Mdot
.494 .25066 Mdot
.494 .25097 Mdot
.494 .25104 Mdot
.494 .25133 Mdot
.494 .25165 Mdot
.494 .25183 Mdot
.494 .25185 Mdot
.494 .25235 Mdot
.494 .25261 Mdot
.494 .25275 Mdot
.494 .25303 Mdot
.494 .25335 Mdot
.494 .25345 Mdot
.494 .25353 Mdot
.494 .25358 Mdot
.494 .25366 Mdot
.494 .25373 Mdot
.494 .25378 Mdot
.494 .25379 Mdot
.494 .25383 Mdot
.494 .25398 Mdot
.494 .2541 Mdot
.494 .25421 Mdot
.494 .25427 Mdot
.494 .25444 Mdot
.494 .25458 Mdot
.494 .25486 Mdot
.494 .25488 Mdot
.494 .25491 Mdot
.494 .25494 Mdot
.494 .2561 Mdot
.494 .25624 Mdot
.494 .25631 Mdot
.494 .25646 Mdot
.494 .25649 Mdot
.494 .25649 Mdot
.494 .25652 Mdot
.494 .25657 Mdot
.494 .25661 Mdot
.494 .25664 Mdot
.494 .2571 Mdot
.494 .25718 Mdot
.494 .25733 Mdot
.494 .25763 Mdot
.494 .25764 Mdot
.494 .25775 Mdot
.494 .25794 Mdot
.494 .25816 Mdot
.494 .25839 Mdot
.494 .25843 Mdot
.494 .25847 Mdot
.494 .25849 Mdot
.494 .25851 Mdot
.494 .25851 Mdot
.494 .25857 Mdot
.494 .2586 Mdot
.494 .25873 Mdot
.494 .25886 Mdot
.494 .25896 Mdot
.494 .2591 Mdot
.494 .25928 Mdot
.494 .25986 Mdot
.494 .26037 Mdot
.494 .26062 Mdot
.494 .26108 Mdot
.494 .262 Mdot
.494 .26203 Mdot
.494 .26236 Mdot
.494 .26295 Mdot
.494 .26349 Mdot
.494 .26363 Mdot
.494 .26421 Mdot
.494 .26432 Mdot
.494 .26444 Mdot
.494 .26458 Mdot
.494 .26465 Mdot
.494 .26469 Mdot
.494 .2647 Mdot
.494 .2649 Mdot
.494 .26499 Mdot
.494 .26501 Mdot
.494 .26539 Mdot
.494 .26579 Mdot
.494 .26609 Mdot
.494 .26636 Mdot
.494 .26652 Mdot
.494 .26709 Mdot
.494 .26782 Mdot
.494 .26848 Mdot
.494 .26889 Mdot
.494 .27046 Mdot
.494 .27116 Mdot
.494 .27124 Mdot
.494 .27269 Mdot
.494 .27503 Mdot
.494 .27555 Mdot
.494 .27555 Mdot
.494 .27565 Mdot
.494 .27667 Mdot
.494 .27803 Mdot
.494 .27852 Mdot
.494 .27918 Mdot
.494 .27964 Mdot
.494 .27984 Mdot
.494 .27985 Mdot
.494 .28019 Mdot
.494 .28063 Mdot
.494 .28242 Mdot
.494 .28246 Mdot
.494 .28269 Mdot
.494 .28276 Mdot
.494 .28314 Mdot
.494 .28356 Mdot
.494 .28365 Mdot
.494 .2838 Mdot
.494 .28393 Mdot
.494 .28396 Mdot
.494 .28437 Mdot
.494 .28456 Mdot
.494 .28485 Mdot
.494 .28491 Mdot
.494 .28544 Mdot
.494 .28608 Mdot
.494 .28694 Mdot
.494 .2873 Mdot
.494 .28824 Mdot
.494 .28854 Mdot
.494 .28905 Mdot
.494 .28956 Mdot
.494 .28982 Mdot
.494 .29023 Mdot
.494 .29106 Mdot
.494 .2913 Mdot
.494 .29204 Mdot
.494 .29213 Mdot
.494 .2931 Mdot
.494 .29335 Mdot
.494 .29352 Mdot
.494 .29374 Mdot
.494 .29448 Mdot
.494 .29459 Mdot
.494 .29488 Mdot
.494 .29552 Mdot
.494 .29673 Mdot
.494 .29867 Mdot
.494 .29895 Mdot
.494 .30064 Mdot
.494 .30098 Mdot
.494 .30141 Mdot
.494 .30227 Mdot
.494 .30347 Mdot
.494 .30371 Mdot
.494 .30392 Mdot
.494 .30393 Mdot
.494 .30487 Mdot
.494 .30561 Mdot
.494 .3075 Mdot
.494 .30788 Mdot
.494 .30813 Mdot
.494 .30903 Mdot
.494 .31392 Mdot
.494 .3144 Mdot
.494 .31579 Mdot
.494 .31581 Mdot
.494 .31584 Mdot
.494 .31609 Mdot
.494 .31637 Mdot
.494 .31713 Mdot
.494 .31882 Mdot
.494 .32029 Mdot
.494 .3205 Mdot
.494 .32238 Mdot
.494 .3236 Mdot
.494 .32361 Mdot
.494 .32424 Mdot
.494 .32527 Mdot
.494 .32562 Mdot
.494 .32617 Mdot
.494 .32638 Mdot
.494 .3264 Mdot
.494 .3266 Mdot
.494 .32665 Mdot
.494 .32689 Mdot
.494 .32691 Mdot
.494 .32775 Mdot
.494 .32815 Mdot
.494 .3288 Mdot
.494 .3288 Mdot
.494 .32913 Mdot
.494 .32962 Mdot
.494 .3312 Mdot
.494 .33135 Mdot
.494 .33199 Mdot
.494 .33271 Mdot
.494 .33298 Mdot
.494 .33309 Mdot
.494 .33317 Mdot
.494 .3336 Mdot
.494 .33376 Mdot
.494 .33461 Mdot
.494 .33553 Mdot
.494 .33573 Mdot
.494 .33605 Mdot
.494 .33633 Mdot
.494 .33639 Mdot
.494 .33706 Mdot
.494 .33727 Mdot
.494 .33741 Mdot
.494 .33768 Mdot
.494 .33829 Mdot
.494 .33831 Mdot
.494 .3384 Mdot
.494 .33849 Mdot
.494 .33871 Mdot
.494 .33926 Mdot
.494 .33951 Mdot
.494 .34072 Mdot
.494 .3408 Mdot
.494 .342 Mdot
.494 .34228 Mdot
.494 .3425 Mdot
.494 .34318 Mdot
.494 .34493 Mdot
.494 .34525 Mdot
.494 .34547 Mdot
.494 .34613 Mdot
.494 .34639 Mdot
.494 .34671 Mdot
.494 .34671 Mdot
.494 .34728 Mdot
.494 .34772 Mdot
.494 .34783 Mdot
.494 .3484 Mdot
.494 .3485 Mdot
.494 .34976 Mdot
.494 .34986 Mdot
.494 .34989 Mdot
.494 .35014 Mdot
.494 .35027 Mdot
.494 .35035 Mdot
.494 .35067 Mdot
.494 .3507 Mdot
.494 .35102 Mdot
.494 .35129 Mdot
.494 .35143 Mdot
.494 .35184 Mdot
.494 .35236 Mdot
.494 .35285 Mdot
.494 .3532 Mdot
.494 .35343 Mdot
.494 .35374 Mdot
.494 .35381 Mdot
.494 .35465 Mdot
.494 .35466 Mdot
.494 .35472 Mdot
.494 .35487 Mdot
.494 .35523 Mdot
.494 .35603 Mdot
.494 .3562 Mdot
.494 .35744 Mdot
.494 .3583 Mdot
.494 .35852 Mdot
.494 .35942 Mdot
.494 .35968 Mdot
.494 .35991 Mdot
.494 .3611 Mdot
.494 .36129 Mdot
.494 .36135 Mdot
.494 .36165 Mdot
.494 .36183 Mdot
.494 .36201 Mdot
.494 .36217 Mdot
.494 .36218 Mdot
.494 .3622 Mdot
.494 .36222 Mdot
.494 .36289 Mdot
.494 .36296 Mdot
.494 .363 Mdot
.494 .36311 Mdot
.494 .36311 Mdot
.494 .36319 Mdot
.494 .3635 Mdot
.494 .36376 Mdot
.494 .36418 Mdot
.494 .36423 Mdot
.494 .36425 Mdot
.494 .36429 Mdot
.494 .48043 Mdot
.494 .48045 Mdot
.494 .48046 Mdot
.494 .48048 Mdot
.494 .48068 Mdot
.494 .4808 Mdot
.494 .48095 Mdot
.494 .48099 Mdot
.494 .48099 Mdot
.494 .48104 Mdot
.494 .48106 Mdot
.494 .4811 Mdot
.494 .48141 Mdot
.494 .48142 Mdot
.494 .48143 Mdot
.494 .48144 Mdot
.494 .48151 Mdot
.494 .4816 Mdot
.494 .48168 Mdot
.494 .48183 Mdot
.494 .48185 Mdot
.494 .48194 Mdot
.494 .4825 Mdot
.494 .48261 Mdot
.494 .48274 Mdot
.494 .48316 Mdot
.494 .48326 Mdot
.494 .48367 Mdot
.494 .48425 Mdot
.494 .48433 Mdot
.494 .4847 Mdot
.494 .48487 Mdot
.494 .48494 Mdot
.494 .48497 Mdot
.494 .48497 Mdot
.494 .48536 Mdot
.494 .48539 Mdot
.494 .48554 Mdot
.494 .48565 Mdot
.494 .48581 Mdot
.494 .48603 Mdot
.494 .48627 Mdot
.494 .48646 Mdot
.494 .48653 Mdot
.494 .48665 Mdot
.494 .4868 Mdot
.494 .48681 Mdot
.494 .48696 Mdot
.494 .487 Mdot
.494 .48706 Mdot
.494 .48717 Mdot
.494 .48719 Mdot
.494 .48723 Mdot
.494 .48781 Mdot
.494 .48785 Mdot
.494 .48811 Mdot
.494 .48817 Mdot
.494 .48837 Mdot
.494 .48862 Mdot
.494 .48863 Mdot
.494 .48877 Mdot
.494 .48889 Mdot
.494 .48919 Mdot
.494 .48929 Mdot
.494 .48943 Mdot
.494 .49023 Mdot
.494 .49054 Mdot
.494 .49063 Mdot
.494 .49076 Mdot
.494 .4913 Mdot
.494 .49133 Mdot
.494 .49188 Mdot
.494 .49199 Mdot
.494 .49224 Mdot
.494 .49233 Mdot
.494 .49237 Mdot
.494 .49241 Mdot
.494 .49242 Mdot
.494 .4927 Mdot
.494 .49282 Mdot
.494 .49288 Mdot
.494 .49297 Mdot
.494 .49327 Mdot
.494 .4933 Mdot
.494 .49342 Mdot
.494 .49356 Mdot
.494 .49365 Mdot
.494 .49406 Mdot
.494 .49443 Mdot
.494 .49451 Mdot
.494 .49469 Mdot
.494 .49473 Mdot
.494 .49478 Mdot
.494 .4949 Mdot
.494 .49521 Mdot
.494 .4955 Mdot
.494 .49556 Mdot
.494 .49625 Mdot
.494 .49647 Mdot
.494 .49661 Mdot
.494 .49661 Mdot
.494 .4969 Mdot
.494 .49707 Mdot
.494 .49743 Mdot
.494 .49744 Mdot
.494 .49755 Mdot
.494 .49757 Mdot
.494 .49766 Mdot
.494 .49767 Mdot
.494 .49776 Mdot
.494 .49799 Mdot
.494 .49815 Mdot
.494 .49859 Mdot
.494 .49886 Mdot
.494 .49887 Mdot
.494 .49939 Mdot
.494 .5002 Mdot
.494 .50029 Mdot
.494 .50092 Mdot
.494 .50163 Mdot
.494 .50196 Mdot
.494 .50208 Mdot
.494 .50219 Mdot
.494 .50219 Mdot
.494 .5022 Mdot
.494 .50279 Mdot
.494 .503 Mdot
.494 .50505 Mdot
.494 .50542 Mdot
.494 .50553 Mdot
.494 .50569 Mdot
.494 .50647 Mdot
.494 .50678 Mdot
.494 .50717 Mdot
.494 .50717 Mdot
.494 .50726 Mdot
.494 .50736 Mdot
.494 .50785 Mdot
.494 .5082 Mdot
.494 .50838 Mdot
.494 .50852 Mdot
.494 .50921 Mdot
.494 .50933 Mdot
.494 .51012 Mdot
.494 .51061 Mdot
.494 .51087 Mdot
.494 .51099 Mdot
.494 .51103 Mdot
.494 .51133 Mdot
.494 .51142 Mdot
.494 .51149 Mdot
.494 .51159 Mdot
.494 .51198 Mdot
.494 .51202 Mdot
.494 .51232 Mdot
.494 .51241 Mdot
.494 .51275 Mdot
.494 .51291 Mdot
.494 .51302 Mdot
.494 .51322 Mdot
.494 .51343 Mdot
.494 .51355 Mdot
.494 .51392 Mdot
.494 .51406 Mdot
.494 .51441 Mdot
.494 .51466 Mdot
.494 .51488 Mdot
.494 .5149 Mdot
.494 .51501 Mdot
.494 .51509 Mdot
.494 .51525 Mdot
.494 .51526 Mdot
.494 .51532 Mdot
.494 .51537 Mdot
.494 .51541 Mdot
.494 .51558 Mdot
.494 .51573 Mdot
.494 .51575 Mdot
.494 .51584 Mdot
.494 .51586 Mdot
.494 .51657 Mdot
.494 .51674 Mdot
.494 .51688 Mdot
.494 .51688 Mdot
.494 .51696 Mdot
.494 .51714 Mdot
.494 .5174 Mdot
.494 .51759 Mdot
.494 .51813 Mdot
.494 .51852 Mdot
.494 .51856 Mdot
.494 .51857 Mdot
.494 .51877 Mdot
.494 .51968 Mdot
.494 .52024 Mdot
.494 .52027 Mdot
.494 .52054 Mdot
.494 .52115 Mdot
.494 .52131 Mdot
.494 .52156 Mdot
.494 .52184 Mdot
.494 .52206 Mdot
.494 .52223 Mdot
.494 .52234 Mdot
.494 .5225 Mdot
.494 .52264 Mdot
.494 .52265 Mdot
.494 .52268 Mdot
.494 .52276 Mdot
.494 .52276 Mdot
.494 .52278 Mdot
.494 .52281 Mdot
.494 .52286 Mdot
.494 .52291 Mdot
.494 .52295 Mdot
.494 .52317 Mdot
.494 .52322 Mdot
.494 .52343 Mdot
.494 .52365 Mdot
.494 .52378 Mdot
.494 .52379 Mdot
.494 .52414 Mdot
.494 .52432 Mdot
.494 .52441 Mdot
.494 .52461 Mdot
.494 .52483 Mdot
.494 .52489 Mdot
.494 .52495 Mdot
.494 .52498 Mdot
.494 .52503 Mdot
.494 .52508 Mdot
.494 .52509 Mdot
.494 .52512 Mdot
.494 .52512 Mdot
.494 .52512 Mdot
.494 .52513 Mdot
.494 .52515 Mdot
.494 .52516 Mdot
.494 .52525 Mdot
.494 .52533 Mdot
.494 .52541 Mdot
.494 .52545 Mdot
.494 .52545 Mdot
.494 .52556 Mdot
.494 .52562 Mdot
.494 .52565 Mdot
.494 .52583 Mdot
.494 .52584 Mdot
.494 .52585 Mdot
.494 .52587 Mdot
.494 .52588 Mdot
.494 .52588 Mdot
.494 .52589 Mdot
.494 .52595 Mdot
.494 .52598 Mdot
.494 .52603 Mdot
.494 .52647 Mdot
.494 .52648 Mdot
.494 .52649 Mdot
.494 .5265 Mdot
.494 .5266 Mdot
.494 .52665 Mdot
.494 .52672 Mdot
.494 .52674 Mdot
.494 .52678 Mdot
.494 .52683 Mdot
.494 .52688 Mdot
.494 .5269 Mdot
.494 .5269 Mdot
.494 .52692 Mdot
.494 .52695 Mdot
.494 .52698 Mdot
.494 .527 Mdot
.494 .52703 Mdot
.494 .52706 Mdot
.494 .52718 Mdot
.494 .52729 Mdot
.494 .52734 Mdot
.494 .52744 Mdot
.494 .52763 Mdot
.494 .52763 Mdot
.494 .5277 Mdot
.494 .52782 Mdot
.494 .52793 Mdot
.494 .52796 Mdot
.494 .52807 Mdot
.494 .5281 Mdot
.494 .52812 Mdot
.494 .52815 Mdot
.494 .52816 Mdot
.494 .52817 Mdot
.494 .52817 Mdot
.494 .52821 Mdot
.494 .52823 Mdot
.494 .52823 Mdot
.494 .52831 Mdot
.494 .52839 Mdot
.494 .52845 Mdot
.494 .52853 Mdot
.494 .52864 Mdot
.494 .52879 Mdot
.494 .52892 Mdot
.494 .52899 Mdot
.494 .5293 Mdot
.494 .52943 Mdot
.494 .52945 Mdot
.494 .52972 Mdot
.494 .53015 Mdot
.494 .53025 Mdot
.494 .53025 Mdot
.494 .53027 Mdot
.494 .53046 Mdot
.494 .5307 Mdot
.494 .53079 Mdot
.494 .53091 Mdot
.494 .53099 Mdot
.494 .53103 Mdot
.494 .53103 Mdot
.494 .53109 Mdot
.494 .53117 Mdot
.494 .53149 Mdot
.494 .5315 Mdot
.494 .53154 Mdot
.494 .53155 Mdot
.494 .53162 Mdot
.494 .53169 Mdot
.494 .53171 Mdot
.494 .53173 Mdot
.494 .53175 Mdot
.494 .53176 Mdot
.494 .53183 Mdot
.494 .53186 Mdot
.494 .53192 Mdot
.494 .53192 Mdot
.494 .53202 Mdot
.494 .53213 Mdot
.494 .53228 Mdot
.494 .53234 Mdot
.494 .5325 Mdot
.494 .53255 Mdot
.494 .53264 Mdot
.494 .53272 Mdot
.494 .53277 Mdot
.494 .53284 Mdot
.494 .53298 Mdot
.494 .53302 Mdot
.494 .53314 Mdot
.494 .53316 Mdot
.494 .53332 Mdot
.494 .53336 Mdot
.494 .53339 Mdot
.494 .53342 Mdot
.494 .53355 Mdot
.494 .53356 Mdot
.494 .53361 Mdot
.494 .53372 Mdot
.494 .53392 Mdot
.494 .53423 Mdot
.494 .53428 Mdot
.494 .53455 Mdot
.494 .5346 Mdot
.494 .53467 Mdot
.494 .53481 Mdot
.494 .535 Mdot
.494 .53504 Mdot
.494 .53507 Mdot
.494 .53507 Mdot
.494 .53522 Mdot
.494 .53534 Mdot
.494 .53563 Mdot
.494 .53569 Mdot
.494 .53573 Mdot
.494 .53587 Mdot
.494 .53662 Mdot
.494 .5367 Mdot
.494 .53691 Mdot
.494 .53691 Mdot
.494 .53691 Mdot
.494 .53695 Mdot
.494 .53699 Mdot
.494 .53711 Mdot
.494 .53736 Mdot
.494 .53758 Mdot
.494 .53761 Mdot
.494 .53789 Mdot
.494 .53807 Mdot
.494 .53807 Mdot
.494 .53816 Mdot
.494 .53831 Mdot
.494 .53837 Mdot
.494 .53845 Mdot
.494 .53848 Mdot
.494 .53848 Mdot
.494 .53851 Mdot
.494 .53852 Mdot
.494 .53855 Mdot
.494 .53856 Mdot
.494 .53868 Mdot
.494 .53873 Mdot
.494 .53883 Mdot
.494 .53883 Mdot
.494 .53888 Mdot
.494 .53895 Mdot
.494 .53918 Mdot
.494 .5392 Mdot
.494 .53929 Mdot
.494 .53939 Mdot
.494 .53943 Mdot
.494 .53945 Mdot
.494 .53946 Mdot
.494 .53952 Mdot
.494 .53954 Mdot
.494 .53966 Mdot
.494 .5398 Mdot
.494 .53982 Mdot
.494 .53987 Mdot
.494 .53991 Mdot
.494 .53992 Mdot
.494 .54001 Mdot
.494 .54004 Mdot
.494 .54006 Mdot
.494 .5401 Mdot
.494 .54019 Mdot
.494 .54019 Mdot
.494 .5402 Mdot
.494 .54021 Mdot
.494 .54025 Mdot
.494 .54032 Mdot
.494 .54036 Mdot
.494 .54053 Mdot
.494 .54054 Mdot
.494 .54071 Mdot
.494 .54075 Mdot
.494 .54078 Mdot
.494 .54087 Mdot
.494 .54112 Mdot
.494 .54116 Mdot
.494 .54119 Mdot
.494 .54128 Mdot
.494 .54132 Mdot
.494 .54136 Mdot
.494 .54136 Mdot
.494 .54144 Mdot
.494 .5415 Mdot
.494 .54152 Mdot
.494 .5416 Mdot
.494 .54161 Mdot
.494 .54178 Mdot
.494 .5418 Mdot
.494 .5418 Mdot
.494 .54183 Mdot
.494 .54185 Mdot
.494 .54186 Mdot
.494 .54191 Mdot
.494 .54191 Mdot
.494 .54196 Mdot
.494 .54199 Mdot
.494 .54201 Mdot
.494 .54207 Mdot
.494 .54214 Mdot
.494 .54221 Mdot
.494 .54225 Mdot
.494 .54228 Mdot
.494 .54233 Mdot
.494 .54234 Mdot
.494 .54245 Mdot
.494 .54245 Mdot
.494 .54246 Mdot
.494 .54248 Mdot
.494 .54253 Mdot
.494 .54264 Mdot
.494 .54266 Mdot
.494 .54283 Mdot
.494 .54295 Mdot
.494 .54298 Mdot
.494 .5431 Mdot
.494 .54313 Mdot
.494 .54316 Mdot
.494 .54332 Mdot
.494 .54335 Mdot
.494 .54336 Mdot
.494 .5434 Mdot
.494 .54342 Mdot
.494 .54345 Mdot
.494 .54347 Mdot
.494 .54347 Mdot
.494 .54347 Mdot
.494 .54347 Mdot
.494 .54356 Mdot
.494 .54358 Mdot
.494 .54358 Mdot
.494 .54359 Mdot
.494 .54359 Mdot
.494 .54361 Mdot
.494 .54365 Mdot
.494 .54368 Mdot
.494 .54374 Mdot
.494 .54374 Mdot
.494 .54375 Mdot
.494 .54375 Mdot
.496 .20661 Mdot
.496 .20664 Mdot
.496 .20667 Mdot
.496 .20668 Mdot
.496 .2067 Mdot
.496 .20676 Mdot
.496 .20678 Mdot
.496 .20679 Mdot
.496 .20688 Mdot
.496 .20692 Mdot
.496 .20694 Mdot
.496 .20709 Mdot
.496 .20713 Mdot
.496 .20714 Mdot
.496 .20727 Mdot
.496 .20744 Mdot
.496 .20758 Mdot
.496 .20764 Mdot
.496 .20769 Mdot
.496 .20781 Mdot
.496 .20786 Mdot
.496 .20787 Mdot
.496 .20788 Mdot
.496 .20799 Mdot
.496 .20804 Mdot
.496 .2081 Mdot
.496 .20812 Mdot
.496 .20814 Mdot
.496 .20828 Mdot
.496 .20837 Mdot
.496 .20852 Mdot
.496 .20859 Mdot
.496 .20884 Mdot
.496 .20895 Mdot
.496 .20898 Mdot
.496 .20917 Mdot
.496 .20922 Mdot
.496 .20938 Mdot
.496 .20941 Mdot
.496 .20948 Mdot
.496 .20963 Mdot
.496 .20967 Mdot
.496 .20973 Mdot
.496 .20979 Mdot
.496 .21042 Mdot
.496 .21059 Mdot
.496 .21068 Mdot
.496 .21081 Mdot
.496 .21125 Mdot
.496 .21127 Mdot
.496 .21137 Mdot
.496 .21151 Mdot
.496 .21201 Mdot
.496 .21227 Mdot
.496 .21233 Mdot
.496 .21277 Mdot
.496 .2128 Mdot
.496 .21293 Mdot
.496 .21307 Mdot
.496 .21316 Mdot
.496 .21343 Mdot
.496 .21347 Mdot
.496 .21363 Mdot
.496 .21372 Mdot
.496 .21403 Mdot
.496 .21403 Mdot
.496 .21453 Mdot
.496 .21501 Mdot
.496 .21507 Mdot
.496 .21566 Mdot
.496 .21578 Mdot
.496 .21613 Mdot
.496 .2166 Mdot
.496 .21665 Mdot
.496 .21723 Mdot
.496 .21731 Mdot
.496 .21739 Mdot
.496 .21792 Mdot
.496 .21872 Mdot
.496 .21931 Mdot
.496 .21957 Mdot
.496 .21975 Mdot
.496 .22068 Mdot
.496 .22103 Mdot
.496 .22124 Mdot
.496 .22126 Mdot
.496 .22143 Mdot
.496 .22171 Mdot
.496 .22175 Mdot
.496 .22243 Mdot
.496 .22277 Mdot
.496 .22293 Mdot
.496 .22307 Mdot
.496 .22359 Mdot
.496 .22394 Mdot
.496 .22435 Mdot
.496 .22533 Mdot
.496 .22544 Mdot
.496 .22567 Mdot
.496 .2274 Mdot
.496 .22757 Mdot
.496 .22829 Mdot
.496 .22838 Mdot
.496 .22903 Mdot
.496 .22987 Mdot
.496 .2301 Mdot
.496 .23053 Mdot
.496 .23062 Mdot
.496 .23063 Mdot
.496 .23108 Mdot
.496 .23152 Mdot
.496 .23162 Mdot
.496 .23164 Mdot
.496 .23192 Mdot
.496 .23224 Mdot
.496 .23248 Mdot
.496 .23259 Mdot
.496 .23266 Mdot
.496 .23285 Mdot
.496 .23294 Mdot
.496 .23295 Mdot
.496 .23312 Mdot
.496 .23327 Mdot
.496 .23332 Mdot
.496 .23351 Mdot
.496 .23362 Mdot
.496 .23381 Mdot
.496 .23389 Mdot
.496 .23419 Mdot
.496 .23431 Mdot
.496 .23455 Mdot
.496 .2346 Mdot
.496 .23476 Mdot
.496 .23486 Mdot
.496 .23501 Mdot
.496 .23505 Mdot
.496 .2351 Mdot
.496 .23596 Mdot
.496 .23643 Mdot
.496 .23653 Mdot
.496 .23664 Mdot
.496 .23702 Mdot
.496 .23759 Mdot
.496 .23768 Mdot
.496 .23784 Mdot
.496 .23805 Mdot
.496 .23816 Mdot
.496 .23822 Mdot
.496 .23842 Mdot
.496 .23874 Mdot
.496 .23904 Mdot
.496 .23907 Mdot
.496 .23943 Mdot
.496 .23998 Mdot
.496 .24033 Mdot
.496 .24037 Mdot
.496 .24042 Mdot
.496 .24113 Mdot
.496 .24144 Mdot
.496 .24157 Mdot
.496 .24213 Mdot
.496 .24241 Mdot
.496 .24263 Mdot
.496 .24265 Mdot
.496 .24297 Mdot
.496 .24313 Mdot
.496 .24351 Mdot
.496 .24367 Mdot
.496 .24434 Mdot
.496 .24556 Mdot
.496 .24559 Mdot
.496 .24621 Mdot
.496 .2463 Mdot
.496 .24648 Mdot
.496 .24669 Mdot
.496 .24687 Mdot
.496 .24691 Mdot
.496 .24715 Mdot
.496 .24732 Mdot
.496 .24739 Mdot
.496 .24743 Mdot
.496 .24743 Mdot
.496 .2475 Mdot
.496 .24756 Mdot
.496 .24758 Mdot
.496 .24769 Mdot
.496 .24779 Mdot
.496 .24791 Mdot
.496 .24805 Mdot
.496 .24807 Mdot
.496 .24822 Mdot
.496 .24824 Mdot
.496 .24826 Mdot
.496 .24858 Mdot
.496 .24879 Mdot
.496 .24898 Mdot
.496 .24922 Mdot
.496 .24928 Mdot
.496 .24936 Mdot
.496 .2494 Mdot
.496 .24942 Mdot
.496 .2495 Mdot
.496 .24961 Mdot
.496 .24972 Mdot
.496 .24973 Mdot
.496 .2502 Mdot
.496 .25048 Mdot
.496 .25059 Mdot
.496 .25063 Mdot
.496 .25093 Mdot
.496 .25101 Mdot
.496 .25118 Mdot
.496 .25132 Mdot
.496 .25161 Mdot
.496 .25203 Mdot
.496 .25204 Mdot
.496 .25229 Mdot
.496 .25264 Mdot
.496 .25267 Mdot
.496 .25272 Mdot
.496 .25276 Mdot
.496 .25288 Mdot
.496 .25295 Mdot
.496 .25328 Mdot
.496 .25334 Mdot
.496 .25338 Mdot
.496 .25345 Mdot
.496 .25371 Mdot
.496 .25376 Mdot
.496 .25394 Mdot
.496 .25423 Mdot
.496 .25443 Mdot
.496 .25446 Mdot
.496 .25447 Mdot
.496 .25451 Mdot
.496 .25453 Mdot
.496 .25478 Mdot
.496 .25496 Mdot
.496 .25503 Mdot
.496 .25522 Mdot
.496 .25528 Mdot
.496 .25533 Mdot
.496 .25537 Mdot
.496 .25548 Mdot
.496 .25552 Mdot
.496 .25581 Mdot
.496 .25582 Mdot
.496 .25594 Mdot
.496 .25624 Mdot
.496 .25646 Mdot
.496 .25669 Mdot
.496 .25672 Mdot
.496 .2568 Mdot
.496 .25682 Mdot
.496 .25687 Mdot
.496 .25722 Mdot
.496 .25723 Mdot
.496 .25773 Mdot
.496 .25783 Mdot
.496 .25788 Mdot
.496 .25806 Mdot
.496 .25809 Mdot
.496 .25815 Mdot
.496 .25861 Mdot
.496 .25875 Mdot
.496 .25879 Mdot
.496 .2588 Mdot
.496 .25887 Mdot
.496 .25891 Mdot
.496 .25906 Mdot
.496 .2595 Mdot
.496 .25951 Mdot
.496 .25952 Mdot
.496 .25962 Mdot
.496 .25963 Mdot
.496 .25985 Mdot
.496 .25992 Mdot
.496 .25993 Mdot
.496 .26001 Mdot
.496 .26001 Mdot
.496 .26004 Mdot
.496 .26008 Mdot
.496 .26018 Mdot
.496 .26034 Mdot
.496 .26072 Mdot
.496 .26116 Mdot
.496 .26119 Mdot
.496 .26196 Mdot
.496 .2625 Mdot
.496 .26275 Mdot
.496 .26306 Mdot
.496 .26321 Mdot
.496 .26377 Mdot
.496 .26386 Mdot
.496 .26406 Mdot
.496 .26457 Mdot
.496 .26546 Mdot
.496 .26548 Mdot
.496 .26569 Mdot
.496 .26591 Mdot
.496 .26605 Mdot
.496 .26609 Mdot
.496 .26617 Mdot
.496 .26631 Mdot
.496 .26643 Mdot
.496 .2669 Mdot
.496 .26725 Mdot
.496 .26765 Mdot
.496 .26828 Mdot
.496 .26831 Mdot
.496 .26834 Mdot
.496 .26865 Mdot
.496 .26869 Mdot
.496 .26895 Mdot
.496 .26917 Mdot
.496 .26938 Mdot
.496 .2696 Mdot
.496 .26963 Mdot
.496 .26975 Mdot
.496 .26988 Mdot
.496 .26989 Mdot
.496 .26996 Mdot
.496 .2701 Mdot
.496 .27042 Mdot
.496 .2709 Mdot
.496 .27098 Mdot
.496 .27132 Mdot
.496 .27175 Mdot
.496 .2721 Mdot
.496 .27228 Mdot
.496 .2735 Mdot
.496 .27357 Mdot
.496 .27602 Mdot
.496 .27738 Mdot
.496 .2777 Mdot
.496 .27848 Mdot
.496 .27881 Mdot
.496 .27948 Mdot
.496 .27951 Mdot
.496 .27995 Mdot
.496 .28054 Mdot
.496 .2817 Mdot
.496 .28198 Mdot
.496 .28262 Mdot
.496 .28412 Mdot
.496 .28422 Mdot
.496 .28431 Mdot
.496 .28506 Mdot
.496 .28623 Mdot
.496 .28699 Mdot
.496 .28706 Mdot
.496 .2877 Mdot
.496 .28838 Mdot
.496 .28883 Mdot
.496 .28895 Mdot
.496 .28919 Mdot
.496 .28964 Mdot
.496 .28999 Mdot
.496 .29019 Mdot
.496 .29144 Mdot
.496 .29227 Mdot
.496 .29252 Mdot
.496 .29272 Mdot
.496 .29376 Mdot
.496 .29566 Mdot
.496 .29578 Mdot
.496 .29587 Mdot
.496 .2962 Mdot
.496 .29642 Mdot
.496 .29679 Mdot
.496 .29691 Mdot
.496 .29744 Mdot
.496 .29771 Mdot
.496 .29838 Mdot
.496 .29856 Mdot
.496 .29899 Mdot
.496 .29924 Mdot
.496 .29966 Mdot
.496 .29977 Mdot
.496 .30012 Mdot
.496 .3005 Mdot
.496 .30053 Mdot
.496 .30074 Mdot
.496 .30117 Mdot
.496 .30132 Mdot
.496 .30157 Mdot
.496 .30212 Mdot
.496 .30284 Mdot
.496 .30348 Mdot
.496 .30354 Mdot
.496 .30377 Mdot
.496 .30479 Mdot
.496 .3058 Mdot
.496 .30585 Mdot
.496 .30604 Mdot
.496 .30705 Mdot
.496 .30757 Mdot
.496 .30953 Mdot
.496 .31106 Mdot
.496 .31127 Mdot
.496 .31297 Mdot
.496 .31337 Mdot
.496 .31748 Mdot
.496 .31805 Mdot
.496 .31831 Mdot
.496 .32066 Mdot
.496 .32167 Mdot
.496 .32251 Mdot
.496 .32378 Mdot
.496 .32411 Mdot
.496 .32451 Mdot
.496 .32535 Mdot
.496 .32702 Mdot
.496 .32711 Mdot
.496 .3278 Mdot
.496 .3282 Mdot
.496 .32826 Mdot
.496 .32879 Mdot
.496 .32964 Mdot
.496 .33196 Mdot
.496 .33239 Mdot
.496 .33303 Mdot
.496 .33452 Mdot
.496 .33652 Mdot
.496 .33784 Mdot
.496 .33805 Mdot
.496 .33824 Mdot
.496 .33971 Mdot
.496 .33984 Mdot
.496 .34103 Mdot
.496 .34191 Mdot
.496 .34222 Mdot
.496 .34372 Mdot
.496 .34386 Mdot
.496 .34507 Mdot
.496 .34635 Mdot
.496 .34636 Mdot
.496 .34715 Mdot
.496 .34737 Mdot
.496 .3478 Mdot
.496 .34788 Mdot
.496 .34857 Mdot
.496 .3488 Mdot
.496 .34917 Mdot
.496 .34951 Mdot
.496 .34958 Mdot
.496 .35072 Mdot
.496 .35087 Mdot
.496 .35154 Mdot
.496 .35282 Mdot
.496 .35319 Mdot
.496 .35343 Mdot
.496 .35349 Mdot
.496 .35463 Mdot
.496 .35496 Mdot
.496 .35518 Mdot
.496 .35564 Mdot
.496 .35726 Mdot
.496 .35743 Mdot
.496 .35756 Mdot
.496 .35767 Mdot
.496 .35806 Mdot
.496 .35825 Mdot
.496 .35832 Mdot
.496 .35873 Mdot
.496 .35886 Mdot
.496 .35936 Mdot
.496 .35943 Mdot
.496 .35971 Mdot
.496 .36038 Mdot
.496 .36055 Mdot
.496 .36096 Mdot
.496 .36118 Mdot
.496 .36154 Mdot
.496 .3616 Mdot
.496 .36164 Mdot
.496 .36182 Mdot
.496 .36193 Mdot
.496 .36223 Mdot
.496 .36226 Mdot
.496 .36227 Mdot
.496 .36241 Mdot
.496 .36273 Mdot
.496 .36284 Mdot
.496 .36301 Mdot
.496 .36337 Mdot
.496 .3638 Mdot
.496 .36415 Mdot
.496 .36417 Mdot
.496 .36429 Mdot
.496 .36468 Mdot
.496 .36473 Mdot
.496 .36483 Mdot
.496 .36508 Mdot
.496 .36509 Mdot
.496 .36514 Mdot
.496 .36532 Mdot
.496 .36536 Mdot
.496 .36537 Mdot
.496 .36545 Mdot
.496 .36554 Mdot
.496 .4799 Mdot
.496 .47995 Mdot
.496 .47998 Mdot
.496 .47999 Mdot
.496 .48001 Mdot
.496 .48009 Mdot
.496 .48012 Mdot
.496 .48013 Mdot
.496 .48024 Mdot
.496 .48029 Mdot
.496 .48031 Mdot
.496 .4805 Mdot
.496 .48056 Mdot
.496 .48057 Mdot
.496 .48073 Mdot
.496 .48094 Mdot
.496 .48111 Mdot
.496 .48119 Mdot
.496 .48124 Mdot
.496 .48139 Mdot
.496 .48146 Mdot
.496 .48147 Mdot
.496 .48148 Mdot
.496 .48163 Mdot
.496 .48168 Mdot
.496 .48176 Mdot
.496 .48178 Mdot
.496 .48181 Mdot
.496 .48198 Mdot
.496 .48208 Mdot
.496 .48227 Mdot
.496 .48236 Mdot
.496 .48267 Mdot
.496 .4828 Mdot
.496 .48284 Mdot
.496 .48307 Mdot
.496 .48313 Mdot
.496 .48333 Mdot
.496 .48336 Mdot
.496 .48345 Mdot
.496 .48363 Mdot
.496 .48368 Mdot
.496 .48375 Mdot
.496 .48382 Mdot
.496 .48458 Mdot
.496 .48479 Mdot
.496 .4849 Mdot
.496 .48505 Mdot
.496 .48558 Mdot
.496 .48561 Mdot
.496 .48572 Mdot
.496 .48589 Mdot
.496 .48648 Mdot
.496 .48679 Mdot
.496 .48686 Mdot
.496 .48738 Mdot
.496 .48742 Mdot
.496 .48757 Mdot
.496 .48774 Mdot
.496 .48784 Mdot
.496 .48816 Mdot
.496 .4882 Mdot
.496 .48839 Mdot
.496 .48849 Mdot
.496 .48885 Mdot
.496 .48886 Mdot
.496 .48944 Mdot
.496 .48999 Mdot
.496 .49005 Mdot
.496 .49073 Mdot
.496 .49087 Mdot
.496 .49126 Mdot
.496 .4918 Mdot
.496 .49185 Mdot
.496 .49251 Mdot
.496 .49259 Mdot
.496 .49269 Mdot
.496 .49328 Mdot
.496 .49416 Mdot
.496 .49482 Mdot
.496 .4951 Mdot
.496 .49529 Mdot
.496 .49631 Mdot
.496 .49668 Mdot
.496 .49691 Mdot
.496 .49693 Mdot
.496 .49711 Mdot
.496 .49741 Mdot
.496 .49745 Mdot
.496 .49817 Mdot
.496 .49853 Mdot
.496 .49871 Mdot
.496 .49885 Mdot
.496 .4994 Mdot
.496 .49976 Mdot
.496 .50019 Mdot
.496 .50119 Mdot
.496 .5013 Mdot
.496 .50154 Mdot
.496 .50329 Mdot
.496 .50345 Mdot
.496 .50416 Mdot
.496 .50426 Mdot
.496 .5049 Mdot
.496 .50571 Mdot
.496 .50593 Mdot
.496 .50635 Mdot
.496 .50643 Mdot
.496 .50644 Mdot
.496 .50687 Mdot
.496 .50728 Mdot
.496 .50738 Mdot
.496 .5074 Mdot
.496 .50767 Mdot
.496 .50797 Mdot
.496 .50819 Mdot
.496 .5083 Mdot
.496 .50836 Mdot
.496 .50853 Mdot
.496 .50862 Mdot
.496 .50863 Mdot
.496 .50879 Mdot
.496 .50893 Mdot
.496 .50898 Mdot
.496 .50915 Mdot
.496 .50925 Mdot
.496 .50942 Mdot
.496 .5095 Mdot
.496 .50977 Mdot
.496 .50988 Mdot
.496 .5101 Mdot
.496 .51015 Mdot
.496 .5103 Mdot
.496 .51039 Mdot
.496 .51052 Mdot
.496 .51056 Mdot
.496 .5106 Mdot
.496 .51138 Mdot
.496 .51179 Mdot
.496 .51188 Mdot
.496 .51198 Mdot
.496 .51231 Mdot
.496 .51281 Mdot
.496 .51289 Mdot
.496 .51303 Mdot
.496 .51321 Mdot
.496 .51331 Mdot
.496 .51336 Mdot
.496 .51354 Mdot
.496 .51381 Mdot
.496 .51407 Mdot
.496 .5141 Mdot
.496 .5144 Mdot
.496 .51486 Mdot
.496 .51516 Mdot
.496 .5152 Mdot
.496 .51524 Mdot
.496 .51583 Mdot
.496 .51609 Mdot
.496 .51619 Mdot
.496 .51665 Mdot
.496 .51688 Mdot
.496 .51706 Mdot
.496 .51707 Mdot
.496 .51733 Mdot
.496 .51746 Mdot
.496 .51777 Mdot
.496 .51789 Mdot
.496 .51843 Mdot
.496 .51938 Mdot
.496 .51941 Mdot
.496 .51988 Mdot
.496 .51995 Mdot
.496 .52009 Mdot
.496 .52025 Mdot
.496 .52039 Mdot
.496 .52042 Mdot
.496 .5206 Mdot
.496 .52073 Mdot
.496 .52078 Mdot
.496 .52081 Mdot
.496 .52081 Mdot
.496 .52086 Mdot
.496 .52091 Mdot
.496 .52092 Mdot
.496 .52101 Mdot
.496 .52108 Mdot
.496 .52117 Mdot
.496 .52127 Mdot
.496 .52129 Mdot
.496 .5214 Mdot
.496 .52142 Mdot
.496 .52143 Mdot
.496 .52167 Mdot
.496 .52183 Mdot
.496 .52196 Mdot
.496 .52214 Mdot
.496 .52218 Mdot
.496 .52224 Mdot
.496 .52227 Mdot
.496 .52228 Mdot
.496 .52234 Mdot
.496 .52242 Mdot
.496 .5225 Mdot
.496 .52251 Mdot
.496 .52285 Mdot
.496 .52305 Mdot
.496 .52312 Mdot
.496 .52316 Mdot
.496 .52337 Mdot
.496 .52343 Mdot
.496 .52355 Mdot
.496 .52364 Mdot
.496 .52385 Mdot
.496 .52414 Mdot
.496 .52415 Mdot
.496 .52432 Mdot
.496 .52447 Mdot
.496 .52452 Mdot
.496 .52456 Mdot
.496 .52458 Mdot
.496 .52459 Mdot
.496 .52459 Mdot
.496 .52462 Mdot
.496 .52462 Mdot
.496 .52465 Mdot
.496 .52473 Mdot
.496 .52474 Mdot
.496 .52478 Mdot
.496 .52478 Mdot
.496 .52478 Mdot
.496 .52495 Mdot
.496 .52501 Mdot
.496 .52502 Mdot
.496 .52505 Mdot
.496 .52505 Mdot
.496 .52507 Mdot
.496 .52512 Mdot
.496 .52529 Mdot
.496 .52532 Mdot
.496 .52533 Mdot
.496 .5254 Mdot
.496 .52542 Mdot
.496 .52545 Mdot
.496 .52564 Mdot
.496 .52565 Mdot
.496 .52578 Mdot
.496 .5258 Mdot
.496 .52581 Mdot
.496 .52583 Mdot
.496 .52585 Mdot
.496 .52594 Mdot
.496 .52602 Mdot
.496 .52613 Mdot
.496 .52617 Mdot
.496 .52618 Mdot
.496 .52629 Mdot
.496 .5263 Mdot
.496 .52635 Mdot
.496 .52636 Mdot
.496 .52638 Mdot
.496 .5264 Mdot
.496 .52647 Mdot
.496 .5265 Mdot
.496 .52657 Mdot
.496 .52666 Mdot
.496 .52667 Mdot
.496 .52668 Mdot
.496 .52669 Mdot
.496 .5267 Mdot
.496 .52677 Mdot
.496 .52688 Mdot
.496 .52695 Mdot
.496 .52697 Mdot
.496 .52707 Mdot
.496 .52709 Mdot
.496 .52711 Mdot
.496 .52713 Mdot
.496 .52725 Mdot
.496 .52728 Mdot
.496 .52732 Mdot
.496 .52734 Mdot
.496 .52736 Mdot
.496 .52737 Mdot
.496 .5275 Mdot
.496 .52759 Mdot
.496 .5276 Mdot
.496 .52776 Mdot
.496 .52787 Mdot
.496 .52791 Mdot
.496 .52798 Mdot
.496 .52801 Mdot
.496 .52812 Mdot
.496 .52814 Mdot
.496 .52818 Mdot
.496 .52828 Mdot
.496 .52846 Mdot
.496 .52846 Mdot
.496 .5285 Mdot
.496 .52855 Mdot
.496 .52857 Mdot
.496 .52858 Mdot
.496 .52862 Mdot
.496 .52865 Mdot
.496 .52874 Mdot
.496 .52881 Mdot
.496 .52888 Mdot
.496 .52901 Mdot
.496 .52901 Mdot
.496 .52902 Mdot
.496 .52908 Mdot
.496 .52908 Mdot
.496 .52914 Mdot
.496 .52918 Mdot
.496 .52922 Mdot
.496 .52926 Mdot
.496 .52927 Mdot
.496 .52929 Mdot
.496 .52931 Mdot
.496 .52932 Mdot
.496 .52933 Mdot
.496 .52936 Mdot
.496 .52942 Mdot
.496 .52951 Mdot
.496 .52952 Mdot
.496 .52959 Mdot
.496 .52967 Mdot
.496 .52973 Mdot
.496 .52977 Mdot
.496 .52999 Mdot
.496 .53001 Mdot
.496 .53046 Mdot
.496 .53071 Mdot
.496 .53076 Mdot
.496 .5309 Mdot
.496 .53096 Mdot
.496 .53108 Mdot
.496 .53109 Mdot
.496 .53117 Mdot
.496 .53127 Mdot
.496 .53148 Mdot
.496 .53153 Mdot
.496 .53164 Mdot
.496 .5319 Mdot
.496 .53192 Mdot
.496 .53193 Mdot
.496 .53206 Mdot
.496 .53227 Mdot
.496 .5324 Mdot
.496 .53241 Mdot
.496 .53252 Mdot
.496 .53263 Mdot
.496 .53271 Mdot
.496 .53273 Mdot
.496 .53277 Mdot
.496 .53285 Mdot
.496 .5329 Mdot
.496 .53294 Mdot
.496 .53315 Mdot
.496 .53329 Mdot
.496 .53333 Mdot
.496 .53336 Mdot
.496 .53353 Mdot
.496 .53385 Mdot
.496 .53386 Mdot
.496 .53388 Mdot
.496 .53393 Mdot
.496 .53397 Mdot
.496 .53403 Mdot
.496 .53405 Mdot
.496 .53413 Mdot
.496 .53418 Mdot
.496 .53429 Mdot
.496 .53432 Mdot
.496 .53439 Mdot
.496 .53443 Mdot
.496 .53449 Mdot
.496 .53451 Mdot
.496 .53457 Mdot
.496 .53463 Mdot
.496 .53463 Mdot
.496 .53467 Mdot
.496 .53473 Mdot
.496 .53476 Mdot
.496 .5348 Mdot
.496 .53489 Mdot
.496 .535 Mdot
.496 .5351 Mdot
.496 .53511 Mdot
.496 .53515 Mdot
.496 .53531 Mdot
.496 .53547 Mdot
.496 .53547 Mdot
.496 .5355 Mdot
.496 .53566 Mdot
.496 .53574 Mdot
.496 .53604 Mdot
.496 .53628 Mdot
.496 .53631 Mdot
.496 .53657 Mdot
.496 .53663 Mdot
.496 .53725 Mdot
.496 .53734 Mdot
.496 .53738 Mdot
.496 .53772 Mdot
.496 .53787 Mdot
.496 .538 Mdot
.496 .53818 Mdot
.496 .53823 Mdot
.496 .53829 Mdot
.496 .53841 Mdot
.496 .53866 Mdot
.496 .53867 Mdot
.496 .53877 Mdot
.496 .53883 Mdot
.496 .53884 Mdot
.496 .53891 Mdot
.496 .53903 Mdot
.496 .53937 Mdot
.496 .53943 Mdot
.496 .53952 Mdot
.496 .53973 Mdot
.496 .54001 Mdot
.496 .5402 Mdot
.496 .54023 Mdot
.496 .54026 Mdot
.496 .54046 Mdot
.496 .54048 Mdot
.496 .54065 Mdot
.496 .54077 Mdot
.496 .54081 Mdot
.496 .54102 Mdot
.496 .54104 Mdot
.496 .54121 Mdot
.496 .54139 Mdot
.496 .54139 Mdot
.496 .5415 Mdot
.496 .54153 Mdot
.496 .54159 Mdot
.496 .5416 Mdot
.496 .54169 Mdot
.496 .54172 Mdot
.496 .54178 Mdot
.496 .54182 Mdot
.496 .54183 Mdot
.496 .54199 Mdot
.496 .54201 Mdot
.496 .5421 Mdot
.496 .54227 Mdot
.496 .54232 Mdot
.496 .54236 Mdot
.496 .54237 Mdot
.496 .54252 Mdot
.496 .54256 Mdot
.496 .5426 Mdot
.496 .54266 Mdot
.496 .54288 Mdot
.496 .5429 Mdot
.496 .54292 Mdot
.496 .54293 Mdot
.496 .54298 Mdot
.496 .54301 Mdot
.496 .54302 Mdot
.496 .54307 Mdot
.496 .54309 Mdot
.496 .54316 Mdot
.496 .54317 Mdot
.496 .54321 Mdot
.496 .5433 Mdot
.496 .54332 Mdot
.496 .54337 Mdot
.496 .5434 Mdot
.496 .54345 Mdot
.496 .54346 Mdot
.496 .54347 Mdot
.496 .54349 Mdot
.496 .5435 Mdot
.496 .54354 Mdot
.496 .54355 Mdot
.496 .54355 Mdot
.496 .54357 Mdot
.496 .54361 Mdot
.496 .54363 Mdot
.496 .54365 Mdot
.496 .5437 Mdot
.496 .54375 Mdot
.496 .5438 Mdot
.496 .5438 Mdot
.496 .54382 Mdot
.496 .54387 Mdot
.496 .54388 Mdot
.496 .54389 Mdot
.496 .54392 Mdot
.496 .54393 Mdot
.496 .54393 Mdot
.496 .54396 Mdot
.496 .54396 Mdot
.496 .54396 Mdot
.496 .54398 Mdot
.496 .54399 Mdot
.498 .20601 Mdot
.498 .20602 Mdot
.498 .20602 Mdot
.498 .20602 Mdot
.498 .20604 Mdot
.498 .20604 Mdot
.498 .20605 Mdot
.498 .20605 Mdot
.498 .20605 Mdot
.498 .2061 Mdot
.498 .20615 Mdot
.498 .20617 Mdot
.498 .20621 Mdot
.498 .2063 Mdot
.498 .20632 Mdot
.498 .20635 Mdot
.498 .20653 Mdot
.498 .20654 Mdot
.498 .20689 Mdot
.498 .20694 Mdot
.498 .20707 Mdot
.498 .20713 Mdot
.498 .20722 Mdot
.498 .20731 Mdot
.498 .20735 Mdot
.498 .20735 Mdot
.498 .20738 Mdot
.498 .20746 Mdot
.498 .20753 Mdot
.498 .20764 Mdot
.498 .20782 Mdot
.498 .20807 Mdot
.498 .20813 Mdot
.498 .20824 Mdot
.498 .20825 Mdot
.498 .20831 Mdot
.498 .20832 Mdot
.498 .20859 Mdot
.498 .20868 Mdot
.498 .2087 Mdot
.498 .20875 Mdot
.498 .20883 Mdot
.498 .20887 Mdot
.498 .20887 Mdot
.498 .20887 Mdot
.498 .20917 Mdot
.498 .20917 Mdot
.498 .20918 Mdot
.498 .20927 Mdot
.498 .20928 Mdot
.498 .20932 Mdot
.498 .20958 Mdot
.498 .20959 Mdot
.498 .21012 Mdot
.498 .21063 Mdot
.498 .21142 Mdot
.498 .21195 Mdot
.498 .21212 Mdot
.498 .21237 Mdot
.498 .21245 Mdot
.498 .21245 Mdot
.498 .21307 Mdot
.498 .21364 Mdot
.498 .21368 Mdot
.498 .21403 Mdot
.498 .21431 Mdot
.498 .21437 Mdot
.498 .21452 Mdot
.498 .2146 Mdot
.498 .21467 Mdot
.498 .21573 Mdot
.498 .21575 Mdot
.498 .21598 Mdot
.498 .21601 Mdot
.498 .21727 Mdot
.498 .21742 Mdot
.498 .2175 Mdot
.498 .21805 Mdot
.498 .21855 Mdot
.498 .21933 Mdot
.498 .21988 Mdot
.498 .21996 Mdot
.498 .22007 Mdot
.498 .22044 Mdot
.498 .22133 Mdot
.498 .22143 Mdot
.498 .2227 Mdot
.498 .22313 Mdot
.498 .22335 Mdot
.498 .22347 Mdot
.498 .22347 Mdot
.498 .22348 Mdot
.498 .22374 Mdot
.498 .22375 Mdot
.498 .22375 Mdot
.498 .22385 Mdot
.498 .22391 Mdot
.498 .22392 Mdot
.498 .22401 Mdot
.498 .22435 Mdot
.498 .22448 Mdot
.498 .22454 Mdot
.498 .22482 Mdot
.498 .22527 Mdot
.498 .2256 Mdot
.498 .22573 Mdot
.498 .22603 Mdot
.498 .2261 Mdot
.498 .22677 Mdot
.498 .22731 Mdot
.498 .22767 Mdot
.498 .22782 Mdot
.498 .22789 Mdot
.498 .22814 Mdot
.498 .22845 Mdot
.498 .22859 Mdot
.498 .2288 Mdot
.498 .22881 Mdot
.498 .22908 Mdot
.498 .22936 Mdot
.498 .22958 Mdot
.498 .22967 Mdot
.498 .22968 Mdot
.498 .23082 Mdot
.498 .23096 Mdot
.498 .23141 Mdot
.498 .23244 Mdot
.498 .2328 Mdot
.498 .23286 Mdot
.498 .23286 Mdot
.498 .2329 Mdot
.498 .23311 Mdot
.498 .23325 Mdot
.498 .23398 Mdot
.498 .23406 Mdot
.498 .23407 Mdot
.498 .23461 Mdot
.498 .23504 Mdot
.498 .23504 Mdot
.498 .23533 Mdot
.498 .23621 Mdot
.498 .23682 Mdot
.498 .2375 Mdot
.498 .23755 Mdot
.498 .23755 Mdot
.498 .23797 Mdot
.498 .23859 Mdot
.498 .2388 Mdot
.498 .23894 Mdot
.498 .2396 Mdot
.498 .23974 Mdot
.498 .23976 Mdot
.498 .24046 Mdot
.498 .24058 Mdot
.498 .24087 Mdot
.498 .24153 Mdot
.498 .24184 Mdot
.498 .2425 Mdot
.498 .24255 Mdot
.498 .24314 Mdot
.498 .24333 Mdot
.498 .24343 Mdot
.498 .24349 Mdot
.498 .24349 Mdot
.498 .24349 Mdot
.498 .24361 Mdot
.498 .24361 Mdot
.498 .24368 Mdot
.498 .24369 Mdot
.498 .24373 Mdot
.498 .24388 Mdot
.498 .24409 Mdot
.498 .24428 Mdot
.498 .24442 Mdot
.498 .24448 Mdot
.498 .24461 Mdot
.498 .24464 Mdot
.498 .24492 Mdot
.498 .24515 Mdot
.498 .24536 Mdot
.498 .24562 Mdot
.498 .24577 Mdot
.498 .24588 Mdot
.498 .24599 Mdot
.498 .24608 Mdot
.498 .24612 Mdot
.498 .2468 Mdot
.498 .2472 Mdot
.498 .24734 Mdot
.498 .24736 Mdot
.498 .24738 Mdot
.498 .24746 Mdot
.498 .24751 Mdot
.498 .24779 Mdot
.498 .24782 Mdot
.498 .24783 Mdot
.498 .24803 Mdot
.498 .2491 Mdot
.498 .24912 Mdot
.498 .24912 Mdot
.498 .24927 Mdot
.498 .2495 Mdot
.498 .24962 Mdot
.498 .24986 Mdot
.498 .24991 Mdot
.498 .24992 Mdot
.498 .25017 Mdot
.498 .25021 Mdot
.498 .25031 Mdot
.498 .25054 Mdot
.498 .25088 Mdot
.498 .2509 Mdot
.498 .25111 Mdot
.498 .25118 Mdot
.498 .2515 Mdot
.498 .25155 Mdot
.498 .25163 Mdot
.498 .25179 Mdot
.498 .2518 Mdot
.498 .25187 Mdot
.498 .25205 Mdot
.498 .25237 Mdot
.498 .25261 Mdot
.498 .25278 Mdot
.498 .25327 Mdot
.498 .25341 Mdot
.498 .2535 Mdot
.498 .25374 Mdot
.498 .25374 Mdot
.498 .25381 Mdot
.498 .25383 Mdot
.498 .25404 Mdot
.498 .25453 Mdot
.498 .25457 Mdot
.498 .25468 Mdot
.498 .25493 Mdot
.498 .25507 Mdot
.498 .25525 Mdot
.498 .25539 Mdot
.498 .25548 Mdot
.498 .25576 Mdot
.498 .25588 Mdot
.498 .25589 Mdot
.498 .25594 Mdot
.498 .25607 Mdot
.498 .25612 Mdot
.498 .2562 Mdot
.498 .25649 Mdot
.498 .25692 Mdot
.498 .25707 Mdot
.498 .25717 Mdot
.498 .25743 Mdot
.498 .25747 Mdot
.498 .2576 Mdot
.498 .25761 Mdot
.498 .25781 Mdot
.498 .25801 Mdot
.498 .25804 Mdot
.498 .25818 Mdot
.498 .25844 Mdot
.498 .25933 Mdot
.498 .25964 Mdot
.498 .25968 Mdot
.498 .25975 Mdot
.498 .26008 Mdot
.498 .26059 Mdot
.498 .26066 Mdot
.498 .26073 Mdot
.498 .26082 Mdot
.498 .26098 Mdot
.498 .26112 Mdot
.498 .26126 Mdot
.498 .26144 Mdot
.498 .26146 Mdot
.498 .26154 Mdot
.498 .26158 Mdot
.498 .26167 Mdot
.498 .26179 Mdot
.498 .26202 Mdot
.498 .26205 Mdot
.498 .26205 Mdot
.498 .2621 Mdot
.498 .2621 Mdot
.498 .26218 Mdot
.498 .26218 Mdot
.498 .26218 Mdot
.498 .26221 Mdot
.498 .26228 Mdot
.498 .2624 Mdot
.498 .26279 Mdot
.498 .26282 Mdot
.498 .26345 Mdot
.498 .26389 Mdot
.498 .26408 Mdot
.498 .26417 Mdot
.498 .26463 Mdot
.498 .26465 Mdot
.498 .26474 Mdot
.498 .26519 Mdot
.498 .26543 Mdot
.498 .26585 Mdot
.498 .26615 Mdot
.498 .26615 Mdot
.498 .26619 Mdot
.498 .26824 Mdot
.498 .26864 Mdot
.498 .26865 Mdot
.498 .26871 Mdot
.498 .26925 Mdot
.498 .26935 Mdot
.498 .26951 Mdot
.498 .26954 Mdot
.498 .26958 Mdot
.498 .26986 Mdot
.498 .27064 Mdot
.498 .272 Mdot
.498 .27208 Mdot
.498 .27225 Mdot
.498 .27247 Mdot
.498 .27269 Mdot
.498 .27299 Mdot
.498 .2735 Mdot
.498 .27393 Mdot
.498 .27439 Mdot
.498 .27496 Mdot
.498 .27502 Mdot
.498 .27528 Mdot
.498 .27539 Mdot
.498 .27568 Mdot
.498 .27607 Mdot
.498 .2765 Mdot
.498 .27681 Mdot
.498 .27689 Mdot
.498 .2769 Mdot
.498 .27704 Mdot
.498 .27705 Mdot
.498 .27729 Mdot
.498 .27729 Mdot
.498 .2773 Mdot
.498 .27741 Mdot
.498 .27761 Mdot
.498 .27802 Mdot
.498 .27923 Mdot
.498 .27933 Mdot
.498 .2807 Mdot
.498 .28135 Mdot
.498 .28273 Mdot
.498 .28335 Mdot
.498 .28361 Mdot
.498 .28508 Mdot
.498 .28512 Mdot
.498 .28542 Mdot
.498 .28685 Mdot
.498 .28714 Mdot
.498 .28759 Mdot
.498 .28893 Mdot
.498 .28984 Mdot
.498 .28985 Mdot
.498 .28996 Mdot
.498 .29145 Mdot
.498 .29278 Mdot
.498 .29474 Mdot
.498 .29537 Mdot
.498 .29538 Mdot
.498 .29635 Mdot
.498 .29755 Mdot
.498 .29758 Mdot
.498 .29777 Mdot
.498 .29941 Mdot
.498 .29974 Mdot
.498 .30021 Mdot
.498 .30029 Mdot
.498 .3003 Mdot
.498 .30043 Mdot
.498 .30125 Mdot
.498 .30362 Mdot
.498 .30465 Mdot
.498 .30497 Mdot
.498 .30763 Mdot
.498 .30764 Mdot
.498 .30786 Mdot
.498 .30836 Mdot
.498 .30902 Mdot
.498 .30965 Mdot
.498 .30967 Mdot
.498 .31017 Mdot
.498 .31051 Mdot
.498 .31124 Mdot
.498 .31182 Mdot
.498 .31199 Mdot
.498 .31236 Mdot
.498 .31319 Mdot
.498 .31449 Mdot
.498 .31609 Mdot
.498 .31626 Mdot
.498 .31697 Mdot
.498 .3173 Mdot
.498 .31808 Mdot
.498 .31915 Mdot
.498 .31984 Mdot
.498 .31998 Mdot
.498 .32031 Mdot
.498 .32113 Mdot
.498 .32135 Mdot
.498 .32138 Mdot
.498 .3215 Mdot
.498 .32177 Mdot
.498 .32177 Mdot
.498 .32178 Mdot
.498 .32243 Mdot
.498 .32243 Mdot
.498 .32245 Mdot
.498 .32274 Mdot
.498 .32327 Mdot
.498 .32432 Mdot
.498 .32744 Mdot
.498 .32769 Mdot
.498 .3299 Mdot
.498 .3308 Mdot
.498 .33108 Mdot
.498 .33128 Mdot
.498 .33264 Mdot
.498 .33459 Mdot
.498 .33585 Mdot
.498 .33725 Mdot
.498 .33744 Mdot
.498 .33781 Mdot
.498 .34099 Mdot
.498 .34109 Mdot
.498 .34165 Mdot
.498 .34171 Mdot
.498 .3444 Mdot
.498 .34459 Mdot
.498 .34479 Mdot
.498 .34516 Mdot
.498 .34533 Mdot
.498 .34603 Mdot
.498 .34693 Mdot
.498 .34705 Mdot
.498 .34849 Mdot
.498 .3501 Mdot
.498 .3501 Mdot
.498 .35031 Mdot
.498 .35094 Mdot
.498 .35137 Mdot
.498 .35275 Mdot
.498 .35478 Mdot
.498 .35611 Mdot
.498 .3575 Mdot
.498 .35752 Mdot
.498 .3582 Mdot
.498 .3583 Mdot
.498 .35831 Mdot
.498 .35856 Mdot
.498 .35858 Mdot
.498 .35858 Mdot
.498 .35936 Mdot
.498 .35937 Mdot
.498 .35937 Mdot
.498 .35946 Mdot
.498 .35967 Mdot
.498 .35981 Mdot
.498 .35984 Mdot
.498 .36008 Mdot
.498 .36079 Mdot
.498 .36082 Mdot
.498 .36097 Mdot
.498 .36101 Mdot
.498 .3613 Mdot
.498 .36144 Mdot
.498 .3621 Mdot
.498 .36258 Mdot
.498 .36286 Mdot
.498 .36305 Mdot
.498 .36326 Mdot
.498 .36332 Mdot
.498 .36333 Mdot
.498 .36343 Mdot
.498 .36367 Mdot
.498 .36391 Mdot
.498 .36405 Mdot
.498 .36441 Mdot
.498 .36452 Mdot
.498 .36544 Mdot
.498 .36548 Mdot
.498 .36594 Mdot
.498 .36602 Mdot
.498 .36607 Mdot
.498 .36631 Mdot
.498 .36642 Mdot
.498 .36646 Mdot
.498 .3666 Mdot
.498 .36672 Mdot
.498 .36673 Mdot
.498 .36674 Mdot
.498 .36676 Mdot
.498 .36676 Mdot
.498 .3668 Mdot
.498 .3668 Mdot
.498 .3668 Mdot
.498 .36682 Mdot
.498 .47936 Mdot
.498 .47937 Mdot
.498 .47937 Mdot
.498 .47937 Mdot
.498 .47939 Mdot
.498 .47939 Mdot
.498 .47941 Mdot
.498 .47941 Mdot
.498 .47941 Mdot
.498 .47947 Mdot
.498 .47954 Mdot
.498 .47956 Mdot
.498 .47961 Mdot
.498 .47972 Mdot
.498 .47975 Mdot
.498 .47979 Mdot
.498 .48001 Mdot
.498 .48002 Mdot
.498 .48046 Mdot
.498 .48052 Mdot
.498 .48069 Mdot
.498 .48076 Mdot
.498 .48087 Mdot
.498 .48098 Mdot
.498 .48103 Mdot
.498 .48104 Mdot
.498 .48107 Mdot
.498 .48117 Mdot
.498 .48125 Mdot
.498 .48139 Mdot
.498 .48162 Mdot
.498 .48193 Mdot
.498 .482 Mdot
.498 .48213 Mdot
.498 .48215 Mdot
.498 .48222 Mdot
.498 .48223 Mdot
.498 .48257 Mdot
.498 .48268 Mdot
.498 .4827 Mdot
.498 .48276 Mdot
.498 .48286 Mdot
.498 .48291 Mdot
.498 .48291 Mdot
.498 .48291 Mdot
.498 .48328 Mdot
.498 .48328 Mdot
.498 .48329 Mdot
.498 .4834 Mdot
.498 .48341 Mdot
.498 .48346 Mdot
.498 .48377 Mdot
.498 .48378 Mdot
.498 .48443 Mdot
.498 .48505 Mdot
.498 .48599 Mdot
.498 .48663 Mdot
.498 .48682 Mdot
.498 .48712 Mdot
.498 .48721 Mdot
.498 .48721 Mdot
.498 .48795 Mdot
.498 .48861 Mdot
.498 .48866 Mdot
.498 .48907 Mdot
.498 .48939 Mdot
.498 .48946 Mdot
.498 .48963 Mdot
.498 .48972 Mdot
.498 .48981 Mdot
.498 .49102 Mdot
.498 .49105 Mdot
.498 .4913 Mdot
.498 .49135 Mdot
.498 .49276 Mdot
.498 .49293 Mdot
.498 .49302 Mdot
.498 .49364 Mdot
.498 .49419 Mdot
.498 .49505 Mdot
.498 .49565 Mdot
.498 .49574 Mdot
.498 .49586 Mdot
.498 .49625 Mdot
.498 .49721 Mdot
.498 .49733 Mdot
.498 .49867 Mdot
.498 .49913 Mdot
.498 .49936 Mdot
.498 .49948 Mdot
.498 .49949 Mdot
.498 .49949 Mdot
.498 .49977 Mdot
.498 .49977 Mdot
.498 .49977 Mdot
.498 .49989 Mdot
.498 .49994 Mdot
.498 .49995 Mdot
.498 .50004 Mdot
.498 .5004 Mdot
.498 .50054 Mdot
.498 .5006 Mdot
.498 .50089 Mdot
.498 .50135 Mdot
.498 .50168 Mdot
.498 .50182 Mdot
.498 .50212 Mdot
.498 .50219 Mdot
.498 .50287 Mdot
.498 .50341 Mdot
.498 .50377 Mdot
.498 .50392 Mdot
.498 .50399 Mdot
.498 .50424 Mdot
.498 .50454 Mdot
.498 .50468 Mdot
.498 .50489 Mdot
.498 .5049 Mdot
.498 .50516 Mdot
.498 .50544 Mdot
.498 .50565 Mdot
.498 .50574 Mdot
.498 .50574 Mdot
.498 .50684 Mdot
.498 .50698 Mdot
.498 .5074 Mdot
.498 .50837 Mdot
.498 .50871 Mdot
.498 .50876 Mdot
.498 .50877 Mdot
.498 .5088 Mdot
.498 .509 Mdot
.498 .50913 Mdot
.498 .5098 Mdot
.498 .50987 Mdot
.498 .50989 Mdot
.498 .51038 Mdot
.498 .51077 Mdot
.498 .51077 Mdot
.498 .51103 Mdot
.498 .51182 Mdot
.498 .51236 Mdot
.498 .51295 Mdot
.498 .513 Mdot
.498 .513 Mdot
.498 .51337 Mdot
.498 .5139 Mdot
.498 .51408 Mdot
.498 .5142 Mdot
.498 .51477 Mdot
.498 .51488 Mdot
.498 .5149 Mdot
.498 .51549 Mdot
.498 .51559 Mdot
.498 .51583 Mdot
.498 .51638 Mdot
.498 .51663 Mdot
.498 .51717 Mdot
.498 .51721 Mdot
.498 .51769 Mdot
.498 .51785 Mdot
.498 .51793 Mdot
.498 .51797 Mdot
.498 .51797 Mdot
.498 .51797 Mdot
.498 .51807 Mdot
.498 .51807 Mdot
.498 .51813 Mdot
.498 .51813 Mdot
.498 .51816 Mdot
.498 .51828 Mdot
.498 .51845 Mdot
.498 .5186 Mdot
.498 .51871 Mdot
.498 .51876 Mdot
.498 .51886 Mdot
.498 .51888 Mdot
.498 .51911 Mdot
.498 .51929 Mdot
.498 .51945 Mdot
.498 .51965 Mdot
.498 .51977 Mdot
.498 .51985 Mdot
.498 .51994 Mdot
.498 .52001 Mdot
.498 .52004 Mdot
.498 .52056 Mdot
.498 .52086 Mdot
.498 .52097 Mdot
.498 .52099 Mdot
.498 .521 Mdot
.498 .52106 Mdot
.498 .5211 Mdot
.498 .52131 Mdot
.498 .52133 Mdot
.498 .52133 Mdot
.498 .52149 Mdot
.498 .52228 Mdot
.498 .52229 Mdot
.498 .52229 Mdot
.498 .5224 Mdot
.498 .52257 Mdot
.498 .52266 Mdot
.498 .52283 Mdot
.498 .52287 Mdot
.498 .52287 Mdot
.498 .52305 Mdot
.498 .52308 Mdot
.498 .52316 Mdot
.498 .52332 Mdot
.498 .52356 Mdot
.498 .52358 Mdot
.498 .52372 Mdot
.498 .52377 Mdot
.498 .52379 Mdot
.498 .52381 Mdot
.498 .52381 Mdot
.498 .52381 Mdot
.498 .52384 Mdot
.498 .52384 Mdot
.498 .52386 Mdot
.498 .52386 Mdot
.498 .52387 Mdot
.498 .52395 Mdot
.498 .524 Mdot
.498 .52404 Mdot
.498 .52405 Mdot
.498 .52408 Mdot
.498 .52409 Mdot
.498 .52416 Mdot
.498 .52421 Mdot
.498 .52426 Mdot
.498 .52432 Mdot
.498 .52436 Mdot
.498 .52439 Mdot
.498 .52441 Mdot
.498 .5246 Mdot
.498 .52473 Mdot
.498 .52476 Mdot
.498 .52477 Mdot
.498 .52489 Mdot
.498 .52523 Mdot
.498 .52532 Mdot
.498 .52538 Mdot
.498 .52539 Mdot
.498 .52546 Mdot
.498 .52554 Mdot
.498 .52555 Mdot
.498 .52559 Mdot
.498 .52561 Mdot
.498 .52571 Mdot
.498 .52574 Mdot
.498 .5258 Mdot
.498 .52596 Mdot
.498 .52607 Mdot
.498 .5261 Mdot
.498 .52612 Mdot
.498 .52617 Mdot
.498 .52619 Mdot
.498 .52619 Mdot
.498 .52624 Mdot
.498 .52634 Mdot
.498 .52638 Mdot
.498 .52643 Mdot
.498 .5265 Mdot
.498 .52655 Mdot
.498 .52665 Mdot
.498 .52668 Mdot
.498 .5267 Mdot
.498 .52689 Mdot
.498 .52696 Mdot
.498 .52697 Mdot
.498 .527 Mdot
.498 .527 Mdot
.498 .52709 Mdot
.498 .52712 Mdot
.498 .52717 Mdot
.498 .52736 Mdot
.498 .52742 Mdot
.498 .52751 Mdot
.498 .52763 Mdot
.498 .5277 Mdot
.498 .52772 Mdot
.498 .52773 Mdot
.498 .52779 Mdot
.498 .52782 Mdot
.498 .52783 Mdot
.498 .52796 Mdot
.498 .52798 Mdot
.498 .52806 Mdot
.498 .52807 Mdot
.498 .52819 Mdot
.498 .52828 Mdot
.498 .52832 Mdot
.498 .52833 Mdot
.498 .52843 Mdot
.498 .52843 Mdot
.498 .52845 Mdot
.498 .52854 Mdot
.498 .52858 Mdot
.498 .52867 Mdot
.498 .52872 Mdot
.498 .52872 Mdot
.498 .52873 Mdot
.498 .52913 Mdot
.498 .5292 Mdot
.498 .52921 Mdot
.498 .52922 Mdot
.498 .52932 Mdot
.498 .52934 Mdot
.498 .52937 Mdot
.498 .52938 Mdot
.498 .52938 Mdot
.498 .52944 Mdot
.498 .52959 Mdot
.498 .52984 Mdot
.498 .52985 Mdot
.498 .52989 Mdot
.498 .52993 Mdot
.498 .52997 Mdot
.498 .53002 Mdot
.498 .53012 Mdot
.498 .5302 Mdot
.498 .53028 Mdot
.498 .53039 Mdot
.498 .5304 Mdot
.498 .53044 Mdot
.498 .53047 Mdot
.498 .53052 Mdot
.498 .53059 Mdot
.498 .53067 Mdot
.498 .53072 Mdot
.498 .53074 Mdot
.498 .53074 Mdot
.498 .53077 Mdot
.498 .53077 Mdot
.498 .53081 Mdot
.498 .53081 Mdot
.498 .53081 Mdot
.498 .53083 Mdot
.498 .53087 Mdot
.498 .53094 Mdot
.498 .53116 Mdot
.498 .53118 Mdot
.498 .53142 Mdot
.498 .53153 Mdot
.498 .53177 Mdot
.498 .53188 Mdot
.498 .53193 Mdot
.498 .53218 Mdot
.498 .53219 Mdot
.498 .53224 Mdot
.498 .53248 Mdot
.498 .53253 Mdot
.498 .53261 Mdot
.498 .53283 Mdot
.498 .53299 Mdot
.498 .53299 Mdot
.498 .53301 Mdot
.498 .53326 Mdot
.498 .53348 Mdot
.498 .5338 Mdot
.498 .5339 Mdot
.498 .5339 Mdot
.498 .53406 Mdot
.498 .53426 Mdot
.498 .53426 Mdot
.498 .53429 Mdot
.498 .53455 Mdot
.498 .53461 Mdot
.498 .53468 Mdot
.498 .5347 Mdot
.498 .5347 Mdot
.498 .53472 Mdot
.498 .53485 Mdot
.498 .53522 Mdot
.498 .53538 Mdot
.498 .53543 Mdot
.498 .53585 Mdot
.498 .53585 Mdot
.498 .53588 Mdot
.498 .53596 Mdot
.498 .53606 Mdot
.498 .53616 Mdot
.498 .53616 Mdot
.498 .53624 Mdot
.498 .53629 Mdot
.498 .5364 Mdot
.498 .53649 Mdot
.498 .53651 Mdot
.498 .53657 Mdot
.498 .5367 Mdot
.498 .53689 Mdot
.498 .53713 Mdot
.498 .53716 Mdot
.498 .53726 Mdot
.498 .53731 Mdot
.498 .53743 Mdot
.498 .53759 Mdot
.498 .53769 Mdot
.498 .53771 Mdot
.498 .53776 Mdot
.498 .53788 Mdot
.498 .53791 Mdot
.498 .53792 Mdot
.498 .53794 Mdot
.498 .53797 Mdot
.498 .53797 Mdot
.498 .53798 Mdot
.498 .53807 Mdot
.498 .53807 Mdot
.498 .53807 Mdot
.498 .53812 Mdot
.498 .53819 Mdot
.498 .53835 Mdot
.498 .5388 Mdot
.498 .53884 Mdot
.498 .53915 Mdot
.498 .53928 Mdot
.498 .53932 Mdot
.498 .53935 Mdot
.498 .53954 Mdot
.498 .53982 Mdot
.498 .54 Mdot
.498 .5402 Mdot
.498 .54022 Mdot
.498 .54028 Mdot
.498 .54072 Mdot
.498 .54073 Mdot
.498 .54081 Mdot
.498 .54082 Mdot
.498 .54119 Mdot
.498 .54122 Mdot
.498 .54125 Mdot
.498 .5413 Mdot
.498 .54132 Mdot
.498 .54142 Mdot
.498 .54156 Mdot
.498 .54176 Mdot
.498 .54198 Mdot
.498 .54198 Mdot
.498 .542 Mdot
.498 .54209 Mdot
.498 .54215 Mdot
.498 .54234 Mdot
.498 .54261 Mdot
.498 .54279 Mdot
.498 .54298 Mdot
.498 .54298 Mdot
.498 .54307 Mdot
.498 .54309 Mdot
.498 .54309 Mdot
.498 .54312 Mdot
.498 .54312 Mdot
.498 .54312 Mdot
.498 .54323 Mdot
.498 .54323 Mdot
.498 .54323 Mdot
.498 .54324 Mdot
.498 .54327 Mdot
.498 .54329 Mdot
.498 .54329 Mdot
.498 .54333 Mdot
.498 .54342 Mdot
.498 .54342 Mdot
.498 .54344 Mdot
.498 .54345 Mdot
.498 .54349 Mdot
.498 .54351 Mdot
.498 .5436 Mdot
.498 .54366 Mdot
.498 .5437 Mdot
.498 .54372 Mdot
.498 .54375 Mdot
.498 .54376 Mdot
.498 .54376 Mdot
.498 .54377 Mdot
.498 .5438 Mdot
.498 .54384 Mdot
.498 .54386 Mdot
.498 .5439 Mdot
.498 .54392 Mdot
.498 .54404 Mdot
.498 .54405 Mdot
.498 .54411 Mdot
.498 .54412 Mdot
.498 .54412 Mdot
.498 .54416 Mdot
.498 .54417 Mdot
.498 .54418 Mdot
.498 .54419 Mdot
.498 .54421 Mdot
.498 .54421 Mdot
.498 .54421 Mdot
.498 .54422 Mdot
.498 .54422 Mdot
.498 .54422 Mdot
.498 .54422 Mdot
.498 .54422 Mdot
.498 .54422 Mdot
.5 .20542 Mdot
.5 .20542 Mdot
.5 .20544 Mdot
.5 .20545 Mdot
.5 .20546 Mdot
.5 .2055 Mdot
.5 .20556 Mdot
.5 .20556 Mdot
.5 .20557 Mdot
.5 .2056 Mdot
.5 .20564 Mdot
.5 .20565 Mdot
.5 .20571 Mdot
.5 .20576 Mdot
.5 .20586 Mdot
.5 .20591 Mdot
.5 .20591 Mdot
.5 .20623 Mdot
.5 .20642 Mdot
.5 .2065 Mdot
.5 .20677 Mdot
.5 .20677 Mdot
.5 .20687 Mdot
.5 .20694 Mdot
.5 .20745 Mdot
.5 .20749 Mdot
.5 .20775 Mdot
.5 .20782 Mdot
.5 .20787 Mdot
.5 .20802 Mdot
.5 .20812 Mdot
.5 .20812 Mdot
.5 .20816 Mdot
.5 .20826 Mdot
.5 .20829 Mdot
.5 .20831 Mdot
.5 .20836 Mdot
.5 .20865 Mdot
.5 .20881 Mdot
.5 .20888 Mdot
.5 .20891 Mdot
.5 .20912 Mdot
.5 .20928 Mdot
.5 .20945 Mdot
.5 .20953 Mdot
.5 .20955 Mdot
.5 .20963 Mdot
.5 .2098 Mdot
.5 .20996 Mdot
.5 .2102 Mdot
.5 .21042 Mdot
.5 .2105 Mdot
.5 .2112 Mdot
.5 .21145 Mdot
.5 .21183 Mdot
.5 .21187 Mdot
.5 .2122 Mdot
.5 .21237 Mdot
.5 .21247 Mdot
.5 .21284 Mdot
.5 .21296 Mdot
.5 .2136 Mdot
.5 .21392 Mdot
.5 .21399 Mdot
.5 .21417 Mdot
.5 .21446 Mdot
.5 .21451 Mdot
.5 .21456 Mdot
.5 .21468 Mdot
.5 .21489 Mdot
.5 .21556 Mdot
.5 .21573 Mdot
.5 .21577 Mdot
.5 .21609 Mdot
.5 .21612 Mdot
.5 .21612 Mdot
.5 .21619 Mdot
.5 .21623 Mdot
.5 .21637 Mdot
.5 .2167 Mdot
.5 .21709 Mdot
.5 .21721 Mdot
.5 .21726 Mdot
.5 .21731 Mdot
.5 .21749 Mdot
.5 .21759 Mdot
.5 .21813 Mdot
.5 .21821 Mdot
.5 .21826 Mdot
.5 .21831 Mdot
.5 .21875 Mdot
.5 .21875 Mdot
.5 .21876 Mdot
.5 .21891 Mdot
.5 .21893 Mdot
.5 .21901 Mdot
.5 .21934 Mdot
.5 .21944 Mdot
.5 .2195 Mdot
.5 .21953 Mdot
.5 .21956 Mdot
.5 .2197 Mdot
.5 .21979 Mdot
.5 .22 Mdot
.5 .22035 Mdot
.5 .22042 Mdot
.5 .22098 Mdot
.5 .22101 Mdot
.5 .22124 Mdot
.5 .2214 Mdot
.5 .22186 Mdot
.5 .22224 Mdot
.5 .22235 Mdot
.5 .22254 Mdot
.5 .22255 Mdot
.5 .22262 Mdot
.5 .22288 Mdot
.5 .22352 Mdot
.5 .22357 Mdot
.5 .22361 Mdot
.5 .22374 Mdot
.5 .22375 Mdot
.5 .22384 Mdot
.5 .22399 Mdot
.5 .2241 Mdot
.5 .22502 Mdot
.5 .22511 Mdot
.5 .22524 Mdot
.5 .22606 Mdot
.5 .22671 Mdot
.5 .22671 Mdot
.5 .22707 Mdot
.5 .22722 Mdot
.5 .2274 Mdot
.5 .22757 Mdot
.5 .2277 Mdot
.5 .22774 Mdot
.5 .2283 Mdot
.5 .22838 Mdot
.5 .22854 Mdot
.5 .22886 Mdot
.5 .2291 Mdot
.5 .22981 Mdot
.5 .23013 Mdot
.5 .23042 Mdot
.5 .23105 Mdot
.5 .23216 Mdot
.5 .23229 Mdot
.5 .23269 Mdot
.5 .23356 Mdot
.5 .23362 Mdot
.5 .23399 Mdot
.5 .23434 Mdot
.5 .23447 Mdot
.5 .23482 Mdot
.5 .23496 Mdot
.5 .23503 Mdot
.5 .23506 Mdot
.5 .23538 Mdot
.5 .23568 Mdot
.5 .23614 Mdot
.5 .23631 Mdot
.5 .23758 Mdot
.5 .2377 Mdot
.5 .23776 Mdot
.5 .23867 Mdot
.5 .23997 Mdot
.5 .23999 Mdot
.5 .24007 Mdot
.5 .24018 Mdot
.5 .24025 Mdot
.5 .24055 Mdot
.5 .24072 Mdot
.5 .24099 Mdot
.5 .24103 Mdot
.5 .24106 Mdot
.5 .24108 Mdot
.5 .2413 Mdot
.5 .24131 Mdot
.5 .24139 Mdot
.5 .24139 Mdot
.5 .2416 Mdot
.5 .24168 Mdot
.5 .24169 Mdot
.5 .24182 Mdot
.5 .24208 Mdot
.5 .24212 Mdot
.5 .24239 Mdot
.5 .2425 Mdot
.5 .24258 Mdot
.5 .24325 Mdot
.5 .24356 Mdot
.5 .24363 Mdot
.5 .24364 Mdot
.5 .24368 Mdot
.5 .24374 Mdot
.5 .24419 Mdot
.5 .24422 Mdot
.5 .24428 Mdot
.5 .2449 Mdot
.5 .24525 Mdot
.5 .24531 Mdot
.5 .24532 Mdot
.5 .24558 Mdot
.5 .24565 Mdot
.5 .24615 Mdot
.5 .24639 Mdot
.5 .24663 Mdot
.5 .24706 Mdot
.5 .2476 Mdot
.5 .24762 Mdot
.5 .24793 Mdot
.5 .24806 Mdot
.5 .24814 Mdot
.5 .24815 Mdot
.5 .24827 Mdot
.5 .24838 Mdot
.5 .24907 Mdot
.5 .24914 Mdot
.5 .25019 Mdot
.5 .25032 Mdot
.5 .25039 Mdot
.5 .25042 Mdot
.5 .25057 Mdot
.5 .25066 Mdot
.5 .25077 Mdot
.5 .25121 Mdot
.5 .25123 Mdot
.5 .2514 Mdot
.5 .25142 Mdot
.5 .25177 Mdot
.5 .25186 Mdot
.5 .25254 Mdot
.5 .25272 Mdot
.5 .25272 Mdot
.5 .25305 Mdot
.5 .2534 Mdot
.5 .25423 Mdot
.5 .25445 Mdot
.5 .25584 Mdot
.5 .25623 Mdot
.5 .25679 Mdot
.5 .25711 Mdot
.5 .25758 Mdot
.5 .2576 Mdot
.5 .25772 Mdot
.5 .25835 Mdot
.5 .25887 Mdot
.5 .25894 Mdot
.5 .25895 Mdot
.5 .25927 Mdot
.5 .25928 Mdot
.5 .26017 Mdot
.5 .26052 Mdot
.5 .26068 Mdot
.5 .26134 Mdot
.5 .26137 Mdot
.5 .26168 Mdot
.5 .26172 Mdot
.5 .26175 Mdot
.5 .26175 Mdot
.5 .26199 Mdot
.5 .26248 Mdot
.5 .26255 Mdot
.5 .26273 Mdot
.5 .26275 Mdot
.5 .26292 Mdot
.5 .26301 Mdot
.5 .26306 Mdot
.5 .2632 Mdot
.5 .26325 Mdot
.5 .26326 Mdot
.5 .2634 Mdot
.5 .26342 Mdot
.5 .26343 Mdot
.5 .26346 Mdot
.5 .26364 Mdot
.5 .26375 Mdot
.5 .26395 Mdot
.5 .264 Mdot
.5 .26407 Mdot
.5 .26412 Mdot
.5 .26414 Mdot
.5 .26563 Mdot
.5 .26576 Mdot
.5 .26709 Mdot
.5 .2673 Mdot
.5 .26753 Mdot
.5 .26755 Mdot
.5 .26771 Mdot
.5 .26796 Mdot
.5 .26857 Mdot
.5 .26862 Mdot
.5 .26966 Mdot
.5 .2705 Mdot
.5 .27099 Mdot
.5 .27146 Mdot
.5 .27247 Mdot
.5 .2726 Mdot
.5 .27312 Mdot
.5 .27315 Mdot
.5 .27326 Mdot
.5 .27398 Mdot
.5 .27522 Mdot
.5 .27534 Mdot
.5 .27541 Mdot
.5 .27632 Mdot
.5 .27645 Mdot
.5 .27654 Mdot
.5 .27654 Mdot
.5 .2767 Mdot
.5 .27733 Mdot
.5 .27872 Mdot
.5 .27887 Mdot
.5 .2791 Mdot
.5 .27968 Mdot
.5 .27974 Mdot
.5 .2803 Mdot
.5 .28057 Mdot
.5 .28059 Mdot
.5 .28076 Mdot
.5 .28118 Mdot
.5 .2812 Mdot
.5 .28137 Mdot
.5 .28137 Mdot
.5 .28184 Mdot
.5 .28189 Mdot
.5 .28194 Mdot
.5 .28203 Mdot
.5 .28261 Mdot
.5 .28297 Mdot
.5 .2836 Mdot
.5 .28398 Mdot
.5 .28414 Mdot
.5 .28419 Mdot
.5 .28699 Mdot
.5 .28896 Mdot
.5 .2891 Mdot
.5 .28935 Mdot
.5 .29214 Mdot
.5 .29252 Mdot
.5 .29353 Mdot
.5 .2942 Mdot
.5 .29492 Mdot
.5 .29498 Mdot
.5 .29513 Mdot
.5 .29547 Mdot
.5 .29625 Mdot
.5 .29654 Mdot
.5 .29733 Mdot
.5 .29816 Mdot
.5 .29829 Mdot
.5 .30027 Mdot
.5 .30118 Mdot
.5 .30149 Mdot
.5 .30405 Mdot
.5 .30551 Mdot
.5 .30618 Mdot
.5 .30692 Mdot
.5 .30858 Mdot
.5 .30915 Mdot
.5 .30989 Mdot
.5 .31027 Mdot
.5 .31048 Mdot
.5 .3118 Mdot
.5 .31189 Mdot
.5 .3122 Mdot
.5 .31261 Mdot
.5 .31304 Mdot
.5 .31338 Mdot
.5 .31426 Mdot
.5 .31426 Mdot
.5 .3158 Mdot
.5 .31778 Mdot
.5 .3181 Mdot
.5 .31831 Mdot
.5 .32053 Mdot
.5 .32081 Mdot
.5 .32116 Mdot
.5 .3214 Mdot
.5 .3214 Mdot
.5 .32173 Mdot
.5 .32183 Mdot
.5 .32196 Mdot
.5 .32352 Mdot
.5 .32417 Mdot
.5 .32432 Mdot
.5 .32434 Mdot
.5 .32482 Mdot
.5 .32509 Mdot
.5 .32603 Mdot
.5 .32716 Mdot
.5 .32756 Mdot
.5 .32813 Mdot
.5 .3282 Mdot
.5 .3296 Mdot
.5 .32976 Mdot
.5 .33063 Mdot
.5 .33115 Mdot
.5 .33137 Mdot
.5 .33174 Mdot
.5 .33181 Mdot
.5 .33187 Mdot
.5 .33202 Mdot
.5 .33229 Mdot
.5 .3331 Mdot
.5 .33331 Mdot
.5 .33334 Mdot
.5 .33373 Mdot
.5 .33375 Mdot
.5 .33376 Mdot
.5 .33486 Mdot
.5 .335 Mdot
.5 .33511 Mdot
.5 .33531 Mdot
.5 .33667 Mdot
.5 .33693 Mdot
.5 .33738 Mdot
.5 .33749 Mdot
.5 .33764 Mdot
.5 .33794 Mdot
.5 .33891 Mdot
.5 .33975 Mdot
.5 .34011 Mdot
.5 .34022 Mdot
.5 .34039 Mdot
.5 .3404 Mdot
.5 .34046 Mdot
.5 .34129 Mdot
.5 .34137 Mdot
.5 .34181 Mdot
.5 .34352 Mdot
.5 .34406 Mdot
.5 .34436 Mdot
.5 .34448 Mdot
.5 .34463 Mdot
.5 .34537 Mdot
.5 .34582 Mdot
.5 .34601 Mdot
.5 .34682 Mdot
.5 .34847 Mdot
.5 .34877 Mdot
.5 .34973 Mdot
.5 .34998 Mdot
.5 .35043 Mdot
.5 .35127 Mdot
.5 .35139 Mdot
.5 .35235 Mdot
.5 .35302 Mdot
.5 .35483 Mdot
.5 .35503 Mdot
.5 .35561 Mdot
.5 .35623 Mdot
.5 .35663 Mdot
.5 .35708 Mdot
.5 .35731 Mdot
.5 .35734 Mdot
.5 .35755 Mdot
.5 .35801 Mdot
.5 .35843 Mdot
.5 .35896 Mdot
.5 .35904 Mdot
.5 .35923 Mdot
.5 .35965 Mdot
.5 .36039 Mdot
.5 .36054 Mdot
.5 .3606 Mdot
.5 .36066 Mdot
.5 .36093 Mdot
.5 .36103 Mdot
.5 .36104 Mdot
.5 .3613 Mdot
.5 .36169 Mdot
.5 .3618 Mdot
.5 .36199 Mdot
.5 .36267 Mdot
.5 .36279 Mdot
.5 .36411 Mdot
.5 .3643 Mdot
.5 .36456 Mdot
.5 .36457 Mdot
.5 .36527 Mdot
.5 .36549 Mdot
.5 .36598 Mdot
.5 .36683 Mdot
.5 .36683 Mdot
.5 .36697 Mdot
.5 .36722 Mdot
.5 .36736 Mdot
.5 .36751 Mdot
.5 .36754 Mdot
.5 .36764 Mdot
.5 .36773 Mdot
.5 .36773 Mdot
.5 .36775 Mdot
.5 .3679 Mdot
.5 .36801 Mdot
.5 .36803 Mdot
.5 .36807 Mdot
.5 .3681 Mdot
.5 .36811 Mdot
.5 .47882 Mdot
.5 .47883 Mdot
.5 .47884 Mdot
.5 .47886 Mdot
.5 .47887 Mdot
.5 .47892 Mdot
.5 .47899 Mdot
.5 .479 Mdot
.5 .479 Mdot
.5 .47905 Mdot
.5 .4791 Mdot
.5 .47911 Mdot
.5 .47918 Mdot
.5 .47925 Mdot
.5 .47937 Mdot
.5 .47943 Mdot
.5 .47943 Mdot
.5 .47984 Mdot
.5 .48008 Mdot
.5 .48018 Mdot
.5 .48052 Mdot
.5 .48052 Mdot
.5 .48065 Mdot
.5 .48073 Mdot
.5 .48136 Mdot
.5 .48142 Mdot
.5 .48174 Mdot
.5 .48183 Mdot
.5 .48188 Mdot
.5 .48207 Mdot
.5 .48219 Mdot
.5 .4822 Mdot
.5 .48224 Mdot
.5 .48237 Mdot
.5 .4824 Mdot
.5 .48243 Mdot
.5 .4825 Mdot
.5 .48285 Mdot
.5 .48304 Mdot
.5 .48313 Mdot
.5 .48317 Mdot
.5 .48342 Mdot
.5 .48361 Mdot
.5 .48383 Mdot
.5 .48393 Mdot
.5 .48394 Mdot
.5 .48405 Mdot
.5 .48426 Mdot
.5 .48444 Mdot
.5 .48474 Mdot
.5 .48501 Mdot
.5 .4851 Mdot
.5 .48594 Mdot
.5 .48624 Mdot
.5 .48669 Mdot
.5 .48674 Mdot
.5 .48713 Mdot
.5 .48733 Mdot
.5 .48745 Mdot
.5 .48789 Mdot
.5 .48802 Mdot
.5 .48878 Mdot
.5 .48914 Mdot
.5 .48923 Mdot
.5 .48944 Mdot
.5 .48977 Mdot
.5 .48984 Mdot
.5 .48989 Mdot
.5 .49003 Mdot
.5 .49027 Mdot
.5 .49104 Mdot
.5 .49124 Mdot
.5 .49128 Mdot
.5 .49165 Mdot
.5 .49167 Mdot
.5 .49168 Mdot
.5 .49176 Mdot
.5 .4918 Mdot
.5 .49196 Mdot
.5 .49234 Mdot
.5 .49277 Mdot
.5 .4929 Mdot
.5 .49297 Mdot
.5 .49302 Mdot
.5 .49322 Mdot
.5 .49333 Mdot
.5 .49394 Mdot
.5 .49403 Mdot
.5 .49408 Mdot
.5 .49414 Mdot
.5 .49462 Mdot
.5 .49463 Mdot
.5 .49464 Mdot
.5 .49481 Mdot
.5 .49482 Mdot
.5 .49491 Mdot
.5 .49527 Mdot
.5 .49539 Mdot
.5 .49545 Mdot
.5 .49548 Mdot
.5 .49551 Mdot
.5 .49567 Mdot
.5 .49577 Mdot
.5 .496 Mdot
.5 .49638 Mdot
.5 .49645 Mdot
.5 .49705 Mdot
.5 .49709 Mdot
.5 .49733 Mdot
.5 .49751 Mdot
.5 .498 Mdot
.5 .4984 Mdot
.5 .49852 Mdot
.5 .49872 Mdot
.5 .49874 Mdot
.5 .4988 Mdot
.5 .49908 Mdot
.5 .49975 Mdot
.5 .49981 Mdot
.5 .49985 Mdot
.5 .49999 Mdot
.5 .49999 Mdot
.5 .50009 Mdot
.5 .50024 Mdot
.5 .50036 Mdot
.5 .50131 Mdot
.5 .5014 Mdot
.5 .50153 Mdot
.5 .50237 Mdot
.5 .50302 Mdot
.5 .50302 Mdot
.5 .50339 Mdot
.5 .50353 Mdot
.5 .50372 Mdot
.5 .50389 Mdot
.5 .50402 Mdot
.5 .50405 Mdot
.5 .50461 Mdot
.5 .50469 Mdot
.5 .50485 Mdot
.5 .50516 Mdot
.5 .5054 Mdot
.5 .50609 Mdot
.5 .5064 Mdot
.5 .50667 Mdot
.5 .50728 Mdot
.5 .50833 Mdot
.5 .50846 Mdot
.5 .50883 Mdot
.5 .50964 Mdot
.5 .50969 Mdot
.5 .51003 Mdot
.5 .51035 Mdot
.5 .51047 Mdot
.5 .51079 Mdot
.5 .51092 Mdot
.5 .51098 Mdot
.5 .51101 Mdot
.5 .5113 Mdot
.5 .51157 Mdot
.5 .51198 Mdot
.5 .51213 Mdot
.5 .51325 Mdot
.5 .51335 Mdot
.5 .51341 Mdot
.5 .51419 Mdot
.5 .5153 Mdot
.5 .51532 Mdot
.5 .51539 Mdot
.5 .51554 Mdot
.5 .51579 Mdot
.5 .51593 Mdot
.5 .51616 Mdot
.5 .51619 Mdot
.5 .51621 Mdot
.5 .51623 Mdot
.5 .51642 Mdot
.5 .51642 Mdot
.5 .51648 Mdot
.5 .51649 Mdot
.5 .51666 Mdot
.5 .51672 Mdot
.5 .51673 Mdot
.5 .51684 Mdot
.5 .51706 Mdot
.5 .51708 Mdot
.5 .51731 Mdot
.5 .5174 Mdot
.5 .51746 Mdot
.5 .51801 Mdot
.5 .51825 Mdot
.5 .51831 Mdot
.5 .51831 Mdot
.5 .51835 Mdot
.5 .5184 Mdot
.5 .51875 Mdot
.5 .51878 Mdot
.5 .51883 Mdot
.5 .51931 Mdot
.5 .51959 Mdot
.5 .51963 Mdot
.5 .51964 Mdot
.5 .51985 Mdot
.5 .5199 Mdot
.5 .52029 Mdot
.5 .52047 Mdot
.5 .52066 Mdot
.5 .52098 Mdot
.5 .52139 Mdot
.5 .5214 Mdot
.5 .52164 Mdot
.5 .52174 Mdot
.5 .5218 Mdot
.5 .5218 Mdot
.5 .52189 Mdot
.5 .52197 Mdot
.5 .52248 Mdot
.5 .52253 Mdot
.5 .5231 Mdot
.5 .52311 Mdot
.5 .52313 Mdot
.5 .52316 Mdot
.5 .52317 Mdot
.5 .52325 Mdot
.5 .52329 Mdot
.5 .52336 Mdot
.5 .52337 Mdot
.5 .52338 Mdot
.5 .52338 Mdot
.5 .52344 Mdot
.5 .52344 Mdot
.5 .52346 Mdot
.5 .52351 Mdot
.5 .52353 Mdot
.5 .52357 Mdot
.5 .52363 Mdot
.5 .52364 Mdot
.5 .52371 Mdot
.5 .52374 Mdot
.5 .52392 Mdot
.5 .52401 Mdot
.5 .52401 Mdot
.5 .52402 Mdot
.5 .52404 Mdot
.5 .52416 Mdot
.5 .52417 Mdot
.5 .52442 Mdot
.5 .52448 Mdot
.5 .52461 Mdot
.5 .52495 Mdot
.5 .52495 Mdot
.5 .52508 Mdot
.5 .52508 Mdot
.5 .52511 Mdot
.5 .5253 Mdot
.5 .52554 Mdot
.5 .52559 Mdot
.5 .52559 Mdot
.5 .52577 Mdot
.5 .52589 Mdot
.5 .5261 Mdot
.5 .52625 Mdot
.5 .52677 Mdot
.5 .52685 Mdot
.5 .52716 Mdot
.5 .52729 Mdot
.5 .52742 Mdot
.5 .52742 Mdot
.5 .52749 Mdot
.5 .52774 Mdot
.5 .52777 Mdot
.5 .52791 Mdot
.5 .52791 Mdot
.5 .52797 Mdot
.5 .52798 Mdot
.5 .52815 Mdot
.5 .52819 Mdot
.5 .52822 Mdot
.5 .52828 Mdot
.5 .52829 Mdot
.5 .52832 Mdot
.5 .52837 Mdot
.5 .52876 Mdot
.5 .52878 Mdot
.5 .52904 Mdot
.5 .52908 Mdot
.5 .52912 Mdot
.5 .52913 Mdot
.5 .52916 Mdot
.5 .5292 Mdot
.5 .52932 Mdot
.5 .52933 Mdot
.5 .52953 Mdot
.5 .52978 Mdot
.5 .52986 Mdot
.5 .53005 Mdot
.5 .53007 Mdot
.5 .53017 Mdot
.5 .53018 Mdot
.5 .5302 Mdot
.5 .53033 Mdot
.5 .53056 Mdot
.5 .53058 Mdot
.5 .53059 Mdot
.5 .53075 Mdot
.5 .53078 Mdot
.5 .53079 Mdot
.5 .53079 Mdot
.5 .53082 Mdot
.5 .53094 Mdot
.5 .53118 Mdot
.5 .53121 Mdot
.5 .53125 Mdot
.5 .53135 Mdot
.5 .53136 Mdot
.5 .53146 Mdot
.5 .53151 Mdot
.5 .53151 Mdot
.5 .53154 Mdot
.5 .53162 Mdot
.5 .53162 Mdot
.5 .53165 Mdot
.5 .53165 Mdot
.5 .53173 Mdot
.5 .53174 Mdot
.5 .53175 Mdot
.5 .53176 Mdot
.5 .53187 Mdot
.5 .53193 Mdot
.5 .53204 Mdot
.5 .53206 Mdot
.5 .5321 Mdot
.5 .53213 Mdot
.5 .53214 Mdot
.5 .53262 Mdot
.5 .53295 Mdot
.5 .53297 Mdot
.5 .53301 Mdot
.5 .53348 Mdot
.5 .53354 Mdot
.5 .53371 Mdot
.5 .53382 Mdot
.5 .53393 Mdot
.5 .53394 Mdot
.5 .53397 Mdot
.5 .53402 Mdot
.5 .53415 Mdot
.5 .5342 Mdot
.5 .53432 Mdot
.5 .53446 Mdot
.5 .53448 Mdot
.5 .53479 Mdot
.5 .53494 Mdot
.5 .53498 Mdot
.5 .53539 Mdot
.5 .53561 Mdot
.5 .53572 Mdot
.5 .53583 Mdot
.5 .53609 Mdot
.5 .53618 Mdot
.5 .53629 Mdot
.5 .53635 Mdot
.5 .53638 Mdot
.5 .53658 Mdot
.5 .53659 Mdot
.5 .53664 Mdot
.5 .5367 Mdot
.5 .53677 Mdot
.5 .53682 Mdot
.5 .53695 Mdot
.5 .53695 Mdot
.5 .53718 Mdot
.5 .53747 Mdot
.5 .53752 Mdot
.5 .53755 Mdot
.5 .53788 Mdot
.5 .53792 Mdot
.5 .53797 Mdot
.5 .53801 Mdot
.5 .53801 Mdot
.5 .53806 Mdot
.5 .53807 Mdot
.5 .53809 Mdot
.5 .53832 Mdot
.5 .53841 Mdot
.5 .53843 Mdot
.5 .53844 Mdot
.5 .53851 Mdot
.5 .53855 Mdot
.5 .53868 Mdot
.5 .53884 Mdot
.5 .5389 Mdot
.5 .53898 Mdot
.5 .53899 Mdot
.5 .53919 Mdot
.5 .53922 Mdot
.5 .53934 Mdot
.5 .53941 Mdot
.5 .53945 Mdot
.5 .5395 Mdot
.5 .53951 Mdot
.5 .53952 Mdot
.5 .53954 Mdot
.5 .53958 Mdot
.5 .53969 Mdot
.5 .53972 Mdot
.5 .53973 Mdot
.5 .53978 Mdot
.5 .53978 Mdot
.5 .53978 Mdot
.5 .53994 Mdot
.5 .53996 Mdot
.5 .53998 Mdot
.5 .54 Mdot
.5 .5402 Mdot
.5 .54023 Mdot
.5 .54029 Mdot
.5 .54031 Mdot
.5 .54033 Mdot
.5 .54037 Mdot
.5 .54051 Mdot
.5 .54063 Mdot
.5 .54068 Mdot
.5 .54069 Mdot
.5 .54071 Mdot
.5 .54072 Mdot
.5 .54072 Mdot
.5 .54084 Mdot
.5 .54085 Mdot
.5 .54091 Mdot
.5 .54115 Mdot
.5 .54122 Mdot
.5 .54126 Mdot
.5 .54128 Mdot
.5 .5413 Mdot
.5 .5414 Mdot
.5 .54146 Mdot
.5 .54149 Mdot
.5 .5416 Mdot
.5 .54183 Mdot
.5 .54187 Mdot
.5 .542 Mdot
.5 .54203 Mdot
.5 .54209 Mdot
.5 .54221 Mdot
.5 .54222 Mdot
.5 .54235 Mdot
.5 .54244 Mdot
.5 .54269 Mdot
.5 .54272 Mdot
.5 .54279 Mdot
.5 .54288 Mdot
.5 .54293 Mdot
.5 .54299 Mdot
.5 .54302 Mdot
.5 .54303 Mdot
.5 .54306 Mdot
.5 .54312 Mdot
.5 .54317 Mdot
.5 .54324 Mdot
.5 .54325 Mdot
.5 .54328 Mdot
.5 .54334 Mdot
.5 .54343 Mdot
.5 .54345 Mdot
.5 .54346 Mdot
.5 .54347 Mdot
.5 .54351 Mdot
.5 .54352 Mdot
.5 .54352 Mdot
.5 .54356 Mdot
.5 .54361 Mdot
.5 .54362 Mdot
.5 .54365 Mdot
.5 .54374 Mdot
.5 .54376 Mdot
.5 .54393 Mdot
.5 .54395 Mdot
.5 .54399 Mdot
.5 .54399 Mdot
.5 .54408 Mdot
.5 .54411 Mdot
.5 .54418 Mdot
.5 .54429 Mdot
.5 .54429 Mdot
.5 .54431 Mdot
.5 .54434 Mdot
.5 .54436 Mdot
.5 .54438 Mdot
.5 .54438 Mdot
.5 .5444 Mdot
.5 .54441 Mdot
.5 .54441 Mdot
.5 .54441 Mdot
.5 .54443 Mdot
.5 .54445 Mdot
.5 .54445 Mdot
.5 .54445 Mdot
.5 .54446 Mdot
.5 .54446 Mdot
.502 .20483 Mdot
.502 .20483 Mdot
.502 .20484 Mdot
.502 .20487 Mdot
.502 .20487 Mdot
.502 .20488 Mdot
.502 .20488 Mdot
.502 .20494 Mdot
.502 .20495 Mdot
.502 .20501 Mdot
.502 .20507 Mdot
.502 .20513 Mdot
.502 .20517 Mdot
.502 .20519 Mdot
.502 .20522 Mdot
.502 .20523 Mdot
.502 .2053 Mdot
.502 .20532 Mdot
.502 .20546 Mdot
.502 .20548 Mdot
.502 .20551 Mdot
.502 .20566 Mdot
.502 .20575 Mdot
.502 .20578 Mdot
.502 .20607 Mdot
.502 .20613 Mdot
.502 .20619 Mdot
.502 .20622 Mdot
.502 .20638 Mdot
.502 .20648 Mdot
.502 .20658 Mdot
.502 .20678 Mdot
.502 .20731 Mdot
.502 .20735 Mdot
.502 .20744 Mdot
.502 .20775 Mdot
.502 .208 Mdot
.502 .20805 Mdot
.502 .20816 Mdot
.502 .20867 Mdot
.502 .20896 Mdot
.502 .20941 Mdot
.502 .20969 Mdot
.502 .2097 Mdot
.502 .2099 Mdot
.502 .20999 Mdot
.502 .21035 Mdot
.502 .21036 Mdot
.502 .21039 Mdot
.502 .21045 Mdot
.502 .21051 Mdot
.502 .21075 Mdot
.502 .21079 Mdot
.502 .2109 Mdot
.502 .2109 Mdot
.502 .21092 Mdot
.502 .21094 Mdot
.502 .21121 Mdot
.502 .21149 Mdot
.502 .21171 Mdot
.502 .21204 Mdot
.502 .2124 Mdot
.502 .21285 Mdot
.502 .21296 Mdot
.502 .21307 Mdot
.502 .21372 Mdot
.502 .21376 Mdot
.502 .21385 Mdot
.502 .21393 Mdot
.502 .21396 Mdot
.502 .21396 Mdot
.502 .21409 Mdot
.502 .21422 Mdot
.502 .21435 Mdot
.502 .21437 Mdot
.502 .21456 Mdot
.502 .2147 Mdot
.502 .21486 Mdot
.502 .21488 Mdot
.502 .21492 Mdot
.502 .21499 Mdot
.502 .21503 Mdot
.502 .21507 Mdot
.502 .21518 Mdot
.502 .21584 Mdot
.502 .2161 Mdot
.502 .21639 Mdot
.502 .21675 Mdot
.502 .21697 Mdot
.502 .21703 Mdot
.502 .21705 Mdot
.502 .21715 Mdot
.502 .21716 Mdot
.502 .21719 Mdot
.502 .21758 Mdot
.502 .21766 Mdot
.502 .21771 Mdot
.502 .21789 Mdot
.502 .21789 Mdot
.502 .21795 Mdot
.502 .21797 Mdot
.502 .21848 Mdot
.502 .21883 Mdot
.502 .21885 Mdot
.502 .21892 Mdot
.502 .21894 Mdot
.502 .21918 Mdot
.502 .21925 Mdot
.502 .21931 Mdot
.502 .21939 Mdot
.502 .21995 Mdot
.502 .22089 Mdot
.502 .22105 Mdot
.502 .22108 Mdot
.502 .2214 Mdot
.502 .22167 Mdot
.502 .22173 Mdot
.502 .22186 Mdot
.502 .22239 Mdot
.502 .22262 Mdot
.502 .22339 Mdot
.502 .22368 Mdot
.502 .22376 Mdot
.502 .2238 Mdot
.502 .22459 Mdot
.502 .22471 Mdot
.502 .22483 Mdot
.502 .22503 Mdot
.502 .22515 Mdot
.502 .22524 Mdot
.502 .22571 Mdot
.502 .22613 Mdot
.502 .22653 Mdot
.502 .22673 Mdot
.502 .22678 Mdot
.502 .22702 Mdot
.502 .22719 Mdot
.502 .22762 Mdot
.502 .2277 Mdot
.502 .22801 Mdot
.502 .22802 Mdot
.502 .22812 Mdot
.502 .22835 Mdot
.502 .22865 Mdot
.502 .22878 Mdot
.502 .22941 Mdot
.502 .23014 Mdot
.502 .23064 Mdot
.502 .23068 Mdot
.502 .23096 Mdot
.502 .23131 Mdot
.502 .23136 Mdot
.502 .23169 Mdot
.502 .2319 Mdot
.502 .23253 Mdot
.502 .23329 Mdot
.502 .23457 Mdot
.502 .23462 Mdot
.502 .23473 Mdot
.502 .23579 Mdot
.502 .23601 Mdot
.502 .2365 Mdot
.502 .23651 Mdot
.502 .23658 Mdot
.502 .23662 Mdot
.502 .23679 Mdot
.502 .23682 Mdot
.502 .23689 Mdot
.502 .23691 Mdot
.502 .2373 Mdot
.502 .23744 Mdot
.502 .23766 Mdot
.502 .23789 Mdot
.502 .23824 Mdot
.502 .2383 Mdot
.502 .2387 Mdot
.502 .23872 Mdot
.502 .23877 Mdot
.502 .23884 Mdot
.502 .23884 Mdot
.502 .23907 Mdot
.502 .23918 Mdot
.502 .23926 Mdot
.502 .23939 Mdot
.502 .23942 Mdot
.502 .23952 Mdot
.502 .24003 Mdot
.502 .24018 Mdot
.502 .24037 Mdot
.502 .24052 Mdot
.502 .24059 Mdot
.502 .24083 Mdot
.502 .24095 Mdot
.502 .24098 Mdot
.502 .24099 Mdot
.502 .24124 Mdot
.502 .24141 Mdot
.502 .24164 Mdot
.502 .24246 Mdot
.502 .24247 Mdot
.502 .24262 Mdot
.502 .24276 Mdot
.502 .24282 Mdot
.502 .24316 Mdot
.502 .2435 Mdot
.502 .24363 Mdot
.502 .24366 Mdot
.502 .24368 Mdot
.502 .24482 Mdot
.502 .24502 Mdot
.502 .2453 Mdot
.502 .24598 Mdot
.502 .24626 Mdot
.502 .24645 Mdot
.502 .24647 Mdot
.502 .24673 Mdot
.502 .24693 Mdot
.502 .24717 Mdot
.502 .24795 Mdot
.502 .24798 Mdot
.502 .24845 Mdot
.502 .24925 Mdot
.502 .25005 Mdot
.502 .25021 Mdot
.502 .25072 Mdot
.502 .25077 Mdot
.502 .25095 Mdot
.502 .25158 Mdot
.502 .25168 Mdot
.502 .252 Mdot
.502 .25206 Mdot
.502 .25256 Mdot
.502 .25348 Mdot
.502 .25388 Mdot
.502 .25406 Mdot
.502 .25604 Mdot
.502 .25636 Mdot
.502 .25655 Mdot
.502 .25708 Mdot
.502 .2575 Mdot
.502 .25797 Mdot
.502 .25845 Mdot
.502 .25876 Mdot
.502 .25923 Mdot
.502 .25937 Mdot
.502 .25965 Mdot
.502 .25966 Mdot
.502 .25978 Mdot
.502 .25996 Mdot
.502 .26038 Mdot
.502 .26055 Mdot
.502 .26139 Mdot
.502 .2615 Mdot
.502 .26172 Mdot
.502 .26197 Mdot
.502 .26207 Mdot
.502 .26216 Mdot
.502 .26269 Mdot
.502 .26284 Mdot
.502 .26296 Mdot
.502 .26313 Mdot
.502 .26342 Mdot
.502 .26365 Mdot
.502 .26375 Mdot
.502 .26408 Mdot
.502 .26418 Mdot
.502 .26431 Mdot
.502 .26439 Mdot
.502 .26462 Mdot
.502 .2649 Mdot
.502 .26494 Mdot
.502 .26518 Mdot
.502 .26549 Mdot
.502 .26559 Mdot
.502 .26586 Mdot
.502 .26587 Mdot
.502 .26592 Mdot
.502 .26594 Mdot
.502 .26606 Mdot
.502 .26613 Mdot
.502 .26614 Mdot
.502 .26648 Mdot
.502 .26738 Mdot
.502 .26746 Mdot
.502 .26898 Mdot
.502 .26945 Mdot
.502 .26985 Mdot
.502 .27037 Mdot
.502 .2704 Mdot
.502 .27078 Mdot
.502 .27134 Mdot
.502 .2727 Mdot
.502 .27326 Mdot
.502 .27366 Mdot
.502 .27599 Mdot
.502 .27603 Mdot
.502 .2761 Mdot
.502 .27636 Mdot
.502 .27705 Mdot
.502 .27775 Mdot
.502 .27788 Mdot
.502 .27818 Mdot
.502 .27849 Mdot
.502 .27851 Mdot
.502 .28021 Mdot
.502 .2807 Mdot
.502 .28106 Mdot
.502 .28159 Mdot
.502 .28162 Mdot
.502 .28167 Mdot
.502 .28193 Mdot
.502 .28243 Mdot
.502 .28257 Mdot
.502 .28291 Mdot
.502 .2833 Mdot
.502 .28363 Mdot
.502 .28471 Mdot
.502 .28492 Mdot
.502 .28501 Mdot
.502 .28528 Mdot
.502 .28545 Mdot
.502 .28568 Mdot
.502 .28619 Mdot
.502 .28619 Mdot
.502 .28632 Mdot
.502 .28644 Mdot
.502 .28649 Mdot
.502 .28734 Mdot
.502 .28748 Mdot
.502 .28825 Mdot
.502 .28875 Mdot
.502 .28922 Mdot
.502 .28953 Mdot
.502 .2904 Mdot
.502 .29043 Mdot
.502 .29059 Mdot
.502 .29066 Mdot
.502 .29104 Mdot
.502 .29113 Mdot
.502 .29127 Mdot
.502 .29129 Mdot
.502 .29238 Mdot
.502 .29287 Mdot
.502 .29525 Mdot
.502 .29549 Mdot
.502 .2956 Mdot
.502 .29849 Mdot
.502 .30023 Mdot
.502 .30168 Mdot
.502 .30216 Mdot
.502 .30293 Mdot
.502 .30303 Mdot
.502 .30384 Mdot
.502 .3045 Mdot
.502 .30459 Mdot
.502 .30576 Mdot
.502 .30746 Mdot
.502 .30895 Mdot
.502 .30926 Mdot
.502 .30995 Mdot
.502 .3105 Mdot
.502 .31075 Mdot
.502 .31078 Mdot
.502 .31149 Mdot
.502 .3117 Mdot
.502 .31273 Mdot
.502 .31313 Mdot
.502 .3137 Mdot
.502 .31381 Mdot
.502 .3143 Mdot
.502 .31525 Mdot
.502 .31626 Mdot
.502 .31741 Mdot
.502 .31761 Mdot
.502 .3179 Mdot
.502 .3184 Mdot
.502 .3187 Mdot
.502 .31899 Mdot
.502 .3209 Mdot
.502 .32099 Mdot
.502 .32119 Mdot
.502 .3219 Mdot
.502 .32379 Mdot
.502 .32435 Mdot
.502 .32566 Mdot
.502 .326 Mdot
.502 .32615 Mdot
.502 .32681 Mdot
.502 .32761 Mdot
.502 .32766 Mdot
.502 .32807 Mdot
.502 .33041 Mdot
.502 .3318 Mdot
.502 .332 Mdot
.502 .33217 Mdot
.502 .33233 Mdot
.502 .33294 Mdot
.502 .33298 Mdot
.502 .33316 Mdot
.502 .33321 Mdot
.502 .3341 Mdot
.502 .33537 Mdot
.502 .33543 Mdot
.502 .33557 Mdot
.502 .33557 Mdot
.502 .33603 Mdot
.502 .33617 Mdot
.502 .33636 Mdot
.502 .33735 Mdot
.502 .33743 Mdot
.502 .33744 Mdot
.502 .33769 Mdot
.502 .33775 Mdot
.502 .3379 Mdot
.502 .33846 Mdot
.502 .33936 Mdot
.502 .3401 Mdot
.502 .34078 Mdot
.502 .34273 Mdot
.502 .34283 Mdot
.502 .34293 Mdot
.502 .34311 Mdot
.502 .34321 Mdot
.502 .34329 Mdot
.502 .34369 Mdot
.502 .34404 Mdot
.502 .34454 Mdot
.502 .34458 Mdot
.502 .34491 Mdot
.502 .34526 Mdot
.502 .34558 Mdot
.502 .34558 Mdot
.502 .34567 Mdot
.502 .34585 Mdot
.502 .34609 Mdot
.502 .34619 Mdot
.502 .34788 Mdot
.502 .34815 Mdot
.502 .34843 Mdot
.502 .34961 Mdot
.502 .35054 Mdot
.502 .3514 Mdot
.502 .35195 Mdot
.502 .35269 Mdot
.502 .3534 Mdot
.502 .35345 Mdot
.502 .35349 Mdot
.502 .35349 Mdot
.502 .35377 Mdot
.502 .35388 Mdot
.502 .35451 Mdot
.502 .35466 Mdot
.502 .35481 Mdot
.502 .35489 Mdot
.502 .35492 Mdot
.502 .35587 Mdot
.502 .3561 Mdot
.502 .35661 Mdot
.502 .35663 Mdot
.502 .35736 Mdot
.502 .35854 Mdot
.502 .3593 Mdot
.502 .36062 Mdot
.502 .36093 Mdot
.502 .36106 Mdot
.502 .36171 Mdot
.502 .36253 Mdot
.502 .36275 Mdot
.502 .36286 Mdot
.502 .36426 Mdot
.502 .36479 Mdot
.502 .36505 Mdot
.502 .36531 Mdot
.502 .36573 Mdot
.502 .36581 Mdot
.502 .36597 Mdot
.502 .36613 Mdot
.502 .3669 Mdot
.502 .36696 Mdot
.502 .36721 Mdot
.502 .3676 Mdot
.502 .36768 Mdot
.502 .36774 Mdot
.502 .3681 Mdot
.502 .36816 Mdot
.502 .36833 Mdot
.502 .36838 Mdot
.502 .36845 Mdot
.502 .36849 Mdot
.502 .36861 Mdot
.502 .36876 Mdot
.502 .36891 Mdot
.502 .36907 Mdot
.502 .36912 Mdot
.502 .36926 Mdot
.502 .36926 Mdot
.502 .36929 Mdot
.502 .3693 Mdot
.502 .36936 Mdot
.502 .3694 Mdot
.502 .3694 Mdot
.502 .47827 Mdot
.502 .47827 Mdot
.502 .47829 Mdot
.502 .47832 Mdot
.502 .47833 Mdot
.502 .47834 Mdot
.502 .47834 Mdot
.502 .47841 Mdot
.502 .47843 Mdot
.502 .47851 Mdot
.502 .47858 Mdot
.502 .47865 Mdot
.502 .47871 Mdot
.502 .47873 Mdot
.502 .47877 Mdot
.502 .47879 Mdot
.502 .47887 Mdot
.502 .4789 Mdot
.502 .47908 Mdot
.502 .4791 Mdot
.502 .47914 Mdot
.502 .47933 Mdot
.502 .47945 Mdot
.502 .47948 Mdot
.502 .47985 Mdot
.502 .47992 Mdot
.502 .48 Mdot
.502 .48004 Mdot
.502 .48024 Mdot
.502 .48036 Mdot
.502 .48049 Mdot
.502 .48074 Mdot
.502 .4814 Mdot
.502 .48145 Mdot
.502 .48156 Mdot
.502 .48195 Mdot
.502 .48225 Mdot
.502 .48232 Mdot
.502 .48246 Mdot
.502 .48308 Mdot
.502 .48344 Mdot
.502 .48399 Mdot
.502 .48433 Mdot
.502 .48434 Mdot
.502 .48458 Mdot
.502 .48469 Mdot
.502 .48513 Mdot
.502 .48514 Mdot
.502 .48518 Mdot
.502 .48525 Mdot
.502 .48532 Mdot
.502 .48561 Mdot
.502 .48566 Mdot
.502 .48579 Mdot
.502 .48579 Mdot
.502 .48581 Mdot
.502 .48583 Mdot
.502 .48616 Mdot
.502 .4865 Mdot
.502 .48675 Mdot
.502 .48715 Mdot
.502 .48757 Mdot
.502 .48811 Mdot
.502 .48824 Mdot
.502 .48836 Mdot
.502 .48913 Mdot
.502 .48918 Mdot
.502 .48928 Mdot
.502 .48937 Mdot
.502 .48941 Mdot
.502 .48941 Mdot
.502 .48955 Mdot
.502 .48971 Mdot
.502 .48986 Mdot
.502 .48988 Mdot
.502 .4901 Mdot
.502 .49026 Mdot
.502 .49044 Mdot
.502 .49048 Mdot
.502 .49052 Mdot
.502 .4906 Mdot
.502 .49065 Mdot
.502 .4907 Mdot
.502 .49157 Mdot
.502 .49187 Mdot
.502 .4922 Mdot
.502 .49261 Mdot
.502 .49285 Mdot
.502 .49292 Mdot
.502 .49295 Mdot
.502 .49306 Mdot
.502 .49306 Mdot
.502 .4931 Mdot
.502 .49354 Mdot
.502 .49362 Mdot
.502 .49368 Mdot
.502 .49389 Mdot
.502 .49389 Mdot
.502 .49395 Mdot
.502 .49398 Mdot
.502 .49454 Mdot
.502 .49493 Mdot
.502 .49495 Mdot
.502 .49503 Mdot
.502 .49504 Mdot
.502 .49531 Mdot
.502 .49538 Mdot
.502 .49546 Mdot
.502 .49555 Mdot
.502 .49616 Mdot
.502 .49717 Mdot
.502 .49735 Mdot
.502 .49737 Mdot
.502 .49772 Mdot
.502 .49801 Mdot
.502 .49807 Mdot
.502 .49821 Mdot
.502 .49878 Mdot
.502 .49902 Mdot
.502 .49983 Mdot
.502 .50014 Mdot
.502 .50022 Mdot
.502 .50026 Mdot
.502 .50108 Mdot
.502 .5012 Mdot
.502 .50133 Mdot
.502 .50154 Mdot
.502 .50166 Mdot
.502 .50175 Mdot
.502 .50223 Mdot
.502 .50266 Mdot
.502 .50306 Mdot
.502 .50327 Mdot
.502 .50331 Mdot
.502 .50355 Mdot
.502 .50372 Mdot
.502 .50415 Mdot
.502 .50424 Mdot
.502 .50454 Mdot
.502 .50455 Mdot
.502 .50465 Mdot
.502 .50488 Mdot
.502 .50517 Mdot
.502 .5053 Mdot
.502 .50592 Mdot
.502 .50662 Mdot
.502 .50711 Mdot
.502 .50715 Mdot
.502 .50742 Mdot
.502 .50775 Mdot
.502 .50779 Mdot
.502 .50811 Mdot
.502 .5083 Mdot
.502 .5089 Mdot
.502 .50961 Mdot
.502 .51078 Mdot
.502 .51083 Mdot
.502 .51092 Mdot
.502 .51188 Mdot
.502 .51208 Mdot
.502 .51252 Mdot
.502 .51253 Mdot
.502 .51258 Mdot
.502 .51262 Mdot
.502 .51277 Mdot
.502 .5128 Mdot
.502 .51287 Mdot
.502 .51288 Mdot
.502 .51322 Mdot
.502 .51335 Mdot
.502 .51354 Mdot
.502 .51374 Mdot
.502 .51404 Mdot
.502 .5141 Mdot
.502 .51444 Mdot
.502 .51446 Mdot
.502 .5145 Mdot
.502 .51456 Mdot
.502 .51456 Mdot
.502 .51476 Mdot
.502 .51485 Mdot
.502 .51492 Mdot
.502 .51503 Mdot
.502 .51506 Mdot
.502 .51515 Mdot
.502 .51557 Mdot
.502 .5157 Mdot
.502 .51586 Mdot
.502 .51599 Mdot
.502 .51605 Mdot
.502 .51625 Mdot
.502 .51634 Mdot
.502 .51637 Mdot
.502 .51638 Mdot
.502 .51659 Mdot
.502 .51673 Mdot
.502 .51692 Mdot
.502 .51759 Mdot
.502 .5176 Mdot
.502 .51772 Mdot
.502 .51784 Mdot
.502 .51789 Mdot
.502 .51816 Mdot
.502 .51843 Mdot
.502 .51853 Mdot
.502 .51856 Mdot
.502 .51857 Mdot
.502 .51948 Mdot
.502 .51964 Mdot
.502 .51985 Mdot
.502 .52038 Mdot
.502 .52059 Mdot
.502 .52074 Mdot
.502 .52075 Mdot
.502 .52095 Mdot
.502 .52111 Mdot
.502 .52129 Mdot
.502 .52187 Mdot
.502 .5219 Mdot
.502 .52225 Mdot
.502 .52238 Mdot
.502 .52238 Mdot
.502 .52241 Mdot
.502 .52246 Mdot
.502 .52246 Mdot
.502 .52248 Mdot
.502 .52249 Mdot
.502 .52259 Mdot
.502 .52263 Mdot
.502 .52274 Mdot
.502 .52284 Mdot
.502 .52285 Mdot
.502 .52296 Mdot
.502 .52305 Mdot
.502 .52308 Mdot
.502 .52313 Mdot
.502 .52317 Mdot
.502 .52329 Mdot
.502 .52333 Mdot
.502 .52342 Mdot
.502 .52353 Mdot
.502 .5236 Mdot
.502 .52364 Mdot
.502 .5237 Mdot
.502 .5239 Mdot
.502 .52393 Mdot
.502 .52397 Mdot
.502 .52407 Mdot
.502 .52415 Mdot
.502 .52419 Mdot
.502 .52451 Mdot
.502 .52458 Mdot
.502 .52473 Mdot
.502 .5248 Mdot
.502 .52485 Mdot
.502 .52485 Mdot
.502 .52496 Mdot
.502 .52501 Mdot
.502 .52519 Mdot
.502 .5253 Mdot
.502 .52548 Mdot
.502 .52566 Mdot
.502 .52582 Mdot
.502 .52602 Mdot
.502 .52609 Mdot
.502 .52621 Mdot
.502 .52696 Mdot
.502 .52702 Mdot
.502 .52717 Mdot
.502 .52752 Mdot
.502 .5277 Mdot
.502 .52773 Mdot
.502 .52785 Mdot
.502 .52812 Mdot
.502 .52819 Mdot
.502 .52821 Mdot
.502 .5284 Mdot
.502 .52846 Mdot
.502 .52875 Mdot
.502 .52905 Mdot
.502 .52922 Mdot
.502 .52924 Mdot
.502 .52952 Mdot
.502 .52961 Mdot
.502 .52969 Mdot
.502 .52979 Mdot
.502 .52979 Mdot
.502 .52986 Mdot
.502 .52997 Mdot
.502 .53022 Mdot
.502 .53032 Mdot
.502 .53039 Mdot
.502 .53082 Mdot
.502 .53082 Mdot
.502 .53083 Mdot
.502 .53088 Mdot
.502 .53101 Mdot
.502 .53113 Mdot
.502 .53115 Mdot
.502 .53121 Mdot
.502 .53126 Mdot
.502 .53126 Mdot
.502 .53156 Mdot
.502 .53165 Mdot
.502 .53171 Mdot
.502 .5318 Mdot
.502 .53181 Mdot
.502 .53182 Mdot
.502 .53186 Mdot
.502 .53195 Mdot
.502 .53197 Mdot
.502 .53203 Mdot
.502 .5321 Mdot
.502 .53216 Mdot
.502 .53234 Mdot
.502 .53238 Mdot
.502 .53239 Mdot
.502 .53244 Mdot
.502 .53247 Mdot
.502 .53251 Mdot
.502 .53259 Mdot
.502 .53259 Mdot
.502 .53261 Mdot
.502 .53263 Mdot
.502 .53264 Mdot
.502 .53279 Mdot
.502 .53281 Mdot
.502 .53294 Mdot
.502 .53302 Mdot
.502 .5331 Mdot
.502 .53315 Mdot
.502 .5333 Mdot
.502 .5333 Mdot
.502 .53333 Mdot
.502 .53334 Mdot
.502 .5334 Mdot
.502 .53342 Mdot
.502 .53344 Mdot
.502 .53344 Mdot
.502 .53362 Mdot
.502 .5337 Mdot
.502 .53409 Mdot
.502 .53413 Mdot
.502 .53415 Mdot
.502 .53461 Mdot
.502 .53488 Mdot
.502 .53511 Mdot
.502 .53519 Mdot
.502 .53531 Mdot
.502 .53533 Mdot
.502 .53545 Mdot
.502 .53555 Mdot
.502 .53557 Mdot
.502 .53575 Mdot
.502 .53601 Mdot
.502 .53624 Mdot
.502 .53629 Mdot
.502 .53639 Mdot
.502 .53647 Mdot
.502 .53651 Mdot
.502 .53652 Mdot
.502 .53662 Mdot
.502 .53666 Mdot
.502 .53681 Mdot
.502 .53687 Mdot
.502 .53696 Mdot
.502 .53697 Mdot
.502 .53705 Mdot
.502 .53719 Mdot
.502 .53734 Mdot
.502 .53751 Mdot
.502 .53754 Mdot
.502 .53758 Mdot
.502 .53765 Mdot
.502 .5377 Mdot
.502 .53774 Mdot
.502 .53802 Mdot
.502 .53803 Mdot
.502 .53806 Mdot
.502 .53817 Mdot
.502 .53844 Mdot
.502 .53852 Mdot
.502 .53871 Mdot
.502 .53876 Mdot
.502 .53878 Mdot
.502 .53888 Mdot
.502 .53899 Mdot
.502 .539 Mdot
.502 .53906 Mdot
.502 .53939 Mdot
.502 .53959 Mdot
.502 .53962 Mdot
.502 .53964 Mdot
.502 .53966 Mdot
.502 .53975 Mdot
.502 .53976 Mdot
.502 .53978 Mdot
.502 .53979 Mdot
.502 .53991 Mdot
.502 .54009 Mdot
.502 .5401 Mdot
.502 .54012 Mdot
.502 .54012 Mdot
.502 .54018 Mdot
.502 .5402 Mdot
.502 .54023 Mdot
.502 .54037 Mdot
.502 .54038 Mdot
.502 .54038 Mdot
.502 .54042 Mdot
.502 .54042 Mdot
.502 .54045 Mdot
.502 .54052 Mdot
.502 .54065 Mdot
.502 .54075 Mdot
.502 .54084 Mdot
.502 .54108 Mdot
.502 .54111 Mdot
.502 .54113 Mdot
.502 .54114 Mdot
.502 .54117 Mdot
.502 .54118 Mdot
.502 .54119 Mdot
.502 .54125 Mdot
.502 .5413 Mdot
.502 .54136 Mdot
.502 .54137 Mdot
.502 .54141 Mdot
.502 .54146 Mdot
.502 .54151 Mdot
.502 .54151 Mdot
.502 .54152 Mdot
.502 .54154 Mdot
.502 .54157 Mdot
.502 .54159 Mdot
.502 .54182 Mdot
.502 .54186 Mdot
.502 .54189 Mdot
.502 .54206 Mdot
.502 .54218 Mdot
.502 .5423 Mdot
.502 .54237 Mdot
.502 .54247 Mdot
.502 .54257 Mdot
.502 .54257 Mdot
.502 .54258 Mdot
.502 .54258 Mdot
.502 .54262 Mdot
.502 .54263 Mdot
.502 .54272 Mdot
.502 .54274 Mdot
.502 .54276 Mdot
.502 .54277 Mdot
.502 .54277 Mdot
.502 .5429 Mdot
.502 .54293 Mdot
.502 .543 Mdot
.502 .543 Mdot
.502 .5431 Mdot
.502 .54326 Mdot
.502 .54336 Mdot
.502 .54353 Mdot
.502 .54357 Mdot
.502 .54359 Mdot
.502 .54368 Mdot
.502 .54379 Mdot
.502 .54382 Mdot
.502 .54383 Mdot
.502 .54402 Mdot
.502 .54409 Mdot
.502 .54412 Mdot
.502 .54416 Mdot
.502 .54421 Mdot
.502 .54422 Mdot
.502 .54424 Mdot
.502 .54426 Mdot
.502 .54437 Mdot
.502 .54437 Mdot
.502 .54441 Mdot
.502 .54446 Mdot
.502 .54447 Mdot
.502 .54448 Mdot
.502 .54452 Mdot
.502 .54453 Mdot
.502 .54455 Mdot
.502 .54456 Mdot
.502 .54457 Mdot
.502 .54457 Mdot
.502 .54459 Mdot
.502 .54461 Mdot
.502 .54463 Mdot
.502 .54465 Mdot
.502 .54466 Mdot
.502 .54468 Mdot
.502 .54468 Mdot
.502 .54468 Mdot
.502 .54468 Mdot
.502 .54469 Mdot
.502 .54469 Mdot
.502 .54469 Mdot
.504 .20423 Mdot
.504 .20425 Mdot
.504 .20428 Mdot
.504 .20428 Mdot
.504 .20434 Mdot
.504 .20438 Mdot
.504 .2044 Mdot
.504 .20444 Mdot
.504 .20456 Mdot
.504 .20463 Mdot
.504 .20464 Mdot
.504 .20471 Mdot
.504 .20478 Mdot
.504 .20495 Mdot
.504 .205 Mdot
.504 .20501 Mdot
.504 .20504 Mdot
.504 .20508 Mdot
.504 .20521 Mdot
.504 .20542 Mdot
.504 .20546 Mdot
.504 .20547 Mdot
.504 .20557 Mdot
.504 .2056 Mdot
.504 .20567 Mdot
.504 .20567 Mdot
.504 .2057 Mdot
.504 .20582 Mdot
.504 .20602 Mdot
.504 .20602 Mdot
.504 .20602 Mdot
.504 .20614 Mdot
.504 .20623 Mdot
.504 .20635 Mdot
.504 .20641 Mdot
.504 .20646 Mdot
.504 .20673 Mdot
.504 .2068 Mdot
.504 .20684 Mdot
.504 .207 Mdot
.504 .20703 Mdot
.504 .20713 Mdot
.504 .20727 Mdot
.504 .2073 Mdot
.504 .20759 Mdot
.504 .20786 Mdot
.504 .20787 Mdot
.504 .20804 Mdot
.504 .20821 Mdot
.504 .20827 Mdot
.504 .20864 Mdot
.504 .20916 Mdot
.504 .20925 Mdot
.504 .20934 Mdot
.504 .20936 Mdot
.504 .21013 Mdot
.504 .21046 Mdot
.504 .21063 Mdot
.504 .21075 Mdot
.504 .21081 Mdot
.504 .21082 Mdot
.504 .21086 Mdot
.504 .21118 Mdot
.504 .21162 Mdot
.504 .21192 Mdot
.504 .21223 Mdot
.504 .21235 Mdot
.504 .21238 Mdot
.504 .21246 Mdot
.504 .21256 Mdot
.504 .21262 Mdot
.504 .21283 Mdot
.504 .21306 Mdot
.504 .21353 Mdot
.504 .2137 Mdot
.504 .2138 Mdot
.504 .21387 Mdot
.504 .21411 Mdot
.504 .21411 Mdot
.504 .21422 Mdot
.504 .21459 Mdot
.504 .21459 Mdot
.504 .21508 Mdot
.504 .21576 Mdot
.504 .21616 Mdot
.504 .21648 Mdot
.504 .21682 Mdot
.504 .21684 Mdot
.504 .21765 Mdot
.504 .21865 Mdot
.504 .21883 Mdot
.504 .21888 Mdot
.504 .21971 Mdot
.504 .21975 Mdot
.504 .21983 Mdot
.504 .22017 Mdot
.504 .22042 Mdot
.504 .22061 Mdot
.504 .22063 Mdot
.504 .22074 Mdot
.504 .22169 Mdot
.504 .22251 Mdot
.504 .22264 Mdot
.504 .22312 Mdot
.504 .22364 Mdot
.504 .22439 Mdot
.504 .2244 Mdot
.504 .22463 Mdot
.504 .22482 Mdot
.504 .22495 Mdot
.504 .22509 Mdot
.504 .2251 Mdot
.504 .22583 Mdot
.504 .22626 Mdot
.504 .22658 Mdot
.504 .2266 Mdot
.504 .22677 Mdot
.504 .22729 Mdot
.504 .22737 Mdot
.504 .22757 Mdot
.504 .22792 Mdot
.504 .22847 Mdot
.504 .22931 Mdot
.504 .23004 Mdot
.504 .23081 Mdot
.504 .2313 Mdot
.504 .23142 Mdot
.504 .23148 Mdot
.504 .23154 Mdot
.504 .23176 Mdot
.504 .23209 Mdot
.504 .23236 Mdot
.504 .23246 Mdot
.504 .2325 Mdot
.504 .23291 Mdot
.504 .23305 Mdot
.504 .23316 Mdot
.504 .2333 Mdot
.504 .23336 Mdot
.504 .23342 Mdot
.504 .23379 Mdot
.504 .23383 Mdot
.504 .23399 Mdot
.504 .23402 Mdot
.504 .23412 Mdot
.504 .23425 Mdot
.504 .23455 Mdot
.504 .2348 Mdot
.504 .2351 Mdot
.504 .23515 Mdot
.504 .23545 Mdot
.504 .23592 Mdot
.504 .236 Mdot
.504 .23601 Mdot
.504 .23657 Mdot
.504 .2368 Mdot
.504 .23699 Mdot
.504 .23705 Mdot
.504 .23776 Mdot
.504 .23802 Mdot
.504 .23815 Mdot
.504 .23818 Mdot
.504 .23831 Mdot
.504 .23844 Mdot
.504 .23872 Mdot
.504 .23881 Mdot
.504 .23888 Mdot
.504 .23891 Mdot
.504 .23905 Mdot
.504 .23932 Mdot
.504 .23958 Mdot
.504 .23994 Mdot
.504 .24015 Mdot
.504 .24031 Mdot
.504 .24048 Mdot
.504 .2409 Mdot
.504 .24139 Mdot
.504 .24188 Mdot
.504 .24194 Mdot
.504 .2421 Mdot
.504 .24221 Mdot
.504 .24231 Mdot
.504 .24236 Mdot
.504 .24314 Mdot
.504 .24319 Mdot
.504 .2434 Mdot
.504 .24394 Mdot
.504 .24395 Mdot
.504 .24404 Mdot
.504 .24412 Mdot
.504 .24418 Mdot
.504 .24454 Mdot
.504 .24491 Mdot
.504 .24512 Mdot
.504 .24592 Mdot
.504 .24667 Mdot
.504 .24672 Mdot
.504 .24674 Mdot
.504 .24711 Mdot
.504 .24742 Mdot
.504 .24761 Mdot
.504 .24767 Mdot
.504 .24796 Mdot
.504 .24807 Mdot
.504 .2484 Mdot
.504 .24875 Mdot
.504 .24902 Mdot
.504 .24941 Mdot
.504 .24978 Mdot
.504 .24985 Mdot
.504 .24996 Mdot
.504 .25027 Mdot
.504 .25044 Mdot
.504 .25051 Mdot
.504 .25055 Mdot
.504 .25088 Mdot
.504 .25179 Mdot
.504 .25228 Mdot
.504 .25235 Mdot
.504 .25246 Mdot
.504 .2525 Mdot
.504 .25307 Mdot
.504 .25311 Mdot
.504 .25327 Mdot
.504 .25341 Mdot
.504 .25386 Mdot
.504 .25388 Mdot
.504 .25391 Mdot
.504 .25436 Mdot
.504 .25437 Mdot
.504 .25452 Mdot
.504 .25472 Mdot
.504 .255 Mdot
.504 .25501 Mdot
.504 .25526 Mdot
.504 .25545 Mdot
.504 .25578 Mdot
.504 .2558 Mdot
.504 .25587 Mdot
.504 .2559 Mdot
.504 .25671 Mdot
.504 .25697 Mdot
.504 .25707 Mdot
.504 .25725 Mdot
.504 .25732 Mdot
.504 .25758 Mdot
.504 .25818 Mdot
.504 .25837 Mdot
.504 .25844 Mdot
.504 .25861 Mdot
.504 .25865 Mdot
.504 .25877 Mdot
.504 .25917 Mdot
.504 .25919 Mdot
.504 .25922 Mdot
.504 .25968 Mdot
.504 .26016 Mdot
.504 .26075 Mdot
.504 .2609 Mdot
.504 .2609 Mdot
.504 .26124 Mdot
.504 .26137 Mdot
.504 .2614 Mdot
.504 .2619 Mdot
.504 .26193 Mdot
.504 .26199 Mdot
.504 .26206 Mdot
.504 .26216 Mdot
.504 .2622 Mdot
.504 .26252 Mdot
.504 .2631 Mdot
.504 .26321 Mdot
.504 .26332 Mdot
.504 .26346 Mdot
.504 .26387 Mdot
.504 .26405 Mdot
.504 .26416 Mdot
.504 .2642 Mdot
.504 .26427 Mdot
.504 .26454 Mdot
.504 .26491 Mdot
.504 .26539 Mdot
.504 .26543 Mdot
.504 .26572 Mdot
.504 .26611 Mdot
.504 .26611 Mdot
.504 .26617 Mdot
.504 .26649 Mdot
.504 .26674 Mdot
.504 .26695 Mdot
.504 .26713 Mdot
.504 .26734 Mdot
.504 .26744 Mdot
.504 .26753 Mdot
.504 .26764 Mdot
.504 .26767 Mdot
.504 .26793 Mdot
.504 .26798 Mdot
.504 .26802 Mdot
.504 .26812 Mdot
.504 .2682 Mdot
.504 .26863 Mdot
.504 .26936 Mdot
.504 .2694 Mdot
.504 .26949 Mdot
.504 .27099 Mdot
.504 .27259 Mdot
.504 .27301 Mdot
.504 .27378 Mdot
.504 .27451 Mdot
.504 .27463 Mdot
.504 .27479 Mdot
.504 .27499 Mdot
.504 .27499 Mdot
.504 .2761 Mdot
.504 .27653 Mdot
.504 .27665 Mdot
.504 .27827 Mdot
.504 .27838 Mdot
.504 .27858 Mdot
.504 .27881 Mdot
.504 .27914 Mdot
.504 .27926 Mdot
.504 .2803 Mdot
.504 .28133 Mdot
.504 .28221 Mdot
.504 .28258 Mdot
.504 .28293 Mdot
.504 .28337 Mdot
.504 .28415 Mdot
.504 .28471 Mdot
.504 .28529 Mdot
.504 .28559 Mdot
.504 .28567 Mdot
.504 .2858 Mdot
.504 .28601 Mdot
.504 .2866 Mdot
.504 .28689 Mdot
.504 .28717 Mdot
.504 .28725 Mdot
.504 .28753 Mdot
.504 .2881 Mdot
.504 .28966 Mdot
.504 .28977 Mdot
.504 .29021 Mdot
.504 .29072 Mdot
.504 .29195 Mdot
.504 .29198 Mdot
.504 .29215 Mdot
.504 .29319 Mdot
.504 .29388 Mdot
.504 .294 Mdot
.504 .29466 Mdot
.504 .29522 Mdot
.504 .2959 Mdot
.504 .2962 Mdot
.504 .29642 Mdot
.504 .29649 Mdot
.504 .29686 Mdot
.504 .29695 Mdot
.504 .29778 Mdot
.504 .29791 Mdot
.504 .29805 Mdot
.504 .29838 Mdot
.504 .29862 Mdot
.504 .29895 Mdot
.504 .29989 Mdot
.504 .29999 Mdot
.504 .3002 Mdot
.504 .30083 Mdot
.504 .30159 Mdot
.504 .3021 Mdot
.504 .30224 Mdot
.504 .30238 Mdot
.504 .30267 Mdot
.504 .3038 Mdot
.504 .30558 Mdot
.504 .3073 Mdot
.504 .30928 Mdot
.504 .30997 Mdot
.504 .3106 Mdot
.504 .31143 Mdot
.504 .31191 Mdot
.504 .31209 Mdot
.504 .31334 Mdot
.504 .31374 Mdot
.504 .3138 Mdot
.504 .31457 Mdot
.504 .3156 Mdot
.504 .31737 Mdot
.504 .31739 Mdot
.504 .31772 Mdot
.504 .31805 Mdot
.504 .3185 Mdot
.504 .31907 Mdot
.504 .31909 Mdot
.504 .32091 Mdot
.504 .32221 Mdot
.504 .32339 Mdot
.504 .32371 Mdot
.504 .32573 Mdot
.504 .32808 Mdot
.504 .32836 Mdot
.504 .32842 Mdot
.504 .32888 Mdot
.504 .32951 Mdot
.504 .33035 Mdot
.504 .33055 Mdot
.504 .33066 Mdot
.504 .33273 Mdot
.504 .33287 Mdot
.504 .33332 Mdot
.504 .33584 Mdot
.504 .33791 Mdot
.504 .33796 Mdot
.504 .33881 Mdot
.504 .33963 Mdot
.504 .34064 Mdot
.504 .34239 Mdot
.504 .34363 Mdot
.504 .34364 Mdot
.504 .3446 Mdot
.504 .34487 Mdot
.504 .34489 Mdot
.504 .3455 Mdot
.504 .34567 Mdot
.504 .34594 Mdot
.504 .34638 Mdot
.504 .3476 Mdot
.504 .34818 Mdot
.504 .34872 Mdot
.504 .34889 Mdot
.504 .34913 Mdot
.504 .34933 Mdot
.504 .34943 Mdot
.504 .34973 Mdot
.504 .35053 Mdot
.504 .35132 Mdot
.504 .35247 Mdot
.504 .3533 Mdot
.504 .35338 Mdot
.504 .35341 Mdot
.504 .35358 Mdot
.504 .35389 Mdot
.504 .35434 Mdot
.504 .3552 Mdot
.504 .3572 Mdot
.504 .35725 Mdot
.504 .3575 Mdot
.504 .35774 Mdot
.504 .35908 Mdot
.504 .36006 Mdot
.504 .36022 Mdot
.504 .36067 Mdot
.504 .3611 Mdot
.504 .36112 Mdot
.504 .36184 Mdot
.504 .3626 Mdot
.504 .36269 Mdot
.504 .36306 Mdot
.504 .36331 Mdot
.504 .3634 Mdot
.504 .36382 Mdot
.504 .36392 Mdot
.504 .36411 Mdot
.504 .36482 Mdot
.504 .36496 Mdot
.504 .3651 Mdot
.504 .36543 Mdot
.504 .36567 Mdot
.504 .36597 Mdot
.504 .36598 Mdot
.504 .36599 Mdot
.504 .36651 Mdot
.504 .36682 Mdot
.504 .3669 Mdot
.504 .3669 Mdot
.504 .36708 Mdot
.504 .36717 Mdot
.504 .36743 Mdot
.504 .36745 Mdot
.504 .36757 Mdot
.504 .36813 Mdot
.504 .36847 Mdot
.504 .36857 Mdot
.504 .36865 Mdot
.504 .36868 Mdot
.504 .36882 Mdot
.504 .36927 Mdot
.504 .36944 Mdot
.504 .36964 Mdot
.504 .36967 Mdot
.504 .36983 Mdot
.504 .37016 Mdot
.504 .37027 Mdot
.504 .37032 Mdot
.504 .37044 Mdot
.504 .37057 Mdot
.504 .37059 Mdot
.504 .37067 Mdot
.504 .37071 Mdot
.504 .47772 Mdot
.504 .47774 Mdot
.504 .47777 Mdot
.504 .47778 Mdot
.504 .47785 Mdot
.504 .47791 Mdot
.504 .47793 Mdot
.504 .47798 Mdot
.504 .47814 Mdot
.504 .47822 Mdot
.504 .47823 Mdot
.504 .47833 Mdot
.504 .47841 Mdot
.504 .47863 Mdot
.504 .4787 Mdot
.504 .47871 Mdot
.504 .47875 Mdot
.504 .4788 Mdot
.504 .47896 Mdot
.504 .47923 Mdot
.504 .47929 Mdot
.504 .4793 Mdot
.504 .47942 Mdot
.504 .47946 Mdot
.504 .47955 Mdot
.504 .47955 Mdot
.504 .47959 Mdot
.504 .47974 Mdot
.504 .47998 Mdot
.504 .47999 Mdot
.504 .48 Mdot
.504 .48014 Mdot
.504 .48025 Mdot
.504 .48041 Mdot
.504 .48048 Mdot
.504 .48054 Mdot
.504 .48088 Mdot
.504 .48097 Mdot
.504 .48102 Mdot
.504 .48122 Mdot
.504 .48126 Mdot
.504 .48138 Mdot
.504 .48156 Mdot
.504 .4816 Mdot
.504 .48196 Mdot
.504 .4823 Mdot
.504 .48231 Mdot
.504 .48251 Mdot
.504 .48272 Mdot
.504 .4828 Mdot
.504 .48326 Mdot
.504 .48388 Mdot
.504 .48399 Mdot
.504 .48411 Mdot
.504 .48414 Mdot
.504 .48507 Mdot
.504 .48547 Mdot
.504 .48567 Mdot
.504 .48582 Mdot
.504 .4859 Mdot
.504 .48591 Mdot
.504 .48595 Mdot
.504 .48633 Mdot
.504 .48686 Mdot
.504 .48722 Mdot
.504 .48759 Mdot
.504 .48772 Mdot
.504 .48777 Mdot
.504 .48786 Mdot
.504 .48797 Mdot
.504 .48805 Mdot
.504 .4883 Mdot
.504 .48856 Mdot
.504 .48911 Mdot
.504 .48931 Mdot
.504 .48943 Mdot
.504 .48951 Mdot
.504 .48979 Mdot
.504 .4898 Mdot
.504 .48992 Mdot
.504 .49035 Mdot
.504 .49035 Mdot
.504 .49091 Mdot
.504 .4917 Mdot
.504 .49215 Mdot
.504 .49251 Mdot
.504 .49289 Mdot
.504 .49291 Mdot
.504 .49383 Mdot
.504 .49494 Mdot
.504 .49514 Mdot
.504 .4952 Mdot
.504 .49611 Mdot
.504 .49615 Mdot
.504 .49624 Mdot
.504 .49661 Mdot
.504 .49688 Mdot
.504 .49708 Mdot
.504 .49711 Mdot
.504 .49723 Mdot
.504 .49824 Mdot
.504 .49912 Mdot
.504 .49925 Mdot
.504 .49976 Mdot
.504 .50031 Mdot
.504 .50109 Mdot
.504 .5011 Mdot
.504 .50134 Mdot
.504 .50153 Mdot
.504 .50167 Mdot
.504 .50181 Mdot
.504 .50182 Mdot
.504 .50257 Mdot
.504 .503 Mdot
.504 .50333 Mdot
.504 .50335 Mdot
.504 .50352 Mdot
.504 .50404 Mdot
.504 .50412 Mdot
.504 .50432 Mdot
.504 .50467 Mdot
.504 .50522 Mdot
.504 .50604 Mdot
.504 .50675 Mdot
.504 .50749 Mdot
.504 .50795 Mdot
.504 .50807 Mdot
.504 .50812 Mdot
.504 .50818 Mdot
.504 .50839 Mdot
.504 .50871 Mdot
.504 .50896 Mdot
.504 .50905 Mdot
.504 .50909 Mdot
.504 .50947 Mdot
.504 .5096 Mdot
.504 .5097 Mdot
.504 .50984 Mdot
.504 .50989 Mdot
.504 .50995 Mdot
.504 .51028 Mdot
.504 .51032 Mdot
.504 .51047 Mdot
.504 .5105 Mdot
.504 .51059 Mdot
.504 .51071 Mdot
.504 .51099 Mdot
.504 .51121 Mdot
.504 .51148 Mdot
.504 .51153 Mdot
.504 .5118 Mdot
.504 .51222 Mdot
.504 .51229 Mdot
.504 .5123 Mdot
.504 .5128 Mdot
.504 .513 Mdot
.504 .51318 Mdot
.504 .51322 Mdot
.504 .51384 Mdot
.504 .51407 Mdot
.504 .51418 Mdot
.504 .51422 Mdot
.504 .51433 Mdot
.504 .51444 Mdot
.504 .51468 Mdot
.504 .51476 Mdot
.504 .51481 Mdot
.504 .51484 Mdot
.504 .51496 Mdot
.504 .51519 Mdot
.504 .51541 Mdot
.504 .51572 Mdot
.504 .5159 Mdot
.504 .51604 Mdot
.504 .51618 Mdot
.504 .51653 Mdot
.504 .51693 Mdot
.504 .51734 Mdot
.504 .51739 Mdot
.504 .51752 Mdot
.504 .51761 Mdot
.504 .51769 Mdot
.504 .51773 Mdot
.504 .51836 Mdot
.504 .51841 Mdot
.504 .51857 Mdot
.504 .51901 Mdot
.504 .51901 Mdot
.504 .51909 Mdot
.504 .51915 Mdot
.504 .51919 Mdot
.504 .51948 Mdot
.504 .51978 Mdot
.504 .51994 Mdot
.504 .52056 Mdot
.504 .52114 Mdot
.504 .52117 Mdot
.504 .52119 Mdot
.504 .52147 Mdot
.504 .52163 Mdot
.504 .52166 Mdot
.504 .5217 Mdot
.504 .52172 Mdot
.504 .52173 Mdot
.504 .52184 Mdot
.504 .52185 Mdot
.504 .52189 Mdot
.504 .52193 Mdot
.504 .52196 Mdot
.504 .52204 Mdot
.504 .52211 Mdot
.504 .52219 Mdot
.504 .52229 Mdot
.504 .52241 Mdot
.504 .52243 Mdot
.504 .52244 Mdot
.504 .52258 Mdot
.504 .52269 Mdot
.504 .52271 Mdot
.504 .52289 Mdot
.504 .52303 Mdot
.504 .52314 Mdot
.504 .52316 Mdot
.504 .52318 Mdot
.504 .52322 Mdot
.504 .52329 Mdot
.504 .52345 Mdot
.504 .5235 Mdot
.504 .52354 Mdot
.504 .52358 Mdot
.504 .5238 Mdot
.504 .52393 Mdot
.504 .52394 Mdot
.504 .52398 Mdot
.504 .524 Mdot
.504 .52403 Mdot
.504 .52404 Mdot
.504 .52423 Mdot
.504 .52424 Mdot
.504 .52429 Mdot
.504 .52442 Mdot
.504 .52442 Mdot
.504 .52447 Mdot
.504 .5247 Mdot
.504 .52488 Mdot
.504 .52506 Mdot
.504 .52507 Mdot
.504 .52507 Mdot
.504 .52523 Mdot
.504 .52527 Mdot
.504 .52528 Mdot
.504 .52535 Mdot
.504 .52537 Mdot
.504 .52545 Mdot
.504 .52567 Mdot
.504 .52577 Mdot
.504 .5258 Mdot
.504 .52587 Mdot
.504 .5259 Mdot
.504 .526 Mdot
.504 .5263 Mdot
.504 .52632 Mdot
.504 .52634 Mdot
.504 .52635 Mdot
.504 .52647 Mdot
.504 .52655 Mdot
.504 .52664 Mdot
.504 .52665 Mdot
.504 .52675 Mdot
.504 .52682 Mdot
.504 .52688 Mdot
.504 .52688 Mdot
.504 .52705 Mdot
.504 .52707 Mdot
.504 .52707 Mdot
.504 .52724 Mdot
.504 .52729 Mdot
.504 .52735 Mdot
.504 .52737 Mdot
.504 .52758 Mdot
.504 .52759 Mdot
.504 .52764 Mdot
.504 .52766 Mdot
.504 .52785 Mdot
.504 .52818 Mdot
.504 .52831 Mdot
.504 .52832 Mdot
.504 .52835 Mdot
.504 .52841 Mdot
.504 .52853 Mdot
.504 .52857 Mdot
.504 .5286 Mdot
.504 .52873 Mdot
.504 .52888 Mdot
.504 .52898 Mdot
.504 .52911 Mdot
.504 .52923 Mdot
.504 .52927 Mdot
.504 .52938 Mdot
.504 .5294 Mdot
.504 .52947 Mdot
.504 .52959 Mdot
.504 .52972 Mdot
.504 .52973 Mdot
.504 .52975 Mdot
.504 .53003 Mdot
.504 .53032 Mdot
.504 .5304 Mdot
.504 .53054 Mdot
.504 .53067 Mdot
.504 .53069 Mdot
.504 .53072 Mdot
.504 .53075 Mdot
.504 .53076 Mdot
.504 .53095 Mdot
.504 .53103 Mdot
.504 .53105 Mdot
.504 .53134 Mdot
.504 .53136 Mdot
.504 .53139 Mdot
.504 .53143 Mdot
.504 .53149 Mdot
.504 .53151 Mdot
.504 .5317 Mdot
.504 .53187 Mdot
.504 .53203 Mdot
.504 .53209 Mdot
.504 .53215 Mdot
.504 .53222 Mdot
.504 .53236 Mdot
.504 .53245 Mdot
.504 .53255 Mdot
.504 .5326 Mdot
.504 .53261 Mdot
.504 .53264 Mdot
.504 .53267 Mdot
.504 .53277 Mdot
.504 .53282 Mdot
.504 .53287 Mdot
.504 .53288 Mdot
.504 .53293 Mdot
.504 .53302 Mdot
.504 .53328 Mdot
.504 .5333 Mdot
.504 .53337 Mdot
.504 .53346 Mdot
.504 .53366 Mdot
.504 .53366 Mdot
.504 .53369 Mdot
.504 .53386 Mdot
.504 .53397 Mdot
.504 .53399 Mdot
.504 .5341 Mdot
.504 .53419 Mdot
.504 .5343 Mdot
.504 .53435 Mdot
.504 .53438 Mdot
.504 .53439 Mdot
.504 .53445 Mdot
.504 .53447 Mdot
.504 .5346 Mdot
.504 .53462 Mdot
.504 .53464 Mdot
.504 .53469 Mdot
.504 .53473 Mdot
.504 .53478 Mdot
.504 .53493 Mdot
.504 .53495 Mdot
.504 .53498 Mdot
.504 .53508 Mdot
.504 .5352 Mdot
.504 .53528 Mdot
.504 .5353 Mdot
.504 .53532 Mdot
.504 .53537 Mdot
.504 .53554 Mdot
.504 .53582 Mdot
.504 .53608 Mdot
.504 .53638 Mdot
.504 .53658 Mdot
.504 .53671 Mdot
.504 .53678 Mdot
.504 .53681 Mdot
.504 .53699 Mdot
.504 .53705 Mdot
.504 .53706 Mdot
.504 .53718 Mdot
.504 .53733 Mdot
.504 .53759 Mdot
.504 .53759 Mdot
.504 .53764 Mdot
.504 .53769 Mdot
.504 .53776 Mdot
.504 .53784 Mdot
.504 .53784 Mdot
.504 .53811 Mdot
.504 .5383 Mdot
.504 .53847 Mdot
.504 .53852 Mdot
.504 .53881 Mdot
.504 .53914 Mdot
.504 .53918 Mdot
.504 .53919 Mdot
.504 .53926 Mdot
.504 .53935 Mdot
.504 .53946 Mdot
.504 .53949 Mdot
.504 .53951 Mdot
.504 .5398 Mdot
.504 .53982 Mdot
.504 .53988 Mdot
.504 .54024 Mdot
.504 .54052 Mdot
.504 .54053 Mdot
.504 .54065 Mdot
.504 .54076 Mdot
.504 .5409 Mdot
.504 .54114 Mdot
.504 .54131 Mdot
.504 .54132 Mdot
.504 .54145 Mdot
.504 .54148 Mdot
.504 .54149 Mdot
.504 .54157 Mdot
.504 .54159 Mdot
.504 .54163 Mdot
.504 .54169 Mdot
.504 .54185 Mdot
.504 .54193 Mdot
.504 .54201 Mdot
.504 .54203 Mdot
.504 .54206 Mdot
.504 .54209 Mdot
.504 .5421 Mdot
.504 .54214 Mdot
.504 .54225 Mdot
.504 .54236 Mdot
.504 .54251 Mdot
.504 .54262 Mdot
.504 .54264 Mdot
.504 .54264 Mdot
.504 .54266 Mdot
.504 .5427 Mdot
.504 .54276 Mdot
.504 .54288 Mdot
.504 .54315 Mdot
.504 .54315 Mdot
.504 .54319 Mdot
.504 .54322 Mdot
.504 .5434 Mdot
.504 .54353 Mdot
.504 .54355 Mdot
.504 .54361 Mdot
.504 .54367 Mdot
.504 .54367 Mdot
.504 .54376 Mdot
.504 .54386 Mdot
.504 .54388 Mdot
.504 .54392 Mdot
.504 .54396 Mdot
.504 .54397 Mdot
.504 .54402 Mdot
.504 .54404 Mdot
.504 .54406 Mdot
.504 .54416 Mdot
.504 .54418 Mdot
.504 .54419 Mdot
.504 .54424 Mdot
.504 .54427 Mdot
.504 .54431 Mdot
.504 .54431 Mdot
.504 .54431 Mdot
.504 .54438 Mdot
.504 .54442 Mdot
.504 .54443 Mdot
.504 .54443 Mdot
.504 .54445 Mdot
.504 .54447 Mdot
.504 .5445 Mdot
.504 .5445 Mdot
.504 .54452 Mdot
.504 .54459 Mdot
.504 .54464 Mdot
.504 .54465 Mdot
.504 .54466 Mdot
.504 .54466 Mdot
.504 .54468 Mdot
.504 .54474 Mdot
.504 .54476 Mdot
.504 .54479 Mdot
.504 .54479 Mdot
.504 .54482 Mdot
.504 .54486 Mdot
.504 .54487 Mdot
.504 .54488 Mdot
.504 .54489 Mdot
.504 .54491 Mdot
.504 .54491 Mdot
.504 .54492 Mdot
.504 .54493 Mdot
.506 .20364 Mdot
.506 .20366 Mdot
.506 .20369 Mdot
.506 .20371 Mdot
.506 .20371 Mdot
.506 .20376 Mdot
.506 .20378 Mdot
.506 .20382 Mdot
.506 .20385 Mdot
.506 .20385 Mdot
.506 .20389 Mdot
.506 .20393 Mdot
.506 .20393 Mdot
.506 .20395 Mdot
.506 .20405 Mdot
.506 .20406 Mdot
.506 .20411 Mdot
.506 .20425 Mdot
.506 .20425 Mdot
.506 .20426 Mdot
.506 .20434 Mdot
.506 .20436 Mdot
.506 .20436 Mdot
.506 .20438 Mdot
.506 .20447 Mdot
.506 .20448 Mdot
.506 .2045 Mdot
.506 .20468 Mdot
.506 .20468 Mdot
.506 .20476 Mdot
.506 .20483 Mdot
.506 .20532 Mdot
.506 .20536 Mdot
.506 .20544 Mdot
.506 .20546 Mdot
.506 .20546 Mdot
.506 .2056 Mdot
.506 .20567 Mdot
.506 .20568 Mdot
.506 .20598 Mdot
.506 .20609 Mdot
.506 .20625 Mdot
.506 .20627 Mdot
.506 .20629 Mdot
.506 .20639 Mdot
.506 .20643 Mdot
.506 .20644 Mdot
.506 .20654 Mdot
.506 .20661 Mdot
.506 .20664 Mdot
.506 .20666 Mdot
.506 .2067 Mdot
.506 .20673 Mdot
.506 .207 Mdot
.506 .20726 Mdot
.506 .2074 Mdot
.506 .20752 Mdot
.506 .20754 Mdot
.506 .20769 Mdot
.506 .20855 Mdot
.506 .20891 Mdot
.506 .20926 Mdot
.506 .20926 Mdot
.506 .20927 Mdot
.506 .21043 Mdot
.506 .21054 Mdot
.506 .21055 Mdot
.506 .21062 Mdot
.506 .21084 Mdot
.506 .21085 Mdot
.506 .21181 Mdot
.506 .21193 Mdot
.506 .212 Mdot
.506 .212 Mdot
.506 .21246 Mdot
.506 .21252 Mdot
.506 .21273 Mdot
.506 .21299 Mdot
.506 .2133 Mdot
.506 .21409 Mdot
.506 .21494 Mdot
.506 .21565 Mdot
.506 .21593 Mdot
.506 .21662 Mdot
.506 .21694 Mdot
.506 .21706 Mdot
.506 .21737 Mdot
.506 .21766 Mdot
.506 .21809 Mdot
.506 .21848 Mdot
.506 .21951 Mdot
.506 .21955 Mdot
.506 .22031 Mdot
.506 .22037 Mdot
.506 .22108 Mdot
.506 .22108 Mdot
.506 .22251 Mdot
.506 .22295 Mdot
.506 .22302 Mdot
.506 .22312 Mdot
.506 .22321 Mdot
.506 .22322 Mdot
.506 .22326 Mdot
.506 .22339 Mdot
.506 .22423 Mdot
.506 .225 Mdot
.506 .22555 Mdot
.506 .22556 Mdot
.506 .22572 Mdot
.506 .22639 Mdot
.506 .22695 Mdot
.506 .22697 Mdot
.506 .2273 Mdot
.506 .22765 Mdot
.506 .22791 Mdot
.506 .22827 Mdot
.506 .2293 Mdot
.506 .2293 Mdot
.506 .22962 Mdot
.506 .22979 Mdot
.506 .23002 Mdot
.506 .23014 Mdot
.506 .23014 Mdot
.506 .23019 Mdot
.506 .2305 Mdot
.506 .23062 Mdot
.506 .23092 Mdot
.506 .23092 Mdot
.506 .23094 Mdot
.506 .23111 Mdot
.506 .23113 Mdot
.506 .23114 Mdot
.506 .2314 Mdot
.506 .23169 Mdot
.506 .23169 Mdot
.506 .23181 Mdot
.506 .23259 Mdot
.506 .23264 Mdot
.506 .23277 Mdot
.506 .23277 Mdot
.506 .23293 Mdot
.506 .23301 Mdot
.506 .23303 Mdot
.506 .23347 Mdot
.506 .23367 Mdot
.506 .23369 Mdot
.506 .234 Mdot
.506 .23403 Mdot
.506 .23409 Mdot
.506 .23437 Mdot
.506 .23472 Mdot
.506 .23482 Mdot
.506 .23484 Mdot
.506 .23496 Mdot
.506 .23565 Mdot
.506 .23592 Mdot
.506 .23617 Mdot
.506 .23705 Mdot
.506 .2371 Mdot
.506 .23724 Mdot
.506 .23725 Mdot
.506 .23784 Mdot
.506 .23796 Mdot
.506 .23823 Mdot
.506 .23827 Mdot
.506 .23839 Mdot
.506 .23854 Mdot
.506 .23871 Mdot
.506 .23997 Mdot
.506 .24062 Mdot
.506 .24068 Mdot
.506 .24118 Mdot
.506 .24184 Mdot
.506 .24185 Mdot
.506 .24223 Mdot
.506 .24254 Mdot
.506 .24316 Mdot
.506 .24335 Mdot
.506 .24337 Mdot
.506 .24346 Mdot
.506 .24346 Mdot
.506 .24348 Mdot
.506 .24353 Mdot
.506 .24388 Mdot
.506 .2442 Mdot
.506 .24442 Mdot
.506 .24442 Mdot
.506 .24475 Mdot
.506 .24498 Mdot
.506 .24499 Mdot
.506 .24511 Mdot
.506 .24525 Mdot
.506 .24535 Mdot
.506 .24589 Mdot
.506 .2465 Mdot
.506 .24724 Mdot
.506 .24751 Mdot
.506 .24751 Mdot
.506 .24776 Mdot
.506 .2484 Mdot
.506 .24922 Mdot
.506 .24971 Mdot
.506 .24993 Mdot
.506 .24995 Mdot
.506 .25012 Mdot
.506 .25034 Mdot
.506 .25035 Mdot
.506 .25091 Mdot
.506 .25103 Mdot
.506 .25113 Mdot
.506 .2512 Mdot
.506 .25131 Mdot
.506 .25148 Mdot
.506 .25151 Mdot
.506 .25168 Mdot
.506 .25213 Mdot
.506 .25221 Mdot
.506 .25229 Mdot
.506 .25277 Mdot
.506 .253 Mdot
.506 .25313 Mdot
.506 .25349 Mdot
.506 .2535 Mdot
.506 .25372 Mdot
.506 .2548 Mdot
.506 .25493 Mdot
.506 .25514 Mdot
.506 .25521 Mdot
.506 .25534 Mdot
.506 .25565 Mdot
.506 .25571 Mdot
.506 .25606 Mdot
.506 .25608 Mdot
.506 .25617 Mdot
.506 .25623 Mdot
.506 .2564 Mdot
.506 .25673 Mdot
.506 .25686 Mdot
.506 .25696 Mdot
.506 .25697 Mdot
.506 .2571 Mdot
.506 .25739 Mdot
.506 .25787 Mdot
.506 .25825 Mdot
.506 .2584 Mdot
.506 .2584 Mdot
.506 .25856 Mdot
.506 .25938 Mdot
.506 .2597 Mdot
.506 .25977 Mdot
.506 .25985 Mdot
.506 .25993 Mdot
.506 .26007 Mdot
.506 .26028 Mdot
.506 .26028 Mdot
.506 .26041 Mdot
.506 .26061 Mdot
.506 .26083 Mdot
.506 .26093 Mdot
.506 .26094 Mdot
.506 .26106 Mdot
.506 .26145 Mdot
.506 .26165 Mdot
.506 .26188 Mdot
.506 .26189 Mdot
.506 .26232 Mdot
.506 .26264 Mdot
.506 .26267 Mdot
.506 .26309 Mdot
.506 .26403 Mdot
.506 .26413 Mdot
.506 .2645 Mdot
.506 .26489 Mdot
.506 .2649 Mdot
.506 .26562 Mdot
.506 .2658 Mdot
.506 .26594 Mdot
.506 .26598 Mdot
.506 .26646 Mdot
.506 .26655 Mdot
.506 .26656 Mdot
.506 .26663 Mdot
.506 .26688 Mdot
.506 .26707 Mdot
.506 .26711 Mdot
.506 .26713 Mdot
.506 .26735 Mdot
.506 .26737 Mdot
.506 .26784 Mdot
.506 .2679 Mdot
.506 .2681 Mdot
.506 .26814 Mdot
.506 .26871 Mdot
.506 .26879 Mdot
.506 .2688 Mdot
.506 .26901 Mdot
.506 .2692 Mdot
.506 .26923 Mdot
.506 .26935 Mdot
.506 .26937 Mdot
.506 .26959 Mdot
.506 .26968 Mdot
.506 .26994 Mdot
.506 .26994 Mdot
.506 .27004 Mdot
.506 .27021 Mdot
.506 .27034 Mdot
.506 .27059 Mdot
.506 .27166 Mdot
.506 .27186 Mdot
.506 .27214 Mdot
.506 .2724 Mdot
.506 .27242 Mdot
.506 .27287 Mdot
.506 .27355 Mdot
.506 .27356 Mdot
.506 .27401 Mdot
.506 .27466 Mdot
.506 .27537 Mdot
.506 .27549 Mdot
.506 .27552 Mdot
.506 .27553 Mdot
.506 .2757 Mdot
.506 .27575 Mdot
.506 .27615 Mdot
.506 .27743 Mdot
.506 .27809 Mdot
.506 .27887 Mdot
.506 .2789 Mdot
.506 .28029 Mdot
.506 .28135 Mdot
.506 .28147 Mdot
.506 .28286 Mdot
.506 .28558 Mdot
.506 .28595 Mdot
.506 .28628 Mdot
.506 .28655 Mdot
.506 .28663 Mdot
.506 .28722 Mdot
.506 .28748 Mdot
.506 .28878 Mdot
.506 .2888 Mdot
.506 .28911 Mdot
.506 .28921 Mdot
.506 .29116 Mdot
.506 .29173 Mdot
.506 .29233 Mdot
.506 .29387 Mdot
.506 .29415 Mdot
.506 .2942 Mdot
.506 .29443 Mdot
.506 .29521 Mdot
.506 .29585 Mdot
.506 .29598 Mdot
.506 .29604 Mdot
.506 .29675 Mdot
.506 .29681 Mdot
.506 .29725 Mdot
.506 .29826 Mdot
.506 .2983 Mdot
.506 .29849 Mdot
.506 .29885 Mdot
.506 .29886 Mdot
.506 .29914 Mdot
.506 .29926 Mdot
.506 .30106 Mdot
.506 .30134 Mdot
.506 .30134 Mdot
.506 .30202 Mdot
.506 .30262 Mdot
.506 .30264 Mdot
.506 .3027 Mdot
.506 .30309 Mdot
.506 .30313 Mdot
.506 .30314 Mdot
.506 .30383 Mdot
.506 .30412 Mdot
.506 .30483 Mdot
.506 .30494 Mdot
.506 .30495 Mdot
.506 .30524 Mdot
.506 .30578 Mdot
.506 .30617 Mdot
.506 .30694 Mdot
.506 .30694 Mdot
.506 .30937 Mdot
.506 .31022 Mdot
.506 .31084 Mdot
.506 .31169 Mdot
.506 .31248 Mdot
.506 .31251 Mdot
.506 .31388 Mdot
.506 .31548 Mdot
.506 .31587 Mdot
.506 .31591 Mdot
.506 .31722 Mdot
.506 .31911 Mdot
.506 .32117 Mdot
.506 .3215 Mdot
.506 .32158 Mdot
.506 .32161 Mdot
.506 .32182 Mdot
.506 .32209 Mdot
.506 .32224 Mdot
.506 .32334 Mdot
.506 .32688 Mdot
.506 .32688 Mdot
.506 .32865 Mdot
.506 .32881 Mdot
.506 .33072 Mdot
.506 .33081 Mdot
.506 .3334 Mdot
.506 .33438 Mdot
.506 .33548 Mdot
.506 .33622 Mdot
.506 .337 Mdot
.506 .3373 Mdot
.506 .33813 Mdot
.506 .33989 Mdot
.506 .3406 Mdot
.506 .34243 Mdot
.506 .34462 Mdot
.506 .34666 Mdot
.506 .34745 Mdot
.506 .34813 Mdot
.506 .34867 Mdot
.506 .34883 Mdot
.506 .35002 Mdot
.506 .35002 Mdot
.506 .35021 Mdot
.506 .35052 Mdot
.506 .35301 Mdot
.506 .35304 Mdot
.506 .35361 Mdot
.506 .3538 Mdot
.506 .35382 Mdot
.506 .35411 Mdot
.506 .35716 Mdot
.506 .35716 Mdot
.506 .35717 Mdot
.506 .3581 Mdot
.506 .35903 Mdot
.506 .3613 Mdot
.506 .3617 Mdot
.506 .36176 Mdot
.506 .36207 Mdot
.506 .36242 Mdot
.506 .36311 Mdot
.506 .36384 Mdot
.506 .36391 Mdot
.506 .36403 Mdot
.506 .36407 Mdot
.506 .36414 Mdot
.506 .36434 Mdot
.506 .3646 Mdot
.506 .36463 Mdot
.506 .36473 Mdot
.506 .36498 Mdot
.506 .36504 Mdot
.506 .36511 Mdot
.506 .36553 Mdot
.506 .36582 Mdot
.506 .3666 Mdot
.506 .36664 Mdot
.506 .36683 Mdot
.506 .36718 Mdot
.506 .36718 Mdot
.506 .36725 Mdot
.506 .36745 Mdot
.506 .36756 Mdot
.506 .36886 Mdot
.506 .36905 Mdot
.506 .36926 Mdot
.506 .36926 Mdot
.506 .36972 Mdot
.506 .3698 Mdot
.506 .36982 Mdot
.506 .37006 Mdot
.506 .37011 Mdot
.506 .37011 Mdot
.506 .37015 Mdot
.506 .37038 Mdot
.506 .3704 Mdot
.506 .37041 Mdot
.506 .37076 Mdot
.506 .3709 Mdot
.506 .37092 Mdot
.506 .3712 Mdot
.506 .37125 Mdot
.506 .37125 Mdot
.506 .37136 Mdot
.506 .37145 Mdot
.506 .37146 Mdot
.506 .37154 Mdot
.506 .37165 Mdot
.506 .37169 Mdot
.506 .37183 Mdot
.506 .37183 Mdot
.506 .37187 Mdot
.506 .37196 Mdot
.506 .37202 Mdot
.506 .47716 Mdot
.506 .47719 Mdot
.506 .47723 Mdot
.506 .47725 Mdot
.506 .47725 Mdot
.506 .47732 Mdot
.506 .47734 Mdot
.506 .47739 Mdot
.506 .47743 Mdot
.506 .47743 Mdot
.506 .47748 Mdot
.506 .47753 Mdot
.506 .47753 Mdot
.506 .47755 Mdot
.506 .47769 Mdot
.506 .4777 Mdot
.506 .47777 Mdot
.506 .47794 Mdot
.506 .47795 Mdot
.506 .47795 Mdot
.506 .47806 Mdot
.506 .47808 Mdot
.506 .47809 Mdot
.506 .47811 Mdot
.506 .47822 Mdot
.506 .47824 Mdot
.506 .47827 Mdot
.506 .47849 Mdot
.506 .4785 Mdot
.506 .47859 Mdot
.506 .47869 Mdot
.506 .47931 Mdot
.506 .47936 Mdot
.506 .47946 Mdot
.506 .47949 Mdot
.506 .47949 Mdot
.506 .47966 Mdot
.506 .47975 Mdot
.506 .47977 Mdot
.506 .48014 Mdot
.506 .48028 Mdot
.506 .48048 Mdot
.506 .48051 Mdot
.506 .48054 Mdot
.506 .48066 Mdot
.506 .48071 Mdot
.506 .48072 Mdot
.506 .48085 Mdot
.506 .48094 Mdot
.506 .48098 Mdot
.506 .481 Mdot
.506 .48105 Mdot
.506 .48109 Mdot
.506 .48143 Mdot
.506 .48176 Mdot
.506 .48192 Mdot
.506 .48207 Mdot
.506 .4821 Mdot
.506 .48229 Mdot
.506 .48335 Mdot
.506 .48379 Mdot
.506 .48422 Mdot
.506 .48422 Mdot
.506 .48423 Mdot
.506 .48564 Mdot
.506 .48578 Mdot
.506 .48579 Mdot
.506 .48587 Mdot
.506 .48614 Mdot
.506 .48615 Mdot
.506 .48729 Mdot
.506 .48744 Mdot
.506 .48752 Mdot
.506 .48752 Mdot
.506 .48807 Mdot
.506 .48814 Mdot
.506 .48839 Mdot
.506 .4887 Mdot
.506 .48905 Mdot
.506 .48997 Mdot
.506 .49096 Mdot
.506 .49178 Mdot
.506 .4921 Mdot
.506 .49288 Mdot
.506 .49325 Mdot
.506 .49338 Mdot
.506 .49373 Mdot
.506 .49405 Mdot
.506 .49454 Mdot
.506 .49497 Mdot
.506 .4961 Mdot
.506 .49614 Mdot
.506 .49697 Mdot
.506 .49704 Mdot
.506 .49781 Mdot
.506 .49781 Mdot
.506 .49933 Mdot
.506 .4998 Mdot
.506 .49987 Mdot
.506 .49998 Mdot
.506 .50007 Mdot
.506 .50009 Mdot
.506 .50012 Mdot
.506 .50026 Mdot
.506 .50114 Mdot
.506 .50194 Mdot
.506 .5025 Mdot
.506 .50251 Mdot
.506 .50267 Mdot
.506 .50335 Mdot
.506 .50392 Mdot
.506 .50394 Mdot
.506 .50427 Mdot
.506 .50462 Mdot
.506 .50488 Mdot
.506 .50524 Mdot
.506 .50624 Mdot
.506 .50624 Mdot
.506 .50656 Mdot
.506 .50672 Mdot
.506 .50695 Mdot
.506 .50707 Mdot
.506 .50707 Mdot
.506 .50711 Mdot
.506 .50741 Mdot
.506 .50752 Mdot
.506 .50781 Mdot
.506 .50782 Mdot
.506 .50783 Mdot
.506 .50799 Mdot
.506 .50802 Mdot
.506 .50802 Mdot
.506 .50827 Mdot
.506 .50855 Mdot
.506 .50855 Mdot
.506 .50866 Mdot
.506 .5094 Mdot
.506 .50944 Mdot
.506 .50956 Mdot
.506 .50956 Mdot
.506 .50971 Mdot
.506 .50979 Mdot
.506 .5098 Mdot
.506 .51022 Mdot
.506 .51039 Mdot
.506 .51042 Mdot
.506 .5107 Mdot
.506 .51073 Mdot
.506 .51078 Mdot
.506 .51104 Mdot
.506 .51136 Mdot
.506 .51145 Mdot
.506 .51147 Mdot
.506 .51158 Mdot
.506 .5122 Mdot
.506 .51244 Mdot
.506 .51267 Mdot
.506 .51345 Mdot
.506 .51349 Mdot
.506 .51362 Mdot
.506 .51362 Mdot
.506 .51414 Mdot
.506 .51424 Mdot
.506 .51448 Mdot
.506 .51451 Mdot
.506 .51462 Mdot
.506 .51475 Mdot
.506 .5149 Mdot
.506 .51597 Mdot
.506 .51652 Mdot
.506 .51657 Mdot
.506 .51698 Mdot
.506 .51753 Mdot
.506 .51754 Mdot
.506 .51785 Mdot
.506 .5181 Mdot
.506 .5186 Mdot
.506 .51876 Mdot
.506 .51878 Mdot
.506 .51884 Mdot
.506 .51885 Mdot
.506 .51886 Mdot
.506 .5189 Mdot
.506 .51918 Mdot
.506 .51943 Mdot
.506 .51961 Mdot
.506 .51961 Mdot
.506 .51987 Mdot
.506 .52005 Mdot
.506 .52006 Mdot
.506 .52016 Mdot
.506 .52027 Mdot
.506 .52034 Mdot
.506 .52076 Mdot
.506 .52085 Mdot
.506 .5209 Mdot
.506 .52097 Mdot
.506 .521 Mdot
.506 .52101 Mdot
.506 .52111 Mdot
.506 .52114 Mdot
.506 .52123 Mdot
.506 .52123 Mdot
.506 .52128 Mdot
.506 .52129 Mdot
.506 .52136 Mdot
.506 .52145 Mdot
.506 .52145 Mdot
.506 .52148 Mdot
.506 .5217 Mdot
.506 .52171 Mdot
.506 .52179 Mdot
.506 .52181 Mdot
.506 .52199 Mdot
.506 .522 Mdot
.506 .52208 Mdot
.506 .52209 Mdot
.506 .52211 Mdot
.506 .52218 Mdot
.506 .52228 Mdot
.506 .5223 Mdot
.506 .52231 Mdot
.506 .52234 Mdot
.506 .52252 Mdot
.506 .52254 Mdot
.506 .52259 Mdot
.506 .52266 Mdot
.506 .52294 Mdot
.506 .52294 Mdot
.506 .52309 Mdot
.506 .52323 Mdot
.506 .52327 Mdot
.506 .52363 Mdot
.506 .52379 Mdot
.506 .5238 Mdot
.506 .52392 Mdot
.506 .52408 Mdot
.506 .52409 Mdot
.506 .52418 Mdot
.506 .52425 Mdot
.506 .5244 Mdot
.506 .52444 Mdot
.506 .52445 Mdot
.506 .52449 Mdot
.506 .52457 Mdot
.506 .52464 Mdot
.506 .5247 Mdot
.506 .5247 Mdot
.506 .52477 Mdot
.506 .52483 Mdot
.506 .52486 Mdot
.506 .52489 Mdot
.506 .52491 Mdot
.506 .52504 Mdot
.506 .52534 Mdot
.506 .5254 Mdot
.506 .52541 Mdot
.506 .52546 Mdot
.506 .5256 Mdot
.506 .52579 Mdot
.506 .5259 Mdot
.506 .52594 Mdot
.506 .52595 Mdot
.506 .52598 Mdot
.506 .52603 Mdot
.506 .52616 Mdot
.506 .52622 Mdot
.506 .52624 Mdot
.506 .52628 Mdot
.506 .52629 Mdot
.506 .52642 Mdot
.506 .52644 Mdot
.506 .52656 Mdot
.506 .52661 Mdot
.506 .52663 Mdot
.506 .52671 Mdot
.506 .52676 Mdot
.506 .52716 Mdot
.506 .52725 Mdot
.506 .52725 Mdot
.506 .52739 Mdot
.506 .52743 Mdot
.506 .52752 Mdot
.506 .5277 Mdot
.506 .52773 Mdot
.506 .52776 Mdot
.506 .52792 Mdot
.506 .52799 Mdot
.506 .528 Mdot
.506 .52806 Mdot
.506 .5281 Mdot
.506 .52813 Mdot
.506 .52817 Mdot
.506 .52821 Mdot
.506 .52842 Mdot
.506 .52842 Mdot
.506 .52851 Mdot
.506 .52857 Mdot
.506 .52858 Mdot
.506 .52866 Mdot
.506 .52884 Mdot
.506 .52915 Mdot
.506 .52938 Mdot
.506 .52947 Mdot
.506 .52948 Mdot
.506 .52958 Mdot
.506 .52985 Mdot
.506 .53008 Mdot
.506 .53027 Mdot
.506 .53031 Mdot
.506 .53036 Mdot
.506 .53041 Mdot
.506 .53041 Mdot
.506 .53049 Mdot
.506 .53062 Mdot
.506 .53062 Mdot
.506 .5307 Mdot
.506 .53082 Mdot
.506 .53094 Mdot
.506 .53096 Mdot
.506 .53097 Mdot
.506 .53097 Mdot
.506 .531 Mdot
.506 .53101 Mdot
.506 .53108 Mdot
.506 .53131 Mdot
.506 .53142 Mdot
.506 .53156 Mdot
.506 .53157 Mdot
.506 .53181 Mdot
.506 .53199 Mdot
.506 .53201 Mdot
.506 .53225 Mdot
.506 .53271 Mdot
.506 .53277 Mdot
.506 .53283 Mdot
.506 .53287 Mdot
.506 .53289 Mdot
.506 .53298 Mdot
.506 .53303 Mdot
.506 .53324 Mdot
.506 .53325 Mdot
.506 .5333 Mdot
.506 .53331 Mdot
.506 .53363 Mdot
.506 .53373 Mdot
.506 .53382 Mdot
.506 .53407 Mdot
.506 .53412 Mdot
.506 .53413 Mdot
.506 .53416 Mdot
.506 .53429 Mdot
.506 .53439 Mdot
.506 .53441 Mdot
.506 .53442 Mdot
.506 .53454 Mdot
.506 .53454 Mdot
.506 .53461 Mdot
.506 .53477 Mdot
.506 .53478 Mdot
.506 .53481 Mdot
.506 .53487 Mdot
.506 .53487 Mdot
.506 .53491 Mdot
.506 .53493 Mdot
.506 .53521 Mdot
.506 .53526 Mdot
.506 .53526 Mdot
.506 .53536 Mdot
.506 .53546 Mdot
.506 .53546 Mdot
.506 .53547 Mdot
.506 .53553 Mdot
.506 .53553 Mdot
.506 .53554 Mdot
.506 .53564 Mdot
.506 .53569 Mdot
.506 .5358 Mdot
.506 .53582 Mdot
.506 .53582 Mdot
.506 .53586 Mdot
.506 .53594 Mdot
.506 .536 Mdot
.506 .53612 Mdot
.506 .53612 Mdot
.506 .53649 Mdot
.506 .53662 Mdot
.506 .53671 Mdot
.506 .53684 Mdot
.506 .53696 Mdot
.506 .53696 Mdot
.506 .53716 Mdot
.506 .5374 Mdot
.506 .53746 Mdot
.506 .53746 Mdot
.506 .53766 Mdot
.506 .53793 Mdot
.506 .53823 Mdot
.506 .53828 Mdot
.506 .53829 Mdot
.506 .5383 Mdot
.506 .53833 Mdot
.506 .53837 Mdot
.506 .53839 Mdot
.506 .53855 Mdot
.506 .53905 Mdot
.506 .53905 Mdot
.506 .53931 Mdot
.506 .53933 Mdot
.506 .5396 Mdot
.506 .53961 Mdot
.506 .53998 Mdot
.506 .54011 Mdot
.506 .54027 Mdot
.506 .54037 Mdot
.506 .54048 Mdot
.506 .54052 Mdot
.506 .54063 Mdot
.506 .54088 Mdot
.506 .54097 Mdot
.506 .54122 Mdot
.506 .54152 Mdot
.506 .5418 Mdot
.506 .54191 Mdot
.506 .542 Mdot
.506 .54207 Mdot
.506 .54209 Mdot
.506 .54226 Mdot
.506 .54226 Mdot
.506 .54228 Mdot
.506 .54232 Mdot
.506 .54266 Mdot
.506 .54266 Mdot
.506 .54274 Mdot
.506 .54276 Mdot
.506 .54277 Mdot
.506 .54281 Mdot
.506 .54321 Mdot
.506 .54321 Mdot
.506 .54321 Mdot
.506 .54334 Mdot
.506 .54346 Mdot
.506 .54376 Mdot
.506 .54381 Mdot
.506 .54382 Mdot
.506 .54386 Mdot
.506 .54391 Mdot
.506 .544 Mdot
.506 .54409 Mdot
.506 .5441 Mdot
.506 .54412 Mdot
.506 .54412 Mdot
.506 .54413 Mdot
.506 .54416 Mdot
.506 .54419 Mdot
.506 .5442 Mdot
.506 .54421 Mdot
.506 .54424 Mdot
.506 .54425 Mdot
.506 .54426 Mdot
.506 .54432 Mdot
.506 .54446 Mdot
.506 .54446 Mdot
.506 .54449 Mdot
.506 .54453 Mdot
.506 .54453 Mdot
.506 .54454 Mdot
.506 .54457 Mdot
.506 .54458 Mdot
.506 .54475 Mdot
.506 .54478 Mdot
.506 .5448 Mdot
.506 .5448 Mdot
.506 .54486 Mdot
.506 .54487 Mdot
.506 .54488 Mdot
.506 .54491 Mdot
.506 .54491 Mdot
.506 .54492 Mdot
.506 .54492 Mdot
.506 .54495 Mdot
.506 .54495 Mdot
.506 .54495 Mdot
.506 .545 Mdot
.506 .54502 Mdot
.506 .54502 Mdot
.506 .54506 Mdot
.506 .54506 Mdot
.506 .54506 Mdot
.506 .54508 Mdot
.506 .54509 Mdot
.506 .54509 Mdot
.506 .5451 Mdot
.506 .54512 Mdot
.506 .54512 Mdot
.506 .54514 Mdot
.506 .54514 Mdot
.506 .54514 Mdot
.506 .54516 Mdot
.506 .54516 Mdot
.508 .20304 Mdot
.508 .20304 Mdot
.508 .20304 Mdot
.508 .20304 Mdot
.508 .20304 Mdot
.508 .20304 Mdot
.508 .20304 Mdot
.508 .20304 Mdot
.508 .20305 Mdot
.508 .20305 Mdot
.508 .20305 Mdot
.508 .20305 Mdot
.508 .20305 Mdot
.508 .20305 Mdot
.508 .20305 Mdot
.508 .20306 Mdot
.508 .20306 Mdot
.508 .20306 Mdot
.508 .20306 Mdot
.508 .20306 Mdot
.508 .20306 Mdot
.508 .20306 Mdot
.508 .20306 Mdot
.508 .20306 Mdot
.508 .20306 Mdot
.508 .20306 Mdot
.508 .20306 Mdot
.508 .20306 Mdot
.508 .20307 Mdot
.508 .20307 Mdot
.508 .20307 Mdot
.508 .20307 Mdot
.508 .20307 Mdot
.508 .20307 Mdot
.508 .20307 Mdot
.508 .20308 Mdot
.508 .20308 Mdot
.508 .20308 Mdot
.508 .20308 Mdot
.508 .20308 Mdot
.508 .20308 Mdot
.508 .20309 Mdot
.508 .20311 Mdot
.508 .20311 Mdot
.508 .20312 Mdot
.508 .20312 Mdot
.508 .20312 Mdot
.508 .20312 Mdot
.508 .20312 Mdot
.508 .20312 Mdot
.508 .20326 Mdot
.508 .20326 Mdot
.508 .20327 Mdot
.508 .20327 Mdot
.508 .20327 Mdot
.508 .20327 Mdot
.508 .20327 Mdot
.508 .20332 Mdot
.508 .20333 Mdot
.508 .20335 Mdot
.508 .20335 Mdot
.508 .20335 Mdot
.508 .20335 Mdot
.508 .20336 Mdot
.508 .20336 Mdot
.508 .20338 Mdot
.508 .20338 Mdot
.508 .20339 Mdot
.508 .20339 Mdot
.508 .20339 Mdot
.508 .20339 Mdot
.508 .20339 Mdot
.508 .2034 Mdot
.508 .2034 Mdot
.508 .2034 Mdot
.508 .2034 Mdot
.508 .2034 Mdot
.508 .2034 Mdot
.508 .20341 Mdot
.508 .20341 Mdot
.508 .20341 Mdot
.508 .20341 Mdot
.508 .20341 Mdot
.508 .20341 Mdot
.508 .20342 Mdot
.508 .20342 Mdot
.508 .20343 Mdot
.508 .20343 Mdot
.508 .20343 Mdot
.508 .20343 Mdot
.508 .20343 Mdot
.508 .20344 Mdot
.508 .20346 Mdot
.508 .20346 Mdot
.508 .20346 Mdot
.508 .20346 Mdot
.508 .20346 Mdot
.508 .20346 Mdot
.508 .20346 Mdot
.508 .20346 Mdot
.508 .22621 Mdot
.508 .22622 Mdot
.508 .22622 Mdot
.508 .22622 Mdot
.508 .22622 Mdot
.508 .22622 Mdot
.508 .22623 Mdot
.508 .22623 Mdot
.508 .22627 Mdot
.508 .2263 Mdot
.508 .2263 Mdot
.508 .2263 Mdot
.508 .2263 Mdot
.508 .22631 Mdot
.508 .22631 Mdot
.508 .22633 Mdot
.508 .22634 Mdot
.508 .22634 Mdot
.508 .22634 Mdot
.508 .22634 Mdot
.508 .22635 Mdot
.508 .22636 Mdot
.508 .22636 Mdot
.508 .22637 Mdot
.508 .22637 Mdot
.508 .22638 Mdot
.508 .22638 Mdot
.508 .22638 Mdot
.508 .2264 Mdot
.508 .2264 Mdot
.508 .2264 Mdot
.508 .2264 Mdot
.508 .22641 Mdot
.508 .22641 Mdot
.508 .22643 Mdot
.508 .22648 Mdot
.508 .22649 Mdot
.508 .2265 Mdot
.508 .2265 Mdot
.508 .22651 Mdot
.508 .22651 Mdot
.508 .22655 Mdot
.508 .22659 Mdot
.508 .22673 Mdot
.508 .22674 Mdot
.508 .22674 Mdot
.508 .22676 Mdot
.508 .22676 Mdot
.508 .22676 Mdot
.508 .22678 Mdot
.508 .22772 Mdot
.508 .22776 Mdot
.508 .22777 Mdot
.508 .22777 Mdot
.508 .22781 Mdot
.508 .22781 Mdot
.508 .22784 Mdot
.508 .22815 Mdot
.508 .22824 Mdot
.508 .22834 Mdot
.508 .22835 Mdot
.508 .22838 Mdot
.508 .22838 Mdot
.508 .2284 Mdot
.508 .22841 Mdot
.508 .22855 Mdot
.508 .22861 Mdot
.508 .22861 Mdot
.508 .22862 Mdot
.508 .22862 Mdot
.508 .22863 Mdot
.508 .22863 Mdot
.508 .22869 Mdot
.508 .22869 Mdot
.508 .2287 Mdot
.508 .22872 Mdot
.508 .22872 Mdot
.508 .22875 Mdot
.508 .22875 Mdot
.508 .22878 Mdot
.508 .22878 Mdot
.508 .22879 Mdot
.508 .22879 Mdot
.508 .22879 Mdot
.508 .22882 Mdot
.508 .22889 Mdot
.508 .22889 Mdot
.508 .2289 Mdot
.508 .2289 Mdot
.508 .22891 Mdot
.508 .22892 Mdot
.508 .229 Mdot
.508 .22912 Mdot
.508 .22913 Mdot
.508 .22913 Mdot
.508 .22913 Mdot
.508 .22915 Mdot
.508 .22915 Mdot
.508 .22915 Mdot
.508 .22917 Mdot
.508 .27027 Mdot
.508 .27028 Mdot
.508 .27028 Mdot
.508 .27028 Mdot
.508 .27029 Mdot
.508 .27029 Mdot
.508 .2703 Mdot
.508 .27031 Mdot
.508 .2704 Mdot
.508 .27046 Mdot
.508 .27046 Mdot
.508 .27047 Mdot
.508 .27047 Mdot
.508 .27048 Mdot
.508 .27048 Mdot
.508 .27053 Mdot
.508 .27055 Mdot
.508 .27055 Mdot
.508 .27056 Mdot
.508 .27056 Mdot
.508 .27056 Mdot
.508 .27058 Mdot
.508 .27059 Mdot
.508 .27061 Mdot
.508 .27061 Mdot
.508 .27062 Mdot
.508 .27063 Mdot
.508 .27063 Mdot
.508 .27068 Mdot
.508 .27068 Mdot
.508 .27068 Mdot
.508 .27068 Mdot
.508 .27069 Mdot
.508 .27069 Mdot
.508 .27074 Mdot
.508 .27084 Mdot
.508 .27085 Mdot
.508 .27086 Mdot
.508 .27087 Mdot
.508 .27089 Mdot
.508 .2709 Mdot
.508 .27097 Mdot
.508 .27104 Mdot
.508 .27129 Mdot
.508 .27131 Mdot
.508 .27131 Mdot
.508 .27134 Mdot
.508 .27134 Mdot
.508 .27134 Mdot
.508 .27138 Mdot
.508 .27211 Mdot
.508 .27213 Mdot
.508 .27213 Mdot
.508 .27213 Mdot
.508 .27215 Mdot
.508 .27215 Mdot
.508 .27215 Mdot
.508 .27216 Mdot
.508 .27227 Mdot
.508 .27229 Mdot
.508 .27233 Mdot
.508 .27233 Mdot
.508 .27234 Mdot
.508 .27234 Mdot
.508 .27235 Mdot
.508 .27235 Mdot
.508 .27239 Mdot
.508 .27241 Mdot
.508 .27241 Mdot
.508 .27241 Mdot
.508 .27241 Mdot
.508 .27241 Mdot
.508 .27242 Mdot
.508 .27243 Mdot
.508 .27243 Mdot
.508 .27244 Mdot
.508 .27244 Mdot
.508 .27244 Mdot
.508 .27245 Mdot
.508 .27245 Mdot
.508 .27246 Mdot
.508 .27246 Mdot
.508 .27246 Mdot
.508 .27246 Mdot
.508 .27246 Mdot
.508 .27247 Mdot
.508 .27249 Mdot
.508 .27249 Mdot
.508 .27249 Mdot
.508 .27249 Mdot
.508 .2725 Mdot
.508 .2725 Mdot
.508 .27252 Mdot
.508 .27255 Mdot
.508 .27256 Mdot
.508 .27256 Mdot
.508 .27256 Mdot
.508 .27256 Mdot
.508 .27256 Mdot
.508 .27256 Mdot
.508 .27257 Mdot
.508 .30684 Mdot
.508 .30688 Mdot
.508 .30689 Mdot
.508 .30689 Mdot
.508 .30692 Mdot
.508 .30692 Mdot
.508 .30695 Mdot
.508 .30697 Mdot
.508 .30725 Mdot
.508 .30743 Mdot
.508 .30744 Mdot
.508 .30748 Mdot
.508 .30748 Mdot
.508 .3075 Mdot
.508 .30751 Mdot
.508 .30766 Mdot
.508 .30773 Mdot
.508 .30774 Mdot
.508 .30775 Mdot
.508 .30776 Mdot
.508 .30776 Mdot
.508 .30784 Mdot
.508 .30784 Mdot
.508 .30791 Mdot
.508 .30791 Mdot
.508 .30796 Mdot
.508 .30797 Mdot
.508 .30797 Mdot
.508 .30812 Mdot
.508 .30813 Mdot
.508 .30814 Mdot
.508 .30814 Mdot
.508 .30816 Mdot
.508 .30817 Mdot
.508 .30832 Mdot
.508 .30863 Mdot
.508 .30867 Mdot
.508 .3087 Mdot
.508 .30871 Mdot
.508 .30878 Mdot
.508 .30881 Mdot
.508 .30904 Mdot
.508 .30925 Mdot
.508 .31001 Mdot
.508 .31007 Mdot
.508 .31007 Mdot
.508 .31016 Mdot
.508 .31016 Mdot
.508 .31019 Mdot
.508 .31028 Mdot
.508 .31254 Mdot
.508 .31258 Mdot
.508 .3126 Mdot
.508 .3126 Mdot
.508 .31264 Mdot
.508 .31264 Mdot
.508 .31267 Mdot
.508 .313 Mdot
.508 .31309 Mdot
.508 .31319 Mdot
.508 .3132 Mdot
.508 .31323 Mdot
.508 .31323 Mdot
.508 .31324 Mdot
.508 .31326 Mdot
.508 .31338 Mdot
.508 .31344 Mdot
.508 .31344 Mdot
.508 .31345 Mdot
.508 .31345 Mdot
.508 .31345 Mdot
.508 .31346 Mdot
.508 .31351 Mdot
.508 .31351 Mdot
.508 .31352 Mdot
.508 .31353 Mdot
.508 .31354 Mdot
.508 .31356 Mdot
.508 .31356 Mdot
.508 .31359 Mdot
.508 .31359 Mdot
.508 .3136 Mdot
.508 .3136 Mdot
.508 .3136 Mdot
.508 .31363 Mdot
.508 .31368 Mdot
.508 .31369 Mdot
.508 .31369 Mdot
.508 .31369 Mdot
.508 .31371 Mdot
.508 .31371 Mdot
.508 .31378 Mdot
.508 .31388 Mdot
.508 .31388 Mdot
.508 .31389 Mdot
.508 .31389 Mdot
.508 .3139 Mdot
.508 .3139 Mdot
.508 .31391 Mdot
.508 .31392 Mdot
.508 .37222 Mdot
.508 .37223 Mdot
.508 .37223 Mdot
.508 .37223 Mdot
.508 .37223 Mdot
.508 .37223 Mdot
.508 .37224 Mdot
.508 .37224 Mdot
.508 .37228 Mdot
.508 .37231 Mdot
.508 .37232 Mdot
.508 .37232 Mdot
.508 .37232 Mdot
.508 .37232 Mdot
.508 .37233 Mdot
.508 .37235 Mdot
.508 .37236 Mdot
.508 .37236 Mdot
.508 .37236 Mdot
.508 .37237 Mdot
.508 .37237 Mdot
.508 .37238 Mdot
.508 .37238 Mdot
.508 .37239 Mdot
.508 .37239 Mdot
.508 .3724 Mdot
.508 .3724 Mdot
.508 .3724 Mdot
.508 .37242 Mdot
.508 .37243 Mdot
.508 .37243 Mdot
.508 .37243 Mdot
.508 .37243 Mdot
.508 .37243 Mdot
.508 .37246 Mdot
.508 .37251 Mdot
.508 .37251 Mdot
.508 .37252 Mdot
.508 .37252 Mdot
.508 .37253 Mdot
.508 .37253 Mdot
.508 .37257 Mdot
.508 .3726 Mdot
.508 .37273 Mdot
.508 .37274 Mdot
.508 .37274 Mdot
.508 .37275 Mdot
.508 .37275 Mdot
.508 .37275 Mdot
.508 .37277 Mdot
.508 .37313 Mdot
.508 .37314 Mdot
.508 .37314 Mdot
.508 .37314 Mdot
.508 .37315 Mdot
.508 .37315 Mdot
.508 .37315 Mdot
.508 .37316 Mdot
.508 .37321 Mdot
.508 .37324 Mdot
.508 .37324 Mdot
.508 .37325 Mdot
.508 .37325 Mdot
.508 .37325 Mdot
.508 .37325 Mdot
.508 .37327 Mdot
.508 .37328 Mdot
.508 .37328 Mdot
.508 .37328 Mdot
.508 .37328 Mdot
.508 .37328 Mdot
.508 .37328 Mdot
.508 .37329 Mdot
.508 .37329 Mdot
.508 .37329 Mdot
.508 .37329 Mdot
.508 .37329 Mdot
.508 .3733 Mdot
.508 .3733 Mdot
.508 .3733 Mdot
.508 .3733 Mdot
.508 .3733 Mdot
.508 .37331 Mdot
.508 .37331 Mdot
.508 .37331 Mdot
.508 .37332 Mdot
.508 .37332 Mdot
.508 .37332 Mdot
.508 .37332 Mdot
.508 .37332 Mdot
.508 .37332 Mdot
.508 .37333 Mdot
.508 .37335 Mdot
.508 .37335 Mdot
.508 .37335 Mdot
.508 .37335 Mdot
.508 .37335 Mdot
.508 .37335 Mdot
.508 .37335 Mdot
.508 .37336 Mdot
.508 .47659 Mdot
.508 .47659 Mdot
.508 .47659 Mdot
.508 .47659 Mdot
.508 .47659 Mdot
.508 .47659 Mdot
.508 .47659 Mdot
.508 .47659 Mdot
.508 .4766 Mdot
.508 .4766 Mdot
.508 .4766 Mdot
.508 .4766 Mdot
.508 .4766 Mdot
.508 .4766 Mdot
.508 .4766 Mdot
.508 .47661 Mdot
.508 .47661 Mdot
.508 .47661 Mdot
.508 .47661 Mdot
.508 .47661 Mdot
.508 .47661 Mdot
.508 .47661 Mdot
.508 .47661 Mdot
.508 .47662 Mdot
.508 .47662 Mdot
.508 .47662 Mdot
.508 .47662 Mdot
.508 .47662 Mdot
.508 .47662 Mdot
.508 .47662 Mdot
.508 .47662 Mdot
.508 .47662 Mdot
.508 .47662 Mdot
.508 .47662 Mdot
.508 .47663 Mdot
.508 .47664 Mdot
.508 .47664 Mdot
.508 .47664 Mdot
.508 .47664 Mdot
.508 .47664 Mdot
.508 .47664 Mdot
.508 .47666 Mdot
.508 .47668 Mdot
.508 .47668 Mdot
.508 .47669 Mdot
.508 .47669 Mdot
.508 .47669 Mdot
.508 .47669 Mdot
.508 .47669 Mdot
.508 .47669 Mdot
.508 .47687 Mdot
.508 .47688 Mdot
.508 .47688 Mdot
.508 .47688 Mdot
.508 .47689 Mdot
.508 .47689 Mdot
.508 .47689 Mdot
.508 .47695 Mdot
.508 .47697 Mdot
.508 .47699 Mdot
.508 .47699 Mdot
.508 .47699 Mdot
.508 .47699 Mdot
.508 .477 Mdot
.508 .477 Mdot
.508 .47702 Mdot
.508 .47704 Mdot
.508 .47704 Mdot
.508 .47704 Mdot
.508 .47704 Mdot
.508 .47704 Mdot
.508 .47704 Mdot
.508 .47705 Mdot
.508 .47705 Mdot
.508 .47705 Mdot
.508 .47706 Mdot
.508 .47706 Mdot
.508 .47706 Mdot
.508 .47706 Mdot
.508 .47707 Mdot
.508 .47707 Mdot
.508 .47707 Mdot
.508 .47707 Mdot
.508 .47707 Mdot
.508 .47708 Mdot
.508 .47709 Mdot
.508 .47709 Mdot
.508 .47709 Mdot
.508 .47709 Mdot
.508 .47709 Mdot
.508 .47709 Mdot
.508 .47711 Mdot
.508 .47713 Mdot
.508 .47713 Mdot
.508 .47713 Mdot
.508 .47713 Mdot
.508 .47713 Mdot
.508 .47713 Mdot
.508 .47714 Mdot
.508 .47714 Mdot
.508 .50339 Mdot
.508 .50339 Mdot
.508 .5034 Mdot
.508 .5034 Mdot
.508 .5034 Mdot
.508 .5034 Mdot
.508 .5034 Mdot
.508 .50341 Mdot
.508 .50345 Mdot
.508 .50348 Mdot
.508 .50348 Mdot
.508 .50348 Mdot
.508 .50348 Mdot
.508 .50349 Mdot
.508 .50349 Mdot
.508 .50351 Mdot
.508 .50352 Mdot
.508 .50352 Mdot
.508 .50352 Mdot
.508 .50352 Mdot
.508 .50353 Mdot
.508 .50354 Mdot
.508 .50354 Mdot
.508 .50355 Mdot
.508 .50355 Mdot
.508 .50356 Mdot
.508 .50356 Mdot
.508 .50356 Mdot
.508 .50358 Mdot
.508 .50358 Mdot
.508 .50359 Mdot
.508 .50359 Mdot
.508 .50359 Mdot
.508 .50359 Mdot
.508 .50361 Mdot
.508 .50367 Mdot
.508 .50367 Mdot
.508 .50368 Mdot
.508 .50368 Mdot
.508 .50369 Mdot
.508 .50369 Mdot
.508 .50374 Mdot
.508 .50377 Mdot
.508 .50391 Mdot
.508 .50392 Mdot
.508 .50393 Mdot
.508 .50394 Mdot
.508 .50394 Mdot
.508 .50395 Mdot
.508 .50397 Mdot
.508 .50491 Mdot
.508 .50495 Mdot
.508 .50496 Mdot
.508 .50496 Mdot
.508 .505 Mdot
.508 .505 Mdot
.508 .50502 Mdot
.508 .50534 Mdot
.508 .50542 Mdot
.508 .50552 Mdot
.508 .50553 Mdot
.508 .50556 Mdot
.508 .50557 Mdot
.508 .50558 Mdot
.508 .50559 Mdot
.508 .50572 Mdot
.508 .50579 Mdot
.508 .50579 Mdot
.508 .5058 Mdot
.508 .5058 Mdot
.508 .5058 Mdot
.508 .50581 Mdot
.508 .50587 Mdot
.508 .50587 Mdot
.508 .50588 Mdot
.508 .50589 Mdot
.508 .50589 Mdot
.508 .50593 Mdot
.508 .50593 Mdot
.508 .50596 Mdot
.508 .50596 Mdot
.508 .50596 Mdot
.508 .50597 Mdot
.508 .50597 Mdot
.508 .506 Mdot
.508 .50606 Mdot
.508 .50607 Mdot
.508 .50607 Mdot
.508 .50607 Mdot
.508 .50609 Mdot
.508 .50609 Mdot
.508 .50617 Mdot
.508 .50629 Mdot
.508 .50629 Mdot
.508 .5063 Mdot
.508 .5063 Mdot
.508 .50632 Mdot
.508 .50632 Mdot
.508 .50632 Mdot
.508 .50634 Mdot
.508 .52004 Mdot
.508 .52004 Mdot
.508 .52004 Mdot
.508 .52004 Mdot
.508 .52004 Mdot
.508 .52004 Mdot
.508 .52004 Mdot
.508 .52004 Mdot
.508 .52005 Mdot
.508 .52006 Mdot
.508 .52006 Mdot
.508 .52007 Mdot
.508 .52007 Mdot
.508 .52007 Mdot
.508 .52007 Mdot
.508 .52007 Mdot
.508 .52008 Mdot
.508 .52008 Mdot
.508 .52008 Mdot
.508 .52008 Mdot
.508 .52008 Mdot
.508 .52008 Mdot
.508 .52008 Mdot
.508 .52009 Mdot
.508 .52009 Mdot
.508 .52009 Mdot
.508 .52009 Mdot
.508 .52009 Mdot
.508 .5201 Mdot
.508 .5201 Mdot
.508 .5201 Mdot
.508 .5201 Mdot
.508 .5201 Mdot
.508 .5201 Mdot
.508 .52011 Mdot
.508 .52012 Mdot
.508 .52012 Mdot
.508 .52012 Mdot
.508 .52012 Mdot
.508 .52013 Mdot
.508 .52013 Mdot
.508 .52015 Mdot
.508 .52019 Mdot
.508 .5202 Mdot
.508 .5202 Mdot
.508 .5202 Mdot
.508 .52021 Mdot
.508 .52021 Mdot
.508 .52021 Mdot
.508 .52021 Mdot
.508 .5205 Mdot
.508 .52051 Mdot
.508 .52051 Mdot
.508 .52051 Mdot
.508 .52052 Mdot
.508 .52052 Mdot
.508 .52053 Mdot
.508 .52063 Mdot
.508 .52065 Mdot
.508 .52068 Mdot
.508 .52068 Mdot
.508 .52069 Mdot
.508 .52069 Mdot
.508 .5207 Mdot
.508 .5207 Mdot
.508 .52074 Mdot
.508 .52076 Mdot
.508 .52076 Mdot
.508 .52076 Mdot
.508 .52076 Mdot
.508 .52077 Mdot
.508 .52077 Mdot
.508 .52078 Mdot
.508 .52078 Mdot
.508 .52079 Mdot
.508 .52079 Mdot
.508 .52079 Mdot
.508 .5208 Mdot
.508 .5208 Mdot
.508 .52081 Mdot
.508 .52081 Mdot
.508 .52081 Mdot
.508 .52081 Mdot
.508 .52081 Mdot
.508 .52082 Mdot
.508 .52084 Mdot
.508 .52084 Mdot
.508 .52085 Mdot
.508 .52085 Mdot
.508 .52085 Mdot
.508 .52085 Mdot
.508 .52087 Mdot
.508 .52091 Mdot
.508 .52091 Mdot
.508 .52091 Mdot
.508 .52091 Mdot
.508 .52092 Mdot
.508 .52092 Mdot
.508 .52092 Mdot
.508 .52092 Mdot
.508 .5362 Mdot
.508 .53621 Mdot
.508 .53621 Mdot
.508 .53621 Mdot
.508 .53621 Mdot
.508 .53621 Mdot
.508 .53622 Mdot
.508 .53622 Mdot
.508 .53626 Mdot
.508 .53629 Mdot
.508 .53629 Mdot
.508 .5363 Mdot
.508 .5363 Mdot
.508 .5363 Mdot
.508 .5363 Mdot
.508 .53632 Mdot
.508 .53634 Mdot
.508 .53634 Mdot
.508 .53634 Mdot
.508 .53634 Mdot
.508 .53634 Mdot
.508 .53635 Mdot
.508 .53635 Mdot
.508 .53636 Mdot
.508 .53636 Mdot
.508 .53637 Mdot
.508 .53637 Mdot
.508 .53637 Mdot
.508 .53639 Mdot
.508 .5364 Mdot
.508 .5364 Mdot
.508 .5364 Mdot
.508 .5364 Mdot
.508 .5364 Mdot
.508 .53642 Mdot
.508 .53647 Mdot
.508 .53648 Mdot
.508 .53648 Mdot
.508 .53648 Mdot
.508 .53649 Mdot
.508 .5365 Mdot
.508 .53653 Mdot
.508 .53656 Mdot
.508 .53668 Mdot
.508 .53669 Mdot
.508 .53669 Mdot
.508 .5367 Mdot
.508 .5367 Mdot
.508 .53671 Mdot
.508 .53672 Mdot
.508 .53706 Mdot
.508 .53706 Mdot
.508 .53706 Mdot
.508 .53706 Mdot
.508 .53707 Mdot
.508 .53707 Mdot
.508 .53708 Mdot
.508 .53713 Mdot
.508 .53714 Mdot
.508 .53715 Mdot
.508 .53715 Mdot
.508 .53716 Mdot
.508 .53716 Mdot
.508 .53716 Mdot
.508 .53716 Mdot
.508 .53718 Mdot
.508 .53719 Mdot
.508 .53719 Mdot
.508 .53719 Mdot
.508 .53719 Mdot
.508 .53719 Mdot
.508 .53719 Mdot
.508 .5372 Mdot
.508 .5372 Mdot
.508 .5372 Mdot
.508 .5372 Mdot
.508 .5372 Mdot
.508 .53721 Mdot
.508 .53721 Mdot
.508 .53721 Mdot
.508 .53721 Mdot
.508 .53721 Mdot
.508 .53721 Mdot
.508 .53721 Mdot
.508 .53722 Mdot
.508 .53723 Mdot
.508 .53723 Mdot
.508 .53723 Mdot
.508 .53723 Mdot
.508 .53723 Mdot
.508 .53723 Mdot
.508 .53724 Mdot
.508 .53725 Mdot
.508 .53726 Mdot
.508 .53726 Mdot
.508 .53726 Mdot
.508 .53726 Mdot
.508 .53726 Mdot
.508 .53726 Mdot
.508 .53726 Mdot
.508 .54525 Mdot
.508 .54525 Mdot
.508 .54525 Mdot
.508 .54525 Mdot
.508 .54525 Mdot
.508 .54525 Mdot
.508 .54526 Mdot
.508 .54526 Mdot
.508 .54526 Mdot
.508 .54527 Mdot
.508 .54527 Mdot
.508 .54527 Mdot
.508 .54527 Mdot
.508 .54527 Mdot
.508 .54527 Mdot
.508 .54527 Mdot
.508 .54527 Mdot
.508 .54527 Mdot
.508 .54527 Mdot
.508 .54527 Mdot
.508 .54527 Mdot
.508 .54527 Mdot
.508 .54527 Mdot
.508 .54528 Mdot
.508 .54528 Mdot
.508 .54528 Mdot
.508 .54528 Mdot
.508 .54528 Mdot
.508 .54528 Mdot
.508 .54528 Mdot
.508 .54528 Mdot
.508 .54528 Mdot
.508 .54528 Mdot
.508 .54528 Mdot
.508 .54528 Mdot
.508 .54529 Mdot
.508 .54529 Mdot
.508 .54529 Mdot
.508 .54529 Mdot
.508 .54529 Mdot
.508 .54529 Mdot
.508 .5453 Mdot
.508 .5453 Mdot
.508 .54532 Mdot
.508 .54532 Mdot
.508 .54532 Mdot
.508 .54532 Mdot
.508 .54532 Mdot
.508 .54532 Mdot
.508 .54532 Mdot
.508 .54537 Mdot
.508 .54537 Mdot
.508 .54537 Mdot
.508 .54537 Mdot
.508 .54537 Mdot
.508 .54537 Mdot
.508 .54537 Mdot
.508 .54537 Mdot
.508 .54538 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .54539 Mdot
.508 .5454 Mdot
.508 .5454 Mdot
.508 .5454 Mdot
.508 .5454 Mdot
.508 .5454 Mdot
.508 .5454 Mdot
.508 .5454 Mdot
.508 .5454 Mdot
.508 .5454 Mdot
.508 .5454 Mdot
.508 .5454 Mdot
.508 .5454 Mdot
.508 .5454 Mdot
.508 .5454 Mdot
.508 .5454 Mdot
.51 .20244 Mdot
.51 .20244 Mdot
.51 .20245 Mdot
.51 .20246 Mdot
.51 .20248 Mdot
.51 .20252 Mdot
.51 .20256 Mdot
.51 .20258 Mdot
.51 .20265 Mdot
.51 .20268 Mdot
.51 .20269 Mdot
.51 .2027 Mdot
.51 .20277 Mdot
.51 .20278 Mdot
.51 .20298 Mdot
.51 .203 Mdot
.51 .2033 Mdot
.51 .20333 Mdot
.51 .20336 Mdot
.51 .20337 Mdot
.51 .20361 Mdot
.51 .20368 Mdot
.51 .20374 Mdot
.51 .20376 Mdot
.51 .20379 Mdot
.51 .20379 Mdot
.51 .20393 Mdot
.51 .20395 Mdot
.51 .20405 Mdot
.51 .20419 Mdot
.51 .20421 Mdot
.51 .20423 Mdot
.51 .20425 Mdot
.51 .20426 Mdot
.51 .20436 Mdot
.51 .20442 Mdot
.51 .20449 Mdot
.51 .20468 Mdot
.51 .20475 Mdot
.51 .20484 Mdot
.51 .20488 Mdot
.51 .20498 Mdot
.51 .20498 Mdot
.51 .20518 Mdot
.51 .2052 Mdot
.51 .20521 Mdot
.51 .20524 Mdot
.51 .20524 Mdot
.51 .20527 Mdot
.51 .2053 Mdot
.51 .20533 Mdot
.51 .20536 Mdot
.51 .20551 Mdot
.51 .20592 Mdot
.51 .20621 Mdot
.51 .20622 Mdot
.51 .2064 Mdot
.51 .20672 Mdot
.51 .20703 Mdot
.51 .20716 Mdot
.51 .20743 Mdot
.51 .20759 Mdot
.51 .20772 Mdot
.51 .20775 Mdot
.51 .20777 Mdot
.51 .20791 Mdot
.51 .20798 Mdot
.51 .2082 Mdot
.51 .2082 Mdot
.51 .20833 Mdot
.51 .20855 Mdot
.51 .20897 Mdot
.51 .20906 Mdot
.51 .20951 Mdot
.51 .21021 Mdot
.51 .21087 Mdot
.51 .21101 Mdot
.51 .21129 Mdot
.51 .21159 Mdot
.51 .21278 Mdot
.51 .2129 Mdot
.51 .21388 Mdot
.51 .2144 Mdot
.51 .21478 Mdot
.51 .21502 Mdot
.51 .21506 Mdot
.51 .2153 Mdot
.51 .216 Mdot
.51 .21634 Mdot
.51 .21653 Mdot
.51 .21689 Mdot
.51 .21717 Mdot
.51 .21739 Mdot
.51 .21822 Mdot
.51 .21828 Mdot
.51 .21885 Mdot
.51 .219 Mdot
.51 .22021 Mdot
.51 .22051 Mdot
.51 .22091 Mdot
.51 .22103 Mdot
.51 .22141 Mdot
.51 .22172 Mdot
.51 .2221 Mdot
.51 .22269 Mdot
.51 .22284 Mdot
.51 .22287 Mdot
.51 .2229 Mdot
.51 .22292 Mdot
.51 .22298 Mdot
.51 .22316 Mdot
.51 .22317 Mdot
.51 .22326 Mdot
.51 .22339 Mdot
.51 .22346 Mdot
.51 .22366 Mdot
.51 .2238 Mdot
.51 .22391 Mdot
.51 .22397 Mdot
.51 .22428 Mdot
.51 .22448 Mdot
.51 .22449 Mdot
.51 .22452 Mdot
.51 .22455 Mdot
.51 .22464 Mdot
.51 .22509 Mdot
.51 .22511 Mdot
.51 .22516 Mdot
.51 .22576 Mdot
.51 .2258 Mdot
.51 .22652 Mdot
.51 .22655 Mdot
.51 .22665 Mdot
.51 .22768 Mdot
.51 .22808 Mdot
.51 .22829 Mdot
.51 .22837 Mdot
.51 .22876 Mdot
.51 .22897 Mdot
.51 .22918 Mdot
.51 .22927 Mdot
.51 .22972 Mdot
.51 .22991 Mdot
.51 .22992 Mdot
.51 .23103 Mdot
.51 .23153 Mdot
.51 .23199 Mdot
.51 .23214 Mdot
.51 .23232 Mdot
.51 .23236 Mdot
.51 .23238 Mdot
.51 .23258 Mdot
.51 .23305 Mdot
.51 .23342 Mdot
.51 .23342 Mdot
.51 .23345 Mdot
.51 .23358 Mdot
.51 .23409 Mdot
.51 .23434 Mdot
.51 .2345 Mdot
.51 .23501 Mdot
.51 .23531 Mdot
.51 .23543 Mdot
.51 .23555 Mdot
.51 .23556 Mdot
.51 .23572 Mdot
.51 .23587 Mdot
.51 .23587 Mdot
.51 .23597 Mdot
.51 .23639 Mdot
.51 .23675 Mdot
.51 .23719 Mdot
.51 .23758 Mdot
.51 .23766 Mdot
.51 .23924 Mdot
.51 .23951 Mdot
.51 .23982 Mdot
.51 .23984 Mdot
.51 .24046 Mdot
.51 .24056 Mdot
.51 .24086 Mdot
.51 .24134 Mdot
.51 .24162 Mdot
.51 .24169 Mdot
.51 .24235 Mdot
.51 .24273 Mdot
.51 .24302 Mdot
.51 .24326 Mdot
.51 .24345 Mdot
.51 .24349 Mdot
.51 .24358 Mdot
.51 .24376 Mdot
.51 .24378 Mdot
.51 .244 Mdot
.51 .24425 Mdot
.51 .24449 Mdot
.51 .2445 Mdot
.51 .24479 Mdot
.51 .24546 Mdot
.51 .24548 Mdot
.51 .24599 Mdot
.51 .24606 Mdot
.51 .24606 Mdot
.51 .24702 Mdot
.51 .24719 Mdot
.51 .24732 Mdot
.51 .24755 Mdot
.51 .24798 Mdot
.51 .24807 Mdot
.51 .24817 Mdot
.51 .24835 Mdot
.51 .24879 Mdot
.51 .24941 Mdot
.51 .24952 Mdot
.51 .25002 Mdot
.51 .25075 Mdot
.51 .25136 Mdot
.51 .25191 Mdot
.51 .25202 Mdot
.51 .25228 Mdot
.51 .2528 Mdot
.51 .2535 Mdot
.51 .25436 Mdot
.51 .25505 Mdot
.51 .25519 Mdot
.51 .25525 Mdot
.51 .25633 Mdot
.51 .25668 Mdot
.51 .2573 Mdot
.51 .25777 Mdot
.51 .25798 Mdot
.51 .2587 Mdot
.51 .259 Mdot
.51 .25941 Mdot
.51 .2596 Mdot
.51 .25974 Mdot
.51 .25989 Mdot
.51 .26003 Mdot
.51 .26005 Mdot
.51 .26016 Mdot
.51 .26021 Mdot
.51 .26023 Mdot
.51 .26035 Mdot
.51 .2605 Mdot
.51 .26133 Mdot
.51 .26137 Mdot
.51 .26154 Mdot
.51 .26185 Mdot
.51 .26204 Mdot
.51 .2625 Mdot
.51 .26251 Mdot
.51 .26271 Mdot
.51 .26288 Mdot
.51 .26391 Mdot
.51 .26422 Mdot
.51 .26452 Mdot
.51 .26475 Mdot
.51 .26504 Mdot
.51 .2651 Mdot
.51 .2651 Mdot
.51 .26521 Mdot
.51 .26531 Mdot
.51 .26532 Mdot
.51 .2654 Mdot
.51 .26548 Mdot
.51 .26615 Mdot
.51 .26632 Mdot
.51 .26668 Mdot
.51 .26676 Mdot
.51 .26679 Mdot
.51 .26704 Mdot
.51 .26737 Mdot
.51 .26751 Mdot
.51 .26753 Mdot
.51 .26769 Mdot
.51 .2678 Mdot
.51 .26812 Mdot
.51 .26848 Mdot
.51 .26929 Mdot
.51 .2693 Mdot
.51 .26945 Mdot
.51 .26978 Mdot
.51 .26985 Mdot
.51 .27 Mdot
.51 .27016 Mdot
.51 .27046 Mdot
.51 .27051 Mdot
.51 .27178 Mdot
.51 .27186 Mdot
.51 .27188 Mdot
.51 .27245 Mdot
.51 .27248 Mdot
.51 .27297 Mdot
.51 .273 Mdot
.51 .27302 Mdot
.51 .27339 Mdot
.51 .27346 Mdot
.51 .27348 Mdot
.51 .27351 Mdot
.51 .27368 Mdot
.51 .27394 Mdot
.51 .27399 Mdot
.51 .27408 Mdot
.51 .27419 Mdot
.51 .27436 Mdot
.51 .27442 Mdot
.51 .27453 Mdot
.51 .27461 Mdot
.51 .27461 Mdot
.51 .27477 Mdot
.51 .27482 Mdot
.51 .27484 Mdot
.51 .27486 Mdot
.51 .27502 Mdot
.51 .27552 Mdot
.51 .27612 Mdot
.51 .27692 Mdot
.51 .27831 Mdot
.51 .27845 Mdot
.51 .27905 Mdot
.51 .28007 Mdot
.51 .28071 Mdot
.51 .28091 Mdot
.51 .28225 Mdot
.51 .2823 Mdot
.51 .28296 Mdot
.51 .28355 Mdot
.51 .287 Mdot
.51 .28717 Mdot
.51 .28805 Mdot
.51 .28903 Mdot
.51 .28981 Mdot
.51 .29077 Mdot
.51 .29098 Mdot
.51 .29098 Mdot
.51 .29133 Mdot
.51 .29167 Mdot
.51 .2917 Mdot
.51 .29197 Mdot
.51 .29223 Mdot
.51 .29292 Mdot
.51 .29408 Mdot
.51 .29443 Mdot
.51 .29501 Mdot
.51 .29618 Mdot
.51 .29646 Mdot
.51 .29653 Mdot
.51 .29654 Mdot
.51 .29737 Mdot
.51 .29845 Mdot
.51 .29892 Mdot
.51 .29897 Mdot
.51 .29907 Mdot
.51 .29949 Mdot
.51 .29984 Mdot
.51 .3009 Mdot
.51 .30206 Mdot
.51 .30467 Mdot
.51 .30469 Mdot
.51 .30515 Mdot
.51 .30621 Mdot
.51 .30642 Mdot
.51 .30691 Mdot
.51 .30742 Mdot
.51 .30835 Mdot
.51 .30853 Mdot
.51 .30903 Mdot
.51 .30999 Mdot
.51 .31247 Mdot
.51 .31272 Mdot
.51 .31279 Mdot
.51 .31453 Mdot
.51 .31463 Mdot
.51 .31609 Mdot
.51 .3162 Mdot
.51 .31625 Mdot
.51 .31737 Mdot
.51 .31757 Mdot
.51 .31764 Mdot
.51 .31774 Mdot
.51 .31775 Mdot
.51 .31824 Mdot
.51 .319 Mdot
.51 .31915 Mdot
.51 .31943 Mdot
.51 .31976 Mdot
.51 .32025 Mdot
.51 .32043 Mdot
.51 .32075 Mdot
.51 .32097 Mdot
.51 .32099 Mdot
.51 .32144 Mdot
.51 .32158 Mdot
.51 .32164 Mdot
.51 .32171 Mdot
.51 .32178 Mdot
.51 .32217 Mdot
.51 .32363 Mdot
.51 .32456 Mdot
.51 .32534 Mdot
.51 .32629 Mdot
.51 .3266 Mdot
.51 .3276 Mdot
.51 .32835 Mdot
.51 .3314 Mdot
.51 .33178 Mdot
.51 .33323 Mdot
.51 .33337 Mdot
.51 .33548 Mdot
.51 .33604 Mdot
.51 .33677 Mdot
.51 .33767 Mdot
.51 .33818 Mdot
.51 .33904 Mdot
.51 .34084 Mdot
.51 .34147 Mdot
.51 .34158 Mdot
.51 .34218 Mdot
.51 .34315 Mdot
.51 .34452 Mdot
.51 .34705 Mdot
.51 .34736 Mdot
.51 .35047 Mdot
.51 .35125 Mdot
.51 .352 Mdot
.51 .35234 Mdot
.51 .35407 Mdot
.51 .35593 Mdot
.51 .35712 Mdot
.51 .35735 Mdot
.51 .35844 Mdot
.51 .35902 Mdot
.51 .35938 Mdot
.51 .35938 Mdot
.51 .35995 Mdot
.51 .36013 Mdot
.51 .36052 Mdot
.51 .36057 Mdot
.51 .36063 Mdot
.51 .36099 Mdot
.51 .36141 Mdot
.51 .36212 Mdot
.51 .36247 Mdot
.51 .36328 Mdot
.51 .36415 Mdot
.51 .36461 Mdot
.51 .36464 Mdot
.51 .36542 Mdot
.51 .36651 Mdot
.51 .36689 Mdot
.51 .36699 Mdot
.51 .36707 Mdot
.51 .36715 Mdot
.51 .36722 Mdot
.51 .36723 Mdot
.51 .36731 Mdot
.51 .36732 Mdot
.51 .36739 Mdot
.51 .36747 Mdot
.51 .3679 Mdot
.51 .36792 Mdot
.51 .36818 Mdot
.51 .36827 Mdot
.51 .36852 Mdot
.51 .36871 Mdot
.51 .36941 Mdot
.51 .36956 Mdot
.51 .36982 Mdot
.51 .36986 Mdot
.51 .36991 Mdot
.51 .36997 Mdot
.51 .37001 Mdot
.51 .37039 Mdot
.51 .37066 Mdot
.51 .3707 Mdot
.51 .37108 Mdot
.51 .37109 Mdot
.51 .37117 Mdot
.51 .37122 Mdot
.51 .37139 Mdot
.51 .37157 Mdot
.51 .37221 Mdot
.51 .37225 Mdot
.51 .37232 Mdot
.51 .3724 Mdot
.51 .3732 Mdot
.51 .37325 Mdot
.51 .3738 Mdot
.51 .3738 Mdot
.51 .37399 Mdot
.51 .37402 Mdot
.51 .37405 Mdot
.51 .37413 Mdot
.51 .37432 Mdot
.51 .37438 Mdot
.51 .37449 Mdot
.51 .37457 Mdot
.51 .37465 Mdot
.51 .37468 Mdot
.51 .37469 Mdot
.51 .3747 Mdot
.51 .47601 Mdot
.51 .47602 Mdot
.51 .47602 Mdot
.51 .47603 Mdot
.51 .47607 Mdot
.51 .47611 Mdot
.51 .47617 Mdot
.51 .47619 Mdot
.51 .47629 Mdot
.51 .47633 Mdot
.51 .47634 Mdot
.51 .47636 Mdot
.51 .47645 Mdot
.51 .47645 Mdot
.51 .47671 Mdot
.51 .47674 Mdot
.51 .47713 Mdot
.51 .47717 Mdot
.51 .4772 Mdot
.51 .47722 Mdot
.51 .47753 Mdot
.51 .47762 Mdot
.51 .4777 Mdot
.51 .47772 Mdot
.51 .47776 Mdot
.51 .47777 Mdot
.51 .47795 Mdot
.51 .47797 Mdot
.51 .4781 Mdot
.51 .47828 Mdot
.51 .4783 Mdot
.51 .47833 Mdot
.51 .47836 Mdot
.51 .47837 Mdot
.51 .4785 Mdot
.51 .47857 Mdot
.51 .47891 Mdot
.51 .479 Mdot
.51 .47912 Mdot
.51 .47917 Mdot
.51 .47929 Mdot
.51 .4793 Mdot
.51 .47954 Mdot
.51 .47957 Mdot
.51 .47958 Mdot
.51 .47962 Mdot
.51 .47962 Mdot
.51 .47966 Mdot
.51 .4797 Mdot
.51 .47973 Mdot
.51 .47978 Mdot
.51 .47996 Mdot
.51 .48048 Mdot
.51 .48085 Mdot
.51 .48087 Mdot
.51 .48109 Mdot
.51 .4815 Mdot
.51 .48188 Mdot
.51 .48205 Mdot
.51 .48238 Mdot
.51 .48258 Mdot
.51 .48274 Mdot
.51 .48277 Mdot
.51 .4828 Mdot
.51 .48298 Mdot
.51 .48306 Mdot
.51 .48333 Mdot
.51 .48333 Mdot
.51 .4835 Mdot
.51 .48377 Mdot
.51 .48428 Mdot
.51 .48439 Mdot
.51 .48494 Mdot
.51 .4858 Mdot
.51 .48659 Mdot
.51 .48675 Mdot
.51 .48709 Mdot
.51 .48745 Mdot
.51 .48887 Mdot
.51 .48901 Mdot
.51 .49015 Mdot
.51 .49077 Mdot
.51 .4912 Mdot
.51 .49147 Mdot
.51 .49152 Mdot
.51 .4918 Mdot
.51 .4926 Mdot
.51 .49299 Mdot
.51 .49321 Mdot
.51 .49361 Mdot
.51 .49393 Mdot
.51 .49418 Mdot
.51 .49511 Mdot
.51 .49517 Mdot
.51 .4958 Mdot
.51 .49597 Mdot
.51 .49729 Mdot
.51 .49762 Mdot
.51 .49805 Mdot
.51 .49818 Mdot
.51 .49859 Mdot
.51 .49893 Mdot
.51 .49933 Mdot
.51 .49995 Mdot
.51 .50012 Mdot
.51 .50015 Mdot
.51 .50018 Mdot
.51 .5002 Mdot
.51 .50026 Mdot
.51 .50045 Mdot
.51 .50046 Mdot
.51 .50056 Mdot
.51 .50069 Mdot
.51 .50077 Mdot
.51 .50098 Mdot
.51 .50112 Mdot
.51 .50124 Mdot
.51 .5013 Mdot
.51 .50162 Mdot
.51 .50183 Mdot
.51 .50184 Mdot
.51 .50188 Mdot
.51 .50191 Mdot
.51 .50199 Mdot
.51 .50246 Mdot
.51 .50248 Mdot
.51 .50253 Mdot
.51 .50315 Mdot
.51 .50319 Mdot
.51 .50392 Mdot
.51 .50395 Mdot
.51 .50405 Mdot
.51 .50509 Mdot
.51 .50548 Mdot
.51 .50569 Mdot
.51 .50577 Mdot
.51 .50615 Mdot
.51 .50636 Mdot
.51 .50657 Mdot
.51 .50665 Mdot
.51 .50709 Mdot
.51 .50728 Mdot
.51 .50729 Mdot
.51 .50836 Mdot
.51 .50883 Mdot
.51 .50926 Mdot
.51 .50941 Mdot
.51 .50957 Mdot
.51 .50962 Mdot
.51 .50964 Mdot
.51 .50983 Mdot
.51 .51027 Mdot
.51 .5106 Mdot
.51 .51061 Mdot
.51 .51064 Mdot
.51 .51075 Mdot
.51 .51122 Mdot
.51 .51145 Mdot
.51 .5116 Mdot
.51 .51206 Mdot
.51 .51234 Mdot
.51 .51245 Mdot
.51 .51255 Mdot
.51 .51256 Mdot
.51 .5127 Mdot
.51 .51284 Mdot
.51 .51284 Mdot
.51 .51293 Mdot
.51 .51331 Mdot
.51 .51362 Mdot
.51 .51401 Mdot
.51 .51436 Mdot
.51 .51443 Mdot
.51 .51579 Mdot
.51 .51603 Mdot
.51 .51629 Mdot
.51 .5163 Mdot
.51 .51683 Mdot
.51 .51691 Mdot
.51 .51716 Mdot
.51 .51756 Mdot
.51 .51779 Mdot
.51 .51785 Mdot
.51 .51839 Mdot
.51 .5187 Mdot
.51 .51894 Mdot
.51 .51913 Mdot
.51 .51919 Mdot
.51 .5192 Mdot
.51 .51921 Mdot
.51 .51923 Mdot
.51 .51929 Mdot
.51 .51929 Mdot
.51 .51932 Mdot
.51 .51936 Mdot
.51 .51939 Mdot
.51 .51945 Mdot
.51 .51949 Mdot
.51 .51953 Mdot
.51 .51955 Mdot
.51 .51965 Mdot
.51 .51971 Mdot
.51 .51973 Mdot
.51 .51974 Mdot
.51 .51976 Mdot
.51 .51991 Mdot
.51 .51991 Mdot
.51 .51993 Mdot
.51 .52011 Mdot
.51 .52012 Mdot
.51 .52034 Mdot
.51 .52035 Mdot
.51 .52038 Mdot
.51 .52087 Mdot
.51 .52089 Mdot
.51 .52101 Mdot
.51 .52107 Mdot
.51 .52113 Mdot
.51 .52116 Mdot
.51 .52128 Mdot
.51 .52134 Mdot
.51 .52134 Mdot
.51 .52165 Mdot
.51 .52179 Mdot
.51 .52192 Mdot
.51 .52196 Mdot
.51 .52202 Mdot
.51 .52203 Mdot
.51 .52208 Mdot
.51 .52221 Mdot
.51 .5223 Mdot
.51 .52231 Mdot
.51 .52235 Mdot
.51 .52248 Mdot
.51 .52255 Mdot
.51 .5228 Mdot
.51 .52283 Mdot
.51 .52286 Mdot
.51 .52287 Mdot
.51 .52291 Mdot
.51 .52295 Mdot
.51 .52295 Mdot
.51 .52297 Mdot
.51 .52308 Mdot
.51 .52317 Mdot
.51 .52328 Mdot
.51 .5234 Mdot
.51 .52379 Mdot
.51 .52386 Mdot
.51 .52393 Mdot
.51 .52394 Mdot
.51 .52411 Mdot
.51 .52418 Mdot
.51 .5243 Mdot
.51 .52437 Mdot
.51 .52438 Mdot
.51 .52469 Mdot
.51 .52475 Mdot
.51 .5248 Mdot
.51 .52481 Mdot
.51 .52482 Mdot
.51 .52487 Mdot
.51 .52487 Mdot
.51 .52492 Mdot
.51 .52498 Mdot
.51 .52503 Mdot
.51 .5251 Mdot
.51 .52526 Mdot
.51 .52537 Mdot
.51 .52564 Mdot
.51 .52573 Mdot
.51 .5259 Mdot
.51 .52613 Mdot
.51 .52626 Mdot
.51 .52667 Mdot
.51 .52669 Mdot
.51 .52675 Mdot
.51 .527 Mdot
.51 .52732 Mdot
.51 .52759 Mdot
.51 .52778 Mdot
.51 .52788 Mdot
.51 .52792 Mdot
.51 .52812 Mdot
.51 .52835 Mdot
.51 .52862 Mdot
.51 .52881 Mdot
.51 .52885 Mdot
.51 .52908 Mdot
.51 .52924 Mdot
.51 .52931 Mdot
.51 .52935 Mdot
.51 .52938 Mdot
.51 .52954 Mdot
.51 .52962 Mdot
.51 .52967 Mdot
.51 .52973 Mdot
.51 .53009 Mdot
.51 .53009 Mdot
.51 .53012 Mdot
.51 .5303 Mdot
.51 .53031 Mdot
.51 .53055 Mdot
.51 .53066 Mdot
.51 .53067 Mdot
.51 .53075 Mdot
.51 .53085 Mdot
.51 .53093 Mdot
.51 .53094 Mdot
.51 .531 Mdot
.51 .53103 Mdot
.51 .53105 Mdot
.51 .53112 Mdot
.51 .53121 Mdot
.51 .53131 Mdot
.51 .53145 Mdot
.51 .5317 Mdot
.51 .53172 Mdot
.51 .53182 Mdot
.51 .532 Mdot
.51 .53211 Mdot
.51 .53214 Mdot
.51 .53237 Mdot
.51 .53238 Mdot
.51 .53249 Mdot
.51 .53259 Mdot
.51 .53316 Mdot
.51 .53319 Mdot
.51 .53334 Mdot
.51 .5335 Mdot
.51 .53363 Mdot
.51 .53378 Mdot
.51 .53382 Mdot
.51 .53382 Mdot
.51 .53387 Mdot
.51 .53393 Mdot
.51 .53393 Mdot
.51 .53397 Mdot
.51 .53402 Mdot
.51 .53413 Mdot
.51 .53431 Mdot
.51 .53437 Mdot
.51 .53446 Mdot
.51 .53465 Mdot
.51 .53469 Mdot
.51 .5347 Mdot
.51 .5347 Mdot
.51 .53484 Mdot
.51 .535 Mdot
.51 .53508 Mdot
.51 .53509 Mdot
.51 .5351 Mdot
.51 .53517 Mdot
.51 .53522 Mdot
.51 .53539 Mdot
.51 .53557 Mdot
.51 .53596 Mdot
.51 .53597 Mdot
.51 .53604 Mdot
.51 .5362 Mdot
.51 .53623 Mdot
.51 .53631 Mdot
.51 .53638 Mdot
.51 .53652 Mdot
.51 .53655 Mdot
.51 .53662 Mdot
.51 .53677 Mdot
.51 .53714 Mdot
.51 .53717 Mdot
.51 .53718 Mdot
.51 .53744 Mdot
.51 .53746 Mdot
.51 .53767 Mdot
.51 .53769 Mdot
.51 .53769 Mdot
.51 .53786 Mdot
.51 .53789 Mdot
.51 .5379 Mdot
.51 .53791 Mdot
.51 .53791 Mdot
.51 .53798 Mdot
.51 .53809 Mdot
.51 .53812 Mdot
.51 .53816 Mdot
.51 .5382 Mdot
.51 .53827 Mdot
.51 .5383 Mdot
.51 .53835 Mdot
.51 .53838 Mdot
.51 .53838 Mdot
.51 .53845 Mdot
.51 .53847 Mdot
.51 .53847 Mdot
.51 .53848 Mdot
.51 .53849 Mdot
.51 .53855 Mdot
.51 .53876 Mdot
.51 .53889 Mdot
.51 .539 Mdot
.51 .53914 Mdot
.51 .53918 Mdot
.51 .53932 Mdot
.51 .53943 Mdot
.51 .53986 Mdot
.51 .53991 Mdot
.51 .54011 Mdot
.51 .54013 Mdot
.51 .54042 Mdot
.51 .5405 Mdot
.51 .5406 Mdot
.51 .54073 Mdot
.51 .5408 Mdot
.51 .54091 Mdot
.51 .54116 Mdot
.51 .54125 Mdot
.51 .54126 Mdot
.51 .54134 Mdot
.51 .54147 Mdot
.51 .54166 Mdot
.51 .542 Mdot
.51 .54204 Mdot
.51 .54246 Mdot
.51 .54256 Mdot
.51 .54266 Mdot
.51 .54271 Mdot
.51 .54294 Mdot
.51 .54319 Mdot
.51 .54334 Mdot
.51 .54338 Mdot
.51 .54352 Mdot
.51 .54359 Mdot
.51 .54364 Mdot
.51 .54364 Mdot
.51 .54372 Mdot
.51 .54374 Mdot
.51 .54379 Mdot
.51 .5438 Mdot
.51 .54381 Mdot
.51 .54385 Mdot
.51 .54391 Mdot
.51 .544 Mdot
.51 .54405 Mdot
.51 .54415 Mdot
.51 .54427 Mdot
.51 .54433 Mdot
.51 .54433 Mdot
.51 .54443 Mdot
.51 .54458 Mdot
.51 .54463 Mdot
.51 .54464 Mdot
.51 .54465 Mdot
.51 .54466 Mdot
.51 .54467 Mdot
.51 .54467 Mdot
.51 .54468 Mdot
.51 .54468 Mdot
.51 .54469 Mdot
.51 .54476 Mdot
.51 .54476 Mdot
.51 .54479 Mdot
.51 .54481 Mdot
.51 .54484 Mdot
.51 .54486 Mdot
.51 .54493 Mdot
.51 .54495 Mdot
.51 .54497 Mdot
.51 .54501 Mdot
.51 .54501 Mdot
.51 .54502 Mdot
.51 .54502 Mdot
.51 .54503 Mdot
.51 .54508 Mdot
.51 .54511 Mdot
.51 .54512 Mdot
.51 .54517 Mdot
.51 .54517 Mdot
.51 .54518 Mdot
.51 .54519 Mdot
.51 .54521 Mdot
.51 .54523 Mdot
.51 .54532 Mdot
.51 .54532 Mdot
.51 .54533 Mdot
.51 .54534 Mdot
.51 .54544 Mdot
.51 .54545 Mdot
.51 .54552 Mdot
.51 .54552 Mdot
.51 .54554 Mdot
.51 .54555 Mdot
.51 .54555 Mdot
.51 .54556 Mdot
.51 .54559 Mdot
.51 .54559 Mdot
.51 .54561 Mdot
.51 .54562 Mdot
.51 .54563 Mdot
.51 .54563 Mdot
.51 .54563 Mdot
.51 .54564 Mdot
.512 .20184 Mdot
.512 .20184 Mdot
.512 .20185 Mdot
.512 .20186 Mdot
.512 .20196 Mdot
.512 .20203 Mdot
.512 .20208 Mdot
.512 .2021 Mdot
.512 .20212 Mdot
.512 .20212 Mdot
.512 .20216 Mdot
.512 .20218 Mdot
.512 .20229 Mdot
.512 .20245 Mdot
.512 .20248 Mdot
.512 .20254 Mdot
.512 .20255 Mdot
.512 .20263 Mdot
.512 .20284 Mdot
.512 .20286 Mdot
.512 .20312 Mdot
.512 .20322 Mdot
.512 .20326 Mdot
.512 .20332 Mdot
.512 .20332 Mdot
.512 .20361 Mdot
.512 .20367 Mdot
.512 .20376 Mdot
.512 .20376 Mdot
.512 .20384 Mdot
.512 .20391 Mdot
.512 .2041 Mdot
.512 .20439 Mdot
.512 .20441 Mdot
.512 .20449 Mdot
.512 .20466 Mdot
.512 .20481 Mdot
.512 .20492 Mdot
.512 .20498 Mdot
.512 .20504 Mdot
.512 .2051 Mdot
.512 .20516 Mdot
.512 .20557 Mdot
.512 .20565 Mdot
.512 .20584 Mdot
.512 .20588 Mdot
.512 .20601 Mdot
.512 .20606 Mdot
.512 .20614 Mdot
.512 .20636 Mdot
.512 .20641 Mdot
.512 .20643 Mdot
.512 .20643 Mdot
.512 .20653 Mdot
.512 .20671 Mdot
.512 .20673 Mdot
.512 .207 Mdot
.512 .20728 Mdot
.512 .20731 Mdot
.512 .20755 Mdot
.512 .20797 Mdot
.512 .20814 Mdot
.512 .209 Mdot
.512 .20913 Mdot
.512 .20916 Mdot
.512 .20926 Mdot
.512 .20928 Mdot
.512 .20964 Mdot
.512 .21075 Mdot
.512 .21107 Mdot
.512 .21111 Mdot
.512 .21127 Mdot
.512 .2115 Mdot
.512 .21166 Mdot
.512 .21183 Mdot
.512 .21208 Mdot
.512 .21251 Mdot
.512 .21269 Mdot
.512 .21303 Mdot
.512 .21332 Mdot
.512 .21332 Mdot
.512 .21384 Mdot
.512 .21421 Mdot
.512 .21437 Mdot
.512 .21546 Mdot
.512 .21552 Mdot
.512 .2159 Mdot
.512 .21604 Mdot
.512 .21625 Mdot
.512 .21672 Mdot
.512 .21719 Mdot
.512 .21725 Mdot
.512 .21741 Mdot
.512 .21764 Mdot
.512 .2182 Mdot
.512 .2184 Mdot
.512 .21866 Mdot
.512 .21868 Mdot
.512 .21884 Mdot
.512 .21941 Mdot
.512 .21961 Mdot
.512 .21962 Mdot
.512 .21968 Mdot
.512 .21976 Mdot
.512 .22026 Mdot
.512 .22036 Mdot
.512 .22079 Mdot
.512 .22098 Mdot
.512 .22115 Mdot
.512 .22117 Mdot
.512 .22129 Mdot
.512 .22136 Mdot
.512 .22138 Mdot
.512 .22142 Mdot
.512 .22163 Mdot
.512 .22176 Mdot
.512 .222 Mdot
.512 .22238 Mdot
.512 .22248 Mdot
.512 .22253 Mdot
.512 .22263 Mdot
.512 .22357 Mdot
.512 .22365 Mdot
.512 .22375 Mdot
.512 .22382 Mdot
.512 .22417 Mdot
.512 .22424 Mdot
.512 .2248 Mdot
.512 .22517 Mdot
.512 .22532 Mdot
.512 .22533 Mdot
.512 .22627 Mdot
.512 .22628 Mdot
.512 .22639 Mdot
.512 .22743 Mdot
.512 .22793 Mdot
.512 .22806 Mdot
.512 .22825 Mdot
.512 .22901 Mdot
.512 .22928 Mdot
.512 .22954 Mdot
.512 .22969 Mdot
.512 .22975 Mdot
.512 .23005 Mdot
.512 .23039 Mdot
.512 .23044 Mdot
.512 .23109 Mdot
.512 .23151 Mdot
.512 .23165 Mdot
.512 .23179 Mdot
.512 .23188 Mdot
.512 .23233 Mdot
.512 .2325 Mdot
.512 .23271 Mdot
.512 .23302 Mdot
.512 .23303 Mdot
.512 .23312 Mdot
.512 .23329 Mdot
.512 .23365 Mdot
.512 .23376 Mdot
.512 .23418 Mdot
.512 .23434 Mdot
.512 .23448 Mdot
.512 .23458 Mdot
.512 .23481 Mdot
.512 .23547 Mdot
.512 .23564 Mdot
.512 .23669 Mdot
.512 .23795 Mdot
.512 .23808 Mdot
.512 .23862 Mdot
.512 .23872 Mdot
.512 .2389 Mdot
.512 .23905 Mdot
.512 .24011 Mdot
.512 .24032 Mdot
.512 .24039 Mdot
.512 .24048 Mdot
.512 .24092 Mdot
.512 .24102 Mdot
.512 .24137 Mdot
.512 .24146 Mdot
.512 .24158 Mdot
.512 .2419 Mdot
.512 .24226 Mdot
.512 .24257 Mdot
.512 .24265 Mdot
.512 .24273 Mdot
.512 .24314 Mdot
.512 .24324 Mdot
.512 .24372 Mdot
.512 .24425 Mdot
.512 .24529 Mdot
.512 .24607 Mdot
.512 .24619 Mdot
.512 .2466 Mdot
.512 .2467 Mdot
.512 .24702 Mdot
.512 .24739 Mdot
.512 .24759 Mdot
.512 .24767 Mdot
.512 .24775 Mdot
.512 .24798 Mdot
.512 .24839 Mdot
.512 .24904 Mdot
.512 .24918 Mdot
.512 .2496 Mdot
.512 .24997 Mdot
.512 .25012 Mdot
.512 .25033 Mdot
.512 .25036 Mdot
.512 .25052 Mdot
.512 .25149 Mdot
.512 .25162 Mdot
.512 .25165 Mdot
.512 .25175 Mdot
.512 .25187 Mdot
.512 .25193 Mdot
.512 .25198 Mdot
.512 .25256 Mdot
.512 .25272 Mdot
.512 .25279 Mdot
.512 .25318 Mdot
.512 .25319 Mdot
.512 .25329 Mdot
.512 .25354 Mdot
.512 .25447 Mdot
.512 .25461 Mdot
.512 .25493 Mdot
.512 .25496 Mdot
.512 .25512 Mdot
.512 .25513 Mdot
.512 .2552 Mdot
.512 .25585 Mdot
.512 .25586 Mdot
.512 .25598 Mdot
.512 .25607 Mdot
.512 .25628 Mdot
.512 .25698 Mdot
.512 .25735 Mdot
.512 .2574 Mdot
.512 .25744 Mdot
.512 .25756 Mdot
.512 .25778 Mdot
.512 .25797 Mdot
.512 .25803 Mdot
.512 .25826 Mdot
.512 .25943 Mdot
.512 .25975 Mdot
.512 .26004 Mdot
.512 .2601 Mdot
.512 .26036 Mdot
.512 .26041 Mdot
.512 .26046 Mdot
.512 .26064 Mdot
.512 .26087 Mdot
.512 .26114 Mdot
.512 .2612 Mdot
.512 .26186 Mdot
.512 .26199 Mdot
.512 .26267 Mdot
.512 .26287 Mdot
.512 .26294 Mdot
.512 .26329 Mdot
.512 .26337 Mdot
.512 .2642 Mdot
.512 .2649 Mdot
.512 .26501 Mdot
.512 .26545 Mdot
.512 .26561 Mdot
.512 .26578 Mdot
.512 .26588 Mdot
.512 .26618 Mdot
.512 .26625 Mdot
.512 .26668 Mdot
.512 .26669 Mdot
.512 .2669 Mdot
.512 .26717 Mdot
.512 .26748 Mdot
.512 .26755 Mdot
.512 .26775 Mdot
.512 .26855 Mdot
.512 .2688 Mdot
.512 .26902 Mdot
.512 .26906 Mdot
.512 .26936 Mdot
.512 .26956 Mdot
.512 .27013 Mdot
.512 .27037 Mdot
.512 .27155 Mdot
.512 .27165 Mdot
.512 .27251 Mdot
.512 .2728 Mdot
.512 .27326 Mdot
.512 .27331 Mdot
.512 .2736 Mdot
.512 .27365 Mdot
.512 .27381 Mdot
.512 .27459 Mdot
.512 .27467 Mdot
.512 .2748 Mdot
.512 .27532 Mdot
.512 .27544 Mdot
.512 .27562 Mdot
.512 .27566 Mdot
.512 .27567 Mdot
.512 .27573 Mdot
.512 .27584 Mdot
.512 .27585 Mdot
.512 .27601 Mdot
.512 .27617 Mdot
.512 .27655 Mdot
.512 .27664 Mdot
.512 .27708 Mdot
.512 .27716 Mdot
.512 .27722 Mdot
.512 .27723 Mdot
.512 .2774 Mdot
.512 .27807 Mdot
.512 .27834 Mdot
.512 .27853 Mdot
.512 .27928 Mdot
.512 .2795 Mdot
.512 .28043 Mdot
.512 .28063 Mdot
.512 .28078 Mdot
.512 .28123 Mdot
.512 .28353 Mdot
.512 .28385 Mdot
.512 .28424 Mdot
.512 .28445 Mdot
.512 .28564 Mdot
.512 .28592 Mdot
.512 .28873 Mdot
.512 .29108 Mdot
.512 .29145 Mdot
.512 .29294 Mdot
.512 .29346 Mdot
.512 .29369 Mdot
.512 .29401 Mdot
.512 .29437 Mdot
.512 .29534 Mdot
.512 .2956 Mdot
.512 .29642 Mdot
.512 .29681 Mdot
.512 .297 Mdot
.512 .29704 Mdot
.512 .29775 Mdot
.512 .29822 Mdot
.512 .29863 Mdot
.512 .29988 Mdot
.512 .3002 Mdot
.512 .30054 Mdot
.512 .30152 Mdot
.512 .30303 Mdot
.512 .30317 Mdot
.512 .30396 Mdot
.512 .30466 Mdot
.512 .3048 Mdot
.512 .30516 Mdot
.512 .30577 Mdot
.512 .30642 Mdot
.512 .30823 Mdot
.512 .30868 Mdot
.512 .30901 Mdot
.512 .31021 Mdot
.512 .31272 Mdot
.512 .31297 Mdot
.512 .31301 Mdot
.512 .31528 Mdot
.512 .31533 Mdot
.512 .31568 Mdot
.512 .31658 Mdot
.512 .31795 Mdot
.512 .31813 Mdot
.512 .31899 Mdot
.512 .31916 Mdot
.512 .31941 Mdot
.512 .31962 Mdot
.512 .32195 Mdot
.512 .32218 Mdot
.512 .3223 Mdot
.512 .32256 Mdot
.512 .3235 Mdot
.512 .3241 Mdot
.512 .32444 Mdot
.512 .32497 Mdot
.512 .32506 Mdot
.512 .3251 Mdot
.512 .32527 Mdot
.512 .32558 Mdot
.512 .32562 Mdot
.512 .32606 Mdot
.512 .32653 Mdot
.512 .32761 Mdot
.512 .32787 Mdot
.512 .32912 Mdot
.512 .32934 Mdot
.512 .32948 Mdot
.512 .32952 Mdot
.512 .33001 Mdot
.512 .33146 Mdot
.512 .33185 Mdot
.512 .33191 Mdot
.512 .33258 Mdot
.512 .33279 Mdot
.512 .33309 Mdot
.512 .33451 Mdot
.512 .33509 Mdot
.512 .33549 Mdot
.512 .33566 Mdot
.512 .33687 Mdot
.512 .33807 Mdot
.512 .3386 Mdot
.512 .33897 Mdot
.512 .33994 Mdot
.512 .3401 Mdot
.512 .34291 Mdot
.512 .34332 Mdot
.512 .34429 Mdot
.512 .34564 Mdot
.512 .34565 Mdot
.512 .3464 Mdot
.512 .34728 Mdot
.512 .34776 Mdot
.512 .34886 Mdot
.512 .34952 Mdot
.512 .34998 Mdot
.512 .35039 Mdot
.512 .35099 Mdot
.512 .35141 Mdot
.512 .35153 Mdot
.512 .35235 Mdot
.512 .35527 Mdot
.512 .35622 Mdot
.512 .35628 Mdot
.512 .35655 Mdot
.512 .35662 Mdot
.512 .35697 Mdot
.512 .35923 Mdot
.512 .3597 Mdot
.512 .36081 Mdot
.512 .36143 Mdot
.512 .36151 Mdot
.512 .36228 Mdot
.512 .36297 Mdot
.512 .36304 Mdot
.512 .36352 Mdot
.512 .36377 Mdot
.512 .36378 Mdot
.512 .36384 Mdot
.512 .36398 Mdot
.512 .36456 Mdot
.512 .36475 Mdot
.512 .36489 Mdot
.512 .36525 Mdot
.512 .36536 Mdot
.512 .36585 Mdot
.512 .36608 Mdot
.512 .36716 Mdot
.512 .36733 Mdot
.512 .36748 Mdot
.512 .36765 Mdot
.512 .3678 Mdot
.512 .36809 Mdot
.512 .3685 Mdot
.512 .36896 Mdot
.512 .36917 Mdot
.512 .36922 Mdot
.512 .37 Mdot
.512 .3705 Mdot
.512 .37068 Mdot
.512 .3709 Mdot
.512 .3709 Mdot
.512 .37115 Mdot
.512 .3713 Mdot
.512 .37207 Mdot
.512 .37209 Mdot
.512 .37224 Mdot
.512 .37234 Mdot
.512 .37262 Mdot
.512 .37332 Mdot
.512 .37336 Mdot
.512 .37393 Mdot
.512 .37415 Mdot
.512 .37417 Mdot
.512 .37434 Mdot
.512 .37441 Mdot
.512 .37483 Mdot
.512 .37514 Mdot
.512 .3752 Mdot
.512 .37528 Mdot
.512 .3753 Mdot
.512 .37533 Mdot
.512 .37539 Mdot
.512 .37554 Mdot
.512 .37572 Mdot
.512 .37598 Mdot
.512 .37602 Mdot
.512 .37604 Mdot
.512 .37605 Mdot
.512 .47543 Mdot
.512 .47543 Mdot
.512 .47544 Mdot
.512 .47546 Mdot
.512 .47559 Mdot
.512 .47567 Mdot
.512 .47575 Mdot
.512 .47578 Mdot
.512 .47579 Mdot
.512 .4758 Mdot
.512 .47584 Mdot
.512 .47587 Mdot
.512 .47602 Mdot
.512 .47623 Mdot
.512 .47626 Mdot
.512 .47634 Mdot
.512 .47636 Mdot
.512 .47646 Mdot
.512 .47674 Mdot
.512 .47676 Mdot
.512 .4771 Mdot
.512 .47724 Mdot
.512 .47728 Mdot
.512 .47736 Mdot
.512 .47737 Mdot
.512 .47774 Mdot
.512 .47781 Mdot
.512 .47793 Mdot
.512 .47793 Mdot
.512 .47803 Mdot
.512 .47812 Mdot
.512 .47836 Mdot
.512 .47874 Mdot
.512 .47876 Mdot
.512 .47886 Mdot
.512 .47908 Mdot
.512 .47928 Mdot
.512 .47942 Mdot
.512 .47949 Mdot
.512 .47957 Mdot
.512 .47965 Mdot
.512 .47973 Mdot
.512 .48024 Mdot
.512 .48035 Mdot
.512 .48058 Mdot
.512 .48064 Mdot
.512 .48081 Mdot
.512 .48087 Mdot
.512 .48096 Mdot
.512 .48124 Mdot
.512 .48131 Mdot
.512 .48133 Mdot
.512 .48134 Mdot
.512 .48146 Mdot
.512 .48168 Mdot
.512 .48171 Mdot
.512 .48204 Mdot
.512 .4824 Mdot
.512 .48244 Mdot
.512 .48273 Mdot
.512 .48326 Mdot
.512 .48347 Mdot
.512 .48453 Mdot
.512 .48469 Mdot
.512 .48472 Mdot
.512 .48485 Mdot
.512 .48487 Mdot
.512 .48531 Mdot
.512 .48666 Mdot
.512 .48703 Mdot
.512 .48709 Mdot
.512 .48728 Mdot
.512 .48756 Mdot
.512 .48774 Mdot
.512 .48795 Mdot
.512 .48825 Mdot
.512 .48875 Mdot
.512 .48897 Mdot
.512 .48937 Mdot
.512 .48971 Mdot
.512 .48971 Mdot
.512 .49032 Mdot
.512 .49076 Mdot
.512 .49094 Mdot
.512 .49219 Mdot
.512 .49227 Mdot
.512 .4927 Mdot
.512 .49286 Mdot
.512 .49309 Mdot
.512 .49363 Mdot
.512 .49416 Mdot
.512 .49423 Mdot
.512 .49441 Mdot
.512 .49467 Mdot
.512 .49529 Mdot
.512 .49551 Mdot
.512 .49581 Mdot
.512 .49583 Mdot
.512 .496 Mdot
.512 .49663 Mdot
.512 .49685 Mdot
.512 .49686 Mdot
.512 .49692 Mdot
.512 .49702 Mdot
.512 .49756 Mdot
.512 .49767 Mdot
.512 .49814 Mdot
.512 .49834 Mdot
.512 .49853 Mdot
.512 .49855 Mdot
.512 .49868 Mdot
.512 .49875 Mdot
.512 .49877 Mdot
.512 .49881 Mdot
.512 .49904 Mdot
.512 .49918 Mdot
.512 .49944 Mdot
.512 .49984 Mdot
.512 .49995 Mdot
.512 .5 Mdot
.512 .5001 Mdot
.512 .50109 Mdot
.512 .50118 Mdot
.512 .50129 Mdot
.512 .50136 Mdot
.512 .50173 Mdot
.512 .5018 Mdot
.512 .50238 Mdot
.512 .50276 Mdot
.512 .50291 Mdot
.512 .50293 Mdot
.512 .50388 Mdot
.512 .5039 Mdot
.512 .504 Mdot
.512 .50505 Mdot
.512 .50555 Mdot
.512 .50568 Mdot
.512 .50587 Mdot
.512 .50662 Mdot
.512 .50688 Mdot
.512 .50714 Mdot
.512 .50729 Mdot
.512 .50734 Mdot
.512 .50763 Mdot
.512 .50796 Mdot
.512 .50801 Mdot
.512 .50863 Mdot
.512 .50903 Mdot
.512 .50917 Mdot
.512 .5093 Mdot
.512 .50981 Mdot
.512 .50997 Mdot
.512 .51016 Mdot
.512 .51045 Mdot
.512 .51047 Mdot
.512 .51054 Mdot
.512 .5107 Mdot
.512 .51103 Mdot
.512 .51114 Mdot
.512 .51153 Mdot
.512 .51167 Mdot
.512 .5118 Mdot
.512 .5119 Mdot
.512 .51211 Mdot
.512 .5127 Mdot
.512 .51285 Mdot
.512 .51379 Mdot
.512 .5149 Mdot
.512 .51501 Mdot
.512 .51548 Mdot
.512 .51557 Mdot
.512 .51572 Mdot
.512 .51585 Mdot
.512 .51675 Mdot
.512 .51693 Mdot
.512 .51699 Mdot
.512 .51707 Mdot
.512 .51743 Mdot
.512 .51752 Mdot
.512 .51781 Mdot
.512 .51788 Mdot
.512 .51799 Mdot
.512 .51825 Mdot
.512 .51832 Mdot
.512 .51832 Mdot
.512 .51834 Mdot
.512 .51837 Mdot
.512 .51855 Mdot
.512 .51858 Mdot
.512 .51873 Mdot
.512 .51879 Mdot
.512 .51885 Mdot
.512 .51886 Mdot
.512 .5189 Mdot
.512 .51892 Mdot
.512 .51893 Mdot
.512 .51894 Mdot
.512 .51901 Mdot
.512 .51906 Mdot
.512 .51926 Mdot
.512 .51931 Mdot
.512 .51934 Mdot
.512 .51964 Mdot
.512 .5197 Mdot
.512 .51973 Mdot
.512 .51984 Mdot
.512 .51986 Mdot
.512 .52003 Mdot
.512 .52015 Mdot
.512 .52048 Mdot
.512 .52052 Mdot
.512 .52097 Mdot
.512 .52107 Mdot
.512 .52128 Mdot
.512 .52136 Mdot
.512 .52148 Mdot
.512 .52149 Mdot
.512 .52157 Mdot
.512 .52167 Mdot
.512 .52198 Mdot
.512 .52205 Mdot
.512 .52208 Mdot
.512 .5222 Mdot
.512 .5223 Mdot
.512 .52238 Mdot
.512 .52239 Mdot
.512 .52255 Mdot
.512 .52258 Mdot
.512 .52269 Mdot
.512 .52273 Mdot
.512 .52279 Mdot
.512 .52285 Mdot
.512 .52302 Mdot
.512 .52307 Mdot
.512 .52333 Mdot
.512 .52365 Mdot
.512 .52368 Mdot
.512 .52381 Mdot
.512 .52384 Mdot
.512 .52392 Mdot
.512 .52417 Mdot
.512 .52422 Mdot
.512 .52447 Mdot
.512 .52449 Mdot
.512 .5246 Mdot
.512 .52468 Mdot
.512 .52475 Mdot
.512 .52477 Mdot
.512 .52479 Mdot
.512 .52489 Mdot
.512 .52491 Mdot
.512 .52502 Mdot
.512 .52514 Mdot
.512 .52558 Mdot
.512 .52567 Mdot
.512 .52569 Mdot
.512 .52576 Mdot
.512 .52584 Mdot
.512 .52589 Mdot
.512 .52591 Mdot
.512 .52592 Mdot
.512 .52606 Mdot
.512 .52632 Mdot
.512 .5264 Mdot
.512 .52644 Mdot
.512 .52648 Mdot
.512 .52649 Mdot
.512 .52673 Mdot
.512 .52675 Mdot
.512 .52676 Mdot
.512 .52682 Mdot
.512 .52683 Mdot
.512 .52695 Mdot
.512 .527 Mdot
.512 .52735 Mdot
.512 .52744 Mdot
.512 .52748 Mdot
.512 .52748 Mdot
.512 .52763 Mdot
.512 .52766 Mdot
.512 .52772 Mdot
.512 .52793 Mdot
.512 .52795 Mdot
.512 .52797 Mdot
.512 .52802 Mdot
.512 .52805 Mdot
.512 .52807 Mdot
.512 .52811 Mdot
.512 .52848 Mdot
.512 .52854 Mdot
.512 .52854 Mdot
.512 .52862 Mdot
.512 .52868 Mdot
.512 .52882 Mdot
.512 .52897 Mdot
.512 .52902 Mdot
.512 .52926 Mdot
.512 .52942 Mdot
.512 .5295 Mdot
.512 .52953 Mdot
.512 .52956 Mdot
.512 .52964 Mdot
.512 .52977 Mdot
.512 .52989 Mdot
.512 .52993 Mdot
.512 .53008 Mdot
.512 .53012 Mdot
.512 .53041 Mdot
.512 .53079 Mdot
.512 .53099 Mdot
.512 .53116 Mdot
.512 .5312 Mdot
.512 .53135 Mdot
.512 .53138 Mdot
.512 .53141 Mdot
.512 .53152 Mdot
.512 .53165 Mdot
.512 .53177 Mdot
.512 .53182 Mdot
.512 .53185 Mdot
.512 .53198 Mdot
.512 .53201 Mdot
.512 .53217 Mdot
.512 .53221 Mdot
.512 .53223 Mdot
.512 .53231 Mdot
.512 .5327 Mdot
.512 .53275 Mdot
.512 .53282 Mdot
.512 .53285 Mdot
.512 .53305 Mdot
.512 .5331 Mdot
.512 .53356 Mdot
.512 .53394 Mdot
.512 .534 Mdot
.512 .53423 Mdot
.512 .53432 Mdot
.512 .53435 Mdot
.512 .53441 Mdot
.512 .53446 Mdot
.512 .53462 Mdot
.512 .53466 Mdot
.512 .53479 Mdot
.512 .53485 Mdot
.512 .53488 Mdot
.512 .53488 Mdot
.512 .53499 Mdot
.512 .53507 Mdot
.512 .53513 Mdot
.512 .53529 Mdot
.512 .53533 Mdot
.512 .53538 Mdot
.512 .53543 Mdot
.512 .53558 Mdot
.512 .53581 Mdot
.512 .53583 Mdot
.512 .53595 Mdot
.512 .53606 Mdot
.512 .53608 Mdot
.512 .53613 Mdot
.512 .53623 Mdot
.512 .53633 Mdot
.512 .5366 Mdot
.512 .53666 Mdot
.512 .53671 Mdot
.512 .53689 Mdot
.512 .53726 Mdot
.512 .5373 Mdot
.512 .53731 Mdot
.512 .53764 Mdot
.512 .53765 Mdot
.512 .5377 Mdot
.512 .53783 Mdot
.512 .53803 Mdot
.512 .53805 Mdot
.512 .53818 Mdot
.512 .5382 Mdot
.512 .53824 Mdot
.512 .53827 Mdot
.512 .5386 Mdot
.512 .53864 Mdot
.512 .53865 Mdot
.512 .53869 Mdot
.512 .53883 Mdot
.512 .53891 Mdot
.512 .53896 Mdot
.512 .53903 Mdot
.512 .53905 Mdot
.512 .53905 Mdot
.512 .53908 Mdot
.512 .53912 Mdot
.512 .53913 Mdot
.512 .53919 Mdot
.512 .53926 Mdot
.512 .53941 Mdot
.512 .53944 Mdot
.512 .53962 Mdot
.512 .53965 Mdot
.512 .53967 Mdot
.512 .53967 Mdot
.512 .53974 Mdot
.512 .53995 Mdot
.512 .54 Mdot
.512 .54001 Mdot
.512 .5401 Mdot
.512 .54017 Mdot
.512 .54037 Mdot
.512 .54045 Mdot
.512 .5405 Mdot
.512 .54053 Mdot
.512 .54069 Mdot
.512 .54086 Mdot
.512 .54093 Mdot
.512 .54098 Mdot
.512 .54111 Mdot
.512 .54114 Mdot
.512 .54152 Mdot
.512 .54157 Mdot
.512 .5417 Mdot
.512 .54188 Mdot
.512 .54189 Mdot
.512 .54199 Mdot
.512 .54211 Mdot
.512 .54217 Mdot
.512 .54232 Mdot
.512 .54241 Mdot
.512 .54247 Mdot
.512 .54252 Mdot
.512 .5426 Mdot
.512 .54266 Mdot
.512 .54267 Mdot
.512 .54278 Mdot
.512 .54317 Mdot
.512 .54329 Mdot
.512 .5433 Mdot
.512 .54334 Mdot
.512 .54335 Mdot
.512 .54339 Mdot
.512 .54369 Mdot
.512 .54375 Mdot
.512 .5439 Mdot
.512 .54398 Mdot
.512 .54399 Mdot
.512 .54409 Mdot
.512 .54418 Mdot
.512 .54419 Mdot
.512 .54425 Mdot
.512 .54429 Mdot
.512 .54429 Mdot
.512 .54429 Mdot
.512 .54431 Mdot
.512 .54439 Mdot
.512 .54441 Mdot
.512 .54443 Mdot
.512 .54448 Mdot
.512 .54449 Mdot
.512 .54456 Mdot
.512 .54458 Mdot
.512 .54473 Mdot
.512 .54475 Mdot
.512 .54477 Mdot
.512 .54479 Mdot
.512 .54481 Mdot
.512 .54485 Mdot
.512 .5449 Mdot
.512 .54496 Mdot
.512 .54499 Mdot
.512 .54499 Mdot
.512 .54509 Mdot
.512 .54516 Mdot
.512 .54518 Mdot
.512 .54521 Mdot
.512 .54521 Mdot
.512 .54524 Mdot
.512 .54526 Mdot
.512 .54536 Mdot
.512 .54536 Mdot
.512 .54538 Mdot
.512 .54539 Mdot
.512 .54543 Mdot
.512 .54552 Mdot
.512 .54553 Mdot
.512 .5456 Mdot
.512 .54563 Mdot
.512 .54563 Mdot
.512 .54565 Mdot
.512 .54566 Mdot
.512 .54571 Mdot
.512 .54576 Mdot
.512 .54576 Mdot
.512 .54577 Mdot
.512 .54578 Mdot
.512 .54578 Mdot
.512 .54579 Mdot
.512 .54581 Mdot
.512 .54583 Mdot
.512 .54586 Mdot
.512 .54587 Mdot
.512 .54587 Mdot
.512 .54587 Mdot
.514 .20124 Mdot
.514 .20124 Mdot
.514 .20139 Mdot
.514 .2015 Mdot
.514 .20151 Mdot
.514 .20152 Mdot
.514 .20156 Mdot
.514 .2016 Mdot
.514 .20166 Mdot
.514 .20173 Mdot
.514 .20187 Mdot
.514 .20187 Mdot
.514 .20188 Mdot
.514 .20189 Mdot
.514 .20193 Mdot
.514 .20201 Mdot
.514 .20206 Mdot
.514 .20211 Mdot
.514 .20231 Mdot
.514 .20231 Mdot
.514 .20233 Mdot
.514 .20238 Mdot
.514 .20249 Mdot
.514 .20254 Mdot
.514 .2026 Mdot
.514 .2026 Mdot
.514 .20266 Mdot
.514 .20272 Mdot
.514 .20291 Mdot
.514 .20316 Mdot
.514 .20324 Mdot
.514 .20328 Mdot
.514 .20333 Mdot
.514 .20338 Mdot
.514 .20345 Mdot
.514 .20357 Mdot
.514 .20365 Mdot
.514 .20383 Mdot
.514 .20385 Mdot
.514 .20402 Mdot
.514 .20442 Mdot
.514 .20448 Mdot
.514 .20458 Mdot
.514 .20482 Mdot
.514 .20491 Mdot
.514 .20522 Mdot
.514 .20529 Mdot
.514 .20568 Mdot
.514 .20575 Mdot
.514 .20589 Mdot
.514 .20608 Mdot
.514 .20616 Mdot
.514 .20634 Mdot
.514 .20655 Mdot
.514 .20657 Mdot
.514 .20663 Mdot
.514 .2069 Mdot
.514 .20699 Mdot
.514 .20706 Mdot
.514 .2071 Mdot
.514 .20714 Mdot
.514 .20763 Mdot
.514 .20779 Mdot
.514 .20807 Mdot
.514 .20864 Mdot
.514 .20875 Mdot
.514 .20929 Mdot
.514 .20959 Mdot
.514 .20988 Mdot
.514 .21014 Mdot
.514 .21025 Mdot
.514 .21032 Mdot
.514 .21041 Mdot
.514 .21059 Mdot
.514 .21075 Mdot
.514 .21077 Mdot
.514 .21132 Mdot
.514 .21138 Mdot
.514 .21141 Mdot
.514 .21154 Mdot
.514 .21158 Mdot
.514 .21305 Mdot
.514 .21334 Mdot
.514 .21359 Mdot
.514 .21372 Mdot
.514 .2138 Mdot
.514 .21409 Mdot
.514 .21443 Mdot
.514 .21449 Mdot
.514 .21522 Mdot
.514 .21528 Mdot
.514 .2157 Mdot
.514 .21582 Mdot
.514 .21629 Mdot
.514 .21645 Mdot
.514 .21648 Mdot
.514 .21679 Mdot
.514 .21693 Mdot
.514 .21725 Mdot
.514 .21737 Mdot
.514 .21804 Mdot
.514 .2181 Mdot
.514 .21812 Mdot
.514 .21841 Mdot
.514 .21842 Mdot
.514 .21849 Mdot
.514 .21858 Mdot
.514 .21863 Mdot
.514 .21866 Mdot
.514 .21872 Mdot
.514 .21885 Mdot
.514 .21899 Mdot
.514 .21944 Mdot
.514 .21949 Mdot
.514 .21981 Mdot
.514 .22037 Mdot
.514 .22039 Mdot
.514 .22042 Mdot
.514 .22051 Mdot
.514 .22069 Mdot
.514 .22074 Mdot
.514 .22087 Mdot
.514 .22099 Mdot
.514 .22128 Mdot
.514 .22161 Mdot
.514 .2219 Mdot
.514 .22197 Mdot
.514 .22281 Mdot
.514 .22283 Mdot
.514 .223 Mdot
.514 .22308 Mdot
.514 .22327 Mdot
.514 .22333 Mdot
.514 .22342 Mdot
.514 .2235 Mdot
.514 .22379 Mdot
.514 .22431 Mdot
.514 .22456 Mdot
.514 .22487 Mdot
.514 .22526 Mdot
.514 .2253 Mdot
.514 .2253 Mdot
.514 .22576 Mdot
.514 .22613 Mdot
.514 .22613 Mdot
.514 .22751 Mdot
.514 .22791 Mdot
.514 .22899 Mdot
.514 .22937 Mdot
.514 .22955 Mdot
.514 .22966 Mdot
.514 .22995 Mdot
.514 .23028 Mdot
.514 .23037 Mdot
.514 .23053 Mdot
.514 .23062 Mdot
.514 .23102 Mdot
.514 .23105 Mdot
.514 .23113 Mdot
.514 .23136 Mdot
.514 .23144 Mdot
.514 .23144 Mdot
.514 .23153 Mdot
.514 .2316 Mdot
.514 .23229 Mdot
.514 .23247 Mdot
.514 .23306 Mdot
.514 .23344 Mdot
.514 .23349 Mdot
.514 .23359 Mdot
.514 .23413 Mdot
.514 .23451 Mdot
.514 .23467 Mdot
.514 .23481 Mdot
.514 .23517 Mdot
.514 .23547 Mdot
.514 .2359 Mdot
.514 .23601 Mdot
.514 .23694 Mdot
.514 .2381 Mdot
.514 .23824 Mdot
.514 .23927 Mdot
.514 .23934 Mdot
.514 .23938 Mdot
.514 .23972 Mdot
.514 .24034 Mdot
.514 .24056 Mdot
.514 .24154 Mdot
.514 .24159 Mdot
.514 .24163 Mdot
.514 .24169 Mdot
.514 .24196 Mdot
.514 .2421 Mdot
.514 .24259 Mdot
.514 .24332 Mdot
.514 .2434 Mdot
.514 .2446 Mdot
.514 .24526 Mdot
.514 .24566 Mdot
.514 .24586 Mdot
.514 .24589 Mdot
.514 .24653 Mdot
.514 .24653 Mdot
.514 .24658 Mdot
.514 .24682 Mdot
.514 .24727 Mdot
.514 .24884 Mdot
.514 .2492 Mdot
.514 .24953 Mdot
.514 .24991 Mdot
.514 .24993 Mdot
.514 .24996 Mdot
.514 .25005 Mdot
.514 .25051 Mdot
.514 .2511 Mdot
.514 .25122 Mdot
.514 .2515 Mdot
.514 .25159 Mdot
.514 .25173 Mdot
.514 .25256 Mdot
.514 .25259 Mdot
.514 .25291 Mdot
.514 .25335 Mdot
.514 .25346 Mdot
.514 .25389 Mdot
.514 .25413 Mdot
.514 .25432 Mdot
.514 .25479 Mdot
.514 .25514 Mdot
.514 .25547 Mdot
.514 .25573 Mdot
.514 .25578 Mdot
.514 .25581 Mdot
.514 .25733 Mdot
.514 .25759 Mdot
.514 .25776 Mdot
.514 .25776 Mdot
.514 .25814 Mdot
.514 .25828 Mdot
.514 .25851 Mdot
.514 .25963 Mdot
.514 .25968 Mdot
.514 .26012 Mdot
.514 .2605 Mdot
.514 .26067 Mdot
.514 .26073 Mdot
.514 .26077 Mdot
.514 .26138 Mdot
.514 .26151 Mdot
.514 .2619 Mdot
.514 .26214 Mdot
.514 .26218 Mdot
.514 .26284 Mdot
.514 .26429 Mdot
.514 .26519 Mdot
.514 .2653 Mdot
.514 .26592 Mdot
.514 .26628 Mdot
.514 .26669 Mdot
.514 .26682 Mdot
.514 .2673 Mdot
.514 .26735 Mdot
.514 .26741 Mdot
.514 .26741 Mdot
.514 .26769 Mdot
.514 .268 Mdot
.514 .26824 Mdot
.514 .26847 Mdot
.514 .26869 Mdot
.514 .26876 Mdot
.514 .26889 Mdot
.514 .26917 Mdot
.514 .26997 Mdot
.514 .27027 Mdot
.514 .27132 Mdot
.514 .27133 Mdot
.514 .27161 Mdot
.514 .27197 Mdot
.514 .27197 Mdot
.514 .2723 Mdot
.514 .27255 Mdot
.514 .27317 Mdot
.514 .27347 Mdot
.514 .27355 Mdot
.514 .2736 Mdot
.514 .27381 Mdot
.514 .27397 Mdot
.514 .27467 Mdot
.514 .27497 Mdot
.514 .27526 Mdot
.514 .2755 Mdot
.514 .27572 Mdot
.514 .27592 Mdot
.514 .276 Mdot
.514 .27603 Mdot
.514 .27604 Mdot
.514 .27653 Mdot
.514 .27682 Mdot
.514 .27687 Mdot
.514 .27727 Mdot
.514 .2774 Mdot
.514 .27752 Mdot
.514 .27757 Mdot
.514 .2776 Mdot
.514 .27772 Mdot
.514 .2778 Mdot
.514 .27807 Mdot
.514 .27808 Mdot
.514 .27814 Mdot
.514 .27877 Mdot
.514 .27933 Mdot
.514 .27963 Mdot
.514 .27966 Mdot
.514 .27982 Mdot
.514 .28028 Mdot
.514 .28163 Mdot
.514 .28236 Mdot
.514 .28245 Mdot
.514 .28259 Mdot
.514 .28485 Mdot
.514 .28516 Mdot
.514 .28772 Mdot
.514 .28981 Mdot
.514 .29005 Mdot
.514 .29102 Mdot
.514 .29169 Mdot
.514 .29252 Mdot
.514 .29284 Mdot
.514 .29321 Mdot
.514 .29406 Mdot
.514 .29531 Mdot
.514 .29553 Mdot
.514 .29564 Mdot
.514 .29652 Mdot
.514 .29788 Mdot
.514 .29831 Mdot
.514 .29991 Mdot
.514 .30007 Mdot
.514 .30028 Mdot
.514 .30028 Mdot
.514 .30047 Mdot
.514 .301 Mdot
.514 .30119 Mdot
.514 .30127 Mdot
.514 .30222 Mdot
.514 .30243 Mdot
.514 .30279 Mdot
.514 .30302 Mdot
.514 .30378 Mdot
.514 .30449 Mdot
.514 .30474 Mdot
.514 .30516 Mdot
.514 .30606 Mdot
.514 .30865 Mdot
.514 .30962 Mdot
.514 .31295 Mdot
.514 .31297 Mdot
.514 .31386 Mdot
.514 .31498 Mdot
.514 .31499 Mdot
.514 .31508 Mdot
.514 .31603 Mdot
.514 .31679 Mdot
.514 .31741 Mdot
.514 .3187 Mdot
.514 .3194 Mdot
.514 .31961 Mdot
.514 .31984 Mdot
.514 .31999 Mdot
.514 .32046 Mdot
.514 .32064 Mdot
.514 .32108 Mdot
.514 .32113 Mdot
.514 .32321 Mdot
.514 .32338 Mdot
.514 .32411 Mdot
.514 .32495 Mdot
.514 .32566 Mdot
.514 .32596 Mdot
.514 .32631 Mdot
.514 .32643 Mdot
.514 .32687 Mdot
.514 .32712 Mdot
.514 .32719 Mdot
.514 .32724 Mdot
.514 .32864 Mdot
.514 .32944 Mdot
.514 .32959 Mdot
.514 .33072 Mdot
.514 .33109 Mdot
.514 .33142 Mdot
.514 .33156 Mdot
.514 .33165 Mdot
.514 .33177 Mdot
.514 .33198 Mdot
.514 .33219 Mdot
.514 .3322 Mdot
.514 .33294 Mdot
.514 .33298 Mdot
.514 .33314 Mdot
.514 .33485 Mdot
.514 .33517 Mdot
.514 .33598 Mdot
.514 .33634 Mdot
.514 .33715 Mdot
.514 .33721 Mdot
.514 .33764 Mdot
.514 .33884 Mdot
.514 .33914 Mdot
.514 .34023 Mdot
.514 .34039 Mdot
.514 .34227 Mdot
.514 .34243 Mdot
.514 .34331 Mdot
.514 .34408 Mdot
.514 .34428 Mdot
.514 .34463 Mdot
.514 .34528 Mdot
.514 .34603 Mdot
.514 .34986 Mdot
.514 .34997 Mdot
.514 .35032 Mdot
.514 .35041 Mdot
.514 .35056 Mdot
.514 .35201 Mdot
.514 .35205 Mdot
.514 .35248 Mdot
.514 .35294 Mdot
.514 .35318 Mdot
.514 .35338 Mdot
.514 .35367 Mdot
.514 .35435 Mdot
.514 .3551 Mdot
.514 .35591 Mdot
.514 .35732 Mdot
.514 .35761 Mdot
.514 .35913 Mdot
.514 .35987 Mdot
.514 .3603 Mdot
.514 .36161 Mdot
.514 .3617 Mdot
.514 .36182 Mdot
.514 .362 Mdot
.514 .36223 Mdot
.514 .36296 Mdot
.514 .36311 Mdot
.514 .36317 Mdot
.514 .36372 Mdot
.514 .3642 Mdot
.514 .36444 Mdot
.514 .36493 Mdot
.514 .36531 Mdot
.514 .36549 Mdot
.514 .36654 Mdot
.514 .36674 Mdot
.514 .36755 Mdot
.514 .36778 Mdot
.514 .36844 Mdot
.514 .36871 Mdot
.514 .36885 Mdot
.514 .36994 Mdot
.514 .37039 Mdot
.514 .37044 Mdot
.514 .37094 Mdot
.514 .37114 Mdot
.514 .37147 Mdot
.514 .37164 Mdot
.514 .3718 Mdot
.514 .37192 Mdot
.514 .37203 Mdot
.514 .37224 Mdot
.514 .37292 Mdot
.514 .37343 Mdot
.514 .37357 Mdot
.514 .37375 Mdot
.514 .37375 Mdot
.514 .37391 Mdot
.514 .37403 Mdot
.514 .37433 Mdot
.514 .37447 Mdot
.514 .37451 Mdot
.514 .37453 Mdot
.514 .37505 Mdot
.514 .37519 Mdot
.514 .37533 Mdot
.514 .37555 Mdot
.514 .37564 Mdot
.514 .37568 Mdot
.514 .37569 Mdot
.514 .3757 Mdot
.514 .37609 Mdot
.514 .37628 Mdot
.514 .37642 Mdot
.514 .37653 Mdot
.514 .37666 Mdot
.514 .37667 Mdot
.514 .37669 Mdot
.514 .37699 Mdot
.514 .37725 Mdot
.514 .37739 Mdot
.514 .3774 Mdot
.514 .47484 Mdot
.514 .47485 Mdot
.514 .47504 Mdot
.514 .47519 Mdot
.514 .4752 Mdot
.514 .47521 Mdot
.514 .47527 Mdot
.514 .47532 Mdot
.514 .47539 Mdot
.514 .47548 Mdot
.514 .47567 Mdot
.514 .47568 Mdot
.514 .47568 Mdot
.514 .4757 Mdot
.514 .47575 Mdot
.514 .47586 Mdot
.514 .47592 Mdot
.514 .47599 Mdot
.514 .47625 Mdot
.514 .47626 Mdot
.514 .47627 Mdot
.514 .47635 Mdot
.514 .47649 Mdot
.514 .47655 Mdot
.514 .47663 Mdot
.514 .47663 Mdot
.514 .47671 Mdot
.514 .47678 Mdot
.514 .47703 Mdot
.514 .47736 Mdot
.514 .47746 Mdot
.514 .47752 Mdot
.514 .47757 Mdot
.514 .47765 Mdot
.514 .47773 Mdot
.514 .47789 Mdot
.514 .47799 Mdot
.514 .47823 Mdot
.514 .47825 Mdot
.514 .47847 Mdot
.514 .47899 Mdot
.514 .47906 Mdot
.514 .47919 Mdot
.514 .4795 Mdot
.514 .47961 Mdot
.514 .48 Mdot
.514 .4801 Mdot
.514 .4806 Mdot
.514 .48068 Mdot
.514 .48086 Mdot
.514 .48109 Mdot
.514 .48121 Mdot
.514 .48143 Mdot
.514 .4817 Mdot
.514 .48172 Mdot
.514 .48179 Mdot
.514 .48214 Mdot
.514 .48224 Mdot
.514 .48233 Mdot
.514 .48239 Mdot
.514 .48243 Mdot
.514 .48304 Mdot
.514 .48324 Mdot
.514 .48359 Mdot
.514 .4843 Mdot
.514 .48443 Mdot
.514 .48509 Mdot
.514 .48546 Mdot
.514 .48581 Mdot
.514 .48612 Mdot
.514 .48625 Mdot
.514 .48635 Mdot
.514 .48646 Mdot
.514 .48667 Mdot
.514 .48687 Mdot
.514 .48688 Mdot
.514 .48754 Mdot
.514 .48762 Mdot
.514 .48765 Mdot
.514 .48781 Mdot
.514 .48787 Mdot
.514 .4896 Mdot
.514 .48994 Mdot
.514 .49023 Mdot
.514 .49039 Mdot
.514 .49048 Mdot
.514 .49083 Mdot
.514 .49122 Mdot
.514 .49129 Mdot
.514 .49213 Mdot
.514 .4922 Mdot
.514 .49268 Mdot
.514 .49282 Mdot
.514 .49335 Mdot
.514 .49354 Mdot
.514 .49357 Mdot
.514 .49392 Mdot
.514 .49408 Mdot
.514 .49444 Mdot
.514 .49458 Mdot
.514 .49533 Mdot
.514 .4954 Mdot
.514 .49542 Mdot
.514 .49574 Mdot
.514 .49575 Mdot
.514 .49583 Mdot
.514 .49593 Mdot
.514 .49598 Mdot
.514 .49602 Mdot
.514 .49608 Mdot
.514 .49622 Mdot
.514 .49638 Mdot
.514 .49687 Mdot
.514 .49694 Mdot
.514 .49729 Mdot
.514 .49789 Mdot
.514 .49792 Mdot
.514 .49794 Mdot
.514 .49805 Mdot
.514 .49824 Mdot
.514 .49829 Mdot
.514 .49844 Mdot
.514 .49857 Mdot
.514 .49888 Mdot
.514 .49924 Mdot
.514 .49955 Mdot
.514 .49962 Mdot
.514 .50051 Mdot
.514 .50053 Mdot
.514 .50072 Mdot
.514 .5008 Mdot
.514 .50099 Mdot
.514 .50106 Mdot
.514 .50116 Mdot
.514 .50124 Mdot
.514 .50154 Mdot
.514 .50209 Mdot
.514 .50235 Mdot
.514 .50267 Mdot
.514 .50307 Mdot
.514 .50311 Mdot
.514 .50311 Mdot
.514 .50358 Mdot
.514 .50395 Mdot
.514 .50396 Mdot
.514 .50535 Mdot
.514 .50575 Mdot
.514 .50682 Mdot
.514 .50719 Mdot
.514 .50736 Mdot
.514 .50747 Mdot
.514 .50776 Mdot
.514 .50807 Mdot
.514 .50816 Mdot
.514 .50831 Mdot
.514 .5084 Mdot
.514 .50878 Mdot
.514 .50882 Mdot
.514 .50889 Mdot
.514 .50911 Mdot
.514 .50919 Mdot
.514 .50919 Mdot
.514 .50927 Mdot
.514 .50934 Mdot
.514 .50999 Mdot
.514 .51016 Mdot
.514 .51071 Mdot
.514 .51107 Mdot
.514 .51111 Mdot
.514 .5112 Mdot
.514 .5117 Mdot
.514 .51205 Mdot
.514 .51219 Mdot
.514 .51232 Mdot
.514 .51265 Mdot
.514 .51292 Mdot
.514 .51331 Mdot
.514 .51341 Mdot
.514 .51424 Mdot
.514 .51525 Mdot
.514 .51537 Mdot
.514 .51626 Mdot
.514 .51632 Mdot
.514 .51635 Mdot
.514 .51664 Mdot
.514 .51717 Mdot
.514 .51735 Mdot
.514 .51742 Mdot
.514 .51742 Mdot
.514 .51754 Mdot
.514 .51776 Mdot
.514 .51801 Mdot
.514 .51803 Mdot
.514 .51803 Mdot
.514 .51814 Mdot
.514 .51817 Mdot
.514 .51822 Mdot
.514 .51823 Mdot
.514 .51825 Mdot
.514 .5183 Mdot
.514 .51835 Mdot
.514 .5185 Mdot
.514 .51852 Mdot
.514 .51863 Mdot
.514 .51882 Mdot
.514 .51883 Mdot
.514 .51884 Mdot
.514 .51887 Mdot
.514 .51895 Mdot
.514 .51903 Mdot
.514 .51913 Mdot
.514 .51924 Mdot
.514 .51936 Mdot
.514 .51963 Mdot
.514 .51969 Mdot
.514 .51977 Mdot
.514 .51979 Mdot
.514 .51982 Mdot
.514 .51994 Mdot
.514 .52018 Mdot
.514 .52027 Mdot
.514 .5204 Mdot
.514 .5204 Mdot
.514 .52054 Mdot
.514 .52065 Mdot
.514 .52065 Mdot
.514 .52105 Mdot
.514 .52117 Mdot
.514 .52148 Mdot
.514 .52158 Mdot
.514 .52163 Mdot
.514 .52166 Mdot
.514 .52174 Mdot
.514 .52183 Mdot
.514 .52193 Mdot
.514 .52205 Mdot
.514 .52215 Mdot
.514 .52215 Mdot
.514 .52217 Mdot
.514 .52219 Mdot
.514 .52238 Mdot
.514 .52243 Mdot
.514 .52258 Mdot
.514 .52272 Mdot
.514 .52296 Mdot
.514 .523 Mdot
.514 .52334 Mdot
.514 .52389 Mdot
.514 .52414 Mdot
.514 .52415 Mdot
.514 .52425 Mdot
.514 .52439 Mdot
.514 .52445 Mdot
.514 .52468 Mdot
.514 .52469 Mdot
.514 .52471 Mdot
.514 .52477 Mdot
.514 .52492 Mdot
.514 .52509 Mdot
.514 .5251 Mdot
.514 .52553 Mdot
.514 .52561 Mdot
.514 .52567 Mdot
.514 .52581 Mdot
.514 .52581 Mdot
.514 .52587 Mdot
.514 .52597 Mdot
.514 .52654 Mdot
.514 .52655 Mdot
.514 .52657 Mdot
.514 .52667 Mdot
.514 .52679 Mdot
.514 .52692 Mdot
.514 .5271 Mdot
.514 .52717 Mdot
.514 .52726 Mdot
.514 .52742 Mdot
.514 .52746 Mdot
.514 .52763 Mdot
.514 .52775 Mdot
.514 .52776 Mdot
.514 .52806 Mdot
.514 .52812 Mdot
.514 .52815 Mdot
.514 .52825 Mdot
.514 .5283 Mdot
.514 .52852 Mdot
.514 .52869 Mdot
.514 .52872 Mdot
.514 .52873 Mdot
.514 .52874 Mdot
.514 .52888 Mdot
.514 .529 Mdot
.514 .52914 Mdot
.514 .52972 Mdot
.514 .52988 Mdot
.514 .52997 Mdot
.514 .52999 Mdot
.514 .52999 Mdot
.514 .53022 Mdot
.514 .53024 Mdot
.514 .53031 Mdot
.514 .53046 Mdot
.514 .5307 Mdot
.514 .53114 Mdot
.514 .53117 Mdot
.514 .53144 Mdot
.514 .53162 Mdot
.514 .53167 Mdot
.514 .53177 Mdot
.514 .53179 Mdot
.514 .5318 Mdot
.514 .53182 Mdot
.514 .53218 Mdot
.514 .53226 Mdot
.514 .53249 Mdot
.514 .53261 Mdot
.514 .53263 Mdot
.514 .53265 Mdot
.514 .53303 Mdot
.514 .53308 Mdot
.514 .5335 Mdot
.514 .53384 Mdot
.514 .53387 Mdot
.514 .53403 Mdot
.514 .53414 Mdot
.514 .53427 Mdot
.514 .53432 Mdot
.514 .53438 Mdot
.514 .53452 Mdot
.514 .53471 Mdot
.514 .53475 Mdot
.514 .53476 Mdot
.514 .5349 Mdot
.514 .53512 Mdot
.514 .53518 Mdot
.514 .53543 Mdot
.514 .53545 Mdot
.514 .53549 Mdot
.514 .53549 Mdot
.514 .53552 Mdot
.514 .5356 Mdot
.514 .53563 Mdot
.514 .53564 Mdot
.514 .53578 Mdot
.514 .53582 Mdot
.514 .53587 Mdot
.514 .53591 Mdot
.514 .53602 Mdot
.514 .53613 Mdot
.514 .53617 Mdot
.514 .53623 Mdot
.514 .53637 Mdot
.514 .53675 Mdot
.514 .5369 Mdot
.514 .53739 Mdot
.514 .53739 Mdot
.514 .53752 Mdot
.514 .53768 Mdot
.514 .53769 Mdot
.514 .5377 Mdot
.514 .53784 Mdot
.514 .53795 Mdot
.514 .53804 Mdot
.514 .53822 Mdot
.514 .53833 Mdot
.514 .53836 Mdot
.514 .53839 Mdot
.514 .53841 Mdot
.514 .53848 Mdot
.514 .5385 Mdot
.514 .53857 Mdot
.514 .53857 Mdot
.514 .53887 Mdot
.514 .53889 Mdot
.514 .539 Mdot
.514 .53911 Mdot
.514 .53922 Mdot
.514 .53926 Mdot
.514 .53931 Mdot
.514 .53932 Mdot
.514 .53939 Mdot
.514 .53942 Mdot
.514 .53943 Mdot
.514 .53944 Mdot
.514 .53963 Mdot
.514 .53975 Mdot
.514 .53977 Mdot
.514 .53992 Mdot
.514 .53997 Mdot
.514 .54002 Mdot
.514 .54004 Mdot
.514 .54005 Mdot
.514 .54007 Mdot
.514 .5401 Mdot
.514 .54013 Mdot
.514 .54013 Mdot
.514 .54023 Mdot
.514 .54024 Mdot
.514 .54026 Mdot
.514 .54049 Mdot
.514 .54054 Mdot
.514 .54065 Mdot
.514 .5407 Mdot
.514 .54081 Mdot
.514 .54082 Mdot
.514 .54088 Mdot
.514 .54104 Mdot
.514 .54108 Mdot
.514 .54123 Mdot
.514 .54125 Mdot
.514 .5415 Mdot
.514 .54153 Mdot
.514 .54165 Mdot
.514 .54175 Mdot
.514 .54178 Mdot
.514 .54182 Mdot
.514 .54191 Mdot
.514 .54201 Mdot
.514 .54252 Mdot
.514 .54254 Mdot
.514 .54258 Mdot
.514 .5426 Mdot
.514 .54262 Mdot
.514 .54281 Mdot
.514 .54281 Mdot
.514 .54287 Mdot
.514 .54293 Mdot
.514 .54296 Mdot
.514 .54299 Mdot
.514 .54303 Mdot
.514 .54312 Mdot
.514 .54322 Mdot
.514 .54332 Mdot
.514 .54351 Mdot
.514 .54355 Mdot
.514 .54375 Mdot
.514 .54384 Mdot
.514 .5439 Mdot
.514 .54407 Mdot
.514 .54408 Mdot
.514 .5441 Mdot
.514 .54412 Mdot
.514 .54415 Mdot
.514 .54425 Mdot
.514 .54427 Mdot
.514 .54427 Mdot
.514 .54434 Mdot
.514 .54441 Mdot
.514 .54444 Mdot
.514 .5445 Mdot
.514 .54455 Mdot
.514 .54457 Mdot
.514 .54471 Mdot
.514 .54474 Mdot
.514 .54484 Mdot
.514 .54487 Mdot
.514 .54495 Mdot
.514 .54499 Mdot
.514 .54501 Mdot
.514 .54515 Mdot
.514 .54521 Mdot
.514 .54521 Mdot
.514 .54528 Mdot
.514 .5453 Mdot
.514 .54535 Mdot
.514 .54537 Mdot
.514 .54539 Mdot
.514 .5454 Mdot
.514 .54542 Mdot
.514 .54544 Mdot
.514 .54553 Mdot
.514 .5456 Mdot
.514 .54562 Mdot
.514 .54564 Mdot
.514 .54564 Mdot
.514 .54566 Mdot
.514 .54567 Mdot
.514 .54571 Mdot
.514 .54573 Mdot
.514 .54574 Mdot
.514 .54574 Mdot
.514 .5458 Mdot
.514 .54582 Mdot
.514 .54584 Mdot
.514 .54587 Mdot
.514 .54588 Mdot
.514 .54589 Mdot
.514 .54589 Mdot
.514 .54589 Mdot
.514 .54594 Mdot
.514 .54596 Mdot
.514 .54598 Mdot
.514 .54599 Mdot
.514 .54601 Mdot
.514 .54601 Mdot
.514 .54602 Mdot
.514 .54605 Mdot
.514 .5461 Mdot
.514 .54611 Mdot
.516 .20063 Mdot
.516 .20064 Mdot
.516 .20064 Mdot
.516 .20064 Mdot
.516 .20064 Mdot
.516 .20064 Mdot
.516 .20064 Mdot
.516 .20066 Mdot
.516 .20067 Mdot
.516 .20067 Mdot
.516 .20069 Mdot
.516 .2007 Mdot
.516 .2007 Mdot
.516 .20071 Mdot
.516 .20074 Mdot
.516 .20081 Mdot
.516 .20083 Mdot
.516 .20092 Mdot
.516 .20093 Mdot
.516 .20107 Mdot
.516 .20138 Mdot
.516 .20147 Mdot
.516 .20154 Mdot
.516 .20174 Mdot
.516 .20176 Mdot
.516 .20218 Mdot
.516 .2022 Mdot
.516 .20262 Mdot
.516 .20271 Mdot
.516 .20273 Mdot
.516 .20277 Mdot
.516 .20277 Mdot
.516 .20278 Mdot
.516 .20282 Mdot
.516 .20283 Mdot
.516 .20288 Mdot
.516 .20289 Mdot
.516 .20291 Mdot
.516 .20293 Mdot
.516 .20303 Mdot
.516 .20319 Mdot
.516 .20325 Mdot
.516 .20333 Mdot
.516 .20333 Mdot
.516 .20345 Mdot
.516 .20378 Mdot
.516 .2039 Mdot
.516 .20397 Mdot
.516 .20431 Mdot
.516 .2048 Mdot
.516 .20499 Mdot
.516 .20551 Mdot
.516 .20555 Mdot
.516 .20562 Mdot
.516 .2059 Mdot
.516 .20617 Mdot
.516 .20643 Mdot
.516 .20648 Mdot
.516 .20649 Mdot
.516 .20659 Mdot
.516 .20664 Mdot
.516 .20665 Mdot
.516 .2067 Mdot
.516 .20736 Mdot
.516 .20757 Mdot
.516 .20763 Mdot
.516 .20837 Mdot
.516 .20847 Mdot
.516 .20856 Mdot
.516 .20897 Mdot
.516 .20907 Mdot
.516 .21003 Mdot
.516 .2102 Mdot
.516 .2103 Mdot
.516 .21068 Mdot
.516 .21117 Mdot
.516 .21126 Mdot
.516 .21181 Mdot
.516 .21339 Mdot
.516 .2134 Mdot
.516 .2134 Mdot
.516 .21341 Mdot
.516 .21342 Mdot
.516 .21344 Mdot
.516 .21344 Mdot
.516 .21345 Mdot
.516 .21355 Mdot
.516 .21357 Mdot
.516 .21361 Mdot
.516 .21364 Mdot
.516 .2137 Mdot
.516 .21373 Mdot
.516 .21375 Mdot
.516 .21383 Mdot
.516 .21395 Mdot
.516 .21412 Mdot
.516 .21434 Mdot
.516 .21435 Mdot
.516 .21449 Mdot
.516 .21455 Mdot
.516 .21502 Mdot
.516 .21508 Mdot
.516 .21516 Mdot
.516 .21577 Mdot
.516 .21591 Mdot
.516 .21614 Mdot
.516 .21753 Mdot
.516 .21777 Mdot
.516 .21781 Mdot
.516 .21804 Mdot
.516 .21821 Mdot
.516 .21826 Mdot
.516 .21834 Mdot
.516 .21882 Mdot
.516 .21887 Mdot
.516 .21909 Mdot
.516 .21918 Mdot
.516 .21959 Mdot
.516 .21974 Mdot
.516 .22013 Mdot
.516 .22016 Mdot
.516 .22017 Mdot
.516 .2202 Mdot
.516 .22026 Mdot
.516 .2203 Mdot
.516 .22063 Mdot
.516 .22082 Mdot
.516 .22086 Mdot
.516 .22139 Mdot
.516 .22177 Mdot
.516 .22203 Mdot
.516 .22209 Mdot
.516 .22219 Mdot
.516 .22239 Mdot
.516 .22248 Mdot
.516 .22259 Mdot
.516 .22266 Mdot
.516 .22272 Mdot
.516 .22299 Mdot
.516 .22301 Mdot
.516 .22302 Mdot
.516 .22307 Mdot
.516 .22308 Mdot
.516 .22312 Mdot
.516 .22313 Mdot
.516 .22313 Mdot
.516 .22318 Mdot
.516 .2232 Mdot
.516 .22328 Mdot
.516 .22495 Mdot
.516 .22623 Mdot
.516 .22681 Mdot
.516 .22683 Mdot
.516 .22698 Mdot
.516 .22729 Mdot
.516 .22729 Mdot
.516 .22735 Mdot
.516 .22741 Mdot
.516 .22768 Mdot
.516 .22777 Mdot
.516 .22777 Mdot
.516 .22813 Mdot
.516 .22816 Mdot
.516 .22833 Mdot
.516 .22848 Mdot
.516 .22859 Mdot
.516 .22889 Mdot
.516 .22927 Mdot
.516 .2293 Mdot
.516 .22966 Mdot
.516 .23046 Mdot
.516 .23058 Mdot
.516 .2309 Mdot
.516 .23093 Mdot
.516 .23151 Mdot
.516 .23153 Mdot
.516 .23238 Mdot
.516 .23249 Mdot
.516 .23279 Mdot
.516 .23424 Mdot
.516 .23464 Mdot
.516 .23512 Mdot
.516 .23533 Mdot
.516 .23605 Mdot
.516 .23661 Mdot
.516 .23928 Mdot
.516 .23937 Mdot
.516 .23971 Mdot
.516 .23981 Mdot
.516 .24115 Mdot
.516 .24147 Mdot
.516 .24173 Mdot
.516 .24181 Mdot
.516 .24186 Mdot
.516 .24226 Mdot
.516 .24231 Mdot
.516 .24245 Mdot
.516 .24253 Mdot
.516 .24328 Mdot
.516 .2435 Mdot
.516 .24414 Mdot
.516 .24483 Mdot
.516 .24505 Mdot
.516 .24518 Mdot
.516 .24558 Mdot
.516 .24573 Mdot
.516 .24586 Mdot
.516 .24681 Mdot
.516 .24927 Mdot
.516 .2497 Mdot
.516 .24989 Mdot
.516 .24992 Mdot
.516 .25007 Mdot
.516 .25012 Mdot
.516 .25014 Mdot
.516 .25038 Mdot
.516 .25065 Mdot
.516 .25086 Mdot
.516 .25093 Mdot
.516 .25114 Mdot
.516 .25223 Mdot
.516 .25243 Mdot
.516 .25313 Mdot
.516 .25373 Mdot
.516 .25422 Mdot
.516 .25511 Mdot
.516 .25543 Mdot
.516 .25552 Mdot
.516 .25564 Mdot
.516 .25588 Mdot
.516 .25793 Mdot
.516 .25825 Mdot
.516 .25833 Mdot
.516 .25846 Mdot
.516 .25887 Mdot
.516 .25925 Mdot
.516 .25938 Mdot
.516 .25984 Mdot
.516 .25988 Mdot
.516 .25997 Mdot
.516 .26027 Mdot
.516 .26033 Mdot
.516 .26068 Mdot
.516 .26151 Mdot
.516 .26179 Mdot
.516 .26355 Mdot
.516 .26391 Mdot
.516 .26453 Mdot
.516 .2663 Mdot
.516 .26638 Mdot
.516 .26697 Mdot
.516 .26698 Mdot
.516 .26738 Mdot
.516 .26772 Mdot
.516 .26829 Mdot
.516 .26855 Mdot
.516 .26857 Mdot
.516 .26885 Mdot
.516 .26915 Mdot
.516 .26925 Mdot
.516 .26937 Mdot
.516 .2694 Mdot
.516 .26966 Mdot
.516 .26966 Mdot
.516 .26973 Mdot
.516 .26993 Mdot
.516 .26998 Mdot
.516 .27002 Mdot
.516 .27002 Mdot
.516 .27026 Mdot
.516 .27037 Mdot
.516 .27038 Mdot
.516 .27082 Mdot
.516 .27181 Mdot
.516 .27313 Mdot
.516 .2732 Mdot
.516 .2733 Mdot
.516 .27359 Mdot
.516 .27517 Mdot
.516 .27533 Mdot
.516 .27562 Mdot
.516 .27565 Mdot
.516 .27573 Mdot
.516 .27576 Mdot
.516 .27659 Mdot
.516 .27667 Mdot
.516 .27686 Mdot
.516 .27691 Mdot
.516 .27734 Mdot
.516 .27741 Mdot
.516 .27786 Mdot
.516 .27809 Mdot
.516 .27962 Mdot
.516 .28044 Mdot
.516 .2805 Mdot
.516 .28098 Mdot
.516 .28103 Mdot
.516 .28118 Mdot
.516 .28119 Mdot
.516 .28141 Mdot
.516 .28159 Mdot
.516 .28172 Mdot
.516 .28181 Mdot
.516 .28183 Mdot
.516 .28186 Mdot
.516 .28192 Mdot
.516 .28195 Mdot
.516 .28199 Mdot
.516 .28201 Mdot
.516 .28212 Mdot
.516 .28213 Mdot
.516 .28213 Mdot
.516 .28215 Mdot
.516 .28217 Mdot
.516 .28217 Mdot
.516 .28217 Mdot
.516 .28218 Mdot
.516 .28803 Mdot
.516 .28928 Mdot
.516 .2909 Mdot
.516 .29139 Mdot
.516 .29247 Mdot
.516 .29338 Mdot
.516 .29673 Mdot
.516 .29742 Mdot
.516 .29768 Mdot
.516 .29966 Mdot
.516 .29972 Mdot
.516 .30106 Mdot
.516 .30113 Mdot
.516 .30188 Mdot
.516 .30218 Mdot
.516 .30406 Mdot
.516 .30493 Mdot
.516 .30501 Mdot
.516 .30591 Mdot
.516 .30664 Mdot
.516 .3069 Mdot
.516 .30724 Mdot
.516 .30765 Mdot
.516 .30773 Mdot
.516 .30859 Mdot
.516 .30859 Mdot
.516 .30881 Mdot
.516 .30947 Mdot
.516 .30961 Mdot
.516 .30975 Mdot
.516 .30976 Mdot
.516 .31051 Mdot
.516 .31087 Mdot
.516 .31092 Mdot
.516 .31233 Mdot
.516 .31546 Mdot
.516 .31957 Mdot
.516 .31979 Mdot
.516 .31984 Mdot
.516 .31995 Mdot
.516 .31995 Mdot
.516 .31997 Mdot
.516 .32009 Mdot
.516 .32012 Mdot
.516 .32024 Mdot
.516 .32025 Mdot
.516 .32031 Mdot
.516 .32098 Mdot
.516 .32113 Mdot
.516 .3213 Mdot
.516 .32158 Mdot
.516 .3223 Mdot
.516 .32255 Mdot
.516 .32269 Mdot
.516 .32336 Mdot
.516 .3243 Mdot
.516 .32563 Mdot
.516 .32574 Mdot
.516 .32621 Mdot
.516 .32706 Mdot
.516 .32715 Mdot
.516 .32731 Mdot
.516 .32739 Mdot
.516 .3274 Mdot
.516 .32747 Mdot
.516 .32846 Mdot
.516 .32884 Mdot
.516 .32988 Mdot
.516 .33013 Mdot
.516 .33067 Mdot
.516 .3308 Mdot
.516 .33202 Mdot
.516 .33223 Mdot
.516 .33235 Mdot
.516 .3328 Mdot
.516 .33339 Mdot
.516 .33349 Mdot
.516 .33411 Mdot
.516 .33767 Mdot
.516 .33827 Mdot
.516 .33863 Mdot
.516 .3402 Mdot
.516 .34041 Mdot
.516 .34057 Mdot
.516 .34181 Mdot
.516 .34194 Mdot
.516 .34231 Mdot
.516 .34233 Mdot
.516 .3429 Mdot
.516 .34335 Mdot
.516 .34366 Mdot
.516 .34389 Mdot
.516 .34393 Mdot
.516 .34401 Mdot
.516 .34418 Mdot
.516 .34425 Mdot
.516 .34434 Mdot
.516 .3444 Mdot
.516 .34467 Mdot
.516 .34469 Mdot
.516 .34469 Mdot
.516 .34474 Mdot
.516 .34478 Mdot
.516 .34478 Mdot
.516 .34478 Mdot
.516 .34482 Mdot
.516 .34897 Mdot
.516 .3504 Mdot
.516 .35063 Mdot
.516 .35194 Mdot
.516 .35292 Mdot
.516 .35319 Mdot
.516 .35365 Mdot
.516 .35619 Mdot
.516 .35646 Mdot
.516 .35755 Mdot
.516 .35778 Mdot
.516 .35803 Mdot
.516 .36002 Mdot
.516 .36018 Mdot
.516 .36073 Mdot
.516 .3625 Mdot
.516 .36263 Mdot
.516 .36264 Mdot
.516 .36277 Mdot
.516 .36305 Mdot
.516 .36308 Mdot
.516 .3632 Mdot
.516 .36392 Mdot
.516 .36463 Mdot
.516 .36538 Mdot
.516 .36555 Mdot
.516 .36567 Mdot
.516 .36706 Mdot
.516 .36758 Mdot
.516 .3689 Mdot
.516 .3698 Mdot
.516 .36999 Mdot
.516 .3703 Mdot
.516 .37119 Mdot
.516 .37152 Mdot
.516 .37153 Mdot
.516 .37173 Mdot
.516 .3719 Mdot
.516 .37232 Mdot
.516 .3726 Mdot
.516 .37265 Mdot
.516 .37271 Mdot
.516 .37272 Mdot
.516 .37285 Mdot
.516 .37289 Mdot
.516 .37301 Mdot
.516 .37303 Mdot
.516 .37303 Mdot
.516 .37314 Mdot
.516 .3732 Mdot
.516 .37342 Mdot
.516 .37456 Mdot
.516 .37462 Mdot
.516 .37573 Mdot
.516 .37578 Mdot
.516 .37633 Mdot
.516 .37653 Mdot
.516 .37678 Mdot
.516 .3776 Mdot
.516 .37798 Mdot
.516 .378 Mdot
.516 .37825 Mdot
.516 .37832 Mdot
.516 .37851 Mdot
.516 .37856 Mdot
.516 .37861 Mdot
.516 .37861 Mdot
.516 .37863 Mdot
.516 .37867 Mdot
.516 .37869 Mdot
.516 .3787 Mdot
.516 .37875 Mdot
.516 .37875 Mdot
.516 .37876 Mdot
.516 .37877 Mdot
.516 .37877 Mdot
.516 .37877 Mdot
.516 .37878 Mdot
.516 .47424 Mdot
.516 .47425 Mdot
.516 .47425 Mdot
.516 .47425 Mdot
.516 .47425 Mdot
.516 .47426 Mdot
.516 .47426 Mdot
.516 .47428 Mdot
.516 .47429 Mdot
.516 .4743 Mdot
.516 .47432 Mdot
.516 .47432 Mdot
.516 .47433 Mdot
.516 .47435 Mdot
.516 .47438 Mdot
.516 .47447 Mdot
.516 .4745 Mdot
.516 .47462 Mdot
.516 .47464 Mdot
.516 .47482 Mdot
.516 .47523 Mdot
.516 .47535 Mdot
.516 .47545 Mdot
.516 .47571 Mdot
.516 .47574 Mdot
.516 .47628 Mdot
.516 .47631 Mdot
.516 .47687 Mdot
.516 .47697 Mdot
.516 .477 Mdot
.516 .47705 Mdot
.516 .47705 Mdot
.516 .47707 Mdot
.516 .47712 Mdot
.516 .47714 Mdot
.516 .4772 Mdot
.516 .47721 Mdot
.516 .47724 Mdot
.516 .47726 Mdot
.516 .4774 Mdot
.516 .4776 Mdot
.516 .47768 Mdot
.516 .47778 Mdot
.516 .47778 Mdot
.516 .47794 Mdot
.516 .47837 Mdot
.516 .47852 Mdot
.516 .47861 Mdot
.516 .47904 Mdot
.516 .47967 Mdot
.516 .47992 Mdot
.516 .48059 Mdot
.516 .48064 Mdot
.516 .48072 Mdot
.516 .48108 Mdot
.516 .48141 Mdot
.516 .48175 Mdot
.516 .48181 Mdot
.516 .48183 Mdot
.516 .48195 Mdot
.516 .48202 Mdot
.516 .48202 Mdot
.516 .48208 Mdot
.516 .48291 Mdot
.516 .48317 Mdot
.516 .48325 Mdot
.516 .48417 Mdot
.516 .48429 Mdot
.516 .4844 Mdot
.516 .4849 Mdot
.516 .48503 Mdot
.516 .4862 Mdot
.516 .48641 Mdot
.516 .48653 Mdot
.516 .48699 Mdot
.516 .48758 Mdot
.516 .48769 Mdot
.516 .48834 Mdot
.516 .49021 Mdot
.516 .49023 Mdot
.516 .49023 Mdot
.516 .49023 Mdot
.516 .49025 Mdot
.516 .49027 Mdot
.516 .49027 Mdot
.516 .49028 Mdot
.516 .4904 Mdot
.516 .49043 Mdot
.516 .49047 Mdot
.516 .4905 Mdot
.516 .49058 Mdot
.516 .49061 Mdot
.516 .49063 Mdot
.516 .49073 Mdot
.516 .49087 Mdot
.516 .49107 Mdot
.516 .49133 Mdot
.516 .49134 Mdot
.516 .4915 Mdot
.516 .49156 Mdot
.516 .49211 Mdot
.516 .49218 Mdot
.516 .49228 Mdot
.516 .49297 Mdot
.516 .49313 Mdot
.516 .4934 Mdot
.516 .49496 Mdot
.516 .49524 Mdot
.516 .49528 Mdot
.516 .49554 Mdot
.516 .49573 Mdot
.516 .49579 Mdot
.516 .49588 Mdot
.516 .49641 Mdot
.516 .49647 Mdot
.516 .4967 Mdot
.516 .49681 Mdot
.516 .49726 Mdot
.516 .49743 Mdot
.516 .49785 Mdot
.516 .49788 Mdot
.516 .49789 Mdot
.516 .49792 Mdot
.516 .49799 Mdot
.516 .49803 Mdot
.516 .4984 Mdot
.516 .4986 Mdot
.516 .49864 Mdot
.516 .49922 Mdot
.516 .49962 Mdot
.516 .4999 Mdot
.516 .49996 Mdot
.516 .50007 Mdot
.516 .50038 Mdot
.516 .5005 Mdot
.516 .50057 Mdot
.516 .50063 Mdot
.516 .50092 Mdot
.516 .50094 Mdot
.516 .50095 Mdot
.516 .501 Mdot
.516 .50101 Mdot
.516 .50106 Mdot
.516 .50107 Mdot
.516 .50107 Mdot
.516 .50112 Mdot
.516 .50114 Mdot
.516 .50123 Mdot
.516 .50296 Mdot
.516 .50427 Mdot
.516 .50486 Mdot
.516 .50488 Mdot
.516 .50503 Mdot
.516 .50534 Mdot
.516 .50535 Mdot
.516 .50541 Mdot
.516 .50546 Mdot
.516 .50574 Mdot
.516 .50583 Mdot
.516 .50583 Mdot
.516 .50619 Mdot
.516 .50622 Mdot
.516 .50639 Mdot
.516 .50653 Mdot
.516 .50664 Mdot
.516 .50693 Mdot
.516 .50731 Mdot
.516 .50734 Mdot
.516 .50769 Mdot
.516 .50846 Mdot
.516 .50858 Mdot
.516 .50889 Mdot
.516 .50892 Mdot
.516 .50947 Mdot
.516 .50949 Mdot
.516 .51029 Mdot
.516 .5104 Mdot
.516 .51068 Mdot
.516 .51203 Mdot
.516 .51239 Mdot
.516 .51282 Mdot
.516 .51302 Mdot
.516 .51367 Mdot
.516 .51416 Mdot
.516 .51647 Mdot
.516 .51648 Mdot
.516 .51648 Mdot
.516 .51648 Mdot
.516 .51648 Mdot
.516 .51649 Mdot
.516 .51649 Mdot
.516 .51649 Mdot
.516 .51654 Mdot
.516 .51655 Mdot
.516 .51656 Mdot
.516 .51657 Mdot
.516 .5166 Mdot
.516 .51661 Mdot
.516 .51662 Mdot
.516 .51665 Mdot
.516 .5167 Mdot
.516 .51686 Mdot
.516 .51687 Mdot
.516 .51692 Mdot
.516 .51694 Mdot
.516 .51713 Mdot
.516 .51715 Mdot
.516 .51747 Mdot
.516 .51807 Mdot
.516 .51816 Mdot
.516 .51834 Mdot
.516 .51836 Mdot
.516 .51853 Mdot
.516 .51855 Mdot
.516 .51862 Mdot
.516 .51866 Mdot
.516 .51898 Mdot
.516 .51899 Mdot
.516 .51902 Mdot
.516 .51903 Mdot
.516 .51915 Mdot
.516 .51921 Mdot
.516 .51982 Mdot
.516 .51993 Mdot
.516 .51997 Mdot
.516 .52 Mdot
.516 .52051 Mdot
.516 .52088 Mdot
.516 .52105 Mdot
.516 .52106 Mdot
.516 .5211 Mdot
.516 .52119 Mdot
.516 .52119 Mdot
.516 .52121 Mdot
.516 .52123 Mdot
.516 .5213 Mdot
.516 .52133 Mdot
.516 .52133 Mdot
.516 .52143 Mdot
.516 .52144 Mdot
.516 .52149 Mdot
.516 .52153 Mdot
.516 .52164 Mdot
.516 .52175 Mdot
.516 .52176 Mdot
.516 .52186 Mdot
.516 .52207 Mdot
.516 .5222 Mdot
.516 .52236 Mdot
.516 .52236 Mdot
.516 .52259 Mdot
.516 .52262 Mdot
.516 .52329 Mdot
.516 .52353 Mdot
.516 .52366 Mdot
.516 .52433 Mdot
.516 .52443 Mdot
.516 .52475 Mdot
.516 .52488 Mdot
.516 .5249 Mdot
.516 .52502 Mdot
.516 .52505 Mdot
.516 .52507 Mdot
.516 .52524 Mdot
.516 .52529 Mdot
.516 .52543 Mdot
.516 .52559 Mdot
.516 .52563 Mdot
.516 .52566 Mdot
.516 .52579 Mdot
.516 .52655 Mdot
.516 .52664 Mdot
.516 .52669 Mdot
.516 .52672 Mdot
.516 .52684 Mdot
.516 .52717 Mdot
.516 .52736 Mdot
.516 .52758 Mdot
.516 .52784 Mdot
.516 .52792 Mdot
.516 .52832 Mdot
.516 .5284 Mdot
.516 .52842 Mdot
.516 .5285 Mdot
.516 .5286 Mdot
.516 .52869 Mdot
.516 .5287 Mdot
.516 .52872 Mdot
.516 .52878 Mdot
.516 .52879 Mdot
.516 .52886 Mdot
.516 .52901 Mdot
.516 .52993 Mdot
.516 .53028 Mdot
.516 .53032 Mdot
.516 .53038 Mdot
.516 .53053 Mdot
.516 .53057 Mdot
.516 .53065 Mdot
.516 .53091 Mdot
.516 .53114 Mdot
.516 .53122 Mdot
.516 .5315 Mdot
.516 .53153 Mdot
.516 .53158 Mdot
.516 .5316 Mdot
.516 .53174 Mdot
.516 .53176 Mdot
.516 .53179 Mdot
.516 .53189 Mdot
.516 .532 Mdot
.516 .53249 Mdot
.516 .53253 Mdot
.516 .53265 Mdot
.516 .53268 Mdot
.516 .53365 Mdot
.516 .53386 Mdot
.516 .53412 Mdot
.516 .5342 Mdot
.516 .53437 Mdot
.516 .53451 Mdot
.516 .53504 Mdot
.516 .53514 Mdot
.516 .53518 Mdot
.516 .53549 Mdot
.516 .5355 Mdot
.516 .5357 Mdot
.516 .53571 Mdot
.516 .53583 Mdot
.516 .53587 Mdot
.516 .53616 Mdot
.516 .53629 Mdot
.516 .5363 Mdot
.516 .53644 Mdot
.516 .53655 Mdot
.516 .53658 Mdot
.516 .53664 Mdot
.516 .5367 Mdot
.516 .53671 Mdot
.516 .53684 Mdot
.516 .53684 Mdot
.516 .53687 Mdot
.516 .53697 Mdot
.516 .53699 Mdot
.516 .53701 Mdot
.516 .53701 Mdot
.516 .53712 Mdot
.516 .53717 Mdot
.516 .53718 Mdot
.516 .53739 Mdot
.516 .53784 Mdot
.516 .53844 Mdot
.516 .53847 Mdot
.516 .53847 Mdot
.516 .53849 Mdot
.516 .53849 Mdot
.516 .53849 Mdot
.516 .53851 Mdot
.516 .53851 Mdot
.516 .53853 Mdot
.516 .53853 Mdot
.516 .53854 Mdot
.516 .53864 Mdot
.516 .53866 Mdot
.516 .53868 Mdot
.516 .53872 Mdot
.516 .53875 Mdot
.516 .53882 Mdot
.516 .53886 Mdot
.516 .53888 Mdot
.516 .53897 Mdot
.516 .53911 Mdot
.516 .53929 Mdot
.516 .53931 Mdot
.516 .53938 Mdot
.516 .53949 Mdot
.516 .53951 Mdot
.516 .53953 Mdot
.516 .53954 Mdot
.516 .53954 Mdot
.516 .53955 Mdot
.516 .53969 Mdot
.516 .53974 Mdot
.516 .53989 Mdot
.516 .53992 Mdot
.516 .54 Mdot
.516 .54002 Mdot
.516 .54018 Mdot
.516 .54021 Mdot
.516 .54023 Mdot
.516 .54029 Mdot
.516 .54037 Mdot
.516 .54039 Mdot
.516 .54047 Mdot
.516 .54096 Mdot
.516 .54104 Mdot
.516 .54109 Mdot
.516 .5413 Mdot
.516 .54133 Mdot
.516 .54135 Mdot
.516 .54152 Mdot
.516 .54154 Mdot
.516 .54159 Mdot
.516 .54159 Mdot
.516 .54167 Mdot
.516 .54173 Mdot
.516 .54177 Mdot
.516 .5418 Mdot
.516 .5418 Mdot
.516 .54181 Mdot
.516 .54184 Mdot
.516 .54185 Mdot
.516 .54186 Mdot
.516 .54187 Mdot
.516 .5419 Mdot
.516 .54191 Mdot
.516 .54191 Mdot
.516 .54191 Mdot
.516 .54192 Mdot
.516 .54192 Mdot
.516 .54192 Mdot
.516 .54192 Mdot
.516 .54248 Mdot
.516 .54267 Mdot
.516 .5427 Mdot
.516 .54287 Mdot
.516 .543 Mdot
.516 .54303 Mdot
.516 .54309 Mdot
.516 .54343 Mdot
.516 .54346 Mdot
.516 .54361 Mdot
.516 .54364 Mdot
.516 .54367 Mdot
.516 .54393 Mdot
.516 .54395 Mdot
.516 .54402 Mdot
.516 .54425 Mdot
.516 .54427 Mdot
.516 .54427 Mdot
.516 .54429 Mdot
.516 .54432 Mdot
.516 .54433 Mdot
.516 .54434 Mdot
.516 .54444 Mdot
.516 .54453 Mdot
.516 .54462 Mdot
.516 .54465 Mdot
.516 .54466 Mdot
.516 .54484 Mdot
.516 .54491 Mdot
.516 .54508 Mdot
.516 .54519 Mdot
.516 .54522 Mdot
.516 .54526 Mdot
.516 .54537 Mdot
.516 .54542 Mdot
.516 .54542 Mdot
.516 .54544 Mdot
.516 .54546 Mdot
.516 .54552 Mdot
.516 .54555 Mdot
.516 .54556 Mdot
.516 .54557 Mdot
.516 .54557 Mdot
.516 .54559 Mdot
.516 .54559 Mdot
.516 .54561 Mdot
.516 .54561 Mdot
.516 .54561 Mdot
.516 .54562 Mdot
.516 .54563 Mdot
.516 .54566 Mdot
.516 .5458 Mdot
.516 .54581 Mdot
.516 .54595 Mdot
.516 .54596 Mdot
.516 .54603 Mdot
.516 .54606 Mdot
.516 .54609 Mdot
.516 .54619 Mdot
.516 .54624 Mdot
.516 .54624 Mdot
.516 .54627 Mdot
.516 .54628 Mdot
.516 .54631 Mdot
.516 .54631 Mdot
.516 .54632 Mdot
.516 .54632 Mdot
.516 .54632 Mdot
.516 .54633 Mdot
.516 .54633 Mdot
.516 .54633 Mdot
.516 .54634 Mdot
.516 .54634 Mdot
.516 .54634 Mdot
.516 .54634 Mdot
.516 .54634 Mdot
.516 .54634 Mdot
.516 .54634 Mdot
.518 .20004 Mdot
.518 .20004 Mdot
.518 .20004 Mdot
.518 .20004 Mdot
.518 .20006 Mdot
.518 .20006 Mdot
.518 .20007 Mdot
.518 .20009 Mdot
.518 .20009 Mdot
.518 .20009 Mdot
.518 .20009 Mdot
.518 .2001 Mdot
.518 .20014 Mdot
.518 .2002 Mdot
.518 .20026 Mdot
.518 .20028 Mdot
.518 .20032 Mdot
.518 .20036 Mdot
.518 .20039 Mdot
.518 .20041 Mdot
.518 .20041 Mdot
.518 .20044 Mdot
.518 .20046 Mdot
.518 .20052 Mdot
.518 .20053 Mdot
.518 .20055 Mdot
.518 .20085 Mdot
.518 .20092 Mdot
.518 .20109 Mdot
.518 .20118 Mdot
.518 .20122 Mdot
.518 .20136 Mdot
.518 .20148 Mdot
.518 .20155 Mdot
.518 .20164 Mdot
.518 .20166 Mdot
.518 .20168 Mdot
.518 .2017 Mdot
.518 .20172 Mdot
.518 .2019 Mdot
.518 .20201 Mdot
.518 .20201 Mdot
.518 .20202 Mdot
.518 .20206 Mdot
.518 .20209 Mdot
.518 .20214 Mdot
.518 .2022 Mdot
.518 .20225 Mdot
.518 .20242 Mdot
.518 .20254 Mdot
.518 .20257 Mdot
.518 .20257 Mdot
.518 .20258 Mdot
.518 .20258 Mdot
.518 .20258 Mdot
.518 .2029 Mdot
.518 .20295 Mdot
.518 .20347 Mdot
.518 .20371 Mdot
.518 .20378 Mdot
.518 .20415 Mdot
.518 .20515 Mdot
.518 .20537 Mdot
.518 .20556 Mdot
.518 .20579 Mdot
.518 .20605 Mdot
.518 .20639 Mdot
.518 .20649 Mdot
.518 .20704 Mdot
.518 .20736 Mdot
.518 .20741 Mdot
.518 .20751 Mdot
.518 .2078 Mdot
.518 .20787 Mdot
.518 .20905 Mdot
.518 .20953 Mdot
.518 .21051 Mdot
.518 .21051 Mdot
.518 .21055 Mdot
.518 .21063 Mdot
.518 .21064 Mdot
.518 .21066 Mdot
.518 .21076 Mdot
.518 .21076 Mdot
.518 .21078 Mdot
.518 .21081 Mdot
.518 .21083 Mdot
.518 .21105 Mdot
.518 .21133 Mdot
.518 .21134 Mdot
.518 .21136 Mdot
.518 .21144 Mdot
.518 .2117 Mdot
.518 .2117 Mdot
.518 .21178 Mdot
.518 .21192 Mdot
.518 .21196 Mdot
.518 .21202 Mdot
.518 .21221 Mdot
.518 .21241 Mdot
.518 .21247 Mdot
.518 .21248 Mdot
.518 .21265 Mdot
.518 .2128 Mdot
.518 .21298 Mdot
.518 .2131 Mdot
.518 .21318 Mdot
.518 .21327 Mdot
.518 .21337 Mdot
.518 .21436 Mdot
.518 .21505 Mdot
.518 .21544 Mdot
.518 .2161 Mdot
.518 .21649 Mdot
.518 .21707 Mdot
.518 .21718 Mdot
.518 .21733 Mdot
.518 .21734 Mdot
.518 .21817 Mdot
.518 .2184 Mdot
.518 .219 Mdot
.518 .21919 Mdot
.518 .21927 Mdot
.518 .21945 Mdot
.518 .22003 Mdot
.518 .22018 Mdot
.518 .22033 Mdot
.518 .22045 Mdot
.518 .22059 Mdot
.518 .22162 Mdot
.518 .22181 Mdot
.518 .22229 Mdot
.518 .22258 Mdot
.518 .22259 Mdot
.518 .22259 Mdot
.518 .22262 Mdot
.518 .2229 Mdot
.518 .22295 Mdot
.518 .22309 Mdot
.518 .22315 Mdot
.518 .22315 Mdot
.518 .22327 Mdot
.518 .22347 Mdot
.518 .22354 Mdot
.518 .22392 Mdot
.518 .2241 Mdot
.518 .22415 Mdot
.518 .22429 Mdot
.518 .22466 Mdot
.518 .22523 Mdot
.518 .22526 Mdot
.518 .22547 Mdot
.518 .22555 Mdot
.518 .22618 Mdot
.518 .2264 Mdot
.518 .22662 Mdot
.518 .22665 Mdot
.518 .22668 Mdot
.518 .2267 Mdot
.518 .22671 Mdot
.518 .22684 Mdot
.518 .22706 Mdot
.518 .22718 Mdot
.518 .22766 Mdot
.518 .22769 Mdot
.518 .22797 Mdot
.518 .22799 Mdot
.518 .22894 Mdot
.518 .22898 Mdot
.518 .22911 Mdot
.518 .22921 Mdot
.518 .22931 Mdot
.518 .22934 Mdot
.518 .22948 Mdot
.518 .22961 Mdot
.518 .23038 Mdot
.518 .23121 Mdot
.518 .2313 Mdot
.518 .23141 Mdot
.518 .23146 Mdot
.518 .23149 Mdot
.518 .23186 Mdot
.518 .23194 Mdot
.518 .23199 Mdot
.518 .2323 Mdot
.518 .23246 Mdot
.518 .23246 Mdot
.518 .23282 Mdot
.518 .23356 Mdot
.518 .23386 Mdot
.518 .23548 Mdot
.518 .23555 Mdot
.518 .23613 Mdot
.518 .23637 Mdot
.518 .23837 Mdot
.518 .23861 Mdot
.518 .23913 Mdot
.518 .24111 Mdot
.518 .24155 Mdot
.518 .24191 Mdot
.518 .24342 Mdot
.518 .24349 Mdot
.518 .2438 Mdot
.518 .24511 Mdot
.518 .24558 Mdot
.518 .2458 Mdot
.518 .2469 Mdot
.518 .24725 Mdot
.518 .24779 Mdot
.518 .24881 Mdot
.518 .2496 Mdot
.518 .24974 Mdot
.518 .24986 Mdot
.518 .25033 Mdot
.518 .2514 Mdot
.518 .25198 Mdot
.518 .25222 Mdot
.518 .25301 Mdot
.518 .25324 Mdot
.518 .25352 Mdot
.518 .25395 Mdot
.518 .2544 Mdot
.518 .25533 Mdot
.518 .25541 Mdot
.518 .25586 Mdot
.518 .25644 Mdot
.518 .25695 Mdot
.518 .25899 Mdot
.518 .25989 Mdot
.518 .26011 Mdot
.518 .26038 Mdot
.518 .2616 Mdot
.518 .26193 Mdot
.518 .26351 Mdot
.518 .26389 Mdot
.518 .26393 Mdot
.518 .26501 Mdot
.518 .26521 Mdot
.518 .26571 Mdot
.518 .26793 Mdot
.518 .26802 Mdot
.518 .26829 Mdot
.518 .26838 Mdot
.518 .26934 Mdot
.518 .27004 Mdot
.518 .27005 Mdot
.518 .27006 Mdot
.518 .27009 Mdot
.518 .27011 Mdot
.518 .27027 Mdot
.518 .27092 Mdot
.518 .27189 Mdot
.518 .27204 Mdot
.518 .27217 Mdot
.518 .27253 Mdot
.518 .27269 Mdot
.518 .27279 Mdot
.518 .27283 Mdot
.518 .27294 Mdot
.518 .27321 Mdot
.518 .27323 Mdot
.518 .27324 Mdot
.518 .27387 Mdot
.518 .27403 Mdot
.518 .27488 Mdot
.518 .275 Mdot
.518 .2751 Mdot
.518 .27523 Mdot
.518 .27536 Mdot
.518 .27586 Mdot
.518 .27601 Mdot
.518 .27625 Mdot
.518 .27678 Mdot
.518 .27698 Mdot
.518 .27773 Mdot
.518 .27774 Mdot
.518 .27798 Mdot
.518 .27852 Mdot
.518 .27952 Mdot
.518 .2799 Mdot
.518 .28169 Mdot
.518 .28179 Mdot
.518 .28187 Mdot
.518 .282 Mdot
.518 .28219 Mdot
.518 .28235 Mdot
.518 .28253 Mdot
.518 .28254 Mdot
.518 .28261 Mdot
.518 .28283 Mdot
.518 .28303 Mdot
.518 .28314 Mdot
.518 .28329 Mdot
.518 .28338 Mdot
.518 .28368 Mdot
.518 .28379 Mdot
.518 .28411 Mdot
.518 .28437 Mdot
.518 .28439 Mdot
.518 .28443 Mdot
.518 .28444 Mdot
.518 .28445 Mdot
.518 .28456 Mdot
.518 .28459 Mdot
.518 .2846 Mdot
.518 .28469 Mdot
.518 .28474 Mdot
.518 .28474 Mdot
.518 .28813 Mdot
.518 .28867 Mdot
.518 .28998 Mdot
.518 .29013 Mdot
.518 .29384 Mdot
.518 .29452 Mdot
.518 .29624 Mdot
.518 .29707 Mdot
.518 .29708 Mdot
.518 .29744 Mdot
.518 .29816 Mdot
.518 .29828 Mdot
.518 .29848 Mdot
.518 .29935 Mdot
.518 .2994 Mdot
.518 .29954 Mdot
.518 .2998 Mdot
.518 .3 Mdot
.518 .30197 Mdot
.518 .30379 Mdot
.518 .30409 Mdot
.518 .30444 Mdot
.518 .30451 Mdot
.518 .30474 Mdot
.518 .30497 Mdot
.518 .30529 Mdot
.518 .3054 Mdot
.518 .30767 Mdot
.518 .30772 Mdot
.518 .3084 Mdot
.518 .30847 Mdot
.518 .30963 Mdot
.518 .30992 Mdot
.518 .31045 Mdot
.518 .31078 Mdot
.518 .3108 Mdot
.518 .31084 Mdot
.518 .31092 Mdot
.518 .31099 Mdot
.518 .31151 Mdot
.518 .31206 Mdot
.518 .31361 Mdot
.518 .31379 Mdot
.518 .31431 Mdot
.518 .3144 Mdot
.518 .3158 Mdot
.518 .31671 Mdot
.518 .31704 Mdot
.518 .31718 Mdot
.518 .31762 Mdot
.518 .31857 Mdot
.518 .31874 Mdot
.518 .31924 Mdot
.518 .31954 Mdot
.518 .31954 Mdot
.518 .31968 Mdot
.518 .32003 Mdot
.518 .32016 Mdot
.518 .32087 Mdot
.518 .32093 Mdot
.518 .32094 Mdot
.518 .32096 Mdot
.518 .32169 Mdot
.518 .32289 Mdot
.518 .32337 Mdot
.518 .32595 Mdot
.518 .32631 Mdot
.518 .32661 Mdot
.518 .32699 Mdot
.518 .32739 Mdot
.518 .32885 Mdot
.518 .3293 Mdot
.518 .3295 Mdot
.518 .32999 Mdot
.518 .33152 Mdot
.518 .33212 Mdot
.518 .33423 Mdot
.518 .33427 Mdot
.518 .33465 Mdot
.518 .33493 Mdot
.518 .33643 Mdot
.518 .33745 Mdot
.518 .33914 Mdot
.518 .34016 Mdot
.518 .34195 Mdot
.518 .34455 Mdot
.518 .3448 Mdot
.518 .34505 Mdot
.518 .34525 Mdot
.518 .34556 Mdot
.518 .34604 Mdot
.518 .34643 Mdot
.518 .34687 Mdot
.518 .3469 Mdot
.518 .34706 Mdot
.518 .34759 Mdot
.518 .34809 Mdot
.518 .34825 Mdot
.518 .34834 Mdot
.518 .34871 Mdot
.518 .34892 Mdot
.518 .34894 Mdot
.518 .34962 Mdot
.518 .34982 Mdot
.518 .34989 Mdot
.518 .34991 Mdot
.518 .35064 Mdot
.518 .35122 Mdot
.518 .35128 Mdot
.518 .35136 Mdot
.518 .3514 Mdot
.518 .35141 Mdot
.518 .35167 Mdot
.518 .35173 Mdot
.518 .35176 Mdot
.518 .35197 Mdot
.518 .35208 Mdot
.518 .35208 Mdot
.518 .35467 Mdot
.518 .35595 Mdot
.518 .35909 Mdot
.518 .35927 Mdot
.518 .36004 Mdot
.518 .36032 Mdot
.518 .36045 Mdot
.518 .36129 Mdot
.518 .36277 Mdot
.518 .36303 Mdot
.518 .36395 Mdot
.518 .36464 Mdot
.518 .36527 Mdot
.518 .36577 Mdot
.518 .36636 Mdot
.518 .36906 Mdot
.518 .37003 Mdot
.518 .37022 Mdot
.518 .37088 Mdot
.518 .37228 Mdot
.518 .37241 Mdot
.518 .37327 Mdot
.518 .37327 Mdot
.518 .37328 Mdot
.518 .37329 Mdot
.518 .3733 Mdot
.518 .37338 Mdot
.518 .37369 Mdot
.518 .37416 Mdot
.518 .3743 Mdot
.518 .37447 Mdot
.518 .37459 Mdot
.518 .37467 Mdot
.518 .37479 Mdot
.518 .37481 Mdot
.518 .37481 Mdot
.518 .37511 Mdot
.518 .37559 Mdot
.518 .37565 Mdot
.518 .37569 Mdot
.518 .37575 Mdot
.518 .37582 Mdot
.518 .37605 Mdot
.518 .37623 Mdot
.518 .37658 Mdot
.518 .37693 Mdot
.518 .37704 Mdot
.518 .3773 Mdot
.518 .37776 Mdot
.518 .37793 Mdot
.518 .37876 Mdot
.518 .37881 Mdot
.518 .37884 Mdot
.518 .37899 Mdot
.518 .37906 Mdot
.518 .37914 Mdot
.518 .37915 Mdot
.518 .37918 Mdot
.518 .37928 Mdot
.518 .37937 Mdot
.518 .37949 Mdot
.518 .37953 Mdot
.518 .37971 Mdot
.518 .37986 Mdot
.518 .37997 Mdot
.518 .37999 Mdot
.518 .38 Mdot
.518 .38001 Mdot
.518 .38001 Mdot
.518 .38006 Mdot
.518 .38007 Mdot
.518 .38008 Mdot
.518 .38012 Mdot
.518 .38014 Mdot
.518 .38014 Mdot
.518 .47365 Mdot
.518 .47365 Mdot
.518 .47366 Mdot
.518 .47368 Mdot
.518 .47368 Mdot
.518 .47369 Mdot
.518 .47371 Mdot
.518 .47372 Mdot
.518 .47372 Mdot
.518 .47373 Mdot
.518 .47373 Mdot
.518 .47379 Mdot
.518 .47386 Mdot
.518 .47395 Mdot
.518 .47397 Mdot
.518 .47403 Mdot
.518 .47408 Mdot
.518 .47413 Mdot
.518 .47414 Mdot
.518 .47414 Mdot
.518 .47418 Mdot
.518 .47422 Mdot
.518 .47429 Mdot
.518 .47431 Mdot
.518 .47433 Mdot
.518 .47474 Mdot
.518 .47482 Mdot
.518 .47505 Mdot
.518 .47517 Mdot
.518 .47523 Mdot
.518 .4754 Mdot
.518 .47557 Mdot
.518 .47566 Mdot
.518 .47578 Mdot
.518 .47581 Mdot
.518 .47584 Mdot
.518 .47586 Mdot
.518 .47589 Mdot
.518 .47612 Mdot
.518 .47627 Mdot
.518 .47627 Mdot
.518 .47627 Mdot
.518 .47634 Mdot
.518 .47637 Mdot
.518 .47643 Mdot
.518 .47652 Mdot
.518 .47658 Mdot
.518 .47681 Mdot
.518 .47696 Mdot
.518 .477 Mdot
.518 .477 Mdot
.518 .47701 Mdot
.518 .47701 Mdot
.518 .47701 Mdot
.518 .47743 Mdot
.518 .47749 Mdot
.518 .47817 Mdot
.518 .47849 Mdot
.518 .47858 Mdot
.518 .47904 Mdot
.518 .48033 Mdot
.518 .48061 Mdot
.518 .48085 Mdot
.518 .48115 Mdot
.518 .48147 Mdot
.518 .48191 Mdot
.518 .48203 Mdot
.518 .48272 Mdot
.518 .48312 Mdot
.518 .48318 Mdot
.518 .48331 Mdot
.518 .48367 Mdot
.518 .48375 Mdot
.518 .48521 Mdot
.518 .4858 Mdot
.518 .48699 Mdot
.518 .48699 Mdot
.518 .48704 Mdot
.518 .48713 Mdot
.518 .48715 Mdot
.518 .48718 Mdot
.518 .48729 Mdot
.518 .4873 Mdot
.518 .48732 Mdot
.518 .48735 Mdot
.518 .48738 Mdot
.518 .48765 Mdot
.518 .48798 Mdot
.518 .48799 Mdot
.518 .48802 Mdot
.518 .48811 Mdot
.518 .48842 Mdot
.518 .48843 Mdot
.518 .48852 Mdot
.518 .48869 Mdot
.518 .48873 Mdot
.518 .48881 Mdot
.518 .48903 Mdot
.518 .48927 Mdot
.518 .48934 Mdot
.518 .48936 Mdot
.518 .48955 Mdot
.518 .48973 Mdot
.518 .48995 Mdot
.518 .49009 Mdot
.518 .49018 Mdot
.518 .49029 Mdot
.518 .4904 Mdot
.518 .49156 Mdot
.518 .49236 Mdot
.518 .49281 Mdot
.518 .49356 Mdot
.518 .49401 Mdot
.518 .49467 Mdot
.518 .49479 Mdot
.518 .49496 Mdot
.518 .49497 Mdot
.518 .4959 Mdot
.518 .49616 Mdot
.518 .49682 Mdot
.518 .49703 Mdot
.518 .49712 Mdot
.518 .49732 Mdot
.518 .49795 Mdot
.518 .49812 Mdot
.518 .49828 Mdot
.518 .49841 Mdot
.518 .49857 Mdot
.518 .49967 Mdot
.518 .49988 Mdot
.518 .50039 Mdot
.518 .5007 Mdot
.518 .50071 Mdot
.518 .50071 Mdot
.518 .50074 Mdot
.518 .50104 Mdot
.518 .50109 Mdot
.518 .50124 Mdot
.518 .5013 Mdot
.518 .5013 Mdot
.518 .50143 Mdot
.518 .50164 Mdot
.518 .50171 Mdot
.518 .50211 Mdot
.518 .5023 Mdot
.518 .50235 Mdot
.518 .50249 Mdot
.518 .50288 Mdot
.518 .50347 Mdot
.518 .5035 Mdot
.518 .50372 Mdot
.518 .5038 Mdot
.518 .50444 Mdot
.518 .50467 Mdot
.518 .50489 Mdot
.518 .50492 Mdot
.518 .50495 Mdot
.518 .50497 Mdot
.518 .50498 Mdot
.518 .50511 Mdot
.518 .50533 Mdot
.518 .50545 Mdot
.518 .50593 Mdot
.518 .50596 Mdot
.518 .50624 Mdot
.518 .50626 Mdot
.518 .5072 Mdot
.518 .50724 Mdot
.518 .50737 Mdot
.518 .50747 Mdot
.518 .50756 Mdot
.518 .50759 Mdot
.518 .50773 Mdot
.518 .50786 Mdot
.518 .5086 Mdot
.518 .5094 Mdot
.518 .50949 Mdot
.518 .50959 Mdot
.518 .50965 Mdot
.518 .50967 Mdot
.518 .51002 Mdot
.518 .5101 Mdot
.518 .51015 Mdot
.518 .51044 Mdot
.518 .51059 Mdot
.518 .51059 Mdot
.518 .51093 Mdot
.518 .51162 Mdot
.518 .51189 Mdot
.518 .51338 Mdot
.518 .51343 Mdot
.518 .51396 Mdot
.518 .51417 Mdot
.518 .51551 Mdot
.518 .51551 Mdot
.518 .51553 Mdot
.518 .51557 Mdot
.518 .51557 Mdot
.518 .51558 Mdot
.518 .51563 Mdot
.518 .51563 Mdot
.518 .51564 Mdot
.518 .51565 Mdot
.518 .51566 Mdot
.518 .51576 Mdot
.518 .51589 Mdot
.518 .51593 Mdot
.518 .51605 Mdot
.518 .51608 Mdot
.518 .51614 Mdot
.518 .51618 Mdot
.518 .51626 Mdot
.518 .51635 Mdot
.518 .51638 Mdot
.518 .51638 Mdot
.518 .51645 Mdot
.518 .51651 Mdot
.518 .51659 Mdot
.518 .51664 Mdot
.518 .51667 Mdot
.518 .51671 Mdot
.518 .51741 Mdot
.518 .51756 Mdot
.518 .51795 Mdot
.518 .51816 Mdot
.518 .51825 Mdot
.518 .51826 Mdot
.518 .51855 Mdot
.518 .51863 Mdot
.518 .51883 Mdot
.518 .51893 Mdot
.518 .51899 Mdot
.518 .51918 Mdot
.518 .51923 Mdot
.518 .51928 Mdot
.518 .51932 Mdot
.518 .51936 Mdot
.518 .51976 Mdot
.518 .52 Mdot
.518 .52 Mdot
.518 .52001 Mdot
.518 .52011 Mdot
.518 .52016 Mdot
.518 .52017 Mdot
.518 .52021 Mdot
.518 .52027 Mdot
.518 .52041 Mdot
.518 .52046 Mdot
.518 .52052 Mdot
.518 .52089 Mdot
.518 .52114 Mdot
.518 .5212 Mdot
.518 .52121 Mdot
.518 .52122 Mdot
.518 .52123 Mdot
.518 .52123 Mdot
.518 .5215 Mdot
.518 .52186 Mdot
.518 .5219 Mdot
.518 .522 Mdot
.518 .52204 Mdot
.518 .52289 Mdot
.518 .52308 Mdot
.518 .52315 Mdot
.518 .52356 Mdot
.518 .52357 Mdot
.518 .52372 Mdot
.518 .52432 Mdot
.518 .52444 Mdot
.518 .5249 Mdot
.518 .525 Mdot
.518 .52509 Mdot
.518 .52543 Mdot
.518 .52619 Mdot
.518 .52639 Mdot
.518 .5266 Mdot
.518 .52677 Mdot
.518 .5268 Mdot
.518 .52715 Mdot
.518 .52731 Mdot
.518 .52748 Mdot
.518 .52758 Mdot
.518 .52767 Mdot
.518 .52796 Mdot
.518 .52805 Mdot
.518 .52826 Mdot
.518 .52866 Mdot
.518 .52884 Mdot
.518 .52888 Mdot
.518 .52893 Mdot
.518 .52922 Mdot
.518 .5296 Mdot
.518 .5298 Mdot
.518 .52993 Mdot
.518 .53034 Mdot
.518 .53042 Mdot
.518 .53059 Mdot
.518 .53107 Mdot
.518 .53118 Mdot
.518 .53121 Mdot
.518 .53176 Mdot
.518 .53189 Mdot
.518 .53206 Mdot
.518 .53277 Mdot
.518 .53296 Mdot
.518 .53305 Mdot
.518 .53378 Mdot
.518 .53386 Mdot
.518 .53407 Mdot
.518 .5341 Mdot
.518 .53468 Mdot
.518 .53479 Mdot
.518 .53506 Mdot
.518 .53519 Mdot
.518 .53519 Mdot
.518 .53525 Mdot
.518 .53536 Mdot
.518 .53538 Mdot
.518 .53541 Mdot
.518 .53554 Mdot
.518 .53555 Mdot
.518 .53557 Mdot
.518 .53561 Mdot
.518 .53564 Mdot
.518 .53594 Mdot
.518 .53621 Mdot
.518 .53626 Mdot
.518 .53631 Mdot
.518 .53632 Mdot
.518 .53636 Mdot
.518 .53639 Mdot
.518 .53644 Mdot
.518 .53645 Mdot
.518 .53679 Mdot
.518 .5368 Mdot
.518 .5369 Mdot
.518 .53691 Mdot
.518 .53708 Mdot
.518 .53713 Mdot
.518 .5372 Mdot
.518 .53725 Mdot
.518 .53725 Mdot
.518 .53726 Mdot
.518 .53727 Mdot
.518 .53728 Mdot
.518 .53736 Mdot
.518 .53744 Mdot
.518 .53766 Mdot
.518 .53769 Mdot
.518 .53777 Mdot
.518 .53778 Mdot
.518 .53798 Mdot
.518 .53811 Mdot
.518 .53816 Mdot
.518 .53818 Mdot
.518 .53824 Mdot
.518 .53838 Mdot
.518 .5384 Mdot
.518 .53847 Mdot
.518 .53852 Mdot
.518 .53852 Mdot
.518 .53854 Mdot
.518 .53859 Mdot
.518 .53861 Mdot
.518 .53871 Mdot
.518 .53872 Mdot
.518 .53872 Mdot
.518 .53872 Mdot
.518 .53882 Mdot
.518 .53899 Mdot
.518 .53906 Mdot
.518 .53942 Mdot
.518 .53947 Mdot
.518 .53951 Mdot
.518 .53957 Mdot
.518 .53962 Mdot
.518 .53983 Mdot
.518 .53989 Mdot
.518 .53992 Mdot
.518 .53998 Mdot
.518 .5402 Mdot
.518 .54028 Mdot
.518 .54057 Mdot
.518 .54057 Mdot
.518 .54062 Mdot
.518 .54066 Mdot
.518 .54087 Mdot
.518 .54101 Mdot
.518 .54123 Mdot
.518 .54137 Mdot
.518 .54161 Mdot
.518 .54196 Mdot
.518 .54199 Mdot
.518 .54203 Mdot
.518 .54205 Mdot
.518 .5421 Mdot
.518 .54216 Mdot
.518 .54221 Mdot
.518 .54227 Mdot
.518 .54227 Mdot
.518 .5423 Mdot
.518 .54237 Mdot
.518 .54243 Mdot
.518 .54245 Mdot
.518 .54247 Mdot
.518 .54251 Mdot
.518 .54254 Mdot
.518 .54254 Mdot
.518 .54263 Mdot
.518 .54266 Mdot
.518 .54267 Mdot
.518 .54267 Mdot
.518 .54277 Mdot
.518 .54285 Mdot
.518 .54285 Mdot
.518 .54286 Mdot
.518 .54287 Mdot
.518 .54287 Mdot
.518 .54291 Mdot
.518 .54291 Mdot
.518 .54292 Mdot
.518 .54295 Mdot
.518 .54296 Mdot
.518 .54296 Mdot
.518 .5433 Mdot
.518 .54347 Mdot
.518 .54388 Mdot
.518 .5439 Mdot
.518 .544 Mdot
.518 .54404 Mdot
.518 .54405 Mdot
.518 .54416 Mdot
.518 .54435 Mdot
.518 .54439 Mdot
.518 .54451 Mdot
.518 .54459 Mdot
.518 .54468 Mdot
.518 .54474 Mdot
.518 .54482 Mdot
.518 .54516 Mdot
.518 .54529 Mdot
.518 .54531 Mdot
.518 .5454 Mdot
.518 .54558 Mdot
.518 .54559 Mdot
.518 .5457 Mdot
.518 .5457 Mdot
.518 .5457 Mdot
.518 .5457 Mdot
.518 .54571 Mdot
.518 .54572 Mdot
.518 .54576 Mdot
.518 .54582 Mdot
.518 .54583 Mdot
.518 .54585 Mdot
.518 .54587 Mdot
.518 .54588 Mdot
.518 .5459 Mdot
.518 .5459 Mdot
.518 .5459 Mdot
.518 .54594 Mdot
.518 .546 Mdot
.518 .546 Mdot
.518 .54601 Mdot
.518 .54602 Mdot
.518 .54603 Mdot
.518 .54606 Mdot
.518 .54608 Mdot
.518 .54612 Mdot
.518 .54617 Mdot
.518 .54618 Mdot
.518 .54621 Mdot
.518 .54627 Mdot
.518 .5463 Mdot
.518 .5464 Mdot
.518 .54641 Mdot
.518 .54641 Mdot
.518 .54643 Mdot
.518 .54644 Mdot
.518 .54645 Mdot
.518 .54645 Mdot
.518 .54645 Mdot
.518 .54647 Mdot
.518 .54648 Mdot
.518 .54649 Mdot
.518 .5465 Mdot
.518 .54652 Mdot
.518 .54654 Mdot
.518 .54655 Mdot
.518 .54656 Mdot
.518 .54656 Mdot
.518 .54656 Mdot
.518 .54656 Mdot
.518 .54657 Mdot
.518 .54657 Mdot
.518 .54657 Mdot
.518 .54657 Mdot
.518 .54658 Mdot
.518 .54658 Mdot
.518 .54658 Mdot
.52 .19943 Mdot
.52 .19943 Mdot
.52 .19943 Mdot
.52 .19946 Mdot
.52 .19947 Mdot
.52 .19949 Mdot
.52 .19949 Mdot
.52 .19958 Mdot
.52 .19958 Mdot
.52 .19959 Mdot
.52 .19963 Mdot
.52 .19965 Mdot
.52 .19967 Mdot
.52 .19975 Mdot
.52 .19976 Mdot
.52 .19987 Mdot
.52 .2 Mdot
.52 .20007 Mdot
.52 .20012 Mdot
.52 .20016 Mdot
.52 .20044 Mdot
.52 .20061 Mdot
.52 .20067 Mdot
.52 .20076 Mdot
.52 .20089 Mdot
.52 .20113 Mdot
.52 .20165 Mdot
.52 .20168 Mdot
.52 .20175 Mdot
.52 .20183 Mdot
.52 .20193 Mdot
.52 .2021 Mdot
.52 .2022 Mdot
.52 .20235 Mdot
.52 .20237 Mdot
.52 .20239 Mdot
.52 .20245 Mdot
.52 .20253 Mdot
.52 .20256 Mdot
.52 .20278 Mdot
.52 .20301 Mdot
.52 .20314 Mdot
.52 .20363 Mdot
.52 .20383 Mdot
.52 .20408 Mdot
.52 .20411 Mdot
.52 .20441 Mdot
.52 .20444 Mdot
.52 .20469 Mdot
.52 .20576 Mdot
.52 .20584 Mdot
.52 .20586 Mdot
.52 .20614 Mdot
.52 .20665 Mdot
.52 .20674 Mdot
.52 .2069 Mdot
.52 .20691 Mdot
.52 .20697 Mdot
.52 .20737 Mdot
.52 .20749 Mdot
.52 .20752 Mdot
.52 .20772 Mdot
.52 .20773 Mdot
.52 .20774 Mdot
.52 .20775 Mdot
.52 .20788 Mdot
.52 .20795 Mdot
.52 .20796 Mdot
.52 .20801 Mdot
.52 .20804 Mdot
.52 .20814 Mdot
.52 .20848 Mdot
.52 .20848 Mdot
.52 .20849 Mdot
.52 .20859 Mdot
.52 .20868 Mdot
.52 .20879 Mdot
.52 .2088 Mdot
.52 .20889 Mdot
.52 .20931 Mdot
.52 .20937 Mdot
.52 .20973 Mdot
.52 .20977 Mdot
.52 .20993 Mdot
.52 .21021 Mdot
.52 .21033 Mdot
.52 .21054 Mdot
.52 .21061 Mdot
.52 .21069 Mdot
.52 .211 Mdot
.52 .21123 Mdot
.52 .21128 Mdot
.52 .2114 Mdot
.52 .21144 Mdot
.52 .21228 Mdot
.52 .21234 Mdot
.52 .2125 Mdot
.52 .21301 Mdot
.52 .21318 Mdot
.52 .21395 Mdot
.52 .21405 Mdot
.52 .21409 Mdot
.52 .21419 Mdot
.52 .21424 Mdot
.52 .2143 Mdot
.52 .21438 Mdot
.52 .21441 Mdot
.52 .21465 Mdot
.52 .21494 Mdot
.52 .21577 Mdot
.52 .21656 Mdot
.52 .21723 Mdot
.52 .21739 Mdot
.52 .21766 Mdot
.52 .2181 Mdot
.52 .2182 Mdot
.52 .21842 Mdot
.52 .21862 Mdot
.52 .21874 Mdot
.52 .21875 Mdot
.52 .21906 Mdot
.52 .21907 Mdot
.52 .2192 Mdot
.52 .21948 Mdot
.52 .21965 Mdot
.52 .21971 Mdot
.52 .22055 Mdot
.52 .22074 Mdot
.52 .22077 Mdot
.52 .22094 Mdot
.52 .22145 Mdot
.52 .22155 Mdot
.52 .22192 Mdot
.52 .22201 Mdot
.52 .22207 Mdot
.52 .22208 Mdot
.52 .22223 Mdot
.52 .22232 Mdot
.52 .22248 Mdot
.52 .22272 Mdot
.52 .22396 Mdot
.52 .22421 Mdot
.52 .22466 Mdot
.52 .22473 Mdot
.52 .22481 Mdot
.52 .22495 Mdot
.52 .22523 Mdot
.52 .22549 Mdot
.52 .22576 Mdot
.52 .2259 Mdot
.52 .22604 Mdot
.52 .22605 Mdot
.52 .22651 Mdot
.52 .22671 Mdot
.52 .22711 Mdot
.52 .22737 Mdot
.52 .2275 Mdot
.52 .22795 Mdot
.52 .22807 Mdot
.52 .22852 Mdot
.52 .22873 Mdot
.52 .22904 Mdot
.52 .22958 Mdot
.52 .23074 Mdot
.52 .23087 Mdot
.52 .23105 Mdot
.52 .23134 Mdot
.52 .23194 Mdot
.52 .23205 Mdot
.52 .23213 Mdot
.52 .23264 Mdot
.52 .2328 Mdot
.52 .23303 Mdot
.52 .23374 Mdot
.52 .23436 Mdot
.52 .23454 Mdot
.52 .23532 Mdot
.52 .23589 Mdot
.52 .23603 Mdot
.52 .23627 Mdot
.52 .23661 Mdot
.52 .23761 Mdot
.52 .23784 Mdot
.52 .23801 Mdot
.52 .23838 Mdot
.52 .23844 Mdot
.52 .2389 Mdot
.52 .23897 Mdot
.52 .2393 Mdot
.52 .23965 Mdot
.52 .23972 Mdot
.52 .23976 Mdot
.52 .23978 Mdot
.52 .23986 Mdot
.52 .23997 Mdot
.52 .24127 Mdot
.52 .24171 Mdot
.52 .24184 Mdot
.52 .24207 Mdot
.52 .2421 Mdot
.52 .24243 Mdot
.52 .24252 Mdot
.52 .24282 Mdot
.52 .24302 Mdot
.52 .24303 Mdot
.52 .24308 Mdot
.52 .24312 Mdot
.52 .24405 Mdot
.52 .2442 Mdot
.52 .2443 Mdot
.52 .2445 Mdot
.52 .24474 Mdot
.52 .24502 Mdot
.52 .24659 Mdot
.52 .24684 Mdot
.52 .24691 Mdot
.52 .24767 Mdot
.52 .24809 Mdot
.52 .24848 Mdot
.52 .24884 Mdot
.52 .24913 Mdot
.52 .2505 Mdot
.52 .25057 Mdot
.52 .25188 Mdot
.52 .25197 Mdot
.52 .25239 Mdot
.52 .25459 Mdot
.52 .25539 Mdot
.52 .25555 Mdot
.52 .25774 Mdot
.52 .25804 Mdot
.52 .25816 Mdot
.52 .25903 Mdot
.52 .25921 Mdot
.52 .26076 Mdot
.52 .26082 Mdot
.52 .26095 Mdot
.52 .26137 Mdot
.52 .26208 Mdot
.52 .26222 Mdot
.52 .26286 Mdot
.52 .26332 Mdot
.52 .26369 Mdot
.52 .2652 Mdot
.52 .26535 Mdot
.52 .26586 Mdot
.52 .26593 Mdot
.52 .26667 Mdot
.52 .26795 Mdot
.52 .26905 Mdot
.52 .26915 Mdot
.52 .26933 Mdot
.52 .26963 Mdot
.52 .26978 Mdot
.52 .27012 Mdot
.52 .27012 Mdot
.52 .27023 Mdot
.52 .27034 Mdot
.52 .27054 Mdot
.52 .27074 Mdot
.52 .27105 Mdot
.52 .27117 Mdot
.52 .27171 Mdot
.52 .27268 Mdot
.52 .273 Mdot
.52 .27307 Mdot
.52 .27319 Mdot
.52 .2732 Mdot
.52 .27324 Mdot
.52 .27362 Mdot
.52 .2737 Mdot
.52 .27412 Mdot
.52 .27426 Mdot
.52 .27428 Mdot
.52 .27444 Mdot
.52 .27515 Mdot
.52 .2752 Mdot
.52 .2757 Mdot
.52 .27598 Mdot
.52 .27692 Mdot
.52 .27731 Mdot
.52 .27866 Mdot
.52 .27944 Mdot
.52 .27972 Mdot
.52 .27996 Mdot
.52 .27999 Mdot
.52 .28013 Mdot
.52 .28018 Mdot
.52 .28028 Mdot
.52 .28032 Mdot
.52 .28041 Mdot
.52 .28119 Mdot
.52 .28136 Mdot
.52 .2819 Mdot
.52 .28206 Mdot
.52 .28303 Mdot
.52 .28307 Mdot
.52 .2832 Mdot
.52 .28326 Mdot
.52 .28352 Mdot
.52 .28395 Mdot
.52 .28403 Mdot
.52 .28441 Mdot
.52 .28473 Mdot
.52 .28491 Mdot
.52 .2854 Mdot
.52 .28547 Mdot
.52 .28597 Mdot
.52 .28609 Mdot
.52 .28623 Mdot
.52 .28646 Mdot
.52 .28648 Mdot
.52 .28648 Mdot
.52 .28704 Mdot
.52 .28708 Mdot
.52 .28714 Mdot
.52 .28715 Mdot
.52 .28725 Mdot
.52 .28742 Mdot
.52 .28744 Mdot
.52 .28745 Mdot
.52 .28792 Mdot
.52 .28846 Mdot
.52 .28878 Mdot
.52 .29006 Mdot
.52 .29185 Mdot
.52 .29226 Mdot
.52 .29369 Mdot
.52 .29533 Mdot
.52 .29585 Mdot
.52 .29624 Mdot
.52 .29742 Mdot
.52 .29762 Mdot
.52 .29787 Mdot
.52 .29928 Mdot
.52 .29996 Mdot
.52 .30038 Mdot
.52 .30069 Mdot
.52 .30344 Mdot
.52 .30475 Mdot
.52 .30549 Mdot
.52 .30601 Mdot
.52 .30707 Mdot
.52 .30736 Mdot
.52 .30846 Mdot
.52 .30878 Mdot
.52 .3094 Mdot
.52 .31038 Mdot
.52 .31087 Mdot
.52 .312 Mdot
.52 .31201 Mdot
.52 .31237 Mdot
.52 .3127 Mdot
.52 .31336 Mdot
.52 .31401 Mdot
.52 .3147 Mdot
.52 .31504 Mdot
.52 .31523 Mdot
.52 .3154 Mdot
.52 .31652 Mdot
.52 .31715 Mdot
.52 .32023 Mdot
.52 .32085 Mdot
.52 .32124 Mdot
.52 .32146 Mdot
.52 .32183 Mdot
.52 .32187 Mdot
.52 .32201 Mdot
.52 .32225 Mdot
.52 .32317 Mdot
.52 .32343 Mdot
.52 .32472 Mdot
.52 .32514 Mdot
.52 .3252 Mdot
.52 .32571 Mdot
.52 .32784 Mdot
.52 .328 Mdot
.52 .32841 Mdot
.52 .32913 Mdot
.52 .32948 Mdot
.52 .3295 Mdot
.52 .33027 Mdot
.52 .33031 Mdot
.52 .33061 Mdot
.52 .33112 Mdot
.52 .33169 Mdot
.52 .33196 Mdot
.52 .33307 Mdot
.52 .33377 Mdot
.52 .33418 Mdot
.52 .33591 Mdot
.52 .33797 Mdot
.52 .34011 Mdot
.52 .34086 Mdot
.52 .34149 Mdot
.52 .34158 Mdot
.52 .34178 Mdot
.52 .34195 Mdot
.52 .34207 Mdot
.52 .34234 Mdot
.52 .34245 Mdot
.52 .34269 Mdot
.52 .34471 Mdot
.52 .34516 Mdot
.52 .34652 Mdot
.52 .34692 Mdot
.52 .34708 Mdot
.52 .34931 Mdot
.52 .3494 Mdot
.52 .34971 Mdot
.52 .34987 Mdot
.52 .35047 Mdot
.52 .35128 Mdot
.52 .35149 Mdot
.52 .35169 Mdot
.52 .35223 Mdot
.52 .35257 Mdot
.52 .35331 Mdot
.52 .35371 Mdot
.52 .35383 Mdot
.52 .3548 Mdot
.52 .35495 Mdot
.52 .35606 Mdot
.52 .35629 Mdot
.52 .35633 Mdot
.52 .35662 Mdot
.52 .35686 Mdot
.52 .35712 Mdot
.52 .35715 Mdot
.52 .35716 Mdot
.52 .35807 Mdot
.52 .35833 Mdot
.52 .35841 Mdot
.52 .35855 Mdot
.52 .35857 Mdot
.52 .35877 Mdot
.52 .35912 Mdot
.52 .35912 Mdot
.52 .35916 Mdot
.52 .35918 Mdot
.52 .35973 Mdot
.52 .35982 Mdot
.52 .36013 Mdot
.52 .3612 Mdot
.52 .36135 Mdot
.52 .36139 Mdot
.52 .36182 Mdot
.52 .36206 Mdot
.52 .36341 Mdot
.52 .36417 Mdot
.52 .36422 Mdot
.52 .36445 Mdot
.52 .36731 Mdot
.52 .36798 Mdot
.52 .36808 Mdot
.52 .36887 Mdot
.52 .36897 Mdot
.52 .36962 Mdot
.52 .37018 Mdot
.52 .37148 Mdot
.52 .37185 Mdot
.52 .37248 Mdot
.52 .37306 Mdot
.52 .37315 Mdot
.52 .37337 Mdot
.52 .37354 Mdot
.52 .37359 Mdot
.52 .37364 Mdot
.52 .37404 Mdot
.52 .3743 Mdot
.52 .37476 Mdot
.52 .37503 Mdot
.52 .37525 Mdot
.52 .37545 Mdot
.52 .37552 Mdot
.52 .37694 Mdot
.52 .37757 Mdot
.52 .37793 Mdot
.52 .37819 Mdot
.52 .37834 Mdot
.52 .37881 Mdot
.52 .37957 Mdot
.52 .37968 Mdot
.52 .37979 Mdot
.52 .37999 Mdot
.52 .38034 Mdot
.52 .38064 Mdot
.52 .38067 Mdot
.52 .38089 Mdot
.52 .38095 Mdot
.52 .38101 Mdot
.52 .38111 Mdot
.52 .38112 Mdot
.52 .38112 Mdot
.52 .38137 Mdot
.52 .38139 Mdot
.52 .38142 Mdot
.52 .38146 Mdot
.52 .38154 Mdot
.52 .38155 Mdot
.52 .38155 Mdot
.52 .47303 Mdot
.52 .47303 Mdot
.52 .47304 Mdot
.52 .47307 Mdot
.52 .4731 Mdot
.52 .47311 Mdot
.52 .47312 Mdot
.52 .47324 Mdot
.52 .47325 Mdot
.52 .47325 Mdot
.52 .4733 Mdot
.52 .47333 Mdot
.52 .47336 Mdot
.52 .47347 Mdot
.52 .47348 Mdot
.52 .47363 Mdot
.52 .47381 Mdot
.52 .4739 Mdot
.52 .47396 Mdot
.52 .47401 Mdot
.52 .47438 Mdot
.52 .47462 Mdot
.52 .47469 Mdot
.52 .47482 Mdot
.52 .475 Mdot
.52 .4753 Mdot
.52 .476 Mdot
.52 .47603 Mdot
.52 .47613 Mdot
.52 .47624 Mdot
.52 .47637 Mdot
.52 .47659 Mdot
.52 .47672 Mdot
.52 .47691 Mdot
.52 .47694 Mdot
.52 .47696 Mdot
.52 .47704 Mdot
.52 .47715 Mdot
.52 .47719 Mdot
.52 .47747 Mdot
.52 .47778 Mdot
.52 .47795 Mdot
.52 .47858 Mdot
.52 .47885 Mdot
.52 .47916 Mdot
.52 .47921 Mdot
.52 .47959 Mdot
.52 .47963 Mdot
.52 .47995 Mdot
.52 .48131 Mdot
.52 .48142 Mdot
.52 .48144 Mdot
.52 .4818 Mdot
.52 .48243 Mdot
.52 .48255 Mdot
.52 .48275 Mdot
.52 .48277 Mdot
.52 .48284 Mdot
.52 .48334 Mdot
.52 .48348 Mdot
.52 .48353 Mdot
.52 .48378 Mdot
.52 .48379 Mdot
.52 .48381 Mdot
.52 .48381 Mdot
.52 .48397 Mdot
.52 .48407 Mdot
.52 .48407 Mdot
.52 .48414 Mdot
.52 .48417 Mdot
.52 .4843 Mdot
.52 .48472 Mdot
.52 .48472 Mdot
.52 .48474 Mdot
.52 .48486 Mdot
.52 .48497 Mdot
.52 .4851 Mdot
.52 .48512 Mdot
.52 .48523 Mdot
.52 .48574 Mdot
.52 .48581 Mdot
.52 .48625 Mdot
.52 .48631 Mdot
.52 .4865 Mdot
.52 .48683 Mdot
.52 .48699 Mdot
.52 .48723 Mdot
.52 .48733 Mdot
.52 .48742 Mdot
.52 .48779 Mdot
.52 .48807 Mdot
.52 .48814 Mdot
.52 .48828 Mdot
.52 .48832 Mdot
.52 .48933 Mdot
.52 .4894 Mdot
.52 .48958 Mdot
.52 .49019 Mdot
.52 .49039 Mdot
.52 .4913 Mdot
.52 .4914 Mdot
.52 .49146 Mdot
.52 .49158 Mdot
.52 .49163 Mdot
.52 .49171 Mdot
.52 .49179 Mdot
.52 .49183 Mdot
.52 .49211 Mdot
.52 .49245 Mdot
.52 .4934 Mdot
.52 .4943 Mdot
.52 .49506 Mdot
.52 .49524 Mdot
.52 .49555 Mdot
.52 .49603 Mdot
.52 .49615 Mdot
.52 .49639 Mdot
.52 .49661 Mdot
.52 .49674 Mdot
.52 .49676 Mdot
.52 .4971 Mdot
.52 .49711 Mdot
.52 .49726 Mdot
.52 .49757 Mdot
.52 .49775 Mdot
.52 .49781 Mdot
.52 .49873 Mdot
.52 .49895 Mdot
.52 .49897 Mdot
.52 .49915 Mdot
.52 .4997 Mdot
.52 .49982 Mdot
.52 .50021 Mdot
.52 .50031 Mdot
.52 .50037 Mdot
.52 .50039 Mdot
.52 .50054 Mdot
.52 .50064 Mdot
.52 .5008 Mdot
.52 .50106 Mdot
.52 .50237 Mdot
.52 .50263 Mdot
.52 .5031 Mdot
.52 .50317 Mdot
.52 .50325 Mdot
.52 .5034 Mdot
.52 .50368 Mdot
.52 .50396 Mdot
.52 .50423 Mdot
.52 .50437 Mdot
.52 .50452 Mdot
.52 .50452 Mdot
.52 .50499 Mdot
.52 .50519 Mdot
.52 .5056 Mdot
.52 .50586 Mdot
.52 .50599 Mdot
.52 .50645 Mdot
.52 .50656 Mdot
.52 .507 Mdot
.52 .50721 Mdot
.52 .50752 Mdot
.52 .50805 Mdot
.52 .50917 Mdot
.52 .5093 Mdot
.52 .50947 Mdot
.52 .50975 Mdot
.52 .51032 Mdot
.52 .51042 Mdot
.52 .5105 Mdot
.52 .51098 Mdot
.52 .51113 Mdot
.52 .51134 Mdot
.52 .512 Mdot
.52 .51257 Mdot
.52 .51274 Mdot
.52 .51345 Mdot
.52 .51396 Mdot
.52 .51409 Mdot
.52 .5143 Mdot
.52 .51449 Mdot
.52 .51449 Mdot
.52 .5145 Mdot
.52 .51457 Mdot
.52 .51461 Mdot
.52 .51461 Mdot
.52 .51464 Mdot
.52 .51465 Mdot
.52 .51487 Mdot
.52 .51487 Mdot
.52 .51488 Mdot
.52 .51497 Mdot
.52 .51502 Mdot
.52 .51507 Mdot
.52 .51527 Mdot
.52 .5153 Mdot
.52 .51549 Mdot
.52 .51556 Mdot
.52 .51569 Mdot
.52 .51584 Mdot
.52 .51587 Mdot
.52 .51604 Mdot
.52 .51614 Mdot
.52 .51617 Mdot
.52 .51622 Mdot
.52 .51623 Mdot
.52 .51661 Mdot
.52 .51667 Mdot
.52 .51688 Mdot
.52 .51695 Mdot
.52 .51726 Mdot
.52 .51729 Mdot
.52 .51731 Mdot
.52 .51735 Mdot
.52 .51737 Mdot
.52 .51742 Mdot
.52 .51743 Mdot
.52 .51753 Mdot
.52 .51763 Mdot
.52 .51794 Mdot
.52 .51847 Mdot
.52 .51862 Mdot
.52 .51898 Mdot
.52 .51909 Mdot
.52 .51928 Mdot
.52 .5193 Mdot
.52 .51958 Mdot
.52 .51964 Mdot
.52 .51965 Mdot
.52 .5197 Mdot
.52 .51986 Mdot
.52 .5199 Mdot
.52 .52004 Mdot
.52 .52006 Mdot
.52 .52006 Mdot
.52 .52011 Mdot
.52 .52013 Mdot
.52 .52026 Mdot
.52 .52063 Mdot
.52 .52084 Mdot
.52 .52088 Mdot
.52 .521 Mdot
.52 .52108 Mdot
.52 .52116 Mdot
.52 .5212 Mdot
.52 .52124 Mdot
.52 .52124 Mdot
.52 .52137 Mdot
.52 .52143 Mdot
.52 .52154 Mdot
.52 .52161 Mdot
.52 .52165 Mdot
.52 .52207 Mdot
.52 .52256 Mdot
.52 .52284 Mdot
.52 .52287 Mdot
.52 .52306 Mdot
.52 .52312 Mdot
.52 .52369 Mdot
.52 .52383 Mdot
.52 .52401 Mdot
.52 .52425 Mdot
.52 .5243 Mdot
.52 .52457 Mdot
.52 .52473 Mdot
.52 .52478 Mdot
.52 .5248 Mdot
.52 .52538 Mdot
.52 .52545 Mdot
.52 .52578 Mdot
.52 .52582 Mdot
.52 .52594 Mdot
.52 .52676 Mdot
.52 .52682 Mdot
.52 .52712 Mdot
.52 .52793 Mdot
.52 .52809 Mdot
.52 .52812 Mdot
.52 .52861 Mdot
.52 .52864 Mdot
.52 .52915 Mdot
.52 .52925 Mdot
.52 .52953 Mdot
.52 .52968 Mdot
.52 .52996 Mdot
.52 .52999 Mdot
.52 .53008 Mdot
.52 .53066 Mdot
.52 .53076 Mdot
.52 .53085 Mdot
.52 .53092 Mdot
.52 .53096 Mdot
.52 .53102 Mdot
.52 .53136 Mdot
.52 .53137 Mdot
.52 .53139 Mdot
.52 .53139 Mdot
.52 .53146 Mdot
.52 .53157 Mdot
.52 .53161 Mdot
.52 .53173 Mdot
.52 .53174 Mdot
.52 .53182 Mdot
.52 .53187 Mdot
.52 .53203 Mdot
.52 .53251 Mdot
.52 .53254 Mdot
.52 .53257 Mdot
.52 .53258 Mdot
.52 .5326 Mdot
.52 .53262 Mdot
.52 .53275 Mdot
.52 .53287 Mdot
.52 .53289 Mdot
.52 .53306 Mdot
.52 .53308 Mdot
.52 .53322 Mdot
.52 .53328 Mdot
.52 .53336 Mdot
.52 .53372 Mdot
.52 .53385 Mdot
.52 .53394 Mdot
.52 .53399 Mdot
.52 .53419 Mdot
.52 .53447 Mdot
.52 .53454 Mdot
.52 .53476 Mdot
.52 .53502 Mdot
.52 .5351 Mdot
.52 .53516 Mdot
.52 .53534 Mdot
.52 .53537 Mdot
.52 .53541 Mdot
.52 .53563 Mdot
.52 .53573 Mdot
.52 .53579 Mdot
.52 .53584 Mdot
.52 .53626 Mdot
.52 .53645 Mdot
.52 .53656 Mdot
.52 .53664 Mdot
.52 .5368 Mdot
.52 .53684 Mdot
.52 .537 Mdot
.52 .53705 Mdot
.52 .53714 Mdot
.52 .53728 Mdot
.52 .53736 Mdot
.52 .53752 Mdot
.52 .53752 Mdot
.52 .53757 Mdot
.52 .53762 Mdot
.52 .53772 Mdot
.52 .53781 Mdot
.52 .53791 Mdot
.52 .53796 Mdot
.52 .53799 Mdot
.52 .53801 Mdot
.52 .53817 Mdot
.52 .53826 Mdot
.52 .5387 Mdot
.52 .53879 Mdot
.52 .53884 Mdot
.52 .53888 Mdot
.52 .53893 Mdot
.52 .53893 Mdot
.52 .53895 Mdot
.52 .53899 Mdot
.52 .53912 Mdot
.52 .53915 Mdot
.52 .53933 Mdot
.52 .53939 Mdot
.52 .5394 Mdot
.52 .53947 Mdot
.52 .53977 Mdot
.52 .53979 Mdot
.52 .53985 Mdot
.52 .53995 Mdot
.52 .53999 Mdot
.52 .54 Mdot
.52 .5401 Mdot
.52 .54011 Mdot
.52 .54015 Mdot
.52 .54022 Mdot
.52 .5403 Mdot
.52 .54033 Mdot
.52 .54049 Mdot
.52 .54058 Mdot
.52 .54064 Mdot
.52 .54087 Mdot
.52 .54115 Mdot
.52 .54144 Mdot
.52 .54154 Mdot
.52 .54163 Mdot
.52 .54164 Mdot
.52 .54166 Mdot
.52 .54169 Mdot
.52 .5417 Mdot
.52 .54174 Mdot
.52 .54175 Mdot
.52 .54179 Mdot
.52 .54206 Mdot
.52 .54212 Mdot
.52 .5423 Mdot
.52 .54235 Mdot
.52 .54237 Mdot
.52 .54267 Mdot
.52 .54268 Mdot
.52 .54272 Mdot
.52 .54274 Mdot
.52 .54282 Mdot
.52 .54292 Mdot
.52 .54295 Mdot
.52 .54298 Mdot
.52 .54305 Mdot
.52 .54309 Mdot
.52 .54319 Mdot
.52 .54324 Mdot
.52 .54326 Mdot
.52 .54339 Mdot
.52 .54341 Mdot
.52 .54355 Mdot
.52 .54358 Mdot
.52 .54359 Mdot
.52 .54362 Mdot
.52 .54365 Mdot
.52 .54369 Mdot
.52 .54369 Mdot
.52 .54369 Mdot
.52 .54381 Mdot
.52 .54385 Mdot
.52 .54386 Mdot
.52 .54387 Mdot
.52 .54388 Mdot
.52 .5439 Mdot
.52 .54395 Mdot
.52 .54395 Mdot
.52 .54395 Mdot
.52 .54396 Mdot
.52 .54403 Mdot
.52 .54404 Mdot
.52 .54408 Mdot
.52 .54422 Mdot
.52 .54424 Mdot
.52 .54424 Mdot
.52 .5443 Mdot
.52 .54433 Mdot
.52 .5445 Mdot
.52 .5446 Mdot
.52 .54461 Mdot
.52 .54464 Mdot
.52 .545 Mdot
.52 .54509 Mdot
.52 .5451 Mdot
.52 .5452 Mdot
.52 .54522 Mdot
.52 .5453 Mdot
.52 .54537 Mdot
.52 .54554 Mdot
.52 .54558 Mdot
.52 .54566 Mdot
.52 .54574 Mdot
.52 .54575 Mdot
.52 .54578 Mdot
.52 .5458 Mdot
.52 .5458 Mdot
.52 .54581 Mdot
.52 .54586 Mdot
.52 .54589 Mdot
.52 .54595 Mdot
.52 .54599 Mdot
.52 .54602 Mdot
.52 .54604 Mdot
.52 .54605 Mdot
.52 .54623 Mdot
.52 .54631 Mdot
.52 .54636 Mdot
.52 .54639 Mdot
.52 .54641 Mdot
.52 .54647 Mdot
.52 .54656 Mdot
.52 .54658 Mdot
.52 .54659 Mdot
.52 .54662 Mdot
.52 .54666 Mdot
.52 .5467 Mdot
.52 .5467 Mdot
.52 .54673 Mdot
.52 .54674 Mdot
.52 .54674 Mdot
.52 .54676 Mdot
.52 .54676 Mdot
.52 .54676 Mdot
.52 .54679 Mdot
.52 .54679 Mdot
.52 .5468 Mdot
.52 .5468 Mdot
.52 .54681 Mdot
.52 .54681 Mdot
.52 .54681 Mdot
.522 .19882 Mdot
.522 .19882 Mdot
.522 .19884 Mdot
.522 .19885 Mdot
.522 .19897 Mdot
.522 .19898 Mdot
.522 .19899 Mdot
.522 .19904 Mdot
.522 .19908 Mdot
.522 .19911 Mdot
.522 .1992 Mdot
.522 .19924 Mdot
.522 .19929 Mdot
.522 .19957 Mdot
.522 .1996 Mdot
.522 .19962 Mdot
.522 .19962 Mdot
.522 .19967 Mdot
.522 .19971 Mdot
.522 .19971 Mdot
.522 .19972 Mdot
.522 .19975 Mdot
.522 .19979 Mdot
.522 .19982 Mdot
.522 .20001 Mdot
.522 .20002 Mdot
.522 .20027 Mdot
.522 .20028 Mdot
.522 .20036 Mdot
.522 .20036 Mdot
.522 .20056 Mdot
.522 .2009 Mdot
.522 .20127 Mdot
.522 .20198 Mdot
.522 .20204 Mdot
.522 .20206 Mdot
.522 .20216 Mdot
.522 .20226 Mdot
.522 .20238 Mdot
.522 .2028 Mdot
.522 .20348 Mdot
.522 .20393 Mdot
.522 .20475 Mdot
.522 .20483 Mdot
.522 .20511 Mdot
.522 .20513 Mdot
.522 .20516 Mdot
.522 .20518 Mdot
.522 .20527 Mdot
.522 .20527 Mdot
.522 .20528 Mdot
.522 .20534 Mdot
.522 .20554 Mdot
.522 .20582 Mdot
.522 .20584 Mdot
.522 .20591 Mdot
.522 .2061 Mdot
.522 .20629 Mdot
.522 .20641 Mdot
.522 .20642 Mdot
.522 .20644 Mdot
.522 .20653 Mdot
.522 .20672 Mdot
.522 .20684 Mdot
.522 .20687 Mdot
.522 .20703 Mdot
.522 .20724 Mdot
.522 .20727 Mdot
.522 .20764 Mdot
.522 .20784 Mdot
.522 .20827 Mdot
.522 .20844 Mdot
.522 .20845 Mdot
.522 .20845 Mdot
.522 .20845 Mdot
.522 .20862 Mdot
.522 .20863 Mdot
.522 .2088 Mdot
.522 .20889 Mdot
.522 .20891 Mdot
.522 .20912 Mdot
.522 .20916 Mdot
.522 .20916 Mdot
.522 .20933 Mdot
.522 .20936 Mdot
.522 .20941 Mdot
.522 .20956 Mdot
.522 .20977 Mdot
.522 .20993 Mdot
.522 .21061 Mdot
.522 .21063 Mdot
.522 .21095 Mdot
.522 .21101 Mdot
.522 .21198 Mdot
.522 .21214 Mdot
.522 .21216 Mdot
.522 .2122 Mdot
.522 .21224 Mdot
.522 .21225 Mdot
.522 .21244 Mdot
.522 .21253 Mdot
.522 .21295 Mdot
.522 .21298 Mdot
.522 .21354 Mdot
.522 .21392 Mdot
.522 .21418 Mdot
.522 .21632 Mdot
.522 .21785 Mdot
.522 .21844 Mdot
.522 .21863 Mdot
.522 .2188 Mdot
.522 .21946 Mdot
.522 .21981 Mdot
.522 .22063 Mdot
.522 .22161 Mdot
.522 .2217 Mdot
.522 .22238 Mdot
.522 .22312 Mdot
.522 .22335 Mdot
.522 .22344 Mdot
.522 .22379 Mdot
.522 .22407 Mdot
.522 .22412 Mdot
.522 .22424 Mdot
.522 .22425 Mdot
.522 .22438 Mdot
.522 .22439 Mdot
.522 .22442 Mdot
.522 .22448 Mdot
.522 .22501 Mdot
.522 .22513 Mdot
.522 .22523 Mdot
.522 .22554 Mdot
.522 .22589 Mdot
.522 .22658 Mdot
.522 .22686 Mdot
.522 .22762 Mdot
.522 .22833 Mdot
.522 .2284 Mdot
.522 .22856 Mdot
.522 .22878 Mdot
.522 .22997 Mdot
.522 .23005 Mdot
.522 .2301 Mdot
.522 .23049 Mdot
.522 .23085 Mdot
.522 .23096 Mdot
.522 .2316 Mdot
.522 .23267 Mdot
.522 .23274 Mdot
.522 .23292 Mdot
.522 .23303 Mdot
.522 .23337 Mdot
.522 .23423 Mdot
.522 .23486 Mdot
.522 .23504 Mdot
.522 .23506 Mdot
.522 .23515 Mdot
.522 .23532 Mdot
.522 .23567 Mdot
.522 .23586 Mdot
.522 .23587 Mdot
.522 .23604 Mdot
.522 .23658 Mdot
.522 .23668 Mdot
.522 .23692 Mdot
.522 .23702 Mdot
.522 .23702 Mdot
.522 .23702 Mdot
.522 .23712 Mdot
.522 .23738 Mdot
.522 .2374 Mdot
.522 .23814 Mdot
.522 .23815 Mdot
.522 .23887 Mdot
.522 .23889 Mdot
.522 .23891 Mdot
.522 .23892 Mdot
.522 .23893 Mdot
.522 .23952 Mdot
.522 .23969 Mdot
.522 .2416 Mdot
.522 .24201 Mdot
.522 .24247 Mdot
.522 .24313 Mdot
.522 .24349 Mdot
.522 .24388 Mdot
.522 .24418 Mdot
.522 .24429 Mdot
.522 .24466 Mdot
.522 .24502 Mdot
.522 .24527 Mdot
.522 .24529 Mdot
.522 .24601 Mdot
.522 .24613 Mdot
.522 .24617 Mdot
.522 .24638 Mdot
.522 .24674 Mdot
.522 .24682 Mdot
.522 .24685 Mdot
.522 .24751 Mdot
.522 .2476 Mdot
.522 .248 Mdot
.522 .24804 Mdot
.522 .24814 Mdot
.522 .24815 Mdot
.522 .24818 Mdot
.522 .24827 Mdot
.522 .24875 Mdot
.522 .24971 Mdot
.522 .25005 Mdot
.522 .25016 Mdot
.522 .25028 Mdot
.522 .25051 Mdot
.522 .25062 Mdot
.522 .25071 Mdot
.522 .25096 Mdot
.522 .25103 Mdot
.522 .25117 Mdot
.522 .25152 Mdot
.522 .25156 Mdot
.522 .2516 Mdot
.522 .25216 Mdot
.522 .25246 Mdot
.522 .25343 Mdot
.522 .25374 Mdot
.522 .25376 Mdot
.522 .25378 Mdot
.522 .25397 Mdot
.522 .25423 Mdot
.522 .25433 Mdot
.522 .25446 Mdot
.522 .25453 Mdot
.522 .25459 Mdot
.522 .25558 Mdot
.522 .25565 Mdot
.522 .25573 Mdot
.522 .25601 Mdot
.522 .25638 Mdot
.522 .2564 Mdot
.522 .25665 Mdot
.522 .2568 Mdot
.522 .25728 Mdot
.522 .25743 Mdot
.522 .25764 Mdot
.522 .2581 Mdot
.522 .25833 Mdot
.522 .25854 Mdot
.522 .2592 Mdot
.522 .26071 Mdot
.522 .26107 Mdot
.522 .26202 Mdot
.522 .2622 Mdot
.522 .26226 Mdot
.522 .26226 Mdot
.522 .26247 Mdot
.522 .26254 Mdot
.522 .26312 Mdot
.522 .26334 Mdot
.522 .26352 Mdot
.522 .26484 Mdot
.522 .26491 Mdot
.522 .26508 Mdot
.522 .26579 Mdot
.522 .26623 Mdot
.522 .26631 Mdot
.522 .26655 Mdot
.522 .26682 Mdot
.522 .26801 Mdot
.522 .26806 Mdot
.522 .26857 Mdot
.522 .26911 Mdot
.522 .26932 Mdot
.522 .26983 Mdot
.522 .27008 Mdot
.522 .27032 Mdot
.522 .27039 Mdot
.522 .27093 Mdot
.522 .27095 Mdot
.522 .27106 Mdot
.522 .27141 Mdot
.522 .27175 Mdot
.522 .2725 Mdot
.522 .27391 Mdot
.522 .27488 Mdot
.522 .27543 Mdot
.522 .27575 Mdot
.522 .27762 Mdot
.522 .27962 Mdot
.522 .27987 Mdot
.522 .28025 Mdot
.522 .2808 Mdot
.522 .28083 Mdot
.522 .28126 Mdot
.522 .28136 Mdot
.522 .28155 Mdot
.522 .28156 Mdot
.522 .2816 Mdot
.522 .28164 Mdot
.522 .28167 Mdot
.522 .28287 Mdot
.522 .28293 Mdot
.522 .28327 Mdot
.522 .28329 Mdot
.522 .28406 Mdot
.522 .28424 Mdot
.522 .28448 Mdot
.522 .28466 Mdot
.522 .28471 Mdot
.522 .28474 Mdot
.522 .28494 Mdot
.522 .28494 Mdot
.522 .28499 Mdot
.522 .28524 Mdot
.522 .28527 Mdot
.522 .28537 Mdot
.522 .28558 Mdot
.522 .28558 Mdot
.522 .28579 Mdot
.522 .28579 Mdot
.522 .2858 Mdot
.522 .28601 Mdot
.522 .28655 Mdot
.522 .28679 Mdot
.522 .28727 Mdot
.522 .28758 Mdot
.522 .28784 Mdot
.522 .288 Mdot
.522 .28837 Mdot
.522 .2884 Mdot
.522 .28841 Mdot
.522 .28857 Mdot
.522 .28881 Mdot
.522 .28884 Mdot
.522 .28911 Mdot
.522 .28921 Mdot
.522 .28923 Mdot
.522 .28964 Mdot
.522 .29002 Mdot
.522 .29002 Mdot
.522 .29003 Mdot
.522 .29016 Mdot
.522 .29019 Mdot
.522 .29023 Mdot
.522 .29027 Mdot
.522 .29069 Mdot
.522 .29213 Mdot
.522 .29412 Mdot
.522 .29492 Mdot
.522 .29517 Mdot
.522 .29558 Mdot
.522 .29575 Mdot
.522 .29825 Mdot
.522 .29976 Mdot
.522 .30003 Mdot
.522 .30088 Mdot
.522 .30182 Mdot
.522 .30193 Mdot
.522 .30211 Mdot
.522 .30496 Mdot
.522 .30548 Mdot
.522 .30589 Mdot
.522 .30606 Mdot
.522 .30778 Mdot
.522 .30874 Mdot
.522 .30961 Mdot
.522 .3103 Mdot
.522 .312 Mdot
.522 .31284 Mdot
.522 .31363 Mdot
.522 .31387 Mdot
.522 .31415 Mdot
.522 .31548 Mdot
.522 .31563 Mdot
.522 .3157 Mdot
.522 .31572 Mdot
.522 .31605 Mdot
.522 .31607 Mdot
.522 .31637 Mdot
.522 .31648 Mdot
.522 .31719 Mdot
.522 .31805 Mdot
.522 .31829 Mdot
.522 .31886 Mdot
.522 .32072 Mdot
.522 .32242 Mdot
.522 .32266 Mdot
.522 .32514 Mdot
.522 .32722 Mdot
.522 .32811 Mdot
.522 .32979 Mdot
.522 .33024 Mdot
.522 .33073 Mdot
.522 .33225 Mdot
.522 .3362 Mdot
.522 .34177 Mdot
.522 .34245 Mdot
.522 .34345 Mdot
.522 .34492 Mdot
.522 .34499 Mdot
.522 .34611 Mdot
.522 .34636 Mdot
.522 .34684 Mdot
.522 .34688 Mdot
.522 .34697 Mdot
.522 .34708 Mdot
.522 .34715 Mdot
.522 .34755 Mdot
.522 .35014 Mdot
.522 .35029 Mdot
.522 .35112 Mdot
.522 .35118 Mdot
.522 .353 Mdot
.522 .35342 Mdot
.522 .35398 Mdot
.522 .35439 Mdot
.522 .35452 Mdot
.522 .35458 Mdot
.522 .35504 Mdot
.522 .35504 Mdot
.522 .35515 Mdot
.522 .35571 Mdot
.522 .35577 Mdot
.522 .356 Mdot
.522 .35647 Mdot
.522 .35648 Mdot
.522 .35693 Mdot
.522 .35694 Mdot
.522 .35695 Mdot
.522 .35696 Mdot
.522 .35743 Mdot
.522 .35859 Mdot
.522 .3591 Mdot
.522 .36011 Mdot
.522 .36017 Mdot
.522 .36074 Mdot
.522 .36117 Mdot
.522 .36126 Mdot
.522 .36158 Mdot
.522 .36207 Mdot
.522 .36232 Mdot
.522 .36238 Mdot
.522 .3624 Mdot
.522 .36272 Mdot
.522 .36325 Mdot
.522 .36376 Mdot
.522 .36394 Mdot
.522 .36398 Mdot
.522 .36476 Mdot
.522 .36529 Mdot
.522 .36545 Mdot
.522 .36546 Mdot
.522 .36548 Mdot
.522 .36571 Mdot
.522 .36577 Mdot
.522 .36584 Mdot
.522 .36591 Mdot
.522 .36666 Mdot
.522 .36687 Mdot
.522 .3691 Mdot
.522 .37032 Mdot
.522 .37216 Mdot
.522 .37327 Mdot
.522 .37362 Mdot
.522 .37389 Mdot
.522 .37416 Mdot
.522 .37421 Mdot
.522 .37438 Mdot
.522 .37628 Mdot
.522 .3773 Mdot
.522 .37822 Mdot
.522 .37876 Mdot
.522 .37878 Mdot
.522 .37897 Mdot
.522 .37902 Mdot
.522 .3797 Mdot
.522 .37973 Mdot
.522 .38024 Mdot
.522 .38032 Mdot
.522 .38043 Mdot
.522 .38051 Mdot
.522 .38053 Mdot
.522 .38054 Mdot
.522 .38063 Mdot
.522 .38076 Mdot
.522 .38078 Mdot
.522 .38082 Mdot
.522 .38092 Mdot
.522 .38167 Mdot
.522 .38181 Mdot
.522 .38192 Mdot
.522 .38215 Mdot
.522 .38224 Mdot
.522 .38235 Mdot
.522 .38248 Mdot
.522 .38252 Mdot
.522 .38253 Mdot
.522 .38288 Mdot
.522 .38288 Mdot
.522 .38294 Mdot
.522 .38296 Mdot
.522 .47241 Mdot
.522 .47242 Mdot
.522 .47245 Mdot
.522 .47245 Mdot
.522 .47262 Mdot
.522 .47263 Mdot
.522 .47265 Mdot
.522 .47272 Mdot
.522 .47277 Mdot
.522 .47281 Mdot
.522 .47293 Mdot
.522 .47299 Mdot
.522 .47305 Mdot
.522 .47343 Mdot
.522 .47347 Mdot
.522 .4735 Mdot
.522 .4735 Mdot
.522 .47357 Mdot
.522 .47361 Mdot
.522 .47362 Mdot
.522 .47363 Mdot
.522 .47367 Mdot
.522 .47372 Mdot
.522 .47376 Mdot
.522 .47401 Mdot
.522 .47403 Mdot
.522 .47436 Mdot
.522 .47439 Mdot
.522 .47448 Mdot
.522 .47449 Mdot
.522 .47475 Mdot
.522 .47521 Mdot
.522 .4757 Mdot
.522 .47663 Mdot
.522 .47671 Mdot
.522 .47674 Mdot
.522 .47687 Mdot
.522 .477 Mdot
.522 .47717 Mdot
.522 .4777 Mdot
.522 .47859 Mdot
.522 .47917 Mdot
.522 .48024 Mdot
.522 .48034 Mdot
.522 .48069 Mdot
.522 .48072 Mdot
.522 .48076 Mdot
.522 .48078 Mdot
.522 .4809 Mdot
.522 .4809 Mdot
.522 .48091 Mdot
.522 .48099 Mdot
.522 .48124 Mdot
.522 .4816 Mdot
.522 .48162 Mdot
.522 .48171 Mdot
.522 .48195 Mdot
.522 .4822 Mdot
.522 .48235 Mdot
.522 .48236 Mdot
.522 .48238 Mdot
.522 .4825 Mdot
.522 .48273 Mdot
.522 .48288 Mdot
.522 .48292 Mdot
.522 .48312 Mdot
.522 .48339 Mdot
.522 .48342 Mdot
.522 .48389 Mdot
.522 .48413 Mdot
.522 .48466 Mdot
.522 .48488 Mdot
.522 .48489 Mdot
.522 .48489 Mdot
.522 .4849 Mdot
.522 .4851 Mdot
.522 .48511 Mdot
.522 .48533 Mdot
.522 .48543 Mdot
.522 .48546 Mdot
.522 .48572 Mdot
.522 .48577 Mdot
.522 .48577 Mdot
.522 .48598 Mdot
.522 .48601 Mdot
.522 .48607 Mdot
.522 .48625 Mdot
.522 .48651 Mdot
.522 .4867 Mdot
.522 .48754 Mdot
.522 .48756 Mdot
.522 .48794 Mdot
.522 .48801 Mdot
.522 .48918 Mdot
.522 .48936 Mdot
.522 .4894 Mdot
.522 .48944 Mdot
.522 .48949 Mdot
.522 .4895 Mdot
.522 .48972 Mdot
.522 .48983 Mdot
.522 .49033 Mdot
.522 .49037 Mdot
.522 .49103 Mdot
.522 .49147 Mdot
.522 .49177 Mdot
.522 .49423 Mdot
.522 .49596 Mdot
.522 .49662 Mdot
.522 .49683 Mdot
.522 .49703 Mdot
.522 .49776 Mdot
.522 .49814 Mdot
.522 .49903 Mdot
.522 .50009 Mdot
.522 .50019 Mdot
.522 .50092 Mdot
.522 .5017 Mdot
.522 .50194 Mdot
.522 .50204 Mdot
.522 .50241 Mdot
.522 .5027 Mdot
.522 .50275 Mdot
.522 .50288 Mdot
.522 .50288 Mdot
.522 .50302 Mdot
.522 .50303 Mdot
.522 .50306 Mdot
.522 .50312 Mdot
.522 .50368 Mdot
.522 .5038 Mdot
.522 .5039 Mdot
.522 .50423 Mdot
.522 .50458 Mdot
.522 .50528 Mdot
.522 .50557 Mdot
.522 .50632 Mdot
.522 .50703 Mdot
.522 .5071 Mdot
.522 .50727 Mdot
.522 .50748 Mdot
.522 .50865 Mdot
.522 .50872 Mdot
.522 .50877 Mdot
.522 .50915 Mdot
.522 .50949 Mdot
.522 .5096 Mdot
.522 .51022 Mdot
.522 .51123 Mdot
.522 .51129 Mdot
.522 .51146 Mdot
.522 .51156 Mdot
.522 .51188 Mdot
.522 .51268 Mdot
.522 .51325 Mdot
.522 .51342 Mdot
.522 .51343 Mdot
.522 .51345 Mdot
.522 .51346 Mdot
.522 .51351 Mdot
.522 .51352 Mdot
.522 .51352 Mdot
.522 .51367 Mdot
.522 .51383 Mdot
.522 .51384 Mdot
.522 .51388 Mdot
.522 .51398 Mdot
.522 .514 Mdot
.522 .51409 Mdot
.522 .51416 Mdot
.522 .51416 Mdot
.522 .51417 Mdot
.522 .51432 Mdot
.522 .51438 Mdot
.522 .51448 Mdot
.522 .51461 Mdot
.522 .5148 Mdot
.522 .51489 Mdot
.522 .5151 Mdot
.522 .51519 Mdot
.522 .51519 Mdot
.522 .51519 Mdot
.522 .51527 Mdot
.522 .51528 Mdot
.522 .51536 Mdot
.522 .5154 Mdot
.522 .51541 Mdot
.522 .51551 Mdot
.522 .51553 Mdot
.522 .51553 Mdot
.522 .51561 Mdot
.522 .51562 Mdot
.522 .51564 Mdot
.522 .51571 Mdot
.522 .5158 Mdot
.522 .51587 Mdot
.522 .51617 Mdot
.522 .51618 Mdot
.522 .51632 Mdot
.522 .51634 Mdot
.522 .51681 Mdot
.522 .51682 Mdot
.522 .51684 Mdot
.522 .51685 Mdot
.522 .51686 Mdot
.522 .51693 Mdot
.522 .51697 Mdot
.522 .51714 Mdot
.522 .51715 Mdot
.522 .51737 Mdot
.522 .51751 Mdot
.522 .51761 Mdot
.522 .51839 Mdot
.522 .51912 Mdot
.522 .51924 Mdot
.522 .51945 Mdot
.522 .51983 Mdot
.522 .52037 Mdot
.522 .52066 Mdot
.522 .52079 Mdot
.522 .52093 Mdot
.522 .52097 Mdot
.522 .52098 Mdot
.522 .52118 Mdot
.522 .52121 Mdot
.522 .5213 Mdot
.522 .5214 Mdot
.522 .52159 Mdot
.522 .52167 Mdot
.522 .52188 Mdot
.522 .52207 Mdot
.522 .52209 Mdot
.522 .52254 Mdot
.522 .52265 Mdot
.522 .52274 Mdot
.522 .52277 Mdot
.522 .52294 Mdot
.522 .52321 Mdot
.522 .52327 Mdot
.522 .5233 Mdot
.522 .5238 Mdot
.522 .52387 Mdot
.522 .52395 Mdot
.522 .52417 Mdot
.522 .5242 Mdot
.522 .52428 Mdot
.522 .52428 Mdot
.522 .5243 Mdot
.522 .52437 Mdot
.522 .52473 Mdot
.522 .52486 Mdot
.522 .52543 Mdot
.522 .52568 Mdot
.522 .52576 Mdot
.522 .52584 Mdot
.522 .52601 Mdot
.522 .52609 Mdot
.522 .52615 Mdot
.522 .52633 Mdot
.522 .52639 Mdot
.522 .52648 Mdot
.522 .52649 Mdot
.522 .52663 Mdot
.522 .52673 Mdot
.522 .52676 Mdot
.522 .52678 Mdot
.522 .52716 Mdot
.522 .52718 Mdot
.522 .5272 Mdot
.522 .52725 Mdot
.522 .52729 Mdot
.522 .52739 Mdot
.522 .52746 Mdot
.522 .52747 Mdot
.522 .52747 Mdot
.522 .52759 Mdot
.522 .52795 Mdot
.522 .52806 Mdot
.522 .52827 Mdot
.522 .52828 Mdot
.522 .5283 Mdot
.522 .52843 Mdot
.522 .52848 Mdot
.522 .52851 Mdot
.522 .5286 Mdot
.522 .52863 Mdot
.522 .52867 Mdot
.522 .52876 Mdot
.522 .5288 Mdot
.522 .52884 Mdot
.522 .52897 Mdot
.522 .52932 Mdot
.522 .5295 Mdot
.522 .52953 Mdot
.522 .52955 Mdot
.522 .52955 Mdot
.522 .52959 Mdot
.522 .5296 Mdot
.522 .52975 Mdot
.522 .52978 Mdot
.522 .53002 Mdot
.522 .53004 Mdot
.522 .53007 Mdot
.522 .5302 Mdot
.522 .53028 Mdot
.522 .53029 Mdot
.522 .53033 Mdot
.522 .5306 Mdot
.522 .53061 Mdot
.522 .5307 Mdot
.522 .53083 Mdot
.522 .53096 Mdot
.522 .53101 Mdot
.522 .53111 Mdot
.522 .53126 Mdot
.522 .53139 Mdot
.522 .53163 Mdot
.522 .5318 Mdot
.522 .53195 Mdot
.522 .53264 Mdot
.522 .5327 Mdot
.522 .53292 Mdot
.522 .53292 Mdot
.522 .53293 Mdot
.522 .53294 Mdot
.522 .53294 Mdot
.522 .5332 Mdot
.522 .53321 Mdot
.522 .53347 Mdot
.522 .53348 Mdot
.522 .53358 Mdot
.522 .53361 Mdot
.522 .53361 Mdot
.522 .53361 Mdot
.522 .53365 Mdot
.522 .53373 Mdot
.522 .53377 Mdot
.522 .53397 Mdot
.522 .53403 Mdot
.522 .53403 Mdot
.522 .5341 Mdot
.522 .53423 Mdot
.522 .53429 Mdot
.522 .53432 Mdot
.522 .53433 Mdot
.522 .53439 Mdot
.522 .53462 Mdot
.522 .53493 Mdot
.522 .53505 Mdot
.522 .53509 Mdot
.522 .53516 Mdot
.522 .53518 Mdot
.522 .53557 Mdot
.522 .5358 Mdot
.522 .53584 Mdot
.522 .53597 Mdot
.522 .53611 Mdot
.522 .53612 Mdot
.522 .53615 Mdot
.522 .53658 Mdot
.522 .53665 Mdot
.522 .53671 Mdot
.522 .53674 Mdot
.522 .53699 Mdot
.522 .53726 Mdot
.522 .53736 Mdot
.522 .53761 Mdot
.522 .53773 Mdot
.522 .53785 Mdot
.522 .53788 Mdot
.522 .53792 Mdot
.522 .53811 Mdot
.522 .53813 Mdot
.522 .53814 Mdot
.522 .53815 Mdot
.522 .53819 Mdot
.522 .53819 Mdot
.522 .53824 Mdot
.522 .53825 Mdot
.522 .53835 Mdot
.522 .53848 Mdot
.522 .53851 Mdot
.522 .53859 Mdot
.522 .53885 Mdot
.522 .53909 Mdot
.522 .53913 Mdot
.522 .53947 Mdot
.522 .53976 Mdot
.522 .53988 Mdot
.522 .54012 Mdot
.522 .54018 Mdot
.522 .54025 Mdot
.522 .54045 Mdot
.522 .54099 Mdot
.522 .54174 Mdot
.522 .54183 Mdot
.522 .54196 Mdot
.522 .54216 Mdot
.522 .54217 Mdot
.522 .54231 Mdot
.522 .54235 Mdot
.522 .54241 Mdot
.522 .54242 Mdot
.522 .54243 Mdot
.522 .54244 Mdot
.522 .54245 Mdot
.522 .54251 Mdot
.522 .54285 Mdot
.522 .54287 Mdot
.522 .54297 Mdot
.522 .54298 Mdot
.522 .54322 Mdot
.522 .54328 Mdot
.522 .54335 Mdot
.522 .5434 Mdot
.522 .54342 Mdot
.522 .54343 Mdot
.522 .54349 Mdot
.522 .54349 Mdot
.522 .5435 Mdot
.522 .54357 Mdot
.522 .54358 Mdot
.522 .54361 Mdot
.522 .54367 Mdot
.522 .54367 Mdot
.522 .54373 Mdot
.522 .54373 Mdot
.522 .54373 Mdot
.522 .54374 Mdot
.522 .5438 Mdot
.522 .54395 Mdot
.522 .54401 Mdot
.522 .54414 Mdot
.522 .54415 Mdot
.522 .54422 Mdot
.522 .54428 Mdot
.522 .54429 Mdot
.522 .54433 Mdot
.522 .5444 Mdot
.522 .54443 Mdot
.522 .54444 Mdot
.522 .54444 Mdot
.522 .54448 Mdot
.522 .54455 Mdot
.522 .54461 Mdot
.522 .54464 Mdot
.522 .54464 Mdot
.522 .54474 Mdot
.522 .54481 Mdot
.522 .54483 Mdot
.522 .54483 Mdot
.522 .54483 Mdot
.522 .54486 Mdot
.522 .54487 Mdot
.522 .54488 Mdot
.522 .54489 Mdot
.522 .54498 Mdot
.522 .54501 Mdot
.522 .5453 Mdot
.522 .54545 Mdot
.522 .54568 Mdot
.522 .54583 Mdot
.522 .54587 Mdot
.522 .5459 Mdot
.522 .54594 Mdot
.522 .54595 Mdot
.522 .54597 Mdot
.522 .54621 Mdot
.522 .54634 Mdot
.522 .54645 Mdot
.522 .54652 Mdot
.522 .54652 Mdot
.522 .54655 Mdot
.522 .54655 Mdot
.522 .54664 Mdot
.522 .54664 Mdot
.522 .54671 Mdot
.522 .54672 Mdot
.522 .54673 Mdot
.522 .54674 Mdot
.522 .54674 Mdot
.522 .54674 Mdot
.522 .54676 Mdot
.522 .54677 Mdot
.522 .54677 Mdot
.522 .54678 Mdot
.522 .54679 Mdot
.522 .54689 Mdot
.522 .5469 Mdot
.522 .54692 Mdot
.522 .54695 Mdot
.522 .54696 Mdot
.522 .54697 Mdot
.522 .54699 Mdot
.522 .54699 Mdot
.522 .54699 Mdot
.522 .54704 Mdot
.522 .54704 Mdot
.522 .54705 Mdot
.522 .54705 Mdot
.524 .19821 Mdot
.524 .19821 Mdot
.524 .19823 Mdot
.524 .19824 Mdot
.524 .19824 Mdot
.524 .19825 Mdot
.524 .19826 Mdot
.524 .19831 Mdot
.524 .19833 Mdot
.524 .19837 Mdot
.524 .19865 Mdot
.524 .1987 Mdot
.524 .19878 Mdot
.524 .19891 Mdot
.524 .199 Mdot
.524 .19914 Mdot
.524 .19919 Mdot
.524 .19937 Mdot
.524 .19969 Mdot
.524 .19972 Mdot
.524 .19995 Mdot
.524 .2 Mdot
.524 .20001 Mdot
.524 .2001 Mdot
.524 .20016 Mdot
.524 .20022 Mdot
.524 .20037 Mdot
.524 .20046 Mdot
.524 .20049 Mdot
.524 .2005 Mdot
.524 .20081 Mdot
.524 .20081 Mdot
.524 .20086 Mdot
.524 .20088 Mdot
.524 .20097 Mdot
.524 .2011 Mdot
.524 .20116 Mdot
.524 .20127 Mdot
.524 .20137 Mdot
.524 .2016 Mdot
.524 .20241 Mdot
.524 .2028 Mdot
.524 .2028 Mdot
.524 .20286 Mdot
.524 .20287 Mdot
.524 .20291 Mdot
.524 .20292 Mdot
.524 .20296 Mdot
.524 .20297 Mdot
.524 .20318 Mdot
.524 .20326 Mdot
.524 .20339 Mdot
.524 .20345 Mdot
.524 .20363 Mdot
.524 .2038 Mdot
.524 .20436 Mdot
.524 .20451 Mdot
.524 .20454 Mdot
.524 .20455 Mdot
.524 .20457 Mdot
.524 .20475 Mdot
.524 .20487 Mdot
.524 .20509 Mdot
.524 .20514 Mdot
.524 .20564 Mdot
.524 .20598 Mdot
.524 .20604 Mdot
.524 .2064 Mdot
.524 .20672 Mdot
.524 .20683 Mdot
.524 .20693 Mdot
.524 .20696 Mdot
.524 .20721 Mdot
.524 .20732 Mdot
.524 .20778 Mdot
.524 .20787 Mdot
.524 .20844 Mdot
.524 .20858 Mdot
.524 .20859 Mdot
.524 .20871 Mdot
.524 .20878 Mdot
.524 .20882 Mdot
.524 .20919 Mdot
.524 .20953 Mdot
.524 .20969 Mdot
.524 .20987 Mdot
.524 .20999 Mdot
.524 .21004 Mdot
.524 .21006 Mdot
.524 .21037 Mdot
.524 .21039 Mdot
.524 .21056 Mdot
.524 .2106 Mdot
.524 .21089 Mdot
.524 .211 Mdot
.524 .21117 Mdot
.524 .21121 Mdot
.524 .21128 Mdot
.524 .21135 Mdot
.524 .21172 Mdot
.524 .21187 Mdot
.524 .2122 Mdot
.524 .21259 Mdot
.524 .21303 Mdot
.524 .21341 Mdot
.524 .21346 Mdot
.524 .214 Mdot
.524 .21405 Mdot
.524 .21411 Mdot
.524 .21421 Mdot
.524 .21431 Mdot
.524 .21555 Mdot
.524 .21606 Mdot
.524 .21626 Mdot
.524 .21628 Mdot
.524 .21639 Mdot
.524 .21651 Mdot
.524 .21653 Mdot
.524 .2166 Mdot
.524 .21674 Mdot
.524 .21682 Mdot
.524 .21711 Mdot
.524 .21729 Mdot
.524 .21738 Mdot
.524 .21745 Mdot
.524 .21821 Mdot
.524 .21865 Mdot
.524 .2191 Mdot
.524 .21925 Mdot
.524 .21944 Mdot
.524 .22011 Mdot
.524 .22049 Mdot
.524 .22179 Mdot
.524 .22185 Mdot
.524 .22195 Mdot
.524 .22324 Mdot
.524 .22328 Mdot
.524 .22442 Mdot
.524 .22494 Mdot
.524 .22629 Mdot
.524 .22641 Mdot
.524 .22643 Mdot
.524 .22654 Mdot
.524 .22687 Mdot
.524 .22697 Mdot
.524 .22758 Mdot
.524 .22793 Mdot
.524 .22802 Mdot
.524 .22816 Mdot
.524 .22911 Mdot
.524 .22927 Mdot
.524 .22968 Mdot
.524 .22992 Mdot
.524 .23 Mdot
.524 .23027 Mdot
.524 .23104 Mdot
.524 .23109 Mdot
.524 .23111 Mdot
.524 .23121 Mdot
.524 .23127 Mdot
.524 .23135 Mdot
.524 .2315 Mdot
.524 .23161 Mdot
.524 .23163 Mdot
.524 .23165 Mdot
.524 .23196 Mdot
.524 .23196 Mdot
.524 .23201 Mdot
.524 .23203 Mdot
.524 .2324 Mdot
.524 .23248 Mdot
.524 .23269 Mdot
.524 .23336 Mdot
.524 .23426 Mdot
.524 .23437 Mdot
.524 .23476 Mdot
.524 .23487 Mdot
.524 .23489 Mdot
.524 .23601 Mdot
.524 .23631 Mdot
.524 .23647 Mdot
.524 .23653 Mdot
.524 .23678 Mdot
.524 .2372 Mdot
.524 .23727 Mdot
.524 .23733 Mdot
.524 .23792 Mdot
.524 .23796 Mdot
.524 .23811 Mdot
.524 .23952 Mdot
.524 .23978 Mdot
.524 .23982 Mdot
.524 .24044 Mdot
.524 .24065 Mdot
.524 .24079 Mdot
.524 .24085 Mdot
.524 .24292 Mdot
.524 .24344 Mdot
.524 .24456 Mdot
.524 .24457 Mdot
.524 .24473 Mdot
.524 .24517 Mdot
.524 .24568 Mdot
.524 .24588 Mdot
.524 .24614 Mdot
.524 .24624 Mdot
.524 .24634 Mdot
.524 .24646 Mdot
.524 .24723 Mdot
.524 .24739 Mdot
.524 .24813 Mdot
.524 .24836 Mdot
.524 .24893 Mdot
.524 .24894 Mdot
.524 .2492 Mdot
.524 .24924 Mdot
.524 .25091 Mdot
.524 .25123 Mdot
.524 .25168 Mdot
.524 .25342 Mdot
.524 .25366 Mdot
.524 .25478 Mdot
.524 .25492 Mdot
.524 .25537 Mdot
.524 .25579 Mdot
.524 .25631 Mdot
.524 .25638 Mdot
.524 .25644 Mdot
.524 .2565 Mdot
.524 .25664 Mdot
.524 .2574 Mdot
.524 .25962 Mdot
.524 .2597 Mdot
.524 .2602 Mdot
.524 .26023 Mdot
.524 .26038 Mdot
.524 .26125 Mdot
.524 .26134 Mdot
.524 .26181 Mdot
.524 .26223 Mdot
.524 .26256 Mdot
.524 .26327 Mdot
.524 .26329 Mdot
.524 .26361 Mdot
.524 .26368 Mdot
.524 .26484 Mdot
.524 .2649 Mdot
.524 .26514 Mdot
.524 .26516 Mdot
.524 .26519 Mdot
.524 .2654 Mdot
.524 .26541 Mdot
.524 .26542 Mdot
.524 .2656 Mdot
.524 .26576 Mdot
.524 .26577 Mdot
.524 .26581 Mdot
.524 .26632 Mdot
.524 .26673 Mdot
.524 .26779 Mdot
.524 .26795 Mdot
.524 .2687 Mdot
.524 .26903 Mdot
.524 .26904 Mdot
.524 .27139 Mdot
.524 .27248 Mdot
.524 .27252 Mdot
.524 .27387 Mdot
.524 .27442 Mdot
.524 .27508 Mdot
.524 .27545 Mdot
.524 .27617 Mdot
.524 .27672 Mdot
.524 .27685 Mdot
.524 .27691 Mdot
.524 .27704 Mdot
.524 .27714 Mdot
.524 .27715 Mdot
.524 .27734 Mdot
.524 .27779 Mdot
.524 .27895 Mdot
.524 .27904 Mdot
.524 .27914 Mdot
.524 .27919 Mdot
.524 .27924 Mdot
.524 .27976 Mdot
.524 .2798 Mdot
.524 .28062 Mdot
.524 .28101 Mdot
.524 .28134 Mdot
.524 .28188 Mdot
.524 .28195 Mdot
.524 .28225 Mdot
.524 .28292 Mdot
.524 .28326 Mdot
.524 .28334 Mdot
.524 .28367 Mdot
.524 .28385 Mdot
.524 .28466 Mdot
.524 .28479 Mdot
.524 .28494 Mdot
.524 .28578 Mdot
.524 .28589 Mdot
.524 .28646 Mdot
.524 .2866 Mdot
.524 .28691 Mdot
.524 .28695 Mdot
.524 .28721 Mdot
.524 .28763 Mdot
.524 .2881 Mdot
.524 .28865 Mdot
.524 .28943 Mdot
.524 .28991 Mdot
.524 .29018 Mdot
.524 .29023 Mdot
.524 .29028 Mdot
.524 .29049 Mdot
.524 .29137 Mdot
.524 .29163 Mdot
.524 .29203 Mdot
.524 .29225 Mdot
.524 .29237 Mdot
.524 .29273 Mdot
.524 .29275 Mdot
.524 .29283 Mdot
.524 .29284 Mdot
.524 .29292 Mdot
.524 .29302 Mdot
.524 .29302 Mdot
.524 .29373 Mdot
.524 .29528 Mdot
.524 .29576 Mdot
.524 .29596 Mdot
.524 .29683 Mdot
.524 .29688 Mdot
.524 .29699 Mdot
.524 .297 Mdot
.524 .29772 Mdot
.524 .29776 Mdot
.524 .29783 Mdot
.524 .29806 Mdot
.524 .29844 Mdot
.524 .29861 Mdot
.524 .29876 Mdot
.524 .299 Mdot
.524 .29904 Mdot
.524 .29917 Mdot
.524 .30098 Mdot
.524 .30164 Mdot
.524 .30183 Mdot
.524 .30241 Mdot
.524 .30337 Mdot
.524 .30377 Mdot
.524 .30606 Mdot
.524 .30641 Mdot
.524 .30662 Mdot
.524 .30746 Mdot
.524 .30896 Mdot
.524 .30919 Mdot
.524 .30999 Mdot
.524 .31028 Mdot
.524 .31033 Mdot
.524 .31062 Mdot
.524 .31394 Mdot
.524 .31524 Mdot
.524 .31808 Mdot
.524 .31817 Mdot
.524 .32142 Mdot
.524 .32169 Mdot
.524 .32183 Mdot
.524 .32512 Mdot
.524 .3261 Mdot
.524 .32782 Mdot
.524 .32829 Mdot
.524 .32868 Mdot
.524 .32984 Mdot
.524 .33096 Mdot
.524 .33294 Mdot
.524 .33311 Mdot
.524 .33333 Mdot
.524 .3338 Mdot
.524 .33457 Mdot
.524 .33476 Mdot
.524 .33513 Mdot
.524 .33531 Mdot
.524 .33536 Mdot
.524 .33566 Mdot
.524 .33596 Mdot
.524 .33601 Mdot
.524 .33654 Mdot
.524 .33785 Mdot
.524 .3411 Mdot
.524 .34137 Mdot
.524 .34163 Mdot
.524 .34179 Mdot
.524 .34192 Mdot
.524 .34333 Mdot
.524 .34346 Mdot
.524 .34447 Mdot
.524 .34564 Mdot
.524 .34667 Mdot
.524 .34753 Mdot
.524 .34792 Mdot
.524 .34891 Mdot
.524 .34909 Mdot
.524 .3494 Mdot
.524 .34984 Mdot
.524 .35014 Mdot
.524 .35091 Mdot
.524 .35102 Mdot
.524 .35147 Mdot
.524 .35152 Mdot
.524 .35234 Mdot
.524 .35239 Mdot
.524 .35254 Mdot
.524 .35284 Mdot
.524 .35333 Mdot
.524 .35377 Mdot
.524 .35467 Mdot
.524 .35566 Mdot
.524 .35576 Mdot
.524 .35596 Mdot
.524 .35626 Mdot
.524 .3563 Mdot
.524 .35667 Mdot
.524 .35821 Mdot
.524 .35845 Mdot
.524 .35968 Mdot
.524 .35998 Mdot
.524 .36064 Mdot
.524 .36073 Mdot
.524 .36098 Mdot
.524 .36128 Mdot
.524 .36215 Mdot
.524 .3631 Mdot
.524 .36328 Mdot
.524 .3642 Mdot
.524 .36555 Mdot
.524 .36568 Mdot
.524 .36627 Mdot
.524 .36659 Mdot
.524 .36708 Mdot
.524 .36715 Mdot
.524 .36718 Mdot
.524 .36725 Mdot
.524 .36765 Mdot
.524 .36918 Mdot
.524 .36962 Mdot
.524 .37012 Mdot
.524 .37028 Mdot
.524 .37065 Mdot
.524 .37084 Mdot
.524 .37142 Mdot
.524 .37145 Mdot
.524 .37157 Mdot
.524 .37159 Mdot
.524 .3717 Mdot
.524 .37171 Mdot
.524 .37187 Mdot
.524 .37188 Mdot
.524 .37294 Mdot
.524 .37513 Mdot
.524 .37577 Mdot
.524 .37603 Mdot
.524 .37634 Mdot
.524 .37651 Mdot
.524 .37684 Mdot
.524 .3771 Mdot
.524 .37716 Mdot
.524 .37729 Mdot
.524 .3773 Mdot
.524 .37812 Mdot
.524 .37817 Mdot
.524 .37824 Mdot
.524 .37849 Mdot
.524 .37888 Mdot
.524 .37906 Mdot
.524 .37921 Mdot
.524 .37946 Mdot
.524 .37949 Mdot
.524 .37962 Mdot
.524 .38026 Mdot
.524 .38034 Mdot
.524 .3812 Mdot
.524 .3817 Mdot
.524 .38184 Mdot
.524 .38223 Mdot
.524 .38247 Mdot
.524 .38281 Mdot
.524 .38302 Mdot
.524 .38318 Mdot
.524 .38394 Mdot
.524 .38404 Mdot
.524 .38409 Mdot
.524 .38425 Mdot
.524 .38426 Mdot
.524 .38429 Mdot
.524 .38429 Mdot
.524 .38433 Mdot
.524 .38437 Mdot
.524 .38437 Mdot
.524 .47179 Mdot
.524 .47179 Mdot
.524 .47181 Mdot
.524 .47183 Mdot
.524 .47183 Mdot
.524 .47185 Mdot
.524 .47185 Mdot
.524 .47193 Mdot
.524 .47196 Mdot
.524 .472 Mdot
.524 .47238 Mdot
.524 .47246 Mdot
.524 .47257 Mdot
.524 .47274 Mdot
.524 .47286 Mdot
.524 .47305 Mdot
.524 .47312 Mdot
.524 .47336 Mdot
.524 .47379 Mdot
.524 .47383 Mdot
.524 .47415 Mdot
.524 .47421 Mdot
.524 .47423 Mdot
.524 .47435 Mdot
.524 .47442 Mdot
.524 .47451 Mdot
.524 .4747 Mdot
.524 .47483 Mdot
.524 .47486 Mdot
.524 .47488 Mdot
.524 .47529 Mdot
.524 .47529 Mdot
.524 .47535 Mdot
.524 .47538 Mdot
.524 .47551 Mdot
.524 .47567 Mdot
.524 .47576 Mdot
.524 .47591 Mdot
.524 .47603 Mdot
.524 .47634 Mdot
.524 .4774 Mdot
.524 .47792 Mdot
.524 .47792 Mdot
.524 .478 Mdot
.524 .478 Mdot
.524 .47805 Mdot
.524 .47807 Mdot
.524 .47812 Mdot
.524 .47814 Mdot
.524 .47841 Mdot
.524 .47851 Mdot
.524 .47868 Mdot
.524 .47876 Mdot
.524 .479 Mdot
.524 .47921 Mdot
.524 .47994 Mdot
.524 .48013 Mdot
.524 .48016 Mdot
.524 .48018 Mdot
.524 .48021 Mdot
.524 .48044 Mdot
.524 .48059 Mdot
.524 .48087 Mdot
.524 .48094 Mdot
.524 .48157 Mdot
.524 .48201 Mdot
.524 .48209 Mdot
.524 .48253 Mdot
.524 .48294 Mdot
.524 .48308 Mdot
.524 .4832 Mdot
.524 .48324 Mdot
.524 .48355 Mdot
.524 .48369 Mdot
.524 .48426 Mdot
.524 .48437 Mdot
.524 .48509 Mdot
.524 .48526 Mdot
.524 .48527 Mdot
.524 .48541 Mdot
.524 .4855 Mdot
.524 .48555 Mdot
.524 .48601 Mdot
.524 .48642 Mdot
.524 .48662 Mdot
.524 .48684 Mdot
.524 .48698 Mdot
.524 .48705 Mdot
.524 .48707 Mdot
.524 .48745 Mdot
.524 .48747 Mdot
.524 .48768 Mdot
.524 .48773 Mdot
.524 .48807 Mdot
.524 .48821 Mdot
.524 .48841 Mdot
.524 .48855 Mdot
.524 .48864 Mdot
.524 .48908 Mdot
.524 .48926 Mdot
.524 .48965 Mdot
.524 .49011 Mdot
.524 .49063 Mdot
.524 .49109 Mdot
.524 .49114 Mdot
.524 .49177 Mdot
.524 .49183 Mdot
.524 .4919 Mdot
.524 .49201 Mdot
.524 .49213 Mdot
.524 .49357 Mdot
.524 .49415 Mdot
.524 .49438 Mdot
.524 .4944 Mdot
.524 .49453 Mdot
.524 .49467 Mdot
.524 .49469 Mdot
.524 .49477 Mdot
.524 .49493 Mdot
.524 .49501 Mdot
.524 .49535 Mdot
.524 .49555 Mdot
.524 .49565 Mdot
.524 .49573 Mdot
.524 .49658 Mdot
.524 .49707 Mdot
.524 .49757 Mdot
.524 .49774 Mdot
.524 .49794 Mdot
.524 .49868 Mdot
.524 .4991 Mdot
.524 .5005 Mdot
.524 .50056 Mdot
.524 .50068 Mdot
.524 .50205 Mdot
.524 .50209 Mdot
.524 .50328 Mdot
.524 .50382 Mdot
.524 .5052 Mdot
.524 .50532 Mdot
.524 .50534 Mdot
.524 .50546 Mdot
.524 .5058 Mdot
.524 .50589 Mdot
.524 .50651 Mdot
.524 .50686 Mdot
.524 .50694 Mdot
.524 .50709 Mdot
.524 .50802 Mdot
.524 .50819 Mdot
.524 .50858 Mdot
.524 .50882 Mdot
.524 .50889 Mdot
.524 .50916 Mdot
.524 .50989 Mdot
.524 .50995 Mdot
.524 .50996 Mdot
.524 .51006 Mdot
.524 .51012 Mdot
.524 .51019 Mdot
.524 .51034 Mdot
.524 .51044 Mdot
.524 .51046 Mdot
.524 .51048 Mdot
.524 .51077 Mdot
.524 .51077 Mdot
.524 .51082 Mdot
.524 .51084 Mdot
.524 .51119 Mdot
.524 .51127 Mdot
.524 .51146 Mdot
.524 .51209 Mdot
.524 .51237 Mdot
.524 .51237 Mdot
.524 .51241 Mdot
.524 .51244 Mdot
.524 .51245 Mdot
.524 .51248 Mdot
.524 .51248 Mdot
.524 .51263 Mdot
.524 .51268 Mdot
.524 .51276 Mdot
.524 .51292 Mdot
.524 .51303 Mdot
.524 .51338 Mdot
.524 .51346 Mdot
.524 .51348 Mdot
.524 .5135 Mdot
.524 .51361 Mdot
.524 .5138 Mdot
.524 .51411 Mdot
.524 .51433 Mdot
.524 .51451 Mdot
.524 .51468 Mdot
.524 .51478 Mdot
.524 .5148 Mdot
.524 .51492 Mdot
.524 .51498 Mdot
.524 .5152 Mdot
.524 .51524 Mdot
.524 .51558 Mdot
.524 .51563 Mdot
.524 .51568 Mdot
.524 .516 Mdot
.524 .51607 Mdot
.524 .5162 Mdot
.524 .51623 Mdot
.524 .51637 Mdot
.524 .51663 Mdot
.524 .51675 Mdot
.524 .51678 Mdot
.524 .51699 Mdot
.524 .51712 Mdot
.524 .51727 Mdot
.524 .51759 Mdot
.524 .5176 Mdot
.524 .5178 Mdot
.524 .51782 Mdot
.524 .51785 Mdot
.524 .51788 Mdot
.524 .51792 Mdot
.524 .51837 Mdot
.524 .51855 Mdot
.524 .51862 Mdot
.524 .51862 Mdot
.524 .51866 Mdot
.524 .51871 Mdot
.524 .51873 Mdot
.524 .51878 Mdot
.524 .519 Mdot
.524 .51928 Mdot
.524 .51942 Mdot
.524 .51967 Mdot
.524 .51989 Mdot
.524 .52041 Mdot
.524 .52042 Mdot
.524 .52084 Mdot
.524 .52174 Mdot
.524 .52175 Mdot
.524 .52187 Mdot
.524 .52216 Mdot
.524 .52222 Mdot
.524 .52262 Mdot
.524 .52278 Mdot
.524 .52297 Mdot
.524 .52299 Mdot
.524 .52299 Mdot
.524 .52305 Mdot
.524 .52312 Mdot
.524 .52313 Mdot
.524 .52313 Mdot
.524 .52321 Mdot
.524 .52322 Mdot
.524 .52323 Mdot
.524 .52332 Mdot
.524 .52334 Mdot
.524 .52378 Mdot
.524 .52381 Mdot
.524 .52393 Mdot
.524 .52394 Mdot
.524 .5242 Mdot
.524 .52433 Mdot
.524 .52449 Mdot
.524 .52466 Mdot
.524 .5247 Mdot
.524 .52502 Mdot
.524 .52508 Mdot
.524 .52509 Mdot
.524 .52528 Mdot
.524 .52531 Mdot
.524 .52615 Mdot
.524 .52643 Mdot
.524 .52648 Mdot
.524 .52651 Mdot
.524 .52653 Mdot
.524 .52655 Mdot
.524 .52675 Mdot
.524 .5269 Mdot
.524 .52707 Mdot
.524 .52713 Mdot
.524 .52754 Mdot
.524 .52763 Mdot
.524 .52828 Mdot
.524 .52845 Mdot
.524 .52856 Mdot
.524 .52918 Mdot
.524 .5292 Mdot
.524 .52929 Mdot
.524 .5293 Mdot
.524 .52959 Mdot
.524 .52986 Mdot
.524 .52992 Mdot
.524 .53021 Mdot
.524 .53025 Mdot
.524 .53029 Mdot
.524 .53032 Mdot
.524 .53042 Mdot
.524 .53049 Mdot
.524 .53068 Mdot
.524 .53084 Mdot
.524 .5309 Mdot
.524 .5309 Mdot
.524 .53131 Mdot
.524 .5315 Mdot
.524 .53226 Mdot
.524 .53228 Mdot
.524 .53233 Mdot
.524 .53241 Mdot
.524 .53263 Mdot
.524 .53265 Mdot
.524 .53274 Mdot
.524 .53325 Mdot
.524 .53331 Mdot
.524 .53332 Mdot
.524 .53354 Mdot
.524 .53356 Mdot
.524 .53358 Mdot
.524 .53374 Mdot
.524 .53383 Mdot
.524 .53385 Mdot
.524 .5339 Mdot
.524 .53401 Mdot
.524 .53442 Mdot
.524 .53443 Mdot
.524 .53447 Mdot
.524 .5346 Mdot
.524 .53464 Mdot
.524 .53497 Mdot
.524 .53521 Mdot
.524 .53528 Mdot
.524 .53532 Mdot
.524 .53545 Mdot
.524 .53546 Mdot
.524 .53547 Mdot
.524 .53547 Mdot
.524 .53558 Mdot
.524 .53559 Mdot
.524 .5356 Mdot
.524 .53564 Mdot
.524 .53569 Mdot
.524 .53572 Mdot
.524 .53574 Mdot
.524 .53578 Mdot
.524 .53578 Mdot
.524 .5358 Mdot
.524 .53608 Mdot
.524 .53618 Mdot
.524 .5362 Mdot
.524 .53629 Mdot
.524 .53644 Mdot
.524 .53649 Mdot
.524 .53683 Mdot
.524 .53688 Mdot
.524 .53692 Mdot
.524 .53704 Mdot
.524 .53726 Mdot
.524 .53729 Mdot
.524 .53741 Mdot
.524 .53745 Mdot
.524 .53746 Mdot
.524 .5375 Mdot
.524 .53798 Mdot
.524 .53816 Mdot
.524 .53857 Mdot
.524 .53858 Mdot
.524 .53904 Mdot
.524 .53908 Mdot
.524 .5391 Mdot
.524 .53955 Mdot
.524 .53969 Mdot
.524 .53993 Mdot
.524 .53999 Mdot
.524 .54004 Mdot
.524 .5402 Mdot
.524 .54036 Mdot
.524 .54063 Mdot
.524 .54065 Mdot
.524 .54068 Mdot
.524 .54074 Mdot
.524 .54085 Mdot
.524 .54087 Mdot
.524 .54092 Mdot
.524 .54095 Mdot
.524 .54095 Mdot
.524 .541 Mdot
.524 .54104 Mdot
.524 .54104 Mdot
.524 .54111 Mdot
.524 .54129 Mdot
.524 .54172 Mdot
.524 .54176 Mdot
.524 .54179 Mdot
.524 .54182 Mdot
.524 .54183 Mdot
.524 .54202 Mdot
.524 .54204 Mdot
.524 .54217 Mdot
.524 .54233 Mdot
.524 .54246 Mdot
.524 .54257 Mdot
.524 .54263 Mdot
.524 .54276 Mdot
.524 .54278 Mdot
.524 .5428 Mdot
.524 .54282 Mdot
.524 .54288 Mdot
.524 .54292 Mdot
.524 .54302 Mdot
.524 .54303 Mdot
.524 .54309 Mdot
.524 .5431 Mdot
.524 .5432 Mdot
.524 .54321 Mdot
.524 .54323 Mdot
.524 .54327 Mdot
.524 .54333 Mdot
.524 .54339 Mdot
.524 .54351 Mdot
.524 .54364 Mdot
.524 .54365 Mdot
.524 .54367 Mdot
.524 .54371 Mdot
.524 .54372 Mdot
.524 .54377 Mdot
.524 .54396 Mdot
.524 .544 Mdot
.524 .54415 Mdot
.524 .54419 Mdot
.524 .54428 Mdot
.524 .54429 Mdot
.524 .54432 Mdot
.524 .54436 Mdot
.524 .54447 Mdot
.524 .54459 Mdot
.524 .54462 Mdot
.524 .54473 Mdot
.524 .54491 Mdot
.524 .54492 Mdot
.524 .545 Mdot
.524 .54504 Mdot
.524 .5451 Mdot
.524 .54511 Mdot
.524 .54511 Mdot
.524 .54512 Mdot
.524 .54517 Mdot
.524 .54537 Mdot
.524 .54543 Mdot
.524 .54549 Mdot
.524 .54551 Mdot
.524 .54556 Mdot
.524 .54558 Mdot
.524 .54565 Mdot
.524 .54566 Mdot
.524 .54567 Mdot
.524 .54568 Mdot
.524 .54569 Mdot
.524 .54569 Mdot
.524 .54571 Mdot
.524 .54571 Mdot
.524 .54585 Mdot
.524 .54612 Mdot
.524 .5462 Mdot
.524 .54624 Mdot
.524 .54627 Mdot
.524 .5463 Mdot
.524 .54634 Mdot
.524 .54637 Mdot
.524 .54638 Mdot
.524 .54639 Mdot
.524 .5464 Mdot
.524 .5465 Mdot
.524 .54651 Mdot
.524 .54651 Mdot
.524 .54655 Mdot
.524 .5466 Mdot
.524 .54662 Mdot
.524 .54664 Mdot
.524 .54667 Mdot
.524 .54667 Mdot
.524 .54669 Mdot
.524 .54677 Mdot
.524 .54678 Mdot
.524 .54689 Mdot
.524 .54695 Mdot
.524 .54697 Mdot
.524 .54702 Mdot
.524 .54705 Mdot
.524 .54709 Mdot
.524 .54711 Mdot
.524 .54713 Mdot
.524 .54723 Mdot
.524 .54724 Mdot
.524 .54725 Mdot
.524 .54727 Mdot
.524 .54727 Mdot
.524 .54727 Mdot
.524 .54727 Mdot
.524 .54728 Mdot
.524 .54728 Mdot
.524 .54728 Mdot
.526 .1976 Mdot
.526 .19761 Mdot
.526 .19762 Mdot
.526 .19764 Mdot
.526 .19766 Mdot
.526 .19766 Mdot
.526 .19775 Mdot
.526 .19779 Mdot
.526 .19782 Mdot
.526 .19785 Mdot
.526 .19793 Mdot
.526 .19801 Mdot
.526 .19811 Mdot
.526 .19812 Mdot
.526 .19818 Mdot
.526 .19823 Mdot
.526 .19865 Mdot
.526 .19865 Mdot
.526 .1988 Mdot
.526 .19884 Mdot
.526 .19888 Mdot
.526 .199 Mdot
.526 .19926 Mdot
.526 .19938 Mdot
.526 .19943 Mdot
.526 .19971 Mdot
.526 .20003 Mdot
.526 .20015 Mdot
.526 .20023 Mdot
.526 .20055 Mdot
.526 .20067 Mdot
.526 .20069 Mdot
.526 .20073 Mdot
.526 .20076 Mdot
.526 .20082 Mdot
.526 .20086 Mdot
.526 .20088 Mdot
.526 .20116 Mdot
.526 .20117 Mdot
.526 .20123 Mdot
.526 .2013 Mdot
.526 .20138 Mdot
.526 .20147 Mdot
.526 .20148 Mdot
.526 .20152 Mdot
.526 .20176 Mdot
.526 .20206 Mdot
.526 .20207 Mdot
.526 .20216 Mdot
.526 .20234 Mdot
.526 .2024 Mdot
.526 .20244 Mdot
.526 .20264 Mdot
.526 .20266 Mdot
.526 .20287 Mdot
.526 .2031 Mdot
.526 .20356 Mdot
.526 .20379 Mdot
.526 .20385 Mdot
.526 .20385 Mdot
.526 .20392 Mdot
.526 .20408 Mdot
.526 .20445 Mdot
.526 .2046 Mdot
.526 .2046 Mdot
.526 .20483 Mdot
.526 .20509 Mdot
.526 .20527 Mdot
.526 .20533 Mdot
.526 .20542 Mdot
.526 .20566 Mdot
.526 .20617 Mdot
.526 .20624 Mdot
.526 .20752 Mdot
.526 .20772 Mdot
.526 .20779 Mdot
.526 .20785 Mdot
.526 .20802 Mdot
.526 .20803 Mdot
.526 .20815 Mdot
.526 .20818 Mdot
.526 .20818 Mdot
.526 .20845 Mdot
.526 .20864 Mdot
.526 .20876 Mdot
.526 .20902 Mdot
.526 .20971 Mdot
.526 .21 Mdot
.526 .21005 Mdot
.526 .21007 Mdot
.526 .21013 Mdot
.526 .21031 Mdot
.526 .21083 Mdot
.526 .21085 Mdot
.526 .21115 Mdot
.526 .21131 Mdot
.526 .21142 Mdot
.526 .21153 Mdot
.526 .21154 Mdot
.526 .21187 Mdot
.526 .21216 Mdot
.526 .21261 Mdot
.526 .21308 Mdot
.526 .21325 Mdot
.526 .2133 Mdot
.526 .21384 Mdot
.526 .21432 Mdot
.526 .21459 Mdot
.526 .21474 Mdot
.526 .21513 Mdot
.526 .21553 Mdot
.526 .21592 Mdot
.526 .21604 Mdot
.526 .21605 Mdot
.526 .21633 Mdot
.526 .21651 Mdot
.526 .2168 Mdot
.526 .21691 Mdot
.526 .21696 Mdot
.526 .21723 Mdot
.526 .21723 Mdot
.526 .21731 Mdot
.526 .21734 Mdot
.526 .21849 Mdot
.526 .21866 Mdot
.526 .2188 Mdot
.526 .21901 Mdot
.526 .21931 Mdot
.526 .21935 Mdot
.526 .21936 Mdot
.526 .21981 Mdot
.526 .2203 Mdot
.526 .22088 Mdot
.526 .22091 Mdot
.526 .22155 Mdot
.526 .22165 Mdot
.526 .22193 Mdot
.526 .222 Mdot
.526 .22243 Mdot
.526 .22272 Mdot
.526 .22344 Mdot
.526 .22371 Mdot
.526 .22461 Mdot
.526 .22464 Mdot
.526 .22505 Mdot
.526 .22537 Mdot
.526 .22545 Mdot
.526 .2256 Mdot
.526 .22603 Mdot
.526 .22605 Mdot
.526 .22616 Mdot
.526 .22688 Mdot
.526 .22715 Mdot
.526 .22725 Mdot
.526 .22829 Mdot
.526 .22875 Mdot
.526 .22911 Mdot
.526 .22922 Mdot
.526 .22993 Mdot
.526 .23015 Mdot
.526 .23026 Mdot
.526 .23043 Mdot
.526 .23075 Mdot
.526 .2309 Mdot
.526 .23161 Mdot
.526 .23265 Mdot
.526 .23271 Mdot
.526 .23338 Mdot
.526 .23345 Mdot
.526 .2338 Mdot
.526 .23443 Mdot
.526 .23459 Mdot
.526 .23477 Mdot
.526 .23554 Mdot
.526 .23603 Mdot
.526 .23687 Mdot
.526 .23709 Mdot
.526 .23711 Mdot
.526 .23803 Mdot
.526 .23805 Mdot
.526 .23816 Mdot
.526 .23863 Mdot
.526 .23868 Mdot
.526 .23873 Mdot
.526 .23873 Mdot
.526 .23952 Mdot
.526 .23975 Mdot
.526 .24007 Mdot
.526 .24067 Mdot
.526 .24098 Mdot
.526 .24115 Mdot
.526 .24119 Mdot
.526 .24164 Mdot
.526 .24185 Mdot
.526 .24297 Mdot
.526 .24323 Mdot
.526 .24425 Mdot
.526 .24663 Mdot
.526 .24684 Mdot
.526 .24686 Mdot
.526 .24698 Mdot
.526 .24728 Mdot
.526 .24801 Mdot
.526 .24802 Mdot
.526 .24852 Mdot
.526 .24941 Mdot
.526 .24981 Mdot
.526 .25019 Mdot
.526 .25095 Mdot
.526 .25096 Mdot
.526 .25145 Mdot
.526 .2517 Mdot
.526 .25215 Mdot
.526 .25249 Mdot
.526 .25259 Mdot
.526 .25262 Mdot
.526 .25263 Mdot
.526 .25264 Mdot
.526 .25265 Mdot
.526 .25271 Mdot
.526 .25289 Mdot
.526 .25354 Mdot
.526 .25395 Mdot
.526 .25438 Mdot
.526 .25487 Mdot
.526 .25515 Mdot
.526 .25515 Mdot
.526 .25579 Mdot
.526 .25581 Mdot
.526 .25593 Mdot
.526 .25728 Mdot
.526 .25787 Mdot
.526 .25802 Mdot
.526 .25868 Mdot
.526 .2588 Mdot
.526 .25906 Mdot
.526 .25909 Mdot
.526 .25937 Mdot
.526 .26054 Mdot
.526 .2606 Mdot
.526 .26154 Mdot
.526 .26155 Mdot
.526 .26301 Mdot
.526 .26312 Mdot
.526 .26363 Mdot
.526 .26385 Mdot
.526 .2639 Mdot
.526 .26434 Mdot
.526 .26437 Mdot
.526 .26553 Mdot
.526 .26563 Mdot
.526 .26675 Mdot
.526 .26699 Mdot
.526 .26731 Mdot
.526 .2683 Mdot
.526 .26882 Mdot
.526 .26891 Mdot
.526 .26922 Mdot
.526 .27062 Mdot
.526 .27136 Mdot
.526 .27192 Mdot
.526 .27197 Mdot
.526 .27219 Mdot
.526 .27227 Mdot
.526 .2728 Mdot
.526 .27326 Mdot
.526 .27365 Mdot
.526 .27402 Mdot
.526 .27406 Mdot
.526 .2743 Mdot
.526 .27474 Mdot
.526 .27571 Mdot
.526 .27573 Mdot
.526 .2758 Mdot
.526 .2758 Mdot
.526 .27608 Mdot
.526 .27618 Mdot
.526 .27643 Mdot
.526 .27658 Mdot
.526 .27683 Mdot
.526 .27684 Mdot
.526 .27694 Mdot
.526 .27766 Mdot
.526 .27814 Mdot
.526 .27884 Mdot
.526 .27936 Mdot
.526 .27957 Mdot
.526 .28002 Mdot
.526 .28075 Mdot
.526 .28108 Mdot
.526 .28109 Mdot
.526 .28121 Mdot
.526 .28132 Mdot
.526 .28236 Mdot
.526 .28261 Mdot
.526 .28264 Mdot
.526 .28268 Mdot
.526 .2844 Mdot
.526 .28471 Mdot
.526 .28472 Mdot
.526 .28475 Mdot
.526 .28525 Mdot
.526 .28549 Mdot
.526 .28707 Mdot
.526 .28716 Mdot
.526 .28783 Mdot
.526 .28807 Mdot
.526 .28827 Mdot
.526 .28834 Mdot
.526 .28928 Mdot
.526 .28928 Mdot
.526 .29003 Mdot
.526 .29045 Mdot
.526 .2908 Mdot
.526 .2919 Mdot
.526 .29224 Mdot
.526 .29227 Mdot
.526 .29261 Mdot
.526 .29269 Mdot
.526 .29309 Mdot
.526 .29325 Mdot
.526 .29328 Mdot
.526 .29382 Mdot
.526 .29435 Mdot
.526 .29453 Mdot
.526 .29468 Mdot
.526 .29481 Mdot
.526 .29494 Mdot
.526 .29495 Mdot
.526 .29553 Mdot
.526 .29555 Mdot
.526 .29565 Mdot
.526 .29577 Mdot
.526 .29583 Mdot
.526 .29592 Mdot
.526 .29739 Mdot
.526 .29907 Mdot
.526 .29943 Mdot
.526 .3002 Mdot
.526 .30059 Mdot
.526 .30087 Mdot
.526 .3014 Mdot
.526 .3031 Mdot
.526 .30336 Mdot
.526 .30423 Mdot
.526 .30533 Mdot
.526 .30788 Mdot
.526 .30811 Mdot
.526 .30877 Mdot
.526 .31055 Mdot
.526 .31081 Mdot
.526 .31087 Mdot
.526 .31192 Mdot
.526 .31229 Mdot
.526 .31249 Mdot
.526 .31329 Mdot
.526 .31432 Mdot
.526 .31438 Mdot
.526 .31664 Mdot
.526 .31731 Mdot
.526 .3191 Mdot
.526 .31985 Mdot
.526 .32092 Mdot
.526 .3211 Mdot
.526 .32181 Mdot
.526 .32207 Mdot
.526 .3237 Mdot
.526 .32378 Mdot
.526 .32525 Mdot
.526 .3265 Mdot
.526 .32766 Mdot
.526 .32767 Mdot
.526 .32778 Mdot
.526 .32854 Mdot
.526 .32908 Mdot
.526 .32944 Mdot
.526 .32989 Mdot
.526 .33287 Mdot
.526 .33293 Mdot
.526 .33314 Mdot
.526 .33315 Mdot
.526 .33385 Mdot
.526 .33398 Mdot
.526 .33427 Mdot
.526 .33503 Mdot
.526 .33548 Mdot
.526 .33622 Mdot
.526 .33624 Mdot
.526 .33655 Mdot
.526 .33757 Mdot
.526 .33863 Mdot
.526 .33964 Mdot
.526 .34003 Mdot
.526 .34074 Mdot
.526 .342 Mdot
.526 .34344 Mdot
.526 .34356 Mdot
.526 .34401 Mdot
.526 .34526 Mdot
.526 .34644 Mdot
.526 .34721 Mdot
.526 .34809 Mdot
.526 .34811 Mdot
.526 .34841 Mdot
.526 .34864 Mdot
.526 .3487 Mdot
.526 .34914 Mdot
.526 .34992 Mdot
.526 .34999 Mdot
.526 .35136 Mdot
.526 .35185 Mdot
.526 .352 Mdot
.526 .35207 Mdot
.526 .35218 Mdot
.526 .35297 Mdot
.526 .35481 Mdot
.526 .35551 Mdot
.526 .35582 Mdot
.526 .35635 Mdot
.526 .35707 Mdot
.526 .35707 Mdot
.526 .35714 Mdot
.526 .35746 Mdot
.526 .35749 Mdot
.526 .35797 Mdot
.526 .35811 Mdot
.526 .3583 Mdot
.526 .35884 Mdot
.526 .3623 Mdot
.526 .36248 Mdot
.526 .36387 Mdot
.526 .3645 Mdot
.526 .36476 Mdot
.526 .3649 Mdot
.526 .3654 Mdot
.526 .3661 Mdot
.526 .36673 Mdot
.526 .36674 Mdot
.526 .36714 Mdot
.526 .36815 Mdot
.526 .36856 Mdot
.526 .36876 Mdot
.526 .36877 Mdot
.526 .36892 Mdot
.526 .36954 Mdot
.526 .37081 Mdot
.526 .37142 Mdot
.526 .37199 Mdot
.526 .37204 Mdot
.526 .37259 Mdot
.526 .37271 Mdot
.526 .37286 Mdot
.526 .37334 Mdot
.526 .37359 Mdot
.526 .37363 Mdot
.526 .37445 Mdot
.526 .37509 Mdot
.526 .3752 Mdot
.526 .37523 Mdot
.526 .37548 Mdot
.526 .3757 Mdot
.526 .37588 Mdot
.526 .37606 Mdot
.526 .37607 Mdot
.526 .37685 Mdot
.526 .37688 Mdot
.526 .37701 Mdot
.526 .37717 Mdot
.526 .37724 Mdot
.526 .37736 Mdot
.526 .37741 Mdot
.526 .37774 Mdot
.526 .37861 Mdot
.526 .37882 Mdot
.526 .37915 Mdot
.526 .38002 Mdot
.526 .38079 Mdot
.526 .38093 Mdot
.526 .38127 Mdot
.526 .38197 Mdot
.526 .3823 Mdot
.526 .38241 Mdot
.526 .38253 Mdot
.526 .38294 Mdot
.526 .38294 Mdot
.526 .38407 Mdot
.526 .38422 Mdot
.526 .38438 Mdot
.526 .38441 Mdot
.526 .38467 Mdot
.526 .3849 Mdot
.526 .38513 Mdot
.526 .3852 Mdot
.526 .38527 Mdot
.526 .38538 Mdot
.526 .38563 Mdot
.526 .38564 Mdot
.526 .38568 Mdot
.526 .38573 Mdot
.526 .38576 Mdot
.526 .3858 Mdot
.526 .47116 Mdot
.526 .47118 Mdot
.526 .47119 Mdot
.526 .47122 Mdot
.526 .47124 Mdot
.526 .47124 Mdot
.526 .47137 Mdot
.526 .47142 Mdot
.526 .47146 Mdot
.526 .47149 Mdot
.526 .47161 Mdot
.526 .47172 Mdot
.526 .47185 Mdot
.526 .47187 Mdot
.526 .47195 Mdot
.526 .47202 Mdot
.526 .47259 Mdot
.526 .47259 Mdot
.526 .47279 Mdot
.526 .47285 Mdot
.526 .4729 Mdot
.526 .47307 Mdot
.526 .47341 Mdot
.526 .47358 Mdot
.526 .47365 Mdot
.526 .47403 Mdot
.526 .47446 Mdot
.526 .47462 Mdot
.526 .47472 Mdot
.526 .47515 Mdot
.526 .47531 Mdot
.526 .47533 Mdot
.526 .47539 Mdot
.526 .47542 Mdot
.526 .4755 Mdot
.526 .47557 Mdot
.526 .47558 Mdot
.526 .47596 Mdot
.526 .47597 Mdot
.526 .47605 Mdot
.526 .47614 Mdot
.526 .47625 Mdot
.526 .47637 Mdot
.526 .47639 Mdot
.526 .47644 Mdot
.526 .47675 Mdot
.526 .47714 Mdot
.526 .47717 Mdot
.526 .47729 Mdot
.526 .47752 Mdot
.526 .47759 Mdot
.526 .47765 Mdot
.526 .47791 Mdot
.526 .47794 Mdot
.526 .47821 Mdot
.526 .47851 Mdot
.526 .47911 Mdot
.526 .47941 Mdot
.526 .47948 Mdot
.526 .47948 Mdot
.526 .47958 Mdot
.526 .47978 Mdot
.526 .48025 Mdot
.526 .48045 Mdot
.526 .48045 Mdot
.526 .48075 Mdot
.526 .48108 Mdot
.526 .48132 Mdot
.526 .48138 Mdot
.526 .4815 Mdot
.526 .4818 Mdot
.526 .48246 Mdot
.526 .48254 Mdot
.526 .48415 Mdot
.526 .4844 Mdot
.526 .48449 Mdot
.526 .48456 Mdot
.526 .48478 Mdot
.526 .48479 Mdot
.526 .48494 Mdot
.526 .48497 Mdot
.526 .48497 Mdot
.526 .4853 Mdot
.526 .48555 Mdot
.526 .48569 Mdot
.526 .48601 Mdot
.526 .48685 Mdot
.526 .48721 Mdot
.526 .48726 Mdot
.526 .4873 Mdot
.526 .48737 Mdot
.526 .48759 Mdot
.526 .48821 Mdot
.526 .48824 Mdot
.526 .4886 Mdot
.526 .48879 Mdot
.526 .48893 Mdot
.526 .48906 Mdot
.526 .48907 Mdot
.526 .48947 Mdot
.526 .48981 Mdot
.526 .49035 Mdot
.526 .4909 Mdot
.526 .49111 Mdot
.526 .49116 Mdot
.526 .4918 Mdot
.526 .49236 Mdot
.526 .49268 Mdot
.526 .49285 Mdot
.526 .49329 Mdot
.526 .49376 Mdot
.526 .49421 Mdot
.526 .49434 Mdot
.526 .49435 Mdot
.526 .49467 Mdot
.526 .49487 Mdot
.526 .4952 Mdot
.526 .49533 Mdot
.526 .49539 Mdot
.526 .49569 Mdot
.526 .4957 Mdot
.526 .49579 Mdot
.526 .49582 Mdot
.526 .49711 Mdot
.526 .4973 Mdot
.526 .49746 Mdot
.526 .49769 Mdot
.526 .49802 Mdot
.526 .49807 Mdot
.526 .49807 Mdot
.526 .49857 Mdot
.526 .4991 Mdot
.526 .49973 Mdot
.526 .49976 Mdot
.526 .50046 Mdot
.526 .50057 Mdot
.526 .50087 Mdot
.526 .50094 Mdot
.526 .5014 Mdot
.526 .50171 Mdot
.526 .50247 Mdot
.526 .50275 Mdot
.526 .5037 Mdot
.526 .50372 Mdot
.526 .50415 Mdot
.526 .50448 Mdot
.526 .50456 Mdot
.526 .50472 Mdot
.526 .50516 Mdot
.526 .50518 Mdot
.526 .50529 Mdot
.526 .50602 Mdot
.526 .5063 Mdot
.526 .50639 Mdot
.526 .50744 Mdot
.526 .50789 Mdot
.526 .50824 Mdot
.526 .50835 Mdot
.526 .50904 Mdot
.526 .50926 Mdot
.526 .50937 Mdot
.526 .50953 Mdot
.526 .50984 Mdot
.526 .50998 Mdot
.526 .51066 Mdot
.526 .51126 Mdot
.526 .51129 Mdot
.526 .51131 Mdot
.526 .51136 Mdot
.526 .5114 Mdot
.526 .51141 Mdot
.526 .51164 Mdot
.526 .51165 Mdot
.526 .5117 Mdot
.526 .51175 Mdot
.526 .51181 Mdot
.526 .51188 Mdot
.526 .5121 Mdot
.526 .51231 Mdot
.526 .51233 Mdot
.526 .51239 Mdot
.526 .51255 Mdot
.526 .51258 Mdot
.526 .51272 Mdot
.526 .51273 Mdot
.526 .51287 Mdot
.526 .5133 Mdot
.526 .51344 Mdot
.526 .51361 Mdot
.526 .51391 Mdot
.526 .51391 Mdot
.526 .51428 Mdot
.526 .51431 Mdot
.526 .51439 Mdot
.526 .51448 Mdot
.526 .51475 Mdot
.526 .51478 Mdot
.526 .51541 Mdot
.526 .5155 Mdot
.526 .5157 Mdot
.526 .51571 Mdot
.526 .51571 Mdot
.526 .51583 Mdot
.526 .51651 Mdot
.526 .51652 Mdot
.526 .51654 Mdot
.526 .51664 Mdot
.526 .51704 Mdot
.526 .51708 Mdot
.526 .51713 Mdot
.526 .51713 Mdot
.526 .51726 Mdot
.526 .51755 Mdot
.526 .51772 Mdot
.526 .51781 Mdot
.526 .51801 Mdot
.526 .51828 Mdot
.526 .51847 Mdot
.526 .51874 Mdot
.526 .51878 Mdot
.526 .51879 Mdot
.526 .51888 Mdot
.526 .51894 Mdot
.526 .51904 Mdot
.526 .51908 Mdot
.526 .51919 Mdot
.526 .51919 Mdot
.526 .51921 Mdot
.526 .51922 Mdot
.526 .5196 Mdot
.526 .51976 Mdot
.526 .51986 Mdot
.526 .51987 Mdot
.526 .52001 Mdot
.526 .52017 Mdot
.526 .52034 Mdot
.526 .52055 Mdot
.526 .52058 Mdot
.526 .52066 Mdot
.526 .52068 Mdot
.526 .5209 Mdot
.526 .52118 Mdot
.526 .52172 Mdot
.526 .52183 Mdot
.526 .52187 Mdot
.526 .52207 Mdot
.526 .52245 Mdot
.526 .52257 Mdot
.526 .52266 Mdot
.526 .52308 Mdot
.526 .52312 Mdot
.526 .52356 Mdot
.526 .52357 Mdot
.526 .52374 Mdot
.526 .52376 Mdot
.526 .52384 Mdot
.526 .52403 Mdot
.526 .52408 Mdot
.526 .52463 Mdot
.526 .52463 Mdot
.526 .52498 Mdot
.526 .52501 Mdot
.526 .52545 Mdot
.526 .52555 Mdot
.526 .52556 Mdot
.526 .52566 Mdot
.526 .52571 Mdot
.526 .52595 Mdot
.526 .52601 Mdot
.526 .52623 Mdot
.526 .52674 Mdot
.526 .52678 Mdot
.526 .52679 Mdot
.526 .52703 Mdot
.526 .52703 Mdot
.526 .52713 Mdot
.526 .52731 Mdot
.526 .52747 Mdot
.526 .52763 Mdot
.526 .52787 Mdot
.526 .52794 Mdot
.526 .52796 Mdot
.526 .52796 Mdot
.526 .52796 Mdot
.526 .52797 Mdot
.526 .52798 Mdot
.526 .52801 Mdot
.526 .52814 Mdot
.526 .52831 Mdot
.526 .5284 Mdot
.526 .52858 Mdot
.526 .52858 Mdot
.526 .52887 Mdot
.526 .52901 Mdot
.526 .52916 Mdot
.526 .52948 Mdot
.526 .52967 Mdot
.526 .52967 Mdot
.526 .52994 Mdot
.526 .53005 Mdot
.526 .53009 Mdot
.526 .5301 Mdot
.526 .53018 Mdot
.526 .53105 Mdot
.526 .53143 Mdot
.526 .53152 Mdot
.526 .53193 Mdot
.526 .53201 Mdot
.526 .53217 Mdot
.526 .53218 Mdot
.526 .53225 Mdot
.526 .53236 Mdot
.526 .53258 Mdot
.526 .53269 Mdot
.526 .53278 Mdot
.526 .53306 Mdot
.526 .53306 Mdot
.526 .53308 Mdot
.526 .5331 Mdot
.526 .53327 Mdot
.526 .53331 Mdot
.526 .53332 Mdot
.526 .53365 Mdot
.526 .53366 Mdot
.526 .53374 Mdot
.526 .53404 Mdot
.526 .53422 Mdot
.526 .5345 Mdot
.526 .53456 Mdot
.526 .53462 Mdot
.526 .53485 Mdot
.526 .53497 Mdot
.526 .535 Mdot
.526 .53524 Mdot
.526 .53526 Mdot
.526 .53563 Mdot
.526 .53589 Mdot
.526 .53594 Mdot
.526 .53606 Mdot
.526 .53612 Mdot
.526 .53616 Mdot
.526 .53624 Mdot
.526 .53649 Mdot
.526 .53653 Mdot
.526 .53666 Mdot
.526 .53682 Mdot
.526 .53719 Mdot
.526 .53723 Mdot
.526 .53732 Mdot
.526 .53758 Mdot
.526 .53762 Mdot
.526 .53763 Mdot
.526 .53778 Mdot
.526 .53783 Mdot
.526 .53786 Mdot
.526 .53797 Mdot
.526 .53812 Mdot
.526 .53813 Mdot
.526 .53845 Mdot
.526 .53855 Mdot
.526 .5388 Mdot
.526 .5389 Mdot
.526 .53905 Mdot
.526 .53908 Mdot
.526 .53918 Mdot
.526 .53921 Mdot
.526 .53944 Mdot
.526 .53945 Mdot
.526 .53965 Mdot
.526 .53983 Mdot
.526 .53999 Mdot
.526 .53999 Mdot
.526 .54 Mdot
.526 .54011 Mdot
.526 .54018 Mdot
.526 .54023 Mdot
.526 .54029 Mdot
.526 .5407 Mdot
.526 .5407 Mdot
.526 .54073 Mdot
.526 .54073 Mdot
.526 .54083 Mdot
.526 .54085 Mdot
.526 .54089 Mdot
.526 .54099 Mdot
.526 .54105 Mdot
.526 .54115 Mdot
.526 .54115 Mdot
.526 .54119 Mdot
.526 .54133 Mdot
.526 .54147 Mdot
.526 .5416 Mdot
.526 .54166 Mdot
.526 .54175 Mdot
.526 .54192 Mdot
.526 .54211 Mdot
.526 .54212 Mdot
.526 .54218 Mdot
.526 .54235 Mdot
.526 .5425 Mdot
.526 .54261 Mdot
.526 .54272 Mdot
.526 .54272 Mdot
.526 .54276 Mdot
.526 .5428 Mdot
.526 .54286 Mdot
.526 .54296 Mdot
.526 .54297 Mdot
.526 .54315 Mdot
.526 .54321 Mdot
.526 .54323 Mdot
.526 .54324 Mdot
.526 .54325 Mdot
.526 .54336 Mdot
.526 .5436 Mdot
.526 .54369 Mdot
.526 .54373 Mdot
.526 .54379 Mdot
.526 .54389 Mdot
.526 .54389 Mdot
.526 .5439 Mdot
.526 .54394 Mdot
.526 .54394 Mdot
.526 .544 Mdot
.526 .54402 Mdot
.526 .54404 Mdot
.526 .54411 Mdot
.526 .54456 Mdot
.526 .54458 Mdot
.526 .54476 Mdot
.526 .54484 Mdot
.526 .54487 Mdot
.526 .54489 Mdot
.526 .54495 Mdot
.526 .54504 Mdot
.526 .54512 Mdot
.526 .54512 Mdot
.526 .54517 Mdot
.526 .5453 Mdot
.526 .54535 Mdot
.526 .54538 Mdot
.526 .54538 Mdot
.526 .5454 Mdot
.526 .54548 Mdot
.526 .54564 Mdot
.526 .54572 Mdot
.526 .54579 Mdot
.526 .5458 Mdot
.526 .54586 Mdot
.526 .54588 Mdot
.526 .5459 Mdot
.526 .54596 Mdot
.526 .54599 Mdot
.526 .546 Mdot
.526 .5461 Mdot
.526 .54618 Mdot
.526 .54619 Mdot
.526 .5462 Mdot
.526 .54623 Mdot
.526 .54626 Mdot
.526 .54628 Mdot
.526 .5463 Mdot
.526 .5463 Mdot
.526 .5464 Mdot
.526 .5464 Mdot
.526 .54642 Mdot
.526 .54644 Mdot
.526 .54645 Mdot
.526 .54646 Mdot
.526 .54647 Mdot
.526 .54651 Mdot
.526 .54662 Mdot
.526 .54665 Mdot
.526 .54669 Mdot
.526 .5468 Mdot
.526 .54689 Mdot
.526 .54691 Mdot
.526 .54695 Mdot
.526 .54704 Mdot
.526 .54708 Mdot
.526 .5471 Mdot
.526 .54711 Mdot
.526 .54716 Mdot
.526 .54716 Mdot
.526 .5473 Mdot
.526 .54732 Mdot
.526 .54734 Mdot
.526 .54735 Mdot
.526 .54738 Mdot
.526 .54741 Mdot
.526 .54744 Mdot
.526 .54745 Mdot
.526 .54745 Mdot
.526 .54747 Mdot
.526 .5475 Mdot
.526 .5475 Mdot
.526 .5475 Mdot
.526 .54751 Mdot
.526 .54751 Mdot
.526 .54752 Mdot
.528 .19699 Mdot
.528 .19701 Mdot
.528 .19704 Mdot
.528 .19705 Mdot
.528 .19705 Mdot
.528 .19705 Mdot
.528 .19708 Mdot
.528 .19709 Mdot
.528 .19711 Mdot
.528 .19733 Mdot
.528 .19737 Mdot
.528 .19744 Mdot
.528 .19749 Mdot
.528 .19754 Mdot
.528 .1976 Mdot
.528 .19766 Mdot
.528 .19813 Mdot
.528 .19816 Mdot
.528 .19833 Mdot
.528 .19834 Mdot
.528 .19857 Mdot
.528 .1988 Mdot
.528 .19885 Mdot
.528 .19887 Mdot
.528 .19888 Mdot
.528 .19897 Mdot
.528 .19898 Mdot
.528 .19899 Mdot
.528 .19899 Mdot
.528 .19905 Mdot
.528 .19907 Mdot
.528 .19909 Mdot
.528 .19912 Mdot
.528 .19949 Mdot
.528 .19949 Mdot
.528 .19955 Mdot
.528 .19969 Mdot
.528 .19973 Mdot
.528 .19974 Mdot
.528 .19974 Mdot
.528 .19978 Mdot
.528 .19985 Mdot
.528 .2 Mdot
.528 .20005 Mdot
.528 .2002 Mdot
.528 .20037 Mdot
.528 .20057 Mdot
.528 .2007 Mdot
.528 .20076 Mdot
.528 .20103 Mdot
.528 .2011 Mdot
.528 .20121 Mdot
.528 .20141 Mdot
.528 .2015 Mdot
.528 .20249 Mdot
.528 .20261 Mdot
.528 .20267 Mdot
.528 .20274 Mdot
.528 .20313 Mdot
.528 .20332 Mdot
.528 .20334 Mdot
.528 .20355 Mdot
.528 .20356 Mdot
.528 .20369 Mdot
.528 .20436 Mdot
.528 .20437 Mdot
.528 .20493 Mdot
.528 .20529 Mdot
.528 .20544 Mdot
.528 .20567 Mdot
.528 .2058 Mdot
.528 .20582 Mdot
.528 .20583 Mdot
.528 .2063 Mdot
.528 .20636 Mdot
.528 .20637 Mdot
.528 .20638 Mdot
.528 .20647 Mdot
.528 .20659 Mdot
.528 .20669 Mdot
.528 .20682 Mdot
.528 .20688 Mdot
.528 .20689 Mdot
.528 .20708 Mdot
.528 .20744 Mdot
.528 .20779 Mdot
.528 .20785 Mdot
.528 .20809 Mdot
.528 .20829 Mdot
.528 .20834 Mdot
.528 .20849 Mdot
.528 .20862 Mdot
.528 .20886 Mdot
.528 .20907 Mdot
.528 .20909 Mdot
.528 .20916 Mdot
.528 .20942 Mdot
.528 .20943 Mdot
.528 .21024 Mdot
.528 .21046 Mdot
.528 .21047 Mdot
.528 .21053 Mdot
.528 .21053 Mdot
.528 .21054 Mdot
.528 .21077 Mdot
.528 .21083 Mdot
.528 .2112 Mdot
.528 .21139 Mdot
.528 .21167 Mdot
.528 .21209 Mdot
.528 .21241 Mdot
.528 .21243 Mdot
.528 .21336 Mdot
.528 .21355 Mdot
.528 .21364 Mdot
.528 .2139 Mdot
.528 .21406 Mdot
.528 .2145 Mdot
.528 .21509 Mdot
.528 .21537 Mdot
.528 .21581 Mdot
.528 .21583 Mdot
.528 .21664 Mdot
.528 .2167 Mdot
.528 .21672 Mdot
.528 .21691 Mdot
.528 .2171 Mdot
.528 .21749 Mdot
.528 .21904 Mdot
.528 .21929 Mdot
.528 .21956 Mdot
.528 .22038 Mdot
.528 .22052 Mdot
.528 .2206 Mdot
.528 .22168 Mdot
.528 .22173 Mdot
.528 .22185 Mdot
.528 .22191 Mdot
.528 .22253 Mdot
.528 .2226 Mdot
.528 .22315 Mdot
.528 .22315 Mdot
.528 .22338 Mdot
.528 .22417 Mdot
.528 .22439 Mdot
.528 .22486 Mdot
.528 .22574 Mdot
.528 .22622 Mdot
.528 .22644 Mdot
.528 .22734 Mdot
.528 .22737 Mdot
.528 .22738 Mdot
.528 .22738 Mdot
.528 .22759 Mdot
.528 .22766 Mdot
.528 .2285 Mdot
.528 .22866 Mdot
.528 .22877 Mdot
.528 .22901 Mdot
.528 .22989 Mdot
.528 .23048 Mdot
.528 .23106 Mdot
.528 .23149 Mdot
.528 .23173 Mdot
.528 .23178 Mdot
.528 .23198 Mdot
.528 .23259 Mdot
.528 .23285 Mdot
.528 .23315 Mdot
.528 .23322 Mdot
.528 .2341 Mdot
.528 .23463 Mdot
.528 .23471 Mdot
.528 .23513 Mdot
.528 .23567 Mdot
.528 .23597 Mdot
.528 .23632 Mdot
.528 .23654 Mdot
.528 .23701 Mdot
.528 .23716 Mdot
.528 .23742 Mdot
.528 .23754 Mdot
.528 .23769 Mdot
.528 .23781 Mdot
.528 .23847 Mdot
.528 .23873 Mdot
.528 .23966 Mdot
.528 .2397 Mdot
.528 .23981 Mdot
.528 .24031 Mdot
.528 .24095 Mdot
.528 .24195 Mdot
.528 .24285 Mdot
.528 .24291 Mdot
.528 .24317 Mdot
.528 .24336 Mdot
.528 .24344 Mdot
.528 .2438 Mdot
.528 .24426 Mdot
.528 .24482 Mdot
.528 .24525 Mdot
.528 .24528 Mdot
.528 .24536 Mdot
.528 .24565 Mdot
.528 .24603 Mdot
.528 .24717 Mdot
.528 .2472 Mdot
.528 .24791 Mdot
.528 .24796 Mdot
.528 .24807 Mdot
.528 .24872 Mdot
.528 .24982 Mdot
.528 .24985 Mdot
.528 .25061 Mdot
.528 .25171 Mdot
.528 .25224 Mdot
.528 .2524 Mdot
.528 .25257 Mdot
.528 .25285 Mdot
.528 .25386 Mdot
.528 .25532 Mdot
.528 .25533 Mdot
.528 .25597 Mdot
.528 .25744 Mdot
.528 .25749 Mdot
.528 .25889 Mdot
.528 .25957 Mdot
.528 .25963 Mdot
.528 .25966 Mdot
.528 .26077 Mdot
.528 .26085 Mdot
.528 .26094 Mdot
.528 .26117 Mdot
.528 .26126 Mdot
.528 .26191 Mdot
.528 .2627 Mdot
.528 .26275 Mdot
.528 .26406 Mdot
.528 .26446 Mdot
.528 .26477 Mdot
.528 .26506 Mdot
.528 .26545 Mdot
.528 .26584 Mdot
.528 .26644 Mdot
.528 .2666 Mdot
.528 .26667 Mdot
.528 .26756 Mdot
.528 .26872 Mdot
.528 .2697 Mdot
.528 .27044 Mdot
.528 .27062 Mdot
.528 .27103 Mdot
.528 .27109 Mdot
.528 .27156 Mdot
.528 .2716 Mdot
.528 .2717 Mdot
.528 .27274 Mdot
.528 .27339 Mdot
.528 .27362 Mdot
.528 .27382 Mdot
.528 .27543 Mdot
.528 .27574 Mdot
.528 .27576 Mdot
.528 .27654 Mdot
.528 .27717 Mdot
.528 .2777 Mdot
.528 .27825 Mdot
.528 .27849 Mdot
.528 .27858 Mdot
.528 .27875 Mdot
.528 .27963 Mdot
.528 .27996 Mdot
.528 .28065 Mdot
.528 .28084 Mdot
.528 .28121 Mdot
.528 .28127 Mdot
.528 .28151 Mdot
.528 .28152 Mdot
.528 .28159 Mdot
.528 .28182 Mdot
.528 .28267 Mdot
.528 .28268 Mdot
.528 .28296 Mdot
.528 .28304 Mdot
.528 .28306 Mdot
.528 .28329 Mdot
.528 .28355 Mdot
.528 .28414 Mdot
.528 .28448 Mdot
.528 .2853 Mdot
.528 .28553 Mdot
.528 .28555 Mdot
.528 .28562 Mdot
.528 .28578 Mdot
.528 .28604 Mdot
.528 .28615 Mdot
.528 .28616 Mdot
.528 .28618 Mdot
.528 .28625 Mdot
.528 .28683 Mdot
.528 .28685 Mdot
.528 .28688 Mdot
.528 .28704 Mdot
.528 .28733 Mdot
.528 .28753 Mdot
.528 .288 Mdot
.528 .28877 Mdot
.528 .28877 Mdot
.528 .28972 Mdot
.528 .28992 Mdot
.528 .29024 Mdot
.528 .29026 Mdot
.528 .29115 Mdot
.528 .29135 Mdot
.528 .29154 Mdot
.528 .2932 Mdot
.528 .29336 Mdot
.528 .29405 Mdot
.528 .29457 Mdot
.528 .29467 Mdot
.528 .29493 Mdot
.528 .29532 Mdot
.528 .29568 Mdot
.528 .29599 Mdot
.528 .2961 Mdot
.528 .29642 Mdot
.528 .29658 Mdot
.528 .29667 Mdot
.528 .2967 Mdot
.528 .29725 Mdot
.528 .29814 Mdot
.528 .29824 Mdot
.528 .29827 Mdot
.528 .29834 Mdot
.528 .29849 Mdot
.528 .2985 Mdot
.528 .29851 Mdot
.528 .29854 Mdot
.528 .29879 Mdot
.528 .29888 Mdot
.528 .29966 Mdot
.528 .30107 Mdot
.528 .3032 Mdot
.528 .30378 Mdot
.528 .30404 Mdot
.528 .30442 Mdot
.528 .30648 Mdot
.528 .30664 Mdot
.528 .30716 Mdot
.528 .30717 Mdot
.528 .30719 Mdot
.528 .30726 Mdot
.528 .30945 Mdot
.528 .31 Mdot
.528 .3112 Mdot
.528 .31337 Mdot
.528 .31454 Mdot
.528 .3151 Mdot
.528 .31707 Mdot
.528 .31764 Mdot
.528 .31765 Mdot
.528 .31903 Mdot
.528 .31923 Mdot
.528 .32079 Mdot
.528 .32093 Mdot
.528 .32125 Mdot
.528 .32137 Mdot
.528 .32412 Mdot
.528 .32432 Mdot
.528 .32468 Mdot
.528 .32677 Mdot
.528 .32748 Mdot
.528 .32813 Mdot
.528 .33214 Mdot
.528 .33315 Mdot
.528 .33362 Mdot
.528 .33412 Mdot
.528 .33417 Mdot
.528 .33434 Mdot
.528 .33646 Mdot
.528 .33651 Mdot
.528 .33766 Mdot
.528 .33838 Mdot
.528 .33993 Mdot
.528 .34111 Mdot
.528 .34151 Mdot
.528 .34222 Mdot
.528 .34245 Mdot
.528 .34293 Mdot
.528 .3454 Mdot
.528 .34546 Mdot
.528 .3463 Mdot
.528 .34742 Mdot
.528 .34817 Mdot
.528 .34868 Mdot
.528 .34966 Mdot
.528 .34981 Mdot
.528 .35044 Mdot
.528 .35046 Mdot
.528 .35047 Mdot
.528 .35062 Mdot
.528 .35067 Mdot
.528 .35125 Mdot
.528 .35341 Mdot
.528 .35345 Mdot
.528 .35415 Mdot
.528 .35434 Mdot
.528 .35438 Mdot
.528 .35494 Mdot
.528 .3556 Mdot
.528 .35593 Mdot
.528 .35634 Mdot
.528 .35648 Mdot
.528 .35702 Mdot
.528 .35766 Mdot
.528 .35781 Mdot
.528 .35876 Mdot
.528 .35972 Mdot
.528 .36025 Mdot
.528 .36029 Mdot
.528 .36043 Mdot
.528 .36079 Mdot
.528 .36106 Mdot
.528 .36138 Mdot
.528 .36162 Mdot
.528 .36164 Mdot
.528 .36169 Mdot
.528 .36185 Mdot
.528 .36311 Mdot
.528 .36314 Mdot
.528 .3632 Mdot
.528 .36356 Mdot
.528 .36416 Mdot
.528 .36459 Mdot
.528 .36554 Mdot
.528 .36709 Mdot
.528 .36709 Mdot
.528 .36893 Mdot
.528 .36927 Mdot
.528 .3693 Mdot
.528 .36988 Mdot
.528 .36992 Mdot
.528 .37044 Mdot
.528 .37151 Mdot
.528 .3717 Mdot
.528 .37186 Mdot
.528 .37219 Mdot
.528 .3749 Mdot
.528 .37514 Mdot
.528 .37568 Mdot
.528 .37598 Mdot
.528 .37618 Mdot
.528 .37692 Mdot
.528 .37707 Mdot
.528 .37744 Mdot
.528 .37797 Mdot
.528 .37845 Mdot
.528 .37885 Mdot
.528 .37899 Mdot
.528 .37939 Mdot
.528 .37959 Mdot
.528 .37969 Mdot
.528 .3797 Mdot
.528 .37973 Mdot
.528 .37983 Mdot
.528 .38021 Mdot
.528 .38038 Mdot
.528 .38039 Mdot
.528 .38138 Mdot
.528 .38149 Mdot
.528 .38152 Mdot
.528 .38159 Mdot
.528 .38176 Mdot
.528 .38176 Mdot
.528 .38177 Mdot
.528 .3818 Mdot
.528 .38206 Mdot
.528 .38208 Mdot
.528 .38215 Mdot
.528 .38227 Mdot
.528 .3829 Mdot
.528 .38354 Mdot
.528 .38355 Mdot
.528 .38402 Mdot
.528 .3841 Mdot
.528 .3854 Mdot
.528 .38556 Mdot
.528 .38572 Mdot
.528 .38587 Mdot
.528 .386 Mdot
.528 .38619 Mdot
.528 .38629 Mdot
.528 .38691 Mdot
.528 .38695 Mdot
.528 .387 Mdot
.528 .38706 Mdot
.528 .38706 Mdot
.528 .38707 Mdot
.528 .38708 Mdot
.528 .38719 Mdot
.528 .38722 Mdot
.528 .47052 Mdot
.528 .47054 Mdot
.528 .4706 Mdot
.528 .4706 Mdot
.528 .4706 Mdot
.528 .47061 Mdot
.528 .47064 Mdot
.528 .47066 Mdot
.528 .47068 Mdot
.528 .47099 Mdot
.528 .47104 Mdot
.528 .47114 Mdot
.528 .4712 Mdot
.528 .47128 Mdot
.528 .47136 Mdot
.528 .47144 Mdot
.528 .47209 Mdot
.528 .47213 Mdot
.528 .47236 Mdot
.528 .47237 Mdot
.528 .47268 Mdot
.528 .473 Mdot
.528 .47306 Mdot
.528 .47309 Mdot
.528 .4731 Mdot
.528 .47323 Mdot
.528 .47324 Mdot
.528 .47325 Mdot
.528 .47325 Mdot
.528 .47333 Mdot
.528 .47337 Mdot
.528 .47339 Mdot
.528 .47344 Mdot
.528 .47393 Mdot
.528 .47393 Mdot
.528 .47401 Mdot
.528 .4742 Mdot
.528 .47425 Mdot
.528 .47427 Mdot
.528 .47427 Mdot
.528 .47432 Mdot
.528 .47442 Mdot
.528 .47461 Mdot
.528 .47468 Mdot
.528 .47488 Mdot
.528 .47512 Mdot
.528 .47537 Mdot
.528 .47555 Mdot
.528 .47562 Mdot
.528 .47599 Mdot
.528 .47608 Mdot
.528 .47623 Mdot
.528 .47649 Mdot
.528 .47661 Mdot
.528 .47792 Mdot
.528 .47808 Mdot
.528 .47815 Mdot
.528 .47824 Mdot
.528 .47875 Mdot
.528 .47901 Mdot
.528 .47903 Mdot
.528 .4793 Mdot
.528 .47932 Mdot
.528 .47948 Mdot
.528 .48035 Mdot
.528 .48036 Mdot
.528 .48108 Mdot
.528 .48154 Mdot
.528 .48174 Mdot
.528 .48202 Mdot
.528 .48219 Mdot
.528 .48222 Mdot
.528 .48223 Mdot
.528 .48282 Mdot
.528 .4829 Mdot
.528 .48292 Mdot
.528 .48293 Mdot
.528 .48304 Mdot
.528 .48319 Mdot
.528 .48331 Mdot
.528 .48348 Mdot
.528 .48355 Mdot
.528 .48357 Mdot
.528 .48381 Mdot
.528 .48426 Mdot
.528 .4847 Mdot
.528 .48477 Mdot
.528 .48506 Mdot
.528 .48531 Mdot
.528 .48538 Mdot
.528 .48556 Mdot
.528 .48572 Mdot
.528 .48602 Mdot
.528 .48628 Mdot
.528 .4863 Mdot
.528 .48639 Mdot
.528 .48671 Mdot
.528 .48672 Mdot
.528 .48771 Mdot
.528 .48797 Mdot
.528 .48799 Mdot
.528 .48806 Mdot
.528 .48806 Mdot
.528 .48807 Mdot
.528 .48836 Mdot
.528 .48843 Mdot
.528 .48887 Mdot
.528 .4891 Mdot
.528 .48944 Mdot
.528 .48994 Mdot
.528 .49032 Mdot
.528 .49035 Mdot
.528 .49145 Mdot
.528 .49166 Mdot
.528 .49177 Mdot
.528 .49208 Mdot
.528 .49226 Mdot
.528 .49278 Mdot
.528 .49346 Mdot
.528 .49378 Mdot
.528 .49429 Mdot
.528 .49431 Mdot
.528 .49524 Mdot
.528 .49531 Mdot
.528 .49533 Mdot
.528 .49555 Mdot
.528 .49576 Mdot
.528 .4962 Mdot
.528 .49793 Mdot
.528 .4982 Mdot
.528 .49851 Mdot
.528 .49941 Mdot
.528 .49956 Mdot
.528 .49964 Mdot
.528 .50081 Mdot
.528 .50086 Mdot
.528 .501 Mdot
.528 .50106 Mdot
.528 .50172 Mdot
.528 .5018 Mdot
.528 .50238 Mdot
.528 .50238 Mdot
.528 .50262 Mdot
.528 .50345 Mdot
.528 .50368 Mdot
.528 .50417 Mdot
.528 .50507 Mdot
.528 .50557 Mdot
.528 .50579 Mdot
.528 .5067 Mdot
.528 .50673 Mdot
.528 .50674 Mdot
.528 .50674 Mdot
.528 .50695 Mdot
.528 .50702 Mdot
.528 .50786 Mdot
.528 .50802 Mdot
.528 .50812 Mdot
.528 .50836 Mdot
.528 .50923 Mdot
.528 .5098 Mdot
.528 .51011 Mdot
.528 .51015 Mdot
.528 .51025 Mdot
.528 .51026 Mdot
.528 .51027 Mdot
.528 .51027 Mdot
.528 .51033 Mdot
.528 .51036 Mdot
.528 .51037 Mdot
.528 .51041 Mdot
.528 .51077 Mdot
.528 .51099 Mdot
.528 .511 Mdot
.528 .51104 Mdot
.528 .5111 Mdot
.528 .51123 Mdot
.528 .51128 Mdot
.528 .5114 Mdot
.528 .51155 Mdot
.528 .5117 Mdot
.528 .51181 Mdot
.528 .51185 Mdot
.528 .51206 Mdot
.528 .51233 Mdot
.528 .51239 Mdot
.528 .51306 Mdot
.528 .51313 Mdot
.528 .51321 Mdot
.528 .51357 Mdot
.528 .51358 Mdot
.528 .5137 Mdot
.528 .51378 Mdot
.528 .51416 Mdot
.528 .51416 Mdot
.528 .51465 Mdot
.528 .51473 Mdot
.528 .51484 Mdot
.528 .51491 Mdot
.528 .51492 Mdot
.528 .51492 Mdot
.528 .51515 Mdot
.528 .51518 Mdot
.528 .51519 Mdot
.528 .51519 Mdot
.528 .51524 Mdot
.528 .51534 Mdot
.528 .5154 Mdot
.528 .51543 Mdot
.528 .51543 Mdot
.528 .51552 Mdot
.528 .51585 Mdot
.528 .51598 Mdot
.528 .51621 Mdot
.528 .51632 Mdot
.528 .51641 Mdot
.528 .51641 Mdot
.528 .51644 Mdot
.528 .51655 Mdot
.528 .51656 Mdot
.528 .51689 Mdot
.528 .51698 Mdot
.528 .51701 Mdot
.528 .51701 Mdot
.528 .51711 Mdot
.528 .51713 Mdot
.528 .51727 Mdot
.528 .51735 Mdot
.528 .51762 Mdot
.528 .51775 Mdot
.528 .51809 Mdot
.528 .51816 Mdot
.528 .51819 Mdot
.528 .51828 Mdot
.528 .5185 Mdot
.528 .5187 Mdot
.528 .51895 Mdot
.528 .51925 Mdot
.528 .51925 Mdot
.528 .51937 Mdot
.528 .52 Mdot
.528 .52007 Mdot
.528 .52016 Mdot
.528 .52041 Mdot
.528 .52081 Mdot
.528 .52085 Mdot
.528 .52086 Mdot
.528 .52105 Mdot
.528 .52107 Mdot
.528 .52123 Mdot
.528 .52129 Mdot
.528 .52158 Mdot
.528 .52195 Mdot
.528 .52239 Mdot
.528 .52273 Mdot
.528 .52276 Mdot
.528 .52282 Mdot
.528 .52305 Mdot
.528 .5232 Mdot
.528 .52334 Mdot
.528 .52345 Mdot
.528 .52357 Mdot
.528 .52372 Mdot
.528 .52421 Mdot
.528 .52424 Mdot
.528 .52453 Mdot
.528 .52478 Mdot
.528 .52481 Mdot
.528 .5249 Mdot
.528 .52493 Mdot
.528 .52496 Mdot
.528 .52538 Mdot
.528 .52539 Mdot
.528 .52541 Mdot
.528 .52567 Mdot
.528 .52619 Mdot
.528 .52621 Mdot
.528 .52676 Mdot
.528 .527 Mdot
.528 .527 Mdot
.528 .52755 Mdot
.528 .52792 Mdot
.528 .52803 Mdot
.528 .52809 Mdot
.528 .52815 Mdot
.528 .52834 Mdot
.528 .52875 Mdot
.528 .52903 Mdot
.528 .52904 Mdot
.528 .52945 Mdot
.528 .52969 Mdot
.528 .52973 Mdot
.528 .52975 Mdot
.528 .53001 Mdot
.528 .53002 Mdot
.528 .53044 Mdot
.528 .53058 Mdot
.528 .53068 Mdot
.528 .53071 Mdot
.528 .53072 Mdot
.528 .53088 Mdot
.528 .53109 Mdot
.528 .53126 Mdot
.528 .53139 Mdot
.528 .53142 Mdot
.528 .53149 Mdot
.528 .53158 Mdot
.528 .5316 Mdot
.528 .53193 Mdot
.528 .53229 Mdot
.528 .53253 Mdot
.528 .53271 Mdot
.528 .53275 Mdot
.528 .53276 Mdot
.528 .5331 Mdot
.528 .53319 Mdot
.528 .53343 Mdot
.528 .53348 Mdot
.528 .53353 Mdot
.528 .53357 Mdot
.528 .53367 Mdot
.528 .53372 Mdot
.528 .53389 Mdot
.528 .53397 Mdot
.528 .5341 Mdot
.528 .53421 Mdot
.528 .5344 Mdot
.528 .53455 Mdot
.528 .53458 Mdot
.528 .53477 Mdot
.528 .53509 Mdot
.528 .53512 Mdot
.528 .53522 Mdot
.528 .53532 Mdot
.528 .53553 Mdot
.528 .53561 Mdot
.528 .53562 Mdot
.528 .53571 Mdot
.528 .53586 Mdot
.528 .53607 Mdot
.528 .53628 Mdot
.528 .5366 Mdot
.528 .53668 Mdot
.528 .53672 Mdot
.528 .53678 Mdot
.528 .53708 Mdot
.528 .5371 Mdot
.528 .53718 Mdot
.528 .53718 Mdot
.528 .53718 Mdot
.528 .53719 Mdot
.528 .53751 Mdot
.528 .53759 Mdot
.528 .53776 Mdot
.528 .53807 Mdot
.528 .53824 Mdot
.528 .53832 Mdot
.528 .5386 Mdot
.528 .53868 Mdot
.528 .53868 Mdot
.528 .53887 Mdot
.528 .5389 Mdot
.528 .53912 Mdot
.528 .53914 Mdot
.528 .53918 Mdot
.528 .5392 Mdot
.528 .53958 Mdot
.528 .53961 Mdot
.528 .53966 Mdot
.528 .53995 Mdot
.528 .54004 Mdot
.528 .54013 Mdot
.528 .54067 Mdot
.528 .54081 Mdot
.528 .54087 Mdot
.528 .54094 Mdot
.528 .54095 Mdot
.528 .54097 Mdot
.528 .54126 Mdot
.528 .54126 Mdot
.528 .54142 Mdot
.528 .54151 Mdot
.528 .54172 Mdot
.528 .54187 Mdot
.528 .54193 Mdot
.528 .54202 Mdot
.528 .54205 Mdot
.528 .54212 Mdot
.528 .54244 Mdot
.528 .54245 Mdot
.528 .54256 Mdot
.528 .5427 Mdot
.528 .5428 Mdot
.528 .54287 Mdot
.528 .543 Mdot
.528 .54302 Mdot
.528 .5431 Mdot
.528 .5431 Mdot
.528 .5431 Mdot
.528 .54312 Mdot
.528 .54313 Mdot
.528 .5432 Mdot
.528 .54348 Mdot
.528 .54349 Mdot
.528 .54358 Mdot
.528 .5436 Mdot
.528 .54361 Mdot
.528 .54368 Mdot
.528 .54376 Mdot
.528 .54381 Mdot
.528 .54386 Mdot
.528 .54388 Mdot
.528 .54395 Mdot
.528 .54403 Mdot
.528 .54405 Mdot
.528 .54417 Mdot
.528 .54429 Mdot
.528 .54436 Mdot
.528 .54437 Mdot
.528 .54439 Mdot
.528 .54443 Mdot
.528 .54447 Mdot
.528 .54451 Mdot
.528 .54454 Mdot
.528 .54454 Mdot
.528 .54455 Mdot
.528 .54457 Mdot
.528 .54473 Mdot
.528 .54473 Mdot
.528 .54474 Mdot
.528 .54478 Mdot
.528 .54486 Mdot
.528 .54491 Mdot
.528 .54504 Mdot
.528 .54523 Mdot
.528 .54523 Mdot
.528 .54546 Mdot
.528 .54551 Mdot
.528 .54551 Mdot
.528 .54558 Mdot
.528 .54559 Mdot
.528 .54566 Mdot
.528 .54579 Mdot
.528 .54581 Mdot
.528 .54583 Mdot
.528 .54588 Mdot
.528 .54622 Mdot
.528 .54625 Mdot
.528 .54631 Mdot
.528 .54635 Mdot
.528 .54638 Mdot
.528 .54647 Mdot
.528 .54649 Mdot
.528 .54653 Mdot
.528 .5466 Mdot
.528 .54666 Mdot
.528 .54671 Mdot
.528 .54673 Mdot
.528 .54678 Mdot
.528 .5468 Mdot
.528 .54682 Mdot
.528 .54682 Mdot
.528 .54682 Mdot
.528 .54683 Mdot
.528 .54688 Mdot
.528 .5469 Mdot
.528 .5469 Mdot
.528 .54703 Mdot
.528 .54704 Mdot
.528 .54704 Mdot
.528 .54705 Mdot
.528 .54707 Mdot
.528 .54707 Mdot
.528 .54708 Mdot
.528 .54708 Mdot
.528 .54711 Mdot
.528 .54711 Mdot
.528 .54712 Mdot
.528 .54714 Mdot
.528 .54722 Mdot
.528 .5473 Mdot
.528 .5473 Mdot
.528 .54736 Mdot
.528 .54737 Mdot
.528 .54753 Mdot
.528 .54755 Mdot
.528 .54757 Mdot
.528 .54759 Mdot
.528 .5476 Mdot
.528 .54763 Mdot
.528 .54764 Mdot
.528 .54772 Mdot
.528 .54772 Mdot
.528 .54773 Mdot
.528 .54773 Mdot
.528 .54773 Mdot
.528 .54773 Mdot
.528 .54774 Mdot
.528 .54775 Mdot
.528 .54775 Mdot
.53 .19639 Mdot
.53 .19639 Mdot
.53 .19647 Mdot
.53 .19656 Mdot
.53 .19656 Mdot
.53 .19659 Mdot
.53 .1966 Mdot
.53 .19661 Mdot
.53 .19663 Mdot
.53 .19663 Mdot
.53 .19682 Mdot
.53 .197 Mdot
.53 .19717 Mdot
.53 .1973 Mdot
.53 .1973 Mdot
.53 .19734 Mdot
.53 .19744 Mdot
.53 .19749 Mdot
.53 .19756 Mdot
.53 .19761 Mdot
.53 .19762 Mdot
.53 .19769 Mdot
.53 .19772 Mdot
.53 .19775 Mdot
.53 .19775 Mdot
.53 .19776 Mdot
.53 .1979 Mdot
.53 .19809 Mdot
.53 .19813 Mdot
.53 .19814 Mdot
.53 .19816 Mdot
.53 .19819 Mdot
.53 .19827 Mdot
.53 .19856 Mdot
.53 .19862 Mdot
.53 .19862 Mdot
.53 .19868 Mdot
.53 .19888 Mdot
.53 .19909 Mdot
.53 .19921 Mdot
.53 .19934 Mdot
.53 .19949 Mdot
.53 .1995 Mdot
.53 .1995 Mdot
.53 .19953 Mdot
.53 .19961 Mdot
.53 .19971 Mdot
.53 .19993 Mdot
.53 .19993 Mdot
.53 .20009 Mdot
.53 .20019 Mdot
.53 .20035 Mdot
.53 .20044 Mdot
.53 .20045 Mdot
.53 .20051 Mdot
.53 .20054 Mdot
.53 .20068 Mdot
.53 .2008 Mdot
.53 .20092 Mdot
.53 .20101 Mdot
.53 .20102 Mdot
.53 .20105 Mdot
.53 .20115 Mdot
.53 .20133 Mdot
.53 .2016 Mdot
.53 .2017 Mdot
.53 .20171 Mdot
.53 .20225 Mdot
.53 .20234 Mdot
.53 .20251 Mdot
.53 .20258 Mdot
.53 .20265 Mdot
.53 .20278 Mdot
.53 .20285 Mdot
.53 .20288 Mdot
.53 .20294 Mdot
.53 .20297 Mdot
.53 .20314 Mdot
.53 .20323 Mdot
.53 .20374 Mdot
.53 .20446 Mdot
.53 .20448 Mdot
.53 .20455 Mdot
.53 .20475 Mdot
.53 .20475 Mdot
.53 .20505 Mdot
.53 .20511 Mdot
.53 .20606 Mdot
.53 .20635 Mdot
.53 .20643 Mdot
.53 .2072 Mdot
.53 .20751 Mdot
.53 .20781 Mdot
.53 .20796 Mdot
.53 .20854 Mdot
.53 .20855 Mdot
.53 .20882 Mdot
.53 .20914 Mdot
.53 .20944 Mdot
.53 .20947 Mdot
.53 .20948 Mdot
.53 .2096 Mdot
.53 .20969 Mdot
.53 .21012 Mdot
.53 .21017 Mdot
.53 .21042 Mdot
.53 .21074 Mdot
.53 .21104 Mdot
.53 .21138 Mdot
.53 .21173 Mdot
.53 .21179 Mdot
.53 .2119 Mdot
.53 .21215 Mdot
.53 .21215 Mdot
.53 .21316 Mdot
.53 .21386 Mdot
.53 .21494 Mdot
.53 .215 Mdot
.53 .21526 Mdot
.53 .21549 Mdot
.53 .21561 Mdot
.53 .21599 Mdot
.53 .21624 Mdot
.53 .21715 Mdot
.53 .21719 Mdot
.53 .21809 Mdot
.53 .21896 Mdot
.53 .21964 Mdot
.53 .21965 Mdot
.53 .21989 Mdot
.53 .22049 Mdot
.53 .2205 Mdot
.53 .22068 Mdot
.53 .22105 Mdot
.53 .2212 Mdot
.53 .22136 Mdot
.53 .22176 Mdot
.53 .22195 Mdot
.53 .22201 Mdot
.53 .22253 Mdot
.53 .22321 Mdot
.53 .22411 Mdot
.53 .22446 Mdot
.53 .22495 Mdot
.53 .22505 Mdot
.53 .22508 Mdot
.53 .22517 Mdot
.53 .22556 Mdot
.53 .22613 Mdot
.53 .22681 Mdot
.53 .22774 Mdot
.53 .22797 Mdot
.53 .22917 Mdot
.53 .22945 Mdot
.53 .22967 Mdot
.53 .23004 Mdot
.53 .23023 Mdot
.53 .23046 Mdot
.53 .23053 Mdot
.53 .23054 Mdot
.53 .23067 Mdot
.53 .23099 Mdot
.53 .23163 Mdot
.53 .23189 Mdot
.53 .23227 Mdot
.53 .23287 Mdot
.53 .23322 Mdot
.53 .23399 Mdot
.53 .2344 Mdot
.53 .23443 Mdot
.53 .23445 Mdot
.53 .23461 Mdot
.53 .23492 Mdot
.53 .2354 Mdot
.53 .23571 Mdot
.53 .23697 Mdot
.53 .23719 Mdot
.53 .23761 Mdot
.53 .23797 Mdot
.53 .23878 Mdot
.53 .23895 Mdot
.53 .2404 Mdot
.53 .24259 Mdot
.53 .24264 Mdot
.53 .24312 Mdot
.53 .244 Mdot
.53 .24403 Mdot
.53 .24436 Mdot
.53 .24536 Mdot
.53 .24578 Mdot
.53 .24595 Mdot
.53 .24704 Mdot
.53 .24836 Mdot
.53 .2495 Mdot
.53 .24965 Mdot
.53 .24992 Mdot
.53 .25031 Mdot
.53 .25048 Mdot
.53 .25079 Mdot
.53 .25117 Mdot
.53 .25161 Mdot
.53 .25197 Mdot
.53 .25209 Mdot
.53 .25219 Mdot
.53 .25223 Mdot
.53 .25226 Mdot
.53 .25227 Mdot
.53 .25227 Mdot
.53 .25228 Mdot
.53 .25228 Mdot
.53 .25229 Mdot
.53 .25229 Mdot
.53 .25231 Mdot
.53 .25233 Mdot
.53 .25238 Mdot
.53 .25245 Mdot
.53 .25263 Mdot
.53 .25287 Mdot
.53 .25334 Mdot
.53 .25354 Mdot
.53 .25369 Mdot
.53 .25377 Mdot
.53 .25439 Mdot
.53 .25512 Mdot
.53 .25572 Mdot
.53 .25605 Mdot
.53 .25681 Mdot
.53 .25733 Mdot
.53 .2576 Mdot
.53 .25763 Mdot
.53 .25987 Mdot
.53 .26035 Mdot
.53 .26083 Mdot
.53 .26174 Mdot
.53 .26193 Mdot
.53 .26223 Mdot
.53 .26242 Mdot
.53 .26252 Mdot
.53 .26282 Mdot
.53 .26353 Mdot
.53 .26391 Mdot
.53 .26433 Mdot
.53 .26475 Mdot
.53 .2651 Mdot
.53 .26524 Mdot
.53 .26577 Mdot
.53 .26596 Mdot
.53 .26804 Mdot
.53 .26873 Mdot
.53 .26879 Mdot
.53 .26881 Mdot
.53 .26888 Mdot
.53 .26949 Mdot
.53 .27066 Mdot
.53 .27105 Mdot
.53 .27167 Mdot
.53 .27178 Mdot
.53 .27207 Mdot
.53 .27268 Mdot
.53 .27287 Mdot
.53 .27288 Mdot
.53 .27342 Mdot
.53 .27413 Mdot
.53 .27487 Mdot
.53 .27567 Mdot
.53 .27588 Mdot
.53 .27621 Mdot
.53 .27631 Mdot
.53 .27651 Mdot
.53 .27679 Mdot
.53 .27775 Mdot
.53 .27839 Mdot
.53 .27934 Mdot
.53 .27934 Mdot
.53 .27969 Mdot
.53 .28008 Mdot
.53 .28071 Mdot
.53 .28128 Mdot
.53 .28178 Mdot
.53 .28188 Mdot
.53 .282 Mdot
.53 .28201 Mdot
.53 .28204 Mdot
.53 .28269 Mdot
.53 .28298 Mdot
.53 .28363 Mdot
.53 .28379 Mdot
.53 .28412 Mdot
.53 .28448 Mdot
.53 .28582 Mdot
.53 .287 Mdot
.53 .28708 Mdot
.53 .28745 Mdot
.53 .28745 Mdot
.53 .28772 Mdot
.53 .28783 Mdot
.53 .28881 Mdot
.53 .28953 Mdot
.53 .28965 Mdot
.53 .28989 Mdot
.53 .28994 Mdot
.53 .29002 Mdot
.53 .29018 Mdot
.53 .29037 Mdot
.53 .29047 Mdot
.53 .29058 Mdot
.53 .29083 Mdot
.53 .29098 Mdot
.53 .29201 Mdot
.53 .29275 Mdot
.53 .29293 Mdot
.53 .29299 Mdot
.53 .29299 Mdot
.53 .29315 Mdot
.53 .29336 Mdot
.53 .29359 Mdot
.53 .29383 Mdot
.53 .2939 Mdot
.53 .29418 Mdot
.53 .29468 Mdot
.53 .29499 Mdot
.53 .29499 Mdot
.53 .29564 Mdot
.53 .29588 Mdot
.53 .29588 Mdot
.53 .29589 Mdot
.53 .29651 Mdot
.53 .29676 Mdot
.53 .29788 Mdot
.53 .29803 Mdot
.53 .29878 Mdot
.53 .29901 Mdot
.53 .29909 Mdot
.53 .29914 Mdot
.53 .2993 Mdot
.53 .29984 Mdot
.53 .30028 Mdot
.53 .30031 Mdot
.53 .30031 Mdot
.53 .30039 Mdot
.53 .3005 Mdot
.53 .30073 Mdot
.53 .30077 Mdot
.53 .30119 Mdot
.53 .30136 Mdot
.53 .30172 Mdot
.53 .30187 Mdot
.53 .30188 Mdot
.53 .30241 Mdot
.53 .30531 Mdot
.53 .30587 Mdot
.53 .30817 Mdot
.53 .30982 Mdot
.53 .31125 Mdot
.53 .31221 Mdot
.53 .31245 Mdot
.53 .31251 Mdot
.53 .31275 Mdot
.53 .31398 Mdot
.53 .31486 Mdot
.53 .31712 Mdot
.53 .31884 Mdot
.53 .32015 Mdot
.53 .3203 Mdot
.53 .32078 Mdot
.53 .32181 Mdot
.53 .32223 Mdot
.53 .32259 Mdot
.53 .32355 Mdot
.53 .324 Mdot
.53 .32403 Mdot
.53 .32558 Mdot
.53 .32619 Mdot
.53 .32621 Mdot
.53 .32796 Mdot
.53 .33023 Mdot
.53 .33256 Mdot
.53 .33265 Mdot
.53 .33504 Mdot
.53 .33568 Mdot
.53 .33669 Mdot
.53 .33699 Mdot
.53 .33761 Mdot
.53 .33829 Mdot
.53 .33845 Mdot
.53 .34129 Mdot
.53 .34314 Mdot
.53 .34582 Mdot
.53 .34583 Mdot
.53 .34649 Mdot
.53 .3468 Mdot
.53 .34694 Mdot
.53 .34788 Mdot
.53 .3488 Mdot
.53 .34958 Mdot
.53 .35046 Mdot
.53 .35111 Mdot
.53 .35126 Mdot
.53 .35241 Mdot
.53 .35266 Mdot
.53 .35298 Mdot
.53 .35299 Mdot
.53 .35308 Mdot
.53 .35388 Mdot
.53 .35473 Mdot
.53 .35548 Mdot
.53 .3555 Mdot
.53 .35707 Mdot
.53 .35746 Mdot
.53 .35827 Mdot
.53 .35912 Mdot
.53 .36121 Mdot
.53 .36141 Mdot
.53 .36221 Mdot
.53 .36479 Mdot
.53 .36496 Mdot
.53 .36575 Mdot
.53 .36575 Mdot
.53 .36631 Mdot
.53 .3665 Mdot
.53 .36654 Mdot
.53 .36852 Mdot
.53 .36991 Mdot
.53 .37015 Mdot
.53 .3706 Mdot
.53 .3707 Mdot
.53 .37085 Mdot
.53 .37094 Mdot
.53 .37114 Mdot
.53 .37149 Mdot
.53 .37167 Mdot
.53 .37188 Mdot
.53 .37233 Mdot
.53 .37258 Mdot
.53 .37404 Mdot
.53 .37408 Mdot
.53 .37436 Mdot
.53 .3751 Mdot
.53 .37558 Mdot
.53 .37587 Mdot
.53 .37595 Mdot
.53 .37596 Mdot
.53 .37621 Mdot
.53 .37654 Mdot
.53 .37688 Mdot
.53 .37725 Mdot
.53 .37734 Mdot
.53 .3775 Mdot
.53 .37754 Mdot
.53 .37776 Mdot
.53 .3782 Mdot
.53 .37849 Mdot
.53 .37892 Mdot
.53 .37892 Mdot
.53 .37954 Mdot
.53 .37979 Mdot
.53 .38002 Mdot
.53 .38012 Mdot
.53 .38012 Mdot
.53 .38013 Mdot
.53 .38055 Mdot
.53 .38091 Mdot
.53 .38122 Mdot
.53 .38181 Mdot
.53 .38236 Mdot
.53 .38252 Mdot
.53 .38252 Mdot
.53 .38268 Mdot
.53 .38347 Mdot
.53 .3837 Mdot
.53 .38378 Mdot
.53 .38383 Mdot
.53 .38388 Mdot
.53 .38398 Mdot
.53 .38449 Mdot
.53 .38489 Mdot
.53 .38491 Mdot
.53 .38491 Mdot
.53 .38498 Mdot
.53 .38507 Mdot
.53 .38527 Mdot
.53 .3853 Mdot
.53 .38542 Mdot
.53 .38563 Mdot
.53 .38576 Mdot
.53 .38603 Mdot
.53 .38614 Mdot
.53 .38614 Mdot
.53 .38651 Mdot
.53 .38698 Mdot
.53 .38745 Mdot
.53 .38798 Mdot
.53 .388 Mdot
.53 .38803 Mdot
.53 .38807 Mdot
.53 .38809 Mdot
.53 .38817 Mdot
.53 .38819 Mdot
.53 .38843 Mdot
.53 .38864 Mdot
.53 .38865 Mdot
.53 .46989 Mdot
.53 .46989 Mdot
.53 .47 Mdot
.53 .47012 Mdot
.53 .47013 Mdot
.53 .47017 Mdot
.53 .47018 Mdot
.53 .4702 Mdot
.53 .47022 Mdot
.53 .47022 Mdot
.53 .47049 Mdot
.53 .47073 Mdot
.53 .47097 Mdot
.53 .47115 Mdot
.53 .47115 Mdot
.53 .4712 Mdot
.53 .47134 Mdot
.53 .47141 Mdot
.53 .47151 Mdot
.53 .47157 Mdot
.53 .47159 Mdot
.53 .47169 Mdot
.53 .47173 Mdot
.53 .47177 Mdot
.53 .47177 Mdot
.53 .47178 Mdot
.53 .47197 Mdot
.53 .47223 Mdot
.53 .47228 Mdot
.53 .4723 Mdot
.53 .47233 Mdot
.53 .47237 Mdot
.53 .47248 Mdot
.53 .47287 Mdot
.53 .47295 Mdot
.53 .47295 Mdot
.53 .47304 Mdot
.53 .47331 Mdot
.53 .4736 Mdot
.53 .47375 Mdot
.53 .47393 Mdot
.53 .47413 Mdot
.53 .47414 Mdot
.53 .47414 Mdot
.53 .47419 Mdot
.53 .4743 Mdot
.53 .47442 Mdot
.53 .47473 Mdot
.53 .47473 Mdot
.53 .47494 Mdot
.53 .47508 Mdot
.53 .47529 Mdot
.53 .4754 Mdot
.53 .47542 Mdot
.53 .4755 Mdot
.53 .47554 Mdot
.53 .47572 Mdot
.53 .47589 Mdot
.53 .47605 Mdot
.53 .47617 Mdot
.53 .47617 Mdot
.53 .47622 Mdot
.53 .47636 Mdot
.53 .47659 Mdot
.53 .47695 Mdot
.53 .47709 Mdot
.53 .4771 Mdot
.53 .47781 Mdot
.53 .47793 Mdot
.53 .47814 Mdot
.53 .47824 Mdot
.53 .47833 Mdot
.53 .4785 Mdot
.53 .47859 Mdot
.53 .47864 Mdot
.53 .47871 Mdot
.53 .47876 Mdot
.53 .47897 Mdot
.53 .47908 Mdot
.53 .47975 Mdot
.53 .48069 Mdot
.53 .48071 Mdot
.53 .4808 Mdot
.53 .48106 Mdot
.53 .48106 Mdot
.53 .48143 Mdot
.53 .48151 Mdot
.53 .48272 Mdot
.53 .4831 Mdot
.53 .48319 Mdot
.53 .48416 Mdot
.53 .48456 Mdot
.53 .48493 Mdot
.53 .48511 Mdot
.53 .48583 Mdot
.53 .48584 Mdot
.53 .48618 Mdot
.53 .48658 Mdot
.53 .48694 Mdot
.53 .48698 Mdot
.53 .48699 Mdot
.53 .48713 Mdot
.53 .48724 Mdot
.53 .48777 Mdot
.53 .48784 Mdot
.53 .48813 Mdot
.53 .48853 Mdot
.53 .48889 Mdot
.53 .4893 Mdot
.53 .48972 Mdot
.53 .48979 Mdot
.53 .48992 Mdot
.53 .49022 Mdot
.53 .49022 Mdot
.53 .49142 Mdot
.53 .49224 Mdot
.53 .4935 Mdot
.53 .49357 Mdot
.53 .49387 Mdot
.53 .49414 Mdot
.53 .49427 Mdot
.53 .49471 Mdot
.53 .49499 Mdot
.53 .49603 Mdot
.53 .49607 Mdot
.53 .49708 Mdot
.53 .49806 Mdot
.53 .49881 Mdot
.53 .49882 Mdot
.53 .49908 Mdot
.53 .49974 Mdot
.53 .49975 Mdot
.53 .49994 Mdot
.53 .50035 Mdot
.53 .50051 Mdot
.53 .50068 Mdot
.53 .50112 Mdot
.53 .50132 Mdot
.53 .50138 Mdot
.53 .50193 Mdot
.53 .50266 Mdot
.53 .50361 Mdot
.53 .50397 Mdot
.53 .50448 Mdot
.53 .50459 Mdot
.53 .50461 Mdot
.53 .50471 Mdot
.53 .50511 Mdot
.53 .5057 Mdot
.53 .50638 Mdot
.53 .50732 Mdot
.53 .50755 Mdot
.53 .50873 Mdot
.53 .50895 Mdot
.53 .50895 Mdot
.53 .50901 Mdot
.53 .50916 Mdot
.53 .50923 Mdot
.53 .5094 Mdot
.53 .50941 Mdot
.53 .50951 Mdot
.53 .50955 Mdot
.53 .50959 Mdot
.53 .50959 Mdot
.53 .5096 Mdot
.53 .50978 Mdot
.53 .50999 Mdot
.53 .51006 Mdot
.53 .51008 Mdot
.53 .51011 Mdot
.53 .5102 Mdot
.53 .51051 Mdot
.53 .51057 Mdot
.53 .51102 Mdot
.53 .51112 Mdot
.53 .51137 Mdot
.53 .51137 Mdot
.53 .51137 Mdot
.53 .51147 Mdot
.53 .51173 Mdot
.53 .51173 Mdot
.53 .51185 Mdot
.53 .51205 Mdot
.53 .51217 Mdot
.53 .51219 Mdot
.53 .51229 Mdot
.53 .51238 Mdot
.53 .51246 Mdot
.53 .51253 Mdot
.53 .51253 Mdot
.53 .51255 Mdot
.53 .51262 Mdot
.53 .51292 Mdot
.53 .51333 Mdot
.53 .51339 Mdot
.53 .51349 Mdot
.53 .51353 Mdot
.53 .51357 Mdot
.53 .51365 Mdot
.53 .51371 Mdot
.53 .51374 Mdot
.53 .51376 Mdot
.53 .51386 Mdot
.53 .51391 Mdot
.53 .51419 Mdot
.53 .51458 Mdot
.53 .51462 Mdot
.53 .51473 Mdot
.53 .51473 Mdot
.53 .51487 Mdot
.53 .51491 Mdot
.53 .51537 Mdot
.53 .51589 Mdot
.53 .51604 Mdot
.53 .51617 Mdot
.53 .51623 Mdot
.53 .51648 Mdot
.53 .5166 Mdot
.53 .51685 Mdot
.53 .51686 Mdot
.53 .51687 Mdot
.53 .51692 Mdot
.53 .51695 Mdot
.53 .51715 Mdot
.53 .51737 Mdot
.53 .51761 Mdot
.53 .51777 Mdot
.53 .5179 Mdot
.53 .5179 Mdot
.53 .51827 Mdot
.53 .51852 Mdot
.53 .51889 Mdot
.53 .519 Mdot
.53 .51908 Mdot
.53 .51912 Mdot
.53 .51925 Mdot
.53 .51933 Mdot
.53 .51963 Mdot
.53 .51992 Mdot
.53 .52019 Mdot
.53 .5204 Mdot
.53 .5204 Mdot
.53 .52048 Mdot
.53 .52071 Mdot
.53 .52082 Mdot
.53 .52087 Mdot
.53 .5211 Mdot
.53 .52125 Mdot
.53 .5217 Mdot
.53 .52193 Mdot
.53 .52196 Mdot
.53 .52196 Mdot
.53 .52199 Mdot
.53 .52225 Mdot
.53 .52304 Mdot
.53 .52312 Mdot
.53 .52331 Mdot
.53 .52337 Mdot
.53 .5235 Mdot
.53 .52366 Mdot
.53 .52382 Mdot
.53 .52396 Mdot
.53 .52423 Mdot
.53 .52434 Mdot
.53 .52438 Mdot
.53 .52445 Mdot
.53 .52457 Mdot
.53 .52464 Mdot
.53 .52498 Mdot
.53 .52516 Mdot
.53 .52534 Mdot
.53 .52618 Mdot
.53 .52619 Mdot
.53 .52629 Mdot
.53 .52649 Mdot
.53 .52677 Mdot
.53 .52689 Mdot
.53 .52712 Mdot
.53 .52739 Mdot
.53 .52762 Mdot
.53 .52765 Mdot
.53 .5277 Mdot
.53 .52778 Mdot
.53 .52795 Mdot
.53 .52804 Mdot
.53 .52811 Mdot
.53 .52813 Mdot
.53 .52815 Mdot
.53 .52816 Mdot
.53 .52817 Mdot
.53 .52817 Mdot
.53 .52817 Mdot
.53 .52817 Mdot
.53 .52817 Mdot
.53 .52818 Mdot
.53 .52818 Mdot
.53 .52819 Mdot
.53 .5282 Mdot
.53 .52824 Mdot
.53 .52829 Mdot
.53 .52842 Mdot
.53 .52858 Mdot
.53 .52872 Mdot
.53 .52884 Mdot
.53 .5289 Mdot
.53 .52904 Mdot
.53 .52914 Mdot
.53 .5292 Mdot
.53 .52962 Mdot
.53 .5301 Mdot
.53 .5305 Mdot
.53 .53057 Mdot
.53 .53072 Mdot
.53 .53109 Mdot
.53 .53121 Mdot
.53 .53122 Mdot
.53 .53154 Mdot
.53 .53171 Mdot
.53 .53173 Mdot
.53 .53253 Mdot
.53 .53306 Mdot
.53 .53312 Mdot
.53 .53341 Mdot
.53 .53354 Mdot
.53 .53369 Mdot
.53 .53377 Mdot
.53 .53423 Mdot
.53 .53434 Mdot
.53 .53451 Mdot
.53 .53462 Mdot
.53 .53468 Mdot
.53 .53469 Mdot
.53 .5347 Mdot
.53 .53485 Mdot
.53 .53512 Mdot
.53 .53525 Mdot
.53 .53546 Mdot
.53 .5356 Mdot
.53 .53569 Mdot
.53 .53592 Mdot
.53 .53604 Mdot
.53 .53608 Mdot
.53 .53609 Mdot
.53 .53611 Mdot
.53 .53619 Mdot
.53 .53626 Mdot
.53 .53639 Mdot
.53 .53647 Mdot
.53 .53658 Mdot
.53 .537 Mdot
.53 .53708 Mdot
.53 .53742 Mdot
.53 .53765 Mdot
.53 .53786 Mdot
.53 .538 Mdot
.53 .53803 Mdot
.53 .53804 Mdot
.53 .53807 Mdot
.53 .53825 Mdot
.53 .53837 Mdot
.53 .53869 Mdot
.53 .53893 Mdot
.53 .53911 Mdot
.53 .53913 Mdot
.53 .5392 Mdot
.53 .53934 Mdot
.53 .5394 Mdot
.53 .53945 Mdot
.53 .53958 Mdot
.53 .53965 Mdot
.53 .53965 Mdot
.53 .53986 Mdot
.53 .53995 Mdot
.53 .53995 Mdot
.53 .54019 Mdot
.53 .5405 Mdot
.53 .54081 Mdot
.53 .54082 Mdot
.53 .54114 Mdot
.53 .54123 Mdot
.53 .54136 Mdot
.53 .5414 Mdot
.53 .54149 Mdot
.53 .54158 Mdot
.53 .5416 Mdot
.53 .54197 Mdot
.53 .54222 Mdot
.53 .54257 Mdot
.53 .54257 Mdot
.53 .54266 Mdot
.53 .5427 Mdot
.53 .54271 Mdot
.53 .54284 Mdot
.53 .54296 Mdot
.53 .54306 Mdot
.53 .54317 Mdot
.53 .54325 Mdot
.53 .54328 Mdot
.53 .54342 Mdot
.53 .54346 Mdot
.53 .5435 Mdot
.53 .5435 Mdot
.53 .54351 Mdot
.53 .54361 Mdot
.53 .54372 Mdot
.53 .54382 Mdot
.53 .54382 Mdot
.53 .54402 Mdot
.53 .54407 Mdot
.53 .54418 Mdot
.53 .54428 Mdot
.53 .54455 Mdot
.53 .54458 Mdot
.53 .54468 Mdot
.53 .54501 Mdot
.53 .54503 Mdot
.53 .54513 Mdot
.53 .54513 Mdot
.53 .5452 Mdot
.53 .54522 Mdot
.53 .54523 Mdot
.53 .54548 Mdot
.53 .54565 Mdot
.53 .54568 Mdot
.53 .54574 Mdot
.53 .54575 Mdot
.53 .54577 Mdot
.53 .54578 Mdot
.53 .54581 Mdot
.53 .54585 Mdot
.53 .54587 Mdot
.53 .5459 Mdot
.53 .54595 Mdot
.53 .54599 Mdot
.53 .54617 Mdot
.53 .54617 Mdot
.53 .54621 Mdot
.53 .5463 Mdot
.53 .54636 Mdot
.53 .5464 Mdot
.53 .54641 Mdot
.53 .54641 Mdot
.53 .54644 Mdot
.53 .54648 Mdot
.53 .54652 Mdot
.53 .54657 Mdot
.53 .54658 Mdot
.53 .5466 Mdot
.53 .54661 Mdot
.53 .54664 Mdot
.53 .54669 Mdot
.53 .54673 Mdot
.53 .54678 Mdot
.53 .54678 Mdot
.53 .54686 Mdot
.53 .54689 Mdot
.53 .54692 Mdot
.53 .54693 Mdot
.53 .54693 Mdot
.53 .54693 Mdot
.53 .54698 Mdot
.53 .54703 Mdot
.53 .54707 Mdot
.53 .54714 Mdot
.53 .54721 Mdot
.53 .54723 Mdot
.53 .54723 Mdot
.53 .54725 Mdot
.53 .54735 Mdot
.53 .54737 Mdot
.53 .54738 Mdot
.53 .54739 Mdot
.53 .5474 Mdot
.53 .54741 Mdot
.53 .54747 Mdot
.53 .54752 Mdot
.53 .54752 Mdot
.53 .54752 Mdot
.53 .54753 Mdot
.53 .54754 Mdot
.53 .54757 Mdot
.53 .54757 Mdot
.53 .54759 Mdot
.53 .54761 Mdot
.53 .54763 Mdot
.53 .54766 Mdot
.53 .54768 Mdot
.53 .54768 Mdot
.53 .54772 Mdot
.53 .54778 Mdot
.53 .54784 Mdot
.53 .5479 Mdot
.53 .54791 Mdot
.53 .54792 Mdot
.53 .54792 Mdot
.53 .54793 Mdot
.53 .54793 Mdot
.53 .54796 Mdot
.53 .54799 Mdot
.53 .54799 Mdot
.532 .19577 Mdot
.532 .19577 Mdot
.532 .19578 Mdot
.532 .1958 Mdot
.532 .1958 Mdot
.532 .19603 Mdot
.532 .19605 Mdot
.532 .19605 Mdot
.532 .19606 Mdot
.532 .19608 Mdot
.532 .19608 Mdot
.532 .19615 Mdot
.532 .19619 Mdot
.532 .19626 Mdot
.532 .19636 Mdot
.532 .19638 Mdot
.532 .19639 Mdot
.532 .19643 Mdot
.532 .19643 Mdot
.532 .19645 Mdot
.532 .19654 Mdot
.532 .19656 Mdot
.532 .1966 Mdot
.532 .19672 Mdot
.532 .19679 Mdot
.532 .1969 Mdot
.532 .19694 Mdot
.532 .19696 Mdot
.532 .19704 Mdot
.532 .19704 Mdot
.532 .19707 Mdot
.532 .19711 Mdot
.532 .19723 Mdot
.532 .19725 Mdot
.532 .19726 Mdot
.532 .19732 Mdot
.532 .19741 Mdot
.532 .19748 Mdot
.532 .19752 Mdot
.532 .19769 Mdot
.532 .1977 Mdot
.532 .19782 Mdot
.532 .19783 Mdot
.532 .19787 Mdot
.532 .19795 Mdot
.532 .19815 Mdot
.532 .19821 Mdot
.532 .19823 Mdot
.532 .19826 Mdot
.532 .19828 Mdot
.532 .19833 Mdot
.532 .19854 Mdot
.532 .19856 Mdot
.532 .19865 Mdot
.532 .19875 Mdot
.532 .19901 Mdot
.532 .19914 Mdot
.532 .19922 Mdot
.532 .19924 Mdot
.532 .19944 Mdot
.532 .19964 Mdot
.532 .19972 Mdot
.532 .19975 Mdot
.532 .19981 Mdot
.532 .2 Mdot
.532 .20012 Mdot
.532 .20014 Mdot
.532 .20077 Mdot
.532 .2008 Mdot
.532 .20128 Mdot
.532 .20131 Mdot
.532 .2015 Mdot
.532 .20169 Mdot
.532 .20178 Mdot
.532 .20181 Mdot
.532 .20182 Mdot
.532 .20227 Mdot
.532 .20233 Mdot
.532 .20247 Mdot
.532 .20269 Mdot
.532 .20279 Mdot
.532 .20297 Mdot
.532 .20306 Mdot
.532 .20318 Mdot
.532 .20325 Mdot
.532 .20328 Mdot
.532 .20352 Mdot
.532 .20352 Mdot
.532 .20388 Mdot
.532 .20395 Mdot
.532 .20455 Mdot
.532 .20464 Mdot
.532 .2051 Mdot
.532 .20564 Mdot
.532 .20694 Mdot
.532 .20701 Mdot
.532 .20703 Mdot
.532 .20715 Mdot
.532 .20747 Mdot
.532 .20777 Mdot
.532 .20818 Mdot
.532 .20822 Mdot
.532 .20835 Mdot
.532 .20876 Mdot
.532 .20922 Mdot
.532 .20951 Mdot
.532 .20965 Mdot
.532 .20981 Mdot
.532 .21021 Mdot
.532 .21069 Mdot
.532 .2108 Mdot
.532 .2112 Mdot
.532 .21125 Mdot
.532 .21134 Mdot
.532 .21146 Mdot
.532 .21153 Mdot
.532 .21187 Mdot
.532 .21197 Mdot
.532 .21262 Mdot
.532 .21308 Mdot
.532 .21313 Mdot
.532 .21341 Mdot
.532 .21347 Mdot
.532 .21353 Mdot
.532 .21363 Mdot
.532 .21388 Mdot
.532 .2139 Mdot
.532 .21391 Mdot
.532 .21392 Mdot
.532 .214 Mdot
.532 .21405 Mdot
.532 .21457 Mdot
.532 .21473 Mdot
.532 .2148 Mdot
.532 .21504 Mdot
.532 .21522 Mdot
.532 .21543 Mdot
.532 .2156 Mdot
.532 .21631 Mdot
.532 .21644 Mdot
.532 .21795 Mdot
.532 .21852 Mdot
.532 .21881 Mdot
.532 .21907 Mdot
.532 .2191 Mdot
.532 .22014 Mdot
.532 .22049 Mdot
.532 .22167 Mdot
.532 .22193 Mdot
.532 .22205 Mdot
.532 .22238 Mdot
.532 .22242 Mdot
.532 .22268 Mdot
.532 .22271 Mdot
.532 .22286 Mdot
.532 .2242 Mdot
.532 .22435 Mdot
.532 .22476 Mdot
.532 .22572 Mdot
.532 .22646 Mdot
.532 .22659 Mdot
.532 .2267 Mdot
.532 .22687 Mdot
.532 .22818 Mdot
.532 .2288 Mdot
.532 .22901 Mdot
.532 .22938 Mdot
.532 .23054 Mdot
.532 .23067 Mdot
.532 .2311 Mdot
.532 .23113 Mdot
.532 .23241 Mdot
.532 .23249 Mdot
.532 .23383 Mdot
.532 .23424 Mdot
.532 .23433 Mdot
.532 .2348 Mdot
.532 .23496 Mdot
.532 .2352 Mdot
.532 .23679 Mdot
.532 .23683 Mdot
.532 .23739 Mdot
.532 .23766 Mdot
.532 .23814 Mdot
.532 .23875 Mdot
.532 .23935 Mdot
.532 .23956 Mdot
.532 .23967 Mdot
.532 .23973 Mdot
.532 .24014 Mdot
.532 .24024 Mdot
.532 .24055 Mdot
.532 .24186 Mdot
.532 .24187 Mdot
.532 .24292 Mdot
.532 .24526 Mdot
.532 .24592 Mdot
.532 .24678 Mdot
.532 .24786 Mdot
.532 .24856 Mdot
.532 .2495 Mdot
.532 .25091 Mdot
.532 .25111 Mdot
.532 .25177 Mdot
.532 .25183 Mdot
.532 .25228 Mdot
.532 .25263 Mdot
.532 .25274 Mdot
.532 .254 Mdot
.532 .25438 Mdot
.532 .25545 Mdot
.532 .25582 Mdot
.532 .25714 Mdot
.532 .25774 Mdot
.532 .25775 Mdot
.532 .25899 Mdot
.532 .25902 Mdot
.532 .25921 Mdot
.532 .25957 Mdot
.532 .26022 Mdot
.532 .26038 Mdot
.532 .26072 Mdot
.532 .26172 Mdot
.532 .26226 Mdot
.532 .26257 Mdot
.532 .26347 Mdot
.532 .2643 Mdot
.532 .26432 Mdot
.532 .2646 Mdot
.532 .26569 Mdot
.532 .26715 Mdot
.532 .26726 Mdot
.532 .26743 Mdot
.532 .26794 Mdot
.532 .26902 Mdot
.532 .27011 Mdot
.532 .27032 Mdot
.532 .2706 Mdot
.532 .27286 Mdot
.532 .27288 Mdot
.532 .27309 Mdot
.532 .27331 Mdot
.532 .27572 Mdot
.532 .27641 Mdot
.532 .2766 Mdot
.532 .27706 Mdot
.532 .27719 Mdot
.532 .27753 Mdot
.532 .27764 Mdot
.532 .27789 Mdot
.532 .27793 Mdot
.532 .27836 Mdot
.532 .27906 Mdot
.532 .27944 Mdot
.532 .27964 Mdot
.532 .27969 Mdot
.532 .28008 Mdot
.532 .28106 Mdot
.532 .28136 Mdot
.532 .28214 Mdot
.532 .28257 Mdot
.532 .2827 Mdot
.532 .28274 Mdot
.532 .28319 Mdot
.532 .28401 Mdot
.532 .28403 Mdot
.532 .2841 Mdot
.532 .28561 Mdot
.532 .28627 Mdot
.532 .28683 Mdot
.532 .28694 Mdot
.532 .28772 Mdot
.532 .28829 Mdot
.532 .28829 Mdot
.532 .28861 Mdot
.532 .28866 Mdot
.532 .28875 Mdot
.532 .28891 Mdot
.532 .28904 Mdot
.532 .28943 Mdot
.532 .28974 Mdot
.532 .28996 Mdot
.532 .29073 Mdot
.532 .29092 Mdot
.532 .2912 Mdot
.532 .2915 Mdot
.532 .29156 Mdot
.532 .29232 Mdot
.532 .29239 Mdot
.532 .2935 Mdot
.532 .29372 Mdot
.532 .29406 Mdot
.532 .29418 Mdot
.532 .29424 Mdot
.532 .29478 Mdot
.532 .29516 Mdot
.532 .2952 Mdot
.532 .29536 Mdot
.532 .29617 Mdot
.532 .2964 Mdot
.532 .2966 Mdot
.532 .29664 Mdot
.532 .29712 Mdot
.532 .29724 Mdot
.532 .29729 Mdot
.532 .29735 Mdot
.532 .29754 Mdot
.532 .29823 Mdot
.532 .29837 Mdot
.532 .29868 Mdot
.532 .29871 Mdot
.532 .29948 Mdot
.532 .29975 Mdot
.532 .29993 Mdot
.532 .30052 Mdot
.532 .30062 Mdot
.532 .30064 Mdot
.532 .30089 Mdot
.532 .30095 Mdot
.532 .30111 Mdot
.532 .30149 Mdot
.532 .30176 Mdot
.532 .30222 Mdot
.532 .30238 Mdot
.532 .30249 Mdot
.532 .30289 Mdot
.532 .30295 Mdot
.532 .30297 Mdot
.532 .30308 Mdot
.532 .30314 Mdot
.532 .30318 Mdot
.532 .3033 Mdot
.532 .3044 Mdot
.532 .30483 Mdot
.532 .30485 Mdot
.532 .30496 Mdot
.532 .30502 Mdot
.532 .30507 Mdot
.532 .30762 Mdot
.532 .30802 Mdot
.532 .30829 Mdot
.532 .30862 Mdot
.532 .31045 Mdot
.532 .31285 Mdot
.532 .31387 Mdot
.532 .31425 Mdot
.532 .31762 Mdot
.532 .31801 Mdot
.532 .31808 Mdot
.532 .31875 Mdot
.532 .31885 Mdot
.532 .31968 Mdot
.532 .31999 Mdot
.532 .32064 Mdot
.532 .32366 Mdot
.532 .32457 Mdot
.532 .32725 Mdot
.532 .32733 Mdot
.532 .328 Mdot
.532 .32874 Mdot
.532 .33022 Mdot
.532 .33417 Mdot
.532 .33451 Mdot
.532 .33638 Mdot
.532 .33682 Mdot
.532 .33738 Mdot
.532 .33785 Mdot
.532 .33847 Mdot
.532 .33866 Mdot
.532 .33907 Mdot
.532 .34045 Mdot
.532 .34059 Mdot
.532 .34081 Mdot
.532 .34084 Mdot
.532 .34085 Mdot
.532 .34092 Mdot
.532 .34156 Mdot
.532 .34183 Mdot
.532 .34199 Mdot
.532 .34217 Mdot
.532 .34291 Mdot
.532 .34302 Mdot
.532 .34426 Mdot
.532 .34599 Mdot
.532 .34626 Mdot
.532 .34716 Mdot
.532 .34735 Mdot
.532 .34768 Mdot
.532 .3479 Mdot
.532 .34804 Mdot
.532 .34912 Mdot
.532 .34941 Mdot
.532 .3507 Mdot
.532 .35178 Mdot
.532 .3522 Mdot
.532 .35259 Mdot
.532 .35335 Mdot
.532 .35461 Mdot
.532 .35572 Mdot
.532 .35606 Mdot
.532 .35616 Mdot
.532 .35729 Mdot
.532 .3581 Mdot
.532 .35894 Mdot
.532 .35929 Mdot
.532 .35934 Mdot
.532 .35952 Mdot
.532 .36305 Mdot
.532 .36454 Mdot
.532 .36578 Mdot
.532 .36602 Mdot
.532 .36767 Mdot
.532 .36786 Mdot
.532 .36885 Mdot
.532 .36885 Mdot
.532 .36949 Mdot
.532 .36959 Mdot
.532 .36976 Mdot
.532 .37009 Mdot
.532 .37034 Mdot
.532 .37083 Mdot
.532 .3711 Mdot
.532 .3717 Mdot
.532 .3721 Mdot
.532 .37224 Mdot
.532 .37347 Mdot
.532 .37353 Mdot
.532 .37361 Mdot
.532 .37385 Mdot
.532 .37437 Mdot
.532 .37488 Mdot
.532 .37498 Mdot
.532 .37627 Mdot
.532 .37638 Mdot
.532 .3781 Mdot
.532 .37816 Mdot
.532 .37849 Mdot
.532 .379 Mdot
.532 .37917 Mdot
.532 .37926 Mdot
.532 .37946 Mdot
.532 .38003 Mdot
.532 .38057 Mdot
.532 .38063 Mdot
.532 .38084 Mdot
.532 .38121 Mdot
.532 .38191 Mdot
.532 .38219 Mdot
.532 .38244 Mdot
.532 .38249 Mdot
.532 .38308 Mdot
.532 .38321 Mdot
.532 .38327 Mdot
.532 .38334 Mdot
.532 .3834 Mdot
.532 .38357 Mdot
.532 .38413 Mdot
.532 .38433 Mdot
.532 .38446 Mdot
.532 .38448 Mdot
.532 .38481 Mdot
.532 .38483 Mdot
.532 .38531 Mdot
.532 .3854 Mdot
.532 .3856 Mdot
.532 .38585 Mdot
.532 .38601 Mdot
.532 .38603 Mdot
.532 .3861 Mdot
.532 .38644 Mdot
.532 .38653 Mdot
.532 .38662 Mdot
.532 .38663 Mdot
.532 .38684 Mdot
.532 .38689 Mdot
.532 .38701 Mdot
.532 .3873 Mdot
.532 .3875 Mdot
.532 .38782 Mdot
.532 .38794 Mdot
.532 .38801 Mdot
.532 .38826 Mdot
.532 .3883 Mdot
.532 .38831 Mdot
.532 .38841 Mdot
.532 .38843 Mdot
.532 .3885 Mdot
.532 .38877 Mdot
.532 .38896 Mdot
.532 .38907 Mdot
.532 .38926 Mdot
.532 .38927 Mdot
.532 .38931 Mdot
.532 .38934 Mdot
.532 .38935 Mdot
.532 .3894 Mdot
.532 .39003 Mdot
.532 .39004 Mdot
.532 .39008 Mdot
.532 .39011 Mdot
.532 .39013 Mdot
.532 .46923 Mdot
.532 .46924 Mdot
.532 .46925 Mdot
.532 .46927 Mdot
.532 .46927 Mdot
.532 .46959 Mdot
.532 .46962 Mdot
.532 .46963 Mdot
.532 .46964 Mdot
.532 .46966 Mdot
.532 .46966 Mdot
.532 .46976 Mdot
.532 .46982 Mdot
.532 .46991 Mdot
.532 .47005 Mdot
.532 .47008 Mdot
.532 .47009 Mdot
.532 .47015 Mdot
.532 .47015 Mdot
.532 .47017 Mdot
.532 .47029 Mdot
.532 .47033 Mdot
.532 .47039 Mdot
.532 .47055 Mdot
.532 .47065 Mdot
.532 .47079 Mdot
.532 .47086 Mdot
.532 .47088 Mdot
.532 .47099 Mdot
.532 .47099 Mdot
.532 .47104 Mdot
.532 .47108 Mdot
.532 .47125 Mdot
.532 .47129 Mdot
.532 .4713 Mdot
.532 .47138 Mdot
.532 .4715 Mdot
.532 .4716 Mdot
.532 .47165 Mdot
.532 .47188 Mdot
.532 .4719 Mdot
.532 .47206 Mdot
.532 .47207 Mdot
.532 .47214 Mdot
.532 .47224 Mdot
.532 .47251 Mdot
.532 .4726 Mdot
.532 .47263 Mdot
.532 .47266 Mdot
.532 .47269 Mdot
.532 .47276 Mdot
.532 .47305 Mdot
.532 .47307 Mdot
.532 .4732 Mdot
.532 .47334 Mdot
.532 .47368 Mdot
.532 .47386 Mdot
.532 .47397 Mdot
.532 .474 Mdot
.532 .47426 Mdot
.532 .47454 Mdot
.532 .47464 Mdot
.532 .47468 Mdot
.532 .47477 Mdot
.532 .47502 Mdot
.532 .47518 Mdot
.532 .47521 Mdot
.532 .47605 Mdot
.532 .4761 Mdot
.532 .47672 Mdot
.532 .47677 Mdot
.532 .47702 Mdot
.532 .47727 Mdot
.532 .47739 Mdot
.532 .47743 Mdot
.532 .47745 Mdot
.532 .47804 Mdot
.532 .47811 Mdot
.532 .47831 Mdot
.532 .47859 Mdot
.532 .47872 Mdot
.532 .47896 Mdot
.532 .47907 Mdot
.532 .47923 Mdot
.532 .47931 Mdot
.532 .47936 Mdot
.532 .47967 Mdot
.532 .47967 Mdot
.532 .48013 Mdot
.532 .48022 Mdot
.532 .48101 Mdot
.532 .48112 Mdot
.532 .48171 Mdot
.532 .4824 Mdot
.532 .48405 Mdot
.532 .48413 Mdot
.532 .48416 Mdot
.532 .48431 Mdot
.532 .48471 Mdot
.532 .48508 Mdot
.532 .4856 Mdot
.532 .48564 Mdot
.532 .4858 Mdot
.532 .48631 Mdot
.532 .48688 Mdot
.532 .48723 Mdot
.532 .48741 Mdot
.532 .4876 Mdot
.532 .48809 Mdot
.532 .48867 Mdot
.532 .48881 Mdot
.532 .48929 Mdot
.532 .48935 Mdot
.532 .48945 Mdot
.532 .4896 Mdot
.532 .48969 Mdot
.532 .49009 Mdot
.532 .49021 Mdot
.532 .49099 Mdot
.532 .49154 Mdot
.532 .49159 Mdot
.532 .49192 Mdot
.532 .492 Mdot
.532 .49207 Mdot
.532 .49219 Mdot
.532 .49247 Mdot
.532 .4925 Mdot
.532 .49251 Mdot
.532 .49252 Mdot
.532 .49261 Mdot
.532 .49268 Mdot
.532 .49329 Mdot
.532 .49347 Mdot
.532 .49355 Mdot
.532 .49383 Mdot
.532 .49403 Mdot
.532 .49428 Mdot
.532 .49447 Mdot
.532 .49528 Mdot
.532 .49543 Mdot
.532 .49715 Mdot
.532 .49778 Mdot
.532 .4981 Mdot
.532 .49839 Mdot
.532 .49842 Mdot
.532 .49957 Mdot
.532 .49996 Mdot
.532 .50124 Mdot
.532 .50151 Mdot
.532 .50164 Mdot
.532 .50199 Mdot
.532 .50203 Mdot
.532 .50231 Mdot
.532 .50234 Mdot
.532 .50251 Mdot
.532 .50392 Mdot
.532 .50407 Mdot
.532 .5045 Mdot
.532 .50549 Mdot
.532 .50625 Mdot
.532 .50638 Mdot
.532 .50649 Mdot
.532 .50666 Mdot
.532 .5077 Mdot
.532 .50772 Mdot
.532 .50774 Mdot
.532 .50779 Mdot
.532 .5078 Mdot
.532 .50797 Mdot
.532 .50842 Mdot
.532 .50847 Mdot
.532 .50849 Mdot
.532 .50851 Mdot
.532 .50856 Mdot
.532 .50856 Mdot
.532 .50859 Mdot
.532 .50875 Mdot
.532 .5088 Mdot
.532 .50886 Mdot
.532 .50905 Mdot
.532 .50916 Mdot
.532 .50931 Mdot
.532 .50938 Mdot
.532 .5094 Mdot
.532 .5095 Mdot
.532 .50951 Mdot
.532 .50955 Mdot
.532 .50979 Mdot
.532 .50986 Mdot
.532 .50997 Mdot
.532 .51028 Mdot
.532 .51029 Mdot
.532 .51042 Mdot
.532 .51048 Mdot
.532 .51075 Mdot
.532 .51083 Mdot
.532 .51086 Mdot
.532 .51088 Mdot
.532 .51092 Mdot
.532 .51112 Mdot
.532 .51113 Mdot
.532 .51121 Mdot
.532 .5113 Mdot
.532 .51163 Mdot
.532 .51169 Mdot
.532 .51171 Mdot
.532 .51186 Mdot
.532 .51208 Mdot
.532 .5121 Mdot
.532 .51215 Mdot
.532 .51228 Mdot
.532 .51237 Mdot
.532 .51282 Mdot
.532 .51284 Mdot
.532 .51315 Mdot
.532 .51317 Mdot
.532 .51329 Mdot
.532 .5134 Mdot
.532 .51347 Mdot
.532 .51378 Mdot
.532 .51387 Mdot
.532 .51399 Mdot
.532 .51415 Mdot
.532 .5142 Mdot
.532 .51426 Mdot
.532 .5143 Mdot
.532 .51431 Mdot
.532 .51444 Mdot
.532 .51444 Mdot
.532 .51467 Mdot
.532 .51497 Mdot
.532 .51502 Mdot
.532 .51524 Mdot
.532 .5155 Mdot
.532 .51609 Mdot
.532 .51612 Mdot
.532 .51613 Mdot
.532 .51645 Mdot
.532 .51662 Mdot
.532 .51664 Mdot
.532 .51669 Mdot
.532 .51686 Mdot
.532 .51716 Mdot
.532 .51728 Mdot
.532 .51766 Mdot
.532 .51781 Mdot
.532 .51783 Mdot
.532 .51791 Mdot
.532 .51806 Mdot
.532 .51833 Mdot
.532 .5185 Mdot
.532 .51851 Mdot
.532 .51861 Mdot
.532 .51865 Mdot
.532 .51878 Mdot
.532 .51883 Mdot
.532 .51901 Mdot
.532 .51909 Mdot
.532 .51935 Mdot
.532 .52028 Mdot
.532 .52036 Mdot
.532 .52044 Mdot
.532 .52045 Mdot
.532 .52132 Mdot
.532 .52142 Mdot
.532 .52151 Mdot
.532 .52192 Mdot
.532 .52233 Mdot
.532 .52253 Mdot
.532 .52259 Mdot
.532 .52263 Mdot
.532 .52318 Mdot
.532 .5236 Mdot
.532 .52371 Mdot
.532 .52371 Mdot
.532 .52403 Mdot
.532 .52436 Mdot
.532 .52448 Mdot
.532 .52469 Mdot
.532 .52506 Mdot
.532 .52519 Mdot
.532 .52525 Mdot
.532 .52549 Mdot
.532 .52563 Mdot
.532 .5257 Mdot
.532 .52571 Mdot
.532 .52618 Mdot
.532 .52618 Mdot
.532 .5264 Mdot
.532 .52689 Mdot
.532 .52703 Mdot
.532 .52743 Mdot
.532 .52757 Mdot
.532 .52804 Mdot
.532 .52808 Mdot
.532 .52821 Mdot
.532 .52838 Mdot
.532 .5284 Mdot
.532 .52864 Mdot
.532 .52872 Mdot
.532 .52924 Mdot
.532 .52958 Mdot
.532 .52984 Mdot
.532 .53024 Mdot
.532 .53055 Mdot
.532 .5308 Mdot
.532 .53165 Mdot
.532 .53203 Mdot
.532 .53204 Mdot
.532 .53251 Mdot
.532 .53263 Mdot
.532 .53266 Mdot
.532 .53281 Mdot
.532 .53283 Mdot
.532 .53287 Mdot
.532 .53295 Mdot
.532 .53316 Mdot
.532 .53339 Mdot
.532 .53356 Mdot
.532 .53366 Mdot
.532 .53386 Mdot
.532 .53387 Mdot
.532 .53445 Mdot
.532 .53453 Mdot
.532 .53459 Mdot
.532 .53476 Mdot
.532 .53479 Mdot
.532 .53494 Mdot
.532 .53542 Mdot
.532 .53545 Mdot
.532 .53591 Mdot
.532 .53592 Mdot
.532 .53607 Mdot
.532 .53612 Mdot
.532 .53653 Mdot
.532 .53667 Mdot
.532 .53674 Mdot
.532 .53696 Mdot
.532 .53743 Mdot
.532 .53749 Mdot
.532 .53752 Mdot
.532 .53757 Mdot
.532 .53783 Mdot
.532 .53817 Mdot
.532 .53832 Mdot
.532 .53837 Mdot
.532 .53885 Mdot
.532 .5389 Mdot
.532 .53891 Mdot
.532 .539 Mdot
.532 .53902 Mdot
.532 .53913 Mdot
.532 .53918 Mdot
.532 .53927 Mdot
.532 .53968 Mdot
.532 .53981 Mdot
.532 .54017 Mdot
.532 .54018 Mdot
.532 .54027 Mdot
.532 .54037 Mdot
.532 .54057 Mdot
.532 .5411 Mdot
.532 .54115 Mdot
.532 .5414 Mdot
.532 .54146 Mdot
.532 .54153 Mdot
.532 .54159 Mdot
.532 .54168 Mdot
.532 .5417 Mdot
.532 .54176 Mdot
.532 .54194 Mdot
.532 .54196 Mdot
.532 .54198 Mdot
.532 .54199 Mdot
.532 .54199 Mdot
.532 .542 Mdot
.532 .54208 Mdot
.532 .54212 Mdot
.532 .54214 Mdot
.532 .54216 Mdot
.532 .54226 Mdot
.532 .54227 Mdot
.532 .54244 Mdot
.532 .54266 Mdot
.532 .5427 Mdot
.532 .54281 Mdot
.532 .54284 Mdot
.532 .54288 Mdot
.532 .54291 Mdot
.532 .54293 Mdot
.532 .54307 Mdot
.532 .54311 Mdot
.532 .54327 Mdot
.532 .54341 Mdot
.532 .54347 Mdot
.532 .54352 Mdot
.532 .54361 Mdot
.532 .54378 Mdot
.532 .54392 Mdot
.532 .54396 Mdot
.532 .54397 Mdot
.532 .54412 Mdot
.532 .54422 Mdot
.532 .54433 Mdot
.532 .54437 Mdot
.532 .54438 Mdot
.532 .5444 Mdot
.532 .54485 Mdot
.532 .54504 Mdot
.532 .54519 Mdot
.532 .54523 Mdot
.532 .54543 Mdot
.532 .54546 Mdot
.532 .54558 Mdot
.532 .54558 Mdot
.532 .54566 Mdot
.532 .54567 Mdot
.532 .5457 Mdot
.532 .54574 Mdot
.532 .54577 Mdot
.532 .54583 Mdot
.532 .54586 Mdot
.532 .54594 Mdot
.532 .54599 Mdot
.532 .54601 Mdot
.532 .54616 Mdot
.532 .54617 Mdot
.532 .54618 Mdot
.532 .54621 Mdot
.532 .54627 Mdot
.532 .54634 Mdot
.532 .54635 Mdot
.532 .54651 Mdot
.532 .54652 Mdot
.532 .54674 Mdot
.532 .54674 Mdot
.532 .54679 Mdot
.532 .54685 Mdot
.532 .54687 Mdot
.532 .54688 Mdot
.532 .54691 Mdot
.532 .54698 Mdot
.532 .54704 Mdot
.532 .54705 Mdot
.532 .54708 Mdot
.532 .54721 Mdot
.532 .54724 Mdot
.532 .54728 Mdot
.532 .54728 Mdot
.532 .54735 Mdot
.532 .54737 Mdot
.532 .54738 Mdot
.532 .54739 Mdot
.532 .54739 Mdot
.532 .54742 Mdot
.532 .54748 Mdot
.532 .54751 Mdot
.532 .54752 Mdot
.532 .54753 Mdot
.532 .54757 Mdot
.532 .54757 Mdot
.532 .54763 Mdot
.532 .54764 Mdot
.532 .54767 Mdot
.532 .5477 Mdot
.532 .54772 Mdot
.532 .54772 Mdot
.532 .54773 Mdot
.532 .54777 Mdot
.532 .54778 Mdot
.532 .54779 Mdot
.532 .54779 Mdot
.532 .54782 Mdot
.532 .54783 Mdot
.532 .54784 Mdot
.532 .54788 Mdot
.532 .5479 Mdot
.532 .54794 Mdot
.532 .54795 Mdot
.532 .54796 Mdot
.532 .54799 Mdot
.532 .548 Mdot
.532 .548 Mdot
.532 .54801 Mdot
.532 .54802 Mdot
.532 .54802 Mdot
.532 .54806 Mdot
.532 .54808 Mdot
.532 .54809 Mdot
.532 .54812 Mdot
.532 .54812 Mdot
.532 .54812 Mdot
.532 .54813 Mdot
.532 .54813 Mdot
.532 .54814 Mdot
.532 .54821 Mdot
.532 .54821 Mdot
.532 .54822 Mdot
.532 .54822 Mdot
.532 .54822 Mdot
.534 .19516 Mdot
.534 .30821 Mdot
.534 .39157 Mdot
.534 .46858 Mdot
.534 .50647 Mdot
.534 .54846 Mdot
.536 .19461 Mdot
.536 .31105 Mdot
.536 .39287 Mdot
.536 .468 Mdot
.536 .50535 Mdot
.536 .54867 Mdot
.538 .19414 Mdot
.538 .19414 Mdot
.538 .19414 Mdot
.538 .19414 Mdot
.538 .19414 Mdot
.538 .19414 Mdot
.538 .19426 Mdot
.538 .19426 Mdot
.538 .19426 Mdot
.538 .19426 Mdot
.538 .19426 Mdot
.538 .19426 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .3125 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .31337 Mdot
.538 .3936 Mdot
.538 .3936 Mdot
.538 .3936 Mdot
.538 .3936 Mdot
.538 .3936 Mdot
.538 .3936 Mdot
.538 .3936 Mdot
.538 .3936 Mdot
.538 .3936 Mdot
.538 .3936 Mdot
.538 .3936 Mdot
.538 .3936 Mdot
.538 .3936 Mdot
.538 .3936 Mdot
.538 .39395 Mdot
.538 .39395 Mdot
.538 .39395 Mdot
.538 .39395 Mdot
.538 .39395 Mdot
.538 .39395 Mdot
.538 .39395 Mdot
.538 .39395 Mdot
.538 .39395 Mdot
.538 .39395 Mdot
.538 .39395 Mdot
.538 .39395 Mdot
.538 .39395 Mdot
.538 .46754 Mdot
.538 .46754 Mdot
.538 .46754 Mdot
.538 .46754 Mdot
.538 .46754 Mdot
.538 .46754 Mdot
.538 .46754 Mdot
.538 .46771 Mdot
.538 .46771 Mdot
.538 .46771 Mdot
.538 .46771 Mdot
.538 .46771 Mdot
.538 .46771 Mdot
.538 .46771 Mdot
.538 .50444 Mdot
.538 .50444 Mdot
.538 .50444 Mdot
.538 .50444 Mdot
.538 .50444 Mdot
.538 .50444 Mdot
.538 .50444 Mdot
.538 .50444 Mdot
.538 .50444 Mdot
.538 .50444 Mdot
.538 .50444 Mdot
.538 .50444 Mdot
.538 .50444 Mdot
.538 .50481 Mdot
.538 .50481 Mdot
.538 .50481 Mdot
.538 .50481 Mdot
.538 .50481 Mdot
.538 .50481 Mdot
.538 .50481 Mdot
.538 .50481 Mdot
.538 .50481 Mdot
.538 .50481 Mdot
.538 .50481 Mdot
.538 .50481 Mdot
.538 .50481 Mdot
.538 .50481 Mdot
.538 .54882 Mdot
.538 .54882 Mdot
.538 .54882 Mdot
.538 .54886 Mdot
.538 .54886 Mdot
.54 .19333 Mdot
.54 .19481 Mdot
.54 .3077 Mdot
.54 .31813 Mdot
.54 .39184 Mdot
.54 .39597 Mdot
.54 .46659 Mdot
.54 .46869 Mdot
.54 .50252 Mdot
.54 .50684 Mdot
.54 .54866 Mdot
.54 .54916 Mdot
.542 .19268 Mdot
.542 .19268 Mdot
.542 .19268 Mdot
.542 .19268 Mdot
.542 .19268 Mdot
.542 .19269 Mdot
.542 .1927 Mdot
.542 .19274 Mdot
.542 .19275 Mdot
.542 .19275 Mdot
.542 .19275 Mdot
.542 .19275 Mdot
.542 .19275 Mdot
.542 .19276 Mdot
.542 .19276 Mdot
.542 .19278 Mdot
.542 .19278 Mdot
.542 .1928 Mdot
.542 .19281 Mdot
.542 .19281 Mdot
.542 .19281 Mdot
.542 .19281 Mdot
.542 .19282 Mdot
.542 .19284 Mdot
.542 .19284 Mdot
.542 .19287 Mdot
.542 .19288 Mdot
.542 .19294 Mdot
.542 .19294 Mdot
.542 .19294 Mdot
.542 .19294 Mdot
.542 .19294 Mdot
.542 .19296 Mdot
.542 .19298 Mdot
.542 .19303 Mdot
.542 .19304 Mdot
.542 .19307 Mdot
.542 .19308 Mdot
.542 .19309 Mdot
.542 .19309 Mdot
.542 .19309 Mdot
.542 .19318 Mdot
.542 .19319 Mdot
.542 .19319 Mdot
.542 .19319 Mdot
.542 .19319 Mdot
.542 .1932 Mdot
.542 .19321 Mdot
.542 .19322 Mdot
.542 .19323 Mdot
.542 .19326 Mdot
.542 .19326 Mdot
.542 .19327 Mdot
.542 .19328 Mdot
.542 .19335 Mdot
.542 .19337 Mdot
.542 .19341 Mdot
.542 .19341 Mdot
.542 .19342 Mdot
.542 .19342 Mdot
.542 .19343 Mdot
.542 .19344 Mdot
.542 .19344 Mdot
.542 .19349 Mdot
.542 .19349 Mdot
.542 .19349 Mdot
.542 .1935 Mdot
.542 .19351 Mdot
.542 .19351 Mdot
.542 .19351 Mdot
.542 .19351 Mdot
.542 .19352 Mdot
.542 .19352 Mdot
.542 .19352 Mdot
.542 .19352 Mdot
.542 .19352 Mdot
.542 .19352 Mdot
.542 .19352 Mdot
.542 .19352 Mdot
.542 .19352 Mdot
.542 .19352 Mdot
.542 .19353 Mdot
.542 .19353 Mdot
.542 .19353 Mdot
.542 .19353 Mdot
.542 .19353 Mdot
.542 .19353 Mdot
.542 .19354 Mdot
.542 .19354 Mdot
.542 .19354 Mdot
.542 .19354 Mdot
.542 .19357 Mdot
.542 .19358 Mdot
.542 .19358 Mdot
.542 .19359 Mdot
.542 .19359 Mdot
.542 .19367 Mdot
.542 .19368 Mdot
.542 .19369 Mdot
.542 .19371 Mdot
.542 .19372 Mdot
.542 .19373 Mdot
.542 .19374 Mdot
.542 .19381 Mdot
.542 .19382 Mdot
.542 .19383 Mdot
.542 .19386 Mdot
.542 .19386 Mdot
.542 .19395 Mdot
.542 .19395 Mdot
.542 .19395 Mdot
.542 .19395 Mdot
.542 .19395 Mdot
.542 .19401 Mdot
.542 .19402 Mdot
.542 .19406 Mdot
.542 .19406 Mdot
.542 .19412 Mdot
.542 .19415 Mdot
.542 .19418 Mdot
.542 .19418 Mdot
.542 .19421 Mdot
.542 .19421 Mdot
.542 .19421 Mdot
.542 .19421 Mdot
.542 .19423 Mdot
.542 .19446 Mdot
.542 .19447 Mdot
.542 .19447 Mdot
.542 .1945 Mdot
.542 .19451 Mdot
.542 .1946 Mdot
.542 .19463 Mdot
.542 .19477 Mdot
.542 .19482 Mdot
.542 .19487 Mdot
.542 .19487 Mdot
.542 .19488 Mdot
.542 .19488 Mdot
.542 .19488 Mdot
.542 .19505 Mdot
.542 .19507 Mdot
.542 .19517 Mdot
.542 .19517 Mdot
.542 .19525 Mdot
.542 .19525 Mdot
.542 .19525 Mdot
.542 .19526 Mdot
.542 .19526 Mdot
.542 .1953 Mdot
.542 .19536 Mdot
.542 .19537 Mdot
.542 .19541 Mdot
.542 .19542 Mdot
.542 .19545 Mdot
.542 .19547 Mdot
.542 .19547 Mdot
.542 .19547 Mdot
.542 .19547 Mdot
.542 .1955 Mdot
.542 .19563 Mdot
.542 .19565 Mdot
.542 .19569 Mdot
.542 .19569 Mdot
.542 .19569 Mdot
.542 .19569 Mdot
.542 .19569 Mdot
.542 .30068 Mdot
.542 .30068 Mdot
.542 .30068 Mdot
.542 .30069 Mdot
.542 .30069 Mdot
.542 .30097 Mdot
.542 .3011 Mdot
.542 .302 Mdot
.542 .3022 Mdot
.542 .30222 Mdot
.542 .30223 Mdot
.542 .30223 Mdot
.542 .30233 Mdot
.542 .30257 Mdot
.542 .30259 Mdot
.542 .30286 Mdot
.542 .30296 Mdot
.542 .3034 Mdot
.542 .30365 Mdot
.542 .30366 Mdot
.542 .30372 Mdot
.542 .30372 Mdot
.542 .30372 Mdot
.542 .30428 Mdot
.542 .30428 Mdot
.542 .30498 Mdot
.542 .30509 Mdot
.542 .30628 Mdot
.542 .30628 Mdot
.542 .30629 Mdot
.542 .30631 Mdot
.542 .30632 Mdot
.542 .30671 Mdot
.542 .30702 Mdot
.542 .30802 Mdot
.542 .30819 Mdot
.542 .30885 Mdot
.542 .3089 Mdot
.542 .30914 Mdot
.542 .30914 Mdot
.542 .30918 Mdot
.542 .3108 Mdot
.542 .31093 Mdot
.542 .31094 Mdot
.542 .31095 Mdot
.542 .31095 Mdot
.542 .31115 Mdot
.542 .31117 Mdot
.542 .31137 Mdot
.542 .31159 Mdot
.542 .312 Mdot
.542 .312 Mdot
.542 .31229 Mdot
.542 .31234 Mdot
.542 .31279 Mdot
.542 .31279 Mdot
.542 .31279 Mdot
.542 .3128 Mdot
.542 .3128 Mdot
.542 .31339 Mdot
.542 .31344 Mdot
.542 .31366 Mdot
.542 .31367 Mdot
.542 .31376 Mdot
.542 .31427 Mdot
.542 .31432 Mdot
.542 .31444 Mdot
.542 .31451 Mdot
.542 .31464 Mdot
.542 .31472 Mdot
.542 .31474 Mdot
.542 .31533 Mdot
.542 .31534 Mdot
.542 .31538 Mdot
.542 .3154 Mdot
.542 .31547 Mdot
.542 .31566 Mdot
.542 .31566 Mdot
.542 .31567 Mdot
.542 .31576 Mdot
.542 .31576 Mdot
.542 .31577 Mdot
.542 .31577 Mdot
.542 .31579 Mdot
.542 .31579 Mdot
.542 .3158 Mdot
.542 .3158 Mdot
.542 .31581 Mdot
.542 .31581 Mdot
.542 .31582 Mdot
.542 .31582 Mdot
.542 .31582 Mdot
.542 .31583 Mdot
.542 .31584 Mdot
.542 .31584 Mdot
.542 .31587 Mdot
.542 .31589 Mdot
.542 .31589 Mdot
.542 .31589 Mdot
.542 .316 Mdot
.542 .31605 Mdot
.542 .31607 Mdot
.542 .31608 Mdot
.542 .31639 Mdot
.542 .3164 Mdot
.542 .31644 Mdot
.542 .31651 Mdot
.542 .31654 Mdot
.542 .31661 Mdot
.542 .31663 Mdot
.542 .31688 Mdot
.542 .31693 Mdot
.542 .31704 Mdot
.542 .31756 Mdot
.542 .31758 Mdot
.542 .31771 Mdot
.542 .31771 Mdot
.542 .31789 Mdot
.542 .31798 Mdot
.542 .31807 Mdot
.542 .31808 Mdot
.542 .31817 Mdot
.542 .31817 Mdot
.542 .31817 Mdot
.542 .31817 Mdot
.542 .31823 Mdot
.542 .31889 Mdot
.542 .31891 Mdot
.542 .31891 Mdot
.542 .319 Mdot
.542 .31902 Mdot
.542 .31928 Mdot
.542 .31934 Mdot
.542 .31972 Mdot
.542 .31983 Mdot
.542 .31997 Mdot
.542 .31997 Mdot
.542 .31998 Mdot
.542 .31998 Mdot
.542 .31998 Mdot
.542 .32041 Mdot
.542 .32044 Mdot
.542 .32068 Mdot
.542 .32068 Mdot
.542 .32087 Mdot
.542 .32087 Mdot
.542 .32087 Mdot
.542 .32089 Mdot
.542 .3209 Mdot
.542 .32098 Mdot
.542 .32113 Mdot
.542 .32116 Mdot
.542 .32125 Mdot
.542 .32125 Mdot
.542 .32133 Mdot
.542 .32136 Mdot
.542 .32137 Mdot
.542 .32137 Mdot
.542 .32137 Mdot
.542 .32144 Mdot
.542 .32173 Mdot
.542 .32177 Mdot
.542 .32185 Mdot
.542 .32185 Mdot
.542 .32186 Mdot
.542 .32186 Mdot
.542 .32186 Mdot
.542 .38917 Mdot
.542 .38917 Mdot
.542 .38917 Mdot
.542 .38917 Mdot
.542 .38917 Mdot
.542 .38929 Mdot
.542 .38934 Mdot
.542 .38971 Mdot
.542 .38979 Mdot
.542 .3898 Mdot
.542 .3898 Mdot
.542 .3898 Mdot
.542 .38984 Mdot
.542 .38994 Mdot
.542 .38995 Mdot
.542 .39006 Mdot
.542 .3901 Mdot
.542 .39027 Mdot
.542 .39038 Mdot
.542 .39038 Mdot
.542 .3904 Mdot
.542 .3904 Mdot
.542 .39041 Mdot
.542 .39063 Mdot
.542 .39063 Mdot
.542 .39091 Mdot
.542 .39096 Mdot
.542 .39144 Mdot
.542 .39144 Mdot
.542 .39144 Mdot
.542 .39145 Mdot
.542 .39145 Mdot
.542 .39161 Mdot
.542 .39173 Mdot
.542 .39213 Mdot
.542 .3922 Mdot
.542 .39246 Mdot
.542 .39248 Mdot
.542 .39258 Mdot
.542 .39258 Mdot
.542 .39259 Mdot
.542 .39324 Mdot
.542 .39329 Mdot
.542 .39329 Mdot
.542 .3933 Mdot
.542 .3933 Mdot
.542 .39338 Mdot
.542 .39338 Mdot
.542 .39346 Mdot
.542 .39355 Mdot
.542 .39371 Mdot
.542 .39371 Mdot
.542 .39383 Mdot
.542 .39384 Mdot
.542 .39402 Mdot
.542 .39402 Mdot
.542 .39402 Mdot
.542 .39403 Mdot
.542 .39403 Mdot
.542 .39426 Mdot
.542 .39428 Mdot
.542 .39437 Mdot
.542 .39437 Mdot
.542 .39441 Mdot
.542 .39461 Mdot
.542 .39462 Mdot
.542 .39467 Mdot
.542 .3947 Mdot
.542 .39475 Mdot
.542 .39478 Mdot
.542 .39479 Mdot
.542 .39502 Mdot
.542 .39503 Mdot
.542 .39504 Mdot
.542 .39505 Mdot
.542 .39508 Mdot
.542 .39515 Mdot
.542 .39515 Mdot
.542 .39516 Mdot
.542 .39519 Mdot
.542 .39519 Mdot
.542 .39519 Mdot
.542 .39519 Mdot
.542 .3952 Mdot
.542 .3952 Mdot
.542 .3952 Mdot
.542 .39521 Mdot
.542 .39521 Mdot
.542 .39521 Mdot
.542 .39521 Mdot
.542 .39521 Mdot
.542 .39521 Mdot
.542 .39522 Mdot
.542 .39522 Mdot
.542 .39522 Mdot
.542 .39523 Mdot
.542 .39524 Mdot
.542 .39524 Mdot
.542 .39524 Mdot
.542 .39528 Mdot
.542 .3953 Mdot
.542 .39531 Mdot
.542 .39531 Mdot
.542 .39544 Mdot
.542 .39544 Mdot
.542 .39546 Mdot
.542 .39548 Mdot
.542 .3955 Mdot
.542 .39552 Mdot
.542 .39553 Mdot
.542 .39563 Mdot
.542 .39565 Mdot
.542 .39569 Mdot
.542 .39589 Mdot
.542 .3959 Mdot
.542 .39595 Mdot
.542 .39595 Mdot
.542 .39602 Mdot
.542 .39606 Mdot
.542 .39609 Mdot
.542 .39609 Mdot
.542 .39613 Mdot
.542 .39613 Mdot
.542 .39613 Mdot
.542 .39613 Mdot
.542 .39615 Mdot
.542 .39641 Mdot
.542 .39642 Mdot
.542 .39642 Mdot
.542 .39645 Mdot
.542 .39646 Mdot
.542 .39656 Mdot
.542 .39659 Mdot
.542 .39673 Mdot
.542 .39677 Mdot
.542 .39683 Mdot
.542 .39683 Mdot
.542 .39683 Mdot
.542 .39683 Mdot
.542 .39683 Mdot
.542 .397 Mdot
.542 .39701 Mdot
.542 .39711 Mdot
.542 .39711 Mdot
.542 .39718 Mdot
.542 .39718 Mdot
.542 .39718 Mdot
.542 .39719 Mdot
.542 .39719 Mdot
.542 .39722 Mdot
.542 .39728 Mdot
.542 .39729 Mdot
.542 .39732 Mdot
.542 .39733 Mdot
.542 .39736 Mdot
.542 .39737 Mdot
.542 .39737 Mdot
.542 .39737 Mdot
.542 .39737 Mdot
.542 .3974 Mdot
.542 .39751 Mdot
.542 .39752 Mdot
.542 .39756 Mdot
.542 .39756 Mdot
.542 .39756 Mdot
.542 .39756 Mdot
.542 .39756 Mdot
.542 .46585 Mdot
.542 .46585 Mdot
.542 .46585 Mdot
.542 .46585 Mdot
.542 .46585 Mdot
.542 .46587 Mdot
.542 .46588 Mdot
.542 .46593 Mdot
.542 .46595 Mdot
.542 .46595 Mdot
.542 .46595 Mdot
.542 .46595 Mdot
.542 .46596 Mdot
.542 .46597 Mdot
.542 .46597 Mdot
.542 .46599 Mdot
.542 .466 Mdot
.542 .46603 Mdot
.542 .46604 Mdot
.542 .46604 Mdot
.542 .46605 Mdot
.542 .46605 Mdot
.542 .46605 Mdot
.542 .46609 Mdot
.542 .46609 Mdot
.542 .46613 Mdot
.542 .46614 Mdot
.542 .46622 Mdot
.542 .46623 Mdot
.542 .46623 Mdot
.542 .46623 Mdot
.542 .46623 Mdot
.542 .46626 Mdot
.542 .46628 Mdot
.542 .46635 Mdot
.542 .46637 Mdot
.542 .46642 Mdot
.542 .46642 Mdot
.542 .46644 Mdot
.542 .46644 Mdot
.542 .46644 Mdot
.542 .46658 Mdot
.542 .46659 Mdot
.542 .46659 Mdot
.542 .46659 Mdot
.542 .46659 Mdot
.542 .46661 Mdot
.542 .46661 Mdot
.542 .46662 Mdot
.542 .46664 Mdot
.542 .46668 Mdot
.542 .46668 Mdot
.542 .46671 Mdot
.542 .46671 Mdot
.542 .46681 Mdot
.542 .46684 Mdot
.542 .4669 Mdot
.542 .4669 Mdot
.542 .46691 Mdot
.542 .46692 Mdot
.542 .46693 Mdot
.542 .46694 Mdot
.542 .46694 Mdot
.542 .46701 Mdot
.542 .46701 Mdot
.542 .46701 Mdot
.542 .46702 Mdot
.542 .46704 Mdot
.542 .46704 Mdot
.542 .46704 Mdot
.542 .46705 Mdot
.542 .46705 Mdot
.542 .46705 Mdot
.542 .46706 Mdot
.542 .46706 Mdot
.542 .46706 Mdot
.542 .46706 Mdot
.542 .46706 Mdot
.542 .46706 Mdot
.542 .46706 Mdot
.542 .46706 Mdot
.542 .46706 Mdot
.542 .46706 Mdot
.542 .46707 Mdot
.542 .46707 Mdot
.542 .46707 Mdot
.542 .46707 Mdot
.542 .46709 Mdot
.542 .46709 Mdot
.542 .46709 Mdot
.542 .46713 Mdot
.542 .46714 Mdot
.542 .46715 Mdot
.542 .46715 Mdot
.542 .46716 Mdot
.542 .46728 Mdot
.542 .46728 Mdot
.542 .4673 Mdot
.542 .46732 Mdot
.542 .46733 Mdot
.542 .46736 Mdot
.542 .46737 Mdot
.542 .46747 Mdot
.542 .46749 Mdot
.542 .46749 Mdot
.542 .46754 Mdot
.542 .46755 Mdot
.542 .46766 Mdot
.542 .46766 Mdot
.542 .46767 Mdot
.542 .46767 Mdot
.542 .46767 Mdot
.542 .46776 Mdot
.542 .46777 Mdot
.542 .46783 Mdot
.542 .46783 Mdot
.542 .46791 Mdot
.542 .46795 Mdot
.542 .46799 Mdot
.542 .468 Mdot
.542 .46804 Mdot
.542 .46804 Mdot
.542 .46804 Mdot
.542 .46804 Mdot
.542 .46807 Mdot
.542 .46839 Mdot
.542 .4684 Mdot
.542 .4684 Mdot
.542 .46845 Mdot
.542 .46846 Mdot
.542 .4686 Mdot
.542 .46863 Mdot
.542 .46883 Mdot
.542 .46889 Mdot
.542 .46897 Mdot
.542 .46898 Mdot
.542 .46898 Mdot
.542 .46898 Mdot
.542 .46898 Mdot
.542 .46922 Mdot
.542 .46925 Mdot
.542 .46939 Mdot
.542 .46939 Mdot
.542 .4695 Mdot
.542 .4695 Mdot
.542 .4695 Mdot
.542 .46952 Mdot
.542 .46952 Mdot
.542 .46957 Mdot
.542 .46966 Mdot
.542 .46968 Mdot
.542 .46973 Mdot
.542 .46974 Mdot
.542 .46979 Mdot
.542 .46981 Mdot
.542 .46981 Mdot
.542 .46981 Mdot
.542 .46981 Mdot
.542 .46986 Mdot
.542 .47004 Mdot
.542 .47007 Mdot
.542 .47012 Mdot
.542 .47012 Mdot
.542 .47012 Mdot
.542 .47012 Mdot
.542 .47012 Mdot
.542 .50101 Mdot
.542 .50101 Mdot
.542 .50101 Mdot
.542 .50101 Mdot
.542 .50101 Mdot
.542 .50104 Mdot
.542 .50106 Mdot
.542 .50118 Mdot
.542 .50121 Mdot
.542 .50121 Mdot
.542 .50121 Mdot
.542 .50121 Mdot
.542 .50123 Mdot
.542 .50126 Mdot
.542 .50126 Mdot
.542 .5013 Mdot
.542 .50131 Mdot
.542 .50138 Mdot
.542 .50141 Mdot
.542 .50141 Mdot
.542 .50142 Mdot
.542 .50142 Mdot
.542 .50142 Mdot
.542 .5015 Mdot
.542 .5015 Mdot
.542 .5016 Mdot
.542 .50162 Mdot
.542 .50179 Mdot
.542 .5018 Mdot
.542 .5018 Mdot
.542 .5018 Mdot
.542 .5018 Mdot
.542 .50186 Mdot
.542 .50191 Mdot
.542 .50206 Mdot
.542 .50209 Mdot
.542 .5022 Mdot
.542 .50221 Mdot
.542 .50225 Mdot
.542 .50225 Mdot
.542 .50225 Mdot
.542 .50253 Mdot
.542 .50255 Mdot
.542 .50256 Mdot
.542 .50256 Mdot
.542 .50256 Mdot
.542 .50259 Mdot
.542 .5026 Mdot
.542 .50263 Mdot
.542 .50267 Mdot
.542 .50275 Mdot
.542 .50275 Mdot
.542 .5028 Mdot
.542 .50281 Mdot
.542 .50303 Mdot
.542 .50307 Mdot
.542 .50309 Mdot
.542 .5032 Mdot
.542 .50321 Mdot
.542 .50324 Mdot
.542 .50325 Mdot
.542 .50328 Mdot
.542 .5033 Mdot
.542 .5033 Mdot
.542 .50343 Mdot
.542 .50343 Mdot
.542 .50344 Mdot
.542 .50346 Mdot
.542 .50351 Mdot
.542 .50351 Mdot
.542 .50351 Mdot
.542 .50351 Mdot
.542 .50353 Mdot
.542 .50353 Mdot
.542 .50353 Mdot
.542 .50354 Mdot
.542 .50354 Mdot
.542 .50354 Mdot
.542 .50354 Mdot
.542 .50354 Mdot
.542 .50354 Mdot
.542 .50355 Mdot
.542 .50355 Mdot
.542 .50355 Mdot
.542 .50356 Mdot
.542 .50356 Mdot
.542 .50356 Mdot
.542 .50356 Mdot
.542 .5036 Mdot
.542 .5036 Mdot
.542 .5036 Mdot
.542 .50368 Mdot
.542 .50371 Mdot
.542 .50372 Mdot
.542 .50374 Mdot
.542 .50374 Mdot
.542 .50399 Mdot
.542 .50399 Mdot
.542 .50403 Mdot
.542 .50408 Mdot
.542 .50411 Mdot
.542 .50416 Mdot
.542 .50418 Mdot
.542 .50439 Mdot
.542 .50443 Mdot
.542 .50443 Mdot
.542 .50452 Mdot
.542 .50455 Mdot
.542 .50479 Mdot
.542 .50479 Mdot
.542 .50479 Mdot
.542 .50479 Mdot
.542 .5048 Mdot
.542 .50498 Mdot
.542 .505 Mdot
.542 .50512 Mdot
.542 .50512 Mdot
.542 .50529 Mdot
.542 .50538 Mdot
.542 .50546 Mdot
.542 .50547 Mdot
.542 .50555 Mdot
.542 .50555 Mdot
.542 .50556 Mdot
.542 .50556 Mdot
.542 .50562 Mdot
.542 .50628 Mdot
.542 .5063 Mdot
.542 .5063 Mdot
.542 .5064 Mdot
.542 .50642 Mdot
.542 .50669 Mdot
.542 .50676 Mdot
.542 .50717 Mdot
.542 .50729 Mdot
.542 .50745 Mdot
.542 .50745 Mdot
.542 .50747 Mdot
.542 .50747 Mdot
.542 .50747 Mdot
.542 .50795 Mdot
.542 .508 Mdot
.542 .50828 Mdot
.542 .50828 Mdot
.542 .50851 Mdot
.542 .50851 Mdot
.542 .50851 Mdot
.542 .50854 Mdot
.542 .50854 Mdot
.542 .50864 Mdot
.542 .50882 Mdot
.542 .50886 Mdot
.542 .50897 Mdot
.542 .50898 Mdot
.542 .50907 Mdot
.542 .50912 Mdot
.542 .50912 Mdot
.542 .50912 Mdot
.542 .50913 Mdot
.542 .50921 Mdot
.542 .50957 Mdot
.542 .50963 Mdot
.542 .50974 Mdot
.542 .50974 Mdot
.542 .50974 Mdot
.542 .50974 Mdot
.542 .50974 Mdot
.542 .54839 Mdot
.542 .54839 Mdot
.542 .54839 Mdot
.542 .54839 Mdot
.542 .54839 Mdot
.542 .5484 Mdot
.542 .54841 Mdot
.542 .54845 Mdot
.542 .54846 Mdot
.542 .54846 Mdot
.542 .54846 Mdot
.542 .54846 Mdot
.542 .54847 Mdot
.542 .54848 Mdot
.542 .54848 Mdot
.542 .54849 Mdot
.542 .5485 Mdot
.542 .54852 Mdot
.542 .54853 Mdot
.542 .54853 Mdot
.542 .54854 Mdot
.542 .54854 Mdot
.542 .54854 Mdot
.542 .54856 Mdot
.542 .54856 Mdot
.542 .5486 Mdot
.542 .5486 Mdot
.542 .54866 Mdot
.542 .54866 Mdot
.542 .54866 Mdot
.542 .54866 Mdot
.542 .54866 Mdot
.542 .54868 Mdot
.542 .5487 Mdot
.542 .54874 Mdot
.542 .54875 Mdot
.542 .54879 Mdot
.542 .54879 Mdot
.542 .5488 Mdot
.542 .5488 Mdot
.542 .5488 Mdot
.542 .54888 Mdot
.542 .54889 Mdot
.542 .54889 Mdot
.542 .54889 Mdot
.542 .54889 Mdot
.542 .5489 Mdot
.542 .5489 Mdot
.542 .54891 Mdot
.542 .54892 Mdot
.542 .54894 Mdot
.542 .54894 Mdot
.542 .54895 Mdot
.542 .54895 Mdot
.542 .54897 Mdot
.542 .54897 Mdot
.542 .54897 Mdot
.542 .54897 Mdot
.542 .54897 Mdot
.542 .549 Mdot
.542 .54901 Mdot
.542 .54902 Mdot
.542 .54902 Mdot
.542 .54902 Mdot
.542 .54905 Mdot
.542 .54905 Mdot
.542 .54905 Mdot
.542 .54906 Mdot
.542 .54906 Mdot
.542 .54907 Mdot
.542 .54907 Mdot
.542 .5491 Mdot
.542 .5491 Mdot
.542 .5491 Mdot
.542 .5491 Mdot
.542 .5491 Mdot
.542 .54911 Mdot
.542 .54911 Mdot
.542 .54911 Mdot
.542 .54911 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54912 Mdot
.542 .54913 Mdot
.542 .54913 Mdot
.542 .54913 Mdot
.542 .54913 Mdot
.542 .54915 Mdot
.542 .54915 Mdot
.542 .54915 Mdot
.542 .54915 Mdot
.542 .54915 Mdot
.542 .54916 Mdot
.542 .54916 Mdot
.542 .54917 Mdot
.542 .54918 Mdot
.542 .5492 Mdot
.542 .5492 Mdot
.542 .54921 Mdot
.542 .54921 Mdot
.542 .54922 Mdot
.542 .54922 Mdot
.542 .54923 Mdot
.542 .54923 Mdot
.542 .54923 Mdot
.542 .54923 Mdot
.542 .54923 Mdot
.542 .54923 Mdot
.542 .54923 Mdot
.542 .54926 Mdot
.542 .54926 Mdot
.542 .54926 Mdot
.542 .54927 Mdot
.542 .54927 Mdot
.542 .54928 Mdot
.542 .54929 Mdot
.542 .5493 Mdot
.542 .54931 Mdot
.542 .54931 Mdot
.542 .54931 Mdot
.542 .54932 Mdot
.542 .54932 Mdot
.542 .54932 Mdot
.542 .54934 Mdot
.542 .54934 Mdot
.542 .54935 Mdot
.542 .54935 Mdot
.542 .54936 Mdot
.542 .54936 Mdot
.542 .54936 Mdot
.542 .54936 Mdot
.542 .54936 Mdot
.542 .54936 Mdot
.542 .54937 Mdot
.542 .54937 Mdot
.542 .54937 Mdot
.542 .54937 Mdot
.542 .54938 Mdot
.542 .54938 Mdot
.542 .54938 Mdot
.542 .54938 Mdot
.542 .54938 Mdot
.542 .54938 Mdot
.542 .5494 Mdot
.542 .5494 Mdot
.542 .5494 Mdot
.542 .5494 Mdot
.542 .5494 Mdot
.542 .5494 Mdot
.542 .5494 Mdot
.544 .19206 Mdot
.544 .19206 Mdot
.544 .19206 Mdot
.544 .19206 Mdot
.544 .19207 Mdot
.544 .19208 Mdot
.544 .19208 Mdot
.544 .19208 Mdot
.544 .19209 Mdot
.544 .1921 Mdot
.544 .19211 Mdot
.544 .19214 Mdot
.544 .19214 Mdot
.544 .19214 Mdot
.544 .19215 Mdot
.544 .19216 Mdot
.544 .19216 Mdot
.544 .19221 Mdot
.544 .19222 Mdot
.544 .19223 Mdot
.544 .1923 Mdot
.544 .19242 Mdot
.544 .19249 Mdot
.544 .19251 Mdot
.544 .19254 Mdot
.544 .19256 Mdot
.544 .19264 Mdot
.544 .19268 Mdot
.544 .19272 Mdot
.544 .19273 Mdot
.544 .19283 Mdot
.544 .19283 Mdot
.544 .19285 Mdot
.544 .19289 Mdot
.544 .19296 Mdot
.544 .19334 Mdot
.544 .1934 Mdot
.544 .19355 Mdot
.544 .19365 Mdot
.544 .19372 Mdot
.544 .19384 Mdot
.544 .19404 Mdot
.544 .19404 Mdot
.544 .19413 Mdot
.544 .19419 Mdot
.544 .19419 Mdot
.544 .19436 Mdot
.544 .19439 Mdot
.544 .19444 Mdot
.544 .19449 Mdot
.544 .1945 Mdot
.544 .19453 Mdot
.544 .19458 Mdot
.544 .19466 Mdot
.544 .19468 Mdot
.544 .19475 Mdot
.544 .19478 Mdot
.544 .19479 Mdot
.544 .19504 Mdot
.544 .1951 Mdot
.544 .19518 Mdot
.544 .19521 Mdot
.544 .19522 Mdot
.544 .19528 Mdot
.544 .19529 Mdot
.544 .19536 Mdot
.544 .19555 Mdot
.544 .19558 Mdot
.544 .19565 Mdot
.544 .19585 Mdot
.544 .196 Mdot
.544 .19602 Mdot
.544 .19605 Mdot
.544 .19608 Mdot
.544 .1961 Mdot
.544 .19612 Mdot
.544 .19624 Mdot
.544 .19625 Mdot
.544 .19628 Mdot
.544 .1963 Mdot
.544 .19636 Mdot
.544 .19644 Mdot
.544 .19649 Mdot
.544 .19649 Mdot
.544 .1965 Mdot
.544 .19655 Mdot
.544 .19656 Mdot
.544 .1966 Mdot
.544 .19661 Mdot
.544 .19661 Mdot
.544 .19662 Mdot
.544 .19668 Mdot
.544 .19673 Mdot
.544 .19677 Mdot
.544 .19681 Mdot
.544 .19686 Mdot
.544 .19689 Mdot
.544 .19689 Mdot
.544 .1969 Mdot
.544 .19691 Mdot
.544 .19694 Mdot
.544 .19695 Mdot
.544 .19695 Mdot
.544 .19698 Mdot
.544 .19698 Mdot
.544 .19699 Mdot
.544 .1971 Mdot
.544 .19726 Mdot
.544 .19747 Mdot
.544 .19758 Mdot
.544 .1976 Mdot
.544 .19764 Mdot
.544 .19769 Mdot
.544 .19781 Mdot
.544 .19785 Mdot
.544 .19787 Mdot
.544 .19798 Mdot
.544 .19798 Mdot
.544 .19801 Mdot
.544 .19824 Mdot
.544 .19854 Mdot
.544 .19926 Mdot
.544 .20029 Mdot
.544 .20087 Mdot
.544 .20098 Mdot
.544 .20107 Mdot
.544 .20119 Mdot
.544 .20146 Mdot
.544 .20195 Mdot
.544 .20212 Mdot
.544 .20229 Mdot
.544 .20243 Mdot
.544 .20254 Mdot
.544 .20306 Mdot
.544 .20308 Mdot
.544 .20324 Mdot
.544 .20454 Mdot
.544 .20459 Mdot
.544 .20521 Mdot
.544 .2057 Mdot
.544 .20606 Mdot
.544 .20648 Mdot
.544 .20681 Mdot
.544 .20767 Mdot
.544 .20837 Mdot
.544 .20993 Mdot
.544 .21142 Mdot
.544 .21192 Mdot
.544 .2144 Mdot
.544 .21467 Mdot
.544 .21481 Mdot
.544 .21609 Mdot
.544 .21954 Mdot
.544 .22161 Mdot
.544 .2217 Mdot
.544 .22447 Mdot
.544 .22547 Mdot
.544 .22629 Mdot
.544 .2274 Mdot
.544 .22795 Mdot
.544 .22987 Mdot
.544 .23102 Mdot
.544 .23138 Mdot
.544 .2318 Mdot
.544 .23199 Mdot
.544 .23285 Mdot
.544 .23447 Mdot
.544 .23492 Mdot
.544 .23617 Mdot
.544 .23648 Mdot
.544 .23754 Mdot
.544 .23783 Mdot
.544 .23845 Mdot
.544 .23922 Mdot
.544 .24023 Mdot
.544 .24028 Mdot
.544 .24262 Mdot
.544 .2456 Mdot
.544 .24573 Mdot
.544 .24578 Mdot
.544 .24603 Mdot
.544 .24738 Mdot
.544 .25298 Mdot
.544 .25386 Mdot
.544 .25392 Mdot
.544 .25684 Mdot
.544 .25744 Mdot
.544 .25823 Mdot
.544 .2584 Mdot
.544 .25919 Mdot
.544 .26019 Mdot
.544 .26117 Mdot
.544 .26169 Mdot
.544 .26181 Mdot
.544 .26207 Mdot
.544 .263 Mdot
.544 .26457 Mdot
.544 .26529 Mdot
.544 .26583 Mdot
.544 .2665 Mdot
.544 .2684 Mdot
.544 .26994 Mdot
.544 .27352 Mdot
.544 .27363 Mdot
.544 .27589 Mdot
.544 .27631 Mdot
.544 .27761 Mdot
.544 .27903 Mdot
.544 .27969 Mdot
.544 .28085 Mdot
.544 .28212 Mdot
.544 .28277 Mdot
.544 .28282 Mdot
.544 .28424 Mdot
.544 .28442 Mdot
.544 .28443 Mdot
.544 .28516 Mdot
.544 .28532 Mdot
.544 .28552 Mdot
.544 .28572 Mdot
.544 .28631 Mdot
.544 .28664 Mdot
.544 .28679 Mdot
.544 .2869 Mdot
.544 .28704 Mdot
.544 .28777 Mdot
.544 .28916 Mdot
.544 .29018 Mdot
.544 .29062 Mdot
.544 .29097 Mdot
.544 .29101 Mdot
.544 .29101 Mdot
.544 .29118 Mdot
.544 .29122 Mdot
.544 .29127 Mdot
.544 .29146 Mdot
.544 .29154 Mdot
.544 .2916 Mdot
.544 .29163 Mdot
.544 .29181 Mdot
.544 .29215 Mdot
.544 .2924 Mdot
.544 .29267 Mdot
.544 .29268 Mdot
.544 .29304 Mdot
.544 .29313 Mdot
.544 .29343 Mdot
.544 .29344 Mdot
.544 .29346 Mdot
.544 .29354 Mdot
.544 .29383 Mdot
.544 .2939 Mdot
.544 .29415 Mdot
.544 .29419 Mdot
.544 .29425 Mdot
.544 .29431 Mdot
.544 .29462 Mdot
.544 .29501 Mdot
.544 .29515 Mdot
.544 .29559 Mdot
.544 .29572 Mdot
.544 .29588 Mdot
.544 .29595 Mdot
.544 .2968 Mdot
.544 .29688 Mdot
.544 .29705 Mdot
.544 .29727 Mdot
.544 .29748 Mdot
.544 .29761 Mdot
.544 .29773 Mdot
.544 .2978 Mdot
.544 .29862 Mdot
.544 .29999 Mdot
.544 .30046 Mdot
.544 .30067 Mdot
.544 .30199 Mdot
.544 .30243 Mdot
.544 .30251 Mdot
.544 .30251 Mdot
.544 .30295 Mdot
.544 .30301 Mdot
.544 .3032 Mdot
.544 .30379 Mdot
.544 .30387 Mdot
.544 .30416 Mdot
.544 .30593 Mdot
.544 .30602 Mdot
.544 .30617 Mdot
.544 .30665 Mdot
.544 .30667 Mdot
.544 .30685 Mdot
.544 .30736 Mdot
.544 .30775 Mdot
.544 .30797 Mdot
.544 .30805 Mdot
.544 .30837 Mdot
.544 .3087 Mdot
.544 .30871 Mdot
.544 .3089 Mdot
.544 .31012 Mdot
.544 .31014 Mdot
.544 .31052 Mdot
.544 .31119 Mdot
.544 .3112 Mdot
.544 .31124 Mdot
.544 .31263 Mdot
.544 .31343 Mdot
.544 .31399 Mdot
.544 .31465 Mdot
.544 .31574 Mdot
.544 .31832 Mdot
.544 .31855 Mdot
.544 .31887 Mdot
.544 .31941 Mdot
.544 .31966 Mdot
.544 .3198 Mdot
.544 .31981 Mdot
.544 .32053 Mdot
.544 .32063 Mdot
.544 .32093 Mdot
.544 .3212 Mdot
.544 .32179 Mdot
.544 .3219 Mdot
.544 .32214 Mdot
.544 .32228 Mdot
.544 .32283 Mdot
.544 .32369 Mdot
.544 .32391 Mdot
.544 .32416 Mdot
.544 .32423 Mdot
.544 .32435 Mdot
.544 .32468 Mdot
.544 .3247 Mdot
.544 .32477 Mdot
.544 .3248 Mdot
.544 .3248 Mdot
.544 .3248 Mdot
.544 .32507 Mdot
.544 .32513 Mdot
.544 .32522 Mdot
.544 .32526 Mdot
.544 .32527 Mdot
.544 .32529 Mdot
.544 .32531 Mdot
.544 .32538 Mdot
.544 .32542 Mdot
.544 .32542 Mdot
.544 .32543 Mdot
.544 .333 Mdot
.544 .33641 Mdot
.544 .33677 Mdot
.544 .33751 Mdot
.544 .34418 Mdot
.544 .34551 Mdot
.544 .34957 Mdot
.544 .35382 Mdot
.544 .35575 Mdot
.544 .35811 Mdot
.544 .35902 Mdot
.544 .36016 Mdot
.544 .36116 Mdot
.544 .36249 Mdot
.544 .36421 Mdot
.544 .36434 Mdot
.544 .36796 Mdot
.544 .3684 Mdot
.544 .36843 Mdot
.544 .36989 Mdot
.544 .37019 Mdot
.544 .37058 Mdot
.544 .37104 Mdot
.544 .37153 Mdot
.544 .37288 Mdot
.544 .37362 Mdot
.544 .37396 Mdot
.544 .37422 Mdot
.544 .37453 Mdot
.544 .37612 Mdot
.544 .379 Mdot
.544 .381 Mdot
.544 .38184 Mdot
.544 .38247 Mdot
.544 .38255 Mdot
.544 .38255 Mdot
.544 .38286 Mdot
.544 .38293 Mdot
.544 .38302 Mdot
.544 .38336 Mdot
.544 .3835 Mdot
.544 .38361 Mdot
.544 .38367 Mdot
.544 .38398 Mdot
.544 .38457 Mdot
.544 .385 Mdot
.544 .38533 Mdot
.544 .38535 Mdot
.544 .38535 Mdot
.544 .38542 Mdot
.544 .38544 Mdot
.544 .38546 Mdot
.544 .38554 Mdot
.544 .38557 Mdot
.544 .3856 Mdot
.544 .38561 Mdot
.544 .38568 Mdot
.544 .38583 Mdot
.544 .38593 Mdot
.544 .38605 Mdot
.544 .38619 Mdot
.544 .38636 Mdot
.544 .38636 Mdot
.544 .38637 Mdot
.544 .38641 Mdot
.544 .38653 Mdot
.544 .38655 Mdot
.544 .38667 Mdot
.544 .3867 Mdot
.544 .38672 Mdot
.544 .38685 Mdot
.544 .38707 Mdot
.544 .38725 Mdot
.544 .38731 Mdot
.544 .38737 Mdot
.544 .3874 Mdot
.544 .38776 Mdot
.544 .38779 Mdot
.544 .38785 Mdot
.544 .38795 Mdot
.544 .38803 Mdot
.544 .38809 Mdot
.544 .38813 Mdot
.544 .3885 Mdot
.544 .38906 Mdot
.544 .38925 Mdot
.544 .38933 Mdot
.544 .38987 Mdot
.544 .39005 Mdot
.544 .39008 Mdot
.544 .39026 Mdot
.544 .39028 Mdot
.544 .39036 Mdot
.544 .3906 Mdot
.544 .39075 Mdot
.544 .39146 Mdot
.544 .39149 Mdot
.544 .39155 Mdot
.544 .39175 Mdot
.544 .39182 Mdot
.544 .39203 Mdot
.544 .39218 Mdot
.544 .39227 Mdot
.544 .3923 Mdot
.544 .39243 Mdot
.544 .39256 Mdot
.544 .39264 Mdot
.544 .39312 Mdot
.544 .39313 Mdot
.544 .39328 Mdot
.544 .39355 Mdot
.544 .39355 Mdot
.544 .39411 Mdot
.544 .39443 Mdot
.544 .39465 Mdot
.544 .39491 Mdot
.544 .39533 Mdot
.544 .39551 Mdot
.544 .39655 Mdot
.544 .39676 Mdot
.544 .39686 Mdot
.544 .39691 Mdot
.544 .39691 Mdot
.544 .39719 Mdot
.544 .39723 Mdot
.544 .39735 Mdot
.544 .39745 Mdot
.544 .39767 Mdot
.544 .39772 Mdot
.544 .39781 Mdot
.544 .39787 Mdot
.544 .39808 Mdot
.544 .39841 Mdot
.544 .39859 Mdot
.544 .39862 Mdot
.544 .39866 Mdot
.544 .39879 Mdot
.544 .39879 Mdot
.544 .39882 Mdot
.544 .39883 Mdot
.544 .39883 Mdot
.544 .39883 Mdot
.544 .39893 Mdot
.544 .39896 Mdot
.544 .39899 Mdot
.544 .39901 Mdot
.544 .39901 Mdot
.544 .39902 Mdot
.544 .39903 Mdot
.544 .39905 Mdot
.544 .39907 Mdot
.544 .39907 Mdot
.544 .39907 Mdot
.544 .46516 Mdot
.544 .46516 Mdot
.544 .46516 Mdot
.544 .46517 Mdot
.544 .46518 Mdot
.544 .46518 Mdot
.544 .46519 Mdot
.544 .46519 Mdot
.544 .4652 Mdot
.544 .46521 Mdot
.544 .46523 Mdot
.544 .46528 Mdot
.544 .46528 Mdot
.544 .46528 Mdot
.544 .46529 Mdot
.544 .4653 Mdot
.544 .4653 Mdot
.544 .46537 Mdot
.544 .46539 Mdot
.544 .46541 Mdot
.544 .4655 Mdot
.544 .46567 Mdot
.544 .46578 Mdot
.544 .46581 Mdot
.544 .46586 Mdot
.544 .46588 Mdot
.544 .466 Mdot
.544 .46605 Mdot
.544 .46611 Mdot
.544 .46613 Mdot
.544 .46627 Mdot
.544 .46627 Mdot
.544 .4663 Mdot
.544 .46635 Mdot
.544 .46646 Mdot
.544 .46699 Mdot
.544 .46708 Mdot
.544 .4673 Mdot
.544 .46743 Mdot
.544 .46754 Mdot
.544 .46771 Mdot
.544 .46799 Mdot
.544 .46799 Mdot
.544 .46813 Mdot
.544 .4682 Mdot
.544 .46821 Mdot
.544 .46845 Mdot
.544 .4685 Mdot
.544 .46856 Mdot
.544 .46863 Mdot
.544 .46864 Mdot
.544 .46869 Mdot
.544 .46877 Mdot
.544 .46887 Mdot
.544 .46891 Mdot
.544 .46901 Mdot
.544 .46904 Mdot
.544 .46906 Mdot
.544 .46941 Mdot
.544 .46949 Mdot
.544 .46961 Mdot
.544 .46965 Mdot
.544 .46966 Mdot
.544 .46975 Mdot
.544 .46977 Mdot
.544 .46986 Mdot
.544 .47013 Mdot
.544 .47017 Mdot
.544 .47026 Mdot
.544 .47054 Mdot
.544 .47075 Mdot
.544 .47078 Mdot
.544 .47082 Mdot
.544 .47087 Mdot
.544 .4709 Mdot
.544 .47092 Mdot
.544 .47109 Mdot
.544 .47111 Mdot
.544 .47114 Mdot
.544 .47117 Mdot
.544 .47126 Mdot
.544 .47137 Mdot
.544 .47143 Mdot
.544 .47144 Mdot
.544 .47146 Mdot
.544 .47152 Mdot
.544 .47153 Mdot
.544 .47159 Mdot
.544 .47161 Mdot
.544 .47161 Mdot
.544 .47161 Mdot
.544 .4717 Mdot
.544 .47177 Mdot
.544 .47183 Mdot
.544 .47188 Mdot
.544 .47195 Mdot
.544 .47199 Mdot
.544 .47199 Mdot
.544 .47201 Mdot
.544 .47202 Mdot
.544 .47206 Mdot
.544 .47207 Mdot
.544 .47208 Mdot
.544 .47212 Mdot
.544 .47212 Mdot
.544 .47213 Mdot
.544 .47229 Mdot
.544 .4725 Mdot
.544 .47279 Mdot
.544 .47295 Mdot
.544 .47298 Mdot
.544 .47303 Mdot
.544 .4731 Mdot
.544 .47327 Mdot
.544 .47331 Mdot
.544 .47334 Mdot
.544 .4735 Mdot
.544 .4735 Mdot
.544 .47354 Mdot
.544 .47385 Mdot
.544 .47426 Mdot
.544 .47524 Mdot
.544 .47663 Mdot
.544 .4774 Mdot
.544 .47755 Mdot
.544 .47767 Mdot
.544 .47784 Mdot
.544 .47819 Mdot
.544 .47884 Mdot
.544 .47907 Mdot
.544 .47929 Mdot
.544 .47948 Mdot
.544 .47962 Mdot
.544 .48031 Mdot
.544 .48032 Mdot
.544 .48053 Mdot
.544 .48223 Mdot
.544 .48229 Mdot
.544 .48309 Mdot
.544 .48371 Mdot
.544 .48417 Mdot
.544 .4847 Mdot
.544 .48512 Mdot
.544 .4862 Mdot
.544 .48708 Mdot
.544 .489 Mdot
.544 .49082 Mdot
.544 .49141 Mdot
.544 .49435 Mdot
.544 .49467 Mdot
.544 .49483 Mdot
.544 .49631 Mdot
.544 .49955 Mdot
.544 .49956 Mdot
.544 .49956 Mdot
.544 .49957 Mdot
.544 .4996 Mdot
.544 .49961 Mdot
.544 .49962 Mdot
.544 .49962 Mdot
.544 .49964 Mdot
.544 .49968 Mdot
.544 .49971 Mdot
.544 .49982 Mdot
.544 .49982 Mdot
.544 .49982 Mdot
.544 .49983 Mdot
.544 .49986 Mdot
.544 .49987 Mdot
.544 .50001 Mdot
.544 .50006 Mdot
.544 .50009 Mdot
.544 .5002 Mdot
.544 .50029 Mdot
.544 .50065 Mdot
.544 .50088 Mdot
.544 .50095 Mdot
.544 .50105 Mdot
.544 .50109 Mdot
.544 .50134 Mdot
.544 .50145 Mdot
.544 .50158 Mdot
.544 .50162 Mdot
.544 .50192 Mdot
.544 .50193 Mdot
.544 .50199 Mdot
.544 .50209 Mdot
.544 .50232 Mdot
.544 .50245 Mdot
.544 .50255 Mdot
.544 .50362 Mdot
.544 .50408 Mdot
.544 .50435 Mdot
.544 .50458 Mdot
.544 .50491 Mdot
.544 .50549 Mdot
.544 .5055 Mdot
.544 .50551 Mdot
.544 .50579 Mdot
.544 .50594 Mdot
.544 .50595 Mdot
.544 .50645 Mdot
.544 .50653 Mdot
.544 .50653 Mdot
.544 .50667 Mdot
.544 .5068 Mdot
.544 .50683 Mdot
.544 .50692 Mdot
.544 .50708 Mdot
.544 .50729 Mdot
.544 .50736 Mdot
.544 .50737 Mdot
.544 .50756 Mdot
.544 .50763 Mdot
.544 .50766 Mdot
.544 .50838 Mdot
.544 .5085 Mdot
.544 .50854 Mdot
.544 .50877 Mdot
.544 .50885 Mdot
.544 .50888 Mdot
.544 .50905 Mdot
.544 .50905 Mdot
.544 .50908 Mdot
.544 .50926 Mdot
.544 .5098 Mdot
.544 .50988 Mdot
.544 .51007 Mdot
.544 .51062 Mdot
.544 .51095 Mdot
.544 .51098 Mdot
.544 .51103 Mdot
.544 .51108 Mdot
.544 .51116 Mdot
.544 .51125 Mdot
.544 .51132 Mdot
.544 .51135 Mdot
.544 .51169 Mdot
.544 .51172 Mdot
.544 .51178 Mdot
.544 .51183 Mdot
.544 .51201 Mdot
.544 .51207 Mdot
.544 .51222 Mdot
.544 .51235 Mdot
.544 .51237 Mdot
.544 .51239 Mdot
.544 .51241 Mdot
.544 .51251 Mdot
.544 .51253 Mdot
.544 .51265 Mdot
.544 .51268 Mdot
.544 .51269 Mdot
.544 .5127 Mdot
.544 .51281 Mdot
.544 .51285 Mdot
.544 .51299 Mdot
.544 .513 Mdot
.544 .5131 Mdot
.544 .5132 Mdot
.544 .51334 Mdot
.544 .51341 Mdot
.544 .51342 Mdot
.544 .51345 Mdot
.544 .51348 Mdot
.544 .51355 Mdot
.544 .51357 Mdot
.544 .51359 Mdot
.544 .51365 Mdot
.544 .51365 Mdot
.544 .51367 Mdot
.544 .51381 Mdot
.544 .51398 Mdot
.544 .51439 Mdot
.544 .51493 Mdot
.544 .51522 Mdot
.544 .51527 Mdot
.544 .51532 Mdot
.544 .51538 Mdot
.544 .51551 Mdot
.544 .51573 Mdot
.544 .51582 Mdot
.544 .51589 Mdot
.544 .51596 Mdot
.544 .51624 Mdot
.544 .51624 Mdot
.544 .51632 Mdot
.544 .51687 Mdot
.544 .51689 Mdot
.544 .51714 Mdot
.544 .51764 Mdot
.544 .51808 Mdot
.544 .51834 Mdot
.544 .51889 Mdot
.544 .51939 Mdot
.544 .51955 Mdot
.544 .52042 Mdot
.544 .52046 Mdot
.544 .52183 Mdot
.544 .52241 Mdot
.544 .52313 Mdot
.544 .52338 Mdot
.544 .52359 Mdot
.544 .52386 Mdot
.544 .52445 Mdot
.544 .5248 Mdot
.544 .5249 Mdot
.544 .52494 Mdot
.544 .52514 Mdot
.544 .5255 Mdot
.544 .52588 Mdot
.544 .52617 Mdot
.544 .52623 Mdot
.544 .52653 Mdot
.544 .52675 Mdot
.544 .52784 Mdot
.544 .52786 Mdot
.544 .52818 Mdot
.544 .53024 Mdot
.544 .53074 Mdot
.544 .53083 Mdot
.544 .53085 Mdot
.544 .53089 Mdot
.544 .53198 Mdot
.544 .53283 Mdot
.544 .53284 Mdot
.544 .53321 Mdot
.544 .53349 Mdot
.544 .53371 Mdot
.544 .53382 Mdot
.544 .5342 Mdot
.544 .53431 Mdot
.544 .53476 Mdot
.544 .53492 Mdot
.544 .5355 Mdot
.544 .5358 Mdot
.544 .53587 Mdot
.544 .53602 Mdot
.544 .53615 Mdot
.544 .53656 Mdot
.544 .53724 Mdot
.544 .53744 Mdot
.544 .53783 Mdot
.544 .53812 Mdot
.544 .53847 Mdot
.544 .53945 Mdot
.544 .53948 Mdot
.544 .54021 Mdot
.544 .54141 Mdot
.544 .54186 Mdot
.544 .54191 Mdot
.544 .542 Mdot
.544 .54286 Mdot
.544 .54303 Mdot
.544 .54355 Mdot
.544 .54409 Mdot
.544 .54433 Mdot
.544 .54462 Mdot
.544 .54474 Mdot
.544 .54488 Mdot
.544 .54501 Mdot
.544 .54517 Mdot
.544 .54538 Mdot
.544 .5454 Mdot
.544 .54585 Mdot
.544 .5459 Mdot
.544 .54591 Mdot
.544 .54609 Mdot
.544 .54612 Mdot
.544 .54617 Mdot
.544 .54623 Mdot
.544 .54629 Mdot
.544 .54645 Mdot
.544 .54654 Mdot
.544 .54659 Mdot
.544 .54662 Mdot
.544 .54666 Mdot
.544 .54685 Mdot
.544 .5472 Mdot
.544 .54745 Mdot
.544 .54755 Mdot
.544 .54763 Mdot
.544 .54764 Mdot
.544 .54764 Mdot
.544 .54767 Mdot
.544 .54768 Mdot
.544 .54769 Mdot
.544 .54773 Mdot
.544 .54775 Mdot
.544 .54777 Mdot
.544 .54777 Mdot
.544 .54781 Mdot
.544 .54788 Mdot
.544 .54793 Mdot
.544 .54797 Mdot
.544 .54798 Mdot
.544 .54798 Mdot
.544 .54799 Mdot
.544 .54799 Mdot
.544 .54799 Mdot
.544 .548 Mdot
.544 .548 Mdot
.544 .54801 Mdot
.544 .54801 Mdot
.544 .54802 Mdot
.544 .54803 Mdot
.544 .54805 Mdot
.544 .54806 Mdot
.544 .54808 Mdot
.544 .5481 Mdot
.544 .5481 Mdot
.544 .5481 Mdot
.544 .54811 Mdot
.544 .54812 Mdot
.544 .54812 Mdot
.544 .54814 Mdot
.544 .54814 Mdot
.544 .54814 Mdot
.544 .54816 Mdot
.544 .54819 Mdot
.544 .54821 Mdot
.544 .54821 Mdot
.544 .54822 Mdot
.544 .54823 Mdot
.544 .54827 Mdot
.544 .54827 Mdot
.544 .54828 Mdot
.544 .54829 Mdot
.544 .5483 Mdot
.544 .54831 Mdot
.544 .54836 Mdot
.544 .54843 Mdot
.544 .54845 Mdot
.544 .54846 Mdot
.544 .54853 Mdot
.544 .54855 Mdot
.544 .54855 Mdot
.544 .54857 Mdot
.544 .54858 Mdot
.544 .54858 Mdot
.544 .54861 Mdot
.544 .54863 Mdot
.544 .54872 Mdot
.544 .54872 Mdot
.544 .54873 Mdot
.544 .54875 Mdot
.544 .54876 Mdot
.544 .54879 Mdot
.544 .54881 Mdot
.544 .54882 Mdot
.544 .54882 Mdot
.544 .54884 Mdot
.544 .54885 Mdot
.544 .54886 Mdot
.544 .54892 Mdot
.544 .54892 Mdot
.544 .54894 Mdot
.544 .54897 Mdot
.544 .54897 Mdot
.544 .54904 Mdot
.544 .54908 Mdot
.544 .5491 Mdot
.544 .54914 Mdot
.544 .54919 Mdot
.544 .54921 Mdot
.544 .54933 Mdot
.544 .54936 Mdot
.544 .54937 Mdot
.544 .54938 Mdot
.544 .54938 Mdot
.544 .54941 Mdot
.544 .54942 Mdot
.544 .54943 Mdot
.544 .54944 Mdot
.544 .54947 Mdot
.544 .54947 Mdot
.544 .54949 Mdot
.544 .54949 Mdot
.544 .54952 Mdot
.544 .54956 Mdot
.544 .54958 Mdot
.544 .54958 Mdot
.544 .54959 Mdot
.544 .5496 Mdot
.544 .5496 Mdot
.544 .54961 Mdot
.544 .54961 Mdot
.544 .54961 Mdot
.544 .54961 Mdot
.544 .54962 Mdot
.544 .54962 Mdot
.544 .54963 Mdot
.544 .54963 Mdot
.544 .54963 Mdot
.544 .54963 Mdot
.544 .54963 Mdot
.544 .54964 Mdot
.544 .54964 Mdot
.544 .54964 Mdot
.544 .54964 Mdot
.546 .19143 Mdot
.546 .19144 Mdot
.546 .19144 Mdot
.546 .19144 Mdot
.546 .19145 Mdot
.546 .19145 Mdot
.546 .19146 Mdot
.546 .19148 Mdot
.546 .19149 Mdot
.546 .19153 Mdot
.546 .19155 Mdot
.546 .19157 Mdot
.546 .19161 Mdot
.546 .19161 Mdot
.546 .19163 Mdot
.546 .19172 Mdot
.546 .19177 Mdot
.546 .19178 Mdot
.546 .19178 Mdot
.546 .19181 Mdot
.546 .19193 Mdot
.546 .192 Mdot
.546 .19201 Mdot
.546 .19202 Mdot
.546 .19206 Mdot
.546 .19206 Mdot
.546 .19212 Mdot
.546 .19222 Mdot
.546 .19226 Mdot
.546 .19226 Mdot
.546 .19232 Mdot
.546 .19243 Mdot
.546 .19246 Mdot
.546 .19253 Mdot
.546 .1926 Mdot
.546 .19261 Mdot
.546 .19269 Mdot
.546 .19275 Mdot
.546 .19278 Mdot
.546 .19288 Mdot
.546 .1929 Mdot
.546 .19296 Mdot
.546 .19301 Mdot
.546 .19302 Mdot
.546 .19305 Mdot
.546 .19309 Mdot
.546 .19309 Mdot
.546 .19318 Mdot
.546 .19335 Mdot
.546 .19343 Mdot
.546 .19348 Mdot
.546 .19361 Mdot
.546 .19375 Mdot
.546 .19378 Mdot
.546 .19383 Mdot
.546 .19385 Mdot
.546 .19388 Mdot
.546 .19408 Mdot
.546 .1942 Mdot
.546 .19434 Mdot
.546 .19436 Mdot
.546 .19442 Mdot
.546 .19445 Mdot
.546 .19477 Mdot
.546 .19482 Mdot
.546 .19501 Mdot
.546 .19502 Mdot
.546 .19504 Mdot
.546 .19504 Mdot
.546 .19517 Mdot
.546 .19517 Mdot
.546 .19528 Mdot
.546 .19552 Mdot
.546 .19554 Mdot
.546 .19557 Mdot
.546 .19561 Mdot
.546 .19583 Mdot
.546 .19584 Mdot
.546 .19585 Mdot
.546 .19598 Mdot
.546 .19603 Mdot
.546 .19606 Mdot
.546 .19624 Mdot
.546 .19637 Mdot
.546 .19656 Mdot
.546 .19664 Mdot
.546 .1967 Mdot
.546 .1968 Mdot
.546 .19691 Mdot
.546 .19702 Mdot
.546 .19705 Mdot
.546 .19708 Mdot
.546 .1971 Mdot
.546 .19727 Mdot
.546 .19735 Mdot
.546 .19772 Mdot
.546 .1978 Mdot
.546 .19787 Mdot
.546 .19808 Mdot
.546 .19817 Mdot
.546 .19827 Mdot
.546 .19827 Mdot
.546 .1984 Mdot
.546 .19852 Mdot
.546 .19853 Mdot
.546 .19858 Mdot
.546 .19861 Mdot
.546 .19869 Mdot
.546 .19871 Mdot
.546 .19872 Mdot
.546 .19875 Mdot
.546 .19875 Mdot
.546 .19876 Mdot
.546 .1988 Mdot
.546 .19926 Mdot
.546 .19946 Mdot
.546 .19985 Mdot
.546 .19986 Mdot
.546 .20014 Mdot
.546 .20024 Mdot
.546 .20189 Mdot
.546 .20214 Mdot
.546 .2023 Mdot
.546 .20274 Mdot
.546 .20401 Mdot
.546 .20458 Mdot
.546 .20515 Mdot
.546 .20521 Mdot
.546 .20604 Mdot
.546 .20679 Mdot
.546 .20686 Mdot
.546 .20721 Mdot
.546 .20737 Mdot
.546 .20745 Mdot
.546 .20748 Mdot
.546 .20779 Mdot
.546 .20795 Mdot
.546 .20805 Mdot
.546 .20813 Mdot
.546 .20816 Mdot
.546 .20835 Mdot
.546 .20837 Mdot
.546 .20849 Mdot
.546 .20873 Mdot
.546 .20885 Mdot
.546 .2105 Mdot
.546 .21178 Mdot
.546 .21193 Mdot
.546 .21209 Mdot
.546 .21281 Mdot
.546 .21335 Mdot
.546 .21362 Mdot
.546 .21386 Mdot
.546 .21673 Mdot
.546 .21677 Mdot
.546 .21842 Mdot
.546 .21862 Mdot
.546 .21916 Mdot
.546 .21956 Mdot
.546 .21994 Mdot
.546 .2249 Mdot
.546 .22542 Mdot
.546 .22547 Mdot
.546 .22642 Mdot
.546 .22692 Mdot
.546 .22699 Mdot
.546 .2278 Mdot
.546 .22796 Mdot
.546 .22828 Mdot
.546 .22874 Mdot
.546 .22892 Mdot
.546 .22943 Mdot
.546 .23082 Mdot
.546 .23095 Mdot
.546 .23129 Mdot
.546 .23202 Mdot
.546 .23363 Mdot
.546 .23395 Mdot
.546 .23513 Mdot
.546 .2375 Mdot
.546 .23763 Mdot
.546 .23918 Mdot
.546 .23924 Mdot
.546 .24158 Mdot
.546 .24189 Mdot
.546 .24376 Mdot
.546 .2448 Mdot
.546 .24774 Mdot
.546 .25463 Mdot
.546 .25713 Mdot
.546 .25716 Mdot
.546 .25804 Mdot
.546 .25949 Mdot
.546 .26325 Mdot
.546 .26546 Mdot
.546 .26924 Mdot
.546 .26951 Mdot
.546 .2698 Mdot
.546 .27019 Mdot
.546 .27156 Mdot
.546 .27159 Mdot
.546 .27401 Mdot
.546 .27525 Mdot
.546 .27538 Mdot
.546 .27551 Mdot
.546 .27816 Mdot
.546 .27838 Mdot
.546 .27848 Mdot
.546 .2785 Mdot
.546 .27867 Mdot
.546 .27871 Mdot
.546 .27887 Mdot
.546 .27902 Mdot
.546 .27931 Mdot
.546 .27934 Mdot
.546 .27956 Mdot
.546 .2799 Mdot
.546 .27996 Mdot
.546 .28069 Mdot
.546 .28151 Mdot
.546 .28158 Mdot
.546 .28216 Mdot
.546 .28275 Mdot
.546 .28412 Mdot
.546 .28462 Mdot
.546 .2848 Mdot
.546 .28509 Mdot
.546 .28755 Mdot
.546 .28756 Mdot
.546 .28807 Mdot
.546 .28833 Mdot
.546 .28921 Mdot
.546 .28934 Mdot
.546 .2895 Mdot
.546 .2897 Mdot
.546 .29048 Mdot
.546 .29117 Mdot
.546 .2919 Mdot
.546 .29217 Mdot
.546 .2923 Mdot
.546 .29283 Mdot
.546 .29393 Mdot
.546 .29406 Mdot
.546 .29475 Mdot
.546 .295 Mdot
.546 .29506 Mdot
.546 .29621 Mdot
.546 .29639 Mdot
.546 .29673 Mdot
.546 .2976 Mdot
.546 .29772 Mdot
.546 .29778 Mdot
.546 .29846 Mdot
.546 .29928 Mdot
.546 .29951 Mdot
.546 .29972 Mdot
.546 .29975 Mdot
.546 .2999 Mdot
.546 .30014 Mdot
.546 .30128 Mdot
.546 .30156 Mdot
.546 .30209 Mdot
.546 .3023 Mdot
.546 .30232 Mdot
.546 .30246 Mdot
.546 .30319 Mdot
.546 .3032 Mdot
.546 .30336 Mdot
.546 .30342 Mdot
.546 .30448 Mdot
.546 .30468 Mdot
.546 .30471 Mdot
.546 .30508 Mdot
.546 .30591 Mdot
.546 .30735 Mdot
.546 .30752 Mdot
.546 .30795 Mdot
.546 .30808 Mdot
.546 .3083 Mdot
.546 .30843 Mdot
.546 .30906 Mdot
.546 .30975 Mdot
.546 .30992 Mdot
.546 .31134 Mdot
.546 .31156 Mdot
.546 .31174 Mdot
.546 .31208 Mdot
.546 .31226 Mdot
.546 .3133 Mdot
.546 .31421 Mdot
.546 .31458 Mdot
.546 .31513 Mdot
.546 .31638 Mdot
.546 .31697 Mdot
.546 .31701 Mdot
.546 .31728 Mdot
.546 .31749 Mdot
.546 .31758 Mdot
.546 .31794 Mdot
.546 .3184 Mdot
.546 .31851 Mdot
.546 .31923 Mdot
.546 .31943 Mdot
.546 .31989 Mdot
.546 .32049 Mdot
.546 .32056 Mdot
.546 .32103 Mdot
.546 .3216 Mdot
.546 .32178 Mdot
.546 .3225 Mdot
.546 .32261 Mdot
.546 .32299 Mdot
.546 .32304 Mdot
.546 .32329 Mdot
.546 .32349 Mdot
.546 .32394 Mdot
.546 .32404 Mdot
.546 .32449 Mdot
.546 .32451 Mdot
.546 .32454 Mdot
.546 .32476 Mdot
.546 .32485 Mdot
.546 .3249 Mdot
.546 .32543 Mdot
.546 .32596 Mdot
.546 .3263 Mdot
.546 .32648 Mdot
.546 .32653 Mdot
.546 .32657 Mdot
.546 .3266 Mdot
.546 .32699 Mdot
.546 .32766 Mdot
.546 .32777 Mdot
.546 .32781 Mdot
.546 .32808 Mdot
.546 .32821 Mdot
.546 .32835 Mdot
.546 .3287 Mdot
.546 .32878 Mdot
.546 .32893 Mdot
.546 .32896 Mdot
.546 .32897 Mdot
.546 .32901 Mdot
.546 .32901 Mdot
.546 .32903 Mdot
.546 .32908 Mdot
.546 .33084 Mdot
.546 .33096 Mdot
.546 .33862 Mdot
.546 .33926 Mdot
.546 .33998 Mdot
.546 .34143 Mdot
.546 .34337 Mdot
.546 .34381 Mdot
.546 .34421 Mdot
.546 .3477 Mdot
.546 .35219 Mdot
.546 .35254 Mdot
.546 .35319 Mdot
.546 .35351 Mdot
.546 .35356 Mdot
.546 .35408 Mdot
.546 .35417 Mdot
.546 .35438 Mdot
.546 .35467 Mdot
.546 .3551 Mdot
.546 .35596 Mdot
.546 .35604 Mdot
.546 .35625 Mdot
.546 .35669 Mdot
.546 .35766 Mdot
.546 .35785 Mdot
.546 .35992 Mdot
.546 .36221 Mdot
.546 .36238 Mdot
.546 .36396 Mdot
.546 .36552 Mdot
.546 .36904 Mdot
.546 .37028 Mdot
.546 .37072 Mdot
.546 .37143 Mdot
.546 .37602 Mdot
.546 .37628 Mdot
.546 .37708 Mdot
.546 .37709 Mdot
.546 .37818 Mdot
.546 .37874 Mdot
.546 .38002 Mdot
.546 .38012 Mdot
.546 .38017 Mdot
.546 .38017 Mdot
.546 .38025 Mdot
.546 .38026 Mdot
.546 .38034 Mdot
.546 .38054 Mdot
.546 .38064 Mdot
.546 .38078 Mdot
.546 .38081 Mdot
.546 .38113 Mdot
.546 .38149 Mdot
.546 .38151 Mdot
.546 .38177 Mdot
.546 .38202 Mdot
.546 .38261 Mdot
.546 .38282 Mdot
.546 .38303 Mdot
.546 .38408 Mdot
.546 .38429 Mdot
.546 .38477 Mdot
.546 .38483 Mdot
.546 .3849 Mdot
.546 .38498 Mdot
.546 .38531 Mdot
.546 .38559 Mdot
.546 .3859 Mdot
.546 .38607 Mdot
.546 .38629 Mdot
.546 .3868 Mdot
.546 .38718 Mdot
.546 .38768 Mdot
.546 .38776 Mdot
.546 .3879 Mdot
.546 .38826 Mdot
.546 .3883 Mdot
.546 .38833 Mdot
.546 .38894 Mdot
.546 .38903 Mdot
.546 .38913 Mdot
.546 .38919 Mdot
.546 .38987 Mdot
.546 .39016 Mdot
.546 .39017 Mdot
.546 .39052 Mdot
.546 .39052 Mdot
.546 .39059 Mdot
.546 .39061 Mdot
.546 .39113 Mdot
.546 .39128 Mdot
.546 .39218 Mdot
.546 .39225 Mdot
.546 .39242 Mdot
.546 .39248 Mdot
.546 .39286 Mdot
.546 .3932 Mdot
.546 .39376 Mdot
.546 .39385 Mdot
.546 .39392 Mdot
.546 .39405 Mdot
.546 .39412 Mdot
.546 .39453 Mdot
.546 .39489 Mdot
.546 .39503 Mdot
.546 .39524 Mdot
.546 .39573 Mdot
.546 .39596 Mdot
.546 .39597 Mdot
.546 .39608 Mdot
.546 .39616 Mdot
.546 .3962 Mdot
.546 .39634 Mdot
.546 .39651 Mdot
.546 .39656 Mdot
.546 .39684 Mdot
.546 .39691 Mdot
.546 .39709 Mdot
.546 .39732 Mdot
.546 .39735 Mdot
.546 .39753 Mdot
.546 .39775 Mdot
.546 .39781 Mdot
.546 .39813 Mdot
.546 .39828 Mdot
.546 .3983 Mdot
.546 .39839 Mdot
.546 .39868 Mdot
.546 .39885 Mdot
.546 .39886 Mdot
.546 .39896 Mdot
.546 .39899 Mdot
.546 .39901 Mdot
.546 .39921 Mdot
.546 .39954 Mdot
.546 .39963 Mdot
.546 .39964 Mdot
.546 .39966 Mdot
.546 .3998 Mdot
.546 .40006 Mdot
.546 .4001 Mdot
.546 .40012 Mdot
.546 .40022 Mdot
.546 .40027 Mdot
.546 .40032 Mdot
.546 .40045 Mdot
.546 .40048 Mdot
.546 .40054 Mdot
.546 .40055 Mdot
.546 .40056 Mdot
.546 .40057 Mdot
.546 .40057 Mdot
.546 .40058 Mdot
.546 .4006 Mdot
.546 .46445 Mdot
.546 .46446 Mdot
.546 .46447 Mdot
.546 .46447 Mdot
.546 .46447 Mdot
.546 .46447 Mdot
.546 .46448 Mdot
.546 .46451 Mdot
.546 .46453 Mdot
.546 .4646 Mdot
.546 .46462 Mdot
.546 .46465 Mdot
.546 .4647 Mdot
.546 .46471 Mdot
.546 .46473 Mdot
.546 .46486 Mdot
.546 .46494 Mdot
.546 .46495 Mdot
.546 .46495 Mdot
.546 .465 Mdot
.546 .46517 Mdot
.546 .46528 Mdot
.546 .46529 Mdot
.546 .4653 Mdot
.546 .46535 Mdot
.546 .46536 Mdot
.546 .46545 Mdot
.546 .46559 Mdot
.546 .46564 Mdot
.546 .46565 Mdot
.546 .46573 Mdot
.546 .46589 Mdot
.546 .46593 Mdot
.546 .46604 Mdot
.546 .46613 Mdot
.546 .46615 Mdot
.546 .46627 Mdot
.546 .46636 Mdot
.546 .4664 Mdot
.546 .46654 Mdot
.546 .46656 Mdot
.546 .46665 Mdot
.546 .46673 Mdot
.546 .46674 Mdot
.546 .46678 Mdot
.546 .46684 Mdot
.546 .46685 Mdot
.546 .46696 Mdot
.546 .46721 Mdot
.546 .46732 Mdot
.546 .4674 Mdot
.546 .46758 Mdot
.546 .46779 Mdot
.546 .46782 Mdot
.546 .46789 Mdot
.546 .46793 Mdot
.546 .46797 Mdot
.546 .46825 Mdot
.546 .46843 Mdot
.546 .46862 Mdot
.546 .46865 Mdot
.546 .46874 Mdot
.546 .46877 Mdot
.546 .46923 Mdot
.546 .4693 Mdot
.546 .46956 Mdot
.546 .46958 Mdot
.546 .46961 Mdot
.546 .46961 Mdot
.546 .46979 Mdot
.546 .46979 Mdot
.546 .46994 Mdot
.546 .47028 Mdot
.546 .47031 Mdot
.546 .47036 Mdot
.546 .47041 Mdot
.546 .47071 Mdot
.546 .47073 Mdot
.546 .47075 Mdot
.546 .47093 Mdot
.546 .471 Mdot
.546 .47104 Mdot
.546 .47128 Mdot
.546 .47148 Mdot
.546 .47173 Mdot
.546 .47184 Mdot
.546 .47192 Mdot
.546 .47208 Mdot
.546 .47222 Mdot
.546 .47238 Mdot
.546 .47242 Mdot
.546 .47245 Mdot
.546 .47248 Mdot
.546 .47272 Mdot
.546 .47283 Mdot
.546 .47334 Mdot
.546 .47344 Mdot
.546 .47355 Mdot
.546 .47384 Mdot
.546 .47396 Mdot
.546 .47409 Mdot
.546 .4741 Mdot
.546 .47428 Mdot
.546 .47443 Mdot
.546 .47445 Mdot
.546 .47452 Mdot
.546 .47456 Mdot
.546 .47466 Mdot
.546 .4747 Mdot
.546 .47471 Mdot
.546 .47474 Mdot
.546 .47475 Mdot
.546 .47477 Mdot
.546 .47482 Mdot
.546 .47544 Mdot
.546 .47571 Mdot
.546 .47624 Mdot
.546 .47625 Mdot
.546 .47664 Mdot
.546 .47676 Mdot
.546 .47896 Mdot
.546 .4793 Mdot
.546 .47951 Mdot
.546 .48009 Mdot
.546 .48175 Mdot
.546 .48248 Mdot
.546 .48322 Mdot
.546 .4833 Mdot
.546 .48435 Mdot
.546 .48531 Mdot
.546 .48539 Mdot
.546 .48584 Mdot
.546 .48604 Mdot
.546 .48614 Mdot
.546 .48617 Mdot
.546 .48657 Mdot
.546 .48676 Mdot
.546 .48689 Mdot
.546 .48699 Mdot
.546 .48703 Mdot
.546 .48727 Mdot
.546 .48729 Mdot
.546 .48743 Mdot
.546 .48773 Mdot
.546 .48789 Mdot
.546 .48991 Mdot
.546 .49146 Mdot
.546 .49164 Mdot
.546 .49183 Mdot
.546 .49269 Mdot
.546 .49333 Mdot
.546 .49365 Mdot
.546 .49392 Mdot
.546 .49725 Mdot
.546 .4973 Mdot
.546 .49805 Mdot
.546 .49807 Mdot
.546 .49808 Mdot
.546 .49808 Mdot
.546 .4981 Mdot
.546 .4981 Mdot
.546 .49812 Mdot
.546 .49818 Mdot
.546 .49821 Mdot
.546 .49837 Mdot
.546 .49843 Mdot
.546 .49848 Mdot
.546 .4986 Mdot
.546 .49861 Mdot
.546 .49866 Mdot
.546 .49895 Mdot
.546 .49911 Mdot
.546 .49913 Mdot
.546 .49914 Mdot
.546 .49916 Mdot
.546 .49924 Mdot
.546 .49938 Mdot
.546 .49961 Mdot
.546 .49984 Mdot
.546 .49986 Mdot
.546 .49989 Mdot
.546 .49999 Mdot
.546 .5 Mdot
.546 .50001 Mdot
.546 .5002 Mdot
.546 .50043 Mdot
.546 .50052 Mdot
.546 .50062 Mdot
.546 .50064 Mdot
.546 .5008 Mdot
.546 .50085 Mdot
.546 .50115 Mdot
.546 .50123 Mdot
.546 .50147 Mdot
.546 .50166 Mdot
.546 .50169 Mdot
.546 .50195 Mdot
.546 .50214 Mdot
.546 .50222 Mdot
.546 .50253 Mdot
.546 .50257 Mdot
.546 .50276 Mdot
.546 .50291 Mdot
.546 .50295 Mdot
.546 .50304 Mdot
.546 .50315 Mdot
.546 .50317 Mdot
.546 .50341 Mdot
.546 .50394 Mdot
.546 .50416 Mdot
.546 .50432 Mdot
.546 .50469 Mdot
.546 .50512 Mdot
.546 .5052 Mdot
.546 .50534 Mdot
.546 .50541 Mdot
.546 .5055 Mdot
.546 .50608 Mdot
.546 .50615 Mdot
.546 .50644 Mdot
.546 .5067 Mdot
.546 .50675 Mdot
.546 .50684 Mdot
.546 .50689 Mdot
.546 .50707 Mdot
.546 .50714 Mdot
.546 .50773 Mdot
.546 .50806 Mdot
.546 .50821 Mdot
.546 .50823 Mdot
.546 .5083 Mdot
.546 .50874 Mdot
.546 .50876 Mdot
.546 .50883 Mdot
.546 .50883 Mdot
.546 .50912 Mdot
.546 .50918 Mdot
.546 .50919 Mdot
.546 .50928 Mdot
.546 .50949 Mdot
.546 .5096 Mdot
.546 .51006 Mdot
.546 .51016 Mdot
.546 .51022 Mdot
.546 .51023 Mdot
.546 .51031 Mdot
.546 .51041 Mdot
.546 .51073 Mdot
.546 .51101 Mdot
.546 .51103 Mdot
.546 .51108 Mdot
.546 .51143 Mdot
.546 .51156 Mdot
.546 .51164 Mdot
.546 .5121 Mdot
.546 .51212 Mdot
.546 .51222 Mdot
.546 .51249 Mdot
.546 .51254 Mdot
.546 .51298 Mdot
.546 .51319 Mdot
.546 .51324 Mdot
.546 .51335 Mdot
.546 .51364 Mdot
.546 .51391 Mdot
.546 .51422 Mdot
.546 .5143 Mdot
.546 .51436 Mdot
.546 .51441 Mdot
.546 .51476 Mdot
.546 .51486 Mdot
.546 .51506 Mdot
.546 .51506 Mdot
.546 .51603 Mdot
.546 .51614 Mdot
.546 .51621 Mdot
.546 .51641 Mdot
.546 .51694 Mdot
.546 .51717 Mdot
.546 .5174 Mdot
.546 .51742 Mdot
.546 .51774 Mdot
.546 .51802 Mdot
.546 .51805 Mdot
.546 .51818 Mdot
.546 .51827 Mdot
.546 .51828 Mdot
.546 .51839 Mdot
.546 .51845 Mdot
.546 .51851 Mdot
.546 .51852 Mdot
.546 .51859 Mdot
.546 .5186 Mdot
.546 .51864 Mdot
.546 .51872 Mdot
.546 .51974 Mdot
.546 .51979 Mdot
.546 .51984 Mdot
.546 .52032 Mdot
.546 .52124 Mdot
.546 .52125 Mdot
.546 .52177 Mdot
.546 .52192 Mdot
.546 .52203 Mdot
.546 .52214 Mdot
.546 .52357 Mdot
.546 .5244 Mdot
.546 .52581 Mdot
.546 .52635 Mdot
.546 .52667 Mdot
.546 .52669 Mdot
.546 .52761 Mdot
.546 .53015 Mdot
.546 .53122 Mdot
.546 .5316 Mdot
.546 .53228 Mdot
.546 .53239 Mdot
.546 .53324 Mdot
.546 .53326 Mdot
.546 .53382 Mdot
.546 .53386 Mdot
.546 .53472 Mdot
.546 .53514 Mdot
.546 .53525 Mdot
.546 .53583 Mdot
.546 .53609 Mdot
.546 .53621 Mdot
.546 .53626 Mdot
.546 .53675 Mdot
.546 .53693 Mdot
.546 .53699 Mdot
.546 .53716 Mdot
.546 .53727 Mdot
.546 .53733 Mdot
.546 .53762 Mdot
.546 .53764 Mdot
.546 .53782 Mdot
.546 .53815 Mdot
.546 .53817 Mdot
.546 .53836 Mdot
.546 .5401 Mdot
.546 .54023 Mdot
.546 .54037 Mdot
.546 .54056 Mdot
.546 .54063 Mdot
.546 .54121 Mdot
.546 .54122 Mdot
.546 .54222 Mdot
.546 .5423 Mdot
.546 .54239 Mdot
.546 .54258 Mdot
.546 .54283 Mdot
.546 .54289 Mdot
.546 .54294 Mdot
.546 .54338 Mdot
.546 .54395 Mdot
.546 .54399 Mdot
.546 .54407 Mdot
.546 .54411 Mdot
.546 .54412 Mdot
.546 .54419 Mdot
.546 .5442 Mdot
.546 .54422 Mdot
.546 .54426 Mdot
.546 .54431 Mdot
.546 .54442 Mdot
.546 .54443 Mdot
.546 .54446 Mdot
.546 .54451 Mdot
.546 .54463 Mdot
.546 .54466 Mdot
.546 .54492 Mdot
.546 .5452 Mdot
.546 .54522 Mdot
.546 .54542 Mdot
.546 .54561 Mdot
.546 .54604 Mdot
.546 .5462 Mdot
.546 .54625 Mdot
.546 .54634 Mdot
.546 .5469 Mdot
.546 .54693 Mdot
.546 .54703 Mdot
.546 .54703 Mdot
.546 .54716 Mdot
.546 .54723 Mdot
.546 .54739 Mdot
.546 .5474 Mdot
.546 .5474 Mdot
.546 .5474 Mdot
.546 .54741 Mdot
.546 .54742 Mdot
.546 .54742 Mdot
.546 .54745 Mdot
.546 .54746 Mdot
.546 .54748 Mdot
.546 .54748 Mdot
.546 .54752 Mdot
.546 .54756 Mdot
.546 .54757 Mdot
.546 .5476 Mdot
.546 .54763 Mdot
.546 .5477 Mdot
.546 .54773 Mdot
.546 .54775 Mdot
.546 .54788 Mdot
.546 .54791 Mdot
.546 .54796 Mdot
.546 .54797 Mdot
.546 .54798 Mdot
.546 .54799 Mdot
.546 .54803 Mdot
.546 .54806 Mdot
.546 .5481 Mdot
.546 .54812 Mdot
.546 .54815 Mdot
.546 .54821 Mdot
.546 .54826 Mdot
.546 .54832 Mdot
.546 .54832 Mdot
.546 .54834 Mdot
.546 .54839 Mdot
.546 .54839 Mdot
.546 .54839 Mdot
.546 .54847 Mdot
.546 .54848 Mdot
.546 .54849 Mdot
.546 .5485 Mdot
.546 .54858 Mdot
.546 .54862 Mdot
.546 .54862 Mdot
.546 .54866 Mdot
.546 .54866 Mdot
.546 .54867 Mdot
.546 .54867 Mdot
.546 .54873 Mdot
.546 .54875 Mdot
.546 .54886 Mdot
.546 .54887 Mdot
.546 .54889 Mdot
.546 .5489 Mdot
.546 .54894 Mdot
.546 .54898 Mdot
.546 .54905 Mdot
.546 .54906 Mdot
.546 .54907 Mdot
.546 .54909 Mdot
.546 .54909 Mdot
.546 .54914 Mdot
.546 .54919 Mdot
.546 .5492 Mdot
.546 .54923 Mdot
.546 .54929 Mdot
.546 .54932 Mdot
.546 .54932 Mdot
.546 .54933 Mdot
.546 .54934 Mdot
.546 .54934 Mdot
.546 .54936 Mdot
.546 .54938 Mdot
.546 .54939 Mdot
.546 .54942 Mdot
.546 .54943 Mdot
.546 .54945 Mdot
.546 .54948 Mdot
.546 .54948 Mdot
.546 .5495 Mdot
.546 .54953 Mdot
.546 .54954 Mdot
.546 .54958 Mdot
.546 .54959 Mdot
.546 .5496 Mdot
.546 .54961 Mdot
.546 .54964 Mdot
.546 .54966 Mdot
.546 .54966 Mdot
.546 .54968 Mdot
.546 .54968 Mdot
.546 .54968 Mdot
.546 .54971 Mdot
.546 .54975 Mdot
.546 .54976 Mdot
.546 .54976 Mdot
.546 .54976 Mdot
.546 .54978 Mdot
.546 .54981 Mdot
.546 .54981 Mdot
.546 .54982 Mdot
.546 .54983 Mdot
.546 .54983 Mdot
.546 .54984 Mdot
.546 .54986 Mdot
.546 .54986 Mdot
.546 .54987 Mdot
.546 .54987 Mdot
.546 .54987 Mdot
.546 .54987 Mdot
.546 .54987 Mdot
.546 .54987 Mdot
.546 .54987 Mdot
.548 .19081 Mdot
.548 .19081 Mdot
.548 .19081 Mdot
.548 .19081 Mdot
.548 .19081 Mdot
.548 .19083 Mdot
.548 .19084 Mdot
.548 .19085 Mdot
.548 .19085 Mdot
.548 .19086 Mdot
.548 .19086 Mdot
.548 .19088 Mdot
.548 .19088 Mdot
.548 .19093 Mdot
.548 .19097 Mdot
.548 .19099 Mdot
.548 .19103 Mdot
.548 .19117 Mdot
.548 .19118 Mdot
.548 .19119 Mdot
.548 .19119 Mdot
.548 .19124 Mdot
.548 .19133 Mdot
.548 .19138 Mdot
.548 .19146 Mdot
.548 .19163 Mdot
.548 .19165 Mdot
.548 .19169 Mdot
.548 .19169 Mdot
.548 .19171 Mdot
.548 .19174 Mdot
.548 .19175 Mdot
.548 .19178 Mdot
.548 .19184 Mdot
.548 .1919 Mdot
.548 .19196 Mdot
.548 .19196 Mdot
.548 .19198 Mdot
.548 .192 Mdot
.548 .19217 Mdot
.548 .19217 Mdot
.548 .19217 Mdot
.548 .19222 Mdot
.548 .19222 Mdot
.548 .19223 Mdot
.548 .19229 Mdot
.548 .19253 Mdot
.548 .19273 Mdot
.548 .19285 Mdot
.548 .19285 Mdot
.548 .19285 Mdot
.548 .19287 Mdot
.548 .19287 Mdot
.548 .19288 Mdot
.548 .19297 Mdot
.548 .19308 Mdot
.548 .19311 Mdot
.548 .19343 Mdot
.548 .19346 Mdot
.548 .19364 Mdot
.548 .19381 Mdot
.548 .19384 Mdot
.548 .19385 Mdot
.548 .19406 Mdot
.548 .19408 Mdot
.548 .1941 Mdot
.548 .1941 Mdot
.548 .19426 Mdot
.548 .19427 Mdot
.548 .19428 Mdot
.548 .19435 Mdot
.548 .19471 Mdot
.548 .19476 Mdot
.548 .19491 Mdot
.548 .19503 Mdot
.548 .19505 Mdot
.548 .19509 Mdot
.548 .19511 Mdot
.548 .19513 Mdot
.548 .19517 Mdot
.548 .1952 Mdot
.548 .19521 Mdot
.548 .19536 Mdot
.548 .19558 Mdot
.548 .19562 Mdot
.548 .19585 Mdot
.548 .1959 Mdot
.548 .19592 Mdot
.548 .19599 Mdot
.548 .19607 Mdot
.548 .19617 Mdot
.548 .19626 Mdot
.548 .19628 Mdot
.548 .19629 Mdot
.548 .19648 Mdot
.548 .19657 Mdot
.548 .19686 Mdot
.548 .19723 Mdot
.548 .19741 Mdot
.548 .19761 Mdot
.548 .19763 Mdot
.548 .19785 Mdot
.548 .19811 Mdot
.548 .19849 Mdot
.548 .19858 Mdot
.548 .19883 Mdot
.548 .19885 Mdot
.548 .19891 Mdot
.548 .199 Mdot
.548 .19942 Mdot
.548 .19947 Mdot
.548 .1998 Mdot
.548 .1999 Mdot
.548 .20006 Mdot
.548 .20018 Mdot
.548 .2004 Mdot
.548 .20041 Mdot
.548 .2007 Mdot
.548 .20074 Mdot
.548 .20082 Mdot
.548 .20085 Mdot
.548 .2009 Mdot
.548 .20093 Mdot
.548 .20094 Mdot
.548 .20105 Mdot
.548 .20115 Mdot
.548 .20115 Mdot
.548 .20115 Mdot
.548 .20115 Mdot
.548 .20115 Mdot
.548 .2015 Mdot
.548 .20163 Mdot
.548 .20292 Mdot
.548 .20455 Mdot
.548 .20489 Mdot
.548 .20585 Mdot
.548 .2068 Mdot
.548 .20704 Mdot
.548 .20715 Mdot
.548 .20774 Mdot
.548 .20955 Mdot
.548 .20964 Mdot
.548 .21013 Mdot
.548 .21076 Mdot
.548 .21406 Mdot
.548 .21441 Mdot
.548 .21646 Mdot
.548 .21714 Mdot
.548 .21802 Mdot
.548 .2188 Mdot
.548 .21935 Mdot
.548 .22037 Mdot
.548 .22039 Mdot
.548 .22068 Mdot
.548 .22105 Mdot
.548 .22229 Mdot
.548 .22242 Mdot
.548 .225 Mdot
.548 .22541 Mdot
.548 .22604 Mdot
.548 .22618 Mdot
.548 .22639 Mdot
.548 .22684 Mdot
.548 .22713 Mdot
.548 .22723 Mdot
.548 .22824 Mdot
.548 .22861 Mdot
.548 .22924 Mdot
.548 .22925 Mdot
.548 .22927 Mdot
.548 .22927 Mdot
.548 .22927 Mdot
.548 .23126 Mdot
.548 .23127 Mdot
.548 .23177 Mdot
.548 .23261 Mdot
.548 .23285 Mdot
.548 .23389 Mdot
.548 .23727 Mdot
.548 .23737 Mdot
.548 .24212 Mdot
.548 .24388 Mdot
.548 .24712 Mdot
.548 .25257 Mdot
.548 .25794 Mdot
.548 .2599 Mdot
.548 .26065 Mdot
.548 .26146 Mdot
.548 .26269 Mdot
.548 .26269 Mdot
.548 .26269 Mdot
.548 .2627 Mdot
.548 .2627 Mdot
.548 .26333 Mdot
.548 .26397 Mdot
.548 .26403 Mdot
.548 .26422 Mdot
.548 .2645 Mdot
.548 .26464 Mdot
.548 .26473 Mdot
.548 .26514 Mdot
.548 .2654 Mdot
.548 .26712 Mdot
.548 .26721 Mdot
.548 .26852 Mdot
.548 .26854 Mdot
.548 .26925 Mdot
.548 .27021 Mdot
.548 .27085 Mdot
.548 .27293 Mdot
.548 .2732 Mdot
.548 .27588 Mdot
.548 .27641 Mdot
.548 .27683 Mdot
.548 .27691 Mdot
.548 .27852 Mdot
.548 .27907 Mdot
.548 .27917 Mdot
.548 .27939 Mdot
.548 .28158 Mdot
.548 .28327 Mdot
.548 .28469 Mdot
.548 .28484 Mdot
.548 .28611 Mdot
.548 .28728 Mdot
.548 .28733 Mdot
.548 .28974 Mdot
.548 .28977 Mdot
.548 .29031 Mdot
.548 .29175 Mdot
.548 .29234 Mdot
.548 .29236 Mdot
.548 .29355 Mdot
.548 .29356 Mdot
.548 .29362 Mdot
.548 .29367 Mdot
.548 .29382 Mdot
.548 .29445 Mdot
.548 .29514 Mdot
.548 .29565 Mdot
.548 .29617 Mdot
.548 .29625 Mdot
.548 .29661 Mdot
.548 .29818 Mdot
.548 .29842 Mdot
.548 .29843 Mdot
.548 .29843 Mdot
.548 .29848 Mdot
.548 .29848 Mdot
.548 .29849 Mdot
.548 .3 Mdot
.548 .30004 Mdot
.548 .30096 Mdot
.548 .30106 Mdot
.548 .30111 Mdot
.548 .30134 Mdot
.548 .30156 Mdot
.548 .30175 Mdot
.548 .30186 Mdot
.548 .30212 Mdot
.548 .30227 Mdot
.548 .30309 Mdot
.548 .30348 Mdot
.548 .30373 Mdot
.548 .30419 Mdot
.548 .30446 Mdot
.548 .30454 Mdot
.548 .30558 Mdot
.548 .30612 Mdot
.548 .30646 Mdot
.548 .30704 Mdot
.548 .30753 Mdot
.548 .30763 Mdot
.548 .30766 Mdot
.548 .30806 Mdot
.548 .30884 Mdot
.548 .30886 Mdot
.548 .30893 Mdot
.548 .30909 Mdot
.548 .3091 Mdot
.548 .31063 Mdot
.548 .31069 Mdot
.548 .31089 Mdot
.548 .3121 Mdot
.548 .31341 Mdot
.548 .31358 Mdot
.548 .31568 Mdot
.548 .31594 Mdot
.548 .31602 Mdot
.548 .3161 Mdot
.548 .31691 Mdot
.548 .3176 Mdot
.548 .31762 Mdot
.548 .31762 Mdot
.548 .31776 Mdot
.548 .31777 Mdot
.548 .31779 Mdot
.548 .31868 Mdot
.548 .31922 Mdot
.548 .32013 Mdot
.548 .32019 Mdot
.548 .32096 Mdot
.548 .32101 Mdot
.548 .32185 Mdot
.548 .32232 Mdot
.548 .32236 Mdot
.548 .32239 Mdot
.548 .32272 Mdot
.548 .32273 Mdot
.548 .32276 Mdot
.548 .32367 Mdot
.548 .32396 Mdot
.548 .32417 Mdot
.548 .32428 Mdot
.548 .32431 Mdot
.548 .32475 Mdot
.548 .32513 Mdot
.548 .3252 Mdot
.548 .32558 Mdot
.548 .32581 Mdot
.548 .32594 Mdot
.548 .3261 Mdot
.548 .32625 Mdot
.548 .32629 Mdot
.548 .32659 Mdot
.548 .32673 Mdot
.548 .32718 Mdot
.548 .32799 Mdot
.548 .3286 Mdot
.548 .32896 Mdot
.548 .32949 Mdot
.548 .32961 Mdot
.548 .32994 Mdot
.548 .32996 Mdot
.548 .33004 Mdot
.548 .33015 Mdot
.548 .33118 Mdot
.548 .3313 Mdot
.548 .3315 Mdot
.548 .33164 Mdot
.548 .3319 Mdot
.548 .33226 Mdot
.548 .33231 Mdot
.548 .33241 Mdot
.548 .33244 Mdot
.548 .3325 Mdot
.548 .33253 Mdot
.548 .33254 Mdot
.548 .33267 Mdot
.548 .33279 Mdot
.548 .33279 Mdot
.548 .3328 Mdot
.548 .3328 Mdot
.548 .3328 Mdot
.548 .3368 Mdot
.548 .33774 Mdot
.548 .34667 Mdot
.548 .34838 Mdot
.548 .34972 Mdot
.548 .34997 Mdot
.548 .35494 Mdot
.548 .35657 Mdot
.548 .35687 Mdot
.548 .35752 Mdot
.548 .36015 Mdot
.548 .36279 Mdot
.548 .36375 Mdot
.548 .36826 Mdot
.548 .37186 Mdot
.548 .37223 Mdot
.548 .37261 Mdot
.548 .37319 Mdot
.548 .37319 Mdot
.548 .37319 Mdot
.548 .3732 Mdot
.548 .3732 Mdot
.548 .3735 Mdot
.548 .3738 Mdot
.548 .37382 Mdot
.548 .37391 Mdot
.548 .37405 Mdot
.548 .37411 Mdot
.548 .37434 Mdot
.548 .37447 Mdot
.548 .37526 Mdot
.548 .3753 Mdot
.548 .37591 Mdot
.548 .37624 Mdot
.548 .37668 Mdot
.548 .37697 Mdot
.548 .37791 Mdot
.548 .37803 Mdot
.548 .37922 Mdot
.548 .37946 Mdot
.548 .37964 Mdot
.548 .37968 Mdot
.548 .38038 Mdot
.548 .38062 Mdot
.548 .38171 Mdot
.548 .38244 Mdot
.548 .38305 Mdot
.548 .38311 Mdot
.548 .38365 Mdot
.548 .38417 Mdot
.548 .38519 Mdot
.548 .38602 Mdot
.548 .38627 Mdot
.548 .38679 Mdot
.548 .38682 Mdot
.548 .38688 Mdot
.548 .38714 Mdot
.548 .38742 Mdot
.548 .38763 Mdot
.548 .38784 Mdot
.548 .38787 Mdot
.548 .38802 Mdot
.548 .38866 Mdot
.548 .38879 Mdot
.548 .3894 Mdot
.548 .38983 Mdot
.548 .38985 Mdot
.548 .38994 Mdot
.548 .39003 Mdot
.548 .39011 Mdot
.548 .39015 Mdot
.548 .39025 Mdot
.548 .39032 Mdot
.548 .39064 Mdot
.548 .39109 Mdot
.548 .39122 Mdot
.548 .39222 Mdot
.548 .39242 Mdot
.548 .39245 Mdot
.548 .39247 Mdot
.548 .39293 Mdot
.548 .39294 Mdot
.548 .39297 Mdot
.548 .39303 Mdot
.548 .39364 Mdot
.548 .39366 Mdot
.548 .39374 Mdot
.548 .39421 Mdot
.548 .39472 Mdot
.548 .39479 Mdot
.548 .39571 Mdot
.548 .39577 Mdot
.548 .39608 Mdot
.548 .39635 Mdot
.548 .39636 Mdot
.548 .39636 Mdot
.548 .39642 Mdot
.548 .39642 Mdot
.548 .39643 Mdot
.548 .39677 Mdot
.548 .39733 Mdot
.548 .39798 Mdot
.548 .39816 Mdot
.548 .39818 Mdot
.548 .39819 Mdot
.548 .39832 Mdot
.548 .39832 Mdot
.548 .39833 Mdot
.548 .39879 Mdot
.548 .39887 Mdot
.548 .39891 Mdot
.548 .39892 Mdot
.548 .39909 Mdot
.548 .39926 Mdot
.548 .39941 Mdot
.548 .3995 Mdot
.548 .39954 Mdot
.548 .3996 Mdot
.548 .39966 Mdot
.548 .39968 Mdot
.548 .39979 Mdot
.548 .39984 Mdot
.548 .40032 Mdot
.548 .40055 Mdot
.548 .40069 Mdot
.548 .40093 Mdot
.548 .40106 Mdot
.548 .40106 Mdot
.548 .4011 Mdot
.548 .40114 Mdot
.548 .40152 Mdot
.548 .40164 Mdot
.548 .4017 Mdot
.548 .4018 Mdot
.548 .40193 Mdot
.548 .40195 Mdot
.548 .40199 Mdot
.548 .402 Mdot
.548 .40202 Mdot
.548 .40203 Mdot
.548 .40204 Mdot
.548 .40208 Mdot
.548 .40213 Mdot
.548 .40213 Mdot
.548 .40213 Mdot
.548 .40213 Mdot
.548 .40213 Mdot
.548 .46374 Mdot
.548 .46374 Mdot
.548 .46374 Mdot
.548 .46374 Mdot
.548 .46374 Mdot
.548 .46377 Mdot
.548 .46379 Mdot
.548 .46379 Mdot
.548 .4638 Mdot
.548 .46381 Mdot
.548 .46382 Mdot
.548 .46383 Mdot
.548 .46385 Mdot
.548 .46392 Mdot
.548 .46397 Mdot
.548 .464 Mdot
.548 .46406 Mdot
.548 .46426 Mdot
.548 .46428 Mdot
.548 .4643 Mdot
.548 .4643 Mdot
.548 .46437 Mdot
.548 .46449 Mdot
.548 .46456 Mdot
.548 .46468 Mdot
.548 .46493 Mdot
.548 .46496 Mdot
.548 .46502 Mdot
.548 .46503 Mdot
.548 .46506 Mdot
.548 .46509 Mdot
.548 .46511 Mdot
.548 .46516 Mdot
.548 .46523 Mdot
.548 .46532 Mdot
.548 .46541 Mdot
.548 .46541 Mdot
.548 .46543 Mdot
.548 .46548 Mdot
.548 .46571 Mdot
.548 .46572 Mdot
.548 .46572 Mdot
.548 .46579 Mdot
.548 .46579 Mdot
.548 .4658 Mdot
.548 .46589 Mdot
.548 .46623 Mdot
.548 .46652 Mdot
.548 .46669 Mdot
.548 .4667 Mdot
.548 .4667 Mdot
.548 .46673 Mdot
.548 .46673 Mdot
.548 .46673 Mdot
.548 .46687 Mdot
.548 .46703 Mdot
.548 .46706 Mdot
.548 .46753 Mdot
.548 .46756 Mdot
.548 .46783 Mdot
.548 .46807 Mdot
.548 .46811 Mdot
.548 .46812 Mdot
.548 .46843 Mdot
.548 .46846 Mdot
.548 .46847 Mdot
.548 .46848 Mdot
.548 .46871 Mdot
.548 .46872 Mdot
.548 .46874 Mdot
.548 .46884 Mdot
.548 .46934 Mdot
.548 .46941 Mdot
.548 .46963 Mdot
.548 .4698 Mdot
.548 .46983 Mdot
.548 .46988 Mdot
.548 .4699 Mdot
.548 .46994 Mdot
.548 .46999 Mdot
.548 .47003 Mdot
.548 .47004 Mdot
.548 .47026 Mdot
.548 .47057 Mdot
.548 .47063 Mdot
.548 .47095 Mdot
.548 .47102 Mdot
.548 .47104 Mdot
.548 .47114 Mdot
.548 .47125 Mdot
.548 .47139 Mdot
.548 .47152 Mdot
.548 .47155 Mdot
.548 .47156 Mdot
.548 .47182 Mdot
.548 .47195 Mdot
.548 .47236 Mdot
.548 .47286 Mdot
.548 .47312 Mdot
.548 .47338 Mdot
.548 .47341 Mdot
.548 .47371 Mdot
.548 .47407 Mdot
.548 .4746 Mdot
.548 .47472 Mdot
.548 .47506 Mdot
.548 .47508 Mdot
.548 .47517 Mdot
.548 .47529 Mdot
.548 .47587 Mdot
.548 .47592 Mdot
.548 .47638 Mdot
.548 .47652 Mdot
.548 .47673 Mdot
.548 .47689 Mdot
.548 .47718 Mdot
.548 .4772 Mdot
.548 .47758 Mdot
.548 .47764 Mdot
.548 .47775 Mdot
.548 .47778 Mdot
.548 .47785 Mdot
.548 .47789 Mdot
.548 .4779 Mdot
.548 .47805 Mdot
.548 .47819 Mdot
.548 .47819 Mdot
.548 .47819 Mdot
.548 .47819 Mdot
.548 .47819 Mdot
.548 .47866 Mdot
.548 .47883 Mdot
.548 .48053 Mdot
.548 .48265 Mdot
.548 .48309 Mdot
.548 .48432 Mdot
.548 .48553 Mdot
.548 .48582 Mdot
.548 .48596 Mdot
.548 .48671 Mdot
.548 .48895 Mdot
.548 .48907 Mdot
.548 .48967 Mdot
.548 .49043 Mdot
.548 .49437 Mdot
.548 .49478 Mdot
.548 .49652 Mdot
.548 .49652 Mdot
.548 .49652 Mdot
.548 .49652 Mdot
.548 .49652 Mdot
.548 .49657 Mdot
.548 .49662 Mdot
.548 .49663 Mdot
.548 .49665 Mdot
.548 .49667 Mdot
.548 .49668 Mdot
.548 .49672 Mdot
.548 .49675 Mdot
.548 .4969 Mdot
.548 .49701 Mdot
.548 .49708 Mdot
.548 .49716 Mdot
.548 .49721 Mdot
.548 .49765 Mdot
.548 .4977 Mdot
.548 .49774 Mdot
.548 .49774 Mdot
.548 .49789 Mdot
.548 .49794 Mdot
.548 .49816 Mdot
.548 .49832 Mdot
.548 .49858 Mdot
.548 .49892 Mdot
.548 .49912 Mdot
.548 .49918 Mdot
.548 .4993 Mdot
.548 .49932 Mdot
.548 .49938 Mdot
.548 .49945 Mdot
.548 .4995 Mdot
.548 .4996 Mdot
.548 .49976 Mdot
.548 .49979 Mdot
.548 .49995 Mdot
.548 .50014 Mdot
.548 .50016 Mdot
.548 .5002 Mdot
.548 .50029 Mdot
.548 .50041 Mdot
.548 .5008 Mdot
.548 .50081 Mdot
.548 .50081 Mdot
.548 .50095 Mdot
.548 .50096 Mdot
.548 .50098 Mdot
.548 .50118 Mdot
.548 .50153 Mdot
.548 .50156 Mdot
.548 .50188 Mdot
.548 .5019 Mdot
.548 .50228 Mdot
.548 .50251 Mdot
.548 .50288 Mdot
.548 .50289 Mdot
.548 .50289 Mdot
.548 .50295 Mdot
.548 .50295 Mdot
.548 .50296 Mdot
.548 .50325 Mdot
.548 .50358 Mdot
.548 .50362 Mdot
.548 .50365 Mdot
.548 .50376 Mdot
.548 .50463 Mdot
.548 .5047 Mdot
.548 .50524 Mdot
.548 .50574 Mdot
.548 .50582 Mdot
.548 .50585 Mdot
.548 .50647 Mdot
.548 .50648 Mdot
.548 .50654 Mdot
.548 .50657 Mdot
.548 .50658 Mdot
.548 .5069 Mdot
.548 .50706 Mdot
.548 .50708 Mdot
.548 .50711 Mdot
.548 .50732 Mdot
.548 .50755 Mdot
.548 .50769 Mdot
.548 .50791 Mdot
.548 .50834 Mdot
.548 .50836 Mdot
.548 .50847 Mdot
.548 .50866 Mdot
.548 .50876 Mdot
.548 .50892 Mdot
.548 .50925 Mdot
.548 .50931 Mdot
.548 .50942 Mdot
.548 .50946 Mdot
.548 .50954 Mdot
.548 .50963 Mdot
.548 .50972 Mdot
.548 .50974 Mdot
.548 .50978 Mdot
.548 .51015 Mdot
.548 .51017 Mdot
.548 .51077 Mdot
.548 .51078 Mdot
.548 .51078 Mdot
.548 .5108 Mdot
.548 .5108 Mdot
.548 .5108 Mdot
.548 .5109 Mdot
.548 .51153 Mdot
.548 .51167 Mdot
.548 .5117 Mdot
.548 .51191 Mdot
.548 .51211 Mdot
.548 .51239 Mdot
.548 .51264 Mdot
.548 .51269 Mdot
.548 .51272 Mdot
.548 .51274 Mdot
.548 .51274 Mdot
.548 .51322 Mdot
.548 .51322 Mdot
.548 .51346 Mdot
.548 .51403 Mdot
.548 .51424 Mdot
.548 .51425 Mdot
.548 .5152 Mdot
.548 .51522 Mdot
.548 .51568 Mdot
.548 .51617 Mdot
.548 .51623 Mdot
.548 .51679 Mdot
.548 .51744 Mdot
.548 .51829 Mdot
.548 .51838 Mdot
.548 .51842 Mdot
.548 .51863 Mdot
.548 .51925 Mdot
.548 .51928 Mdot
.548 .51944 Mdot
.548 .51964 Mdot
.548 .52067 Mdot
.548 .52077 Mdot
.548 .52157 Mdot
.548 .52181 Mdot
.548 .52217 Mdot
.548 .52244 Mdot
.548 .52245 Mdot
.548 .52295 Mdot
.548 .52298 Mdot
.548 .52363 Mdot
.548 .52373 Mdot
.548 .52388 Mdot
.548 .52392 Mdot
.548 .52397 Mdot
.548 .52408 Mdot
.548 .52415 Mdot
.548 .52417 Mdot
.548 .52441 Mdot
.548 .52464 Mdot
.548 .52465 Mdot
.548 .52465 Mdot
.548 .52465 Mdot
.548 .52465 Mdot
.548 .52511 Mdot
.548 .52541 Mdot
.548 .52569 Mdot
.548 .52642 Mdot
.548 .52841 Mdot
.548 .53041 Mdot
.548 .53159 Mdot
.548 .53223 Mdot
.548 .53395 Mdot
.548 .53398 Mdot
.548 .5352 Mdot
.548 .53556 Mdot
.548 .53565 Mdot
.548 .53595 Mdot
.548 .53613 Mdot
.548 .53613 Mdot
.548 .53684 Mdot
.548 .53684 Mdot
.548 .53684 Mdot
.548 .53685 Mdot
.548 .53685 Mdot
.548 .53707 Mdot
.548 .53721 Mdot
.548 .53756 Mdot
.548 .5376 Mdot
.548 .5377 Mdot
.548 .53786 Mdot
.548 .53794 Mdot
.548 .53798 Mdot
.548 .53821 Mdot
.548 .53835 Mdot
.548 .53926 Mdot
.548 .53931 Mdot
.548 .53974 Mdot
.548 .53987 Mdot
.548 .53997 Mdot
.548 .53998 Mdot
.548 .54034 Mdot
.548 .54053 Mdot
.548 .5408 Mdot
.548 .54111 Mdot
.548 .54134 Mdot
.548 .54206 Mdot
.548 .54218 Mdot
.548 .54332 Mdot
.548 .54354 Mdot
.548 .54371 Mdot
.548 .54374 Mdot
.548 .54436 Mdot
.548 .54456 Mdot
.548 .5446 Mdot
.548 .54468 Mdot
.548 .54501 Mdot
.548 .54534 Mdot
.548 .54545 Mdot
.548 .54601 Mdot
.548 .54645 Mdot
.548 .5465 Mdot
.548 .54661 Mdot
.548 .54661 Mdot
.548 .54661 Mdot
.548 .54661 Mdot
.548 .54661 Mdot
.548 .54665 Mdot
.548 .54669 Mdot
.548 .54669 Mdot
.548 .5467 Mdot
.548 .54672 Mdot
.548 .54673 Mdot
.548 .54675 Mdot
.548 .54677 Mdot
.548 .54687 Mdot
.548 .54687 Mdot
.548 .54694 Mdot
.548 .54699 Mdot
.548 .54704 Mdot
.548 .54707 Mdot
.548 .54719 Mdot
.548 .5472 Mdot
.548 .54735 Mdot
.548 .54738 Mdot
.548 .5474 Mdot
.548 .5474 Mdot
.548 .54749 Mdot
.548 .54752 Mdot
.548 .54765 Mdot
.548 .54774 Mdot
.548 .54781 Mdot
.548 .54782 Mdot
.548 .54788 Mdot
.548 .54795 Mdot
.548 .54807 Mdot
.548 .54817 Mdot
.548 .5482 Mdot
.548 .54826 Mdot
.548 .54827 Mdot
.548 .54827 Mdot
.548 .54831 Mdot
.548 .54834 Mdot
.548 .54837 Mdot
.548 .54839 Mdot
.548 .54839 Mdot
.548 .54841 Mdot
.548 .54849 Mdot
.548 .5485 Mdot
.548 .54858 Mdot
.548 .54863 Mdot
.548 .54863 Mdot
.548 .54864 Mdot
.548 .54865 Mdot
.548 .54866 Mdot
.548 .54867 Mdot
.548 .54868 Mdot
.548 .54869 Mdot
.548 .54873 Mdot
.548 .54878 Mdot
.548 .5488 Mdot
.548 .54892 Mdot
.548 .54894 Mdot
.548 .54895 Mdot
.548 .54895 Mdot
.548 .549 Mdot
.548 .549 Mdot
.548 .54901 Mdot
.548 .54902 Mdot
.548 .54909 Mdot
.548 .54909 Mdot
.548 .5491 Mdot
.548 .54916 Mdot
.548 .54922 Mdot
.548 .54923 Mdot
.548 .54934 Mdot
.548 .54935 Mdot
.548 .54938 Mdot
.548 .54942 Mdot
.548 .54942 Mdot
.548 .54942 Mdot
.548 .54942 Mdot
.548 .54942 Mdot
.548 .54942 Mdot
.548 .54947 Mdot
.548 .54953 Mdot
.548 .54961 Mdot
.548 .54963 Mdot
.548 .54964 Mdot
.548 .54964 Mdot
.548 .54965 Mdot
.548 .54965 Mdot
.548 .54965 Mdot
.548 .54971 Mdot
.548 .54972 Mdot
.548 .54972 Mdot
.548 .54972 Mdot
.548 .54974 Mdot
.548 .54977 Mdot
.548 .54978 Mdot
.548 .54979 Mdot
.548 .5498 Mdot
.548 .54981 Mdot
.548 .54981 Mdot
.548 .54982 Mdot
.548 .54983 Mdot
.548 .54983 Mdot
.548 .54989 Mdot
.548 .54992 Mdot
.548 .54994 Mdot
.548 .54997 Mdot
.548 .54998 Mdot
.548 .54998 Mdot
.548 .54999 Mdot
.548 .54999 Mdot
.548 .55004 Mdot
.548 .55005 Mdot
.548 .55006 Mdot
.548 .55007 Mdot
.548 .55009 Mdot
.548 .55009 Mdot
.548 .55009 Mdot
.548 .55009 Mdot
.548 .5501 Mdot
.548 .5501 Mdot
.548 .5501 Mdot
.548 .5501 Mdot
.548 .55011 Mdot
.548 .55011 Mdot
.548 .55011 Mdot
.548 .55011 Mdot
.548 .55011 Mdot
.55 .19019 Mdot
.55 .19019 Mdot
.55 .1902 Mdot
.55 .19027 Mdot
.55 .19028 Mdot
.55 .19029 Mdot
.55 .19042 Mdot
.55 .19043 Mdot
.55 .19046 Mdot
.55 .19052 Mdot
.55 .19056 Mdot
.55 .19057 Mdot
.55 .19064 Mdot
.55 .19066 Mdot
.55 .19067 Mdot
.55 .19073 Mdot
.55 .19074 Mdot
.55 .19076 Mdot
.55 .1908 Mdot
.55 .19083 Mdot
.55 .19083 Mdot
.55 .19099 Mdot
.55 .19103 Mdot
.55 .19105 Mdot
.55 .19108 Mdot
.55 .1911 Mdot
.55 .1912 Mdot
.55 .1913 Mdot
.55 .1913 Mdot
.55 .19144 Mdot
.55 .19144 Mdot
.55 .19146 Mdot
.55 .1915 Mdot
.55 .1915 Mdot
.55 .19165 Mdot
.55 .19178 Mdot
.55 .19178 Mdot
.55 .19178 Mdot
.55 .19223 Mdot
.55 .19234 Mdot
.55 .19234 Mdot
.55 .19239 Mdot
.55 .19242 Mdot
.55 .19248 Mdot
.55 .19265 Mdot
.55 .19265 Mdot
.55 .1927 Mdot
.55 .193 Mdot
.55 .19313 Mdot
.55 .19322 Mdot
.55 .1938 Mdot
.55 .19395 Mdot
.55 .19398 Mdot
.55 .19427 Mdot
.55 .19457 Mdot
.55 .19463 Mdot
.55 .1947 Mdot
.55 .19471 Mdot
.55 .19472 Mdot
.55 .19487 Mdot
.55 .19492 Mdot
.55 .19493 Mdot
.55 .1951 Mdot
.55 .1951 Mdot
.55 .19513 Mdot
.55 .19526 Mdot
.55 .1956 Mdot
.55 .19577 Mdot
.55 .19598 Mdot
.55 .19599 Mdot
.55 .19616 Mdot
.55 .19628 Mdot
.55 .19629 Mdot
.55 .1964 Mdot
.55 .19686 Mdot
.55 .19698 Mdot
.55 .19699 Mdot
.55 .19738 Mdot
.55 .1975 Mdot
.55 .1977 Mdot
.55 .19801 Mdot
.55 .19804 Mdot
.55 .19804 Mdot
.55 .19806 Mdot
.55 .1982 Mdot
.55 .19832 Mdot
.55 .19832 Mdot
.55 .19834 Mdot
.55 .19838 Mdot
.55 .19838 Mdot
.55 .19849 Mdot
.55 .19868 Mdot
.55 .19873 Mdot
.55 .19963 Mdot
.55 .19966 Mdot
.55 .19982 Mdot
.55 .2001 Mdot
.55 .20021 Mdot
.55 .20032 Mdot
.55 .20047 Mdot
.55 .20066 Mdot
.55 .20072 Mdot
.55 .2009 Mdot
.55 .2012 Mdot
.55 .20134 Mdot
.55 .2014 Mdot
.55 .20168 Mdot
.55 .20212 Mdot
.55 .20229 Mdot
.55 .20238 Mdot
.55 .20239 Mdot
.55 .20278 Mdot
.55 .20332 Mdot
.55 .20338 Mdot
.55 .20346 Mdot
.55 .20346 Mdot
.55 .20395 Mdot
.55 .20406 Mdot
.55 .20408 Mdot
.55 .20434 Mdot
.55 .20456 Mdot
.55 .20458 Mdot
.55 .20466 Mdot
.55 .20562 Mdot
.55 .20649 Mdot
.55 .20649 Mdot
.55 .20663 Mdot
.55 .20688 Mdot
.55 .2069 Mdot
.55 .20709 Mdot
.55 .20759 Mdot
.55 .20765 Mdot
.55 .20906 Mdot
.55 .20938 Mdot
.55 .21459 Mdot
.55 .2166 Mdot
.55 .21679 Mdot
.55 .21816 Mdot
.55 .21998 Mdot
.55 .2206 Mdot
.55 .22068 Mdot
.55 .22164 Mdot
.55 .22198 Mdot
.55 .2222 Mdot
.55 .22256 Mdot
.55 .22257 Mdot
.55 .22289 Mdot
.55 .22309 Mdot
.55 .22321 Mdot
.55 .22348 Mdot
.55 .22399 Mdot
.55 .22571 Mdot
.55 .22631 Mdot
.55 .22639 Mdot
.55 .22796 Mdot
.55 .22796 Mdot
.55 .22823 Mdot
.55 .22919 Mdot
.55 .23049 Mdot
.55 .23085 Mdot
.55 .23108 Mdot
.55 .23129 Mdot
.55 .23134 Mdot
.55 .23146 Mdot
.55 .2323 Mdot
.55 .23258 Mdot
.55 .23288 Mdot
.55 .23324 Mdot
.55 .23326 Mdot
.55 .23327 Mdot
.55 .23345 Mdot
.55 .23561 Mdot
.55 .23743 Mdot
.55 .23762 Mdot
.55 .24018 Mdot
.55 .24196 Mdot
.55 .24223 Mdot
.55 .24265 Mdot
.55 .24277 Mdot
.55 .24287 Mdot
.55 .24293 Mdot
.55 .24296 Mdot
.55 .24305 Mdot
.55 .24392 Mdot
.55 .24475 Mdot
.55 .24529 Mdot
.55 .24535 Mdot
.55 .24591 Mdot
.55 .24596 Mdot
.55 .24712 Mdot
.55 .24856 Mdot
.55 .24858 Mdot
.55 .24903 Mdot
.55 .24934 Mdot
.55 .2523 Mdot
.55 .25293 Mdot
.55 .25354 Mdot
.55 .25445 Mdot
.55 .2545 Mdot
.55 .25451 Mdot
.55 .25455 Mdot
.55 .25504 Mdot
.55 .25601 Mdot
.55 .25743 Mdot
.55 .25858 Mdot
.55 .25984 Mdot
.55 .25995 Mdot
.55 .26017 Mdot
.55 .26051 Mdot
.55 .26112 Mdot
.55 .26124 Mdot
.55 .26138 Mdot
.55 .2624 Mdot
.55 .26316 Mdot
.55 .26415 Mdot
.55 .26419 Mdot
.55 .26458 Mdot
.55 .2657 Mdot
.55 .26603 Mdot
.55 .26621 Mdot
.55 .26629 Mdot
.55 .26643 Mdot
.55 .26664 Mdot
.55 .26665 Mdot
.55 .26689 Mdot
.55 .26727 Mdot
.55 .26782 Mdot
.55 .26798 Mdot
.55 .26841 Mdot
.55 .26969 Mdot
.55 .27069 Mdot
.55 .27083 Mdot
.55 .27234 Mdot
.55 .27655 Mdot
.55 .27682 Mdot
.55 .27807 Mdot
.55 .27812 Mdot
.55 .27858 Mdot
.55 .27875 Mdot
.55 .27877 Mdot
.55 .27899 Mdot
.55 .27912 Mdot
.55 .27913 Mdot
.55 .27994 Mdot
.55 .28087 Mdot
.55 .28095 Mdot
.55 .28097 Mdot
.55 .28119 Mdot
.55 .28278 Mdot
.55 .2832 Mdot
.55 .2845 Mdot
.55 .28532 Mdot
.55 .28788 Mdot
.55 .28789 Mdot
.55 .28793 Mdot
.55 .28831 Mdot
.55 .28833 Mdot
.55 .28838 Mdot
.55 .28879 Mdot
.55 .28923 Mdot
.55 .28996 Mdot
.55 .29063 Mdot
.55 .29186 Mdot
.55 .29262 Mdot
.55 .29267 Mdot
.55 .29267 Mdot
.55 .29295 Mdot
.55 .29306 Mdot
.55 .29347 Mdot
.55 .29358 Mdot
.55 .29413 Mdot
.55 .29466 Mdot
.55 .29472 Mdot
.55 .295 Mdot
.55 .29618 Mdot
.55 .29734 Mdot
.55 .29821 Mdot
.55 .29972 Mdot
.55 .30058 Mdot
.55 .30059 Mdot
.55 .30078 Mdot
.55 .30079 Mdot
.55 .30125 Mdot
.55 .30125 Mdot
.55 .30196 Mdot
.55 .30207 Mdot
.55 .30241 Mdot
.55 .30344 Mdot
.55 .30353 Mdot
.55 .30361 Mdot
.55 .30407 Mdot
.55 .30451 Mdot
.55 .30519 Mdot
.55 .30537 Mdot
.55 .30667 Mdot
.55 .3069 Mdot
.55 .30871 Mdot
.55 .30893 Mdot
.55 .30998 Mdot
.55 .31128 Mdot
.55 .31257 Mdot
.55 .31328 Mdot
.55 .31358 Mdot
.55 .3141 Mdot
.55 .31415 Mdot
.55 .31481 Mdot
.55 .31493 Mdot
.55 .31494 Mdot
.55 .31576 Mdot
.55 .31588 Mdot
.55 .31644 Mdot
.55 .31733 Mdot
.55 .31794 Mdot
.55 .3183 Mdot
.55 .31831 Mdot
.55 .31955 Mdot
.55 .31982 Mdot
.55 .31996 Mdot
.55 .32003 Mdot
.55 .32017 Mdot
.55 .32058 Mdot
.55 .32058 Mdot
.55 .32137 Mdot
.55 .32166 Mdot
.55 .32468 Mdot
.55 .3247 Mdot
.55 .32472 Mdot
.55 .32505 Mdot
.55 .32562 Mdot
.55 .32644 Mdot
.55 .32677 Mdot
.55 .32678 Mdot
.55 .32705 Mdot
.55 .32723 Mdot
.55 .32724 Mdot
.55 .32825 Mdot
.55 .32826 Mdot
.55 .32897 Mdot
.55 .3297 Mdot
.55 .32991 Mdot
.55 .33007 Mdot
.55 .33007 Mdot
.55 .33029 Mdot
.55 .33053 Mdot
.55 .33059 Mdot
.55 .33172 Mdot
.55 .33174 Mdot
.55 .33194 Mdot
.55 .33227 Mdot
.55 .33241 Mdot
.55 .33253 Mdot
.55 .33292 Mdot
.55 .333 Mdot
.55 .33319 Mdot
.55 .3337 Mdot
.55 .33376 Mdot
.55 .33407 Mdot
.55 .33455 Mdot
.55 .33474 Mdot
.55 .33483 Mdot
.55 .33581 Mdot
.55 .33587 Mdot
.55 .33596 Mdot
.55 .33596 Mdot
.55 .33645 Mdot
.55 .33657 Mdot
.55 .33658 Mdot
.55 .35011 Mdot
.55 .351 Mdot
.55 .35488 Mdot
.55 .35504 Mdot
.55 .35643 Mdot
.55 .35694 Mdot
.55 .35701 Mdot
.55 .35768 Mdot
.55 .35807 Mdot
.55 .35809 Mdot
.55 .36049 Mdot
.55 .36314 Mdot
.55 .36337 Mdot
.55 .36343 Mdot
.55 .36405 Mdot
.55 .36478 Mdot
.55 .36481 Mdot
.55 .36513 Mdot
.55 .36648 Mdot
.55 .36649 Mdot
.55 .36672 Mdot
.55 .36688 Mdot
.55 .36838 Mdot
.55 .36948 Mdot
.55 .3695 Mdot
.55 .36974 Mdot
.55 .37022 Mdot
.55 .37147 Mdot
.55 .37223 Mdot
.55 .37239 Mdot
.55 .37281 Mdot
.55 .37364 Mdot
.55 .37413 Mdot
.55 .37431 Mdot
.55 .37483 Mdot
.55 .37527 Mdot
.55 .37555 Mdot
.55 .37588 Mdot
.55 .37666 Mdot
.55 .37711 Mdot
.55 .37717 Mdot
.55 .37972 Mdot
.55 .37984 Mdot
.55 .38038 Mdot
.55 .38068 Mdot
.55 .38069 Mdot
.55 .38079 Mdot
.55 .38084 Mdot
.55 .38085 Mdot
.55 .3812 Mdot
.55 .3816 Mdot
.55 .38163 Mdot
.55 .38164 Mdot
.55 .38174 Mdot
.55 .3826 Mdot
.55 .38316 Mdot
.55 .38351 Mdot
.55 .38459 Mdot
.55 .38461 Mdot
.55 .38497 Mdot
.55 .38624 Mdot
.55 .38656 Mdot
.55 .38658 Mdot
.55 .38691 Mdot
.55 .3874 Mdot
.55 .38742 Mdot
.55 .38802 Mdot
.55 .38849 Mdot
.55 .38945 Mdot
.55 .38981 Mdot
.55 .38988 Mdot
.55 .38989 Mdot
.55 .39036 Mdot
.55 .3904 Mdot
.55 .39054 Mdot
.55 .39095 Mdot
.55 .39098 Mdot
.55 .39102 Mdot
.55 .3912 Mdot
.55 .39138 Mdot
.55 .39223 Mdot
.55 .39304 Mdot
.55 .39312 Mdot
.55 .39354 Mdot
.55 .39517 Mdot
.55 .39542 Mdot
.55 .39579 Mdot
.55 .39663 Mdot
.55 .39677 Mdot
.55 .39677 Mdot
.55 .39725 Mdot
.55 .39741 Mdot
.55 .39749 Mdot
.55 .39764 Mdot
.55 .39764 Mdot
.55 .39795 Mdot
.55 .3992 Mdot
.55 .39921 Mdot
.55 .39922 Mdot
.55 .39956 Mdot
.55 .4 Mdot
.55 .4 Mdot
.55 .4001 Mdot
.55 .40017 Mdot
.55 .40017 Mdot
.55 .40056 Mdot
.55 .40056 Mdot
.55 .40083 Mdot
.55 .4011 Mdot
.55 .40118 Mdot
.55 .40124 Mdot
.55 .40132 Mdot
.55 .40141 Mdot
.55 .40186 Mdot
.55 .40187 Mdot
.55 .40194 Mdot
.55 .40206 Mdot
.55 .40212 Mdot
.55 .40216 Mdot
.55 .40231 Mdot
.55 .40234 Mdot
.55 .40241 Mdot
.55 .4026 Mdot
.55 .40262 Mdot
.55 .40274 Mdot
.55 .40292 Mdot
.55 .40299 Mdot
.55 .40302 Mdot
.55 .40339 Mdot
.55 .40341 Mdot
.55 .40344 Mdot
.55 .40362 Mdot
.55 .40367 Mdot
.55 .40367 Mdot
.55 .46302 Mdot
.55 .46302 Mdot
.55 .46305 Mdot
.55 .46314 Mdot
.55 .46316 Mdot
.55 .46317 Mdot
.55 .46336 Mdot
.55 .46338 Mdot
.55 .46342 Mdot
.55 .46351 Mdot
.55 .46357 Mdot
.55 .46358 Mdot
.55 .46368 Mdot
.55 .46372 Mdot
.55 .46374 Mdot
.55 .46381 Mdot
.55 .46384 Mdot
.55 .46386 Mdot
.55 .46393 Mdot
.55 .46397 Mdot
.55 .46397 Mdot
.55 .4642 Mdot
.55 .46425 Mdot
.55 .46429 Mdot
.55 .46432 Mdot
.55 .46436 Mdot
.55 .46451 Mdot
.55 .46465 Mdot
.55 .46465 Mdot
.55 .46485 Mdot
.55 .46485 Mdot
.55 .46488 Mdot
.55 .46494 Mdot
.55 .46494 Mdot
.55 .46517 Mdot
.55 .46534 Mdot
.55 .46535 Mdot
.55 .46535 Mdot
.55 .466 Mdot
.55 .46616 Mdot
.55 .46616 Mdot
.55 .46624 Mdot
.55 .46628 Mdot
.55 .46636 Mdot
.55 .4666 Mdot
.55 .4666 Mdot
.55 .46668 Mdot
.55 .46711 Mdot
.55 .46729 Mdot
.55 .46742 Mdot
.55 .46825 Mdot
.55 .46846 Mdot
.55 .46851 Mdot
.55 .46892 Mdot
.55 .46935 Mdot
.55 .46943 Mdot
.55 .46953 Mdot
.55 .46954 Mdot
.55 .46956 Mdot
.55 .46977 Mdot
.55 .46984 Mdot
.55 .46986 Mdot
.55 .4701 Mdot
.55 .4701 Mdot
.55 .47014 Mdot
.55 .47031 Mdot
.55 .4708 Mdot
.55 .47103 Mdot
.55 .47133 Mdot
.55 .47134 Mdot
.55 .47158 Mdot
.55 .47175 Mdot
.55 .47176 Mdot
.55 .47192 Mdot
.55 .47255 Mdot
.55 .47273 Mdot
.55 .47274 Mdot
.55 .47327 Mdot
.55 .47344 Mdot
.55 .47371 Mdot
.55 .47414 Mdot
.55 .47418 Mdot
.55 .47419 Mdot
.55 .4742 Mdot
.55 .4744 Mdot
.55 .47457 Mdot
.55 .47457 Mdot
.55 .4746 Mdot
.55 .47465 Mdot
.55 .47465 Mdot
.55 .4748 Mdot
.55 .47506 Mdot
.55 .47512 Mdot
.55 .47636 Mdot
.55 .47639 Mdot
.55 .4766 Mdot
.55 .47698 Mdot
.55 .47714 Mdot
.55 .47727 Mdot
.55 .47748 Mdot
.55 .47773 Mdot
.55 .47782 Mdot
.55 .47805 Mdot
.55 .47845 Mdot
.55 .47865 Mdot
.55 .47873 Mdot
.55 .47909 Mdot
.55 .47968 Mdot
.55 .47991 Mdot
.55 .48002 Mdot
.55 .48003 Mdot
.55 .48055 Mdot
.55 .48126 Mdot
.55 .48133 Mdot
.55 .48144 Mdot
.55 .48145 Mdot
.55 .48208 Mdot
.55 .48223 Mdot
.55 .48224 Mdot
.55 .48258 Mdot
.55 .48287 Mdot
.55 .4829 Mdot
.55 .483 Mdot
.55 .48423 Mdot
.55 .48534 Mdot
.55 .48534 Mdot
.55 .48552 Mdot
.55 .48583 Mdot
.55 .48586 Mdot
.55 .48609 Mdot
.55 .48673 Mdot
.55 .4868 Mdot
.55 .48856 Mdot
.55 .48896 Mdot
.55 .49494 Mdot
.55 .49494 Mdot
.55 .49499 Mdot
.55 .49521 Mdot
.55 .49521 Mdot
.55 .49525 Mdot
.55 .49527 Mdot
.55 .4957 Mdot
.55 .49574 Mdot
.55 .49582 Mdot
.55 .49603 Mdot
.55 .49616 Mdot
.55 .49619 Mdot
.55 .4964 Mdot
.55 .49649 Mdot
.55 .49652 Mdot
.55 .49669 Mdot
.55 .49674 Mdot
.55 .4968 Mdot
.55 .49695 Mdot
.55 .49703 Mdot
.55 .49704 Mdot
.55 .49752 Mdot
.55 .49755 Mdot
.55 .49765 Mdot
.55 .49775 Mdot
.55 .49775 Mdot
.55 .49782 Mdot
.55 .4979 Mdot
.55 .49822 Mdot
.55 .49852 Mdot
.55 .49853 Mdot
.55 .49896 Mdot
.55 .49896 Mdot
.55 .49904 Mdot
.55 .49915 Mdot
.55 .49916 Mdot
.55 .4993 Mdot
.55 .49965 Mdot
.55 .50003 Mdot
.55 .50004 Mdot
.55 .50004 Mdot
.55 .50132 Mdot
.55 .50144 Mdot
.55 .50177 Mdot
.55 .50177 Mdot
.55 .50194 Mdot
.55 .502 Mdot
.55 .50203 Mdot
.55 .50209 Mdot
.55 .5022 Mdot
.55 .50272 Mdot
.55 .50272 Mdot
.55 .50288 Mdot
.55 .50313 Mdot
.55 .5035 Mdot
.55 .50373 Mdot
.55 .50378 Mdot
.55 .50412 Mdot
.55 .50413 Mdot
.55 .50418 Mdot
.55 .50445 Mdot
.55 .50447 Mdot
.55 .50469 Mdot
.55 .50481 Mdot
.55 .5051 Mdot
.55 .50563 Mdot
.55 .50617 Mdot
.55 .5066 Mdot
.55 .50669 Mdot
.55 .50742 Mdot
.55 .50752 Mdot
.55 .50805 Mdot
.55 .50812 Mdot
.55 .5084 Mdot
.55 .50857 Mdot
.55 .50876 Mdot
.55 .5088 Mdot
.55 .50883 Mdot
.55 .50925 Mdot
.55 .50938 Mdot
.55 .50943 Mdot
.55 .50971 Mdot
.55 .50972 Mdot
.55 .5099 Mdot
.55 .5099 Mdot
.55 .50998 Mdot
.55 .50998 Mdot
.55 .51033 Mdot
.55 .51094 Mdot
.55 .51128 Mdot
.55 .51175 Mdot
.55 .51222 Mdot
.55 .51233 Mdot
.55 .51235 Mdot
.55 .51256 Mdot
.55 .51278 Mdot
.55 .51282 Mdot
.55 .51299 Mdot
.55 .51303 Mdot
.55 .51314 Mdot
.55 .51314 Mdot
.55 .51316 Mdot
.55 .51346 Mdot
.55 .51395 Mdot
.55 .51421 Mdot
.55 .5145 Mdot
.55 .51467 Mdot
.55 .51484 Mdot
.55 .51485 Mdot
.55 .51486 Mdot
.55 .51501 Mdot
.55 .51503 Mdot
.55 .51503 Mdot
.55 .51603 Mdot
.55 .51635 Mdot
.55 .51686 Mdot
.55 .51702 Mdot
.55 .51764 Mdot
.55 .51773 Mdot
.55 .51773 Mdot
.55 .51777 Mdot
.55 .51812 Mdot
.55 .51844 Mdot
.55 .51844 Mdot
.55 .51849 Mdot
.55 .51858 Mdot
.55 .51858 Mdot
.55 .51865 Mdot
.55 .51883 Mdot
.55 .51885 Mdot
.55 .51932 Mdot
.55 .51943 Mdot
.55 .52104 Mdot
.55 .52162 Mdot
.55 .52167 Mdot
.55 .52205 Mdot
.55 .52253 Mdot
.55 .5227 Mdot
.55 .52276 Mdot
.55 .52297 Mdot
.55 .52311 Mdot
.55 .5232 Mdot
.55 .5232 Mdot
.55 .52328 Mdot
.55 .52334 Mdot
.55 .52336 Mdot
.55 .52343 Mdot
.55 .52356 Mdot
.55 .52398 Mdot
.55 .52413 Mdot
.55 .52414 Mdot
.55 .52452 Mdot
.55 .5248 Mdot
.55 .52518 Mdot
.55 .52523 Mdot
.55 .52528 Mdot
.55 .5255 Mdot
.55 .52563 Mdot
.55 .52572 Mdot
.55 .52576 Mdot
.55 .52623 Mdot
.55 .52665 Mdot
.55 .52718 Mdot
.55 .52754 Mdot
.55 .52772 Mdot
.55 .52773 Mdot
.55 .52774 Mdot
.55 .52776 Mdot
.55 .52809 Mdot
.55 .52832 Mdot
.55 .52855 Mdot
.55 .52964 Mdot
.55 .52975 Mdot
.55 .52992 Mdot
.55 .52992 Mdot
.55 .53045 Mdot
.55 .53087 Mdot
.55 .53089 Mdot
.55 .53109 Mdot
.55 .53112 Mdot
.55 .53132 Mdot
.55 .53161 Mdot
.55 .53193 Mdot
.55 .53196 Mdot
.55 .53198 Mdot
.55 .532 Mdot
.55 .53203 Mdot
.55 .53208 Mdot
.55 .53223 Mdot
.55 .53233 Mdot
.55 .53297 Mdot
.55 .53389 Mdot
.55 .53396 Mdot
.55 .53461 Mdot
.55 .53539 Mdot
.55 .53545 Mdot
.55 .53545 Mdot
.55 .53546 Mdot
.55 .53559 Mdot
.55 .5357 Mdot
.55 .5358 Mdot
.55 .5361 Mdot
.55 .53614 Mdot
.55 .53616 Mdot
.55 .53623 Mdot
.55 .53631 Mdot
.55 .53644 Mdot
.55 .5369 Mdot
.55 .53724 Mdot
.55 .53734 Mdot
.55 .53734 Mdot
.55 .5379 Mdot
.55 .53792 Mdot
.55 .53814 Mdot
.55 .53874 Mdot
.55 .53892 Mdot
.55 .53902 Mdot
.55 .53906 Mdot
.55 .53913 Mdot
.55 .53924 Mdot
.55 .53924 Mdot
.55 .53937 Mdot
.55 .53945 Mdot
.55 .53957 Mdot
.55 .5399 Mdot
.55 .53993 Mdot
.55 .54015 Mdot
.55 .54078 Mdot
.55 .54126 Mdot
.55 .54133 Mdot
.55 .54202 Mdot
.55 .54382 Mdot
.55 .54394 Mdot
.55 .54442 Mdot
.55 .54444 Mdot
.55 .54461 Mdot
.55 .54468 Mdot
.55 .54469 Mdot
.55 .54477 Mdot
.55 .54482 Mdot
.55 .54482 Mdot
.55 .54512 Mdot
.55 .54544 Mdot
.55 .54547 Mdot
.55 .54548 Mdot
.55 .54556 Mdot
.55 .54565 Mdot
.55 .54565 Mdot
.55 .54569 Mdot
.55 .54585 Mdot
.55 .54586 Mdot
.55 .54588 Mdot
.55 .5459 Mdot
.55 .54609 Mdot
.55 .54622 Mdot
.55 .54622 Mdot
.55 .54625 Mdot
.55 .54631 Mdot
.55 .54646 Mdot
.55 .54656 Mdot
.55 .54658 Mdot
.55 .54663 Mdot
.55 .54673 Mdot
.55 .54679 Mdot
.55 .54681 Mdot
.55 .54687 Mdot
.55 .54693 Mdot
.55 .54696 Mdot
.55 .547 Mdot
.55 .5471 Mdot
.55 .54715 Mdot
.55 .54716 Mdot
.55 .54747 Mdot
.55 .54748 Mdot
.55 .54755 Mdot
.55 .54758 Mdot
.55 .54758 Mdot
.55 .5476 Mdot
.55 .5476 Mdot
.55 .5476 Mdot
.55 .54765 Mdot
.55 .54769 Mdot
.55 .5477 Mdot
.55 .5477 Mdot
.55 .54771 Mdot
.55 .54781 Mdot
.55 .54788 Mdot
.55 .54792 Mdot
.55 .54805 Mdot
.55 .54806 Mdot
.55 .5481 Mdot
.55 .54825 Mdot
.55 .54829 Mdot
.55 .54829 Mdot
.55 .54833 Mdot
.55 .54839 Mdot
.55 .5484 Mdot
.55 .54847 Mdot
.55 .54852 Mdot
.55 .54864 Mdot
.55 .54868 Mdot
.55 .54869 Mdot
.55 .54869 Mdot
.55 .54875 Mdot
.55 .54875 Mdot
.55 .54877 Mdot
.55 .54882 Mdot
.55 .54882 Mdot
.55 .54883 Mdot
.55 .54885 Mdot
.55 .54887 Mdot
.55 .54897 Mdot
.55 .54907 Mdot
.55 .54908 Mdot
.55 .54913 Mdot
.55 .54933 Mdot
.55 .54936 Mdot
.55 .5494 Mdot
.55 .5495 Mdot
.55 .54952 Mdot
.55 .54952 Mdot
.55 .54958 Mdot
.55 .54959 Mdot
.55 .5496 Mdot
.55 .54962 Mdot
.55 .54962 Mdot
.55 .54966 Mdot
.55 .54981 Mdot
.55 .54981 Mdot
.55 .54981 Mdot
.55 .54985 Mdot
.55 .5499 Mdot
.55 .54991 Mdot
.55 .54992 Mdot
.55 .54993 Mdot
.55 .54993 Mdot
.55 .54997 Mdot
.55 .54997 Mdot
.55 .55 Mdot
.55 .55004 Mdot
.55 .55005 Mdot
.55 .55005 Mdot
.55 .55006 Mdot
.55 .55007 Mdot
.55 .55013 Mdot
.55 .55013 Mdot
.55 .55014 Mdot
.55 .55015 Mdot
.55 .55016 Mdot
.55 .55016 Mdot
.55 .55018 Mdot
.55 .55018 Mdot
.55 .55019 Mdot
.55 .55022 Mdot
.55 .55022 Mdot
.55 .55023 Mdot
.55 .55025 Mdot
.55 .55026 Mdot
.55 .55027 Mdot
.55 .55031 Mdot
.55 .55031 Mdot
.55 .55032 Mdot
.55 .55034 Mdot
.55 .55034 Mdot
.55 .55034 Mdot
.552 .18956 Mdot
.552 .18956 Mdot
.552 .18956 Mdot
.552 .18957 Mdot
.552 .1896 Mdot
.552 .1896 Mdot
.552 .18962 Mdot
.552 .18976 Mdot
.552 .18979 Mdot
.552 .18983 Mdot
.552 .19 Mdot
.552 .19002 Mdot
.552 .19011 Mdot
.552 .19031 Mdot
.552 .19033 Mdot
.552 .19033 Mdot
.552 .19047 Mdot
.552 .19049 Mdot
.552 .1905 Mdot
.552 .19057 Mdot
.552 .19059 Mdot
.552 .19078 Mdot
.552 .19079 Mdot
.552 .19097 Mdot
.552 .19099 Mdot
.552 .19105 Mdot
.552 .19112 Mdot
.552 .19115 Mdot
.552 .19119 Mdot
.552 .19125 Mdot
.552 .19126 Mdot
.552 .19129 Mdot
.552 .19134 Mdot
.552 .19135 Mdot
.552 .19146 Mdot
.552 .19148 Mdot
.552 .19149 Mdot
.552 .19171 Mdot
.552 .19183 Mdot
.552 .19197 Mdot
.552 .19206 Mdot
.552 .19209 Mdot
.552 .19216 Mdot
.552 .19217 Mdot
.552 .19219 Mdot
.552 .19231 Mdot
.552 .1924 Mdot
.552 .19252 Mdot
.552 .1926 Mdot
.552 .19282 Mdot
.552 .19283 Mdot
.552 .19313 Mdot
.552 .19335 Mdot
.552 .19376 Mdot
.552 .19376 Mdot
.552 .19385 Mdot
.552 .19391 Mdot
.552 .19433 Mdot
.552 .1945 Mdot
.552 .19481 Mdot
.552 .19484 Mdot
.552 .19495 Mdot
.552 .1951 Mdot
.552 .19513 Mdot
.552 .19519 Mdot
.552 .19548 Mdot
.552 .19553 Mdot
.552 .19562 Mdot
.552 .19578 Mdot
.552 .19595 Mdot
.552 .19599 Mdot
.552 .19609 Mdot
.552 .19628 Mdot
.552 .1965 Mdot
.552 .19668 Mdot
.552 .19693 Mdot
.552 .19698 Mdot
.552 .19707 Mdot
.552 .1971 Mdot
.552 .19739 Mdot
.552 .19751 Mdot
.552 .19756 Mdot
.552 .19828 Mdot
.552 .1985 Mdot
.552 .19855 Mdot
.552 .1986 Mdot
.552 .19874 Mdot
.552 .19901 Mdot
.552 .19919 Mdot
.552 .1997 Mdot
.552 .1998 Mdot
.552 .19995 Mdot
.552 .20003 Mdot
.552 .20006 Mdot
.552 .20037 Mdot
.552 .2005 Mdot
.552 .20058 Mdot
.552 .2008 Mdot
.552 .20084 Mdot
.552 .20091 Mdot
.552 .20143 Mdot
.552 .20154 Mdot
.552 .20159 Mdot
.552 .2016 Mdot
.552 .20167 Mdot
.552 .2019 Mdot
.552 .202 Mdot
.552 .20253 Mdot
.552 .20316 Mdot
.552 .20358 Mdot
.552 .20371 Mdot
.552 .20384 Mdot
.552 .20385 Mdot
.552 .20395 Mdot
.552 .20401 Mdot
.552 .20478 Mdot
.552 .20537 Mdot
.552 .20566 Mdot
.552 .20568 Mdot
.552 .20583 Mdot
.552 .20593 Mdot
.552 .20668 Mdot
.552 .20708 Mdot
.552 .20723 Mdot
.552 .20727 Mdot
.552 .20742 Mdot
.552 .20748 Mdot
.552 .20757 Mdot
.552 .20757 Mdot
.552 .20758 Mdot
.552 .20832 Mdot
.552 .20866 Mdot
.552 .20905 Mdot
.552 .20919 Mdot
.552 .21014 Mdot
.552 .21053 Mdot
.552 .21189 Mdot
.552 .2123 Mdot
.552 .21376 Mdot
.552 .21502 Mdot
.552 .21528 Mdot
.552 .21574 Mdot
.552 .21673 Mdot
.552 .21804 Mdot
.552 .21891 Mdot
.552 .22022 Mdot
.552 .22042 Mdot
.552 .221 Mdot
.552 .22101 Mdot
.552 .22124 Mdot
.552 .22259 Mdot
.552 .22402 Mdot
.552 .22413 Mdot
.552 .22527 Mdot
.552 .22611 Mdot
.552 .22724 Mdot
.552 .22726 Mdot
.552 .22727 Mdot
.552 .22768 Mdot
.552 .22795 Mdot
.552 .22821 Mdot
.552 .22856 Mdot
.552 .22862 Mdot
.552 .22878 Mdot
.552 .22878 Mdot
.552 .22927 Mdot
.552 .22947 Mdot
.552 .23003 Mdot
.552 .23129 Mdot
.552 .23175 Mdot
.552 .23202 Mdot
.552 .2328 Mdot
.552 .23377 Mdot
.552 .23442 Mdot
.552 .23443 Mdot
.552 .23484 Mdot
.552 .23534 Mdot
.552 .23558 Mdot
.552 .23603 Mdot
.552 .23609 Mdot
.552 .23614 Mdot
.552 .23619 Mdot
.552 .2369 Mdot
.552 .23696 Mdot
.552 .23759 Mdot
.552 .23924 Mdot
.552 .24031 Mdot
.552 .24055 Mdot
.552 .24456 Mdot
.552 .24491 Mdot
.552 .2454 Mdot
.552 .24548 Mdot
.552 .2457 Mdot
.552 .24597 Mdot
.552 .24615 Mdot
.552 .24684 Mdot
.552 .24916 Mdot
.552 .25263 Mdot
.552 .25277 Mdot
.552 .25565 Mdot
.552 .25624 Mdot
.552 .2575 Mdot
.552 .25754 Mdot
.552 .25797 Mdot
.552 .25803 Mdot
.552 .25829 Mdot
.552 .25895 Mdot
.552 .25895 Mdot
.552 .25933 Mdot
.552 .2599 Mdot
.552 .26036 Mdot
.552 .26052 Mdot
.552 .26155 Mdot
.552 .26201 Mdot
.552 .2623 Mdot
.552 .26244 Mdot
.552 .26266 Mdot
.552 .26397 Mdot
.552 .2645 Mdot
.552 .26524 Mdot
.552 .26715 Mdot
.552 .26731 Mdot
.552 .26785 Mdot
.552 .26876 Mdot
.552 .26937 Mdot
.552 .27103 Mdot
.552 .27157 Mdot
.552 .27253 Mdot
.552 .27367 Mdot
.552 .27399 Mdot
.552 .27541 Mdot
.552 .27633 Mdot
.552 .27666 Mdot
.552 .27695 Mdot
.552 .27775 Mdot
.552 .2784 Mdot
.552 .27918 Mdot
.552 .27933 Mdot
.552 .28098 Mdot
.552 .28109 Mdot
.552 .28121 Mdot
.552 .28134 Mdot
.552 .28241 Mdot
.552 .28297 Mdot
.552 .28308 Mdot
.552 .28341 Mdot
.552 .28414 Mdot
.552 .28422 Mdot
.552 .2851 Mdot
.552 .28513 Mdot
.552 .28611 Mdot
.552 .28633 Mdot
.552 .28666 Mdot
.552 .28696 Mdot
.552 .28724 Mdot
.552 .28894 Mdot
.552 .289 Mdot
.552 .29018 Mdot
.552 .29088 Mdot
.552 .29153 Mdot
.552 .29168 Mdot
.552 .29265 Mdot
.552 .29293 Mdot
.552 .29365 Mdot
.552 .29392 Mdot
.552 .29511 Mdot
.552 .29572 Mdot
.552 .29619 Mdot
.552 .2968 Mdot
.552 .29708 Mdot
.552 .29713 Mdot
.552 .29758 Mdot
.552 .29879 Mdot
.552 .29881 Mdot
.552 .29917 Mdot
.552 .2992 Mdot
.552 .29934 Mdot
.552 .29961 Mdot
.552 .29984 Mdot
.552 .30022 Mdot
.552 .30085 Mdot
.552 .30088 Mdot
.552 .30155 Mdot
.552 .30163 Mdot
.552 .30187 Mdot
.552 .30255 Mdot
.552 .30258 Mdot
.552 .30263 Mdot
.552 .30404 Mdot
.552 .30523 Mdot
.552 .30549 Mdot
.552 .3076 Mdot
.552 .30819 Mdot
.552 .30868 Mdot
.552 .30928 Mdot
.552 .30933 Mdot
.552 .31051 Mdot
.552 .31081 Mdot
.552 .31227 Mdot
.552 .31388 Mdot
.552 .31447 Mdot
.552 .31604 Mdot
.552 .31609 Mdot
.552 .31774 Mdot
.552 .31798 Mdot
.552 .3183 Mdot
.552 .31858 Mdot
.552 .3186 Mdot
.552 .31916 Mdot
.552 .31981 Mdot
.552 .32012 Mdot
.552 .32065 Mdot
.552 .32073 Mdot
.552 .32088 Mdot
.552 .32142 Mdot
.552 .32168 Mdot
.552 .32233 Mdot
.552 .32335 Mdot
.552 .3241 Mdot
.552 .32426 Mdot
.552 .32589 Mdot
.552 .32594 Mdot
.552 .32611 Mdot
.552 .3264 Mdot
.552 .32695 Mdot
.552 .32702 Mdot
.552 .32739 Mdot
.552 .32765 Mdot
.552 .3277 Mdot
.552 .32812 Mdot
.552 .32843 Mdot
.552 .32869 Mdot
.552 .32922 Mdot
.552 .32964 Mdot
.552 .32981 Mdot
.552 .32987 Mdot
.552 .33113 Mdot
.552 .33119 Mdot
.552 .33252 Mdot
.552 .33263 Mdot
.552 .3328 Mdot
.552 .33329 Mdot
.552 .33343 Mdot
.552 .33353 Mdot
.552 .33377 Mdot
.552 .33446 Mdot
.552 .33458 Mdot
.552 .33464 Mdot
.552 .33472 Mdot
.552 .33626 Mdot
.552 .33696 Mdot
.552 .33711 Mdot
.552 .33786 Mdot
.552 .33842 Mdot
.552 .33869 Mdot
.552 .33895 Mdot
.552 .33999 Mdot
.552 .34012 Mdot
.552 .34016 Mdot
.552 .34034 Mdot
.552 .34042 Mdot
.552 .34042 Mdot
.552 .34043 Mdot
.552 .34183 Mdot
.552 .34294 Mdot
.552 .34665 Mdot
.552 .34772 Mdot
.552 .35032 Mdot
.552 .35072 Mdot
.552 .35178 Mdot
.552 .35272 Mdot
.552 .35478 Mdot
.552 .35479 Mdot
.552 .3548 Mdot
.552 .35504 Mdot
.552 .35522 Mdot
.552 .35563 Mdot
.552 .35572 Mdot
.552 .35615 Mdot
.552 .35724 Mdot
.552 .35932 Mdot
.552 .35961 Mdot
.552 .36003 Mdot
.552 .36009 Mdot
.552 .36088 Mdot
.552 .36252 Mdot
.552 .36467 Mdot
.552 .36485 Mdot
.552 .36511 Mdot
.552 .36515 Mdot
.552 .3655 Mdot
.552 .36586 Mdot
.552 .36705 Mdot
.552 .3688 Mdot
.552 .37029 Mdot
.552 .37058 Mdot
.552 .37121 Mdot
.552 .37141 Mdot
.552 .37144 Mdot
.552 .37157 Mdot
.552 .37188 Mdot
.552 .37333 Mdot
.552 .37354 Mdot
.552 .37364 Mdot
.552 .37425 Mdot
.552 .3745 Mdot
.552 .37484 Mdot
.552 .37572 Mdot
.552 .37579 Mdot
.552 .37604 Mdot
.552 .37645 Mdot
.552 .37673 Mdot
.552 .37815 Mdot
.552 .37865 Mdot
.552 .37942 Mdot
.552 .37983 Mdot
.552 .37997 Mdot
.552 .3801 Mdot
.552 .38073 Mdot
.552 .38274 Mdot
.552 .38288 Mdot
.552 .38323 Mdot
.552 .38403 Mdot
.552 .38412 Mdot
.552 .38438 Mdot
.552 .3845 Mdot
.552 .38521 Mdot
.552 .38573 Mdot
.552 .38635 Mdot
.552 .38686 Mdot
.552 .38716 Mdot
.552 .38727 Mdot
.552 .38776 Mdot
.552 .3882 Mdot
.552 .38844 Mdot
.552 .38858 Mdot
.552 .3894 Mdot
.552 .38958 Mdot
.552 .38967 Mdot
.552 .39009 Mdot
.552 .39039 Mdot
.552 .39049 Mdot
.552 .39135 Mdot
.552 .39182 Mdot
.552 .39299 Mdot
.552 .39318 Mdot
.552 .39342 Mdot
.552 .39344 Mdot
.552 .39459 Mdot
.552 .39521 Mdot
.552 .39605 Mdot
.552 .39607 Mdot
.552 .3967 Mdot
.552 .39691 Mdot
.552 .39725 Mdot
.552 .39749 Mdot
.552 .39785 Mdot
.552 .3979 Mdot
.552 .39793 Mdot
.552 .39811 Mdot
.552 .39821 Mdot
.552 .39845 Mdot
.552 .39884 Mdot
.552 .39919 Mdot
.552 .3998 Mdot
.552 .39982 Mdot
.552 .39989 Mdot
.552 .4002 Mdot
.552 .40023 Mdot
.552 .40037 Mdot
.552 .40046 Mdot
.552 .40049 Mdot
.552 .40064 Mdot
.552 .40076 Mdot
.552 .40086 Mdot
.552 .40106 Mdot
.552 .40121 Mdot
.552 .40128 Mdot
.552 .40177 Mdot
.552 .40179 Mdot
.552 .40233 Mdot
.552 .40239 Mdot
.552 .40258 Mdot
.552 .40263 Mdot
.552 .40266 Mdot
.552 .40306 Mdot
.552 .40308 Mdot
.552 .40311 Mdot
.552 .40368 Mdot
.552 .40394 Mdot
.552 .404 Mdot
.552 .40448 Mdot
.552 .40458 Mdot
.552 .40467 Mdot
.552 .40506 Mdot
.552 .40511 Mdot
.552 .40512 Mdot
.552 .40519 Mdot
.552 .40522 Mdot
.552 .40522 Mdot
.552 .40522 Mdot
.552 .4623 Mdot
.552 .4623 Mdot
.552 .4623 Mdot
.552 .46231 Mdot
.552 .46235 Mdot
.552 .46236 Mdot
.552 .46238 Mdot
.552 .46259 Mdot
.552 .46264 Mdot
.552 .46269 Mdot
.552 .46294 Mdot
.552 .46297 Mdot
.552 .46311 Mdot
.552 .46341 Mdot
.552 .46342 Mdot
.552 .46343 Mdot
.552 .46364 Mdot
.552 .46366 Mdot
.552 .46368 Mdot
.552 .46378 Mdot
.552 .46381 Mdot
.552 .46409 Mdot
.552 .46411 Mdot
.552 .46436 Mdot
.552 .4644 Mdot
.552 .46448 Mdot
.552 .46458 Mdot
.552 .46463 Mdot
.552 .46469 Mdot
.552 .46477 Mdot
.552 .46479 Mdot
.552 .46484 Mdot
.552 .46491 Mdot
.552 .46492 Mdot
.552 .46508 Mdot
.552 .46512 Mdot
.552 .46513 Mdot
.552 .46545 Mdot
.552 .46563 Mdot
.552 .46583 Mdot
.552 .46595 Mdot
.552 .466 Mdot
.552 .4661 Mdot
.552 .46611 Mdot
.552 .46614 Mdot
.552 .46632 Mdot
.552 .46645 Mdot
.552 .46662 Mdot
.552 .46672 Mdot
.552 .46705 Mdot
.552 .46706 Mdot
.552 .46749 Mdot
.552 .4678 Mdot
.552 .46839 Mdot
.552 .4684 Mdot
.552 .46852 Mdot
.552 .46861 Mdot
.552 .46921 Mdot
.552 .46944 Mdot
.552 .46988 Mdot
.552 .46993 Mdot
.552 .47008 Mdot
.552 .47029 Mdot
.552 .47033 Mdot
.552 .47042 Mdot
.552 .47083 Mdot
.552 .4709 Mdot
.552 .47102 Mdot
.552 .47124 Mdot
.552 .47149 Mdot
.552 .47154 Mdot
.552 .47169 Mdot
.552 .47194 Mdot
.552 .47225 Mdot
.552 .47251 Mdot
.552 .47286 Mdot
.552 .47292 Mdot
.552 .47305 Mdot
.552 .47309 Mdot
.552 .47348 Mdot
.552 .47365 Mdot
.552 .47372 Mdot
.552 .47471 Mdot
.552 .47501 Mdot
.552 .47508 Mdot
.552 .47515 Mdot
.552 .47534 Mdot
.552 .47572 Mdot
.552 .47596 Mdot
.552 .47665 Mdot
.552 .47678 Mdot
.552 .47698 Mdot
.552 .4771 Mdot
.552 .47713 Mdot
.552 .47756 Mdot
.552 .47772 Mdot
.552 .47784 Mdot
.552 .47813 Mdot
.552 .47818 Mdot
.552 .47828 Mdot
.552 .47897 Mdot
.552 .47912 Mdot
.552 .47918 Mdot
.552 .47919 Mdot
.552 .47929 Mdot
.552 .47959 Mdot
.552 .47972 Mdot
.552 .48043 Mdot
.552 .48125 Mdot
.552 .48181 Mdot
.552 .48198 Mdot
.552 .48214 Mdot
.552 .48216 Mdot
.552 .48228 Mdot
.552 .48237 Mdot
.552 .48336 Mdot
.552 .48412 Mdot
.552 .48449 Mdot
.552 .48451 Mdot
.552 .48471 Mdot
.552 .48484 Mdot
.552 .48579 Mdot
.552 .48629 Mdot
.552 .48649 Mdot
.552 .48653 Mdot
.552 .48672 Mdot
.552 .48679 Mdot
.552 .48691 Mdot
.552 .48691 Mdot
.552 .48692 Mdot
.552 .48785 Mdot
.552 .48827 Mdot
.552 .48875 Mdot
.552 .48893 Mdot
.552 .49009 Mdot
.552 .49057 Mdot
.552 .49221 Mdot
.552 .49271 Mdot
.552 .49332 Mdot
.552 .49332 Mdot
.552 .49332 Mdot
.552 .49336 Mdot
.552 .49344 Mdot
.552 .49345 Mdot
.552 .49351 Mdot
.552 .49397 Mdot
.552 .49408 Mdot
.552 .4942 Mdot
.552 .49444 Mdot
.552 .49477 Mdot
.552 .49483 Mdot
.552 .49514 Mdot
.552 .49581 Mdot
.552 .49584 Mdot
.552 .49587 Mdot
.552 .49592 Mdot
.552 .49622 Mdot
.552 .49632 Mdot
.552 .49636 Mdot
.552 .49642 Mdot
.552 .49663 Mdot
.552 .49671 Mdot
.552 .49676 Mdot
.552 .49733 Mdot
.552 .49735 Mdot
.552 .49789 Mdot
.552 .49792 Mdot
.552 .49799 Mdot
.552 .49817 Mdot
.552 .4984 Mdot
.552 .49851 Mdot
.552 .49864 Mdot
.552 .49882 Mdot
.552 .49884 Mdot
.552 .49895 Mdot
.552 .49911 Mdot
.552 .49914 Mdot
.552 .49937 Mdot
.552 .49949 Mdot
.552 .49957 Mdot
.552 .49959 Mdot
.552 .50028 Mdot
.552 .50034 Mdot
.552 .50066 Mdot
.552 .50109 Mdot
.552 .50136 Mdot
.552 .50147 Mdot
.552 .5017 Mdot
.552 .50176 Mdot
.552 .5018 Mdot
.552 .50202 Mdot
.552 .50215 Mdot
.552 .50242 Mdot
.552 .50265 Mdot
.552 .50266 Mdot
.552 .50278 Mdot
.552 .50291 Mdot
.552 .50301 Mdot
.552 .5037 Mdot
.552 .50372 Mdot
.552 .50437 Mdot
.552 .50461 Mdot
.552 .50528 Mdot
.552 .50588 Mdot
.552 .506 Mdot
.552 .50649 Mdot
.552 .5065 Mdot
.552 .50675 Mdot
.552 .50695 Mdot
.552 .50719 Mdot
.552 .50805 Mdot
.552 .50816 Mdot
.552 .50864 Mdot
.552 .50921 Mdot
.552 .50923 Mdot
.552 .50924 Mdot
.552 .50952 Mdot
.552 .50961 Mdot
.552 .50965 Mdot
.552 .50991 Mdot
.552 .50993 Mdot
.552 .51018 Mdot
.552 .51033 Mdot
.552 .51042 Mdot
.552 .51053 Mdot
.552 .51059 Mdot
.552 .5106 Mdot
.552 .51075 Mdot
.552 .51075 Mdot
.552 .51124 Mdot
.552 .51142 Mdot
.552 .51144 Mdot
.552 .51155 Mdot
.552 .51179 Mdot
.552 .51198 Mdot
.552 .51222 Mdot
.552 .5127 Mdot
.552 .5128 Mdot
.552 .51309 Mdot
.552 .5132 Mdot
.552 .51358 Mdot
.552 .51364 Mdot
.552 .5139 Mdot
.552 .51417 Mdot
.552 .51464 Mdot
.552 .51466 Mdot
.552 .51533 Mdot
.552 .51544 Mdot
.552 .51555 Mdot
.552 .51568 Mdot
.552 .51577 Mdot
.552 .51615 Mdot
.552 .51616 Mdot
.552 .51651 Mdot
.552 .51654 Mdot
.552 .51682 Mdot
.552 .51695 Mdot
.552 .517 Mdot
.552 .51721 Mdot
.552 .51763 Mdot
.552 .51768 Mdot
.552 .51772 Mdot
.552 .51776 Mdot
.552 .51841 Mdot
.552 .51846 Mdot
.552 .51876 Mdot
.552 .51901 Mdot
.552 .51932 Mdot
.552 .51943 Mdot
.552 .51956 Mdot
.552 .51991 Mdot
.552 .52045 Mdot
.552 .52058 Mdot
.552 .52101 Mdot
.552 .52138 Mdot
.552 .52158 Mdot
.552 .52221 Mdot
.552 .52244 Mdot
.552 .52279 Mdot
.552 .52299 Mdot
.552 .52305 Mdot
.552 .52377 Mdot
.552 .52405 Mdot
.552 .52425 Mdot
.552 .52474 Mdot
.552 .52482 Mdot
.552 .52488 Mdot
.552 .52499 Mdot
.552 .52516 Mdot
.552 .52554 Mdot
.552 .5256 Mdot
.552 .52577 Mdot
.552 .52599 Mdot
.552 .52613 Mdot
.552 .52613 Mdot
.552 .52637 Mdot
.552 .52647 Mdot
.552 .52649 Mdot
.552 .52665 Mdot
.552 .52667 Mdot
.552 .52714 Mdot
.552 .52735 Mdot
.552 .52842 Mdot
.552 .52847 Mdot
.552 .52974 Mdot
.552 .53059 Mdot
.552 .53084 Mdot
.552 .53091 Mdot
.552 .53101 Mdot
.552 .53109 Mdot
.552 .53111 Mdot
.552 .53129 Mdot
.552 .53142 Mdot
.552 .53287 Mdot
.552 .53296 Mdot
.552 .53335 Mdot
.552 .53394 Mdot
.552 .53416 Mdot
.552 .53419 Mdot
.552 .53444 Mdot
.552 .53446 Mdot
.552 .53448 Mdot
.552 .5345 Mdot
.552 .53466 Mdot
.552 .53475 Mdot
.552 .53492 Mdot
.552 .53507 Mdot
.552 .53507 Mdot
.552 .53531 Mdot
.552 .53565 Mdot
.552 .53593 Mdot
.552 .53603 Mdot
.552 .53619 Mdot
.552 .53664 Mdot
.552 .53684 Mdot
.552 .53691 Mdot
.552 .53708 Mdot
.552 .53708 Mdot
.552 .53714 Mdot
.552 .53716 Mdot
.552 .53728 Mdot
.552 .53737 Mdot
.552 .53747 Mdot
.552 .53761 Mdot
.552 .53762 Mdot
.552 .53763 Mdot
.552 .53803 Mdot
.552 .53832 Mdot
.552 .53872 Mdot
.552 .53876 Mdot
.552 .53926 Mdot
.552 .53974 Mdot
.552 .53982 Mdot
.552 .53982 Mdot
.552 .54002 Mdot
.552 .5401 Mdot
.552 .54055 Mdot
.552 .54086 Mdot
.552 .54131 Mdot
.552 .54166 Mdot
.552 .54182 Mdot
.552 .54191 Mdot
.552 .54234 Mdot
.552 .54285 Mdot
.552 .54299 Mdot
.552 .54346 Mdot
.552 .54359 Mdot
.552 .54392 Mdot
.552 .54397 Mdot
.552 .5441 Mdot
.552 .54422 Mdot
.552 .54448 Mdot
.552 .54448 Mdot
.552 .54448 Mdot
.552 .54451 Mdot
.552 .54453 Mdot
.552 .54458 Mdot
.552 .54459 Mdot
.552 .54465 Mdot
.552 .54478 Mdot
.552 .54504 Mdot
.552 .54507 Mdot
.552 .54513 Mdot
.552 .54513 Mdot
.552 .54523 Mdot
.552 .54543 Mdot
.552 .5457 Mdot
.552 .54572 Mdot
.552 .54575 Mdot
.552 .54575 Mdot
.552 .5458 Mdot
.552 .54584 Mdot
.552 .54599 Mdot
.552 .5462 Mdot
.552 .54638 Mdot
.552 .54642 Mdot
.552 .54649 Mdot
.552 .54652 Mdot
.552 .54652 Mdot
.552 .54654 Mdot
.552 .54658 Mdot
.552 .54675 Mdot
.552 .54678 Mdot
.552 .54679 Mdot
.552 .54686 Mdot
.552 .54689 Mdot
.552 .54693 Mdot
.552 .54704 Mdot
.552 .54705 Mdot
.552 .54708 Mdot
.552 .54713 Mdot
.552 .54716 Mdot
.552 .54734 Mdot
.552 .5474 Mdot
.552 .54749 Mdot
.552 .54754 Mdot
.552 .54756 Mdot
.552 .54757 Mdot
.552 .54765 Mdot
.552 .54789 Mdot
.552 .54791 Mdot
.552 .54795 Mdot
.552 .54805 Mdot
.552 .54809 Mdot
.552 .5481 Mdot
.552 .54819 Mdot
.552 .54825 Mdot
.552 .54832 Mdot
.552 .54838 Mdot
.552 .54842 Mdot
.552 .54843 Mdot
.552 .54849 Mdot
.552 .54854 Mdot
.552 .54857 Mdot
.552 .54859 Mdot
.552 .54869 Mdot
.552 .54871 Mdot
.552 .54872 Mdot
.552 .54877 Mdot
.552 .54881 Mdot
.552 .54882 Mdot
.552 .54892 Mdot
.552 .54898 Mdot
.552 .54912 Mdot
.552 .54914 Mdot
.552 .54917 Mdot
.552 .54917 Mdot
.552 .54931 Mdot
.552 .54938 Mdot
.552 .54948 Mdot
.552 .54949 Mdot
.552 .54956 Mdot
.552 .54959 Mdot
.552 .54963 Mdot
.552 .54966 Mdot
.552 .5497 Mdot
.552 .54971 Mdot
.552 .54971 Mdot
.552 .54973 Mdot
.552 .54974 Mdot
.552 .54977 Mdot
.552 .54982 Mdot
.552 .54986 Mdot
.552 .54993 Mdot
.552 .54994 Mdot
.552 .54994 Mdot
.552 .54998 Mdot
.552 .54998 Mdot
.552 .55 Mdot
.552 .55001 Mdot
.552 .55001 Mdot
.552 .55003 Mdot
.552 .55005 Mdot
.552 .55006 Mdot
.552 .55008 Mdot
.552 .5501 Mdot
.552 .55011 Mdot
.552 .55017 Mdot
.552 .55017 Mdot
.552 .55023 Mdot
.552 .55024 Mdot
.552 .55026 Mdot
.552 .55027 Mdot
.552 .55027 Mdot
.552 .55032 Mdot
.552 .55032 Mdot
.552 .55033 Mdot
.552 .5504 Mdot
.552 .55043 Mdot
.552 .55043 Mdot
.552 .55049 Mdot
.552 .5505 Mdot
.552 .55051 Mdot
.552 .55056 Mdot
.552 .55057 Mdot
.552 .55057 Mdot
.552 .55058 Mdot
.552 .55058 Mdot
.552 .55058 Mdot
.552 .55058 Mdot
.554 .18893 Mdot
.554 .18894 Mdot
.554 .18896 Mdot
.554 .18899 Mdot
.554 .18899 Mdot
.554 .18914 Mdot
.554 .18916 Mdot
.554 .18918 Mdot
.554 .18919 Mdot
.554 .18919 Mdot
.554 .18922 Mdot
.554 .18925 Mdot
.554 .18935 Mdot
.554 .18949 Mdot
.554 .18953 Mdot
.554 .18956 Mdot
.554 .18963 Mdot
.554 .18973 Mdot
.554 .18974 Mdot
.554 .18991 Mdot
.554 .19019 Mdot
.554 .19031 Mdot
.554 .19036 Mdot
.554 .19043 Mdot
.554 .19055 Mdot
.554 .19065 Mdot
.554 .19075 Mdot
.554 .19078 Mdot
.554 .19082 Mdot
.554 .19111 Mdot
.554 .19116 Mdot
.554 .19131 Mdot
.554 .19137 Mdot
.554 .1916 Mdot
.554 .19172 Mdot
.554 .19182 Mdot
.554 .19198 Mdot
.554 .19209 Mdot
.554 .1923 Mdot
.554 .19243 Mdot
.554 .19253 Mdot
.554 .19266 Mdot
.554 .19276 Mdot
.554 .19276 Mdot
.554 .19282 Mdot
.554 .19301 Mdot
.554 .19315 Mdot
.554 .19315 Mdot
.554 .19341 Mdot
.554 .19415 Mdot
.554 .19424 Mdot
.554 .19443 Mdot
.554 .19448 Mdot
.554 .19507 Mdot
.554 .19508 Mdot
.554 .19519 Mdot
.554 .19543 Mdot
.554 .19551 Mdot
.554 .19561 Mdot
.554 .19571 Mdot
.554 .19612 Mdot
.554 .19637 Mdot
.554 .19675 Mdot
.554 .19703 Mdot
.554 .19727 Mdot
.554 .19736 Mdot
.554 .19744 Mdot
.554 .19749 Mdot
.554 .19804 Mdot
.554 .19819 Mdot
.554 .19866 Mdot
.554 .19902 Mdot
.554 .19908 Mdot
.554 .19932 Mdot
.554 .19944 Mdot
.554 .19948 Mdot
.554 .19977 Mdot
.554 .19995 Mdot
.554 .20015 Mdot
.554 .20027 Mdot
.554 .20047 Mdot
.554 .20105 Mdot
.554 .20113 Mdot
.554 .20154 Mdot
.554 .2018 Mdot
.554 .20182 Mdot
.554 .20248 Mdot
.554 .20271 Mdot
.554 .20277 Mdot
.554 .20294 Mdot
.554 .20316 Mdot
.554 .20398 Mdot
.554 .20426 Mdot
.554 .2043 Mdot
.554 .20447 Mdot
.554 .20454 Mdot
.554 .20461 Mdot
.554 .20492 Mdot
.554 .20539 Mdot
.554 .20552 Mdot
.554 .20553 Mdot
.554 .20554 Mdot
.554 .20577 Mdot
.554 .20597 Mdot
.554 .20628 Mdot
.554 .20661 Mdot
.554 .20663 Mdot
.554 .20709 Mdot
.554 .2078 Mdot
.554 .20792 Mdot
.554 .20806 Mdot
.554 .20847 Mdot
.554 .20875 Mdot
.554 .20899 Mdot
.554 .20924 Mdot
.554 .20928 Mdot
.554 .20939 Mdot
.554 .20939 Mdot
.554 .20953 Mdot
.554 .20974 Mdot
.554 .21019 Mdot
.554 .21021 Mdot
.554 .21046 Mdot
.554 .21068 Mdot
.554 .21098 Mdot
.554 .21105 Mdot
.554 .2111 Mdot
.554 .21118 Mdot
.554 .21146 Mdot
.554 .21161 Mdot
.554 .21169 Mdot
.554 .21193 Mdot
.554 .21222 Mdot
.554 .21239 Mdot
.554 .21265 Mdot
.554 .21309 Mdot
.554 .21317 Mdot
.554 .21359 Mdot
.554 .21361 Mdot
.554 .2137 Mdot
.554 .21451 Mdot
.554 .21532 Mdot
.554 .21546 Mdot
.554 .21551 Mdot
.554 .21565 Mdot
.554 .2164 Mdot
.554 .2167 Mdot
.554 .21702 Mdot
.554 .21723 Mdot
.554 .21757 Mdot
.554 .21806 Mdot
.554 .21858 Mdot
.554 .21903 Mdot
.554 .21919 Mdot
.554 .21961 Mdot
.554 .21993 Mdot
.554 .22019 Mdot
.554 .22033 Mdot
.554 .22094 Mdot
.554 .22117 Mdot
.554 .22122 Mdot
.554 .22236 Mdot
.554 .22315 Mdot
.554 .2241 Mdot
.554 .22428 Mdot
.554 .22468 Mdot
.554 .22523 Mdot
.554 .22587 Mdot
.554 .22611 Mdot
.554 .22838 Mdot
.554 .23049 Mdot
.554 .23059 Mdot
.554 .23188 Mdot
.554 .23214 Mdot
.554 .23265 Mdot
.554 .23362 Mdot
.554 .23458 Mdot
.554 .23563 Mdot
.554 .23572 Mdot
.554 .23575 Mdot
.554 .23582 Mdot
.554 .23646 Mdot
.554 .23664 Mdot
.554 .23688 Mdot
.554 .23785 Mdot
.554 .23881 Mdot
.554 .23894 Mdot
.554 .23967 Mdot
.554 .23982 Mdot
.554 .24039 Mdot
.554 .24074 Mdot
.554 .24112 Mdot
.554 .24186 Mdot
.554 .24199 Mdot
.554 .24218 Mdot
.554 .24365 Mdot
.554 .24639 Mdot
.554 .24666 Mdot
.554 .24699 Mdot
.554 .24728 Mdot
.554 .24805 Mdot
.554 .24922 Mdot
.554 .24929 Mdot
.554 .24945 Mdot
.554 .24995 Mdot
.554 .25013 Mdot
.554 .25023 Mdot
.554 .25032 Mdot
.554 .25057 Mdot
.554 .25069 Mdot
.554 .25168 Mdot
.554 .25183 Mdot
.554 .252 Mdot
.554 .25214 Mdot
.554 .25452 Mdot
.554 .25563 Mdot
.554 .2557 Mdot
.554 .25611 Mdot
.554 .25671 Mdot
.554 .25725 Mdot
.554 .25738 Mdot
.554 .25795 Mdot
.554 .25967 Mdot
.554 .26012 Mdot
.554 .26362 Mdot
.554 .26377 Mdot
.554 .26478 Mdot
.554 .26551 Mdot
.554 .26678 Mdot
.554 .26697 Mdot
.554 .26739 Mdot
.554 .26766 Mdot
.554 .26787 Mdot
.554 .2693 Mdot
.554 .26969 Mdot
.554 .26992 Mdot
.554 .27014 Mdot
.554 .27068 Mdot
.554 .27092 Mdot
.554 .2722 Mdot
.554 .27221 Mdot
.554 .27254 Mdot
.554 .2726 Mdot
.554 .27419 Mdot
.554 .27449 Mdot
.554 .27489 Mdot
.554 .27667 Mdot
.554 .27792 Mdot
.554 .27891 Mdot
.554 .27892 Mdot
.554 .27948 Mdot
.554 .2799 Mdot
.554 .28139 Mdot
.554 .28155 Mdot
.554 .28162 Mdot
.554 .28184 Mdot
.554 .28253 Mdot
.554 .28282 Mdot
.554 .28333 Mdot
.554 .28397 Mdot
.554 .28431 Mdot
.554 .28553 Mdot
.554 .28659 Mdot
.554 .28747 Mdot
.554 .28892 Mdot
.554 .28999 Mdot
.554 .29013 Mdot
.554 .29078 Mdot
.554 .29176 Mdot
.554 .29391 Mdot
.554 .29417 Mdot
.554 .29452 Mdot
.554 .29526 Mdot
.554 .29595 Mdot
.554 .29652 Mdot
.554 .29815 Mdot
.554 .29891 Mdot
.554 .29902 Mdot
.554 .29937 Mdot
.554 .30318 Mdot
.554 .30353 Mdot
.554 .3049 Mdot
.554 .30508 Mdot
.554 .3055 Mdot
.554 .30568 Mdot
.554 .30731 Mdot
.554 .30871 Mdot
.554 .30974 Mdot
.554 .31018 Mdot
.554 .31085 Mdot
.554 .31264 Mdot
.554 .31273 Mdot
.554 .31276 Mdot
.554 .31378 Mdot
.554 .31469 Mdot
.554 .31517 Mdot
.554 .31557 Mdot
.554 .31561 Mdot
.554 .31629 Mdot
.554 .31725 Mdot
.554 .31764 Mdot
.554 .31779 Mdot
.554 .318 Mdot
.554 .31838 Mdot
.554 .31893 Mdot
.554 .31999 Mdot
.554 .32034 Mdot
.554 .32051 Mdot
.554 .32104 Mdot
.554 .3213 Mdot
.554 .32186 Mdot
.554 .32252 Mdot
.554 .32297 Mdot
.554 .32323 Mdot
.554 .3234 Mdot
.554 .32341 Mdot
.554 .32412 Mdot
.554 .32459 Mdot
.554 .32583 Mdot
.554 .32597 Mdot
.554 .32635 Mdot
.554 .32728 Mdot
.554 .32744 Mdot
.554 .32778 Mdot
.554 .3282 Mdot
.554 .32876 Mdot
.554 .32961 Mdot
.554 .32999 Mdot
.554 .33029 Mdot
.554 .33041 Mdot
.554 .33051 Mdot
.554 .33125 Mdot
.554 .33201 Mdot
.554 .33243 Mdot
.554 .33278 Mdot
.554 .33292 Mdot
.554 .33296 Mdot
.554 .3333 Mdot
.554 .33349 Mdot
.554 .33386 Mdot
.554 .33478 Mdot
.554 .33549 Mdot
.554 .33687 Mdot
.554 .33767 Mdot
.554 .33794 Mdot
.554 .33797 Mdot
.554 .3382 Mdot
.554 .33826 Mdot
.554 .33899 Mdot
.554 .33912 Mdot
.554 .33934 Mdot
.554 .33952 Mdot
.554 .3398 Mdot
.554 .3401 Mdot
.554 .34052 Mdot
.554 .34114 Mdot
.554 .34125 Mdot
.554 .34171 Mdot
.554 .34195 Mdot
.554 .34216 Mdot
.554 .34236 Mdot
.554 .3424 Mdot
.554 .34249 Mdot
.554 .34249 Mdot
.554 .3426 Mdot
.554 .34278 Mdot
.554 .34316 Mdot
.554 .34337 Mdot
.554 .34378 Mdot
.554 .34388 Mdot
.554 .34395 Mdot
.554 .34417 Mdot
.554 .34429 Mdot
.554 .34435 Mdot
.554 .34454 Mdot
.554 .34476 Mdot
.554 .34489 Mdot
.554 .3451 Mdot
.554 .3459 Mdot
.554 .34651 Mdot
.554 .34722 Mdot
.554 .34725 Mdot
.554 .34849 Mdot
.554 .34908 Mdot
.554 .34945 Mdot
.554 .34976 Mdot
.554 .34987 Mdot
.554 .35055 Mdot
.554 .35121 Mdot
.554 .352 Mdot
.554 .35314 Mdot
.554 .35351 Mdot
.554 .35386 Mdot
.554 .35582 Mdot
.554 .35709 Mdot
.554 .35716 Mdot
.554 .35807 Mdot
.554 .35893 Mdot
.554 .35948 Mdot
.554 .36013 Mdot
.554 .36015 Mdot
.554 .36019 Mdot
.554 .36055 Mdot
.554 .36186 Mdot
.554 .36272 Mdot
.554 .36291 Mdot
.554 .36311 Mdot
.554 .36358 Mdot
.554 .36368 Mdot
.554 .36446 Mdot
.554 .36675 Mdot
.554 .36738 Mdot
.554 .36785 Mdot
.554 .36803 Mdot
.554 .36865 Mdot
.554 .37052 Mdot
.554 .37056 Mdot
.554 .37131 Mdot
.554 .37246 Mdot
.554 .37267 Mdot
.554 .37432 Mdot
.554 .37485 Mdot
.554 .37519 Mdot
.554 .37577 Mdot
.554 .37627 Mdot
.554 .37709 Mdot
.554 .37719 Mdot
.554 .37753 Mdot
.554 .37821 Mdot
.554 .37839 Mdot
.554 .3794 Mdot
.554 .38072 Mdot
.554 .38115 Mdot
.554 .3827 Mdot
.554 .38282 Mdot
.554 .38304 Mdot
.554 .38331 Mdot
.554 .38397 Mdot
.554 .38478 Mdot
.554 .38583 Mdot
.554 .38656 Mdot
.554 .38769 Mdot
.554 .38799 Mdot
.554 .38827 Mdot
.554 .3885 Mdot
.554 .38916 Mdot
.554 .38947 Mdot
.554 .38951 Mdot
.554 .39117 Mdot
.554 .39131 Mdot
.554 .39186 Mdot
.554 .39209 Mdot
.554 .39419 Mdot
.554 .39492 Mdot
.554 .39493 Mdot
.554 .39532 Mdot
.554 .39586 Mdot
.554 .39602 Mdot
.554 .39603 Mdot
.554 .39629 Mdot
.554 .39666 Mdot
.554 .39695 Mdot
.554 .3973 Mdot
.554 .3979 Mdot
.554 .39821 Mdot
.554 .39867 Mdot
.554 .39893 Mdot
.554 .39927 Mdot
.554 .39992 Mdot
.554 .40011 Mdot
.554 .40052 Mdot
.554 .40065 Mdot
.554 .40148 Mdot
.554 .40159 Mdot
.554 .40167 Mdot
.554 .40195 Mdot
.554 .40223 Mdot
.554 .40259 Mdot
.554 .40278 Mdot
.554 .40292 Mdot
.554 .40326 Mdot
.554 .40403 Mdot
.554 .40452 Mdot
.554 .40455 Mdot
.554 .40482 Mdot
.554 .40501 Mdot
.554 .40511 Mdot
.554 .40522 Mdot
.554 .40561 Mdot
.554 .4059 Mdot
.554 .40598 Mdot
.554 .40605 Mdot
.554 .40607 Mdot
.554 .4061 Mdot
.554 .40614 Mdot
.554 .40621 Mdot
.554 .40661 Mdot
.554 .40663 Mdot
.554 .40671 Mdot
.554 .40676 Mdot
.554 .40678 Mdot
.554 .46156 Mdot
.554 .46158 Mdot
.554 .4616 Mdot
.554 .46164 Mdot
.554 .46165 Mdot
.554 .46187 Mdot
.554 .4619 Mdot
.554 .46192 Mdot
.554 .46194 Mdot
.554 .46195 Mdot
.554 .46199 Mdot
.554 .46203 Mdot
.554 .46219 Mdot
.554 .46239 Mdot
.554 .46244 Mdot
.554 .4625 Mdot
.554 .4626 Mdot
.554 .46274 Mdot
.554 .46275 Mdot
.554 .46301 Mdot
.554 .46342 Mdot
.554 .4636 Mdot
.554 .46367 Mdot
.554 .46377 Mdot
.554 .46395 Mdot
.554 .4641 Mdot
.554 .46425 Mdot
.554 .46429 Mdot
.554 .46435 Mdot
.554 .46478 Mdot
.554 .46484 Mdot
.554 .46505 Mdot
.554 .46516 Mdot
.554 .46549 Mdot
.554 .46566 Mdot
.554 .4658 Mdot
.554 .46604 Mdot
.554 .46619 Mdot
.554 .4665 Mdot
.554 .46669 Mdot
.554 .46683 Mdot
.554 .46702 Mdot
.554 .46715 Mdot
.554 .46716 Mdot
.554 .46724 Mdot
.554 .46752 Mdot
.554 .46772 Mdot
.554 .46772 Mdot
.554 .46809 Mdot
.554 .46915 Mdot
.554 .46927 Mdot
.554 .46955 Mdot
.554 .46962 Mdot
.554 .47045 Mdot
.554 .47047 Mdot
.554 .47062 Mdot
.554 .47095 Mdot
.554 .47107 Mdot
.554 .47121 Mdot
.554 .47136 Mdot
.554 .47192 Mdot
.554 .47228 Mdot
.554 .4728 Mdot
.554 .4732 Mdot
.554 .47352 Mdot
.554 .47366 Mdot
.554 .47376 Mdot
.554 .47382 Mdot
.554 .47458 Mdot
.554 .47479 Mdot
.554 .47543 Mdot
.554 .47592 Mdot
.554 .47601 Mdot
.554 .47634 Mdot
.554 .4765 Mdot
.554 .47655 Mdot
.554 .47695 Mdot
.554 .47719 Mdot
.554 .47746 Mdot
.554 .47763 Mdot
.554 .47788 Mdot
.554 .47867 Mdot
.554 .47877 Mdot
.554 .47932 Mdot
.554 .47967 Mdot
.554 .47969 Mdot
.554 .48057 Mdot
.554 .48087 Mdot
.554 .48095 Mdot
.554 .48117 Mdot
.554 .48146 Mdot
.554 .48253 Mdot
.554 .4829 Mdot
.554 .48294 Mdot
.554 .48316 Mdot
.554 .48325 Mdot
.554 .48334 Mdot
.554 .48374 Mdot
.554 .48435 Mdot
.554 .48451 Mdot
.554 .48453 Mdot
.554 .48454 Mdot
.554 .48484 Mdot
.554 .48509 Mdot
.554 .48548 Mdot
.554 .4859 Mdot
.554 .48593 Mdot
.554 .48651 Mdot
.554 .4874 Mdot
.554 .48756 Mdot
.554 .48773 Mdot
.554 .48824 Mdot
.554 .4886 Mdot
.554 .48889 Mdot
.554 .4892 Mdot
.554 .48925 Mdot
.554 .48939 Mdot
.554 .48955 Mdot
.554 .48981 Mdot
.554 .49037 Mdot
.554 .49038 Mdot
.554 .4907 Mdot
.554 .49097 Mdot
.554 .49132 Mdot
.554 .49141 Mdot
.554 .49147 Mdot
.554 .49157 Mdot
.554 .49166 Mdot
.554 .49168 Mdot
.554 .49174 Mdot
.554 .49183 Mdot
.554 .49186 Mdot
.554 .49191 Mdot
.554 .49209 Mdot
.554 .49218 Mdot
.554 .49235 Mdot
.554 .49243 Mdot
.554 .49248 Mdot
.554 .49248 Mdot
.554 .49252 Mdot
.554 .49253 Mdot
.554 .49262 Mdot
.554 .49271 Mdot
.554 .49282 Mdot
.554 .49302 Mdot
.554 .49307 Mdot
.554 .49334 Mdot
.554 .49353 Mdot
.554 .49366 Mdot
.554 .49378 Mdot
.554 .49386 Mdot
.554 .49395 Mdot
.554 .49401 Mdot
.554 .49433 Mdot
.554 .49436 Mdot
.554 .49446 Mdot
.554 .49447 Mdot
.554 .49459 Mdot
.554 .49493 Mdot
.554 .49553 Mdot
.554 .49584 Mdot
.554 .49624 Mdot
.554 .4964 Mdot
.554 .49648 Mdot
.554 .49662 Mdot
.554 .49664 Mdot
.554 .4967 Mdot
.554 .49685 Mdot
.554 .49704 Mdot
.554 .49736 Mdot
.554 .49768 Mdot
.554 .49772 Mdot
.554 .49777 Mdot
.554 .4979 Mdot
.554 .49806 Mdot
.554 .49843 Mdot
.554 .49867 Mdot
.554 .49884 Mdot
.554 .49899 Mdot
.554 .49906 Mdot
.554 .49945 Mdot
.554 .49961 Mdot
.554 .49967 Mdot
.554 .5002 Mdot
.554 .50039 Mdot
.554 .5007 Mdot
.554 .50077 Mdot
.554 .50088 Mdot
.554 .50107 Mdot
.554 .50135 Mdot
.554 .50158 Mdot
.554 .50169 Mdot
.554 .50191 Mdot
.554 .50198 Mdot
.554 .50213 Mdot
.554 .50257 Mdot
.554 .5028 Mdot
.554 .50296 Mdot
.554 .50305 Mdot
.554 .50311 Mdot
.554 .50327 Mdot
.554 .50367 Mdot
.554 .50395 Mdot
.554 .50397 Mdot
.554 .50414 Mdot
.554 .50434 Mdot
.554 .50471 Mdot
.554 .50513 Mdot
.554 .50514 Mdot
.554 .50518 Mdot
.554 .50592 Mdot
.554 .50619 Mdot
.554 .50637 Mdot
.554 .50679 Mdot
.554 .50736 Mdot
.554 .50803 Mdot
.554 .5081 Mdot
.554 .50827 Mdot
.554 .50834 Mdot
.554 .50889 Mdot
.554 .50904 Mdot
.554 .51057 Mdot
.554 .51071 Mdot
.554 .51075 Mdot
.554 .51106 Mdot
.554 .51171 Mdot
.554 .51194 Mdot
.554 .51221 Mdot
.554 .51251 Mdot
.554 .51265 Mdot
.554 .51275 Mdot
.554 .5136 Mdot
.554 .51399 Mdot
.554 .51424 Mdot
.554 .5143 Mdot
.554 .51472 Mdot
.554 .51529 Mdot
.554 .51563 Mdot
.554 .51604 Mdot
.554 .51652 Mdot
.554 .51665 Mdot
.554 .5169 Mdot
.554 .5171 Mdot
.554 .51721 Mdot
.554 .51748 Mdot
.554 .51757 Mdot
.554 .51759 Mdot
.554 .51765 Mdot
.554 .51823 Mdot
.554 .51839 Mdot
.554 .51861 Mdot
.554 .51861 Mdot
.554 .51899 Mdot
.554 .51947 Mdot
.554 .52016 Mdot
.554 .52031 Mdot
.554 .52042 Mdot
.554 .52103 Mdot
.554 .52105 Mdot
.554 .52118 Mdot
.554 .52118 Mdot
.554 .52167 Mdot
.554 .52176 Mdot
.554 .52197 Mdot
.554 .52205 Mdot
.554 .52213 Mdot
.554 .52228 Mdot
.554 .52282 Mdot
.554 .5229 Mdot
.554 .52301 Mdot
.554 .52316 Mdot
.554 .52323 Mdot
.554 .52371 Mdot
.554 .52399 Mdot
.554 .52437 Mdot
.554 .52442 Mdot
.554 .52573 Mdot
.554 .5259 Mdot
.554 .52654 Mdot
.554 .52675 Mdot
.554 .5268 Mdot
.554 .527 Mdot
.554 .52722 Mdot
.554 .52737 Mdot
.554 .5274 Mdot
.554 .52781 Mdot
.554 .52869 Mdot
.554 .52874 Mdot
.554 .5288 Mdot
.554 .52886 Mdot
.554 .52922 Mdot
.554 .52926 Mdot
.554 .52935 Mdot
.554 .52939 Mdot
.554 .52942 Mdot
.554 .52949 Mdot
.554 .52967 Mdot
.554 .52973 Mdot
.554 .52976 Mdot
.554 .53019 Mdot
.554 .53047 Mdot
.554 .53057 Mdot
.554 .53069 Mdot
.554 .53079 Mdot
.554 .53179 Mdot
.554 .53232 Mdot
.554 .53239 Mdot
.554 .53243 Mdot
.554 .5327 Mdot
.554 .53284 Mdot
.554 .53296 Mdot
.554 .53317 Mdot
.554 .53322 Mdot
.554 .53349 Mdot
.554 .53353 Mdot
.554 .53388 Mdot
.554 .53423 Mdot
.554 .53431 Mdot
.554 .53438 Mdot
.554 .53461 Mdot
.554 .53463 Mdot
.554 .53464 Mdot
.554 .53468 Mdot
.554 .53505 Mdot
.554 .5354 Mdot
.554 .53574 Mdot
.554 .53592 Mdot
.554 .53602 Mdot
.554 .53647 Mdot
.554 .53651 Mdot
.554 .53726 Mdot
.554 .53806 Mdot
.554 .53814 Mdot
.554 .53837 Mdot
.554 .53856 Mdot
.554 .5387 Mdot
.554 .53876 Mdot
.554 .5391 Mdot
.554 .53938 Mdot
.554 .53978 Mdot
.554 .5398 Mdot
.554 .53987 Mdot
.554 .54009 Mdot
.554 .54014 Mdot
.554 .54023 Mdot
.554 .54034 Mdot
.554 .54049 Mdot
.554 .54054 Mdot
.554 .5407 Mdot
.554 .54088 Mdot
.554 .54105 Mdot
.554 .54117 Mdot
.554 .54124 Mdot
.554 .54135 Mdot
.554 .54146 Mdot
.554 .54172 Mdot
.554 .54177 Mdot
.554 .54178 Mdot
.554 .54183 Mdot
.554 .54211 Mdot
.554 .54239 Mdot
.554 .54243 Mdot
.554 .54243 Mdot
.554 .54258 Mdot
.554 .54261 Mdot
.554 .54276 Mdot
.554 .54285 Mdot
.554 .54291 Mdot
.554 .54301 Mdot
.554 .54309 Mdot
.554 .54312 Mdot
.554 .54317 Mdot
.554 .54326 Mdot
.554 .54329 Mdot
.554 .54331 Mdot
.554 .54334 Mdot
.554 .54344 Mdot
.554 .54351 Mdot
.554 .5436 Mdot
.554 .54361 Mdot
.554 .54376 Mdot
.554 .54383 Mdot
.554 .54388 Mdot
.554 .54388 Mdot
.554 .54392 Mdot
.554 .54393 Mdot
.554 .54402 Mdot
.554 .5441 Mdot
.554 .5442 Mdot
.554 .54434 Mdot
.554 .54439 Mdot
.554 .54443 Mdot
.554 .54467 Mdot
.554 .54483 Mdot
.554 .54484 Mdot
.554 .54495 Mdot
.554 .54506 Mdot
.554 .54512 Mdot
.554 .5452 Mdot
.554 .54521 Mdot
.554 .54521 Mdot
.554 .54525 Mdot
.554 .54542 Mdot
.554 .54552 Mdot
.554 .54554 Mdot
.554 .54557 Mdot
.554 .54563 Mdot
.554 .54564 Mdot
.554 .54573 Mdot
.554 .54601 Mdot
.554 .54609 Mdot
.554 .54615 Mdot
.554 .54617 Mdot
.554 .54625 Mdot
.554 .54647 Mdot
.554 .54648 Mdot
.554 .54657 Mdot
.554 .54671 Mdot
.554 .54673 Mdot
.554 .54693 Mdot
.554 .547 Mdot
.554 .54704 Mdot
.554 .54711 Mdot
.554 .54717 Mdot
.554 .54727 Mdot
.554 .54728 Mdot
.554 .54732 Mdot
.554 .5474 Mdot
.554 .54742 Mdot
.554 .54754 Mdot
.554 .5477 Mdot
.554 .54775 Mdot
.554 .54794 Mdot
.554 .54796 Mdot
.554 .54798 Mdot
.554 .54801 Mdot
.554 .54809 Mdot
.554 .54819 Mdot
.554 .54832 Mdot
.554 .5484 Mdot
.554 .54854 Mdot
.554 .54858 Mdot
.554 .54861 Mdot
.554 .54864 Mdot
.554 .54872 Mdot
.554 .54875 Mdot
.554 .54876 Mdot
.554 .54896 Mdot
.554 .54897 Mdot
.554 .54904 Mdot
.554 .54907 Mdot
.554 .54932 Mdot
.554 .5494 Mdot
.554 .5494 Mdot
.554 .54945 Mdot
.554 .54951 Mdot
.554 .54953 Mdot
.554 .54953 Mdot
.554 .54957 Mdot
.554 .54961 Mdot
.554 .54964 Mdot
.554 .54969 Mdot
.554 .54976 Mdot
.554 .54979 Mdot
.554 .54985 Mdot
.554 .54988 Mdot
.554 .54992 Mdot
.554 .55 Mdot
.554 .55002 Mdot
.554 .55007 Mdot
.554 .55009 Mdot
.554 .55018 Mdot
.554 .5502 Mdot
.554 .55021 Mdot
.554 .55024 Mdot
.554 .55027 Mdot
.554 .55032 Mdot
.554 .55034 Mdot
.554 .55036 Mdot
.554 .5504 Mdot
.554 .55049 Mdot
.554 .55055 Mdot
.554 .55055 Mdot
.554 .55058 Mdot
.554 .5506 Mdot
.554 .55062 Mdot
.554 .55063 Mdot
.554 .55068 Mdot
.554 .55071 Mdot
.554 .55072 Mdot
.554 .55073 Mdot
.554 .55073 Mdot
.554 .55073 Mdot
.554 .55074 Mdot
.554 .55075 Mdot
.554 .55079 Mdot
.554 .5508 Mdot
.554 .55081 Mdot
.554 .55081 Mdot
.554 .55082 Mdot
.556 .1883 Mdot
.556 .18831 Mdot
.556 .18832 Mdot
.556 .18832 Mdot
.556 .18833 Mdot
.556 .18835 Mdot
.556 .18835 Mdot
.556 .18837 Mdot
.556 .18838 Mdot
.556 .18841 Mdot
.556 .18847 Mdot
.556 .18853 Mdot
.556 .18856 Mdot
.556 .18872 Mdot
.556 .18876 Mdot
.556 .18898 Mdot
.556 .18907 Mdot
.556 .18911 Mdot
.556 .18926 Mdot
.556 .1895 Mdot
.556 .18952 Mdot
.556 .18955 Mdot
.556 .18957 Mdot
.556 .18962 Mdot
.556 .18963 Mdot
.556 .18992 Mdot
.556 .19034 Mdot
.556 .19048 Mdot
.556 .19065 Mdot
.556 .1908 Mdot
.556 .19102 Mdot
.556 .19152 Mdot
.556 .19195 Mdot
.556 .19205 Mdot
.556 .19237 Mdot
.556 .19241 Mdot
.556 .19243 Mdot
.556 .19263 Mdot
.556 .1927 Mdot
.556 .19284 Mdot
.556 .19288 Mdot
.556 .19319 Mdot
.556 .19332 Mdot
.556 .19341 Mdot
.556 .19345 Mdot
.556 .19367 Mdot
.556 .19465 Mdot
.556 .1955 Mdot
.556 .19553 Mdot
.556 .19563 Mdot
.556 .19563 Mdot
.556 .1957 Mdot
.556 .19574 Mdot
.556 .19585 Mdot
.556 .19588 Mdot
.556 .19636 Mdot
.556 .19641 Mdot
.556 .1965 Mdot
.556 .19667 Mdot
.556 .19673 Mdot
.556 .19681 Mdot
.556 .19695 Mdot
.556 .19703 Mdot
.556 .19737 Mdot
.556 .1975 Mdot
.556 .1976 Mdot
.556 .19775 Mdot
.556 .19782 Mdot
.556 .19802 Mdot
.556 .19807 Mdot
.556 .19811 Mdot
.556 .19828 Mdot
.556 .19828 Mdot
.556 .19866 Mdot
.556 .1989 Mdot
.556 .19902 Mdot
.556 .19921 Mdot
.556 .19935 Mdot
.556 .20031 Mdot
.556 .20051 Mdot
.556 .20055 Mdot
.556 .20115 Mdot
.556 .20149 Mdot
.556 .20157 Mdot
.556 .20174 Mdot
.556 .20222 Mdot
.556 .20231 Mdot
.556 .20234 Mdot
.556 .20256 Mdot
.556 .20298 Mdot
.556 .20309 Mdot
.556 .20316 Mdot
.556 .2033 Mdot
.556 .20383 Mdot
.556 .20395 Mdot
.556 .20401 Mdot
.556 .20431 Mdot
.556 .20431 Mdot
.556 .20451 Mdot
.556 .20454 Mdot
.556 .2048 Mdot
.556 .20493 Mdot
.556 .20532 Mdot
.556 .20544 Mdot
.556 .20599 Mdot
.556 .20632 Mdot
.556 .20668 Mdot
.556 .20701 Mdot
.556 .20748 Mdot
.556 .20777 Mdot
.556 .20785 Mdot
.556 .20789 Mdot
.556 .20792 Mdot
.556 .20839 Mdot
.556 .20877 Mdot
.556 .20894 Mdot
.556 .20914 Mdot
.556 .20918 Mdot
.556 .20927 Mdot
.556 .20931 Mdot
.556 .20957 Mdot
.556 .21013 Mdot
.556 .21094 Mdot
.556 .21167 Mdot
.556 .21177 Mdot
.556 .2121 Mdot
.556 .21287 Mdot
.556 .21326 Mdot
.556 .21361 Mdot
.556 .21366 Mdot
.556 .21368 Mdot
.556 .21396 Mdot
.556 .214 Mdot
.556 .21463 Mdot
.556 .21465 Mdot
.556 .21472 Mdot
.556 .21525 Mdot
.556 .21557 Mdot
.556 .21557 Mdot
.556 .21564 Mdot
.556 .21577 Mdot
.556 .21592 Mdot
.556 .21597 Mdot
.556 .21617 Mdot
.556 .21624 Mdot
.556 .2163 Mdot
.556 .21639 Mdot
.556 .21643 Mdot
.556 .21676 Mdot
.556 .21682 Mdot
.556 .21687 Mdot
.556 .21688 Mdot
.556 .2179 Mdot
.556 .21805 Mdot
.556 .21841 Mdot
.556 .21855 Mdot
.556 .21935 Mdot
.556 .22008 Mdot
.556 .22037 Mdot
.556 .22163 Mdot
.556 .22193 Mdot
.556 .22295 Mdot
.556 .22363 Mdot
.556 .22377 Mdot
.556 .22395 Mdot
.556 .2243 Mdot
.556 .22512 Mdot
.556 .22559 Mdot
.556 .22578 Mdot
.556 .22767 Mdot
.556 .22772 Mdot
.556 .22809 Mdot
.556 .2292 Mdot
.556 .23089 Mdot
.556 .23243 Mdot
.556 .23315 Mdot
.556 .23423 Mdot
.556 .23512 Mdot
.556 .23537 Mdot
.556 .23572 Mdot
.556 .23684 Mdot
.556 .23766 Mdot
.556 .23777 Mdot
.556 .23827 Mdot
.556 .23828 Mdot
.556 .23833 Mdot
.556 .23862 Mdot
.556 .23969 Mdot
.556 .23981 Mdot
.556 .23982 Mdot
.556 .24015 Mdot
.556 .24045 Mdot
.556 .24085 Mdot
.556 .24087 Mdot
.556 .24196 Mdot
.556 .24243 Mdot
.556 .24273 Mdot
.556 .24337 Mdot
.556 .24562 Mdot
.556 .24623 Mdot
.556 .24662 Mdot
.556 .247 Mdot
.556 .247 Mdot
.556 .24741 Mdot
.556 .24749 Mdot
.556 .24796 Mdot
.556 .24939 Mdot
.556 .25034 Mdot
.556 .2513 Mdot
.556 .25156 Mdot
.556 .25175 Mdot
.556 .25226 Mdot
.556 .25419 Mdot
.556 .25499 Mdot
.556 .25516 Mdot
.556 .25533 Mdot
.556 .25599 Mdot
.556 .25617 Mdot
.556 .25618 Mdot
.556 .25646 Mdot
.556 .25697 Mdot
.556 .25779 Mdot
.556 .25844 Mdot
.556 .25906 Mdot
.556 .26205 Mdot
.556 .26227 Mdot
.556 .26347 Mdot
.556 .26389 Mdot
.556 .26527 Mdot
.556 .26594 Mdot
.556 .26697 Mdot
.556 .26939 Mdot
.556 .26942 Mdot
.556 .26947 Mdot
.556 .27032 Mdot
.556 .27032 Mdot
.556 .27099 Mdot
.556 .27149 Mdot
.556 .27172 Mdot
.556 .27176 Mdot
.556 .27203 Mdot
.556 .27232 Mdot
.556 .27381 Mdot
.556 .27446 Mdot
.556 .27513 Mdot
.556 .27523 Mdot
.556 .27526 Mdot
.556 .27628 Mdot
.556 .27631 Mdot
.556 .27641 Mdot
.556 .27666 Mdot
.556 .27735 Mdot
.556 .27766 Mdot
.556 .27795 Mdot
.556 .27856 Mdot
.556 .2793 Mdot
.556 .27977 Mdot
.556 .28075 Mdot
.556 .28117 Mdot
.556 .28138 Mdot
.556 .28198 Mdot
.556 .28224 Mdot
.556 .28259 Mdot
.556 .28453 Mdot
.556 .28468 Mdot
.556 .28504 Mdot
.556 .286 Mdot
.556 .28657 Mdot
.556 .28727 Mdot
.556 .28813 Mdot
.556 .28875 Mdot
.556 .289 Mdot
.556 .2891 Mdot
.556 .29233 Mdot
.556 .29255 Mdot
.556 .29276 Mdot
.556 .29329 Mdot
.556 .2936 Mdot
.556 .29409 Mdot
.556 .29412 Mdot
.556 .29479 Mdot
.556 .29499 Mdot
.556 .2969 Mdot
.556 .29967 Mdot
.556 .3006 Mdot
.556 .30074 Mdot
.556 .30093 Mdot
.556 .30549 Mdot
.556 .30599 Mdot
.556 .30719 Mdot
.556 .308 Mdot
.556 .30929 Mdot
.556 .30956 Mdot
.556 .30986 Mdot
.556 .31019 Mdot
.556 .31055 Mdot
.556 .31064 Mdot
.556 .31102 Mdot
.556 .31146 Mdot
.556 .31276 Mdot
.556 .31375 Mdot
.556 .31399 Mdot
.556 .31506 Mdot
.556 .31543 Mdot
.556 .31559 Mdot
.556 .31619 Mdot
.556 .31705 Mdot
.556 .31721 Mdot
.556 .31748 Mdot
.556 .31949 Mdot
.556 .31985 Mdot
.556 .32026 Mdot
.556 .32062 Mdot
.556 .32219 Mdot
.556 .32384 Mdot
.556 .3243 Mdot
.556 .32468 Mdot
.556 .32563 Mdot
.556 .32605 Mdot
.556 .32756 Mdot
.556 .32876 Mdot
.556 .3288 Mdot
.556 .32893 Mdot
.556 .32909 Mdot
.556 .32924 Mdot
.556 .32997 Mdot
.556 .33009 Mdot
.556 .33031 Mdot
.556 .33038 Mdot
.556 .33049 Mdot
.556 .33067 Mdot
.556 .33119 Mdot
.556 .33135 Mdot
.556 .33165 Mdot
.556 .33173 Mdot
.556 .33209 Mdot
.556 .33228 Mdot
.556 .33228 Mdot
.556 .33273 Mdot
.556 .33314 Mdot
.556 .33456 Mdot
.556 .33477 Mdot
.556 .33481 Mdot
.556 .33588 Mdot
.556 .33653 Mdot
.556 .33662 Mdot
.556 .33738 Mdot
.556 .33746 Mdot
.556 .33759 Mdot
.556 .3381 Mdot
.556 .33821 Mdot
.556 .33855 Mdot
.556 .33855 Mdot
.556 .33876 Mdot
.556 .339 Mdot
.556 .33912 Mdot
.556 .33959 Mdot
.556 .34097 Mdot
.556 .34169 Mdot
.556 .34215 Mdot
.556 .34246 Mdot
.556 .34261 Mdot
.556 .34287 Mdot
.556 .34312 Mdot
.556 .34479 Mdot
.556 .34487 Mdot
.556 .34513 Mdot
.556 .34633 Mdot
.556 .34656 Mdot
.556 .34703 Mdot
.556 .3471 Mdot
.556 .34748 Mdot
.556 .34777 Mdot
.556 .34786 Mdot
.556 .34797 Mdot
.556 .34801 Mdot
.556 .34815 Mdot
.556 .3482 Mdot
.556 .34824 Mdot
.556 .3483 Mdot
.556 .34833 Mdot
.556 .34865 Mdot
.556 .34937 Mdot
.556 .34948 Mdot
.556 .34972 Mdot
.556 .34982 Mdot
.556 .35037 Mdot
.556 .35086 Mdot
.556 .3519 Mdot
.556 .35319 Mdot
.556 .35329 Mdot
.556 .3534 Mdot
.556 .35362 Mdot
.556 .35444 Mdot
.556 .35572 Mdot
.556 .35665 Mdot
.556 .35765 Mdot
.556 .35856 Mdot
.556 .3601 Mdot
.556 .36044 Mdot
.556 .36152 Mdot
.556 .36188 Mdot
.556 .36263 Mdot
.556 .36269 Mdot
.556 .36325 Mdot
.556 .36326 Mdot
.556 .36409 Mdot
.556 .36426 Mdot
.556 .36459 Mdot
.556 .36608 Mdot
.556 .36648 Mdot
.556 .36669 Mdot
.556 .36697 Mdot
.556 .36817 Mdot
.556 .36877 Mdot
.556 .36887 Mdot
.556 .36912 Mdot
.556 .37046 Mdot
.556 .37094 Mdot
.556 .37117 Mdot
.556 .37211 Mdot
.556 .37381 Mdot
.556 .37392 Mdot
.556 .37447 Mdot
.556 .3772 Mdot
.556 .37758 Mdot
.556 .37811 Mdot
.556 .37847 Mdot
.556 .37913 Mdot
.556 .38021 Mdot
.556 .38022 Mdot
.556 .38067 Mdot
.556 .38081 Mdot
.556 .38093 Mdot
.556 .38151 Mdot
.556 .38171 Mdot
.556 .38213 Mdot
.556 .3824 Mdot
.556 .38277 Mdot
.556 .38374 Mdot
.556 .38395 Mdot
.556 .38435 Mdot
.556 .38459 Mdot
.556 .38524 Mdot
.556 .3855 Mdot
.556 .38564 Mdot
.556 .38697 Mdot
.556 .38706 Mdot
.556 .38736 Mdot
.556 .38749 Mdot
.556 .38769 Mdot
.556 .3877 Mdot
.556 .38797 Mdot
.556 .38805 Mdot
.556 .39044 Mdot
.556 .39323 Mdot
.556 .39384 Mdot
.556 .39396 Mdot
.556 .39422 Mdot
.556 .39458 Mdot
.556 .39546 Mdot
.556 .39556 Mdot
.556 .39596 Mdot
.556 .39617 Mdot
.556 .39673 Mdot
.556 .39679 Mdot
.556 .39689 Mdot
.556 .3978 Mdot
.556 .39809 Mdot
.556 .39931 Mdot
.556 .4007 Mdot
.556 .40133 Mdot
.556 .40176 Mdot
.556 .40223 Mdot
.556 .40263 Mdot
.556 .40379 Mdot
.556 .40461 Mdot
.556 .40465 Mdot
.556 .40478 Mdot
.556 .40485 Mdot
.556 .40495 Mdot
.556 .40499 Mdot
.556 .40567 Mdot
.556 .4061 Mdot
.556 .40621 Mdot
.556 .40645 Mdot
.556 .40706 Mdot
.556 .40718 Mdot
.556 .40762 Mdot
.556 .40771 Mdot
.556 .40788 Mdot
.556 .40804 Mdot
.556 .40815 Mdot
.556 .40818 Mdot
.556 .40822 Mdot
.556 .40823 Mdot
.556 .40828 Mdot
.556 .4083 Mdot
.556 .40832 Mdot
.556 .40834 Mdot
.556 .40835 Mdot
.556 .46082 Mdot
.556 .46083 Mdot
.556 .46084 Mdot
.556 .46085 Mdot
.556 .46086 Mdot
.556 .46089 Mdot
.556 .46089 Mdot
.556 .46091 Mdot
.556 .46093 Mdot
.556 .46099 Mdot
.556 .46107 Mdot
.556 .46116 Mdot
.556 .46121 Mdot
.556 .46144 Mdot
.556 .46151 Mdot
.556 .46183 Mdot
.556 .46196 Mdot
.556 .46202 Mdot
.556 .46224 Mdot
.556 .4626 Mdot
.556 .46262 Mdot
.556 .46267 Mdot
.556 .46271 Mdot
.556 .46278 Mdot
.556 .4628 Mdot
.556 .46323 Mdot
.556 .46384 Mdot
.556 .46404 Mdot
.556 .46429 Mdot
.556 .46451 Mdot
.556 .46484 Mdot
.556 .46556 Mdot
.556 .46619 Mdot
.556 .46634 Mdot
.556 .4668 Mdot
.556 .46685 Mdot
.556 .46688 Mdot
.556 .46717 Mdot
.556 .46727 Mdot
.556 .46748 Mdot
.556 .46753 Mdot
.556 .46798 Mdot
.556 .46816 Mdot
.556 .46829 Mdot
.556 .46835 Mdot
.556 .46866 Mdot
.556 .47007 Mdot
.556 .47126 Mdot
.556 .4713 Mdot
.556 .47143 Mdot
.556 .47144 Mdot
.556 .47154 Mdot
.556 .4716 Mdot
.556 .47175 Mdot
.556 .4718 Mdot
.556 .47246 Mdot
.556 .47253 Mdot
.556 .47265 Mdot
.556 .47297 Mdot
.556 .47309 Mdot
.556 .47329 Mdot
.556 .47339 Mdot
.556 .47387 Mdot
.556 .47405 Mdot
.556 .47418 Mdot
.556 .47438 Mdot
.556 .47448 Mdot
.556 .47476 Mdot
.556 .47483 Mdot
.556 .47489 Mdot
.556 .47511 Mdot
.556 .47512 Mdot
.556 .47564 Mdot
.556 .47596 Mdot
.556 .47614 Mdot
.556 .47639 Mdot
.556 .47657 Mdot
.556 .47788 Mdot
.556 .47815 Mdot
.556 .4782 Mdot
.556 .47901 Mdot
.556 .47946 Mdot
.556 .47956 Mdot
.556 .47979 Mdot
.556 .48042 Mdot
.556 .48054 Mdot
.556 .48059 Mdot
.556 .48087 Mdot
.556 .48143 Mdot
.556 .48157 Mdot
.556 .48166 Mdot
.556 .48185 Mdot
.556 .48254 Mdot
.556 .4827 Mdot
.556 .48277 Mdot
.556 .48316 Mdot
.556 .48316 Mdot
.556 .48343 Mdot
.556 .48346 Mdot
.556 .4838 Mdot
.556 .48397 Mdot
.556 .48447 Mdot
.556 .48462 Mdot
.556 .48533 Mdot
.556 .48574 Mdot
.556 .4862 Mdot
.556 .48662 Mdot
.556 .48721 Mdot
.556 .48757 Mdot
.556 .48767 Mdot
.556 .48773 Mdot
.556 .48777 Mdot
.556 .48835 Mdot
.556 .48882 Mdot
.556 .48904 Mdot
.556 .48928 Mdot
.556 .48933 Mdot
.556 .48944 Mdot
.556 .48949 Mdot
.556 .48981 Mdot
.556 .48995 Mdot
.556 .48996 Mdot
.556 .48999 Mdot
.556 .49001 Mdot
.556 .49003 Mdot
.556 .4901 Mdot
.556 .49011 Mdot
.556 .49016 Mdot
.556 .4902 Mdot
.556 .49033 Mdot
.556 .4905 Mdot
.556 .49053 Mdot
.556 .49074 Mdot
.556 .49084 Mdot
.556 .49138 Mdot
.556 .49149 Mdot
.556 .49152 Mdot
.556 .49226 Mdot
.556 .49237 Mdot
.556 .49249 Mdot
.556 .49255 Mdot
.556 .49269 Mdot
.556 .49289 Mdot
.556 .49321 Mdot
.556 .49381 Mdot
.556 .49402 Mdot
.556 .49407 Mdot
.556 .49418 Mdot
.556 .49427 Mdot
.556 .49427 Mdot
.556 .49441 Mdot
.556 .49446 Mdot
.556 .49468 Mdot
.556 .49474 Mdot
.556 .49477 Mdot
.556 .49511 Mdot
.556 .49514 Mdot
.556 .49543 Mdot
.556 .49589 Mdot
.556 .4959 Mdot
.556 .496 Mdot
.556 .49661 Mdot
.556 .49679 Mdot
.556 .49698 Mdot
.556 .49698 Mdot
.556 .49706 Mdot
.556 .49721 Mdot
.556 .49725 Mdot
.556 .49738 Mdot
.556 .49745 Mdot
.556 .49767 Mdot
.556 .49775 Mdot
.556 .49779 Mdot
.556 .49782 Mdot
.556 .49792 Mdot
.556 .49797 Mdot
.556 .49828 Mdot
.556 .49834 Mdot
.556 .49841 Mdot
.556 .49847 Mdot
.556 .49849 Mdot
.556 .499 Mdot
.556 .49964 Mdot
.556 .49981 Mdot
.556 .50021 Mdot
.556 .50038 Mdot
.556 .50057 Mdot
.556 .50127 Mdot
.556 .50192 Mdot
.556 .50207 Mdot
.556 .50224 Mdot
.556 .50239 Mdot
.556 .50323 Mdot
.556 .50335 Mdot
.556 .50341 Mdot
.556 .50377 Mdot
.556 .50402 Mdot
.556 .50408 Mdot
.556 .50424 Mdot
.556 .50468 Mdot
.556 .50478 Mdot
.556 .50518 Mdot
.556 .50572 Mdot
.556 .5059 Mdot
.556 .50606 Mdot
.556 .50609 Mdot
.556 .50624 Mdot
.556 .50637 Mdot
.556 .5065 Mdot
.556 .50661 Mdot
.556 .50714 Mdot
.556 .50747 Mdot
.556 .50795 Mdot
.556 .50815 Mdot
.556 .50999 Mdot
.556 .51007 Mdot
.556 .51013 Mdot
.556 .5105 Mdot
.556 .51161 Mdot
.556 .51237 Mdot
.556 .51245 Mdot
.556 .51271 Mdot
.556 .51273 Mdot
.556 .51292 Mdot
.556 .51304 Mdot
.556 .51325 Mdot
.556 .51333 Mdot
.556 .51342 Mdot
.556 .51469 Mdot
.556 .51473 Mdot
.556 .51483 Mdot
.556 .51507 Mdot
.556 .51541 Mdot
.556 .51569 Mdot
.556 .51591 Mdot
.556 .51628 Mdot
.556 .51642 Mdot
.556 .51648 Mdot
.556 .51723 Mdot
.556 .51737 Mdot
.556 .51747 Mdot
.556 .5177 Mdot
.556 .51778 Mdot
.556 .51795 Mdot
.556 .51833 Mdot
.556 .51851 Mdot
.556 .51879 Mdot
.556 .51902 Mdot
.556 .51913 Mdot
.556 .51926 Mdot
.556 .51952 Mdot
.556 .51962 Mdot
.556 .51966 Mdot
.556 .51967 Mdot
.556 .52006 Mdot
.556 .52007 Mdot
.556 .52011 Mdot
.556 .52036 Mdot
.556 .52061 Mdot
.556 .52118 Mdot
.556 .52129 Mdot
.556 .52139 Mdot
.556 .52141 Mdot
.556 .52149 Mdot
.556 .52168 Mdot
.556 .52194 Mdot
.556 .52194 Mdot
.556 .52226 Mdot
.556 .52228 Mdot
.556 .52229 Mdot
.556 .5232 Mdot
.556 .52359 Mdot
.556 .52384 Mdot
.556 .52436 Mdot
.556 .52452 Mdot
.556 .52497 Mdot
.556 .52505 Mdot
.556 .52617 Mdot
.556 .5264 Mdot
.556 .52664 Mdot
.556 .52694 Mdot
.556 .52713 Mdot
.556 .52723 Mdot
.556 .52724 Mdot
.556 .52731 Mdot
.556 .52755 Mdot
.556 .52761 Mdot
.556 .52767 Mdot
.556 .52797 Mdot
.556 .52868 Mdot
.556 .52887 Mdot
.556 .52894 Mdot
.556 .52903 Mdot
.556 .52938 Mdot
.556 .52973 Mdot
.556 .53025 Mdot
.556 .53043 Mdot
.556 .53046 Mdot
.556 .53061 Mdot
.556 .53061 Mdot
.556 .53074 Mdot
.556 .53089 Mdot
.556 .53111 Mdot
.556 .53193 Mdot
.556 .53216 Mdot
.556 .53227 Mdot
.556 .53244 Mdot
.556 .53283 Mdot
.556 .53284 Mdot
.556 .53298 Mdot
.556 .53309 Mdot
.556 .53321 Mdot
.556 .53321 Mdot
.556 .53325 Mdot
.556 .53364 Mdot
.556 .53374 Mdot
.556 .53376 Mdot
.556 .53377 Mdot
.556 .53394 Mdot
.556 .53398 Mdot
.556 .53428 Mdot
.556 .53468 Mdot
.556 .5348 Mdot
.556 .53489 Mdot
.556 .53521 Mdot
.556 .5356 Mdot
.556 .53585 Mdot
.556 .5364 Mdot
.556 .537 Mdot
.556 .53739 Mdot
.556 .53752 Mdot
.556 .53754 Mdot
.556 .53821 Mdot
.556 .53828 Mdot
.556 .53844 Mdot
.556 .53873 Mdot
.556 .53885 Mdot
.556 .53891 Mdot
.556 .53897 Mdot
.556 .5392 Mdot
.556 .53956 Mdot
.556 .53966 Mdot
.556 .54011 Mdot
.556 .54021 Mdot
.556 .54046 Mdot
.556 .54074 Mdot
.556 .54079 Mdot
.556 .54091 Mdot
.556 .54097 Mdot
.556 .54132 Mdot
.556 .54133 Mdot
.556 .54134 Mdot
.556 .54136 Mdot
.556 .54148 Mdot
.556 .54149 Mdot
.556 .54152 Mdot
.556 .54155 Mdot
.556 .54157 Mdot
.556 .54164 Mdot
.556 .54166 Mdot
.556 .54171 Mdot
.556 .54175 Mdot
.556 .54178 Mdot
.556 .54178 Mdot
.556 .54189 Mdot
.556 .54207 Mdot
.556 .5421 Mdot
.556 .5421 Mdot
.556 .54232 Mdot
.556 .54233 Mdot
.556 .54243 Mdot
.556 .54244 Mdot
.556 .54246 Mdot
.556 .54258 Mdot
.556 .54271 Mdot
.556 .54298 Mdot
.556 .54309 Mdot
.556 .54313 Mdot
.556 .54338 Mdot
.556 .54366 Mdot
.556 .54385 Mdot
.556 .54394 Mdot
.556 .54395 Mdot
.556 .54398 Mdot
.556 .544 Mdot
.556 .54406 Mdot
.556 .54413 Mdot
.556 .54425 Mdot
.556 .54441 Mdot
.556 .54443 Mdot
.556 .54444 Mdot
.556 .54447 Mdot
.556 .54457 Mdot
.556 .54473 Mdot
.556 .54484 Mdot
.556 .54496 Mdot
.556 .54508 Mdot
.556 .54526 Mdot
.556 .54531 Mdot
.556 .54544 Mdot
.556 .54548 Mdot
.556 .54557 Mdot
.556 .54558 Mdot
.556 .54565 Mdot
.556 .54565 Mdot
.556 .54575 Mdot
.556 .54577 Mdot
.556 .54581 Mdot
.556 .54599 Mdot
.556 .54604 Mdot
.556 .54607 Mdot
.556 .5461 Mdot
.556 .54625 Mdot
.556 .54632 Mdot
.556 .54633 Mdot
.556 .54636 Mdot
.556 .54653 Mdot
.556 .54658 Mdot
.556 .54661 Mdot
.556 .54673 Mdot
.556 .54693 Mdot
.556 .54694 Mdot
.556 .54701 Mdot
.556 .54734 Mdot
.556 .54738 Mdot
.556 .54745 Mdot
.556 .54749 Mdot
.556 .54757 Mdot
.556 .5477 Mdot
.556 .5477 Mdot
.556 .54776 Mdot
.556 .54777 Mdot
.556 .54786 Mdot
.556 .54788 Mdot
.556 .54793 Mdot
.556 .54796 Mdot
.556 .54801 Mdot
.556 .54812 Mdot
.556 .54815 Mdot
.556 .5482 Mdot
.556 .54822 Mdot
.556 .54824 Mdot
.556 .5483 Mdot
.556 .54833 Mdot
.556 .54835 Mdot
.556 .54851 Mdot
.556 .54852 Mdot
.556 .54856 Mdot
.556 .54857 Mdot
.556 .54859 Mdot
.556 .5486 Mdot
.556 .54863 Mdot
.556 .54864 Mdot
.556 .54892 Mdot
.556 .54925 Mdot
.556 .54933 Mdot
.556 .54934 Mdot
.556 .54937 Mdot
.556 .54942 Mdot
.556 .54952 Mdot
.556 .54953 Mdot
.556 .54958 Mdot
.556 .5496 Mdot
.556 .54967 Mdot
.556 .54968 Mdot
.556 .54969 Mdot
.556 .5498 Mdot
.556 .54983 Mdot
.556 .54998 Mdot
.556 .55014 Mdot
.556 .55022 Mdot
.556 .55027 Mdot
.556 .55032 Mdot
.556 .55037 Mdot
.556 .55051 Mdot
.556 .55061 Mdot
.556 .55061 Mdot
.556 .55063 Mdot
.556 .55064 Mdot
.556 .55065 Mdot
.556 .55065 Mdot
.556 .55073 Mdot
.556 .55078 Mdot
.556 .5508 Mdot
.556 .55083 Mdot
.556 .5509 Mdot
.556 .55091 Mdot
.556 .55096 Mdot
.556 .55097 Mdot
.556 .55099 Mdot
.556 .55101 Mdot
.556 .55103 Mdot
.556 .55103 Mdot
.556 .55103 Mdot
.556 .55104 Mdot
.556 .55104 Mdot
.556 .55104 Mdot
.556 .55105 Mdot
.556 .55105 Mdot
.556 .55105 Mdot
.558 .18769 Mdot
.558 .18773 Mdot
.558 .18774 Mdot
.558 .18775 Mdot
.558 .18781 Mdot
.558 .18784 Mdot
.558 .18787 Mdot
.558 .18791 Mdot
.558 .18793 Mdot
.558 .18807 Mdot
.558 .18808 Mdot
.558 .18812 Mdot
.558 .18814 Mdot
.558 .18819 Mdot
.558 .18824 Mdot
.558 .18836 Mdot
.558 .18848 Mdot
.558 .18856 Mdot
.558 .18878 Mdot
.558 .18884 Mdot
.558 .18895 Mdot
.558 .18897 Mdot
.558 .18903 Mdot
.558 .18908 Mdot
.558 .18921 Mdot
.558 .18928 Mdot
.558 .18935 Mdot
.558 .18941 Mdot
.558 .18951 Mdot
.558 .18973 Mdot
.558 .18995 Mdot
.558 .18999 Mdot
.558 .19 Mdot
.558 .19012 Mdot
.558 .19015 Mdot
.558 .19017 Mdot
.558 .19021 Mdot
.558 .19025 Mdot
.558 .1905 Mdot
.558 .19056 Mdot
.558 .1906 Mdot
.558 .19072 Mdot
.558 .19073 Mdot
.558 .19079 Mdot
.558 .1911 Mdot
.558 .19137 Mdot
.558 .19142 Mdot
.558 .19148 Mdot
.558 .19164 Mdot
.558 .19182 Mdot
.558 .19208 Mdot
.558 .19256 Mdot
.558 .19267 Mdot
.558 .19291 Mdot
.558 .19302 Mdot
.558 .19365 Mdot
.558 .19366 Mdot
.558 .19403 Mdot
.558 .19407 Mdot
.558 .19416 Mdot
.558 .19416 Mdot
.558 .1946 Mdot
.558 .19469 Mdot
.558 .19471 Mdot
.558 .19493 Mdot
.558 .19499 Mdot
.558 .19502 Mdot
.558 .19515 Mdot
.558 .19538 Mdot
.558 .19555 Mdot
.558 .19567 Mdot
.558 .1957 Mdot
.558 .19575 Mdot
.558 .19592 Mdot
.558 .19628 Mdot
.558 .19659 Mdot
.558 .1971 Mdot
.558 .19738 Mdot
.558 .19742 Mdot
.558 .19781 Mdot
.558 .19788 Mdot
.558 .19809 Mdot
.558 .19827 Mdot
.558 .19839 Mdot
.558 .1985 Mdot
.558 .19869 Mdot
.558 .19911 Mdot
.558 .1992 Mdot
.558 .19952 Mdot
.558 .19964 Mdot
.558 .19968 Mdot
.558 .19992 Mdot
.558 .20011 Mdot
.558 .20105 Mdot
.558 .20117 Mdot
.558 .20154 Mdot
.558 .20196 Mdot
.558 .20224 Mdot
.558 .20247 Mdot
.558 .2026 Mdot
.558 .20293 Mdot
.558 .20329 Mdot
.558 .20387 Mdot
.558 .20412 Mdot
.558 .20464 Mdot
.558 .20478 Mdot
.558 .20499 Mdot
.558 .20506 Mdot
.558 .20521 Mdot
.558 .20539 Mdot
.558 .20556 Mdot
.558 .20586 Mdot
.558 .20592 Mdot
.558 .20657 Mdot
.558 .20696 Mdot
.558 .2071 Mdot
.558 .20721 Mdot
.558 .20726 Mdot
.558 .20745 Mdot
.558 .20795 Mdot
.558 .20823 Mdot
.558 .20854 Mdot
.558 .20866 Mdot
.558 .20922 Mdot
.558 .20945 Mdot
.558 .20984 Mdot
.558 .21041 Mdot
.558 .21198 Mdot
.558 .21199 Mdot
.558 .2124 Mdot
.558 .21268 Mdot
.558 .21277 Mdot
.558 .21351 Mdot
.558 .21408 Mdot
.558 .2148 Mdot
.558 .21518 Mdot
.558 .21534 Mdot
.558 .21555 Mdot
.558 .21592 Mdot
.558 .21631 Mdot
.558 .21634 Mdot
.558 .21641 Mdot
.558 .21661 Mdot
.558 .21668 Mdot
.558 .21713 Mdot
.558 .21718 Mdot
.558 .2172 Mdot
.558 .21877 Mdot
.558 .21905 Mdot
.558 .21934 Mdot
.558 .21948 Mdot
.558 .21952 Mdot
.558 .21982 Mdot
.558 .21995 Mdot
.558 .22021 Mdot
.558 .22043 Mdot
.558 .22076 Mdot
.558 .22096 Mdot
.558 .22103 Mdot
.558 .22107 Mdot
.558 .2212 Mdot
.558 .22128 Mdot
.558 .22159 Mdot
.558 .22245 Mdot
.558 .22308 Mdot
.558 .22465 Mdot
.558 .2249 Mdot
.558 .22551 Mdot
.558 .22571 Mdot
.558 .22622 Mdot
.558 .22684 Mdot
.558 .22865 Mdot
.558 .22891 Mdot
.558 .22932 Mdot
.558 .23171 Mdot
.558 .23202 Mdot
.558 .23204 Mdot
.558 .23346 Mdot
.558 .23428 Mdot
.558 .23454 Mdot
.558 .23519 Mdot
.558 .23574 Mdot
.558 .23593 Mdot
.558 .23631 Mdot
.558 .2369 Mdot
.558 .23734 Mdot
.558 .2381 Mdot
.558 .23939 Mdot
.558 .23976 Mdot
.558 .2403 Mdot
.558 .24075 Mdot
.558 .24212 Mdot
.558 .24437 Mdot
.558 .24449 Mdot
.558 .24524 Mdot
.558 .24654 Mdot
.558 .24719 Mdot
.558 .24743 Mdot
.558 .2485 Mdot
.558 .24902 Mdot
.558 .24952 Mdot
.558 .24977 Mdot
.558 .25002 Mdot
.558 .25053 Mdot
.558 .25107 Mdot
.558 .25153 Mdot
.558 .25258 Mdot
.558 .25264 Mdot
.558 .25479 Mdot
.558 .25508 Mdot
.558 .25528 Mdot
.558 .25664 Mdot
.558 .25728 Mdot
.558 .25796 Mdot
.558 .25938 Mdot
.558 .26098 Mdot
.558 .26123 Mdot
.558 .26367 Mdot
.558 .26483 Mdot
.558 .26613 Mdot
.558 .26634 Mdot
.558 .26655 Mdot
.558 .26729 Mdot
.558 .26916 Mdot
.558 .26935 Mdot
.558 .26992 Mdot
.558 .27018 Mdot
.558 .2714 Mdot
.558 .27223 Mdot
.558 .27255 Mdot
.558 .27377 Mdot
.558 .27453 Mdot
.558 .27517 Mdot
.558 .27527 Mdot
.558 .27647 Mdot
.558 .27693 Mdot
.558 .2778 Mdot
.558 .27795 Mdot
.558 .27832 Mdot
.558 .27934 Mdot
.558 .28022 Mdot
.558 .28066 Mdot
.558 .28089 Mdot
.558 .28116 Mdot
.558 .28195 Mdot
.558 .28305 Mdot
.558 .2835 Mdot
.558 .28412 Mdot
.558 .28609 Mdot
.558 .28643 Mdot
.558 .2886 Mdot
.558 .28951 Mdot
.558 .28955 Mdot
.558 .2903 Mdot
.558 .29103 Mdot
.558 .29221 Mdot
.558 .29259 Mdot
.558 .29277 Mdot
.558 .2936 Mdot
.558 .29481 Mdot
.558 .2962 Mdot
.558 .29646 Mdot
.558 .29722 Mdot
.558 .29732 Mdot
.558 .29753 Mdot
.558 .29785 Mdot
.558 .29795 Mdot
.558 .29952 Mdot
.558 .29971 Mdot
.558 .30031 Mdot
.558 .30241 Mdot
.558 .30349 Mdot
.558 .30399 Mdot
.558 .30412 Mdot
.558 .30437 Mdot
.558 .30528 Mdot
.558 .30578 Mdot
.558 .30705 Mdot
.558 .30713 Mdot
.558 .30734 Mdot
.558 .30799 Mdot
.558 .31172 Mdot
.558 .31203 Mdot
.558 .31258 Mdot
.558 .31368 Mdot
.558 .31428 Mdot
.558 .31509 Mdot
.558 .31592 Mdot
.558 .31672 Mdot
.558 .31694 Mdot
.558 .31729 Mdot
.558 .31739 Mdot
.558 .31756 Mdot
.558 .3181 Mdot
.558 .31868 Mdot
.558 .31896 Mdot
.558 .31954 Mdot
.558 .32022 Mdot
.558 .32057 Mdot
.558 .32061 Mdot
.558 .32135 Mdot
.558 .32148 Mdot
.558 .32185 Mdot
.558 .32198 Mdot
.558 .32261 Mdot
.558 .32314 Mdot
.558 .32335 Mdot
.558 .32364 Mdot
.558 .32397 Mdot
.558 .32601 Mdot
.558 .32698 Mdot
.558 .32755 Mdot
.558 .3276 Mdot
.558 .32773 Mdot
.558 .32837 Mdot
.558 .32883 Mdot
.558 .32891 Mdot
.558 .32895 Mdot
.558 .32911 Mdot
.558 .32966 Mdot
.558 .32982 Mdot
.558 .32985 Mdot
.558 .32992 Mdot
.558 .33014 Mdot
.558 .33059 Mdot
.558 .33099 Mdot
.558 .33199 Mdot
.558 .33244 Mdot
.558 .33253 Mdot
.558 .33277 Mdot
.558 .33298 Mdot
.558 .33311 Mdot
.558 .33324 Mdot
.558 .33345 Mdot
.558 .33401 Mdot
.558 .33437 Mdot
.558 .33449 Mdot
.558 .33479 Mdot
.558 .33597 Mdot
.558 .33646 Mdot
.558 .3375 Mdot
.558 .33815 Mdot
.558 .33893 Mdot
.558 .3394 Mdot
.558 .33953 Mdot
.558 .33978 Mdot
.558 .33992 Mdot
.558 .34049 Mdot
.558 .34054 Mdot
.558 .34144 Mdot
.558 .34165 Mdot
.558 .34169 Mdot
.558 .34185 Mdot
.558 .34228 Mdot
.558 .3425 Mdot
.558 .34332 Mdot
.558 .34381 Mdot
.558 .34549 Mdot
.558 .34601 Mdot
.558 .34608 Mdot
.558 .34705 Mdot
.558 .34758 Mdot
.558 .34797 Mdot
.558 .34838 Mdot
.558 .34866 Mdot
.558 .34873 Mdot
.558 .34892 Mdot
.558 .34923 Mdot
.558 .34927 Mdot
.558 .34928 Mdot
.558 .35036 Mdot
.558 .35055 Mdot
.558 .35084 Mdot
.558 .35087 Mdot
.558 .35107 Mdot
.558 .35116 Mdot
.558 .35133 Mdot
.558 .35183 Mdot
.558 .35188 Mdot
.558 .35199 Mdot
.558 .35204 Mdot
.558 .35224 Mdot
.558 .3528 Mdot
.558 .3542 Mdot
.558 .35474 Mdot
.558 .35486 Mdot
.558 .35518 Mdot
.558 .35556 Mdot
.558 .35666 Mdot
.558 .35846 Mdot
.558 .35864 Mdot
.558 .35946 Mdot
.558 .35993 Mdot
.558 .36045 Mdot
.558 .36086 Mdot
.558 .36107 Mdot
.558 .36164 Mdot
.558 .36205 Mdot
.558 .36349 Mdot
.558 .36421 Mdot
.558 .36584 Mdot
.558 .36684 Mdot
.558 .36776 Mdot
.558 .36814 Mdot
.558 .36879 Mdot
.558 .36956 Mdot
.558 .37075 Mdot
.558 .3718 Mdot
.558 .37212 Mdot
.558 .37479 Mdot
.558 .37532 Mdot
.558 .37601 Mdot
.558 .3761 Mdot
.558 .37644 Mdot
.558 .37736 Mdot
.558 .37762 Mdot
.558 .37878 Mdot
.558 .37932 Mdot
.558 .37965 Mdot
.558 .37997 Mdot
.558 .38049 Mdot
.558 .38107 Mdot
.558 .38129 Mdot
.558 .38239 Mdot
.558 .3825 Mdot
.558 .3833 Mdot
.558 .38472 Mdot
.558 .38562 Mdot
.558 .38662 Mdot
.558 .3871 Mdot
.558 .38725 Mdot
.558 .38733 Mdot
.558 .38766 Mdot
.558 .38815 Mdot
.558 .38882 Mdot
.558 .38917 Mdot
.558 .38925 Mdot
.558 .38942 Mdot
.558 .39005 Mdot
.558 .39012 Mdot
.558 .39036 Mdot
.558 .39162 Mdot
.558 .39187 Mdot
.558 .39197 Mdot
.558 .39302 Mdot
.558 .39305 Mdot
.558 .39483 Mdot
.558 .39516 Mdot
.558 .39582 Mdot
.558 .39613 Mdot
.558 .3975 Mdot
.558 .39823 Mdot
.558 .39874 Mdot
.558 .39918 Mdot
.558 .39937 Mdot
.558 .3995 Mdot
.558 .40026 Mdot
.558 .40114 Mdot
.558 .40131 Mdot
.558 .40134 Mdot
.558 .40168 Mdot
.558 .4018 Mdot
.558 .40197 Mdot
.558 .40265 Mdot
.558 .40277 Mdot
.558 .4029 Mdot
.558 .40295 Mdot
.558 .40303 Mdot
.558 .40336 Mdot
.558 .40341 Mdot
.558 .40352 Mdot
.558 .40414 Mdot
.558 .40476 Mdot
.558 .40504 Mdot
.558 .40521 Mdot
.558 .4054 Mdot
.558 .40561 Mdot
.558 .40596 Mdot
.558 .40611 Mdot
.558 .40627 Mdot
.558 .40635 Mdot
.558 .40665 Mdot
.558 .40683 Mdot
.558 .40744 Mdot
.558 .40765 Mdot
.558 .408 Mdot
.558 .40834 Mdot
.558 .40848 Mdot
.558 .40861 Mdot
.558 .40868 Mdot
.558 .40879 Mdot
.558 .4088 Mdot
.558 .4092 Mdot
.558 .40927 Mdot
.558 .40938 Mdot
.558 .40946 Mdot
.558 .40955 Mdot
.558 .40973 Mdot
.558 .40975 Mdot
.558 .40979 Mdot
.558 .40988 Mdot
.558 .4601 Mdot
.558 .46015 Mdot
.558 .46017 Mdot
.558 .46018 Mdot
.558 .46028 Mdot
.558 .46033 Mdot
.558 .46036 Mdot
.558 .46043 Mdot
.558 .46046 Mdot
.558 .46067 Mdot
.558 .46068 Mdot
.558 .46074 Mdot
.558 .46078 Mdot
.558 .46084 Mdot
.558 .46092 Mdot
.558 .4611 Mdot
.558 .46129 Mdot
.558 .4614 Mdot
.558 .46172 Mdot
.558 .46182 Mdot
.558 .46197 Mdot
.558 .46202 Mdot
.558 .4621 Mdot
.558 .46218 Mdot
.558 .46236 Mdot
.558 .46247 Mdot
.558 .46257 Mdot
.558 .46266 Mdot
.558 .46281 Mdot
.558 .46314 Mdot
.558 .46346 Mdot
.558 .46352 Mdot
.558 .46354 Mdot
.558 .46372 Mdot
.558 .46376 Mdot
.558 .46378 Mdot
.558 .46385 Mdot
.558 .46391 Mdot
.558 .46427 Mdot
.558 .46436 Mdot
.558 .46442 Mdot
.558 .46459 Mdot
.558 .46461 Mdot
.558 .4647 Mdot
.558 .46515 Mdot
.558 .46555 Mdot
.558 .46561 Mdot
.558 .46571 Mdot
.558 .46593 Mdot
.558 .4662 Mdot
.558 .46658 Mdot
.558 .46728 Mdot
.558 .46743 Mdot
.558 .46777 Mdot
.558 .46794 Mdot
.558 .46884 Mdot
.558 .46885 Mdot
.558 .46938 Mdot
.558 .46943 Mdot
.558 .46956 Mdot
.558 .47019 Mdot
.558 .47031 Mdot
.558 .47035 Mdot
.558 .47066 Mdot
.558 .47074 Mdot
.558 .47079 Mdot
.558 .47096 Mdot
.558 .47129 Mdot
.558 .47153 Mdot
.558 .4717 Mdot
.558 .47174 Mdot
.558 .47181 Mdot
.558 .47205 Mdot
.558 .47255 Mdot
.558 .47299 Mdot
.558 .47369 Mdot
.558 .47408 Mdot
.558 .47413 Mdot
.558 .47467 Mdot
.558 .47478 Mdot
.558 .47506 Mdot
.558 .47531 Mdot
.558 .47547 Mdot
.558 .47563 Mdot
.558 .47589 Mdot
.558 .47645 Mdot
.558 .47657 Mdot
.558 .47702 Mdot
.558 .47718 Mdot
.558 .47722 Mdot
.558 .47755 Mdot
.558 .47781 Mdot
.558 .47908 Mdot
.558 .47923 Mdot
.558 .47973 Mdot
.558 .48029 Mdot
.558 .48065 Mdot
.558 .48096 Mdot
.558 .48113 Mdot
.558 .48157 Mdot
.558 .48203 Mdot
.558 .48279 Mdot
.558 .48313 Mdot
.558 .48379 Mdot
.558 .48398 Mdot
.558 .48425 Mdot
.558 .48434 Mdot
.558 .48453 Mdot
.558 .48477 Mdot
.558 .48498 Mdot
.558 .48536 Mdot
.558 .48544 Mdot
.558 .48627 Mdot
.558 .48677 Mdot
.558 .48694 Mdot
.558 .48708 Mdot
.558 .48714 Mdot
.558 .48738 Mdot
.558 .48801 Mdot
.558 .48827 Mdot
.558 .48835 Mdot
.558 .48838 Mdot
.558 .48843 Mdot
.558 .48845 Mdot
.558 .48867 Mdot
.558 .48875 Mdot
.558 .48879 Mdot
.558 .48888 Mdot
.558 .48889 Mdot
.558 .48902 Mdot
.558 .48911 Mdot
.558 .48959 Mdot
.558 .4896 Mdot
.558 .48961 Mdot
.558 .48976 Mdot
.558 .48984 Mdot
.558 .48987 Mdot
.558 .48999 Mdot
.558 .49018 Mdot
.558 .49035 Mdot
.558 .49059 Mdot
.558 .49102 Mdot
.558 .49105 Mdot
.558 .49128 Mdot
.558 .49202 Mdot
.558 .49224 Mdot
.558 .4926 Mdot
.558 .4927 Mdot
.558 .49288 Mdot
.558 .49295 Mdot
.558 .49297 Mdot
.558 .49306 Mdot
.558 .49346 Mdot
.558 .49348 Mdot
.558 .49373 Mdot
.558 .49379 Mdot
.558 .4939 Mdot
.558 .49396 Mdot
.558 .49416 Mdot
.558 .4945 Mdot
.558 .49479 Mdot
.558 .49524 Mdot
.558 .49545 Mdot
.558 .49596 Mdot
.558 .49609 Mdot
.558 .49614 Mdot
.558 .49629 Mdot
.558 .49653 Mdot
.558 .49663 Mdot
.558 .49668 Mdot
.558 .49674 Mdot
.558 .49683 Mdot
.558 .49693 Mdot
.558 .49697 Mdot
.558 .49716 Mdot
.558 .49759 Mdot
.558 .49776 Mdot
.558 .49795 Mdot
.558 .49805 Mdot
.558 .49808 Mdot
.558 .49809 Mdot
.558 .49816 Mdot
.558 .49839 Mdot
.558 .49846 Mdot
.558 .49848 Mdot
.558 .49851 Mdot
.558 .49871 Mdot
.558 .49898 Mdot
.558 .49904 Mdot
.558 .49906 Mdot
.558 .49971 Mdot
.558 .50057 Mdot
.558 .50071 Mdot
.558 .50083 Mdot
.558 .50092 Mdot
.558 .50114 Mdot
.558 .50141 Mdot
.558 .50146 Mdot
.558 .50162 Mdot
.558 .50167 Mdot
.558 .50198 Mdot
.558 .502 Mdot
.558 .50215 Mdot
.558 .50243 Mdot
.558 .50267 Mdot
.558 .50279 Mdot
.558 .50303 Mdot
.558 .50325 Mdot
.558 .50333 Mdot
.558 .50337 Mdot
.558 .50351 Mdot
.558 .5036 Mdot
.558 .50393 Mdot
.558 .50428 Mdot
.558 .50461 Mdot
.558 .50486 Mdot
.558 .50531 Mdot
.558 .50554 Mdot
.558 .50567 Mdot
.558 .50719 Mdot
.558 .50746 Mdot
.558 .50754 Mdot
.558 .50757 Mdot
.558 .50809 Mdot
.558 .50829 Mdot
.558 .50866 Mdot
.558 .50876 Mdot
.558 .50881 Mdot
.558 .50901 Mdot
.558 .50945 Mdot
.558 .5103 Mdot
.558 .51053 Mdot
.558 .51061 Mdot
.558 .51124 Mdot
.558 .51128 Mdot
.558 .51141 Mdot
.558 .51149 Mdot
.558 .51153 Mdot
.558 .51183 Mdot
.558 .51193 Mdot
.558 .51249 Mdot
.558 .51297 Mdot
.558 .5133 Mdot
.558 .51337 Mdot
.558 .51352 Mdot
.558 .51398 Mdot
.558 .51427 Mdot
.558 .51456 Mdot
.558 .51458 Mdot
.558 .51494 Mdot
.558 .51578 Mdot
.558 .51592 Mdot
.558 .51668 Mdot
.558 .51692 Mdot
.558 .5171 Mdot
.558 .51753 Mdot
.558 .51783 Mdot
.558 .51794 Mdot
.558 .51802 Mdot
.558 .5182 Mdot
.558 .51853 Mdot
.558 .51893 Mdot
.558 .51907 Mdot
.558 .51913 Mdot
.558 .51946 Mdot
.558 .51964 Mdot
.558 .5201 Mdot
.558 .52013 Mdot
.558 .52038 Mdot
.558 .52067 Mdot
.558 .52113 Mdot
.558 .52126 Mdot
.558 .52157 Mdot
.558 .52203 Mdot
.558 .52213 Mdot
.558 .52235 Mdot
.558 .52242 Mdot
.558 .52313 Mdot
.558 .5234 Mdot
.558 .52349 Mdot
.558 .52356 Mdot
.558 .52405 Mdot
.558 .52449 Mdot
.558 .5254 Mdot
.558 .52549 Mdot
.558 .52609 Mdot
.558 .52662 Mdot
.558 .52687 Mdot
.558 .5271 Mdot
.558 .52761 Mdot
.558 .52768 Mdot
.558 .52779 Mdot
.558 .52858 Mdot
.558 .5286 Mdot
.558 .52899 Mdot
.558 .52915 Mdot
.558 .52935 Mdot
.558 .52954 Mdot
.558 .52963 Mdot
.558 .52972 Mdot
.558 .52991 Mdot
.558 .53009 Mdot
.558 .53049 Mdot
.558 .53057 Mdot
.558 .53081 Mdot
.558 .53128 Mdot
.558 .53156 Mdot
.558 .5316 Mdot
.558 .53241 Mdot
.558 .53291 Mdot
.558 .53307 Mdot
.558 .53326 Mdot
.558 .5334 Mdot
.558 .53386 Mdot
.558 .53413 Mdot
.558 .53429 Mdot
.558 .5345 Mdot
.558 .53464 Mdot
.558 .53471 Mdot
.558 .5349 Mdot
.558 .53513 Mdot
.558 .53523 Mdot
.558 .53552 Mdot
.558 .53603 Mdot
.558 .53603 Mdot
.558 .53614 Mdot
.558 .53699 Mdot
.558 .53714 Mdot
.558 .53723 Mdot
.558 .53787 Mdot
.558 .53809 Mdot
.558 .53827 Mdot
.558 .53833 Mdot
.558 .53855 Mdot
.558 .53864 Mdot
.558 .53919 Mdot
.558 .53941 Mdot
.558 .53971 Mdot
.558 .53982 Mdot
.558 .53985 Mdot
.558 .53989 Mdot
.558 .53991 Mdot
.558 .53993 Mdot
.558 .54 Mdot
.558 .54012 Mdot
.558 .54019 Mdot
.558 .54028 Mdot
.558 .54033 Mdot
.558 .54043 Mdot
.558 .54045 Mdot
.558 .5405 Mdot
.558 .5406 Mdot
.558 .5407 Mdot
.558 .54124 Mdot
.558 .54125 Mdot
.558 .54127 Mdot
.558 .54142 Mdot
.558 .54145 Mdot
.558 .54152 Mdot
.558 .54154 Mdot
.558 .54155 Mdot
.558 .54169 Mdot
.558 .54182 Mdot
.558 .54189 Mdot
.558 .54194 Mdot
.558 .54207 Mdot
.558 .54232 Mdot
.558 .54252 Mdot
.558 .54278 Mdot
.558 .54281 Mdot
.558 .5429 Mdot
.558 .54304 Mdot
.558 .54305 Mdot
.558 .54359 Mdot
.558 .54379 Mdot
.558 .54392 Mdot
.558 .544 Mdot
.558 .54419 Mdot
.558 .54423 Mdot
.558 .54434 Mdot
.558 .54443 Mdot
.558 .54461 Mdot
.558 .54467 Mdot
.558 .54469 Mdot
.558 .54473 Mdot
.558 .54477 Mdot
.558 .54491 Mdot
.558 .54513 Mdot
.558 .54515 Mdot
.558 .54525 Mdot
.558 .54531 Mdot
.558 .54537 Mdot
.558 .54542 Mdot
.558 .54545 Mdot
.558 .54552 Mdot
.558 .54557 Mdot
.558 .54574 Mdot
.558 .54583 Mdot
.558 .54603 Mdot
.558 .54615 Mdot
.558 .54626 Mdot
.558 .54631 Mdot
.558 .54639 Mdot
.558 .54648 Mdot
.558 .54662 Mdot
.558 .54675 Mdot
.558 .54679 Mdot
.558 .54711 Mdot
.558 .54717 Mdot
.558 .54725 Mdot
.558 .54727 Mdot
.558 .54731 Mdot
.558 .54742 Mdot
.558 .54745 Mdot
.558 .54759 Mdot
.558 .54765 Mdot
.558 .54769 Mdot
.558 .54773 Mdot
.558 .54779 Mdot
.558 .54786 Mdot
.558 .54789 Mdot
.558 .54802 Mdot
.558 .54803 Mdot
.558 .54813 Mdot
.558 .5483 Mdot
.558 .5484 Mdot
.558 .54852 Mdot
.558 .54858 Mdot
.558 .5486 Mdot
.558 .54861 Mdot
.558 .54865 Mdot
.558 .54871 Mdot
.558 .54878 Mdot
.558 .54883 Mdot
.558 .54884 Mdot
.558 .54886 Mdot
.558 .54893 Mdot
.558 .54894 Mdot
.558 .54897 Mdot
.558 .54912 Mdot
.558 .54912 Mdot
.558 .54915 Mdot
.558 .54916 Mdot
.558 .54928 Mdot
.558 .54929 Mdot
.558 .5495 Mdot
.558 .54954 Mdot
.558 .54961 Mdot
.558 .54965 Mdot
.558 .54981 Mdot
.558 .5499 Mdot
.558 .54996 Mdot
.558 .55001 Mdot
.558 .55004 Mdot
.558 .55005 Mdot
.558 .55014 Mdot
.558 .55025 Mdot
.558 .55027 Mdot
.558 .55027 Mdot
.558 .55031 Mdot
.558 .55032 Mdot
.558 .55034 Mdot
.558 .55042 Mdot
.558 .55044 Mdot
.558 .55045 Mdot
.558 .55046 Mdot
.558 .55047 Mdot
.558 .55051 Mdot
.558 .55051 Mdot
.558 .55053 Mdot
.558 .5506 Mdot
.558 .55067 Mdot
.558 .55071 Mdot
.558 .55073 Mdot
.558 .55075 Mdot
.558 .55078 Mdot
.558 .55082 Mdot
.558 .55083 Mdot
.558 .55085 Mdot
.558 .55086 Mdot
.558 .5509 Mdot
.558 .55092 Mdot
.558 .55099 Mdot
.558 .55102 Mdot
.558 .55106 Mdot
.558 .5511 Mdot
.558 .55112 Mdot
.558 .55113 Mdot
.558 .55114 Mdot
.558 .55115 Mdot
.558 .55115 Mdot
.558 .5512 Mdot
.558 .55121 Mdot
.558 .55122 Mdot
.558 .55123 Mdot
.558 .55124 Mdot
.558 .55126 Mdot
.558 .55126 Mdot
.558 .55127 Mdot
.558 .55128 Mdot
.56 .18704 Mdot
.56 .18704 Mdot
.56 .18705 Mdot
.56 .18706 Mdot
.56 .18708 Mdot
.56 .18708 Mdot
.56 .18709 Mdot
.56 .18709 Mdot
.56 .1871 Mdot
.56 .18713 Mdot
.56 .18714 Mdot
.56 .18714 Mdot
.56 .18716 Mdot
.56 .18718 Mdot
.56 .18721 Mdot
.56 .18721 Mdot
.56 .18722 Mdot
.56 .18724 Mdot
.56 .18724 Mdot
.56 .18726 Mdot
.56 .18727 Mdot
.56 .18729 Mdot
.56 .18731 Mdot
.56 .18735 Mdot
.56 .18736 Mdot
.56 .18749 Mdot
.56 .18754 Mdot
.56 .18763 Mdot
.56 .18776 Mdot
.56 .18777 Mdot
.56 .18782 Mdot
.56 .18786 Mdot
.56 .18814 Mdot
.56 .18816 Mdot
.56 .1882 Mdot
.56 .18821 Mdot
.56 .18829 Mdot
.56 .18848 Mdot
.56 .18859 Mdot
.56 .1886 Mdot
.56 .18861 Mdot
.56 .18869 Mdot
.56 .18871 Mdot
.56 .18871 Mdot
.56 .18874 Mdot
.56 .18875 Mdot
.56 .18888 Mdot
.56 .18896 Mdot
.56 .18901 Mdot
.56 .18907 Mdot
.56 .18939 Mdot
.56 .18942 Mdot
.56 .18949 Mdot
.56 .18974 Mdot
.56 .18977 Mdot
.56 .18995 Mdot
.56 .19015 Mdot
.56 .1904 Mdot
.56 .19041 Mdot
.56 .19052 Mdot
.56 .19085 Mdot
.56 .19144 Mdot
.56 .19157 Mdot
.56 .19163 Mdot
.56 .19174 Mdot
.56 .19185 Mdot
.56 .19191 Mdot
.56 .19196 Mdot
.56 .19222 Mdot
.56 .19276 Mdot
.56 .19303 Mdot
.56 .19303 Mdot
.56 .19358 Mdot
.56 .19368 Mdot
.56 .19373 Mdot
.56 .19456 Mdot
.56 .19483 Mdot
.56 .19525 Mdot
.56 .19544 Mdot
.56 .1955 Mdot
.56 .19571 Mdot
.56 .19645 Mdot
.56 .19654 Mdot
.56 .19702 Mdot
.56 .19702 Mdot
.56 .19707 Mdot
.56 .19843 Mdot
.56 .1985 Mdot
.56 .19907 Mdot
.56 .19977 Mdot
.56 .1998 Mdot
.56 .19997 Mdot
.56 .20001 Mdot
.56 .20004 Mdot
.56 .20004 Mdot
.56 .20025 Mdot
.56 .20031 Mdot
.56 .20064 Mdot
.56 .2017 Mdot
.56 .20189 Mdot
.56 .20243 Mdot
.56 .20246 Mdot
.56 .20267 Mdot
.56 .20312 Mdot
.56 .20549 Mdot
.56 .20599 Mdot
.56 .20645 Mdot
.56 .20654 Mdot
.56 .20719 Mdot
.56 .20841 Mdot
.56 .20848 Mdot
.56 .20876 Mdot
.56 .20879 Mdot
.56 .20895 Mdot
.56 .20903 Mdot
.56 .20937 Mdot
.56 .20944 Mdot
.56 .20975 Mdot
.56 .20991 Mdot
.56 .20998 Mdot
.56 .21058 Mdot
.56 .21103 Mdot
.56 .21105 Mdot
.56 .21117 Mdot
.56 .213 Mdot
.56 .21324 Mdot
.56 .21349 Mdot
.56 .21388 Mdot
.56 .21402 Mdot
.56 .2141 Mdot
.56 .21448 Mdot
.56 .2147 Mdot
.56 .21532 Mdot
.56 .21557 Mdot
.56 .21613 Mdot
.56 .21692 Mdot
.56 .21727 Mdot
.56 .21774 Mdot
.56 .2179 Mdot
.56 .21793 Mdot
.56 .21804 Mdot
.56 .21823 Mdot
.56 .21888 Mdot
.56 .21896 Mdot
.56 .21915 Mdot
.56 .21947 Mdot
.56 .22043 Mdot
.56 .22161 Mdot
.56 .22211 Mdot
.56 .22277 Mdot
.56 .22303 Mdot
.56 .22377 Mdot
.56 .22395 Mdot
.56 .22424 Mdot
.56 .22442 Mdot
.56 .22462 Mdot
.56 .22467 Mdot
.56 .22476 Mdot
.56 .22494 Mdot
.56 .225 Mdot
.56 .22508 Mdot
.56 .22525 Mdot
.56 .22526 Mdot
.56 .22537 Mdot
.56 .22537 Mdot
.56 .22557 Mdot
.56 .22567 Mdot
.56 .2257 Mdot
.56 .22602 Mdot
.56 .22629 Mdot
.56 .22652 Mdot
.56 .22653 Mdot
.56 .22669 Mdot
.56 .22712 Mdot
.56 .22718 Mdot
.56 .2272 Mdot
.56 .22731 Mdot
.56 .22754 Mdot
.56 .22767 Mdot
.56 .22768 Mdot
.56 .2277 Mdot
.56 .22781 Mdot
.56 .22781 Mdot
.56 .22808 Mdot
.56 .22813 Mdot
.56 .23032 Mdot
.56 .23156 Mdot
.56 .23165 Mdot
.56 .23212 Mdot
.56 .23274 Mdot
.56 .23468 Mdot
.56 .23735 Mdot
.56 .24113 Mdot
.56 .24299 Mdot
.56 .24505 Mdot
.56 .24517 Mdot
.56 .24586 Mdot
.56 .24656 Mdot
.56 .24753 Mdot
.56 .24873 Mdot
.56 .24891 Mdot
.56 .25125 Mdot
.56 .25161 Mdot
.56 .25196 Mdot
.56 .25309 Mdot
.56 .25406 Mdot
.56 .25609 Mdot
.56 .25757 Mdot
.56 .25902 Mdot
.56 .25929 Mdot
.56 .25934 Mdot
.56 .26139 Mdot
.56 .26171 Mdot
.56 .26303 Mdot
.56 .26303 Mdot
.56 .26321 Mdot
.56 .26347 Mdot
.56 .26373 Mdot
.56 .2645 Mdot
.56 .26466 Mdot
.56 .26785 Mdot
.56 .2691 Mdot
.56 .27272 Mdot
.56 .27317 Mdot
.56 .27644 Mdot
.56 .28221 Mdot
.56 .28249 Mdot
.56 .28252 Mdot
.56 .28273 Mdot
.56 .28579 Mdot
.56 .28637 Mdot
.56 .28738 Mdot
.56 .28888 Mdot
.56 .29002 Mdot
.56 .29025 Mdot
.56 .29146 Mdot
.56 .29293 Mdot
.56 .29329 Mdot
.56 .2934 Mdot
.56 .2947 Mdot
.56 .29771 Mdot
.56 .29873 Mdot
.56 .29886 Mdot
.56 .29954 Mdot
.56 .29955 Mdot
.56 .29962 Mdot
.56 .29983 Mdot
.56 .29988 Mdot
.56 .2999 Mdot
.56 .30022 Mdot
.56 .30081 Mdot
.56 .30109 Mdot
.56 .30113 Mdot
.56 .30128 Mdot
.56 .30237 Mdot
.56 .30278 Mdot
.56 .30282 Mdot
.56 .30338 Mdot
.56 .30409 Mdot
.56 .30488 Mdot
.56 .30498 Mdot
.56 .30524 Mdot
.56 .30554 Mdot
.56 .30573 Mdot
.56 .30574 Mdot
.56 .30594 Mdot
.56 .30601 Mdot
.56 .30604 Mdot
.56 .30649 Mdot
.56 .30668 Mdot
.56 .30669 Mdot
.56 .30683 Mdot
.56 .30729 Mdot
.56 .30753 Mdot
.56 .30765 Mdot
.56 .30817 Mdot
.56 .30863 Mdot
.56 .30938 Mdot
.56 .30985 Mdot
.56 .31065 Mdot
.56 .31067 Mdot
.56 .31177 Mdot
.56 .31245 Mdot
.56 .31268 Mdot
.56 .31417 Mdot
.56 .31548 Mdot
.56 .31668 Mdot
.56 .31858 Mdot
.56 .3186 Mdot
.56 .31895 Mdot
.56 .31945 Mdot
.56 .32026 Mdot
.56 .32049 Mdot
.56 .32106 Mdot
.56 .32112 Mdot
.56 .32153 Mdot
.56 .32196 Mdot
.56 .32246 Mdot
.56 .32249 Mdot
.56 .32269 Mdot
.56 .32441 Mdot
.56 .32492 Mdot
.56 .32522 Mdot
.56 .3253 Mdot
.56 .32572 Mdot
.56 .32698 Mdot
.56 .32699 Mdot
.56 .32793 Mdot
.56 .32951 Mdot
.56 .33007 Mdot
.56 .33031 Mdot
.56 .33039 Mdot
.56 .33156 Mdot
.56 .33224 Mdot
.56 .33229 Mdot
.56 .33384 Mdot
.56 .33392 Mdot
.56 .33453 Mdot
.56 .33527 Mdot
.56 .33547 Mdot
.56 .33555 Mdot
.56 .33577 Mdot
.56 .33616 Mdot
.56 .33721 Mdot
.56 .3374 Mdot
.56 .33791 Mdot
.56 .33794 Mdot
.56 .33814 Mdot
.56 .33856 Mdot
.56 .34069 Mdot
.56 .34112 Mdot
.56 .34151 Mdot
.56 .34213 Mdot
.56 .34314 Mdot
.56 .3432 Mdot
.56 .34342 Mdot
.56 .34344 Mdot
.56 .34357 Mdot
.56 .34364 Mdot
.56 .34391 Mdot
.56 .34396 Mdot
.56 .34421 Mdot
.56 .34434 Mdot
.56 .34439 Mdot
.56 .34521 Mdot
.56 .34522 Mdot
.56 .34669 Mdot
.56 .34686 Mdot
.56 .34705 Mdot
.56 .34733 Mdot
.56 .34744 Mdot
.56 .3475 Mdot
.56 .34777 Mdot
.56 .34793 Mdot
.56 .34837 Mdot
.56 .34855 Mdot
.56 .34949 Mdot
.56 .34973 Mdot
.56 .35006 Mdot
.56 .35016 Mdot
.56 .35026 Mdot
.56 .35039 Mdot
.56 .35082 Mdot
.56 .35088 Mdot
.56 .35101 Mdot
.56 .35122 Mdot
.56 .35186 Mdot
.56 .35262 Mdot
.56 .35295 Mdot
.56 .354 Mdot
.56 .35412 Mdot
.56 .35441 Mdot
.56 .35454 Mdot
.56 .35462 Mdot
.56 .35473 Mdot
.56 .35477 Mdot
.56 .35493 Mdot
.56 .35493 Mdot
.56 .35512 Mdot
.56 .35518 Mdot
.56 .3552 Mdot
.56 .3554 Mdot
.56 .35557 Mdot
.56 .3557 Mdot
.56 .35571 Mdot
.56 .35581 Mdot
.56 .35607 Mdot
.56 .3561 Mdot
.56 .35612 Mdot
.56 .35618 Mdot
.56 .3564 Mdot
.56 .3564 Mdot
.56 .35642 Mdot
.56 .35648 Mdot
.56 .35649 Mdot
.56 .35668 Mdot
.56 .35797 Mdot
.56 .35937 Mdot
.56 .36601 Mdot
.56 .36728 Mdot
.56 .36788 Mdot
.56 .36797 Mdot
.56 .36947 Mdot
.56 .37003 Mdot
.56 .37301 Mdot
.56 .37396 Mdot
.56 .37411 Mdot
.56 .37472 Mdot
.56 .37472 Mdot
.56 .3748 Mdot
.56 .37492 Mdot
.56 .37539 Mdot
.56 .37547 Mdot
.56 .37746 Mdot
.56 .37906 Mdot
.56 .37926 Mdot
.56 .38314 Mdot
.56 .38325 Mdot
.56 .38327 Mdot
.56 .38464 Mdot
.56 .38488 Mdot
.56 .38697 Mdot
.56 .38757 Mdot
.56 .38776 Mdot
.56 .38828 Mdot
.56 .38949 Mdot
.56 .39025 Mdot
.56 .39259 Mdot
.56 .39274 Mdot
.56 .39303 Mdot
.56 .39457 Mdot
.56 .39458 Mdot
.56 .39535 Mdot
.56 .39688 Mdot
.56 .39761 Mdot
.56 .39774 Mdot
.56 .39793 Mdot
.56 .39824 Mdot
.56 .39854 Mdot
.56 .39872 Mdot
.56 .39908 Mdot
.56 .40076 Mdot
.56 .4017 Mdot
.56 .40199 Mdot
.56 .40203 Mdot
.56 .40273 Mdot
.56 .4033 Mdot
.56 .40383 Mdot
.56 .4039 Mdot
.56 .40461 Mdot
.56 .40481 Mdot
.56 .40488 Mdot
.56 .40581 Mdot
.56 .40597 Mdot
.56 .40611 Mdot
.56 .40634 Mdot
.56 .4067 Mdot
.56 .40672 Mdot
.56 .4068 Mdot
.56 .40681 Mdot
.56 .40688 Mdot
.56 .40709 Mdot
.56 .40714 Mdot
.56 .40716 Mdot
.56 .40746 Mdot
.56 .40799 Mdot
.56 .40822 Mdot
.56 .40826 Mdot
.56 .40838 Mdot
.56 .40844 Mdot
.56 .4092 Mdot
.56 .40932 Mdot
.56 .40948 Mdot
.56 .4095 Mdot
.56 .40985 Mdot
.56 .41013 Mdot
.56 .41024 Mdot
.56 .41062 Mdot
.56 .41066 Mdot
.56 .41077 Mdot
.56 .41081 Mdot
.56 .41089 Mdot
.56 .4109 Mdot
.56 .41095 Mdot
.56 .41096 Mdot
.56 .41102 Mdot
.56 .41105 Mdot
.56 .41105 Mdot
.56 .41112 Mdot
.56 .41118 Mdot
.56 .41123 Mdot
.56 .41123 Mdot
.56 .41127 Mdot
.56 .41136 Mdot
.56 .41138 Mdot
.56 .41138 Mdot
.56 .4114 Mdot
.56 .41148 Mdot
.56 .41148 Mdot
.56 .41151 Mdot
.56 .41151 Mdot
.56 .45932 Mdot
.56 .45932 Mdot
.56 .45933 Mdot
.56 .45933 Mdot
.56 .45938 Mdot
.56 .45939 Mdot
.56 .45939 Mdot
.56 .4594 Mdot
.56 .45945 Mdot
.56 .45947 Mdot
.56 .45947 Mdot
.56 .45949 Mdot
.56 .45953 Mdot
.56 .45956 Mdot
.56 .45957 Mdot
.56 .45958 Mdot
.56 .45962 Mdot
.56 .45962 Mdot
.56 .45965 Mdot
.56 .45965 Mdot
.56 .45969 Mdot
.56 .45972 Mdot
.56 .45977 Mdot
.56 .45979 Mdot
.56 .46 Mdot
.56 .46006 Mdot
.56 .46021 Mdot
.56 .46039 Mdot
.56 .4604 Mdot
.56 .46049 Mdot
.56 .46055 Mdot
.56 .46096 Mdot
.56 .46099 Mdot
.56 .46105 Mdot
.56 .46107 Mdot
.56 .4612 Mdot
.56 .46148 Mdot
.56 .46164 Mdot
.56 .46165 Mdot
.56 .46167 Mdot
.56 .46178 Mdot
.56 .46182 Mdot
.56 .46183 Mdot
.56 .46187 Mdot
.56 .46188 Mdot
.56 .46207 Mdot
.56 .46219 Mdot
.56 .46227 Mdot
.56 .46235 Mdot
.56 .46284 Mdot
.56 .46288 Mdot
.56 .46298 Mdot
.56 .46335 Mdot
.56 .46339 Mdot
.56 .46366 Mdot
.56 .46396 Mdot
.56 .46433 Mdot
.56 .46434 Mdot
.56 .4645 Mdot
.56 .46498 Mdot
.56 .46585 Mdot
.56 .46604 Mdot
.56 .46613 Mdot
.56 .46628 Mdot
.56 .46644 Mdot
.56 .46653 Mdot
.56 .4666 Mdot
.56 .46698 Mdot
.56 .46775 Mdot
.56 .46815 Mdot
.56 .46815 Mdot
.56 .46893 Mdot
.56 .46908 Mdot
.56 .46916 Mdot
.56 .47033 Mdot
.56 .47071 Mdot
.56 .47131 Mdot
.56 .47157 Mdot
.56 .47166 Mdot
.56 .47196 Mdot
.56 .47299 Mdot
.56 .47311 Mdot
.56 .47378 Mdot
.56 .47379 Mdot
.56 .47385 Mdot
.56 .47573 Mdot
.56 .47583 Mdot
.56 .4766 Mdot
.56 .47756 Mdot
.56 .4776 Mdot
.56 .47782 Mdot
.56 .47788 Mdot
.56 .47792 Mdot
.56 .47792 Mdot
.56 .47821 Mdot
.56 .47828 Mdot
.56 .47873 Mdot
.56 .48014 Mdot
.56 .4804 Mdot
.56 .48111 Mdot
.56 .48115 Mdot
.56 .48143 Mdot
.56 .48203 Mdot
.56 .4851 Mdot
.56 .48574 Mdot
.56 .48632 Mdot
.56 .48641 Mdot
.56 .48641 Mdot
.56 .48644 Mdot
.56 .48645 Mdot
.56 .48645 Mdot
.56 .48655 Mdot
.56 .48658 Mdot
.56 .48659 Mdot
.56 .4866 Mdot
.56 .48672 Mdot
.56 .48676 Mdot
.56 .48677 Mdot
.56 .48683 Mdot
.56 .48691 Mdot
.56 .48699 Mdot
.56 .487 Mdot
.56 .48703 Mdot
.56 .48712 Mdot
.56 .48712 Mdot
.56 .48719 Mdot
.56 .48721 Mdot
.56 .48726 Mdot
.56 .4873 Mdot
.56 .48735 Mdot
.56 .48749 Mdot
.56 .48754 Mdot
.56 .48801 Mdot
.56 .48816 Mdot
.56 .4885 Mdot
.56 .48879 Mdot
.56 .48888 Mdot
.56 .48894 Mdot
.56 .48897 Mdot
.56 .48916 Mdot
.56 .48922 Mdot
.56 .48926 Mdot
.56 .48931 Mdot
.56 .48946 Mdot
.56 .48957 Mdot
.56 .48999 Mdot
.56 .49007 Mdot
.56 .49026 Mdot
.56 .49033 Mdot
.56 .49045 Mdot
.56 .49048 Mdot
.56 .49053 Mdot
.56 .49065 Mdot
.56 .49074 Mdot
.56 .49081 Mdot
.56 .49146 Mdot
.56 .49147 Mdot
.56 .49183 Mdot
.56 .49185 Mdot
.56 .49191 Mdot
.56 .49202 Mdot
.56 .49204 Mdot
.56 .49216 Mdot
.56 .49219 Mdot
.56 .49225 Mdot
.56 .49226 Mdot
.56 .49235 Mdot
.56 .49238 Mdot
.56 .49282 Mdot
.56 .49309 Mdot
.56 .49327 Mdot
.56 .49346 Mdot
.56 .49438 Mdot
.56 .49457 Mdot
.56 .49465 Mdot
.56 .49467 Mdot
.56 .49489 Mdot
.56 .49497 Mdot
.56 .49542 Mdot
.56 .4956 Mdot
.56 .49569 Mdot
.56 .49572 Mdot
.56 .49581 Mdot
.56 .49613 Mdot
.56 .49639 Mdot
.56 .49643 Mdot
.56 .49709 Mdot
.56 .49711 Mdot
.56 .4974 Mdot
.56 .49791 Mdot
.56 .49794 Mdot
.56 .49804 Mdot
.56 .49828 Mdot
.56 .49895 Mdot
.56 .49935 Mdot
.56 .49936 Mdot
.56 .49989 Mdot
.56 .50007 Mdot
.56 .5001 Mdot
.56 .50023 Mdot
.56 .50044 Mdot
.56 .50117 Mdot
.56 .50125 Mdot
.56 .50126 Mdot
.56 .50148 Mdot
.56 .50165 Mdot
.56 .50183 Mdot
.56 .50185 Mdot
.56 .50218 Mdot
.56 .50252 Mdot
.56 .50273 Mdot
.56 .50288 Mdot
.56 .50289 Mdot
.56 .50367 Mdot
.56 .50417 Mdot
.56 .50471 Mdot
.56 .50532 Mdot
.56 .50542 Mdot
.56 .5057 Mdot
.56 .50615 Mdot
.56 .50616 Mdot
.56 .50649 Mdot
.56 .50668 Mdot
.56 .50698 Mdot
.56 .50717 Mdot
.56 .50738 Mdot
.56 .50743 Mdot
.56 .50753 Mdot
.56 .50771 Mdot
.56 .50777 Mdot
.56 .50778 Mdot
.56 .50785 Mdot
.56 .50804 Mdot
.56 .50805 Mdot
.56 .50808 Mdot
.56 .50816 Mdot
.56 .50816 Mdot
.56 .50824 Mdot
.56 .50836 Mdot
.56 .50846 Mdot
.56 .5085 Mdot
.56 .50883 Mdot
.56 .50911 Mdot
.56 .50934 Mdot
.56 .50935 Mdot
.56 .50952 Mdot
.56 .50996 Mdot
.56 .51001 Mdot
.56 .51003 Mdot
.56 .51014 Mdot
.56 .51038 Mdot
.56 .51051 Mdot
.56 .51052 Mdot
.56 .51054 Mdot
.56 .51062 Mdot
.56 .51065 Mdot
.56 .51065 Mdot
.56 .51092 Mdot
.56 .51098 Mdot
.56 .51139 Mdot
.56 .51258 Mdot
.56 .5131 Mdot
.56 .51314 Mdot
.56 .51328 Mdot
.56 .51386 Mdot
.56 .51434 Mdot
.56 .51443 Mdot
.56 .51487 Mdot
.56 .51546 Mdot
.56 .51586 Mdot
.56 .51608 Mdot
.56 .51727 Mdot
.56 .51735 Mdot
.56 .51736 Mdot
.56 .51747 Mdot
.56 .51969 Mdot
.56 .52094 Mdot
.56 .52111 Mdot
.56 .52249 Mdot
.56 .52296 Mdot
.56 .52415 Mdot
.56 .52422 Mdot
.56 .5245 Mdot
.56 .5246 Mdot
.56 .5247 Mdot
.56 .52477 Mdot
.56 .52477 Mdot
.56 .52526 Mdot
.56 .52538 Mdot
.56 .52614 Mdot
.56 .52616 Mdot
.56 .52626 Mdot
.56 .5268 Mdot
.56 .52735 Mdot
.56 .52809 Mdot
.56 .52845 Mdot
.56 .52887 Mdot
.56 .529 Mdot
.56 .52913 Mdot
.56 .52999 Mdot
.56 .53005 Mdot
.56 .53049 Mdot
.56 .53084 Mdot
.56 .5311 Mdot
.56 .53134 Mdot
.56 .53139 Mdot
.56 .53213 Mdot
.56 .53281 Mdot
.56 .53416 Mdot
.56 .53512 Mdot
.56 .53581 Mdot
.56 .53603 Mdot
.56 .5362 Mdot
.56 .53623 Mdot
.56 .53667 Mdot
.56 .53744 Mdot
.56 .53746 Mdot
.56 .53756 Mdot
.56 .53756 Mdot
.56 .5376 Mdot
.56 .5376 Mdot
.56 .53761 Mdot
.56 .53765 Mdot
.56 .53774 Mdot
.56 .53777 Mdot
.56 .53778 Mdot
.56 .5378 Mdot
.56 .53795 Mdot
.56 .53801 Mdot
.56 .53801 Mdot
.56 .53809 Mdot
.56 .53819 Mdot
.56 .5383 Mdot
.56 .53831 Mdot
.56 .53835 Mdot
.56 .53842 Mdot
.56 .53842 Mdot
.56 .53845 Mdot
.56 .53846 Mdot
.56 .53852 Mdot
.56 .53855 Mdot
.56 .53857 Mdot
.56 .53863 Mdot
.56 .53866 Mdot
.56 .53868 Mdot
.56 .53875 Mdot
.56 .53881 Mdot
.56 .53891 Mdot
.56 .53898 Mdot
.56 .53924 Mdot
.56 .53933 Mdot
.56 .53956 Mdot
.56 .53974 Mdot
.56 .54015 Mdot
.56 .54048 Mdot
.56 .54059 Mdot
.56 .54066 Mdot
.56 .54069 Mdot
.56 .54091 Mdot
.56 .54098 Mdot
.56 .54102 Mdot
.56 .54103 Mdot
.56 .54108 Mdot
.56 .54125 Mdot
.56 .54137 Mdot
.56 .54165 Mdot
.56 .54184 Mdot
.56 .54192 Mdot
.56 .54214 Mdot
.56 .54222 Mdot
.56 .54235 Mdot
.56 .54237 Mdot
.56 .54242 Mdot
.56 .54256 Mdot
.56 .54264 Mdot
.56 .54273 Mdot
.56 .54336 Mdot
.56 .5434 Mdot
.56 .54341 Mdot
.56 .54356 Mdot
.56 .54377 Mdot
.56 .54379 Mdot
.56 .54385 Mdot
.56 .54395 Mdot
.56 .54398 Mdot
.56 .54409 Mdot
.56 .54412 Mdot
.56 .54418 Mdot
.56 .54419 Mdot
.56 .54428 Mdot
.56 .54431 Mdot
.56 .54473 Mdot
.56 .54494 Mdot
.56 .54498 Mdot
.56 .54513 Mdot
.56 .5453 Mdot
.56 .54611 Mdot
.56 .54626 Mdot
.56 .54634 Mdot
.56 .54635 Mdot
.56 .54653 Mdot
.56 .5466 Mdot
.56 .54695 Mdot
.56 .54707 Mdot
.56 .54709 Mdot
.56 .54716 Mdot
.56 .54716 Mdot
.56 .54717 Mdot
.56 .54718 Mdot
.56 .54724 Mdot
.56 .54725 Mdot
.56 .54749 Mdot
.56 .54768 Mdot
.56 .5477 Mdot
.56 .54816 Mdot
.56 .54818 Mdot
.56 .54818 Mdot
.56 .54834 Mdot
.56 .54837 Mdot
.56 .54862 Mdot
.56 .54869 Mdot
.56 .54871 Mdot
.56 .54878 Mdot
.56 .54892 Mdot
.56 .54901 Mdot
.56 .54929 Mdot
.56 .5493 Mdot
.56 .54934 Mdot
.56 .54952 Mdot
.56 .54952 Mdot
.56 .54961 Mdot
.56 .54979 Mdot
.56 .54988 Mdot
.56 .5499 Mdot
.56 .54992 Mdot
.56 .54995 Mdot
.56 .54999 Mdot
.56 .55001 Mdot
.56 .55005 Mdot
.56 .55025 Mdot
.56 .55036 Mdot
.56 .5504 Mdot
.56 .5504 Mdot
.56 .55048 Mdot
.56 .55055 Mdot
.56 .55061 Mdot
.56 .55062 Mdot
.56 .55071 Mdot
.56 .55073 Mdot
.56 .55074 Mdot
.56 .55085 Mdot
.56 .55087 Mdot
.56 .55088 Mdot
.56 .55091 Mdot
.56 .55095 Mdot
.56 .55096 Mdot
.56 .55097 Mdot
.56 .55097 Mdot
.56 .55097 Mdot
.56 .551 Mdot
.56 .551 Mdot
.56 .55101 Mdot
.56 .55104 Mdot
.56 .5511 Mdot
.56 .55113 Mdot
.56 .55114 Mdot
.56 .55115 Mdot
.56 .55116 Mdot
.56 .55125 Mdot
.56 .55126 Mdot
.56 .55128 Mdot
.56 .55128 Mdot
.56 .55133 Mdot
.56 .55136 Mdot
.56 .55137 Mdot
.56 .55142 Mdot
.56 .55142 Mdot
.56 .55143 Mdot
.56 .55144 Mdot
.56 .55145 Mdot
.56 .55145 Mdot
.56 .55146 Mdot
.56 .55146 Mdot
.56 .55146 Mdot
.56 .55147 Mdot
.56 .55147 Mdot
.56 .55148 Mdot
.56 .55148 Mdot
.56 .55149 Mdot
.56 .55149 Mdot
.56 .55149 Mdot
.56 .5515 Mdot
.56 .55151 Mdot
.56 .55151 Mdot
.56 .55151 Mdot
.56 .55151 Mdot
.56 .55152 Mdot
.56 .55152 Mdot
.56 .55152 Mdot
.56 .55152 Mdot
.562 .18641 Mdot
.562 .18642 Mdot
.562 .18649 Mdot
.562 .1865 Mdot
.562 .18653 Mdot
.562 .18658 Mdot
.562 .1866 Mdot
.562 .18666 Mdot
.562 .18669 Mdot
.562 .18672 Mdot
.562 .18673 Mdot
.562 .18678 Mdot
.562 .18681 Mdot
.562 .18686 Mdot
.562 .18697 Mdot
.562 .18697 Mdot
.562 .18699 Mdot
.562 .18702 Mdot
.562 .18703 Mdot
.562 .18705 Mdot
.562 .18708 Mdot
.562 .18717 Mdot
.562 .18726 Mdot
.562 .18729 Mdot
.562 .18731 Mdot
.562 .1874 Mdot
.562 .18748 Mdot
.562 .18751 Mdot
.562 .18765 Mdot
.562 .18777 Mdot
.562 .18784 Mdot
.562 .18796 Mdot
.562 .18801 Mdot
.562 .18805 Mdot
.562 .18817 Mdot
.562 .18838 Mdot
.562 .18842 Mdot
.562 .1886 Mdot
.562 .18875 Mdot
.562 .18876 Mdot
.562 .18895 Mdot
.562 .18917 Mdot
.562 .18927 Mdot
.562 .18951 Mdot
.562 .18962 Mdot
.562 .18968 Mdot
.562 .19 Mdot
.562 .19013 Mdot
.562 .19016 Mdot
.562 .19037 Mdot
.562 .19042 Mdot
.562 .19092 Mdot
.562 .19116 Mdot
.562 .19123 Mdot
.562 .19146 Mdot
.562 .19167 Mdot
.562 .19173 Mdot
.562 .19209 Mdot
.562 .19237 Mdot
.562 .19246 Mdot
.562 .19278 Mdot
.562 .19355 Mdot
.562 .19387 Mdot
.562 .19407 Mdot
.562 .19424 Mdot
.562 .1943 Mdot
.562 .19438 Mdot
.562 .1944 Mdot
.562 .1948 Mdot
.562 .19494 Mdot
.562 .19509 Mdot
.562 .19536 Mdot
.562 .19556 Mdot
.562 .19564 Mdot
.562 .19586 Mdot
.562 .19615 Mdot
.562 .1962 Mdot
.562 .19656 Mdot
.562 .19668 Mdot
.562 .19686 Mdot
.562 .19714 Mdot
.562 .19736 Mdot
.562 .19749 Mdot
.562 .19822 Mdot
.562 .19867 Mdot
.562 .1987 Mdot
.562 .19876 Mdot
.562 .19887 Mdot
.562 .19894 Mdot
.562 .19926 Mdot
.562 .19934 Mdot
.562 .1994 Mdot
.562 .19962 Mdot
.562 .19969 Mdot
.562 .19977 Mdot
.562 .2 Mdot
.562 .2002 Mdot
.562 .20093 Mdot
.562 .20123 Mdot
.562 .20211 Mdot
.562 .20231 Mdot
.562 .20281 Mdot
.562 .20285 Mdot
.562 .20299 Mdot
.562 .2032 Mdot
.562 .20341 Mdot
.562 .20376 Mdot
.562 .20405 Mdot
.562 .20467 Mdot
.562 .20487 Mdot
.562 .20662 Mdot
.562 .20675 Mdot
.562 .20764 Mdot
.562 .20816 Mdot
.562 .20954 Mdot
.562 .20987 Mdot
.562 .20999 Mdot
.562 .21041 Mdot
.562 .21062 Mdot
.562 .21126 Mdot
.562 .21217 Mdot
.562 .21237 Mdot
.562 .21258 Mdot
.562 .21265 Mdot
.562 .21343 Mdot
.562 .21376 Mdot
.562 .21388 Mdot
.562 .21391 Mdot
.562 .21425 Mdot
.562 .21427 Mdot
.562 .21479 Mdot
.562 .2153 Mdot
.562 .21591 Mdot
.562 .21611 Mdot
.562 .21618 Mdot
.562 .21694 Mdot
.562 .2184 Mdot
.562 .2189 Mdot
.562 .21949 Mdot
.562 .21967 Mdot
.562 .22002 Mdot
.562 .22023 Mdot
.562 .22036 Mdot
.562 .22136 Mdot
.562 .22168 Mdot
.562 .22235 Mdot
.562 .22238 Mdot
.562 .22253 Mdot
.562 .22278 Mdot
.562 .22311 Mdot
.562 .22316 Mdot
.562 .22389 Mdot
.562 .22429 Mdot
.562 .22545 Mdot
.562 .22567 Mdot
.562 .22573 Mdot
.562 .22608 Mdot
.562 .22617 Mdot
.562 .22618 Mdot
.562 .22627 Mdot
.562 .22642 Mdot
.562 .22661 Mdot
.562 .22678 Mdot
.562 .2269 Mdot
.562 .22828 Mdot
.562 .22834 Mdot
.562 .22901 Mdot
.562 .22941 Mdot
.562 .23008 Mdot
.562 .23025 Mdot
.562 .23058 Mdot
.562 .23063 Mdot
.562 .23103 Mdot
.562 .2319 Mdot
.562 .23214 Mdot
.562 .23247 Mdot
.562 .23279 Mdot
.562 .23311 Mdot
.562 .23329 Mdot
.562 .23343 Mdot
.562 .23356 Mdot
.562 .2343 Mdot
.562 .23435 Mdot
.562 .23452 Mdot
.562 .23474 Mdot
.562 .23578 Mdot
.562 .23599 Mdot
.562 .23899 Mdot
.562 .23935 Mdot
.562 .24053 Mdot
.562 .2424 Mdot
.562 .24354 Mdot
.562 .24469 Mdot
.562 .24518 Mdot
.562 .24535 Mdot
.562 .24547 Mdot
.562 .24568 Mdot
.562 .24844 Mdot
.562 .24848 Mdot
.562 .24925 Mdot
.562 .24964 Mdot
.562 .25004 Mdot
.562 .2516 Mdot
.562 .25169 Mdot
.562 .25473 Mdot
.562 .25655 Mdot
.562 .25745 Mdot
.562 .25789 Mdot
.562 .25815 Mdot
.562 .25851 Mdot
.562 .25957 Mdot
.562 .26094 Mdot
.562 .26205 Mdot
.562 .2622 Mdot
.562 .2636 Mdot
.562 .26409 Mdot
.562 .26455 Mdot
.562 .26457 Mdot
.562 .26593 Mdot
.562 .2663 Mdot
.562 .26681 Mdot
.562 .26871 Mdot
.562 .26884 Mdot
.562 .26927 Mdot
.562 .27 Mdot
.562 .27036 Mdot
.562 .27061 Mdot
.562 .27138 Mdot
.562 .27221 Mdot
.562 .27353 Mdot
.562 .27834 Mdot
.562 .27917 Mdot
.562 .2792 Mdot
.562 .27966 Mdot
.562 .28069 Mdot
.562 .28213 Mdot
.562 .28258 Mdot
.562 .28266 Mdot
.562 .28306 Mdot
.562 .28318 Mdot
.562 .28376 Mdot
.562 .28456 Mdot
.562 .28495 Mdot
.562 .28527 Mdot
.562 .28561 Mdot
.562 .28603 Mdot
.562 .28681 Mdot
.562 .28705 Mdot
.562 .28739 Mdot
.562 .28758 Mdot
.562 .2884 Mdot
.562 .28897 Mdot
.562 .2894 Mdot
.562 .29097 Mdot
.562 .29111 Mdot
.562 .29154 Mdot
.562 .2921 Mdot
.562 .2922 Mdot
.562 .29291 Mdot
.562 .29304 Mdot
.562 .29344 Mdot
.562 .29482 Mdot
.562 .29513 Mdot
.562 .29589 Mdot
.562 .29611 Mdot
.562 .29685 Mdot
.562 .29778 Mdot
.562 .29974 Mdot
.562 .29988 Mdot
.562 .30026 Mdot
.562 .30046 Mdot
.562 .30086 Mdot
.562 .30142 Mdot
.562 .30172 Mdot
.562 .30208 Mdot
.562 .30216 Mdot
.562 .30264 Mdot
.562 .30303 Mdot
.562 .30326 Mdot
.562 .30329 Mdot
.562 .30351 Mdot
.562 .30356 Mdot
.562 .3044 Mdot
.562 .30457 Mdot
.562 .30513 Mdot
.562 .30586 Mdot
.562 .3081 Mdot
.562 .30914 Mdot
.562 .31105 Mdot
.562 .31118 Mdot
.562 .31158 Mdot
.562 .31203 Mdot
.562 .31267 Mdot
.562 .31307 Mdot
.562 .31315 Mdot
.562 .31391 Mdot
.562 .31458 Mdot
.562 .3149 Mdot
.562 .31576 Mdot
.562 .31671 Mdot
.562 .31839 Mdot
.562 .31873 Mdot
.562 .31929 Mdot
.562 .31939 Mdot
.562 .31986 Mdot
.562 .32022 Mdot
.562 .3207 Mdot
.562 .32142 Mdot
.562 .32227 Mdot
.562 .32315 Mdot
.562 .3236 Mdot
.562 .3237 Mdot
.562 .3255 Mdot
.562 .32753 Mdot
.562 .32934 Mdot
.562 .32956 Mdot
.562 .32974 Mdot
.562 .32976 Mdot
.562 .33029 Mdot
.562 .33132 Mdot
.562 .33159 Mdot
.562 .33194 Mdot
.562 .33256 Mdot
.562 .33333 Mdot
.562 .33475 Mdot
.562 .33479 Mdot
.562 .33504 Mdot
.562 .33552 Mdot
.562 .33574 Mdot
.562 .33582 Mdot
.562 .33613 Mdot
.562 .33633 Mdot
.562 .33705 Mdot
.562 .33818 Mdot
.562 .339 Mdot
.562 .33919 Mdot
.562 .33938 Mdot
.562 .33995 Mdot
.562 .34049 Mdot
.562 .34067 Mdot
.562 .34216 Mdot
.562 .34227 Mdot
.562 .343 Mdot
.562 .34341 Mdot
.562 .34476 Mdot
.562 .34486 Mdot
.562 .34518 Mdot
.562 .34534 Mdot
.562 .34651 Mdot
.562 .34681 Mdot
.562 .34686 Mdot
.562 .34775 Mdot
.562 .34777 Mdot
.562 .34802 Mdot
.562 .3484 Mdot
.562 .34938 Mdot
.562 .3499 Mdot
.562 .35089 Mdot
.562 .35161 Mdot
.562 .35196 Mdot
.562 .35218 Mdot
.562 .35283 Mdot
.562 .35304 Mdot
.562 .35358 Mdot
.562 .35373 Mdot
.562 .35397 Mdot
.562 .35468 Mdot
.562 .35539 Mdot
.562 .35552 Mdot
.562 .35557 Mdot
.562 .35578 Mdot
.562 .35584 Mdot
.562 .35589 Mdot
.562 .3561 Mdot
.562 .3562 Mdot
.562 .35627 Mdot
.562 .35713 Mdot
.562 .35753 Mdot
.562 .35776 Mdot
.562 .35815 Mdot
.562 .35825 Mdot
.562 .35844 Mdot
.562 .3587 Mdot
.562 .3592 Mdot
.562 .35933 Mdot
.562 .3597 Mdot
.562 .35999 Mdot
.562 .36006 Mdot
.562 .36055 Mdot
.562 .36067 Mdot
.562 .3608 Mdot
.562 .36137 Mdot
.562 .36311 Mdot
.562 .36393 Mdot
.562 .36491 Mdot
.562 .3655 Mdot
.562 .36609 Mdot
.562 .36649 Mdot
.562 .3666 Mdot
.562 .36801 Mdot
.562 .36859 Mdot
.562 .37106 Mdot
.562 .37193 Mdot
.562 .37398 Mdot
.562 .37457 Mdot
.562 .3752 Mdot
.562 .37543 Mdot
.562 .37564 Mdot
.562 .37626 Mdot
.562 .37643 Mdot
.562 .37666 Mdot
.562 .37756 Mdot
.562 .37775 Mdot
.562 .37808 Mdot
.562 .37823 Mdot
.562 .37834 Mdot
.562 .37962 Mdot
.562 .38169 Mdot
.562 .38206 Mdot
.562 .38269 Mdot
.562 .38348 Mdot
.562 .38398 Mdot
.562 .38431 Mdot
.562 .38534 Mdot
.562 .38548 Mdot
.562 .38631 Mdot
.562 .38695 Mdot
.562 .38718 Mdot
.562 .38774 Mdot
.562 .3885 Mdot
.562 .38893 Mdot
.562 .38932 Mdot
.562 .39047 Mdot
.562 .39052 Mdot
.562 .39067 Mdot
.562 .39075 Mdot
.562 .39091 Mdot
.562 .39139 Mdot
.562 .39197 Mdot
.562 .39287 Mdot
.562 .39508 Mdot
.562 .39597 Mdot
.562 .39623 Mdot
.562 .39704 Mdot
.562 .39805 Mdot
.562 .39823 Mdot
.562 .39882 Mdot
.562 .39946 Mdot
.562 .39967 Mdot
.562 .40034 Mdot
.562 .40177 Mdot
.562 .40192 Mdot
.562 .4025 Mdot
.562 .4026 Mdot
.562 .40296 Mdot
.562 .40387 Mdot
.562 .40404 Mdot
.562 .40434 Mdot
.562 .40502 Mdot
.562 .40532 Mdot
.562 .40593 Mdot
.562 .40647 Mdot
.562 .40651 Mdot
.562 .40692 Mdot
.562 .40744 Mdot
.562 .40756 Mdot
.562 .40815 Mdot
.562 .40849 Mdot
.562 .40859 Mdot
.562 .40872 Mdot
.562 .40907 Mdot
.562 .40926 Mdot
.562 .40962 Mdot
.562 .41 Mdot
.562 .41008 Mdot
.562 .41031 Mdot
.562 .41058 Mdot
.562 .41064 Mdot
.562 .41072 Mdot
.562 .41098 Mdot
.562 .41123 Mdot
.562 .41129 Mdot
.562 .41137 Mdot
.562 .41139 Mdot
.562 .41148 Mdot
.562 .41152 Mdot
.562 .41155 Mdot
.562 .41185 Mdot
.562 .41199 Mdot
.562 .41208 Mdot
.562 .41222 Mdot
.562 .41225 Mdot
.562 .41232 Mdot
.562 .41241 Mdot
.562 .41259 Mdot
.562 .41264 Mdot
.562 .41277 Mdot
.562 .41287 Mdot
.562 .4129 Mdot
.562 .41307 Mdot
.562 .41311 Mdot
.562 .45855 Mdot
.562 .45857 Mdot
.562 .45867 Mdot
.562 .45868 Mdot
.562 .45874 Mdot
.562 .45881 Mdot
.562 .45883 Mdot
.562 .45893 Mdot
.562 .45898 Mdot
.562 .45901 Mdot
.562 .45903 Mdot
.562 .45911 Mdot
.562 .45915 Mdot
.562 .45923 Mdot
.562 .45939 Mdot
.562 .45941 Mdot
.562 .45943 Mdot
.562 .45948 Mdot
.562 .45949 Mdot
.562 .45953 Mdot
.562 .45956 Mdot
.562 .4597 Mdot
.562 .45983 Mdot
.562 .45988 Mdot
.562 .45991 Mdot
.562 .46005 Mdot
.562 .46018 Mdot
.562 .46022 Mdot
.562 .46042 Mdot
.562 .46061 Mdot
.562 .46071 Mdot
.562 .4609 Mdot
.562 .46097 Mdot
.562 .46102 Mdot
.562 .4612 Mdot
.562 .46152 Mdot
.562 .46158 Mdot
.562 .46185 Mdot
.562 .46207 Mdot
.562 .46209 Mdot
.562 .46238 Mdot
.562 .4627 Mdot
.562 .46285 Mdot
.562 .46321 Mdot
.562 .46336 Mdot
.562 .46345 Mdot
.562 .46393 Mdot
.562 .46411 Mdot
.562 .46417 Mdot
.562 .46447 Mdot
.562 .46455 Mdot
.562 .46529 Mdot
.562 .46563 Mdot
.562 .46574 Mdot
.562 .46607 Mdot
.562 .46637 Mdot
.562 .46646 Mdot
.562 .46698 Mdot
.562 .46739 Mdot
.562 .46752 Mdot
.562 .46798 Mdot
.562 .4691 Mdot
.562 .46955 Mdot
.562 .46984 Mdot
.562 .47008 Mdot
.562 .47016 Mdot
.562 .47027 Mdot
.562 .4703 Mdot
.562 .47088 Mdot
.562 .47107 Mdot
.562 .47128 Mdot
.562 .47166 Mdot
.562 .47194 Mdot
.562 .47205 Mdot
.562 .47237 Mdot
.562 .47278 Mdot
.562 .47284 Mdot
.562 .47335 Mdot
.562 .47351 Mdot
.562 .47376 Mdot
.562 .47415 Mdot
.562 .47445 Mdot
.562 .47463 Mdot
.562 .47564 Mdot
.562 .47625 Mdot
.562 .47631 Mdot
.562 .47638 Mdot
.562 .47654 Mdot
.562 .47663 Mdot
.562 .47706 Mdot
.562 .47717 Mdot
.562 .47725 Mdot
.562 .47755 Mdot
.562 .47765 Mdot
.562 .47776 Mdot
.562 .47807 Mdot
.562 .47834 Mdot
.562 .47932 Mdot
.562 .47973 Mdot
.562 .48089 Mdot
.562 .48116 Mdot
.562 .48182 Mdot
.562 .48187 Mdot
.562 .48206 Mdot
.562 .48233 Mdot
.562 .48261 Mdot
.562 .48306 Mdot
.562 .48344 Mdot
.562 .48425 Mdot
.562 .48451 Mdot
.562 .48457 Mdot
.562 .48462 Mdot
.562 .48485 Mdot
.562 .48488 Mdot
.562 .48501 Mdot
.562 .48518 Mdot
.562 .48524 Mdot
.562 .48547 Mdot
.562 .48559 Mdot
.562 .48568 Mdot
.562 .48572 Mdot
.562 .4859 Mdot
.562 .48601 Mdot
.562 .48619 Mdot
.562 .48658 Mdot
.562 .48661 Mdot
.562 .48666 Mdot
.562 .48675 Mdot
.562 .48677 Mdot
.562 .4868 Mdot
.562 .4869 Mdot
.562 .48692 Mdot
.562 .48698 Mdot
.562 .4873 Mdot
.562 .48762 Mdot
.562 .48773 Mdot
.562 .4878 Mdot
.562 .48804 Mdot
.562 .48813 Mdot
.562 .48843 Mdot
.562 .48852 Mdot
.562 .48868 Mdot
.562 .48901 Mdot
.562 .48945 Mdot
.562 .48968 Mdot
.562 .49011 Mdot
.562 .49029 Mdot
.562 .4904 Mdot
.562 .49041 Mdot
.562 .4908 Mdot
.562 .49083 Mdot
.562 .49096 Mdot
.562 .49147 Mdot
.562 .49154 Mdot
.562 .49169 Mdot
.562 .49173 Mdot
.562 .49232 Mdot
.562 .49251 Mdot
.562 .49283 Mdot
.562 .49287 Mdot
.562 .49353 Mdot
.562 .4936 Mdot
.562 .49384 Mdot
.562 .49409 Mdot
.562 .49417 Mdot
.562 .49426 Mdot
.562 .49461 Mdot
.562 .4951 Mdot
.562 .49541 Mdot
.562 .4955 Mdot
.562 .49564 Mdot
.562 .49567 Mdot
.562 .49577 Mdot
.562 .49597 Mdot
.562 .49608 Mdot
.562 .4961 Mdot
.562 .49671 Mdot
.562 .49704 Mdot
.562 .4973 Mdot
.562 .49745 Mdot
.562 .49757 Mdot
.562 .49801 Mdot
.562 .49823 Mdot
.562 .49824 Mdot
.562 .49832 Mdot
.562 .49842 Mdot
.562 .49918 Mdot
.562 .50004 Mdot
.562 .5008 Mdot
.562 .50084 Mdot
.562 .50103 Mdot
.562 .5014 Mdot
.562 .50176 Mdot
.562 .50206 Mdot
.562 .50226 Mdot
.562 .50241 Mdot
.562 .5026 Mdot
.562 .50265 Mdot
.562 .50288 Mdot
.562 .50302 Mdot
.562 .50372 Mdot
.562 .50411 Mdot
.562 .50447 Mdot
.562 .5046 Mdot
.562 .50487 Mdot
.562 .50519 Mdot
.562 .50522 Mdot
.562 .50538 Mdot
.562 .50565 Mdot
.562 .50583 Mdot
.562 .506 Mdot
.562 .50605 Mdot
.562 .50683 Mdot
.562 .50725 Mdot
.562 .50816 Mdot
.562 .50846 Mdot
.562 .50868 Mdot
.562 .50875 Mdot
.562 .50909 Mdot
.562 .50911 Mdot
.562 .5092 Mdot
.562 .50921 Mdot
.562 .5093 Mdot
.562 .50946 Mdot
.562 .50965 Mdot
.562 .50969 Mdot
.562 .50983 Mdot
.562 .50995 Mdot
.562 .51017 Mdot
.562 .51033 Mdot
.562 .51042 Mdot
.562 .51057 Mdot
.562 .51062 Mdot
.562 .51141 Mdot
.562 .51178 Mdot
.562 .51207 Mdot
.562 .51216 Mdot
.562 .51246 Mdot
.562 .51258 Mdot
.562 .51313 Mdot
.562 .51329 Mdot
.562 .51333 Mdot
.562 .51362 Mdot
.562 .51365 Mdot
.562 .51388 Mdot
.562 .51405 Mdot
.562 .5141 Mdot
.562 .51472 Mdot
.562 .51489 Mdot
.562 .51511 Mdot
.562 .51543 Mdot
.562 .51551 Mdot
.562 .51564 Mdot
.562 .51573 Mdot
.562 .51603 Mdot
.562 .5162 Mdot
.562 .51633 Mdot
.562 .51645 Mdot
.562 .51661 Mdot
.562 .51692 Mdot
.562 .51714 Mdot
.562 .51719 Mdot
.562 .51734 Mdot
.562 .51738 Mdot
.562 .51755 Mdot
.562 .51811 Mdot
.562 .5185 Mdot
.562 .51868 Mdot
.562 .51869 Mdot
.562 .51901 Mdot
.562 .52085 Mdot
.562 .52135 Mdot
.562 .52166 Mdot
.562 .52196 Mdot
.562 .52205 Mdot
.562 .52219 Mdot
.562 .52246 Mdot
.562 .52262 Mdot
.562 .52268 Mdot
.562 .52339 Mdot
.562 .52358 Mdot
.562 .52372 Mdot
.562 .52423 Mdot
.562 .52424 Mdot
.562 .52441 Mdot
.562 .52459 Mdot
.562 .52512 Mdot
.562 .52517 Mdot
.562 .52559 Mdot
.562 .5261 Mdot
.562 .52649 Mdot
.562 .52662 Mdot
.562 .52672 Mdot
.562 .52688 Mdot
.562 .52722 Mdot
.562 .52789 Mdot
.562 .52901 Mdot
.562 .52904 Mdot
.562 .52961 Mdot
.562 .52975 Mdot
.562 .5299 Mdot
.562 .53018 Mdot
.562 .53019 Mdot
.562 .5312 Mdot
.562 .53127 Mdot
.562 .53132 Mdot
.562 .53138 Mdot
.562 .53156 Mdot
.562 .53197 Mdot
.562 .53239 Mdot
.562 .53306 Mdot
.562 .53348 Mdot
.562 .53361 Mdot
.562 .53469 Mdot
.562 .53476 Mdot
.562 .53513 Mdot
.562 .53521 Mdot
.562 .53527 Mdot
.562 .53529 Mdot
.562 .53555 Mdot
.562 .5356 Mdot
.562 .53565 Mdot
.562 .53571 Mdot
.562 .53583 Mdot
.562 .53594 Mdot
.562 .53606 Mdot
.562 .53614 Mdot
.562 .53645 Mdot
.562 .5366 Mdot
.562 .53661 Mdot
.562 .53673 Mdot
.562 .53679 Mdot
.562 .53703 Mdot
.562 .53717 Mdot
.562 .5374 Mdot
.562 .53742 Mdot
.562 .53791 Mdot
.562 .53795 Mdot
.562 .53801 Mdot
.562 .53808 Mdot
.562 .53813 Mdot
.562 .53816 Mdot
.562 .53817 Mdot
.562 .5382 Mdot
.562 .53832 Mdot
.562 .53835 Mdot
.562 .53842 Mdot
.562 .53883 Mdot
.562 .53897 Mdot
.562 .53923 Mdot
.562 .53924 Mdot
.562 .53936 Mdot
.562 .53944 Mdot
.562 .5395 Mdot
.562 .53951 Mdot
.562 .53974 Mdot
.562 .53986 Mdot
.562 .5402 Mdot
.562 .54025 Mdot
.562 .54032 Mdot
.562 .54045 Mdot
.562 .54051 Mdot
.562 .54071 Mdot
.562 .54089 Mdot
.562 .5414 Mdot
.562 .54166 Mdot
.562 .54168 Mdot
.562 .54175 Mdot
.562 .54196 Mdot
.562 .54214 Mdot
.562 .54232 Mdot
.562 .54232 Mdot
.562 .54244 Mdot
.562 .54245 Mdot
.562 .54249 Mdot
.562 .54261 Mdot
.562 .54288 Mdot
.562 .5429 Mdot
.562 .54297 Mdot
.562 .54304 Mdot
.562 .54336 Mdot
.562 .54358 Mdot
.562 .54365 Mdot
.562 .54379 Mdot
.562 .54384 Mdot
.562 .54395 Mdot
.562 .54442 Mdot
.562 .5446 Mdot
.562 .5449 Mdot
.562 .54495 Mdot
.562 .54554 Mdot
.562 .54561 Mdot
.562 .54582 Mdot
.562 .54592 Mdot
.562 .54604 Mdot
.562 .54611 Mdot
.562 .54618 Mdot
.562 .54623 Mdot
.562 .54625 Mdot
.562 .54642 Mdot
.562 .54648 Mdot
.562 .54678 Mdot
.562 .54688 Mdot
.562 .54713 Mdot
.562 .5472 Mdot
.562 .54728 Mdot
.562 .5473 Mdot
.562 .54733 Mdot
.562 .5474 Mdot
.562 .54742 Mdot
.562 .54745 Mdot
.562 .54756 Mdot
.562 .54758 Mdot
.562 .54762 Mdot
.562 .54764 Mdot
.562 .54765 Mdot
.562 .5478 Mdot
.562 .54805 Mdot
.562 .54809 Mdot
.562 .54817 Mdot
.562 .54826 Mdot
.562 .54832 Mdot
.562 .54836 Mdot
.562 .54848 Mdot
.562 .5485 Mdot
.562 .5486 Mdot
.562 .54867 Mdot
.562 .5487 Mdot
.562 .54877 Mdot
.562 .54886 Mdot
.562 .54891 Mdot
.562 .54895 Mdot
.562 .54909 Mdot
.562 .5491 Mdot
.562 .54912 Mdot
.562 .54914 Mdot
.562 .5492 Mdot
.562 .54927 Mdot
.562 .54937 Mdot
.562 .54963 Mdot
.562 .54974 Mdot
.562 .54977 Mdot
.562 .54986 Mdot
.562 .54998 Mdot
.562 .55 Mdot
.562 .55007 Mdot
.562 .55015 Mdot
.562 .55017 Mdot
.562 .55025 Mdot
.562 .55042 Mdot
.562 .55044 Mdot
.562 .55051 Mdot
.562 .55052 Mdot
.562 .55056 Mdot
.562 .55067 Mdot
.562 .55069 Mdot
.562 .55072 Mdot
.562 .5508 Mdot
.562 .55084 Mdot
.562 .55091 Mdot
.562 .55097 Mdot
.562 .55098 Mdot
.562 .55103 Mdot
.562 .55109 Mdot
.562 .5511 Mdot
.562 .55117 Mdot
.562 .55121 Mdot
.562 .55122 Mdot
.562 .55124 Mdot
.562 .55128 Mdot
.562 .5513 Mdot
.562 .55135 Mdot
.562 .55139 Mdot
.562 .5514 Mdot
.562 .55143 Mdot
.562 .55146 Mdot
.562 .55147 Mdot
.562 .55148 Mdot
.562 .55151 Mdot
.562 .55154 Mdot
.562 .55154 Mdot
.562 .55155 Mdot
.562 .55155 Mdot
.562 .55157 Mdot
.562 .55157 Mdot
.562 .55157 Mdot
.562 .55161 Mdot
.562 .55163 Mdot
.562 .55164 Mdot
.562 .55165 Mdot
.562 .55166 Mdot
.562 .55166 Mdot
.562 .55167 Mdot
.562 .5517 Mdot
.562 .5517 Mdot
.562 .55172 Mdot
.562 .55173 Mdot
.562 .55173 Mdot
.562 .55175 Mdot
.562 .55176 Mdot
.564 .18577 Mdot
.564 .18578 Mdot
.564 .18578 Mdot
.564 .18578 Mdot
.564 .1858 Mdot
.564 .18581 Mdot
.564 .18582 Mdot
.564 .18584 Mdot
.564 .18586 Mdot
.564 .18588 Mdot
.564 .18591 Mdot
.564 .18593 Mdot
.564 .186 Mdot
.564 .18606 Mdot
.564 .1862 Mdot
.564 .18627 Mdot
.564 .18639 Mdot
.564 .18639 Mdot
.564 .18648 Mdot
.564 .18653 Mdot
.564 .18663 Mdot
.564 .18677 Mdot
.564 .18694 Mdot
.564 .18702 Mdot
.564 .18704 Mdot
.564 .18714 Mdot
.564 .18734 Mdot
.564 .18735 Mdot
.564 .18739 Mdot
.564 .18742 Mdot
.564 .18748 Mdot
.564 .1875 Mdot
.564 .18754 Mdot
.564 .1877 Mdot
.564 .18781 Mdot
.564 .18782 Mdot
.564 .18784 Mdot
.564 .18798 Mdot
.564 .18822 Mdot
.564 .1884 Mdot
.564 .18844 Mdot
.564 .18853 Mdot
.564 .18869 Mdot
.564 .18891 Mdot
.564 .18892 Mdot
.564 .18895 Mdot
.564 .18904 Mdot
.564 .18937 Mdot
.564 .1897 Mdot
.564 .18973 Mdot
.564 .18993 Mdot
.564 .19007 Mdot
.564 .19032 Mdot
.564 .19041 Mdot
.564 .19064 Mdot
.564 .19146 Mdot
.564 .19158 Mdot
.564 .19159 Mdot
.564 .19159 Mdot
.564 .19163 Mdot
.564 .19208 Mdot
.564 .19222 Mdot
.564 .19253 Mdot
.564 .19273 Mdot
.564 .19277 Mdot
.564 .19281 Mdot
.564 .19298 Mdot
.564 .19308 Mdot
.564 .19335 Mdot
.564 .19369 Mdot
.564 .19407 Mdot
.564 .19424 Mdot
.564 .19466 Mdot
.564 .19477 Mdot
.564 .19478 Mdot
.564 .19481 Mdot
.564 .19514 Mdot
.564 .19522 Mdot
.564 .19574 Mdot
.564 .19596 Mdot
.564 .19606 Mdot
.564 .19653 Mdot
.564 .19679 Mdot
.564 .19694 Mdot
.564 .19708 Mdot
.564 .19731 Mdot
.564 .19738 Mdot
.564 .19762 Mdot
.564 .1988 Mdot
.564 .1989 Mdot
.564 .19929 Mdot
.564 .19983 Mdot
.564 .20032 Mdot
.564 .20134 Mdot
.564 .20138 Mdot
.564 .20162 Mdot
.564 .20163 Mdot
.564 .20254 Mdot
.564 .20304 Mdot
.564 .2033 Mdot
.564 .20354 Mdot
.564 .20357 Mdot
.564 .20363 Mdot
.564 .20409 Mdot
.564 .20517 Mdot
.564 .20538 Mdot
.564 .20566 Mdot
.564 .20692 Mdot
.564 .20711 Mdot
.564 .20746 Mdot
.564 .20776 Mdot
.564 .20805 Mdot
.564 .20847 Mdot
.564 .20984 Mdot
.564 .21005 Mdot
.564 .21029 Mdot
.564 .21093 Mdot
.564 .2117 Mdot
.564 .21285 Mdot
.564 .21285 Mdot
.564 .21386 Mdot
.564 .21441 Mdot
.564 .21458 Mdot
.564 .21475 Mdot
.564 .21495 Mdot
.564 .21551 Mdot
.564 .21556 Mdot
.564 .21602 Mdot
.564 .21637 Mdot
.564 .21649 Mdot
.564 .2166 Mdot
.564 .21684 Mdot
.564 .21711 Mdot
.564 .21718 Mdot
.564 .21782 Mdot
.564 .21813 Mdot
.564 .21826 Mdot
.564 .21852 Mdot
.564 .21886 Mdot
.564 .21904 Mdot
.564 .21925 Mdot
.564 .21928 Mdot
.564 .21965 Mdot
.564 .22012 Mdot
.564 .22014 Mdot
.564 .22021 Mdot
.564 .22024 Mdot
.564 .2203 Mdot
.564 .22052 Mdot
.564 .22064 Mdot
.564 .22067 Mdot
.564 .221 Mdot
.564 .22135 Mdot
.564 .22143 Mdot
.564 .22268 Mdot
.564 .22289 Mdot
.564 .22297 Mdot
.564 .22386 Mdot
.564 .22394 Mdot
.564 .22425 Mdot
.564 .2253 Mdot
.564 .22564 Mdot
.564 .22601 Mdot
.564 .22758 Mdot
.564 .22948 Mdot
.564 .22975 Mdot
.564 .23075 Mdot
.564 .23078 Mdot
.564 .23113 Mdot
.564 .23145 Mdot
.564 .23216 Mdot
.564 .23271 Mdot
.564 .23275 Mdot
.564 .23311 Mdot
.564 .2335 Mdot
.564 .23443 Mdot
.564 .23545 Mdot
.564 .23649 Mdot
.564 .23751 Mdot
.564 .2377 Mdot
.564 .23851 Mdot
.564 .23948 Mdot
.564 .2398 Mdot
.564 .24014 Mdot
.564 .24031 Mdot
.564 .24047 Mdot
.564 .24057 Mdot
.564 .24065 Mdot
.564 .24082 Mdot
.564 .2411 Mdot
.564 .24137 Mdot
.564 .24143 Mdot
.564 .24172 Mdot
.564 .2418 Mdot
.564 .24184 Mdot
.564 .24185 Mdot
.564 .24194 Mdot
.564 .24204 Mdot
.564 .24248 Mdot
.564 .24335 Mdot
.564 .24526 Mdot
.564 .24536 Mdot
.564 .24614 Mdot
.564 .25133 Mdot
.564 .25138 Mdot
.564 .2528 Mdot
.564 .25303 Mdot
.564 .25597 Mdot
.564 .25762 Mdot
.564 .25784 Mdot
.564 .25918 Mdot
.564 .26196 Mdot
.564 .26218 Mdot
.564 .26387 Mdot
.564 .26484 Mdot
.564 .26507 Mdot
.564 .26528 Mdot
.564 .2653 Mdot
.564 .26538 Mdot
.564 .26552 Mdot
.564 .26555 Mdot
.564 .2662 Mdot
.564 .26634 Mdot
.564 .26694 Mdot
.564 .26757 Mdot
.564 .26797 Mdot
.564 .26804 Mdot
.564 .26813 Mdot
.564 .26837 Mdot
.564 .26868 Mdot
.564 .26872 Mdot
.564 .26911 Mdot
.564 .26988 Mdot
.564 .2706 Mdot
.564 .27284 Mdot
.564 .2747 Mdot
.564 .27514 Mdot
.564 .27641 Mdot
.564 .27752 Mdot
.564 .27801 Mdot
.564 .27845 Mdot
.564 .27997 Mdot
.564 .28001 Mdot
.564 .28099 Mdot
.564 .282 Mdot
.564 .2824 Mdot
.564 .28375 Mdot
.564 .28466 Mdot
.564 .28559 Mdot
.564 .28647 Mdot
.564 .28656 Mdot
.564 .28701 Mdot
.564 .28767 Mdot
.564 .2879 Mdot
.564 .2892 Mdot
.564 .28963 Mdot
.564 .29042 Mdot
.564 .29128 Mdot
.564 .29136 Mdot
.564 .29285 Mdot
.564 .29341 Mdot
.564 .29383 Mdot
.564 .29451 Mdot
.564 .2958 Mdot
.564 .29597 Mdot
.564 .29604 Mdot
.564 .29686 Mdot
.564 .29929 Mdot
.564 .29984 Mdot
.564 .30112 Mdot
.564 .30327 Mdot
.564 .30385 Mdot
.564 .30423 Mdot
.564 .30509 Mdot
.564 .30633 Mdot
.564 .30781 Mdot
.564 .30836 Mdot
.564 .30862 Mdot
.564 .30883 Mdot
.564 .30907 Mdot
.564 .31031 Mdot
.564 .31063 Mdot
.564 .31091 Mdot
.564 .31113 Mdot
.564 .31134 Mdot
.564 .3119 Mdot
.564 .31245 Mdot
.564 .31477 Mdot
.564 .31518 Mdot
.564 .31538 Mdot
.564 .31577 Mdot
.564 .3163 Mdot
.564 .31718 Mdot
.564 .31726 Mdot
.564 .31757 Mdot
.564 .31817 Mdot
.564 .31831 Mdot
.564 .31839 Mdot
.564 .31857 Mdot
.564 .31863 Mdot
.564 .31916 Mdot
.564 .31945 Mdot
.564 .31948 Mdot
.564 .31952 Mdot
.564 .31988 Mdot
.564 .32046 Mdot
.564 .32087 Mdot
.564 .32096 Mdot
.564 .32151 Mdot
.564 .32198 Mdot
.564 .32289 Mdot
.564 .32359 Mdot
.564 .32394 Mdot
.564 .32479 Mdot
.564 .32649 Mdot
.564 .32669 Mdot
.564 .32669 Mdot
.564 .32742 Mdot
.564 .32806 Mdot
.564 .32835 Mdot
.564 .32847 Mdot
.564 .3287 Mdot
.564 .3292 Mdot
.564 .32965 Mdot
.564 .33088 Mdot
.564 .33103 Mdot
.564 .33106 Mdot
.564 .33218 Mdot
.564 .33255 Mdot
.564 .33309 Mdot
.564 .33354 Mdot
.564 .3337 Mdot
.564 .33395 Mdot
.564 .33403 Mdot
.564 .33553 Mdot
.564 .33656 Mdot
.564 .33829 Mdot
.564 .3383 Mdot
.564 .33913 Mdot
.564 .33981 Mdot
.564 .34006 Mdot
.564 .34011 Mdot
.564 .34144 Mdot
.564 .34186 Mdot
.564 .34305 Mdot
.564 .34357 Mdot
.564 .3438 Mdot
.564 .34414 Mdot
.564 .34535 Mdot
.564 .34554 Mdot
.564 .34602 Mdot
.564 .34659 Mdot
.564 .34743 Mdot
.564 .34854 Mdot
.564 .34867 Mdot
.564 .34878 Mdot
.564 .35041 Mdot
.564 .35088 Mdot
.564 .35118 Mdot
.564 .35135 Mdot
.564 .35158 Mdot
.564 .35185 Mdot
.564 .35209 Mdot
.564 .3524 Mdot
.564 .35241 Mdot
.564 .35246 Mdot
.564 .35324 Mdot
.564 .35403 Mdot
.564 .35421 Mdot
.564 .35476 Mdot
.564 .35481 Mdot
.564 .355 Mdot
.564 .35565 Mdot
.564 .35701 Mdot
.564 .35813 Mdot
.564 .35828 Mdot
.564 .35887 Mdot
.564 .35907 Mdot
.564 .35926 Mdot
.564 .35966 Mdot
.564 .35997 Mdot
.564 .35999 Mdot
.564 .36093 Mdot
.564 .36149 Mdot
.564 .36261 Mdot
.564 .36271 Mdot
.564 .36314 Mdot
.564 .36366 Mdot
.564 .36383 Mdot
.564 .36401 Mdot
.564 .3641 Mdot
.564 .36418 Mdot
.564 .36424 Mdot
.564 .36427 Mdot
.564 .36437 Mdot
.564 .36451 Mdot
.564 .36465 Mdot
.564 .36469 Mdot
.564 .36484 Mdot
.564 .36488 Mdot
.564 .3649 Mdot
.564 .3649 Mdot
.564 .36495 Mdot
.564 .36568 Mdot
.564 .3671 Mdot
.564 .36967 Mdot
.564 .36969 Mdot
.564 .37038 Mdot
.564 .37049 Mdot
.564 .3734 Mdot
.564 .37478 Mdot
.564 .37629 Mdot
.564 .37742 Mdot
.564 .3777 Mdot
.564 .38107 Mdot
.564 .38175 Mdot
.564 .38193 Mdot
.564 .38259 Mdot
.564 .38301 Mdot
.564 .38343 Mdot
.564 .38416 Mdot
.564 .38551 Mdot
.564 .38578 Mdot
.564 .38641 Mdot
.564 .38789 Mdot
.564 .38811 Mdot
.564 .38907 Mdot
.564 .38914 Mdot
.564 .38916 Mdot
.564 .38949 Mdot
.564 .39067 Mdot
.564 .39118 Mdot
.564 .39225 Mdot
.564 .39321 Mdot
.564 .39399 Mdot
.564 .39427 Mdot
.564 .39474 Mdot
.564 .39487 Mdot
.564 .39498 Mdot
.564 .39557 Mdot
.564 .39645 Mdot
.564 .39683 Mdot
.564 .39811 Mdot
.564 .39822 Mdot
.564 .39823 Mdot
.564 .39825 Mdot
.564 .3986 Mdot
.564 .40092 Mdot
.564 .40158 Mdot
.564 .40185 Mdot
.564 .40254 Mdot
.564 .40295 Mdot
.564 .40351 Mdot
.564 .4036 Mdot
.564 .40455 Mdot
.564 .40549 Mdot
.564 .40574 Mdot
.564 .40583 Mdot
.564 .40584 Mdot
.564 .40648 Mdot
.564 .40691 Mdot
.564 .40718 Mdot
.564 .4073 Mdot
.564 .40781 Mdot
.564 .40849 Mdot
.564 .40889 Mdot
.564 .40893 Mdot
.564 .40898 Mdot
.564 .40973 Mdot
.564 .40984 Mdot
.564 .4099 Mdot
.564 .41008 Mdot
.564 .41016 Mdot
.564 .41028 Mdot
.564 .41029 Mdot
.564 .41085 Mdot
.564 .41113 Mdot
.564 .4112 Mdot
.564 .41143 Mdot
.564 .41192 Mdot
.564 .41231 Mdot
.564 .41258 Mdot
.564 .41272 Mdot
.564 .41297 Mdot
.564 .41298 Mdot
.564 .41331 Mdot
.564 .41351 Mdot
.564 .41391 Mdot
.564 .4141 Mdot
.564 .41428 Mdot
.564 .41434 Mdot
.564 .41443 Mdot
.564 .41448 Mdot
.564 .41453 Mdot
.564 .41458 Mdot
.564 .41463 Mdot
.564 .41464 Mdot
.564 .4147 Mdot
.564 .41471 Mdot
.564 .41472 Mdot
.564 .41472 Mdot
.564 .45778 Mdot
.564 .45778 Mdot
.564 .45778 Mdot
.564 .45779 Mdot
.564 .45782 Mdot
.564 .45782 Mdot
.564 .45785 Mdot
.564 .45788 Mdot
.564 .4579 Mdot
.564 .45793 Mdot
.564 .45798 Mdot
.564 .45801 Mdot
.564 .45811 Mdot
.564 .45822 Mdot
.564 .45843 Mdot
.564 .45854 Mdot
.564 .45872 Mdot
.564 .45872 Mdot
.564 .45886 Mdot
.564 .45893 Mdot
.564 .45907 Mdot
.564 .45929 Mdot
.564 .45955 Mdot
.564 .45967 Mdot
.564 .45971 Mdot
.564 .45986 Mdot
.564 .46016 Mdot
.564 .46016 Mdot
.564 .46023 Mdot
.564 .46027 Mdot
.564 .46037 Mdot
.564 .4604 Mdot
.564 .46046 Mdot
.564 .46086 Mdot
.564 .46088 Mdot
.564 .4609 Mdot
.564 .46111 Mdot
.564 .46148 Mdot
.564 .46174 Mdot
.564 .46181 Mdot
.564 .46195 Mdot
.564 .46218 Mdot
.564 .46251 Mdot
.564 .46252 Mdot
.564 .46257 Mdot
.564 .4627 Mdot
.564 .46319 Mdot
.564 .46368 Mdot
.564 .46373 Mdot
.564 .46402 Mdot
.564 .46424 Mdot
.564 .46459 Mdot
.564 .46473 Mdot
.564 .46507 Mdot
.564 .46627 Mdot
.564 .46645 Mdot
.564 .46646 Mdot
.564 .46646 Mdot
.564 .46652 Mdot
.564 .46717 Mdot
.564 .46737 Mdot
.564 .46782 Mdot
.564 .46811 Mdot
.564 .46817 Mdot
.564 .46823 Mdot
.564 .46847 Mdot
.564 .46861 Mdot
.564 .46901 Mdot
.564 .46949 Mdot
.564 .47003 Mdot
.564 .47028 Mdot
.564 .47087 Mdot
.564 .47103 Mdot
.564 .47105 Mdot
.564 .47108 Mdot
.564 .47156 Mdot
.564 .47167 Mdot
.564 .4724 Mdot
.564 .47271 Mdot
.564 .47284 Mdot
.564 .4735 Mdot
.564 .47386 Mdot
.564 .47407 Mdot
.564 .47427 Mdot
.564 .47459 Mdot
.564 .47468 Mdot
.564 .47501 Mdot
.564 .47664 Mdot
.564 .47677 Mdot
.564 .47731 Mdot
.564 .47804 Mdot
.564 .4787 Mdot
.564 .48007 Mdot
.564 .48012 Mdot
.564 .48045 Mdot
.564 .48046 Mdot
.564 .48166 Mdot
.564 .48232 Mdot
.564 .48266 Mdot
.564 .48268 Mdot
.564 .48269 Mdot
.564 .4827 Mdot
.564 .48271 Mdot
.564 .48278 Mdot
.564 .4828 Mdot
.564 .48286 Mdot
.564 .48293 Mdot
.564 .48298 Mdot
.564 .48299 Mdot
.564 .48302 Mdot
.564 .48306 Mdot
.564 .4831 Mdot
.564 .48318 Mdot
.564 .48326 Mdot
.564 .4835 Mdot
.564 .4837 Mdot
.564 .48375 Mdot
.564 .48426 Mdot
.564 .48452 Mdot
.564 .48495 Mdot
.564 .48496 Mdot
.564 .4851 Mdot
.564 .48528 Mdot
.564 .48537 Mdot
.564 .48546 Mdot
.564 .48573 Mdot
.564 .4858 Mdot
.564 .48631 Mdot
.564 .48693 Mdot
.564 .48722 Mdot
.564 .48731 Mdot
.564 .48733 Mdot
.564 .48758 Mdot
.564 .48766 Mdot
.564 .48802 Mdot
.564 .48837 Mdot
.564 .48839 Mdot
.564 .48839 Mdot
.564 .48853 Mdot
.564 .48864 Mdot
.564 .48876 Mdot
.564 .48886 Mdot
.564 .48894 Mdot
.564 .48907 Mdot
.564 .48929 Mdot
.564 .49001 Mdot
.564 .49006 Mdot
.564 .49012 Mdot
.564 .49061 Mdot
.564 .49098 Mdot
.564 .49124 Mdot
.564 .49145 Mdot
.564 .49153 Mdot
.564 .49207 Mdot
.564 .49222 Mdot
.564 .49232 Mdot
.564 .49255 Mdot
.564 .49307 Mdot
.564 .49325 Mdot
.564 .49383 Mdot
.564 .49386 Mdot
.564 .49396 Mdot
.564 .49426 Mdot
.564 .49462 Mdot
.564 .49463 Mdot
.564 .49537 Mdot
.564 .49582 Mdot
.564 .49647 Mdot
.564 .4965 Mdot
.564 .49661 Mdot
.564 .49668 Mdot
.564 .49687 Mdot
.564 .4971 Mdot
.564 .49726 Mdot
.564 .49774 Mdot
.564 .49775 Mdot
.564 .49782 Mdot
.564 .49834 Mdot
.564 .49853 Mdot
.564 .49875 Mdot
.564 .49884 Mdot
.564 .49889 Mdot
.564 .49902 Mdot
.564 .49929 Mdot
.564 .4996 Mdot
.564 .4996 Mdot
.564 .49968 Mdot
.564 .5004 Mdot
.564 .50075 Mdot
.564 .5009 Mdot
.564 .5012 Mdot
.564 .50158 Mdot
.564 .50178 Mdot
.564 .502 Mdot
.564 .50204 Mdot
.564 .50221 Mdot
.564 .50246 Mdot
.564 .5026 Mdot
.564 .50262 Mdot
.564 .50264 Mdot
.564 .50275 Mdot
.564 .50297 Mdot
.564 .503 Mdot
.564 .50307 Mdot
.564 .50311 Mdot
.564 .50317 Mdot
.564 .50341 Mdot
.564 .50354 Mdot
.564 .50358 Mdot
.564 .50394 Mdot
.564 .50416 Mdot
.564 .50432 Mdot
.564 .50441 Mdot
.564 .50457 Mdot
.564 .50553 Mdot
.564 .50575 Mdot
.564 .50598 Mdot
.564 .50607 Mdot
.564 .50616 Mdot
.564 .50627 Mdot
.564 .5064 Mdot
.564 .50691 Mdot
.564 .50701 Mdot
.564 .50709 Mdot
.564 .5072 Mdot
.564 .50742 Mdot
.564 .50802 Mdot
.564 .50852 Mdot
.564 .50887 Mdot
.564 .50902 Mdot
.564 .50926 Mdot
.564 .51012 Mdot
.564 .51063 Mdot
.564 .51085 Mdot
.564 .51182 Mdot
.564 .51215 Mdot
.564 .51217 Mdot
.564 .51224 Mdot
.564 .51275 Mdot
.564 .51302 Mdot
.564 .51319 Mdot
.564 .51341 Mdot
.564 .514 Mdot
.564 .51403 Mdot
.564 .51437 Mdot
.564 .51468 Mdot
.564 .51484 Mdot
.564 .51535 Mdot
.564 .51544 Mdot
.564 .5157 Mdot
.564 .51587 Mdot
.564 .51591 Mdot
.564 .51625 Mdot
.564 .51661 Mdot
.564 .51697 Mdot
.564 .51749 Mdot
.564 .51764 Mdot
.564 .51803 Mdot
.564 .51841 Mdot
.564 .51843 Mdot
.564 .51901 Mdot
.564 .51918 Mdot
.564 .51937 Mdot
.564 .51979 Mdot
.564 .52028 Mdot
.564 .52044 Mdot
.564 .52115 Mdot
.564 .522 Mdot
.564 .52228 Mdot
.564 .52257 Mdot
.564 .52271 Mdot
.564 .52273 Mdot
.564 .52284 Mdot
.564 .52294 Mdot
.564 .52297 Mdot
.564 .523 Mdot
.564 .52314 Mdot
.564 .52338 Mdot
.564 .52361 Mdot
.564 .52366 Mdot
.564 .5239 Mdot
.564 .52392 Mdot
.564 .52397 Mdot
.564 .524 Mdot
.564 .52401 Mdot
.564 .52409 Mdot
.564 .52417 Mdot
.564 .52453 Mdot
.564 .52516 Mdot
.564 .52525 Mdot
.564 .52628 Mdot
.564 .52678 Mdot
.564 .52686 Mdot
.564 .52747 Mdot
.564 .52855 Mdot
.564 .52864 Mdot
.564 .52916 Mdot
.564 .52918 Mdot
.564 .53107 Mdot
.564 .53135 Mdot
.564 .53139 Mdot
.564 .53208 Mdot
.564 .53239 Mdot
.564 .53255 Mdot
.564 .53258 Mdot
.564 .53262 Mdot
.564 .53262 Mdot
.564 .53263 Mdot
.564 .53266 Mdot
.564 .53277 Mdot
.564 .53279 Mdot
.564 .53289 Mdot
.564 .53299 Mdot
.564 .53305 Mdot
.564 .53308 Mdot
.564 .53312 Mdot
.564 .53317 Mdot
.564 .53323 Mdot
.564 .53336 Mdot
.564 .53347 Mdot
.564 .53382 Mdot
.564 .53411 Mdot
.564 .53418 Mdot
.564 .53454 Mdot
.564 .53491 Mdot
.564 .53528 Mdot
.564 .53561 Mdot
.564 .53575 Mdot
.564 .53588 Mdot
.564 .53589 Mdot
.564 .53608 Mdot
.564 .53633 Mdot
.564 .53645 Mdot
.564 .53657 Mdot
.564 .53658 Mdot
.564 .53694 Mdot
.564 .53703 Mdot
.564 .53771 Mdot
.564 .53826 Mdot
.564 .53839 Mdot
.564 .53851 Mdot
.564 .53888 Mdot
.564 .53899 Mdot
.564 .53901 Mdot
.564 .53932 Mdot
.564 .53935 Mdot
.564 .53943 Mdot
.564 .53986 Mdot
.564 .53989 Mdot
.564 .54001 Mdot
.564 .54013 Mdot
.564 .54014 Mdot
.564 .54018 Mdot
.564 .54026 Mdot
.564 .54028 Mdot
.564 .54029 Mdot
.564 .54031 Mdot
.564 .54032 Mdot
.564 .54048 Mdot
.564 .54061 Mdot
.564 .54062 Mdot
.564 .54069 Mdot
.564 .54076 Mdot
.564 .54087 Mdot
.564 .54096 Mdot
.564 .54101 Mdot
.564 .54112 Mdot
.564 .54134 Mdot
.564 .54137 Mdot
.564 .54154 Mdot
.564 .54158 Mdot
.564 .54162 Mdot
.564 .54174 Mdot
.564 .5419 Mdot
.564 .54192 Mdot
.564 .54211 Mdot
.564 .54218 Mdot
.564 .54224 Mdot
.564 .5423 Mdot
.564 .54249 Mdot
.564 .54284 Mdot
.564 .54284 Mdot
.564 .54323 Mdot
.564 .5435 Mdot
.564 .54372 Mdot
.564 .5438 Mdot
.564 .54387 Mdot
.564 .54434 Mdot
.564 .54449 Mdot
.564 .54459 Mdot
.564 .54469 Mdot
.564 .54481 Mdot
.564 .54487 Mdot
.564 .5453 Mdot
.564 .5454 Mdot
.564 .54547 Mdot
.564 .54584 Mdot
.564 .546 Mdot
.564 .54602 Mdot
.564 .54603 Mdot
.564 .54611 Mdot
.564 .5462 Mdot
.564 .54637 Mdot
.564 .54668 Mdot
.564 .54668 Mdot
.564 .54676 Mdot
.564 .54677 Mdot
.564 .54712 Mdot
.564 .54729 Mdot
.564 .54747 Mdot
.564 .5476 Mdot
.564 .54763 Mdot
.564 .54803 Mdot
.564 .54811 Mdot
.564 .54814 Mdot
.564 .54821 Mdot
.564 .54826 Mdot
.564 .54831 Mdot
.564 .5484 Mdot
.564 .54856 Mdot
.564 .54859 Mdot
.564 .54866 Mdot
.564 .54884 Mdot
.564 .54886 Mdot
.564 .54898 Mdot
.564 .54899 Mdot
.564 .54899 Mdot
.564 .54903 Mdot
.564 .54917 Mdot
.564 .54923 Mdot
.564 .54935 Mdot
.564 .54947 Mdot
.564 .54956 Mdot
.564 .54959 Mdot
.564 .54965 Mdot
.564 .54966 Mdot
.564 .54967 Mdot
.564 .54974 Mdot
.564 .54985 Mdot
.564 .54989 Mdot
.564 .55004 Mdot
.564 .55005 Mdot
.564 .55006 Mdot
.564 .55006 Mdot
.564 .5501 Mdot
.564 .55037 Mdot
.564 .55045 Mdot
.564 .55048 Mdot
.564 .55056 Mdot
.564 .55061 Mdot
.564 .55068 Mdot
.564 .55069 Mdot
.564 .5508 Mdot
.564 .55091 Mdot
.564 .55094 Mdot
.564 .55095 Mdot
.564 .55095 Mdot
.564 .55102 Mdot
.564 .55108 Mdot
.564 .55111 Mdot
.564 .55112 Mdot
.564 .55118 Mdot
.564 .55126 Mdot
.564 .55131 Mdot
.564 .55131 Mdot
.564 .55132 Mdot
.564 .55135 Mdot
.564 .55141 Mdot
.564 .55142 Mdot
.564 .55143 Mdot
.564 .55145 Mdot
.564 .55146 Mdot
.564 .55147 Mdot
.564 .55147 Mdot
.564 .55154 Mdot
.564 .55157 Mdot
.564 .55158 Mdot
.564 .55161 Mdot
.564 .55166 Mdot
.564 .55171 Mdot
.564 .55174 Mdot
.564 .55176 Mdot
.564 .55179 Mdot
.564 .55179 Mdot
.564 .55183 Mdot
.564 .55185 Mdot
.564 .5519 Mdot
.564 .55192 Mdot
.564 .55194 Mdot
.564 .55195 Mdot
.564 .55196 Mdot
.564 .55197 Mdot
.564 .55197 Mdot
.564 .55198 Mdot
.564 .55198 Mdot
.564 .55198 Mdot
.564 .55199 Mdot
.564 .55199 Mdot
.564 .55199 Mdot
.564 .55199 Mdot
.566 .18514 Mdot
.566 .18517 Mdot
.566 .18519 Mdot
.566 .18519 Mdot
.566 .18521 Mdot
.566 .18526 Mdot
.566 .18532 Mdot
.566 .18539 Mdot
.566 .18544 Mdot
.566 .18549 Mdot
.566 .18553 Mdot
.566 .18558 Mdot
.566 .18562 Mdot
.566 .18564 Mdot
.566 .18581 Mdot
.566 .18584 Mdot
.566 .18599 Mdot
.566 .18601 Mdot
.566 .1861 Mdot
.566 .18646 Mdot
.566 .18649 Mdot
.566 .1866 Mdot
.566 .18663 Mdot
.566 .18684 Mdot
.566 .18692 Mdot
.566 .18698 Mdot
.566 .18712 Mdot
.566 .18717 Mdot
.566 .1872 Mdot
.566 .18725 Mdot
.566 .18727 Mdot
.566 .18734 Mdot
.566 .18748 Mdot
.566 .1875 Mdot
.566 .18771 Mdot
.566 .18771 Mdot
.566 .18804 Mdot
.566 .18831 Mdot
.566 .1884 Mdot
.566 .18851 Mdot
.566 .18864 Mdot
.566 .18881 Mdot
.566 .1891 Mdot
.566 .18911 Mdot
.566 .18935 Mdot
.566 .1898 Mdot
.566 .18983 Mdot
.566 .19006 Mdot
.566 .19051 Mdot
.566 .19061 Mdot
.566 .19087 Mdot
.566 .19104 Mdot
.566 .19146 Mdot
.566 .19149 Mdot
.566 .19204 Mdot
.566 .19244 Mdot
.566 .19304 Mdot
.566 .19308 Mdot
.566 .1934 Mdot
.566 .19351 Mdot
.566 .19355 Mdot
.566 .19439 Mdot
.566 .19456 Mdot
.566 .19502 Mdot
.566 .19521 Mdot
.566 .1954 Mdot
.566 .19559 Mdot
.566 .1957 Mdot
.566 .19696 Mdot
.566 .19737 Mdot
.566 .19752 Mdot
.566 .19811 Mdot
.566 .19844 Mdot
.566 .19866 Mdot
.566 .19926 Mdot
.566 .1997 Mdot
.566 .19974 Mdot
.566 .19983 Mdot
.566 .2 Mdot
.566 .20002 Mdot
.566 .20031 Mdot
.566 .2004 Mdot
.566 .20096 Mdot
.566 .20099 Mdot
.566 .20106 Mdot
.566 .20186 Mdot
.566 .20275 Mdot
.566 .2028 Mdot
.566 .20289 Mdot
.566 .20348 Mdot
.566 .20406 Mdot
.566 .20409 Mdot
.566 .20441 Mdot
.566 .20442 Mdot
.566 .2048 Mdot
.566 .20529 Mdot
.566 .20564 Mdot
.566 .20673 Mdot
.566 .20756 Mdot
.566 .20764 Mdot
.566 .20879 Mdot
.566 .20915 Mdot
.566 .21026 Mdot
.566 .21035 Mdot
.566 .2107 Mdot
.566 .21215 Mdot
.566 .21244 Mdot
.566 .21317 Mdot
.566 .21318 Mdot
.566 .21334 Mdot
.566 .21356 Mdot
.566 .21376 Mdot
.566 .21398 Mdot
.566 .21404 Mdot
.566 .2142 Mdot
.566 .21476 Mdot
.566 .2152 Mdot
.566 .21573 Mdot
.566 .21588 Mdot
.566 .2164 Mdot
.566 .2167 Mdot
.566 .21833 Mdot
.566 .21919 Mdot
.566 .21939 Mdot
.566 .2196 Mdot
.566 .21992 Mdot
.566 .22001 Mdot
.566 .2204 Mdot
.566 .22091 Mdot
.566 .22104 Mdot
.566 .22106 Mdot
.566 .22189 Mdot
.566 .22288 Mdot
.566 .22358 Mdot
.566 .22425 Mdot
.566 .22461 Mdot
.566 .2253 Mdot
.566 .22559 Mdot
.566 .22595 Mdot
.566 .22689 Mdot
.566 .22706 Mdot
.566 .22709 Mdot
.566 .22748 Mdot
.566 .22769 Mdot
.566 .22779 Mdot
.566 .22786 Mdot
.566 .2282 Mdot
.566 .22872 Mdot
.566 .22879 Mdot
.566 .22888 Mdot
.566 .22933 Mdot
.566 .22934 Mdot
.566 .22984 Mdot
.566 .23 Mdot
.566 .23052 Mdot
.566 .23204 Mdot
.566 .23246 Mdot
.566 .23295 Mdot
.566 .23309 Mdot
.566 .23488 Mdot
.566 .23495 Mdot
.566 .23496 Mdot
.566 .23535 Mdot
.566 .23537 Mdot
.566 .23604 Mdot
.566 .23629 Mdot
.566 .23652 Mdot
.566 .23664 Mdot
.566 .23677 Mdot
.566 .23878 Mdot
.566 .23924 Mdot
.566 .23933 Mdot
.566 .23956 Mdot
.566 .23968 Mdot
.566 .23974 Mdot
.566 .23988 Mdot
.566 .24034 Mdot
.566 .24039 Mdot
.566 .24186 Mdot
.566 .24214 Mdot
.566 .2428 Mdot
.566 .24309 Mdot
.566 .24357 Mdot
.566 .24358 Mdot
.566 .24374 Mdot
.566 .24376 Mdot
.566 .24388 Mdot
.566 .24418 Mdot
.566 .24435 Mdot
.566 .245 Mdot
.566 .24575 Mdot
.566 .24575 Mdot
.566 .24592 Mdot
.566 .24681 Mdot
.566 .24686 Mdot
.566 .24701 Mdot
.566 .24785 Mdot
.566 .24785 Mdot
.566 .248 Mdot
.566 .24834 Mdot
.566 .24838 Mdot
.566 .2486 Mdot
.566 .24865 Mdot
.566 .24889 Mdot
.566 .24897 Mdot
.566 .24898 Mdot
.566 .24903 Mdot
.566 .24926 Mdot
.566 .24945 Mdot
.566 .24956 Mdot
.566 .24958 Mdot
.566 .24975 Mdot
.566 .24982 Mdot
.566 .25024 Mdot
.566 .25034 Mdot
.566 .25078 Mdot
.566 .25087 Mdot
.566 .25157 Mdot
.566 .25187 Mdot
.566 .25189 Mdot
.566 .25361 Mdot
.566 .25364 Mdot
.566 .25395 Mdot
.566 .25399 Mdot
.566 .25405 Mdot
.566 .25417 Mdot
.566 .25593 Mdot
.566 .25629 Mdot
.566 .2563 Mdot
.566 .25754 Mdot
.566 .2579 Mdot
.566 .25814 Mdot
.566 .25929 Mdot
.566 .25967 Mdot
.566 .25993 Mdot
.566 .26003 Mdot
.566 .26033 Mdot
.566 .26057 Mdot
.566 .26063 Mdot
.566 .26098 Mdot
.566 .261 Mdot
.566 .2611 Mdot
.566 .26166 Mdot
.566 .26188 Mdot
.566 .26205 Mdot
.566 .26269 Mdot
.566 .26415 Mdot
.566 .26467 Mdot
.566 .26476 Mdot
.566 .26807 Mdot
.566 .26817 Mdot
.566 .26853 Mdot
.566 .26923 Mdot
.566 .26954 Mdot
.566 .26968 Mdot
.566 .26995 Mdot
.566 .26995 Mdot
.566 .27047 Mdot
.566 .27068 Mdot
.566 .27175 Mdot
.566 .27208 Mdot
.566 .27599 Mdot
.566 .2764 Mdot
.566 .27672 Mdot
.566 .277 Mdot
.566 .27703 Mdot
.566 .27753 Mdot
.566 .27812 Mdot
.566 .27971 Mdot
.566 .27976 Mdot
.566 .27979 Mdot
.566 .28069 Mdot
.566 .28071 Mdot
.566 .28087 Mdot
.566 .28518 Mdot
.566 .28553 Mdot
.566 .28672 Mdot
.566 .28776 Mdot
.566 .28843 Mdot
.566 .28923 Mdot
.566 .29057 Mdot
.566 .2915 Mdot
.566 .29189 Mdot
.566 .29277 Mdot
.566 .29317 Mdot
.566 .29322 Mdot
.566 .29443 Mdot
.566 .29445 Mdot
.566 .29558 Mdot
.566 .29581 Mdot
.566 .296 Mdot
.566 .29655 Mdot
.566 .29729 Mdot
.566 .29777 Mdot
.566 .29817 Mdot
.566 .29834 Mdot
.566 .29859 Mdot
.566 .29911 Mdot
.566 .3001 Mdot
.566 .30018 Mdot
.566 .30063 Mdot
.566 .30303 Mdot
.566 .30385 Mdot
.566 .30395 Mdot
.566 .30417 Mdot
.566 .30469 Mdot
.566 .30502 Mdot
.566 .30647 Mdot
.566 .30734 Mdot
.566 .30741 Mdot
.566 .30766 Mdot
.566 .30916 Mdot
.566 .31098 Mdot
.566 .31214 Mdot
.566 .31358 Mdot
.566 .31513 Mdot
.566 .31576 Mdot
.566 .31582 Mdot
.566 .31617 Mdot
.566 .31752 Mdot
.566 .31856 Mdot
.566 .31878 Mdot
.566 .31931 Mdot
.566 .31952 Mdot
.566 .31965 Mdot
.566 .3202 Mdot
.566 .32073 Mdot
.566 .32271 Mdot
.566 .32303 Mdot
.566 .32403 Mdot
.566 .32597 Mdot
.566 .3268 Mdot
.566 .32742 Mdot
.566 .32825 Mdot
.566 .32966 Mdot
.566 .33007 Mdot
.566 .33022 Mdot
.566 .33151 Mdot
.566 .33207 Mdot
.566 .33229 Mdot
.566 .33272 Mdot
.566 .33423 Mdot
.566 .33467 Mdot
.566 .33483 Mdot
.566 .33545 Mdot
.566 .33578 Mdot
.566 .336 Mdot
.566 .3366 Mdot
.566 .33704 Mdot
.566 .33707 Mdot
.566 .33762 Mdot
.566 .33771 Mdot
.566 .33907 Mdot
.566 .33986 Mdot
.566 .33999 Mdot
.566 .3413 Mdot
.566 .34233 Mdot
.566 .34322 Mdot
.566 .34388 Mdot
.566 .34394 Mdot
.566 .34485 Mdot
.566 .34512 Mdot
.566 .34603 Mdot
.566 .3482 Mdot
.566 .34865 Mdot
.566 .3487 Mdot
.566 .34919 Mdot
.566 .35032 Mdot
.566 .35052 Mdot
.566 .3516 Mdot
.566 .35217 Mdot
.566 .3523 Mdot
.566 .35243 Mdot
.566 .35264 Mdot
.566 .35269 Mdot
.566 .35294 Mdot
.566 .35335 Mdot
.566 .3545 Mdot
.566 .35493 Mdot
.566 .35497 Mdot
.566 .35557 Mdot
.566 .35728 Mdot
.566 .3575 Mdot
.566 .35805 Mdot
.566 .35836 Mdot
.566 .35865 Mdot
.566 .35904 Mdot
.566 .36041 Mdot
.566 .36148 Mdot
.566 .36151 Mdot
.566 .36152 Mdot
.566 .36224 Mdot
.566 .36236 Mdot
.566 .36243 Mdot
.566 .3625 Mdot
.566 .36357 Mdot
.566 .36382 Mdot
.566 .36415 Mdot
.566 .36518 Mdot
.566 .36533 Mdot
.566 .36567 Mdot
.566 .36582 Mdot
.566 .36606 Mdot
.566 .36606 Mdot
.566 .36622 Mdot
.566 .36637 Mdot
.566 .36679 Mdot
.566 .36717 Mdot
.566 .36772 Mdot
.566 .36821 Mdot
.566 .36861 Mdot
.566 .36872 Mdot
.566 .36876 Mdot
.566 .3688 Mdot
.566 .36891 Mdot
.566 .36918 Mdot
.566 .37101 Mdot
.566 .37119 Mdot
.566 .37128 Mdot
.566 .37287 Mdot
.566 .37314 Mdot
.566 .37398 Mdot
.566 .37402 Mdot
.566 .37451 Mdot
.566 .37477 Mdot
.566 .37487 Mdot
.566 .37613 Mdot
.566 .37785 Mdot
.566 .37847 Mdot
.566 .3794 Mdot
.566 .38109 Mdot
.566 .38153 Mdot
.566 .3827 Mdot
.566 .38627 Mdot
.566 .3866 Mdot
.566 .38714 Mdot
.566 .38767 Mdot
.566 .38821 Mdot
.566 .38954 Mdot
.566 .39002 Mdot
.566 .39241 Mdot
.566 .39253 Mdot
.566 .39286 Mdot
.566 .39376 Mdot
.566 .39388 Mdot
.566 .3956 Mdot
.566 .39673 Mdot
.566 .39831 Mdot
.566 .39839 Mdot
.566 .39958 Mdot
.566 .40007 Mdot
.566 .40079 Mdot
.566 .4011 Mdot
.566 .40236 Mdot
.566 .40304 Mdot
.566 .40312 Mdot
.566 .4044 Mdot
.566 .40507 Mdot
.566 .4051 Mdot
.566 .40592 Mdot
.566 .4064 Mdot
.566 .40677 Mdot
.566 .40709 Mdot
.566 .40735 Mdot
.566 .4081 Mdot
.566 .40905 Mdot
.566 .40906 Mdot
.566 .40964 Mdot
.566 .40971 Mdot
.566 .4101 Mdot
.566 .4103 Mdot
.566 .41035 Mdot
.566 .41049 Mdot
.566 .41058 Mdot
.566 .41072 Mdot
.566 .41113 Mdot
.566 .41129 Mdot
.566 .41151 Mdot
.566 .41212 Mdot
.566 .4122 Mdot
.566 .41251 Mdot
.566 .41261 Mdot
.566 .41362 Mdot
.566 .41388 Mdot
.566 .41392 Mdot
.566 .41435 Mdot
.566 .41444 Mdot
.566 .41492 Mdot
.566 .41497 Mdot
.566 .41509 Mdot
.566 .41523 Mdot
.566 .41534 Mdot
.566 .41549 Mdot
.566 .41562 Mdot
.566 .41582 Mdot
.566 .41599 Mdot
.566 .41613 Mdot
.566 .41618 Mdot
.566 .41619 Mdot
.566 .41623 Mdot
.566 .41633 Mdot
.566 .457 Mdot
.566 .45705 Mdot
.566 .45707 Mdot
.566 .45708 Mdot
.566 .45711 Mdot
.566 .45718 Mdot
.566 .45728 Mdot
.566 .45738 Mdot
.566 .45746 Mdot
.566 .45754 Mdot
.566 .4576 Mdot
.566 .45767 Mdot
.566 .45774 Mdot
.566 .45776 Mdot
.566 .45802 Mdot
.566 .45807 Mdot
.566 .4583 Mdot
.566 .45832 Mdot
.566 .45846 Mdot
.566 .45901 Mdot
.566 .45906 Mdot
.566 .45923 Mdot
.566 .45927 Mdot
.566 .4596 Mdot
.566 .45972 Mdot
.566 .4598 Mdot
.566 .46002 Mdot
.566 .4601 Mdot
.566 .46014 Mdot
.566 .46022 Mdot
.566 .46024 Mdot
.566 .46035 Mdot
.566 .46056 Mdot
.566 .4606 Mdot
.566 .4609 Mdot
.566 .46091 Mdot
.566 .46141 Mdot
.566 .46181 Mdot
.566 .46194 Mdot
.566 .46211 Mdot
.566 .46231 Mdot
.566 .46256 Mdot
.566 .46299 Mdot
.566 .46301 Mdot
.566 .46336 Mdot
.566 .46402 Mdot
.566 .46407 Mdot
.566 .46442 Mdot
.566 .46507 Mdot
.566 .46523 Mdot
.566 .4656 Mdot
.566 .46585 Mdot
.566 .46646 Mdot
.566 .4665 Mdot
.566 .46731 Mdot
.566 .46788 Mdot
.566 .46875 Mdot
.566 .46881 Mdot
.566 .46927 Mdot
.566 .46943 Mdot
.566 .4695 Mdot
.566 .47069 Mdot
.566 .47093 Mdot
.566 .47159 Mdot
.566 .47185 Mdot
.566 .47212 Mdot
.566 .47239 Mdot
.566 .47255 Mdot
.566 .4743 Mdot
.566 .47487 Mdot
.566 .47508 Mdot
.566 .4759 Mdot
.566 .47635 Mdot
.566 .47664 Mdot
.566 .47747 Mdot
.566 .47807 Mdot
.566 .47812 Mdot
.566 .47824 Mdot
.566 .47847 Mdot
.566 .4785 Mdot
.566 .47889 Mdot
.566 .47902 Mdot
.566 .47977 Mdot
.566 .47981 Mdot
.566 .4799 Mdot
.566 .48076 Mdot
.566 .48089 Mdot
.566 .48094 Mdot
.566 .48096 Mdot
.566 .48097 Mdot
.566 .48103 Mdot
.566 .48121 Mdot
.566 .48144 Mdot
.566 .4817 Mdot
.566 .48188 Mdot
.566 .48207 Mdot
.566 .48214 Mdot
.566 .48222 Mdot
.566 .48222 Mdot
.566 .48233 Mdot
.566 .4824 Mdot
.566 .48256 Mdot
.566 .48263 Mdot
.566 .4831 Mdot
.566 .48326 Mdot
.566 .48337 Mdot
.566 .48387 Mdot
.566 .4839 Mdot
.566 .48393 Mdot
.566 .48399 Mdot
.566 .48432 Mdot
.566 .48432 Mdot
.566 .48434 Mdot
.566 .48483 Mdot
.566 .48545 Mdot
.566 .48563 Mdot
.566 .48576 Mdot
.566 .48591 Mdot
.566 .48616 Mdot
.566 .48625 Mdot
.566 .48703 Mdot
.566 .4873 Mdot
.566 .48732 Mdot
.566 .48751 Mdot
.566 .48803 Mdot
.566 .48822 Mdot
.566 .48833 Mdot
.566 .48835 Mdot
.566 .48845 Mdot
.566 .48851 Mdot
.566 .48857 Mdot
.566 .48882 Mdot
.566 .4893 Mdot
.566 .48939 Mdot
.566 .48989 Mdot
.566 .49012 Mdot
.566 .49013 Mdot
.566 .49034 Mdot
.566 .4913 Mdot
.566 .4917 Mdot
.566 .49182 Mdot
.566 .49222 Mdot
.566 .49224 Mdot
.566 .49253 Mdot
.566 .49292 Mdot
.566 .49337 Mdot
.566 .49395 Mdot
.566 .494 Mdot
.566 .49435 Mdot
.566 .49494 Mdot
.566 .49498 Mdot
.566 .49521 Mdot
.566 .49523 Mdot
.566 .49542 Mdot
.566 .49568 Mdot
.566 .49577 Mdot
.566 .49592 Mdot
.566 .49618 Mdot
.566 .49625 Mdot
.566 .49644 Mdot
.566 .49709 Mdot
.566 .49727 Mdot
.566 .49737 Mdot
.566 .4976 Mdot
.566 .49816 Mdot
.566 .49822 Mdot
.566 .49839 Mdot
.566 .49899 Mdot
.566 .49935 Mdot
.566 .49961 Mdot
.566 .49996 Mdot
.566 .50078 Mdot
.566 .50119 Mdot
.566 .50133 Mdot
.566 .50215 Mdot
.566 .50238 Mdot
.566 .50261 Mdot
.566 .50266 Mdot
.566 .50275 Mdot
.566 .50297 Mdot
.566 .50306 Mdot
.566 .50349 Mdot
.566 .50405 Mdot
.566 .50419 Mdot
.566 .50422 Mdot
.566 .50448 Mdot
.566 .50512 Mdot
.566 .50571 Mdot
.566 .50618 Mdot
.566 .50693 Mdot
.566 .50753 Mdot
.566 .50764 Mdot
.566 .50766 Mdot
.566 .50801 Mdot
.566 .5086 Mdot
.566 .50874 Mdot
.566 .50894 Mdot
.566 .50904 Mdot
.566 .50907 Mdot
.566 .5094 Mdot
.566 .51037 Mdot
.566 .51055 Mdot
.566 .51058 Mdot
.566 .51097 Mdot
.566 .51118 Mdot
.566 .51128 Mdot
.566 .51135 Mdot
.566 .51151 Mdot
.566 .5117 Mdot
.566 .51199 Mdot
.566 .51221 Mdot
.566 .51229 Mdot
.566 .51238 Mdot
.566 .51282 Mdot
.566 .51283 Mdot
.566 .51331 Mdot
.566 .51333 Mdot
.566 .51349 Mdot
.566 .51383 Mdot
.566 .51399 Mdot
.566 .51435 Mdot
.566 .51488 Mdot
.566 .51519 Mdot
.566 .51545 Mdot
.566 .51586 Mdot
.566 .51632 Mdot
.566 .51646 Mdot
.566 .51812 Mdot
.566 .51819 Mdot
.566 .51819 Mdot
.566 .51854 Mdot
.566 .51855 Mdot
.566 .51857 Mdot
.566 .51918 Mdot
.566 .51941 Mdot
.566 .5196 Mdot
.566 .51961 Mdot
.566 .51972 Mdot
.566 .51984 Mdot
.566 .52 Mdot
.566 .52149 Mdot
.566 .52161 Mdot
.566 .52201 Mdot
.566 .52209 Mdot
.566 .52229 Mdot
.566 .52229 Mdot
.566 .52239 Mdot
.566 .52245 Mdot
.566 .52256 Mdot
.566 .52282 Mdot
.566 .52296 Mdot
.566 .523 Mdot
.566 .52424 Mdot
.566 .52428 Mdot
.566 .52447 Mdot
.566 .52502 Mdot
.566 .52525 Mdot
.566 .52532 Mdot
.566 .5254 Mdot
.566 .52561 Mdot
.566 .52565 Mdot
.566 .52565 Mdot
.566 .52578 Mdot
.566 .5258 Mdot
.566 .52589 Mdot
.566 .52601 Mdot
.566 .52604 Mdot
.566 .52614 Mdot
.566 .52628 Mdot
.566 .52671 Mdot
.566 .5268 Mdot
.566 .52693 Mdot
.566 .52739 Mdot
.566 .52739 Mdot
.566 .52752 Mdot
.566 .52817 Mdot
.566 .52822 Mdot
.566 .52824 Mdot
.566 .52825 Mdot
.566 .52837 Mdot
.566 .52837 Mdot
.566 .52901 Mdot
.566 .52901 Mdot
.566 .52912 Mdot
.566 .52938 Mdot
.566 .52941 Mdot
.566 .52958 Mdot
.566 .52961 Mdot
.566 .52976 Mdot
.566 .52979 Mdot
.566 .52985 Mdot
.566 .52986 Mdot
.566 .5299 Mdot
.566 .52997 Mdot
.566 .53005 Mdot
.566 .53007 Mdot
.566 .53007 Mdot
.566 .5301 Mdot
.566 .53019 Mdot
.566 .53021 Mdot
.566 .53029 Mdot
.566 .5303 Mdot
.566 .53043 Mdot
.566 .53048 Mdot
.566 .53048 Mdot
.566 .53079 Mdot
.566 .53084 Mdot
.566 .53086 Mdot
.566 .53118 Mdot
.566 .53124 Mdot
.566 .53125 Mdot
.566 .53152 Mdot
.566 .53175 Mdot
.566 .53181 Mdot
.566 .53192 Mdot
.566 .53196 Mdot
.566 .53197 Mdot
.566 .53203 Mdot
.566 .53203 Mdot
.566 .53221 Mdot
.566 .53231 Mdot
.566 .53255 Mdot
.566 .53265 Mdot
.566 .53318 Mdot
.566 .5332 Mdot
.566 .53336 Mdot
.566 .53341 Mdot
.566 .53343 Mdot
.566 .53348 Mdot
.566 .53356 Mdot
.566 .53359 Mdot
.566 .53376 Mdot
.566 .53448 Mdot
.566 .53452 Mdot
.566 .53457 Mdot
.566 .53465 Mdot
.566 .53474 Mdot
.566 .53498 Mdot
.566 .53498 Mdot
.566 .53512 Mdot
.566 .53512 Mdot
.566 .53515 Mdot
.566 .53579 Mdot
.566 .53584 Mdot
.566 .53601 Mdot
.566 .53616 Mdot
.566 .5367 Mdot
.566 .53688 Mdot
.566 .53694 Mdot
.566 .53712 Mdot
.566 .53712 Mdot
.566 .53728 Mdot
.566 .53731 Mdot
.566 .53734 Mdot
.566 .53752 Mdot
.566 .53764 Mdot
.566 .53766 Mdot
.566 .5377 Mdot
.566 .53777 Mdot
.566 .53791 Mdot
.566 .53792 Mdot
.566 .53798 Mdot
.566 .53831 Mdot
.566 .53844 Mdot
.566 .53854 Mdot
.566 .53878 Mdot
.566 .53891 Mdot
.566 .53914 Mdot
.566 .53939 Mdot
.566 .53973 Mdot
.566 .54002 Mdot
.566 .54003 Mdot
.566 .54008 Mdot
.566 .54025 Mdot
.566 .54039 Mdot
.566 .54042 Mdot
.566 .54053 Mdot
.566 .5406 Mdot
.566 .54067 Mdot
.566 .54097 Mdot
.566 .54154 Mdot
.566 .54164 Mdot
.566 .54182 Mdot
.566 .54187 Mdot
.566 .54206 Mdot
.566 .54221 Mdot
.566 .5424 Mdot
.566 .54246 Mdot
.566 .54248 Mdot
.566 .54256 Mdot
.566 .54262 Mdot
.566 .5427 Mdot
.566 .54276 Mdot
.566 .54276 Mdot
.566 .54301 Mdot
.566 .54311 Mdot
.566 .54361 Mdot
.566 .54373 Mdot
.566 .54376 Mdot
.566 .54414 Mdot
.566 .54426 Mdot
.566 .54466 Mdot
.566 .54468 Mdot
.566 .54497 Mdot
.566 .54534 Mdot
.566 .54546 Mdot
.566 .54563 Mdot
.566 .54575 Mdot
.566 .54576 Mdot
.566 .54587 Mdot
.566 .54588 Mdot
.566 .54608 Mdot
.566 .54628 Mdot
.566 .54631 Mdot
.566 .54632 Mdot
.566 .54662 Mdot
.566 .5469 Mdot
.566 .54692 Mdot
.566 .54693 Mdot
.566 .54712 Mdot
.566 .54715 Mdot
.566 .54725 Mdot
.566 .54725 Mdot
.566 .54731 Mdot
.566 .54734 Mdot
.566 .54735 Mdot
.566 .5475 Mdot
.566 .54771 Mdot
.566 .54778 Mdot
.566 .54789 Mdot
.566 .54809 Mdot
.566 .54814 Mdot
.566 .54828 Mdot
.566 .5487 Mdot
.566 .54874 Mdot
.566 .54881 Mdot
.566 .54887 Mdot
.566 .54893 Mdot
.566 .54909 Mdot
.566 .54914 Mdot
.566 .54942 Mdot
.566 .54944 Mdot
.566 .54948 Mdot
.566 .54958 Mdot
.566 .5496 Mdot
.566 .5498 Mdot
.566 .54993 Mdot
.566 .55012 Mdot
.566 .55013 Mdot
.566 .55027 Mdot
.566 .55032 Mdot
.566 .55041 Mdot
.566 .55044 Mdot
.566 .55059 Mdot
.566 .55067 Mdot
.566 .55068 Mdot
.566 .55083 Mdot
.566 .55091 Mdot
.566 .55091 Mdot
.566 .55101 Mdot
.566 .55106 Mdot
.566 .55111 Mdot
.566 .55115 Mdot
.566 .55118 Mdot
.566 .55126 Mdot
.566 .55137 Mdot
.566 .55138 Mdot
.566 .55144 Mdot
.566 .55145 Mdot
.566 .5515 Mdot
.566 .55152 Mdot
.566 .55153 Mdot
.566 .55154 Mdot
.566 .55155 Mdot
.566 .55157 Mdot
.566 .55162 Mdot
.566 .55164 Mdot
.566 .55166 Mdot
.566 .55173 Mdot
.566 .55174 Mdot
.566 .55178 Mdot
.566 .55179 Mdot
.566 .55191 Mdot
.566 .55194 Mdot
.566 .55195 Mdot
.566 .552 Mdot
.566 .55201 Mdot
.566 .55206 Mdot
.566 .55207 Mdot
.566 .55208 Mdot
.566 .5521 Mdot
.566 .55211 Mdot
.566 .55213 Mdot
.566 .55217 Mdot
.566 .55219 Mdot
.566 .5522 Mdot
.566 .55221 Mdot
.566 .55221 Mdot
.566 .55222 Mdot
.566 .55223 Mdot
.568 .1845 Mdot
.568 .1845 Mdot
.568 .18451 Mdot
.568 .18451 Mdot
.568 .18451 Mdot
.568 .18453 Mdot
.568 .18454 Mdot
.568 .1846 Mdot
.568 .18462 Mdot
.568 .18467 Mdot
.568 .18472 Mdot
.568 .18474 Mdot
.568 .18478 Mdot
.568 .18484 Mdot
.568 .18486 Mdot
.568 .18486 Mdot
.568 .18486 Mdot
.568 .18489 Mdot
.568 .18496 Mdot
.568 .1852 Mdot
.568 .18522 Mdot
.568 .18528 Mdot
.568 .18532 Mdot
.568 .18542 Mdot
.568 .18575 Mdot
.568 .18579 Mdot
.568 .18606 Mdot
.568 .18632 Mdot
.568 .18636 Mdot
.568 .18676 Mdot
.568 .18685 Mdot
.568 .18687 Mdot
.568 .18689 Mdot
.568 .18702 Mdot
.568 .18734 Mdot
.568 .18762 Mdot
.568 .1877 Mdot
.568 .18771 Mdot
.568 .18834 Mdot
.568 .18846 Mdot
.568 .18882 Mdot
.568 .18906 Mdot
.568 .1891 Mdot
.568 .18934 Mdot
.568 .18939 Mdot
.568 .18969 Mdot
.568 .19053 Mdot
.568 .19059 Mdot
.568 .19066 Mdot
.568 .19072 Mdot
.568 .19102 Mdot
.568 .19123 Mdot
.568 .19124 Mdot
.568 .19142 Mdot
.568 .19162 Mdot
.568 .19179 Mdot
.568 .19226 Mdot
.568 .19274 Mdot
.568 .1932 Mdot
.568 .19333 Mdot
.568 .19359 Mdot
.568 .1944 Mdot
.568 .1945 Mdot
.568 .19485 Mdot
.568 .19521 Mdot
.568 .19598 Mdot
.568 .19624 Mdot
.568 .19646 Mdot
.568 .19655 Mdot
.568 .19657 Mdot
.568 .19664 Mdot
.568 .19699 Mdot
.568 .19779 Mdot
.568 .19795 Mdot
.568 .19806 Mdot
.568 .19809 Mdot
.568 .19857 Mdot
.568 .19871 Mdot
.568 .19871 Mdot
.568 .19885 Mdot
.568 .19901 Mdot
.568 .19922 Mdot
.568 .19922 Mdot
.568 .19922 Mdot
.568 .20113 Mdot
.568 .20121 Mdot
.568 .20122 Mdot
.568 .20157 Mdot
.568 .20162 Mdot
.568 .20179 Mdot
.568 .20335 Mdot
.568 .20447 Mdot
.568 .20561 Mdot
.568 .20563 Mdot
.568 .20654 Mdot
.568 .20666 Mdot
.568 .2069 Mdot
.568 .20695 Mdot
.568 .20808 Mdot
.568 .20827 Mdot
.568 .20859 Mdot
.568 .20872 Mdot
.568 .20956 Mdot
.568 .20959 Mdot
.568 .20971 Mdot
.568 .21013 Mdot
.568 .2106 Mdot
.568 .21067 Mdot
.568 .2107 Mdot
.568 .21097 Mdot
.568 .21222 Mdot
.568 .21233 Mdot
.568 .21301 Mdot
.568 .21319 Mdot
.568 .21342 Mdot
.568 .21399 Mdot
.568 .21422 Mdot
.568 .21453 Mdot
.568 .2154 Mdot
.568 .21584 Mdot
.568 .21647 Mdot
.568 .21663 Mdot
.568 .2167 Mdot
.568 .21673 Mdot
.568 .21808 Mdot
.568 .21971 Mdot
.568 .22002 Mdot
.568 .22039 Mdot
.568 .22097 Mdot
.568 .22113 Mdot
.568 .22159 Mdot
.568 .22181 Mdot
.568 .22181 Mdot
.568 .22181 Mdot
.568 .22185 Mdot
.568 .222 Mdot
.568 .22233 Mdot
.568 .22259 Mdot
.568 .22291 Mdot
.568 .22302 Mdot
.568 .22319 Mdot
.568 .22331 Mdot
.568 .22346 Mdot
.568 .22371 Mdot
.568 .22444 Mdot
.568 .22583 Mdot
.568 .22774 Mdot
.568 .22784 Mdot
.568 .22798 Mdot
.568 .22857 Mdot
.568 .22915 Mdot
.568 .22977 Mdot
.568 .23093 Mdot
.568 .23094 Mdot
.568 .23104 Mdot
.568 .23115 Mdot
.568 .23125 Mdot
.568 .23175 Mdot
.568 .23206 Mdot
.568 .23219 Mdot
.568 .23258 Mdot
.568 .23343 Mdot
.568 .23358 Mdot
.568 .23411 Mdot
.568 .23423 Mdot
.568 .23461 Mdot
.568 .23544 Mdot
.568 .23563 Mdot
.568 .23627 Mdot
.568 .23753 Mdot
.568 .23791 Mdot
.568 .23812 Mdot
.568 .23839 Mdot
.568 .2384 Mdot
.568 .23948 Mdot
.568 .23961 Mdot
.568 .23985 Mdot
.568 .24155 Mdot
.568 .24182 Mdot
.568 .24239 Mdot
.568 .24244 Mdot
.568 .24247 Mdot
.568 .24278 Mdot
.568 .24316 Mdot
.568 .24374 Mdot
.568 .24389 Mdot
.568 .24481 Mdot
.568 .24494 Mdot
.568 .24536 Mdot
.568 .24567 Mdot
.568 .24572 Mdot
.568 .24641 Mdot
.568 .24672 Mdot
.568 .2472 Mdot
.568 .24802 Mdot
.568 .2482 Mdot
.568 .24857 Mdot
.568 .24921 Mdot
.568 .24948 Mdot
.568 .24989 Mdot
.568 .25062 Mdot
.568 .25064 Mdot
.568 .25101 Mdot
.568 .25154 Mdot
.568 .25162 Mdot
.568 .2521 Mdot
.568 .25226 Mdot
.568 .25228 Mdot
.568 .2523 Mdot
.568 .2526 Mdot
.568 .25273 Mdot
.568 .25362 Mdot
.568 .25374 Mdot
.568 .25438 Mdot
.568 .25438 Mdot
.568 .25464 Mdot
.568 .25551 Mdot
.568 .25586 Mdot
.568 .25596 Mdot
.568 .25641 Mdot
.568 .25662 Mdot
.568 .25669 Mdot
.568 .25752 Mdot
.568 .25774 Mdot
.568 .25782 Mdot
.568 .25799 Mdot
.568 .25827 Mdot
.568 .25832 Mdot
.568 .25839 Mdot
.568 .25844 Mdot
.568 .25845 Mdot
.568 .25979 Mdot
.568 .26013 Mdot
.568 .2614 Mdot
.568 .26223 Mdot
.568 .26291 Mdot
.568 .26299 Mdot
.568 .26309 Mdot
.568 .26381 Mdot
.568 .26384 Mdot
.568 .26384 Mdot
.568 .26427 Mdot
.568 .26436 Mdot
.568 .26496 Mdot
.568 .26517 Mdot
.568 .26622 Mdot
.568 .2671 Mdot
.568 .26713 Mdot
.568 .268 Mdot
.568 .26881 Mdot
.568 .26936 Mdot
.568 .26965 Mdot
.568 .27112 Mdot
.568 .27133 Mdot
.568 .27204 Mdot
.568 .27213 Mdot
.568 .27215 Mdot
.568 .27279 Mdot
.568 .27313 Mdot
.568 .27328 Mdot
.568 .27416 Mdot
.568 .27712 Mdot
.568 .27848 Mdot
.568 .27864 Mdot
.568 .27908 Mdot
.568 .28087 Mdot
.568 .28107 Mdot
.568 .28137 Mdot
.568 .2815 Mdot
.568 .28198 Mdot
.568 .28212 Mdot
.568 .28229 Mdot
.568 .28355 Mdot
.568 .28367 Mdot
.568 .28391 Mdot
.568 .28545 Mdot
.568 .28598 Mdot
.568 .28694 Mdot
.568 .28726 Mdot
.568 .28801 Mdot
.568 .28926 Mdot
.568 .28949 Mdot
.568 .28977 Mdot
.568 .29002 Mdot
.568 .29004 Mdot
.568 .29087 Mdot
.568 .29293 Mdot
.568 .29342 Mdot
.568 .29448 Mdot
.568 .29593 Mdot
.568 .29595 Mdot
.568 .29671 Mdot
.568 .29742 Mdot
.568 .29778 Mdot
.568 .29804 Mdot
.568 .30257 Mdot
.568 .30292 Mdot
.568 .30448 Mdot
.568 .30547 Mdot
.568 .30651 Mdot
.568 .30839 Mdot
.568 .30889 Mdot
.568 .30905 Mdot
.568 .30945 Mdot
.568 .30976 Mdot
.568 .31021 Mdot
.568 .31049 Mdot
.568 .31134 Mdot
.568 .31202 Mdot
.568 .31245 Mdot
.568 .31289 Mdot
.568 .31328 Mdot
.568 .31339 Mdot
.568 .3134 Mdot
.568 .3134 Mdot
.568 .31396 Mdot
.568 .31519 Mdot
.568 .31561 Mdot
.568 .31602 Mdot
.568 .31716 Mdot
.568 .31729 Mdot
.568 .31813 Mdot
.568 .31886 Mdot
.568 .31897 Mdot
.568 .3202 Mdot
.568 .32031 Mdot
.568 .32192 Mdot
.568 .32334 Mdot
.568 .3242 Mdot
.568 .3247 Mdot
.568 .32518 Mdot
.568 .32568 Mdot
.568 .32697 Mdot
.568 .32707 Mdot
.568 .32726 Mdot
.568 .32769 Mdot
.568 .32941 Mdot
.568 .33061 Mdot
.568 .33218 Mdot
.568 .33299 Mdot
.568 .33384 Mdot
.568 .33446 Mdot
.568 .33456 Mdot
.568 .33493 Mdot
.568 .33602 Mdot
.568 .33666 Mdot
.568 .3368 Mdot
.568 .33716 Mdot
.568 .33716 Mdot
.568 .33903 Mdot
.568 .33904 Mdot
.568 .33935 Mdot
.568 .34186 Mdot
.568 .3428 Mdot
.568 .34282 Mdot
.568 .34354 Mdot
.568 .34364 Mdot
.568 .34383 Mdot
.568 .34515 Mdot
.568 .3463 Mdot
.568 .34665 Mdot
.568 .34672 Mdot
.568 .34782 Mdot
.568 .3479 Mdot
.568 .34851 Mdot
.568 .34907 Mdot
.568 .34944 Mdot
.568 .35033 Mdot
.568 .35075 Mdot
.568 .35086 Mdot
.568 .3533 Mdot
.568 .35406 Mdot
.568 .35419 Mdot
.568 .35431 Mdot
.568 .35451 Mdot
.568 .35467 Mdot
.568 .35488 Mdot
.568 .35521 Mdot
.568 .35536 Mdot
.568 .35776 Mdot
.568 .35782 Mdot
.568 .35857 Mdot
.568 .35893 Mdot
.568 .36098 Mdot
.568 .36106 Mdot
.568 .36319 Mdot
.568 .36351 Mdot
.568 .36422 Mdot
.568 .36612 Mdot
.568 .36695 Mdot
.568 .36723 Mdot
.568 .36776 Mdot
.568 .36791 Mdot
.568 .36864 Mdot
.568 .36914 Mdot
.568 .36927 Mdot
.568 .36982 Mdot
.568 .37026 Mdot
.568 .3703 Mdot
.568 .37054 Mdot
.568 .37061 Mdot
.568 .37062 Mdot
.568 .37063 Mdot
.568 .37077 Mdot
.568 .37126 Mdot
.568 .37162 Mdot
.568 .37174 Mdot
.568 .37215 Mdot
.568 .37257 Mdot
.568 .3727 Mdot
.568 .37319 Mdot
.568 .37331 Mdot
.568 .37344 Mdot
.568 .37346 Mdot
.568 .37349 Mdot
.568 .37352 Mdot
.568 .37352 Mdot
.568 .37596 Mdot
.568 .37598 Mdot
.568 .37598 Mdot
.568 .37657 Mdot
.568 .37704 Mdot
.568 .37743 Mdot
.568 .37744 Mdot
.568 .37783 Mdot
.568 .37919 Mdot
.568 .37928 Mdot
.568 .37959 Mdot
.568 .38006 Mdot
.568 .38234 Mdot
.568 .38334 Mdot
.568 .38355 Mdot
.568 .3836 Mdot
.568 .38386 Mdot
.568 .3845 Mdot
.568 .38523 Mdot
.568 .38744 Mdot
.568 .38846 Mdot
.568 .38947 Mdot
.568 .38977 Mdot
.568 .39207 Mdot
.568 .39281 Mdot
.568 .39319 Mdot
.568 .39451 Mdot
.568 .39586 Mdot
.568 .39721 Mdot
.568 .39769 Mdot
.568 .39828 Mdot
.568 .39879 Mdot
.568 .39883 Mdot
.568 .39943 Mdot
.568 .40027 Mdot
.568 .40046 Mdot
.568 .40063 Mdot
.568 .40082 Mdot
.568 .40321 Mdot
.568 .40408 Mdot
.568 .40421 Mdot
.568 .40489 Mdot
.568 .40502 Mdot
.568 .4057 Mdot
.568 .40672 Mdot
.568 .40706 Mdot
.568 .40886 Mdot
.568 .40889 Mdot
.568 .40911 Mdot
.568 .40991 Mdot
.568 .41082 Mdot
.568 .41118 Mdot
.568 .41125 Mdot
.568 .41131 Mdot
.568 .41155 Mdot
.568 .41269 Mdot
.568 .41281 Mdot
.568 .41354 Mdot
.568 .41432 Mdot
.568 .41443 Mdot
.568 .41535 Mdot
.568 .41565 Mdot
.568 .41574 Mdot
.568 .41593 Mdot
.568 .41598 Mdot
.568 .41665 Mdot
.568 .41686 Mdot
.568 .41693 Mdot
.568 .41693 Mdot
.568 .41694 Mdot
.568 .41699 Mdot
.568 .41716 Mdot
.568 .41728 Mdot
.568 .41733 Mdot
.568 .41747 Mdot
.568 .41762 Mdot
.568 .41766 Mdot
.568 .41784 Mdot
.568 .41788 Mdot
.568 .41792 Mdot
.568 .41793 Mdot
.568 .41794 Mdot
.568 .41795 Mdot
.568 .41795 Mdot
.568 .45621 Mdot
.568 .45621 Mdot
.568 .45621 Mdot
.568 .45622 Mdot
.568 .45622 Mdot
.568 .45625 Mdot
.568 .45627 Mdot
.568 .45637 Mdot
.568 .45639 Mdot
.568 .45647 Mdot
.568 .45655 Mdot
.568 .45657 Mdot
.568 .45664 Mdot
.568 .45674 Mdot
.568 .45676 Mdot
.568 .45676 Mdot
.568 .45677 Mdot
.568 .4568 Mdot
.568 .45692 Mdot
.568 .45728 Mdot
.568 .45731 Mdot
.568 .45741 Mdot
.568 .45747 Mdot
.568 .45762 Mdot
.568 .45812 Mdot
.568 .45818 Mdot
.568 .4586 Mdot
.568 .45899 Mdot
.568 .45906 Mdot
.568 .45967 Mdot
.568 .4598 Mdot
.568 .45983 Mdot
.568 .45987 Mdot
.568 .46006 Mdot
.568 .46054 Mdot
.568 .46097 Mdot
.568 .46109 Mdot
.568 .4611 Mdot
.568 .46205 Mdot
.568 .46223 Mdot
.568 .46276 Mdot
.568 .46312 Mdot
.568 .46319 Mdot
.568 .46354 Mdot
.568 .46361 Mdot
.568 .46407 Mdot
.568 .4653 Mdot
.568 .4654 Mdot
.568 .46549 Mdot
.568 .46558 Mdot
.568 .46602 Mdot
.568 .46633 Mdot
.568 .46635 Mdot
.568 .4666 Mdot
.568 .4669 Mdot
.568 .46715 Mdot
.568 .46783 Mdot
.568 .46852 Mdot
.568 .46918 Mdot
.568 .46938 Mdot
.568 .46975 Mdot
.568 .4709 Mdot
.568 .47104 Mdot
.568 .47155 Mdot
.568 .47205 Mdot
.568 .47314 Mdot
.568 .4735 Mdot
.568 .47381 Mdot
.568 .47393 Mdot
.568 .47396 Mdot
.568 .47406 Mdot
.568 .47455 Mdot
.568 .47566 Mdot
.568 .47588 Mdot
.568 .47603 Mdot
.568 .47608 Mdot
.568 .47673 Mdot
.568 .47692 Mdot
.568 .47692 Mdot
.568 .47711 Mdot
.568 .47733 Mdot
.568 .47762 Mdot
.568 .47762 Mdot
.568 .47762 Mdot
.568 .47879 Mdot
.568 .47879 Mdot
.568 .4788 Mdot
.568 .47881 Mdot
.568 .47883 Mdot
.568 .47889 Mdot
.568 .47894 Mdot
.568 .47917 Mdot
.568 .47924 Mdot
.568 .47943 Mdot
.568 .47963 Mdot
.568 .47969 Mdot
.568 .47986 Mdot
.568 .48009 Mdot
.568 .48015 Mdot
.568 .48016 Mdot
.568 .48016 Mdot
.568 .4802 Mdot
.568 .48031 Mdot
.568 .48032 Mdot
.568 .48053 Mdot
.568 .48079 Mdot
.568 .48085 Mdot
.568 .48109 Mdot
.568 .48143 Mdot
.568 .4815 Mdot
.568 .48174 Mdot
.568 .48187 Mdot
.568 .48226 Mdot
.568 .48314 Mdot
.568 .48347 Mdot
.568 .48362 Mdot
.568 .4846 Mdot
.568 .48464 Mdot
.568 .48557 Mdot
.568 .48573 Mdot
.568 .48608 Mdot
.568 .48611 Mdot
.568 .48719 Mdot
.568 .48726 Mdot
.568 .48741 Mdot
.568 .4875 Mdot
.568 .48758 Mdot
.568 .48767 Mdot
.568 .48772 Mdot
.568 .48778 Mdot
.568 .48812 Mdot
.568 .48922 Mdot
.568 .48926 Mdot
.568 .48945 Mdot
.568 .48985 Mdot
.568 .49002 Mdot
.568 .49026 Mdot
.568 .49053 Mdot
.568 .49057 Mdot
.568 .49105 Mdot
.568 .49109 Mdot
.568 .49124 Mdot
.568 .49175 Mdot
.568 .49233 Mdot
.568 .49241 Mdot
.568 .49246 Mdot
.568 .49278 Mdot
.568 .49278 Mdot
.568 .4932 Mdot
.568 .49429 Mdot
.568 .49442 Mdot
.568 .49443 Mdot
.568 .49524 Mdot
.568 .49524 Mdot
.568 .49539 Mdot
.568 .49545 Mdot
.568 .49573 Mdot
.568 .4962 Mdot
.568 .49636 Mdot
.568 .4964 Mdot
.568 .49667 Mdot
.568 .49703 Mdot
.568 .49738 Mdot
.568 .49805 Mdot
.568 .49856 Mdot
.568 .49929 Mdot
.568 .49947 Mdot
.568 .49955 Mdot
.568 .49959 Mdot
.568 .50014 Mdot
.568 .50035 Mdot
.568 .50055 Mdot
.568 .50076 Mdot
.568 .50112 Mdot
.568 .50172 Mdot
.568 .50239 Mdot
.568 .50243 Mdot
.568 .50294 Mdot
.568 .50299 Mdot
.568 .50329 Mdot
.568 .50364 Mdot
.568 .50369 Mdot
.568 .50417 Mdot
.568 .50434 Mdot
.568 .50451 Mdot
.568 .50501 Mdot
.568 .50524 Mdot
.568 .50525 Mdot
.568 .50525 Mdot
.568 .50529 Mdot
.568 .50546 Mdot
.568 .50563 Mdot
.568 .50581 Mdot
.568 .50609 Mdot
.568 .50644 Mdot
.568 .50655 Mdot
.568 .50673 Mdot
.568 .50686 Mdot
.568 .50702 Mdot
.568 .50709 Mdot
.568 .50729 Mdot
.568 .50805 Mdot
.568 .50847 Mdot
.568 .50887 Mdot
.568 .5095 Mdot
.568 .50964 Mdot
.568 .51145 Mdot
.568 .51155 Mdot
.568 .5117 Mdot
.568 .51198 Mdot
.568 .51228 Mdot
.568 .51229 Mdot
.568 .51286 Mdot
.568 .51328 Mdot
.568 .51347 Mdot
.568 .51428 Mdot
.568 .51461 Mdot
.568 .51461 Mdot
.568 .51471 Mdot
.568 .51482 Mdot
.568 .51491 Mdot
.568 .5154 Mdot
.568 .51569 Mdot
.568 .51582 Mdot
.568 .51619 Mdot
.568 .5164 Mdot
.568 .517 Mdot
.568 .51709 Mdot
.568 .51713 Mdot
.568 .51762 Mdot
.568 .51769 Mdot
.568 .51774 Mdot
.568 .51793 Mdot
.568 .51798 Mdot
.568 .51809 Mdot
.568 .51817 Mdot
.568 .51886 Mdot
.568 .51903 Mdot
.568 .51909 Mdot
.568 .51961 Mdot
.568 .52074 Mdot
.568 .52107 Mdot
.568 .52113 Mdot
.568 .52126 Mdot
.568 .5215 Mdot
.568 .52151 Mdot
.568 .52154 Mdot
.568 .52181 Mdot
.568 .52189 Mdot
.568 .52244 Mdot
.568 .52255 Mdot
.568 .52276 Mdot
.568 .52307 Mdot
.568 .5234 Mdot
.568 .5234 Mdot
.568 .52374 Mdot
.568 .52413 Mdot
.568 .52421 Mdot
.568 .52443 Mdot
.568 .52463 Mdot
.568 .52463 Mdot
.568 .52464 Mdot
.568 .52491 Mdot
.568 .52495 Mdot
.568 .52497 Mdot
.568 .52523 Mdot
.568 .52554 Mdot
.568 .52601 Mdot
.568 .52613 Mdot
.568 .52663 Mdot
.568 .52663 Mdot
.568 .52665 Mdot
.568 .52668 Mdot
.568 .5267 Mdot
.568 .5268 Mdot
.568 .52687 Mdot
.568 .52689 Mdot
.568 .52697 Mdot
.568 .52728 Mdot
.568 .52731 Mdot
.568 .52738 Mdot
.568 .52755 Mdot
.568 .52759 Mdot
.568 .52772 Mdot
.568 .52804 Mdot
.568 .52813 Mdot
.568 .52813 Mdot
.568 .52837 Mdot
.568 .52841 Mdot
.568 .52874 Mdot
.568 .52879 Mdot
.568 .52889 Mdot
.568 .5289 Mdot
.568 .52891 Mdot
.568 .52897 Mdot
.568 .52914 Mdot
.568 .52917 Mdot
.568 .52937 Mdot
.568 .5295 Mdot
.568 .52951 Mdot
.568 .52978 Mdot
.568 .52993 Mdot
.568 .53002 Mdot
.568 .53026 Mdot
.568 .53039 Mdot
.568 .53046 Mdot
.568 .53076 Mdot
.568 .53093 Mdot
.568 .53104 Mdot
.568 .53129 Mdot
.568 .53131 Mdot
.568 .53142 Mdot
.568 .53157 Mdot
.568 .53162 Mdot
.568 .53195 Mdot
.568 .53201 Mdot
.568 .53222 Mdot
.568 .53235 Mdot
.568 .53247 Mdot
.568 .53248 Mdot
.568 .53249 Mdot
.568 .5327 Mdot
.568 .5328 Mdot
.568 .53341 Mdot
.568 .5335 Mdot
.568 .53354 Mdot
.568 .53393 Mdot
.568 .53393 Mdot
.568 .53403 Mdot
.568 .5341 Mdot
.568 .53424 Mdot
.568 .53469 Mdot
.568 .53492 Mdot
.568 .53498 Mdot
.568 .53528 Mdot
.568 .53542 Mdot
.568 .53546 Mdot
.568 .53565 Mdot
.568 .5357 Mdot
.568 .536 Mdot
.568 .53614 Mdot
.568 .53619 Mdot
.568 .5363 Mdot
.568 .53648 Mdot
.568 .53651 Mdot
.568 .53655 Mdot
.568 .53658 Mdot
.568 .53659 Mdot
.568 .537 Mdot
.568 .53722 Mdot
.568 .53742 Mdot
.568 .53763 Mdot
.568 .53768 Mdot
.568 .53771 Mdot
.568 .53839 Mdot
.568 .53887 Mdot
.568 .53913 Mdot
.568 .53921 Mdot
.568 .53927 Mdot
.568 .53931 Mdot
.568 .53937 Mdot
.568 .53941 Mdot
.568 .53952 Mdot
.568 .53961 Mdot
.568 .53973 Mdot
.568 .53978 Mdot
.568 .53979 Mdot
.568 .53979 Mdot
.568 .53979 Mdot
.568 .53987 Mdot
.568 .54003 Mdot
.568 .54009 Mdot
.568 .54029 Mdot
.568 .54042 Mdot
.568 .54053 Mdot
.568 .54109 Mdot
.568 .54156 Mdot
.568 .54157 Mdot
.568 .54159 Mdot
.568 .54165 Mdot
.568 .54187 Mdot
.568 .54202 Mdot
.568 .54232 Mdot
.568 .54243 Mdot
.568 .5425 Mdot
.568 .5427 Mdot
.568 .54278 Mdot
.568 .54284 Mdot
.568 .54308 Mdot
.568 .54312 Mdot
.568 .54355 Mdot
.568 .54364 Mdot
.568 .54365 Mdot
.568 .54367 Mdot
.568 .54383 Mdot
.568 .54398 Mdot
.568 .54402 Mdot
.568 .54403 Mdot
.568 .54431 Mdot
.568 .54436 Mdot
.568 .54447 Mdot
.568 .54453 Mdot
.568 .54492 Mdot
.568 .54494 Mdot
.568 .54502 Mdot
.568 .54506 Mdot
.568 .54537 Mdot
.568 .54538 Mdot
.568 .54577 Mdot
.568 .54615 Mdot
.568 .54667 Mdot
.568 .54673 Mdot
.568 .54675 Mdot
.568 .54687 Mdot
.568 .54687 Mdot
.568 .5469 Mdot
.568 .54754 Mdot
.568 .54755 Mdot
.568 .54755 Mdot
.568 .54762 Mdot
.568 .54767 Mdot
.568 .54772 Mdot
.568 .54772 Mdot
.568 .54776 Mdot
.568 .54793 Mdot
.568 .54794 Mdot
.568 .54797 Mdot
.568 .54803 Mdot
.568 .5483 Mdot
.568 .54841 Mdot
.568 .54844 Mdot
.568 .54844 Mdot
.568 .54848 Mdot
.568 .54855 Mdot
.568 .54864 Mdot
.568 .5489 Mdot
.568 .54902 Mdot
.568 .54913 Mdot
.568 .54917 Mdot
.568 .54944 Mdot
.568 .54953 Mdot
.568 .54957 Mdot
.568 .54972 Mdot
.568 .54988 Mdot
.568 .55004 Mdot
.568 .5501 Mdot
.568 .55017 Mdot
.568 .55022 Mdot
.568 .55023 Mdot
.568 .5503 Mdot
.568 .5504 Mdot
.568 .55042 Mdot
.568 .55044 Mdot
.568 .55046 Mdot
.568 .55074 Mdot
.568 .55084 Mdot
.568 .55086 Mdot
.568 .55094 Mdot
.568 .55095 Mdot
.568 .55103 Mdot
.568 .55115 Mdot
.568 .55119 Mdot
.568 .5514 Mdot
.568 .5514 Mdot
.568 .55143 Mdot
.568 .55152 Mdot
.568 .55163 Mdot
.568 .55167 Mdot
.568 .55168 Mdot
.568 .55169 Mdot
.568 .55172 Mdot
.568 .55185 Mdot
.568 .55186 Mdot
.568 .55195 Mdot
.568 .55204 Mdot
.568 .55205 Mdot
.568 .55216 Mdot
.568 .55219 Mdot
.568 .55221 Mdot
.568 .55223 Mdot
.568 .55223 Mdot
.568 .55231 Mdot
.568 .55234 Mdot
.568 .55234 Mdot
.568 .55234 Mdot
.568 .55235 Mdot
.568 .55235 Mdot
.568 .55237 Mdot
.568 .55239 Mdot
.568 .55239 Mdot
.568 .55241 Mdot
.568 .55242 Mdot
.568 .55243 Mdot
.568 .55245 Mdot
.568 .55245 Mdot
.568 .55246 Mdot
.568 .55246 Mdot
.568 .55246 Mdot
.568 .55246 Mdot
.568 .55246 Mdot
.57 .18386 Mdot
.57 .19259 Mdot
.57 .21526 Mdot
.57 .2677 Mdot
.57 .30902 Mdot
.57 .33062 Mdot
.57 .37791 Mdot
.57 .39471 Mdot
.57 .41958 Mdot
.57 .45541 Mdot
.57 .4685 Mdot
.57 .47677 Mdot
.57 .4981 Mdot
.57 .50708 Mdot
.57 .52322 Mdot
.57 .5421 Mdot
.57 .5498 Mdot
.57 .5527 Mdot
.572 .18323 Mdot
.572 .18324 Mdot
.572 .18327 Mdot
.572 .18332 Mdot
.572 .18334 Mdot
.572 .18339 Mdot
.572 .1834 Mdot
.572 .18344 Mdot
.572 .18351 Mdot
.572 .18362 Mdot
.572 .18367 Mdot
.572 .18368 Mdot
.572 .18373 Mdot
.572 .18373 Mdot
.572 .18376 Mdot
.572 .18393 Mdot
.572 .18398 Mdot
.572 .18407 Mdot
.572 .18409 Mdot
.572 .18412 Mdot
.572 .18413 Mdot
.572 .18414 Mdot
.572 .18427 Mdot
.572 .18433 Mdot
.572 .18457 Mdot
.572 .18458 Mdot
.572 .18461 Mdot
.572 .18475 Mdot
.572 .18493 Mdot
.572 .18502 Mdot
.572 .18508 Mdot
.572 .18519 Mdot
.572 .18528 Mdot
.572 .1853 Mdot
.572 .18536 Mdot
.572 .1854 Mdot
.572 .18576 Mdot
.572 .18586 Mdot
.572 .18608 Mdot
.572 .1871 Mdot
.572 .18723 Mdot
.572 .18739 Mdot
.572 .18739 Mdot
.572 .18756 Mdot
.572 .18806 Mdot
.572 .18857 Mdot
.572 .18938 Mdot
.572 .18968 Mdot
.572 .19004 Mdot
.572 .19055 Mdot
.572 .19091 Mdot
.572 .19106 Mdot
.572 .19133 Mdot
.572 .19135 Mdot
.572 .19177 Mdot
.572 .19177 Mdot
.572 .19249 Mdot
.572 .19276 Mdot
.572 .19286 Mdot
.572 .19327 Mdot
.572 .19338 Mdot
.572 .19373 Mdot
.572 .19379 Mdot
.572 .19386 Mdot
.572 .19387 Mdot
.572 .19463 Mdot
.572 .19652 Mdot
.572 .19699 Mdot
.572 .19771 Mdot
.572 .19776 Mdot
.572 .19804 Mdot
.572 .19805 Mdot
.572 .1983 Mdot
.572 .1984 Mdot
.572 .19858 Mdot
.572 .19901 Mdot
.572 .19931 Mdot
.572 .19937 Mdot
.572 .19939 Mdot
.572 .19972 Mdot
.572 .19986 Mdot
.572 .20012 Mdot
.572 .20014 Mdot
.572 .20025 Mdot
.572 .20045 Mdot
.572 .20165 Mdot
.572 .2018 Mdot
.572 .20191 Mdot
.572 .20253 Mdot
.572 .20264 Mdot
.572 .20302 Mdot
.572 .2039 Mdot
.572 .20424 Mdot
.572 .20495 Mdot
.572 .20536 Mdot
.572 .2056 Mdot
.572 .20626 Mdot
.572 .20651 Mdot
.572 .20669 Mdot
.572 .20799 Mdot
.572 .20842 Mdot
.572 .20855 Mdot
.572 .20926 Mdot
.572 .20973 Mdot
.572 .21021 Mdot
.572 .21129 Mdot
.572 .21194 Mdot
.572 .212 Mdot
.572 .21213 Mdot
.572 .21218 Mdot
.572 .21231 Mdot
.572 .21241 Mdot
.572 .21256 Mdot
.572 .21262 Mdot
.572 .21274 Mdot
.572 .21286 Mdot
.572 .21312 Mdot
.572 .21401 Mdot
.572 .21432 Mdot
.572 .21437 Mdot
.572 .21474 Mdot
.572 .21478 Mdot
.572 .2149 Mdot
.572 .21522 Mdot
.572 .21555 Mdot
.572 .21563 Mdot
.572 .2158 Mdot
.572 .21606 Mdot
.572 .21759 Mdot
.572 .21779 Mdot
.572 .21854 Mdot
.572 .2188 Mdot
.572 .21913 Mdot
.572 .21933 Mdot
.572 .21977 Mdot
.572 .21998 Mdot
.572 .22061 Mdot
.572 .22131 Mdot
.572 .22132 Mdot
.572 .22144 Mdot
.572 .22206 Mdot
.572 .22258 Mdot
.572 .22286 Mdot
.572 .22411 Mdot
.572 .22446 Mdot
.572 .22466 Mdot
.572 .22522 Mdot
.572 .22559 Mdot
.572 .22574 Mdot
.572 .22583 Mdot
.572 .22584 Mdot
.572 .22603 Mdot
.572 .22612 Mdot
.572 .22693 Mdot
.572 .22895 Mdot
.572 .22907 Mdot
.572 .22974 Mdot
.572 .23023 Mdot
.572 .23131 Mdot
.572 .23132 Mdot
.572 .23227 Mdot
.572 .23232 Mdot
.572 .23255 Mdot
.572 .23371 Mdot
.572 .23422 Mdot
.572 .23433 Mdot
.572 .23443 Mdot
.572 .23485 Mdot
.572 .23514 Mdot
.572 .23576 Mdot
.572 .23738 Mdot
.572 .23804 Mdot
.572 .2391 Mdot
.572 .23912 Mdot
.572 .23928 Mdot
.572 .23993 Mdot
.572 .24017 Mdot
.572 .24032 Mdot
.572 .24081 Mdot
.572 .24103 Mdot
.572 .2411 Mdot
.572 .24119 Mdot
.572 .24125 Mdot
.572 .24137 Mdot
.572 .2418 Mdot
.572 .24265 Mdot
.572 .24444 Mdot
.572 .24533 Mdot
.572 .2454 Mdot
.572 .24595 Mdot
.572 .24637 Mdot
.572 .24684 Mdot
.572 .24689 Mdot
.572 .24978 Mdot
.572 .25228 Mdot
.572 .25235 Mdot
.572 .25246 Mdot
.572 .25282 Mdot
.572 .2529 Mdot
.572 .25345 Mdot
.572 .254 Mdot
.572 .25435 Mdot
.572 .25521 Mdot
.572 .25554 Mdot
.572 .25569 Mdot
.572 .25591 Mdot
.572 .25603 Mdot
.572 .25709 Mdot
.572 .25762 Mdot
.572 .25762 Mdot
.572 .25822 Mdot
.572 .2585 Mdot
.572 .26057 Mdot
.572 .26062 Mdot
.572 .26073 Mdot
.572 .26074 Mdot
.572 .26087 Mdot
.572 .26109 Mdot
.572 .26143 Mdot
.572 .26154 Mdot
.572 .26175 Mdot
.572 .2625 Mdot
.572 .26298 Mdot
.572 .26344 Mdot
.572 .26344 Mdot
.572 .26427 Mdot
.572 .2644 Mdot
.572 .26468 Mdot
.572 .26481 Mdot
.572 .26501 Mdot
.572 .26518 Mdot
.572 .26566 Mdot
.572 .26579 Mdot
.572 .26678 Mdot
.572 .26695 Mdot
.572 .26712 Mdot
.572 .26734 Mdot
.572 .26763 Mdot
.572 .26766 Mdot
.572 .26791 Mdot
.572 .26795 Mdot
.572 .26894 Mdot
.572 .26902 Mdot
.572 .26915 Mdot
.572 .26925 Mdot
.572 .26932 Mdot
.572 .26954 Mdot
.572 .26958 Mdot
.572 .27004 Mdot
.572 .27116 Mdot
.572 .2715 Mdot
.572 .27203 Mdot
.572 .27212 Mdot
.572 .27343 Mdot
.572 .27357 Mdot
.572 .27428 Mdot
.572 .27448 Mdot
.572 .27537 Mdot
.572 .27565 Mdot
.572 .27638 Mdot
.572 .2767 Mdot
.572 .27732 Mdot
.572 .27741 Mdot
.572 .27754 Mdot
.572 .27889 Mdot
.572 .27956 Mdot
.572 .27958 Mdot
.572 .28058 Mdot
.572 .28083 Mdot
.572 .2811 Mdot
.572 .28232 Mdot
.572 .28516 Mdot
.572 .28572 Mdot
.572 .28584 Mdot
.572 .2882 Mdot
.572 .28822 Mdot
.572 .2909 Mdot
.572 .29214 Mdot
.572 .29297 Mdot
.572 .29382 Mdot
.572 .29413 Mdot
.572 .29851 Mdot
.572 .29855 Mdot
.572 .29909 Mdot
.572 .29925 Mdot
.572 .2995 Mdot
.572 .30135 Mdot
.572 .30158 Mdot
.572 .30206 Mdot
.572 .3021 Mdot
.572 .30213 Mdot
.572 .30232 Mdot
.572 .3027 Mdot
.572 .30289 Mdot
.572 .30367 Mdot
.572 .30513 Mdot
.572 .30564 Mdot
.572 .30601 Mdot
.572 .30656 Mdot
.572 .30672 Mdot
.572 .30878 Mdot
.572 .30984 Mdot
.572 .31056 Mdot
.572 .31193 Mdot
.572 .31359 Mdot
.572 .3139 Mdot
.572 .31392 Mdot
.572 .3142 Mdot
.572 .31421 Mdot
.572 .31578 Mdot
.572 .31747 Mdot
.572 .31749 Mdot
.572 .31759 Mdot
.572 .31803 Mdot
.572 .31923 Mdot
.572 .31967 Mdot
.572 .31977 Mdot
.572 .32063 Mdot
.572 .32085 Mdot
.572 .32134 Mdot
.572 .32337 Mdot
.572 .32362 Mdot
.572 .32391 Mdot
.572 .32757 Mdot
.572 .32808 Mdot
.572 .32878 Mdot
.572 .32926 Mdot
.572 .32947 Mdot
.572 .33038 Mdot
.572 .33038 Mdot
.572 .33126 Mdot
.572 .33159 Mdot
.572 .3317 Mdot
.572 .33272 Mdot
.572 .33278 Mdot
.572 .33286 Mdot
.572 .33372 Mdot
.572 .33617 Mdot
.572 .33689 Mdot
.572 .33721 Mdot
.572 .33755 Mdot
.572 .33772 Mdot
.572 .33813 Mdot
.572 .3384 Mdot
.572 .33878 Mdot
.572 .33891 Mdot
.572 .33916 Mdot
.572 .33926 Mdot
.572 .33944 Mdot
.572 .34125 Mdot
.572 .34323 Mdot
.572 .34427 Mdot
.572 .34559 Mdot
.572 .34722 Mdot
.572 .34858 Mdot
.572 .34862 Mdot
.572 .34893 Mdot
.572 .34927 Mdot
.572 .34988 Mdot
.572 .35048 Mdot
.572 .35096 Mdot
.572 .35416 Mdot
.572 .35467 Mdot
.572 .35536 Mdot
.572 .35724 Mdot
.572 .35794 Mdot
.572 .35909 Mdot
.572 .35916 Mdot
.572 .36097 Mdot
.572 .3611 Mdot
.572 .36173 Mdot
.572 .36206 Mdot
.572 .36459 Mdot
.572 .36468 Mdot
.572 .36501 Mdot
.572 .36547 Mdot
.572 .36561 Mdot
.572 .36566 Mdot
.572 .36597 Mdot
.572 .3664 Mdot
.572 .36729 Mdot
.572 .36774 Mdot
.572 .36777 Mdot
.572 .36805 Mdot
.572 .36848 Mdot
.572 .36851 Mdot
.572 .36991 Mdot
.572 .37111 Mdot
.572 .37136 Mdot
.572 .3714 Mdot
.572 .37192 Mdot
.572 .37248 Mdot
.572 .37281 Mdot
.572 .37286 Mdot
.572 .37335 Mdot
.572 .3736 Mdot
.572 .37387 Mdot
.572 .374 Mdot
.572 .37495 Mdot
.572 .37497 Mdot
.572 .37502 Mdot
.572 .37502 Mdot
.572 .37508 Mdot
.572 .37518 Mdot
.572 .37533 Mdot
.572 .37548 Mdot
.572 .37582 Mdot
.572 .37603 Mdot
.572 .37623 Mdot
.572 .37661 Mdot
.572 .37728 Mdot
.572 .37779 Mdot
.572 .37796 Mdot
.572 .37809 Mdot
.572 .37821 Mdot
.572 .37822 Mdot
.572 .37866 Mdot
.572 .37869 Mdot
.572 .37879 Mdot
.572 .37882 Mdot
.572 .37913 Mdot
.572 .37962 Mdot
.572 .37977 Mdot
.572 .38003 Mdot
.572 .38059 Mdot
.572 .38095 Mdot
.572 .38104 Mdot
.572 .38142 Mdot
.572 .38153 Mdot
.572 .38184 Mdot
.572 .38197 Mdot
.572 .38224 Mdot
.572 .38233 Mdot
.572 .38317 Mdot
.572 .38862 Mdot
.572 .39081 Mdot
.572 .39083 Mdot
.572 .39104 Mdot
.572 .3912 Mdot
.572 .39222 Mdot
.572 .39251 Mdot
.572 .39371 Mdot
.572 .39399 Mdot
.572 .39477 Mdot
.572 .39682 Mdot
.572 .39683 Mdot
.572 .39805 Mdot
.572 .39809 Mdot
.572 .39887 Mdot
.572 .39931 Mdot
.572 .40033 Mdot
.572 .40179 Mdot
.572 .40281 Mdot
.572 .40369 Mdot
.572 .40599 Mdot
.572 .40746 Mdot
.572 .40888 Mdot
.572 .40937 Mdot
.572 .40938 Mdot
.572 .40982 Mdot
.572 .41021 Mdot
.572 .41311 Mdot
.572 .41375 Mdot
.572 .41401 Mdot
.572 .41505 Mdot
.572 .41517 Mdot
.572 .41532 Mdot
.572 .41538 Mdot
.572 .41565 Mdot
.572 .41597 Mdot
.572 .41613 Mdot
.572 .41639 Mdot
.572 .41688 Mdot
.572 .4173 Mdot
.572 .41739 Mdot
.572 .4174 Mdot
.572 .41808 Mdot
.572 .41827 Mdot
.572 .41864 Mdot
.572 .41866 Mdot
.572 .41869 Mdot
.572 .41877 Mdot
.572 .41883 Mdot
.572 .41894 Mdot
.572 .41909 Mdot
.572 .41922 Mdot
.572 .41969 Mdot
.572 .41978 Mdot
.572 .41978 Mdot
.572 .41993 Mdot
.572 .41995 Mdot
.572 .4201 Mdot
.572 .42041 Mdot
.572 .42061 Mdot
.572 .42073 Mdot
.572 .42076 Mdot
.572 .42089 Mdot
.572 .42094 Mdot
.572 .42109 Mdot
.572 .42118 Mdot
.572 .42121 Mdot
.572 .45461 Mdot
.572 .45463 Mdot
.572 .45468 Mdot
.572 .45476 Mdot
.572 .45479 Mdot
.572 .45486 Mdot
.572 .45487 Mdot
.572 .45494 Mdot
.572 .45505 Mdot
.572 .45522 Mdot
.572 .45531 Mdot
.572 .45532 Mdot
.572 .4554 Mdot
.572 .4554 Mdot
.572 .45545 Mdot
.572 .45571 Mdot
.572 .45578 Mdot
.572 .45592 Mdot
.572 .45595 Mdot
.572 .456 Mdot
.572 .45601 Mdot
.572 .45603 Mdot
.572 .45623 Mdot
.572 .45633 Mdot
.572 .4567 Mdot
.572 .45671 Mdot
.572 .45676 Mdot
.572 .45698 Mdot
.572 .45725 Mdot
.572 .45739 Mdot
.572 .45748 Mdot
.572 .45765 Mdot
.572 .4578 Mdot
.572 .45783 Mdot
.572 .45791 Mdot
.572 .45798 Mdot
.572 .45854 Mdot
.572 .45868 Mdot
.572 .45902 Mdot
.572 .46057 Mdot
.572 .46077 Mdot
.572 .46101 Mdot
.572 .46102 Mdot
.572 .46127 Mdot
.572 .46202 Mdot
.572 .46279 Mdot
.572 .46399 Mdot
.572 .46445 Mdot
.572 .46498 Mdot
.572 .46572 Mdot
.572 .46625 Mdot
.572 .46648 Mdot
.572 .46687 Mdot
.572 .46689 Mdot
.572 .46751 Mdot
.572 .46752 Mdot
.572 .46855 Mdot
.572 .46895 Mdot
.572 .46909 Mdot
.572 .46969 Mdot
.572 .46984 Mdot
.572 .47035 Mdot
.572 .47043 Mdot
.572 .47053 Mdot
.572 .47054 Mdot
.572 .47163 Mdot
.572 .4743 Mdot
.572 .47471 Mdot
.572 .47476 Mdot
.572 .47488 Mdot
.572 .47495 Mdot
.572 .4751 Mdot
.572 .47516 Mdot
.572 .47534 Mdot
.572 .47538 Mdot
.572 .47555 Mdot
.572 .47582 Mdot
.572 .47595 Mdot
.572 .47602 Mdot
.572 .47626 Mdot
.572 .47641 Mdot
.572 .47642 Mdot
.572 .47647 Mdot
.572 .47648 Mdot
.572 .47669 Mdot
.572 .4767 Mdot
.572 .47676 Mdot
.572 .47682 Mdot
.572 .4769 Mdot
.572 .47715 Mdot
.572 .47747 Mdot
.572 .47765 Mdot
.572 .47774 Mdot
.572 .47785 Mdot
.572 .47801 Mdot
.572 .47808 Mdot
.572 .47815 Mdot
.572 .47819 Mdot
.572 .47822 Mdot
.572 .47822 Mdot
.572 .47825 Mdot
.572 .47826 Mdot
.572 .47871 Mdot
.572 .47877 Mdot
.572 .4789 Mdot
.572 .47901 Mdot
.572 .47925 Mdot
.572 .47927 Mdot
.572 .47943 Mdot
.572 .47969 Mdot
.572 .47994 Mdot
.572 .47995 Mdot
.572 .48007 Mdot
.572 .48064 Mdot
.572 .48129 Mdot
.572 .4813 Mdot
.572 .48151 Mdot
.572 .48164 Mdot
.572 .48165 Mdot
.572 .48186 Mdot
.572 .48228 Mdot
.572 .48248 Mdot
.572 .48262 Mdot
.572 .48264 Mdot
.572 .48271 Mdot
.572 .48292 Mdot
.572 .48307 Mdot
.572 .48311 Mdot
.572 .48428 Mdot
.572 .48443 Mdot
.572 .48472 Mdot
.572 .48478 Mdot
.572 .48561 Mdot
.572 .48564 Mdot
.572 .48616 Mdot
.572 .48648 Mdot
.572 .48733 Mdot
.572 .48764 Mdot
.572 .48787 Mdot
.572 .4893 Mdot
.572 .48952 Mdot
.572 .48979 Mdot
.572 .49006 Mdot
.572 .49021 Mdot
.572 .49035 Mdot
.572 .49036 Mdot
.572 .49096 Mdot
.572 .49168 Mdot
.572 .49227 Mdot
.572 .49272 Mdot
.572 .49359 Mdot
.572 .49437 Mdot
.572 .49445 Mdot
.572 .4945 Mdot
.572 .4946 Mdot
.572 .49466 Mdot
.572 .49482 Mdot
.572 .49494 Mdot
.572 .49512 Mdot
.572 .49519 Mdot
.572 .49534 Mdot
.572 .49548 Mdot
.572 .49578 Mdot
.572 .49684 Mdot
.572 .49721 Mdot
.572 .49724 Mdot
.572 .49727 Mdot
.572 .4977 Mdot
.572 .49775 Mdot
.572 .49789 Mdot
.572 .49826 Mdot
.572 .49827 Mdot
.572 .49865 Mdot
.572 .49874 Mdot
.572 .49894 Mdot
.572 .49924 Mdot
.572 .49945 Mdot
.572 .50099 Mdot
.572 .50112 Mdot
.572 .50122 Mdot
.572 .50207 Mdot
.572 .50228 Mdot
.572 .50236 Mdot
.572 .50272 Mdot
.572 .50277 Mdot
.572 .50295 Mdot
.572 .50344 Mdot
.572 .50363 Mdot
.572 .50367 Mdot
.572 .50367 Mdot
.572 .50437 Mdot
.572 .50502 Mdot
.572 .50502 Mdot
.572 .50514 Mdot
.572 .50515 Mdot
.572 .50527 Mdot
.572 .50595 Mdot
.572 .50651 Mdot
.572 .50681 Mdot
.572 .50724 Mdot
.572 .50807 Mdot
.572 .50814 Mdot
.572 .50836 Mdot
.572 .50851 Mdot
.572 .50871 Mdot
.572 .5093 Mdot
.572 .50961 Mdot
.572 .50969 Mdot
.572 .50984 Mdot
.572 .50992 Mdot
.572 .50993 Mdot
.572 .50994 Mdot
.572 .51014 Mdot
.572 .51023 Mdot
.572 .51097 Mdot
.572 .51107 Mdot
.572 .51113 Mdot
.572 .51134 Mdot
.572 .51136 Mdot
.572 .5131 Mdot
.572 .51322 Mdot
.572 .51355 Mdot
.572 .51388 Mdot
.572 .51436 Mdot
.572 .51541 Mdot
.572 .51542 Mdot
.572 .51634 Mdot
.572 .51639 Mdot
.572 .5166 Mdot
.572 .5177 Mdot
.572 .51817 Mdot
.572 .51827 Mdot
.572 .51837 Mdot
.572 .51875 Mdot
.572 .51876 Mdot
.572 .51902 Mdot
.572 .51954 Mdot
.572 .51959 Mdot
.572 .51962 Mdot
.572 .51986 Mdot
.572 .51998 Mdot
.572 .52026 Mdot
.572 .52036 Mdot
.572 .5207 Mdot
.572 .52078 Mdot
.572 .52105 Mdot
.572 .5211 Mdot
.572 .5216 Mdot
.572 .52163 Mdot
.572 .52183 Mdot
.572 .52196 Mdot
.572 .52238 Mdot
.572 .52256 Mdot
.572 .52257 Mdot
.572 .52265 Mdot
.572 .52268 Mdot
.572 .52272 Mdot
.572 .52277 Mdot
.572 .5228 Mdot
.572 .52317 Mdot
.572 .52318 Mdot
.572 .52328 Mdot
.572 .52329 Mdot
.572 .5234 Mdot
.572 .52348 Mdot
.572 .52354 Mdot
.572 .52361 Mdot
.572 .52398 Mdot
.572 .52403 Mdot
.572 .52421 Mdot
.572 .52427 Mdot
.572 .52435 Mdot
.572 .52439 Mdot
.572 .5245 Mdot
.572 .52455 Mdot
.572 .52486 Mdot
.572 .52486 Mdot
.572 .52503 Mdot
.572 .52521 Mdot
.572 .52549 Mdot
.572 .52556 Mdot
.572 .52561 Mdot
.572 .52573 Mdot
.572 .52581 Mdot
.572 .52586 Mdot
.572 .52587 Mdot
.572 .52591 Mdot
.572 .52592 Mdot
.572 .52669 Mdot
.572 .52679 Mdot
.572 .52702 Mdot
.572 .52702 Mdot
.572 .52721 Mdot
.572 .5276 Mdot
.572 .52764 Mdot
.572 .52773 Mdot
.572 .52778 Mdot
.572 .52791 Mdot
.572 .52822 Mdot
.572 .52835 Mdot
.572 .52855 Mdot
.572 .52875 Mdot
.572 .52878 Mdot
.572 .52891 Mdot
.572 .52895 Mdot
.572 .52898 Mdot
.572 .52989 Mdot
.572 .53094 Mdot
.572 .53096 Mdot
.572 .53113 Mdot
.572 .53128 Mdot
.572 .53148 Mdot
.572 .53151 Mdot
.572 .53183 Mdot
.572 .53247 Mdot
.572 .53278 Mdot
.572 .53293 Mdot
.572 .53298 Mdot
.572 .533 Mdot
.572 .53303 Mdot
.572 .53306 Mdot
.572 .53313 Mdot
.572 .53331 Mdot
.572 .53336 Mdot
.572 .53345 Mdot
.572 .53368 Mdot
.572 .53374 Mdot
.572 .53375 Mdot
.572 .53413 Mdot
.572 .53436 Mdot
.572 .53494 Mdot
.572 .53516 Mdot
.572 .53526 Mdot
.572 .53541 Mdot
.572 .53545 Mdot
.572 .53549 Mdot
.572 .53567 Mdot
.572 .53608 Mdot
.572 .53616 Mdot
.572 .53618 Mdot
.572 .53652 Mdot
.572 .53652 Mdot
.572 .5369 Mdot
.572 .53707 Mdot
.572 .53731 Mdot
.572 .53735 Mdot
.572 .53806 Mdot
.572 .53835 Mdot
.572 .53838 Mdot
.572 .53845 Mdot
.572 .53845 Mdot
.572 .53848 Mdot
.572 .53853 Mdot
.572 .53866 Mdot
.572 .53886 Mdot
.572 .53893 Mdot
.572 .53905 Mdot
.572 .53949 Mdot
.572 .53959 Mdot
.572 .53977 Mdot
.572 .53999 Mdot
.572 .54003 Mdot
.572 .54003 Mdot
.572 .54027 Mdot
.572 .54049 Mdot
.572 .54056 Mdot
.572 .54072 Mdot
.572 .54079 Mdot
.572 .5409 Mdot
.572 .54099 Mdot
.572 .54125 Mdot
.572 .54132 Mdot
.572 .54185 Mdot
.572 .54194 Mdot
.572 .542 Mdot
.572 .54203 Mdot
.572 .54214 Mdot
.572 .54225 Mdot
.572 .54229 Mdot
.572 .54231 Mdot
.572 .54244 Mdot
.572 .54245 Mdot
.572 .54256 Mdot
.572 .54287 Mdot
.572 .54296 Mdot
.572 .543 Mdot
.572 .54304 Mdot
.572 .54306 Mdot
.572 .54311 Mdot
.572 .54314 Mdot
.572 .54319 Mdot
.572 .54321 Mdot
.572 .54325 Mdot
.572 .54327 Mdot
.572 .54349 Mdot
.572 .54387 Mdot
.572 .54403 Mdot
.572 .54419 Mdot
.572 .54443 Mdot
.572 .54448 Mdot
.572 .54462 Mdot
.572 .54507 Mdot
.572 .54513 Mdot
.572 .54521 Mdot
.572 .54544 Mdot
.572 .54552 Mdot
.572 .54566 Mdot
.572 .5459 Mdot
.572 .54602 Mdot
.572 .54632 Mdot
.572 .54644 Mdot
.572 .54648 Mdot
.572 .54669 Mdot
.572 .54673 Mdot
.572 .54678 Mdot
.572 .54718 Mdot
.572 .54725 Mdot
.572 .54729 Mdot
.572 .5473 Mdot
.572 .54738 Mdot
.572 .54743 Mdot
.572 .54754 Mdot
.572 .54755 Mdot
.572 .54757 Mdot
.572 .54767 Mdot
.572 .54782 Mdot
.572 .54788 Mdot
.572 .54791 Mdot
.572 .54799 Mdot
.572 .548 Mdot
.572 .54809 Mdot
.572 .54811 Mdot
.572 .54835 Mdot
.572 .54851 Mdot
.572 .54914 Mdot
.572 .5494 Mdot
.572 .5494 Mdot
.572 .54943 Mdot
.572 .54944 Mdot
.572 .54956 Mdot
.572 .5496 Mdot
.572 .54974 Mdot
.572 .54977 Mdot
.572 .54986 Mdot
.572 .5501 Mdot
.572 .5501 Mdot
.572 .55024 Mdot
.572 .55025 Mdot
.572 .55034 Mdot
.572 .55039 Mdot
.572 .55051 Mdot
.572 .55068 Mdot
.572 .55079 Mdot
.572 .5509 Mdot
.572 .55116 Mdot
.572 .55133 Mdot
.572 .5515 Mdot
.572 .55156 Mdot
.572 .55156 Mdot
.572 .55161 Mdot
.572 .55165 Mdot
.572 .55199 Mdot
.572 .55206 Mdot
.572 .5521 Mdot
.572 .55222 Mdot
.572 .55223 Mdot
.572 .55225 Mdot
.572 .55225 Mdot
.572 .55229 Mdot
.572 .55232 Mdot
.572 .55234 Mdot
.572 .55237 Mdot
.572 .55243 Mdot
.572 .55248 Mdot
.572 .55249 Mdot
.572 .55249 Mdot
.572 .55257 Mdot
.572 .55259 Mdot
.572 .55263 Mdot
.572 .55264 Mdot
.572 .55264 Mdot
.572 .55265 Mdot
.572 .55266 Mdot
.572 .55269 Mdot
.572 .5527 Mdot
.572 .55276 Mdot
.572 .55277 Mdot
.572 .55277 Mdot
.572 .55279 Mdot
.572 .55279 Mdot
.572 .5528 Mdot
.572 .55284 Mdot
.572 .55286 Mdot
.572 .55288 Mdot
.572 .55288 Mdot
.572 .5529 Mdot
.572 .5529 Mdot
.572 .55292 Mdot
.572 .55293 Mdot
.572 .55293 Mdot
.574 .18259 Mdot
.574 .18259 Mdot
.574 .18259 Mdot
.574 .1826 Mdot
.574 .18264 Mdot
.574 .18265 Mdot
.574 .18267 Mdot
.574 .18269 Mdot
.574 .18271 Mdot
.574 .18272 Mdot
.574 .18276 Mdot
.574 .18279 Mdot
.574 .18284 Mdot
.574 .18285 Mdot
.574 .18285 Mdot
.574 .18303 Mdot
.574 .18303 Mdot
.574 .18307 Mdot
.574 .18316 Mdot
.574 .18321 Mdot
.574 .18328 Mdot
.574 .18343 Mdot
.574 .18349 Mdot
.574 .18349 Mdot
.574 .18361 Mdot
.574 .18371 Mdot
.574 .18387 Mdot
.574 .18439 Mdot
.574 .18452 Mdot
.574 .18482 Mdot
.574 .18486 Mdot
.574 .18489 Mdot
.574 .18499 Mdot
.574 .18512 Mdot
.574 .18536 Mdot
.574 .18556 Mdot
.574 .1858 Mdot
.574 .18627 Mdot
.574 .1863 Mdot
.574 .18659 Mdot
.574 .18669 Mdot
.574 .18688 Mdot
.574 .18693 Mdot
.574 .18695 Mdot
.574 .18712 Mdot
.574 .18719 Mdot
.574 .18737 Mdot
.574 .18738 Mdot
.574 .18754 Mdot
.574 .18777 Mdot
.574 .18786 Mdot
.574 .18799 Mdot
.574 .18819 Mdot
.574 .18843 Mdot
.574 .18908 Mdot
.574 .18925 Mdot
.574 .18943 Mdot
.574 .18973 Mdot
.574 .18989 Mdot
.574 .19013 Mdot
.574 .19029 Mdot
.574 .19051 Mdot
.574 .19074 Mdot
.574 .19088 Mdot
.574 .19089 Mdot
.574 .19091 Mdot
.574 .19105 Mdot
.574 .19145 Mdot
.574 .19183 Mdot
.574 .19189 Mdot
.574 .19192 Mdot
.574 .19204 Mdot
.574 .19228 Mdot
.574 .19235 Mdot
.574 .19256 Mdot
.574 .19257 Mdot
.574 .19281 Mdot
.574 .193 Mdot
.574 .19309 Mdot
.574 .19324 Mdot
.574 .19388 Mdot
.574 .19421 Mdot
.574 .19431 Mdot
.574 .19437 Mdot
.574 .19441 Mdot
.574 .19447 Mdot
.574 .1949 Mdot
.574 .19511 Mdot
.574 .19542 Mdot
.574 .19546 Mdot
.574 .1955 Mdot
.574 .19727 Mdot
.574 .19896 Mdot
.574 .19923 Mdot
.574 .19925 Mdot
.574 .19952 Mdot
.574 .19975 Mdot
.574 .20012 Mdot
.574 .20012 Mdot
.574 .20174 Mdot
.574 .20183 Mdot
.574 .20194 Mdot
.574 .20204 Mdot
.574 .20218 Mdot
.574 .20322 Mdot
.574 .20397 Mdot
.574 .20399 Mdot
.574 .20439 Mdot
.574 .20466 Mdot
.574 .20475 Mdot
.574 .20495 Mdot
.574 .20514 Mdot
.574 .20529 Mdot
.574 .20613 Mdot
.574 .20615 Mdot
.574 .20643 Mdot
.574 .20724 Mdot
.574 .2073 Mdot
.574 .20778 Mdot
.574 .20865 Mdot
.574 .21034 Mdot
.574 .21037 Mdot
.574 .21045 Mdot
.574 .21057 Mdot
.574 .21116 Mdot
.574 .21267 Mdot
.574 .21345 Mdot
.574 .21353 Mdot
.574 .21476 Mdot
.574 .21549 Mdot
.574 .21576 Mdot
.574 .21645 Mdot
.574 .21659 Mdot
.574 .21677 Mdot
.574 .21682 Mdot
.574 .21707 Mdot
.574 .21878 Mdot
.574 .22011 Mdot
.574 .22073 Mdot
.574 .22093 Mdot
.574 .22118 Mdot
.574 .22202 Mdot
.574 .22214 Mdot
.574 .22272 Mdot
.574 .22316 Mdot
.574 .22401 Mdot
.574 .22443 Mdot
.574 .22487 Mdot
.574 .22567 Mdot
.574 .22583 Mdot
.574 .22618 Mdot
.574 .22691 Mdot
.574 .22786 Mdot
.574 .22806 Mdot
.574 .22866 Mdot
.574 .22886 Mdot
.574 .22892 Mdot
.574 .22931 Mdot
.574 .23025 Mdot
.574 .2307 Mdot
.574 .23115 Mdot
.574 .23151 Mdot
.574 .2328 Mdot
.574 .23285 Mdot
.574 .23287 Mdot
.574 .23474 Mdot
.574 .23495 Mdot
.574 .23517 Mdot
.574 .23576 Mdot
.574 .23579 Mdot
.574 .23692 Mdot
.574 .23735 Mdot
.574 .23761 Mdot
.574 .23763 Mdot
.574 .23778 Mdot
.574 .24048 Mdot
.574 .24163 Mdot
.574 .24223 Mdot
.574 .24268 Mdot
.574 .24351 Mdot
.574 .24367 Mdot
.574 .24407 Mdot
.574 .24473 Mdot
.574 .24525 Mdot
.574 .24531 Mdot
.574 .24591 Mdot
.574 .2466 Mdot
.574 .25158 Mdot
.574 .25247 Mdot
.574 .25394 Mdot
.574 .25394 Mdot
.574 .25408 Mdot
.574 .2549 Mdot
.574 .25492 Mdot
.574 .25523 Mdot
.574 .25535 Mdot
.574 .25648 Mdot
.574 .25721 Mdot
.574 .2579 Mdot
.574 .25865 Mdot
.574 .25879 Mdot
.574 .25913 Mdot
.574 .26041 Mdot
.574 .2605 Mdot
.574 .26097 Mdot
.574 .26198 Mdot
.574 .26224 Mdot
.574 .26317 Mdot
.574 .26333 Mdot
.574 .26594 Mdot
.574 .26606 Mdot
.574 .26808 Mdot
.574 .27027 Mdot
.574 .27029 Mdot
.574 .27216 Mdot
.574 .27252 Mdot
.574 .27256 Mdot
.574 .27318 Mdot
.574 .27341 Mdot
.574 .27418 Mdot
.574 .27433 Mdot
.574 .27572 Mdot
.574 .27657 Mdot
.574 .27687 Mdot
.574 .27695 Mdot
.574 .27835 Mdot
.574 .27835 Mdot
.574 .27888 Mdot
.574 .27913 Mdot
.574 .27915 Mdot
.574 .27939 Mdot
.574 .28274 Mdot
.574 .28278 Mdot
.574 .28283 Mdot
.574 .28388 Mdot
.574 .28393 Mdot
.574 .28399 Mdot
.574 .2841 Mdot
.574 .28446 Mdot
.574 .28534 Mdot
.574 .28544 Mdot
.574 .28565 Mdot
.574 .28594 Mdot
.574 .28595 Mdot
.574 .28619 Mdot
.574 .28627 Mdot
.574 .2867 Mdot
.574 .28681 Mdot
.574 .28728 Mdot
.574 .28778 Mdot
.574 .28796 Mdot
.574 .28798 Mdot
.574 .28799 Mdot
.574 .28817 Mdot
.574 .28847 Mdot
.574 .2893 Mdot
.574 .28993 Mdot
.574 .29042 Mdot
.574 .29278 Mdot
.574 .29305 Mdot
.574 .29349 Mdot
.574 .29378 Mdot
.574 .29382 Mdot
.574 .29391 Mdot
.574 .29424 Mdot
.574 .29443 Mdot
.574 .29497 Mdot
.574 .29595 Mdot
.574 .29645 Mdot
.574 .29742 Mdot
.574 .29888 Mdot
.574 .30076 Mdot
.574 .30166 Mdot
.574 .30209 Mdot
.574 .3021 Mdot
.574 .30328 Mdot
.574 .30394 Mdot
.574 .30416 Mdot
.574 .3053 Mdot
.574 .30532 Mdot
.574 .30642 Mdot
.574 .30716 Mdot
.574 .30724 Mdot
.574 .30865 Mdot
.574 .30879 Mdot
.574 .30932 Mdot
.574 .3098 Mdot
.574 .3112 Mdot
.574 .31134 Mdot
.574 .31167 Mdot
.574 .31207 Mdot
.574 .31232 Mdot
.574 .31275 Mdot
.574 .31387 Mdot
.574 .31454 Mdot
.574 .31507 Mdot
.574 .3157 Mdot
.574 .31675 Mdot
.574 .31879 Mdot
.574 .3199 Mdot
.574 .32 Mdot
.574 .32009 Mdot
.574 .32032 Mdot
.574 .32116 Mdot
.574 .323 Mdot
.574 .32466 Mdot
.574 .32497 Mdot
.574 .32563 Mdot
.574 .32576 Mdot
.574 .32597 Mdot
.574 .32628 Mdot
.574 .32666 Mdot
.574 .32785 Mdot
.574 .32853 Mdot
.574 .32906 Mdot
.574 .32928 Mdot
.574 .33129 Mdot
.574 .33147 Mdot
.574 .33287 Mdot
.574 .33422 Mdot
.574 .33467 Mdot
.574 .33489 Mdot
.574 .33705 Mdot
.574 .33936 Mdot
.574 .34125 Mdot
.574 .34134 Mdot
.574 .34293 Mdot
.574 .34294 Mdot
.574 .34326 Mdot
.574 .34348 Mdot
.574 .34355 Mdot
.574 .34397 Mdot
.574 .34465 Mdot
.574 .34651 Mdot
.574 .34781 Mdot
.574 .3479 Mdot
.574 .34832 Mdot
.574 .34937 Mdot
.574 .3499 Mdot
.574 .35077 Mdot
.574 .35125 Mdot
.574 .35144 Mdot
.574 .35188 Mdot
.574 .35212 Mdot
.574 .35228 Mdot
.574 .35337 Mdot
.574 .3542 Mdot
.574 .35458 Mdot
.574 .35536 Mdot
.574 .35544 Mdot
.574 .35655 Mdot
.574 .35681 Mdot
.574 .35783 Mdot
.574 .35825 Mdot
.574 .35879 Mdot
.574 .35935 Mdot
.574 .35961 Mdot
.574 .36038 Mdot
.574 .36063 Mdot
.574 .36153 Mdot
.574 .36157 Mdot
.574 .36257 Mdot
.574 .36373 Mdot
.574 .36418 Mdot
.574 .36615 Mdot
.574 .36668 Mdot
.574 .3671 Mdot
.574 .36717 Mdot
.574 .36738 Mdot
.574 .3677 Mdot
.574 .36796 Mdot
.574 .36799 Mdot
.574 .36828 Mdot
.574 .36862 Mdot
.574 .37102 Mdot
.574 .37213 Mdot
.574 .37258 Mdot
.574 .37258 Mdot
.574 .37364 Mdot
.574 .3743 Mdot
.574 .3751 Mdot
.574 .37514 Mdot
.574 .37592 Mdot
.574 .37633 Mdot
.574 .37761 Mdot
.574 .37849 Mdot
.574 .37944 Mdot
.574 .37945 Mdot
.574 .38078 Mdot
.574 .38117 Mdot
.574 .38176 Mdot
.574 .38212 Mdot
.574 .38286 Mdot
.574 .38319 Mdot
.574 .38319 Mdot
.574 .38467 Mdot
.574 .38469 Mdot
.574 .38471 Mdot
.574 .38514 Mdot
.574 .38538 Mdot
.574 .38574 Mdot
.574 .38578 Mdot
.574 .38586 Mdot
.574 .38598 Mdot
.574 .38598 Mdot
.574 .38608 Mdot
.574 .38611 Mdot
.574 .38629 Mdot
.574 .38633 Mdot
.574 .38672 Mdot
.574 .3868 Mdot
.574 .3868 Mdot
.574 .38681 Mdot
.574 .387 Mdot
.574 .38759 Mdot
.574 .38883 Mdot
.574 .389 Mdot
.574 .38913 Mdot
.574 .3893 Mdot
.574 .38959 Mdot
.574 .39055 Mdot
.574 .39237 Mdot
.574 .39282 Mdot
.574 .39308 Mdot
.574 .3936 Mdot
.574 .39431 Mdot
.574 .39434 Mdot
.574 .39493 Mdot
.574 .39513 Mdot
.574 .39584 Mdot
.574 .39617 Mdot
.574 .39626 Mdot
.574 .39643 Mdot
.574 .39753 Mdot
.574 .39868 Mdot
.574 .3991 Mdot
.574 .39913 Mdot
.574 .39917 Mdot
.574 .39956 Mdot
.574 .40024 Mdot
.574 .40085 Mdot
.574 .40133 Mdot
.574 .40202 Mdot
.574 .40246 Mdot
.574 .40334 Mdot
.574 .40385 Mdot
.574 .40434 Mdot
.574 .40619 Mdot
.574 .4069 Mdot
.574 .40747 Mdot
.574 .40784 Mdot
.574 .40808 Mdot
.574 .40874 Mdot
.574 .40921 Mdot
.574 .40924 Mdot
.574 .40976 Mdot
.574 .40995 Mdot
.574 .41043 Mdot
.574 .41049 Mdot
.574 .41065 Mdot
.574 .41117 Mdot
.574 .41147 Mdot
.574 .4123 Mdot
.574 .41239 Mdot
.574 .41373 Mdot
.574 .41441 Mdot
.574 .41497 Mdot
.574 .41566 Mdot
.574 .41602 Mdot
.574 .41631 Mdot
.574 .41641 Mdot
.574 .41653 Mdot
.574 .41736 Mdot
.574 .41775 Mdot
.574 .41922 Mdot
.574 .41966 Mdot
.574 .41997 Mdot
.574 .4203 Mdot
.574 .4203 Mdot
.574 .42047 Mdot
.574 .4209 Mdot
.574 .4211 Mdot
.574 .42123 Mdot
.574 .42149 Mdot
.574 .4216 Mdot
.574 .4216 Mdot
.574 .42212 Mdot
.574 .42212 Mdot
.574 .42213 Mdot
.574 .42228 Mdot
.574 .42236 Mdot
.574 .42249 Mdot
.574 .4225 Mdot
.574 .42257 Mdot
.574 .4226 Mdot
.574 .42268 Mdot
.574 .42269 Mdot
.574 .42283 Mdot
.574 .42285 Mdot
.574 .42286 Mdot
.574 .42286 Mdot
.574 .4538 Mdot
.574 .4538 Mdot
.574 .4538 Mdot
.574 .45381 Mdot
.574 .45389 Mdot
.574 .4539 Mdot
.574 .45394 Mdot
.574 .45396 Mdot
.574 .454 Mdot
.574 .454 Mdot
.574 .45407 Mdot
.574 .45412 Mdot
.574 .4542 Mdot
.574 .45421 Mdot
.574 .45421 Mdot
.574 .45449 Mdot
.574 .45449 Mdot
.574 .45456 Mdot
.574 .4547 Mdot
.574 .45477 Mdot
.574 .45488 Mdot
.574 .45512 Mdot
.574 .45521 Mdot
.574 .45521 Mdot
.574 .45539 Mdot
.574 .45556 Mdot
.574 .45581 Mdot
.574 .45661 Mdot
.574 .45682 Mdot
.574 .45727 Mdot
.574 .45734 Mdot
.574 .45739 Mdot
.574 .45755 Mdot
.574 .45774 Mdot
.574 .45811 Mdot
.574 .45842 Mdot
.574 .45878 Mdot
.574 .4595 Mdot
.574 .45955 Mdot
.574 .45999 Mdot
.574 .46015 Mdot
.574 .46043 Mdot
.574 .46051 Mdot
.574 .46055 Mdot
.574 .4608 Mdot
.574 .4609 Mdot
.574 .46118 Mdot
.574 .46119 Mdot
.574 .46144 Mdot
.574 .46179 Mdot
.574 .46191 Mdot
.574 .46211 Mdot
.574 .46241 Mdot
.574 .46278 Mdot
.574 .46374 Mdot
.574 .464 Mdot
.574 .46426 Mdot
.574 .46472 Mdot
.574 .46494 Mdot
.574 .4653 Mdot
.574 .46555 Mdot
.574 .46586 Mdot
.574 .46621 Mdot
.574 .46641 Mdot
.574 .46643 Mdot
.574 .46645 Mdot
.574 .46666 Mdot
.574 .46724 Mdot
.574 .4678 Mdot
.574 .46789 Mdot
.574 .46793 Mdot
.574 .4681 Mdot
.574 .46846 Mdot
.574 .46856 Mdot
.574 .46886 Mdot
.574 .46887 Mdot
.574 .46923 Mdot
.574 .46949 Mdot
.574 .46962 Mdot
.574 .46985 Mdot
.574 .47075 Mdot
.574 .47123 Mdot
.574 .47137 Mdot
.574 .47146 Mdot
.574 .47152 Mdot
.574 .47161 Mdot
.574 .47222 Mdot
.574 .47251 Mdot
.574 .4726 Mdot
.574 .47261 Mdot
.574 .47261 Mdot
.574 .47264 Mdot
.574 .47284 Mdot
.574 .47286 Mdot
.574 .47294 Mdot
.574 .47296 Mdot
.574 .47301 Mdot
.574 .47301 Mdot
.574 .47307 Mdot
.574 .47311 Mdot
.574 .47313 Mdot
.574 .4733 Mdot
.574 .47342 Mdot
.574 .47363 Mdot
.574 .47364 Mdot
.574 .47365 Mdot
.574 .47437 Mdot
.574 .47437 Mdot
.574 .47453 Mdot
.574 .47489 Mdot
.574 .47507 Mdot
.574 .47535 Mdot
.574 .47554 Mdot
.574 .47618 Mdot
.574 .47618 Mdot
.574 .47664 Mdot
.574 .47706 Mdot
.574 .47767 Mdot
.574 .47787 Mdot
.574 .47824 Mdot
.574 .47826 Mdot
.574 .47864 Mdot
.574 .47895 Mdot
.574 .47945 Mdot
.574 .47946 Mdot
.574 .47967 Mdot
.574 .48019 Mdot
.574 .48131 Mdot
.574 .48147 Mdot
.574 .48161 Mdot
.574 .48162 Mdot
.574 .48174 Mdot
.574 .48189 Mdot
.574 .48199 Mdot
.574 .48202 Mdot
.574 .48221 Mdot
.574 .48246 Mdot
.574 .48337 Mdot
.574 .48358 Mdot
.574 .48411 Mdot
.574 .48457 Mdot
.574 .48459 Mdot
.574 .485 Mdot
.574 .48512 Mdot
.574 .48547 Mdot
.574 .48559 Mdot
.574 .48584 Mdot
.574 .48609 Mdot
.574 .48628 Mdot
.574 .48674 Mdot
.574 .48686 Mdot
.574 .48736 Mdot
.574 .48739 Mdot
.574 .48775 Mdot
.574 .48792 Mdot
.574 .48829 Mdot
.574 .48878 Mdot
.574 .48885 Mdot
.574 .48896 Mdot
.574 .48916 Mdot
.574 .48924 Mdot
.574 .48945 Mdot
.574 .48984 Mdot
.574 .49008 Mdot
.574 .49054 Mdot
.574 .49073 Mdot
.574 .49077 Mdot
.574 .49134 Mdot
.574 .49216 Mdot
.574 .49246 Mdot
.574 .49264 Mdot
.574 .49267 Mdot
.574 .49277 Mdot
.574 .49291 Mdot
.574 .49291 Mdot
.574 .49361 Mdot
.574 .49365 Mdot
.574 .49447 Mdot
.574 .49547 Mdot
.574 .4964 Mdot
.574 .49649 Mdot
.574 .49669 Mdot
.574 .49726 Mdot
.574 .49786 Mdot
.574 .49794 Mdot
.574 .49879 Mdot
.574 .49888 Mdot
.574 .49911 Mdot
.574 .49939 Mdot
.574 .4999 Mdot
.574 .50006 Mdot
.574 .50019 Mdot
.574 .50028 Mdot
.574 .50033 Mdot
.574 .50061 Mdot
.574 .50074 Mdot
.574 .50143 Mdot
.574 .5022 Mdot
.574 .50255 Mdot
.574 .50265 Mdot
.574 .50268 Mdot
.574 .50273 Mdot
.574 .50319 Mdot
.574 .50403 Mdot
.574 .50446 Mdot
.574 .50472 Mdot
.574 .50494 Mdot
.574 .50521 Mdot
.574 .50567 Mdot
.574 .50585 Mdot
.574 .50595 Mdot
.574 .50611 Mdot
.574 .50625 Mdot
.574 .5063 Mdot
.574 .50688 Mdot
.574 .50707 Mdot
.574 .50729 Mdot
.574 .50734 Mdot
.574 .50791 Mdot
.574 .50794 Mdot
.574 .50824 Mdot
.574 .50869 Mdot
.574 .5087 Mdot
.574 .50915 Mdot
.574 .50924 Mdot
.574 .50951 Mdot
.574 .50998 Mdot
.574 .50998 Mdot
.574 .51016 Mdot
.574 .51052 Mdot
.574 .51126 Mdot
.574 .51184 Mdot
.574 .51223 Mdot
.574 .51242 Mdot
.574 .51281 Mdot
.574 .51303 Mdot
.574 .5131 Mdot
.574 .51323 Mdot
.574 .51327 Mdot
.574 .51328 Mdot
.574 .5134 Mdot
.574 .51357 Mdot
.574 .51367 Mdot
.574 .5146 Mdot
.574 .51479 Mdot
.574 .51504 Mdot
.574 .51536 Mdot
.574 .51548 Mdot
.574 .51555 Mdot
.574 .51555 Mdot
.574 .51556 Mdot
.574 .51563 Mdot
.574 .51583 Mdot
.574 .51601 Mdot
.574 .51605 Mdot
.574 .51622 Mdot
.574 .51625 Mdot
.574 .51634 Mdot
.574 .51635 Mdot
.574 .51646 Mdot
.574 .51654 Mdot
.574 .51658 Mdot
.574 .51692 Mdot
.574 .51706 Mdot
.574 .5171 Mdot
.574 .51713 Mdot
.574 .51714 Mdot
.574 .51755 Mdot
.574 .51757 Mdot
.574 .51759 Mdot
.574 .51887 Mdot
.574 .51897 Mdot
.574 .51897 Mdot
.574 .51907 Mdot
.574 .51927 Mdot
.574 .51927 Mdot
.574 .5198 Mdot
.574 .51983 Mdot
.574 .51995 Mdot
.574 .52027 Mdot
.574 .5208 Mdot
.574 .52086 Mdot
.574 .52115 Mdot
.574 .52124 Mdot
.574 .52147 Mdot
.574 .52149 Mdot
.574 .52162 Mdot
.574 .52233 Mdot
.574 .52234 Mdot
.574 .52316 Mdot
.574 .52392 Mdot
.574 .52396 Mdot
.574 .52494 Mdot
.574 .525 Mdot
.574 .52534 Mdot
.574 .52544 Mdot
.574 .52582 Mdot
.574 .52599 Mdot
.574 .52603 Mdot
.574 .5265 Mdot
.574 .52662 Mdot
.574 .52668 Mdot
.574 .52695 Mdot
.574 .52721 Mdot
.574 .52748 Mdot
.574 .52789 Mdot
.574 .52794 Mdot
.574 .52805 Mdot
.574 .52806 Mdot
.574 .52841 Mdot
.574 .52841 Mdot
.574 .52895 Mdot
.574 .52927 Mdot
.574 .53108 Mdot
.574 .53133 Mdot
.574 .53155 Mdot
.574 .53157 Mdot
.574 .53176 Mdot
.574 .532 Mdot
.574 .53214 Mdot
.574 .5322 Mdot
.574 .5325 Mdot
.574 .53266 Mdot
.574 .53288 Mdot
.574 .53329 Mdot
.574 .53425 Mdot
.574 .53431 Mdot
.574 .53432 Mdot
.574 .53441 Mdot
.574 .53456 Mdot
.574 .53497 Mdot
.574 .53498 Mdot
.574 .53518 Mdot
.574 .53526 Mdot
.574 .53534 Mdot
.574 .536 Mdot
.574 .53601 Mdot
.574 .53603 Mdot
.574 .53648 Mdot
.574 .53661 Mdot
.574 .53677 Mdot
.574 .53693 Mdot
.574 .53726 Mdot
.574 .5374 Mdot
.574 .53742 Mdot
.574 .53749 Mdot
.574 .5377 Mdot
.574 .53777 Mdot
.574 .5381 Mdot
.574 .53836 Mdot
.574 .53848 Mdot
.574 .53854 Mdot
.574 .53882 Mdot
.574 .53897 Mdot
.574 .53912 Mdot
.574 .53942 Mdot
.574 .53957 Mdot
.574 .53977 Mdot
.574 .53982 Mdot
.574 .54011 Mdot
.574 .54019 Mdot
.574 .54026 Mdot
.574 .54048 Mdot
.574 .54094 Mdot
.574 .54153 Mdot
.574 .54162 Mdot
.574 .54163 Mdot
.574 .5417 Mdot
.574 .54175 Mdot
.574 .54198 Mdot
.574 .54208 Mdot
.574 .54233 Mdot
.574 .54275 Mdot
.574 .54278 Mdot
.574 .54305 Mdot
.574 .54357 Mdot
.574 .54377 Mdot
.574 .54381 Mdot
.574 .54384 Mdot
.574 .54385 Mdot
.574 .54443 Mdot
.574 .54473 Mdot
.574 .54489 Mdot
.574 .54491 Mdot
.574 .54518 Mdot
.574 .54528 Mdot
.574 .54529 Mdot
.574 .54557 Mdot
.574 .54562 Mdot
.574 .54569 Mdot
.574 .54576 Mdot
.574 .54579 Mdot
.574 .54588 Mdot
.574 .54602 Mdot
.574 .54602 Mdot
.574 .54628 Mdot
.574 .54663 Mdot
.574 .54668 Mdot
.574 .54671 Mdot
.574 .54675 Mdot
.574 .54678 Mdot
.574 .54732 Mdot
.574 .54732 Mdot
.574 .54745 Mdot
.574 .54752 Mdot
.574 .54762 Mdot
.574 .54762 Mdot
.574 .54771 Mdot
.574 .54828 Mdot
.574 .54888 Mdot
.574 .54889 Mdot
.574 .54891 Mdot
.574 .54901 Mdot
.574 .54908 Mdot
.574 .54922 Mdot
.574 .54924 Mdot
.574 .54926 Mdot
.574 .54928 Mdot
.574 .54931 Mdot
.574 .54942 Mdot
.574 .54963 Mdot
.574 .54969 Mdot
.574 .54972 Mdot
.574 .54978 Mdot
.574 .54986 Mdot
.574 .54986 Mdot
.574 .54993 Mdot
.574 .54995 Mdot
.574 .55004 Mdot
.574 .55007 Mdot
.574 .55009 Mdot
.574 .5501 Mdot
.574 .55023 Mdot
.574 .55037 Mdot
.574 .55041 Mdot
.574 .55042 Mdot
.574 .55042 Mdot
.574 .55047 Mdot
.574 .55055 Mdot
.574 .55062 Mdot
.574 .55067 Mdot
.574 .55075 Mdot
.574 .5508 Mdot
.574 .55091 Mdot
.574 .55096 Mdot
.574 .55102 Mdot
.574 .55124 Mdot
.574 .55132 Mdot
.574 .55138 Mdot
.574 .55143 Mdot
.574 .55145 Mdot
.574 .55153 Mdot
.574 .55159 Mdot
.574 .55159 Mdot
.574 .55165 Mdot
.574 .55167 Mdot
.574 .55173 Mdot
.574 .55173 Mdot
.574 .55175 Mdot
.574 .55181 Mdot
.574 .55185 Mdot
.574 .55194 Mdot
.574 .55195 Mdot
.574 .55211 Mdot
.574 .55219 Mdot
.574 .55225 Mdot
.574 .55233 Mdot
.574 .55238 Mdot
.574 .55241 Mdot
.574 .55242 Mdot
.574 .55243 Mdot
.574 .55253 Mdot
.574 .55258 Mdot
.574 .55275 Mdot
.574 .5528 Mdot
.574 .55283 Mdot
.574 .55287 Mdot
.574 .55287 Mdot
.574 .55289 Mdot
.574 .55294 Mdot
.574 .55297 Mdot
.574 .55298 Mdot
.574 .55301 Mdot
.574 .55302 Mdot
.574 .55302 Mdot
.574 .55308 Mdot
.574 .55308 Mdot
.574 .55308 Mdot
.574 .5531 Mdot
.574 .55311 Mdot
.574 .55313 Mdot
.574 .55313 Mdot
.574 .55314 Mdot
.574 .55314 Mdot
.574 .55315 Mdot
.574 .55315 Mdot
.574 .55317 Mdot
.574 .55317 Mdot
.574 .55317 Mdot
.574 .55317 Mdot
.576 .18194 Mdot
.576 .18194 Mdot
.576 .18195 Mdot
.576 .18195 Mdot
.576 .18197 Mdot
.576 .18198 Mdot
.576 .18204 Mdot
.576 .1821 Mdot
.576 .18231 Mdot
.576 .18231 Mdot
.576 .18239 Mdot
.576 .18249 Mdot
.576 .18254 Mdot
.576 .18277 Mdot
.576 .18278 Mdot
.576 .18279 Mdot
.576 .18279 Mdot
.576 .1828 Mdot
.576 .1831 Mdot
.576 .18323 Mdot
.576 .18332 Mdot
.576 .18335 Mdot
.576 .18362 Mdot
.576 .18377 Mdot
.576 .18383 Mdot
.576 .18384 Mdot
.576 .18389 Mdot
.576 .18392 Mdot
.576 .18392 Mdot
.576 .18405 Mdot
.576 .18406 Mdot
.576 .18409 Mdot
.576 .1841 Mdot
.576 .18412 Mdot
.576 .18413 Mdot
.576 .18468 Mdot
.576 .1847 Mdot
.576 .18479 Mdot
.576 .1849 Mdot
.576 .18497 Mdot
.576 .18515 Mdot
.576 .18527 Mdot
.576 .18544 Mdot
.576 .18547 Mdot
.576 .18555 Mdot
.576 .18576 Mdot
.576 .18642 Mdot
.576 .18685 Mdot
.576 .18702 Mdot
.576 .18765 Mdot
.576 .18774 Mdot
.576 .18775 Mdot
.576 .18836 Mdot
.576 .18868 Mdot
.576 .18899 Mdot
.576 .18902 Mdot
.576 .18936 Mdot
.576 .19007 Mdot
.576 .19035 Mdot
.576 .19042 Mdot
.576 .19043 Mdot
.576 .1906 Mdot
.576 .1908 Mdot
.576 .19108 Mdot
.576 .19131 Mdot
.576 .19155 Mdot
.576 .19307 Mdot
.576 .19334 Mdot
.576 .19344 Mdot
.576 .1935 Mdot
.576 .19362 Mdot
.576 .1938 Mdot
.576 .19386 Mdot
.576 .19388 Mdot
.576 .1948 Mdot
.576 .19505 Mdot
.576 .19556 Mdot
.576 .19579 Mdot
.576 .19601 Mdot
.576 .19605 Mdot
.576 .19607 Mdot
.576 .19611 Mdot
.576 .19628 Mdot
.576 .19664 Mdot
.576 .19672 Mdot
.576 .19677 Mdot
.576 .19678 Mdot
.576 .19689 Mdot
.576 .19704 Mdot
.576 .19719 Mdot
.576 .19733 Mdot
.576 .19773 Mdot
.576 .19821 Mdot
.576 .19862 Mdot
.576 .19883 Mdot
.576 .1997 Mdot
.576 .2001 Mdot
.576 .20065 Mdot
.576 .20214 Mdot
.576 .20228 Mdot
.576 .20255 Mdot
.576 .2027 Mdot
.576 .20278 Mdot
.576 .20357 Mdot
.576 .20467 Mdot
.576 .20473 Mdot
.576 .20492 Mdot
.576 .20557 Mdot
.576 .20573 Mdot
.576 .20575 Mdot
.576 .20617 Mdot
.576 .20628 Mdot
.576 .20747 Mdot
.576 .20809 Mdot
.576 .20814 Mdot
.576 .20832 Mdot
.576 .20915 Mdot
.576 .20916 Mdot
.576 .21076 Mdot
.576 .21125 Mdot
.576 .21142 Mdot
.576 .21155 Mdot
.576 .21218 Mdot
.576 .21236 Mdot
.576 .21274 Mdot
.576 .21356 Mdot
.576 .21492 Mdot
.576 .215 Mdot
.576 .21516 Mdot
.576 .21601 Mdot
.576 .21687 Mdot
.576 .21891 Mdot
.576 .22034 Mdot
.576 .22035 Mdot
.576 .22038 Mdot
.576 .22085 Mdot
.576 .22121 Mdot
.576 .22122 Mdot
.576 .22178 Mdot
.576 .22237 Mdot
.576 .22263 Mdot
.576 .22285 Mdot
.576 .22295 Mdot
.576 .22315 Mdot
.576 .22335 Mdot
.576 .22374 Mdot
.576 .22501 Mdot
.576 .22585 Mdot
.576 .22603 Mdot
.576 .22679 Mdot
.576 .22693 Mdot
.576 .22789 Mdot
.576 .22819 Mdot
.576 .22881 Mdot
.576 .2296 Mdot
.576 .23021 Mdot
.576 .23058 Mdot
.576 .23132 Mdot
.576 .23169 Mdot
.576 .23239 Mdot
.576 .23251 Mdot
.576 .23271 Mdot
.576 .23274 Mdot
.576 .23314 Mdot
.576 .23392 Mdot
.576 .23394 Mdot
.576 .23394 Mdot
.576 .23449 Mdot
.576 .23706 Mdot
.576 .23712 Mdot
.576 .23819 Mdot
.576 .23868 Mdot
.576 .23892 Mdot
.576 .23951 Mdot
.576 .23997 Mdot
.576 .24102 Mdot
.576 .24164 Mdot
.576 .24179 Mdot
.576 .24195 Mdot
.576 .24311 Mdot
.576 .24362 Mdot
.576 .2449 Mdot
.576 .24636 Mdot
.576 .24676 Mdot
.576 .25062 Mdot
.576 .25161 Mdot
.576 .25245 Mdot
.576 .25395 Mdot
.576 .25559 Mdot
.576 .25624 Mdot
.576 .25636 Mdot
.576 .25643 Mdot
.576 .25681 Mdot
.576 .25701 Mdot
.576 .25742 Mdot
.576 .25762 Mdot
.576 .25839 Mdot
.576 .25954 Mdot
.576 .25997 Mdot
.576 .26007 Mdot
.576 .26056 Mdot
.576 .26153 Mdot
.576 .26165 Mdot
.576 .26196 Mdot
.576 .26211 Mdot
.576 .26247 Mdot
.576 .26281 Mdot
.576 .26281 Mdot
.576 .26334 Mdot
.576 .26422 Mdot
.576 .26551 Mdot
.576 .26606 Mdot
.576 .26661 Mdot
.576 .26767 Mdot
.576 .26904 Mdot
.576 .26924 Mdot
.576 .26958 Mdot
.576 .27072 Mdot
.576 .27072 Mdot
.576 .27132 Mdot
.576 .27195 Mdot
.576 .27284 Mdot
.576 .27292 Mdot
.576 .27324 Mdot
.576 .27338 Mdot
.576 .27388 Mdot
.576 .27494 Mdot
.576 .27558 Mdot
.576 .27565 Mdot
.576 .27577 Mdot
.576 .2761 Mdot
.576 .27663 Mdot
.576 .27914 Mdot
.576 .27952 Mdot
.576 .28034 Mdot
.576 .28061 Mdot
.576 .28076 Mdot
.576 .28086 Mdot
.576 .28087 Mdot
.576 .28092 Mdot
.576 .28099 Mdot
.576 .28135 Mdot
.576 .28155 Mdot
.576 .2816 Mdot
.576 .28183 Mdot
.576 .28205 Mdot
.576 .28257 Mdot
.576 .28283 Mdot
.576 .28381 Mdot
.576 .28388 Mdot
.576 .2842 Mdot
.576 .28437 Mdot
.576 .28466 Mdot
.576 .2864 Mdot
.576 .28668 Mdot
.576 .28731 Mdot
.576 .28777 Mdot
.576 .28787 Mdot
.576 .28916 Mdot
.576 .28962 Mdot
.576 .28966 Mdot
.576 .29009 Mdot
.576 .29146 Mdot
.576 .29147 Mdot
.576 .29161 Mdot
.576 .2936 Mdot
.576 .29518 Mdot
.576 .29574 Mdot
.576 .29597 Mdot
.576 .29636 Mdot
.576 .29651 Mdot
.576 .29693 Mdot
.576 .29698 Mdot
.576 .29825 Mdot
.576 .29833 Mdot
.576 .29836 Mdot
.576 .29841 Mdot
.576 .29877 Mdot
.576 .29879 Mdot
.576 .29886 Mdot
.576 .299 Mdot
.576 .29901 Mdot
.576 .29918 Mdot
.576 .29958 Mdot
.576 .30039 Mdot
.576 .30075 Mdot
.576 .3012 Mdot
.576 .30236 Mdot
.576 .3034 Mdot
.576 .30672 Mdot
.576 .30773 Mdot
.576 .30826 Mdot
.576 .3088 Mdot
.576 .30906 Mdot
.576 .30964 Mdot
.576 .31033 Mdot
.576 .31189 Mdot
.576 .3134 Mdot
.576 .3134 Mdot
.576 .31391 Mdot
.576 .31438 Mdot
.576 .31563 Mdot
.576 .31572 Mdot
.576 .31573 Mdot
.576 .31577 Mdot
.576 .31755 Mdot
.576 .31959 Mdot
.576 .31976 Mdot
.576 .32129 Mdot
.576 .32263 Mdot
.576 .3227 Mdot
.576 .32325 Mdot
.576 .32515 Mdot
.576 .32544 Mdot
.576 .32747 Mdot
.576 .32981 Mdot
.576 .33025 Mdot
.576 .33048 Mdot
.576 .33107 Mdot
.576 .33378 Mdot
.576 .33397 Mdot
.576 .33425 Mdot
.576 .33646 Mdot
.576 .33652 Mdot
.576 .33757 Mdot
.576 .33807 Mdot
.576 .33908 Mdot
.576 .33985 Mdot
.576 .3402 Mdot
.576 .34067 Mdot
.576 .34204 Mdot
.576 .34396 Mdot
.576 .344 Mdot
.576 .34478 Mdot
.576 .34655 Mdot
.576 .34658 Mdot
.576 .34891 Mdot
.576 .34943 Mdot
.576 .34956 Mdot
.576 .34981 Mdot
.576 .35126 Mdot
.576 .35132 Mdot
.576 .3547 Mdot
.576 .35472 Mdot
.576 .355 Mdot
.576 .3562 Mdot
.576 .35626 Mdot
.576 .35673 Mdot
.576 .35858 Mdot
.576 .35912 Mdot
.576 .35929 Mdot
.576 .36008 Mdot
.576 .36178 Mdot
.576 .36243 Mdot
.576 .36244 Mdot
.576 .36273 Mdot
.576 .36411 Mdot
.576 .36467 Mdot
.576 .36492 Mdot
.576 .36504 Mdot
.576 .36534 Mdot
.576 .36611 Mdot
.576 .3665 Mdot
.576 .36658 Mdot
.576 .36716 Mdot
.576 .36805 Mdot
.576 .36876 Mdot
.576 .36895 Mdot
.576 .3708 Mdot
.576 .37237 Mdot
.576 .37343 Mdot
.576 .37348 Mdot
.576 .37351 Mdot
.576 .37369 Mdot
.576 .37378 Mdot
.576 .37396 Mdot
.576 .37406 Mdot
.576 .37512 Mdot
.576 .37517 Mdot
.576 .37539 Mdot
.576 .37582 Mdot
.576 .37587 Mdot
.576 .37601 Mdot
.576 .37639 Mdot
.576 .37663 Mdot
.576 .37758 Mdot
.576 .37782 Mdot
.576 .3792 Mdot
.576 .37984 Mdot
.576 .38009 Mdot
.576 .38036 Mdot
.576 .38074 Mdot
.576 .38077 Mdot
.576 .38118 Mdot
.576 .38163 Mdot
.576 .3819 Mdot
.576 .38193 Mdot
.576 .38198 Mdot
.576 .38212 Mdot
.576 .38234 Mdot
.576 .38338 Mdot
.576 .38388 Mdot
.576 .38399 Mdot
.576 .38405 Mdot
.576 .38415 Mdot
.576 .38429 Mdot
.576 .38437 Mdot
.576 .3844 Mdot
.576 .38449 Mdot
.576 .38458 Mdot
.576 .38479 Mdot
.576 .38545 Mdot
.576 .38646 Mdot
.576 .3869 Mdot
.576 .38694 Mdot
.576 .38764 Mdot
.576 .38765 Mdot
.576 .38837 Mdot
.576 .38837 Mdot
.576 .39006 Mdot
.576 .3903 Mdot
.576 .39036 Mdot
.576 .39052 Mdot
.576 .39054 Mdot
.576 .39104 Mdot
.576 .39107 Mdot
.576 .39108 Mdot
.576 .39125 Mdot
.576 .39127 Mdot
.576 .39133 Mdot
.576 .39134 Mdot
.576 .3914 Mdot
.576 .39156 Mdot
.576 .39187 Mdot
.576 .39263 Mdot
.576 .39701 Mdot
.576 .3977 Mdot
.576 .39836 Mdot
.576 .39919 Mdot
.576 .39975 Mdot
.576 .40024 Mdot
.576 .40027 Mdot
.576 .40047 Mdot
.576 .40127 Mdot
.576 .40333 Mdot
.576 .4043 Mdot
.576 .40437 Mdot
.576 .40527 Mdot
.576 .40621 Mdot
.576 .40795 Mdot
.576 .40797 Mdot
.576 .40824 Mdot
.576 .41003 Mdot
.576 .41054 Mdot
.576 .41176 Mdot
.576 .41364 Mdot
.576 .41424 Mdot
.576 .41447 Mdot
.576 .41457 Mdot
.576 .41505 Mdot
.576 .41538 Mdot
.576 .41592 Mdot
.576 .41612 Mdot
.576 .41643 Mdot
.576 .41668 Mdot
.576 .41674 Mdot
.576 .4183 Mdot
.576 .41832 Mdot
.576 .41839 Mdot
.576 .41842 Mdot
.576 .41849 Mdot
.576 .41852 Mdot
.576 .41889 Mdot
.576 .4189 Mdot
.576 .41898 Mdot
.576 .41913 Mdot
.576 .41915 Mdot
.576 .41933 Mdot
.576 .41974 Mdot
.576 .42052 Mdot
.576 .42061 Mdot
.576 .42085 Mdot
.576 .42124 Mdot
.576 .42207 Mdot
.576 .4221 Mdot
.576 .42211 Mdot
.576 .42214 Mdot
.576 .42217 Mdot
.576 .42282 Mdot
.576 .42297 Mdot
.576 .42323 Mdot
.576 .42348 Mdot
.576 .42348 Mdot
.576 .42407 Mdot
.576 .42423 Mdot
.576 .42442 Mdot
.576 .42442 Mdot
.576 .42448 Mdot
.576 .42449 Mdot
.576 .42451 Mdot
.576 .42451 Mdot
.576 .45298 Mdot
.576 .45298 Mdot
.576 .45299 Mdot
.576 .45299 Mdot
.576 .45303 Mdot
.576 .45303 Mdot
.576 .45313 Mdot
.576 .45322 Mdot
.576 .45355 Mdot
.576 .45355 Mdot
.576 .45369 Mdot
.576 .45383 Mdot
.576 .45392 Mdot
.576 .45428 Mdot
.576 .4543 Mdot
.576 .45431 Mdot
.576 .45432 Mdot
.576 .45433 Mdot
.576 .45479 Mdot
.576 .45501 Mdot
.576 .45514 Mdot
.576 .45519 Mdot
.576 .45561 Mdot
.576 .45584 Mdot
.576 .45594 Mdot
.576 .45595 Mdot
.576 .45603 Mdot
.576 .45607 Mdot
.576 .45608 Mdot
.576 .45628 Mdot
.576 .4563 Mdot
.576 .45634 Mdot
.576 .45635 Mdot
.576 .45639 Mdot
.576 .4564 Mdot
.576 .45725 Mdot
.576 .45729 Mdot
.576 .45742 Mdot
.576 .45759 Mdot
.576 .4577 Mdot
.576 .45799 Mdot
.576 .45816 Mdot
.576 .45842 Mdot
.576 .45848 Mdot
.576 .4586 Mdot
.576 .45892 Mdot
.576 .45993 Mdot
.576 .46058 Mdot
.576 .46085 Mdot
.576 .46179 Mdot
.576 .46194 Mdot
.576 .46194 Mdot
.576 .46286 Mdot
.576 .46335 Mdot
.576 .46381 Mdot
.576 .46385 Mdot
.576 .46436 Mdot
.576 .46541 Mdot
.576 .46583 Mdot
.576 .46593 Mdot
.576 .46594 Mdot
.576 .4662 Mdot
.576 .46648 Mdot
.576 .4669 Mdot
.576 .46724 Mdot
.576 .46759 Mdot
.576 .4698 Mdot
.576 .47018 Mdot
.576 .47033 Mdot
.576 .47041 Mdot
.576 .47044 Mdot
.576 .47045 Mdot
.576 .47047 Mdot
.576 .47049 Mdot
.576 .47057 Mdot
.576 .47058 Mdot
.576 .47059 Mdot
.576 .47084 Mdot
.576 .47085 Mdot
.576 .47093 Mdot
.576 .47096 Mdot
.576 .47108 Mdot
.576 .47191 Mdot
.576 .47191 Mdot
.576 .47227 Mdot
.576 .47227 Mdot
.576 .47262 Mdot
.576 .47264 Mdot
.576 .47285 Mdot
.576 .47335 Mdot
.576 .47367 Mdot
.576 .47377 Mdot
.576 .47382 Mdot
.576 .47386 Mdot
.576 .47387 Mdot
.576 .47391 Mdot
.576 .47399 Mdot
.576 .47403 Mdot
.576 .47406 Mdot
.576 .47412 Mdot
.576 .47436 Mdot
.576 .47486 Mdot
.576 .47497 Mdot
.576 .47504 Mdot
.576 .47506 Mdot
.576 .47508 Mdot
.576 .47521 Mdot
.576 .47542 Mdot
.576 .47562 Mdot
.576 .47564 Mdot
.576 .47582 Mdot
.576 .47595 Mdot
.576 .47607 Mdot
.576 .47638 Mdot
.576 .47704 Mdot
.576 .47715 Mdot
.576 .47761 Mdot
.576 .47772 Mdot
.576 .4779 Mdot
.576 .47797 Mdot
.576 .47799 Mdot
.576 .4782 Mdot
.576 .4783 Mdot
.576 .47832 Mdot
.576 .47883 Mdot
.576 .47887 Mdot
.576 .47896 Mdot
.576 .47901 Mdot
.576 .47909 Mdot
.576 .4791 Mdot
.576 .47913 Mdot
.576 .47963 Mdot
.576 .48036 Mdot
.576 .48123 Mdot
.576 .48132 Mdot
.576 .48165 Mdot
.576 .48207 Mdot
.576 .48233 Mdot
.576 .48237 Mdot
.576 .48255 Mdot
.576 .48291 Mdot
.576 .48305 Mdot
.576 .4831 Mdot
.576 .48322 Mdot
.576 .48347 Mdot
.576 .48411 Mdot
.576 .48425 Mdot
.576 .48425 Mdot
.576 .48455 Mdot
.576 .48532 Mdot
.576 .48568 Mdot
.576 .48576 Mdot
.576 .48601 Mdot
.576 .48684 Mdot
.576 .48706 Mdot
.576 .48708 Mdot
.576 .48762 Mdot
.576 .48775 Mdot
.576 .48776 Mdot
.576 .48927 Mdot
.576 .4893 Mdot
.576 .48995 Mdot
.576 .49006 Mdot
.576 .49011 Mdot
.576 .49035 Mdot
.576 .49138 Mdot
.576 .49139 Mdot
.576 .49217 Mdot
.576 .49251 Mdot
.576 .49253 Mdot
.576 .49336 Mdot
.576 .49396 Mdot
.576 .49417 Mdot
.576 .49432 Mdot
.576 .49465 Mdot
.576 .49509 Mdot
.576 .49531 Mdot
.576 .49576 Mdot
.576 .49578 Mdot
.576 .49673 Mdot
.576 .49685 Mdot
.576 .49693 Mdot
.576 .49809 Mdot
.576 .49834 Mdot
.576 .49844 Mdot
.576 .49862 Mdot
.576 .49961 Mdot
.576 .50047 Mdot
.576 .50059 Mdot
.576 .50139 Mdot
.576 .50162 Mdot
.576 .50165 Mdot
.576 .5022 Mdot
.576 .50284 Mdot
.576 .50291 Mdot
.576 .50375 Mdot
.576 .50449 Mdot
.576 .5045 Mdot
.576 .50451 Mdot
.576 .50454 Mdot
.576 .50506 Mdot
.576 .50525 Mdot
.576 .50546 Mdot
.576 .50546 Mdot
.576 .50607 Mdot
.576 .50671 Mdot
.576 .50699 Mdot
.576 .50723 Mdot
.576 .50733 Mdot
.576 .50755 Mdot
.576 .50777 Mdot
.576 .50817 Mdot
.576 .50951 Mdot
.576 .50993 Mdot
.576 .51039 Mdot
.576 .51057 Mdot
.576 .51071 Mdot
.576 .51103 Mdot
.576 .51119 Mdot
.576 .51126 Mdot
.576 .51127 Mdot
.576 .51132 Mdot
.576 .51135 Mdot
.576 .51136 Mdot
.576 .5115 Mdot
.576 .51152 Mdot
.576 .51153 Mdot
.576 .51156 Mdot
.576 .51207 Mdot
.576 .51209 Mdot
.576 .51226 Mdot
.576 .51231 Mdot
.576 .51247 Mdot
.576 .51256 Mdot
.576 .51278 Mdot
.576 .5134 Mdot
.576 .51418 Mdot
.576 .51424 Mdot
.576 .51424 Mdot
.576 .51478 Mdot
.576 .51495 Mdot
.576 .51496 Mdot
.576 .51514 Mdot
.576 .51564 Mdot
.576 .51568 Mdot
.576 .51586 Mdot
.576 .5161 Mdot
.576 .51622 Mdot
.576 .51689 Mdot
.576 .517 Mdot
.576 .51707 Mdot
.576 .51719 Mdot
.576 .51722 Mdot
.576 .5176 Mdot
.576 .51769 Mdot
.576 .51789 Mdot
.576 .51798 Mdot
.576 .51807 Mdot
.576 .51809 Mdot
.576 .51817 Mdot
.576 .5183 Mdot
.576 .51833 Mdot
.576 .51835 Mdot
.576 .51835 Mdot
.576 .51839 Mdot
.576 .51845 Mdot
.576 .51855 Mdot
.576 .51887 Mdot
.576 .51901 Mdot
.576 .51997 Mdot
.576 .52017 Mdot
.576 .5203 Mdot
.576 .52034 Mdot
.576 .52037 Mdot
.576 .52061 Mdot
.576 .52102 Mdot
.576 .52121 Mdot
.576 .52126 Mdot
.576 .52138 Mdot
.576 .52141 Mdot
.576 .52175 Mdot
.576 .52198 Mdot
.576 .52221 Mdot
.576 .52221 Mdot
.576 .52264 Mdot
.576 .52277 Mdot
.576 .52284 Mdot
.576 .52336 Mdot
.576 .52376 Mdot
.576 .52396 Mdot
.576 .52417 Mdot
.576 .52465 Mdot
.576 .52498 Mdot
.576 .52517 Mdot
.576 .52517 Mdot
.576 .5253 Mdot
.576 .52543 Mdot
.576 .52549 Mdot
.576 .5256 Mdot
.576 .52565 Mdot
.576 .52601 Mdot
.576 .52619 Mdot
.576 .52623 Mdot
.576 .52639 Mdot
.576 .52681 Mdot
.576 .52709 Mdot
.576 .52717 Mdot
.576 .52732 Mdot
.576 .52739 Mdot
.576 .52753 Mdot
.576 .52756 Mdot
.576 .5276 Mdot
.576 .52784 Mdot
.576 .52844 Mdot
.576 .52899 Mdot
.576 .5293 Mdot
.576 .52966 Mdot
.576 .53106 Mdot
.576 .53121 Mdot
.576 .53173 Mdot
.576 .5322 Mdot
.576 .53238 Mdot
.576 .5328 Mdot
.576 .53285 Mdot
.576 .53291 Mdot
.576 .53313 Mdot
.576 .53351 Mdot
.576 .53367 Mdot
.576 .53388 Mdot
.576 .53397 Mdot
.576 .53414 Mdot
.576 .53452 Mdot
.576 .53455 Mdot
.576 .53546 Mdot
.576 .53565 Mdot
.576 .53566 Mdot
.576 .53566 Mdot
.576 .53608 Mdot
.576 .53609 Mdot
.576 .53616 Mdot
.576 .53621 Mdot
.576 .53645 Mdot
.576 .53658 Mdot
.576 .53685 Mdot
.576 .53698 Mdot
.576 .53719 Mdot
.576 .53747 Mdot
.576 .53769 Mdot
.576 .53779 Mdot
.576 .53813 Mdot
.576 .53818 Mdot
.576 .53845 Mdot
.576 .53851 Mdot
.576 .5388 Mdot
.576 .53925 Mdot
.576 .53938 Mdot
.576 .53945 Mdot
.576 .53952 Mdot
.576 .53956 Mdot
.576 .53963 Mdot
.576 .53972 Mdot
.576 .53993 Mdot
.576 .54013 Mdot
.576 .54013 Mdot
.576 .54025 Mdot
.576 .54042 Mdot
.576 .54043 Mdot
.576 .54043 Mdot
.576 .54093 Mdot
.576 .54163 Mdot
.576 .54193 Mdot
.576 .54222 Mdot
.576 .54228 Mdot
.576 .5423 Mdot
.576 .54277 Mdot
.576 .54306 Mdot
.576 .54318 Mdot
.576 .54325 Mdot
.576 .54347 Mdot
.576 .54351 Mdot
.576 .54357 Mdot
.576 .54373 Mdot
.576 .54428 Mdot
.576 .54429 Mdot
.576 .54457 Mdot
.576 .54463 Mdot
.576 .54465 Mdot
.576 .54486 Mdot
.576 .54526 Mdot
.576 .5453 Mdot
.576 .54544 Mdot
.576 .54545 Mdot
.576 .54551 Mdot
.576 .54573 Mdot
.576 .54579 Mdot
.576 .54581 Mdot
.576 .54618 Mdot
.576 .54645 Mdot
.576 .54648 Mdot
.576 .54653 Mdot
.576 .54662 Mdot
.576 .54667 Mdot
.576 .54717 Mdot
.576 .54736 Mdot
.576 .54749 Mdot
.576 .54778 Mdot
.576 .54786 Mdot
.576 .548 Mdot
.576 .54816 Mdot
.576 .54829 Mdot
.576 .54834 Mdot
.576 .54839 Mdot
.576 .54844 Mdot
.576 .54847 Mdot
.576 .54848 Mdot
.576 .5485 Mdot
.576 .54852 Mdot
.576 .54864 Mdot
.576 .5487 Mdot
.576 .54871 Mdot
.576 .54872 Mdot
.576 .54873 Mdot
.576 .54881 Mdot
.576 .54888 Mdot
.576 .54906 Mdot
.576 .54914 Mdot
.576 .54945 Mdot
.576 .54945 Mdot
.576 .54947 Mdot
.576 .54953 Mdot
.576 .54957 Mdot
.576 .54959 Mdot
.576 .54963 Mdot
.576 .54972 Mdot
.576 .55022 Mdot
.576 .5503 Mdot
.576 .55038 Mdot
.576 .55048 Mdot
.576 .55054 Mdot
.576 .5506 Mdot
.576 .5506 Mdot
.576 .55062 Mdot
.576 .55072 Mdot
.576 .55095 Mdot
.576 .55107 Mdot
.576 .55107 Mdot
.576 .55118 Mdot
.576 .55129 Mdot
.576 .55149 Mdot
.576 .55149 Mdot
.576 .55152 Mdot
.576 .55173 Mdot
.576 .55179 Mdot
.576 .55193 Mdot
.576 .55215 Mdot
.576 .55221 Mdot
.576 .55224 Mdot
.576 .55225 Mdot
.576 .55231 Mdot
.576 .55235 Mdot
.576 .55241 Mdot
.576 .55243 Mdot
.576 .55247 Mdot
.576 .5525 Mdot
.576 .5525 Mdot
.576 .55268 Mdot
.576 .55269 Mdot
.576 .5527 Mdot
.576 .5527 Mdot
.576 .55271 Mdot
.576 .55271 Mdot
.576 .55275 Mdot
.576 .55275 Mdot
.576 .55276 Mdot
.576 .55278 Mdot
.576 .55278 Mdot
.576 .5528 Mdot
.576 .55285 Mdot
.576 .55294 Mdot
.576 .55295 Mdot
.576 .55298 Mdot
.576 .55303 Mdot
.576 .55312 Mdot
.576 .55313 Mdot
.576 .55313 Mdot
.576 .55313 Mdot
.576 .55313 Mdot
.576 .55321 Mdot
.576 .55323 Mdot
.576 .55326 Mdot
.576 .55329 Mdot
.576 .55329 Mdot
.576 .55335 Mdot
.576 .55337 Mdot
.576 .55339 Mdot
.576 .5534 Mdot
.576 .5534 Mdot
.576 .5534 Mdot
.576 .55341 Mdot
.576 .55341 Mdot
.578 .18132 Mdot
.578 .31008 Mdot
.578 .39572 Mdot
.578 .42611 Mdot
.578 .45218 Mdot
.578 .46833 Mdot
.578 .50687 Mdot
.578 .55363 Mdot
.58 .18065 Mdot
.58 .18066 Mdot
.58 .18066 Mdot
.58 .18066 Mdot
.58 .18068 Mdot
.58 .1807 Mdot
.58 .18072 Mdot
.58 .18072 Mdot
.58 .18075 Mdot
.58 .18077 Mdot
.58 .18078 Mdot
.58 .18079 Mdot
.58 .1808 Mdot
.58 .1808 Mdot
.58 .18092 Mdot
.58 .18095 Mdot
.58 .18098 Mdot
.58 .18103 Mdot
.58 .18109 Mdot
.58 .18114 Mdot
.58 .18114 Mdot
.58 .18118 Mdot
.58 .18118 Mdot
.58 .18121 Mdot
.58 .18137 Mdot
.58 .18138 Mdot
.58 .18144 Mdot
.58 .18146 Mdot
.58 .18155 Mdot
.58 .18156 Mdot
.58 .18159 Mdot
.58 .18175 Mdot
.58 .18177 Mdot
.58 .18206 Mdot
.58 .1822 Mdot
.58 .18263 Mdot
.58 .18267 Mdot
.58 .18275 Mdot
.58 .18278 Mdot
.58 .18284 Mdot
.58 .18291 Mdot
.58 .18293 Mdot
.58 .18308 Mdot
.58 .18322 Mdot
.58 .1834 Mdot
.58 .18344 Mdot
.58 .18346 Mdot
.58 .18352 Mdot
.58 .18353 Mdot
.58 .18361 Mdot
.58 .18361 Mdot
.58 .1838 Mdot
.58 .18383 Mdot
.58 .18402 Mdot
.58 .18409 Mdot
.58 .1841 Mdot
.58 .18411 Mdot
.58 .18412 Mdot
.58 .18422 Mdot
.58 .18454 Mdot
.58 .1853 Mdot
.58 .18554 Mdot
.58 .18562 Mdot
.58 .18564 Mdot
.58 .18604 Mdot
.58 .18611 Mdot
.58 .18611 Mdot
.58 .18643 Mdot
.58 .18745 Mdot
.58 .1875 Mdot
.58 .1877 Mdot
.58 .18781 Mdot
.58 .18811 Mdot
.58 .18904 Mdot
.58 .18918 Mdot
.58 .18945 Mdot
.58 .1902 Mdot
.58 .19038 Mdot
.58 .19044 Mdot
.58 .19128 Mdot
.58 .19184 Mdot
.58 .19225 Mdot
.58 .19259 Mdot
.58 .19278 Mdot
.58 .19406 Mdot
.58 .19446 Mdot
.58 .19511 Mdot
.58 .1952 Mdot
.58 .19616 Mdot
.58 .19669 Mdot
.58 .19701 Mdot
.58 .19704 Mdot
.58 .19777 Mdot
.58 .19843 Mdot
.58 .19888 Mdot
.58 .1989 Mdot
.58 .19925 Mdot
.58 .19954 Mdot
.58 .19966 Mdot
.58 .19998 Mdot
.58 .20056 Mdot
.58 .20095 Mdot
.58 .20167 Mdot
.58 .20273 Mdot
.58 .20312 Mdot
.58 .20326 Mdot
.58 .20333 Mdot
.58 .20343 Mdot
.58 .20376 Mdot
.58 .20427 Mdot
.58 .20632 Mdot
.58 .20659 Mdot
.58 .20714 Mdot
.58 .21084 Mdot
.58 .21094 Mdot
.58 .21132 Mdot
.58 .21263 Mdot
.58 .21345 Mdot
.58 .21419 Mdot
.58 .21429 Mdot
.58 .21473 Mdot
.58 .2161 Mdot
.58 .21632 Mdot
.58 .21676 Mdot
.58 .21747 Mdot
.58 .21799 Mdot
.58 .218 Mdot
.58 .21972 Mdot
.58 .22 Mdot
.58 .22054 Mdot
.58 .22059 Mdot
.58 .22077 Mdot
.58 .22157 Mdot
.58 .22198 Mdot
.58 .2226 Mdot
.58 .22266 Mdot
.58 .2227 Mdot
.58 .22423 Mdot
.58 .22583 Mdot
.58 .22599 Mdot
.58 .22733 Mdot
.58 .22751 Mdot
.58 .22805 Mdot
.58 .22879 Mdot
.58 .22879 Mdot
.58 .22909 Mdot
.58 .22987 Mdot
.58 .23001 Mdot
.58 .23071 Mdot
.58 .23236 Mdot
.58 .23244 Mdot
.58 .23297 Mdot
.58 .2334 Mdot
.58 .23343 Mdot
.58 .23401 Mdot
.58 .23413 Mdot
.58 .23494 Mdot
.58 .23631 Mdot
.58 .23633 Mdot
.58 .23867 Mdot
.58 .23878 Mdot
.58 .23916 Mdot
.58 .2394 Mdot
.58 .2396 Mdot
.58 .23976 Mdot
.58 .2419 Mdot
.58 .24229 Mdot
.58 .24352 Mdot
.58 .24472 Mdot
.58 .246 Mdot
.58 .24659 Mdot
.58 .24894 Mdot
.58 .25015 Mdot
.58 .25095 Mdot
.58 .25202 Mdot
.58 .2521 Mdot
.58 .2522 Mdot
.58 .25232 Mdot
.58 .25251 Mdot
.58 .25257 Mdot
.58 .25377 Mdot
.58 .25449 Mdot
.58 .25498 Mdot
.58 .25528 Mdot
.58 .25712 Mdot
.58 .2572 Mdot
.58 .25762 Mdot
.58 .25779 Mdot
.58 .25935 Mdot
.58 .25944 Mdot
.58 .26036 Mdot
.58 .26125 Mdot
.58 .26127 Mdot
.58 .26131 Mdot
.58 .26239 Mdot
.58 .26285 Mdot
.58 .26302 Mdot
.58 .26408 Mdot
.58 .2644 Mdot
.58 .26526 Mdot
.58 .26613 Mdot
.58 .26649 Mdot
.58 .26697 Mdot
.58 .26751 Mdot
.58 .26839 Mdot
.58 .26865 Mdot
.58 .26871 Mdot
.58 .27131 Mdot
.58 .27172 Mdot
.58 .27191 Mdot
.58 .2741 Mdot
.58 .27418 Mdot
.58 .27424 Mdot
.58 .27434 Mdot
.58 .27465 Mdot
.58 .27609 Mdot
.58 .27727 Mdot
.58 .27752 Mdot
.58 .27782 Mdot
.58 .27783 Mdot
.58 .27947 Mdot
.58 .27949 Mdot
.58 .27978 Mdot
.58 .28028 Mdot
.58 .28119 Mdot
.58 .28128 Mdot
.58 .28232 Mdot
.58 .28363 Mdot
.58 .28384 Mdot
.58 .28464 Mdot
.58 .28527 Mdot
.58 .28793 Mdot
.58 .28914 Mdot
.58 .2897 Mdot
.58 .28998 Mdot
.58 .29005 Mdot
.58 .29202 Mdot
.58 .29203 Mdot
.58 .29279 Mdot
.58 .29281 Mdot
.58 .29295 Mdot
.58 .29469 Mdot
.58 .29606 Mdot
.58 .29653 Mdot
.58 .2981 Mdot
.58 .29849 Mdot
.58 .29999 Mdot
.58 .30041 Mdot
.58 .3021 Mdot
.58 .30251 Mdot
.58 .30259 Mdot
.58 .30287 Mdot
.58 .30397 Mdot
.58 .3046 Mdot
.58 .30485 Mdot
.58 .3053 Mdot
.58 .30645 Mdot
.58 .30656 Mdot
.58 .30674 Mdot
.58 .30865 Mdot
.58 .30876 Mdot
.58 .30892 Mdot
.58 .30968 Mdot
.58 .31024 Mdot
.58 .31057 Mdot
.58 .3108 Mdot
.58 .31083 Mdot
.58 .31165 Mdot
.58 .31177 Mdot
.58 .31181 Mdot
.58 .31295 Mdot
.58 .31379 Mdot
.58 .31408 Mdot
.58 .3143 Mdot
.58 .3143 Mdot
.58 .31443 Mdot
.58 .31522 Mdot
.58 .31589 Mdot
.58 .31602 Mdot
.58 .31663 Mdot
.58 .31669 Mdot
.58 .31923 Mdot
.58 .31933 Mdot
.58 .31961 Mdot
.58 .31976 Mdot
.58 .31997 Mdot
.58 .32034 Mdot
.58 .32065 Mdot
.58 .32105 Mdot
.58 .32115 Mdot
.58 .32119 Mdot
.58 .32131 Mdot
.58 .32133 Mdot
.58 .32151 Mdot
.58 .3219 Mdot
.58 .32235 Mdot
.58 .32248 Mdot
.58 .32251 Mdot
.58 .32253 Mdot
.58 .32254 Mdot
.58 .32275 Mdot
.58 .32469 Mdot
.58 .32589 Mdot
.58 .3265 Mdot
.58 .32849 Mdot
.58 .33028 Mdot
.58 .33061 Mdot
.58 .33151 Mdot
.58 .33173 Mdot
.58 .33179 Mdot
.58 .33383 Mdot
.58 .33612 Mdot
.58 .33922 Mdot
.58 .33981 Mdot
.58 .34087 Mdot
.58 .34114 Mdot
.58 .34162 Mdot
.58 .34254 Mdot
.58 .34419 Mdot
.58 .34458 Mdot
.58 .35161 Mdot
.58 .35291 Mdot
.58 .35319 Mdot
.58 .35396 Mdot
.58 .3555 Mdot
.58 .35553 Mdot
.58 .35612 Mdot
.58 .35943 Mdot
.58 .35954 Mdot
.58 .35983 Mdot
.58 .36025 Mdot
.58 .36129 Mdot
.58 .36218 Mdot
.58 .36222 Mdot
.58 .36251 Mdot
.58 .36273 Mdot
.58 .36312 Mdot
.58 .36425 Mdot
.58 .36728 Mdot
.58 .36847 Mdot
.58 .36938 Mdot
.58 .3705 Mdot
.58 .37107 Mdot
.58 .37195 Mdot
.58 .37198 Mdot
.58 .37208 Mdot
.58 .37217 Mdot
.58 .3722 Mdot
.58 .37276 Mdot
.58 .37309 Mdot
.58 .37345 Mdot
.58 .37429 Mdot
.58 .37432 Mdot
.58 .37459 Mdot
.58 .37529 Mdot
.58 .37533 Mdot
.58 .37615 Mdot
.58 .37616 Mdot
.58 .37664 Mdot
.58 .37685 Mdot
.58 .37692 Mdot
.58 .37738 Mdot
.58 .37752 Mdot
.58 .3779 Mdot
.58 .37857 Mdot
.58 .37939 Mdot
.58 .3805 Mdot
.58 .38067 Mdot
.58 .38075 Mdot
.58 .38167 Mdot
.58 .38177 Mdot
.58 .3819 Mdot
.58 .3825 Mdot
.58 .38299 Mdot
.58 .38321 Mdot
.58 .38322 Mdot
.58 .38389 Mdot
.58 .38423 Mdot
.58 .386 Mdot
.58 .38625 Mdot
.58 .3878 Mdot
.58 .38813 Mdot
.58 .38894 Mdot
.58 .3893 Mdot
.58 .39131 Mdot
.58 .39146 Mdot
.58 .39285 Mdot
.58 .393 Mdot
.58 .39304 Mdot
.58 .39314 Mdot
.58 .39356 Mdot
.58 .3939 Mdot
.58 .39407 Mdot
.58 .3945 Mdot
.58 .39454 Mdot
.58 .39461 Mdot
.58 .39572 Mdot
.58 .39593 Mdot
.58 .39614 Mdot
.58 .39615 Mdot
.58 .3965 Mdot
.58 .39652 Mdot
.58 .39694 Mdot
.58 .39736 Mdot
.58 .39745 Mdot
.58 .39779 Mdot
.58 .39809 Mdot
.58 .39834 Mdot
.58 .39927 Mdot
.58 .39931 Mdot
.58 .39941 Mdot
.58 .39947 Mdot
.58 .39955 Mdot
.58 .39968 Mdot
.58 .39979 Mdot
.58 .39994 Mdot
.58 .39998 Mdot
.58 .39999 Mdot
.58 .40011 Mdot
.58 .40025 Mdot
.58 .40042 Mdot
.58 .40047 Mdot
.58 .40048 Mdot
.58 .40048 Mdot
.58 .40049 Mdot
.58 .40265 Mdot
.58 .40342 Mdot
.58 .40382 Mdot
.58 .40651 Mdot
.58 .40736 Mdot
.58 .40769 Mdot
.58 .40827 Mdot
.58 .40841 Mdot
.58 .41135 Mdot
.58 .41225 Mdot
.58 .41226 Mdot
.58 .41247 Mdot
.58 .41363 Mdot
.58 .41366 Mdot
.58 .41391 Mdot
.58 .41458 Mdot
.58 .41677 Mdot
.58 .41767 Mdot
.58 .41798 Mdot
.58 .41799 Mdot
.58 .41802 Mdot
.58 .41806 Mdot
.58 .41826 Mdot
.58 .4188 Mdot
.58 .41889 Mdot
.58 .41943 Mdot
.58 .41943 Mdot
.58 .41967 Mdot
.58 .4197 Mdot
.58 .41986 Mdot
.58 .41991 Mdot
.58 .42003 Mdot
.58 .42055 Mdot
.58 .42093 Mdot
.58 .42137 Mdot
.58 .42142 Mdot
.58 .42162 Mdot
.58 .42179 Mdot
.58 .42187 Mdot
.58 .42211 Mdot
.58 .42222 Mdot
.58 .42345 Mdot
.58 .42385 Mdot
.58 .42467 Mdot
.58 .42472 Mdot
.58 .4252 Mdot
.58 .42526 Mdot
.58 .4253 Mdot
.58 .42556 Mdot
.58 .42562 Mdot
.58 .42577 Mdot
.58 .42581 Mdot
.58 .42626 Mdot
.58 .42633 Mdot
.58 .42634 Mdot
.58 .42646 Mdot
.58 .42647 Mdot
.58 .42661 Mdot
.58 .42679 Mdot
.58 .4269 Mdot
.58 .42701 Mdot
.58 .42709 Mdot
.58 .42742 Mdot
.58 .42743 Mdot
.58 .42746 Mdot
.58 .42748 Mdot
.58 .42751 Mdot
.58 .42756 Mdot
.58 .42766 Mdot
.58 .42767 Mdot
.58 .42771 Mdot
.58 .42776 Mdot
.58 .42781 Mdot
.58 .42783 Mdot
.58 .42783 Mdot
.58 .42784 Mdot
.58 .45131 Mdot
.58 .45131 Mdot
.58 .45132 Mdot
.58 .45132 Mdot
.58 .45136 Mdot
.58 .45138 Mdot
.58 .45141 Mdot
.58 .45141 Mdot
.58 .45147 Mdot
.58 .45149 Mdot
.58 .45151 Mdot
.58 .45152 Mdot
.58 .45154 Mdot
.58 .45155 Mdot
.58 .45173 Mdot
.58 .45178 Mdot
.58 .45184 Mdot
.58 .4519 Mdot
.58 .452 Mdot
.58 .45208 Mdot
.58 .45209 Mdot
.58 .45215 Mdot
.58 .45216 Mdot
.58 .4522 Mdot
.58 .45245 Mdot
.58 .45247 Mdot
.58 .45256 Mdot
.58 .45259 Mdot
.58 .45274 Mdot
.58 .45276 Mdot
.58 .45279 Mdot
.58 .45306 Mdot
.58 .45309 Mdot
.58 .45354 Mdot
.58 .45376 Mdot
.58 .45445 Mdot
.58 .45451 Mdot
.58 .45464 Mdot
.58 .45468 Mdot
.58 .45478 Mdot
.58 .45489 Mdot
.58 .45491 Mdot
.58 .45516 Mdot
.58 .45537 Mdot
.58 .45565 Mdot
.58 .45572 Mdot
.58 .45575 Mdot
.58 .45583 Mdot
.58 .45585 Mdot
.58 .45598 Mdot
.58 .45598 Mdot
.58 .45627 Mdot
.58 .45632 Mdot
.58 .45662 Mdot
.58 .45672 Mdot
.58 .45675 Mdot
.58 .45677 Mdot
.58 .45677 Mdot
.58 .45694 Mdot
.58 .45743 Mdot
.58 .4586 Mdot
.58 .45897 Mdot
.58 .4591 Mdot
.58 .45912 Mdot
.58 .45974 Mdot
.58 .45985 Mdot
.58 .45985 Mdot
.58 .46033 Mdot
.58 .46188 Mdot
.58 .46196 Mdot
.58 .46226 Mdot
.58 .46243 Mdot
.58 .46288 Mdot
.58 .46428 Mdot
.58 .46449 Mdot
.58 .46488 Mdot
.58 .46599 Mdot
.58 .46599 Mdot
.58 .466 Mdot
.58 .466 Mdot
.58 .46603 Mdot
.58 .46611 Mdot
.58 .46619 Mdot
.58 .46625 Mdot
.58 .46625 Mdot
.58 .46627 Mdot
.58 .46635 Mdot
.58 .4664 Mdot
.58 .46647 Mdot
.58 .46651 Mdot
.58 .46654 Mdot
.58 .46659 Mdot
.58 .46661 Mdot
.58 .46709 Mdot
.58 .46722 Mdot
.58 .46737 Mdot
.58 .46754 Mdot
.58 .46758 Mdot
.58 .4678 Mdot
.58 .46801 Mdot
.58 .46802 Mdot
.58 .4682 Mdot
.58 .4682 Mdot
.58 .46831 Mdot
.58 .46841 Mdot
.58 .46897 Mdot
.58 .469 Mdot
.58 .46902 Mdot
.58 .46924 Mdot
.58 .46933 Mdot
.58 .4695 Mdot
.58 .46971 Mdot
.58 .46976 Mdot
.58 .46978 Mdot
.58 .46985 Mdot
.58 .47055 Mdot
.58 .47062 Mdot
.58 .47161 Mdot
.58 .47179 Mdot
.58 .47219 Mdot
.58 .47236 Mdot
.58 .47311 Mdot
.58 .47324 Mdot
.58 .4741 Mdot
.58 .47426 Mdot
.58 .47459 Mdot
.58 .47459 Mdot
.58 .4747 Mdot
.58 .47494 Mdot
.58 .47523 Mdot
.58 .47529 Mdot
.58 .47534 Mdot
.58 .47579 Mdot
.58 .47583 Mdot
.58 .47591 Mdot
.58 .47644 Mdot
.58 .47683 Mdot
.58 .47715 Mdot
.58 .47733 Mdot
.58 .4774 Mdot
.58 .47762 Mdot
.58 .47766 Mdot
.58 .47775 Mdot
.58 .47798 Mdot
.58 .47799 Mdot
.58 .47838 Mdot
.58 .47839 Mdot
.58 .47873 Mdot
.58 .47885 Mdot
.58 .47887 Mdot
.58 .47926 Mdot
.58 .47944 Mdot
.58 .47959 Mdot
.58 .47985 Mdot
.58 .47987 Mdot
.58 .47991 Mdot
.58 .47996 Mdot
.58 .47997 Mdot
.58 .48038 Mdot
.58 .48065 Mdot
.58 .48118 Mdot
.58 .4816 Mdot
.58 .48215 Mdot
.58 .48355 Mdot
.58 .48407 Mdot
.58 .48425 Mdot
.58 .48435 Mdot
.58 .48448 Mdot
.58 .4845 Mdot
.58 .48491 Mdot
.58 .48539 Mdot
.58 .48557 Mdot
.58 .48571 Mdot
.58 .48575 Mdot
.58 .48725 Mdot
.58 .48752 Mdot
.58 .48753 Mdot
.58 .48823 Mdot
.58 .48857 Mdot
.58 .48869 Mdot
.58 .48927 Mdot
.58 .49238 Mdot
.58 .49255 Mdot
.58 .49327 Mdot
.58 .49367 Mdot
.58 .49388 Mdot
.58 .494 Mdot
.58 .49446 Mdot
.58 .49471 Mdot
.58 .49605 Mdot
.58 .49703 Mdot
.58 .4979 Mdot
.58 .49792 Mdot
.58 .49802 Mdot
.58 .4984 Mdot
.58 .49854 Mdot
.58 .4993 Mdot
.58 .50014 Mdot
.58 .50039 Mdot
.58 .5009 Mdot
.58 .50171 Mdot
.58 .50179 Mdot
.58 .5018 Mdot
.58 .50181 Mdot
.58 .50182 Mdot
.58 .50187 Mdot
.58 .50206 Mdot
.58 .50222 Mdot
.58 .5023 Mdot
.58 .50231 Mdot
.58 .50236 Mdot
.58 .50237 Mdot
.58 .50241 Mdot
.58 .50258 Mdot
.58 .50271 Mdot
.58 .50286 Mdot
.58 .50295 Mdot
.58 .50301 Mdot
.58 .50313 Mdot
.58 .50317 Mdot
.58 .50421 Mdot
.58 .50424 Mdot
.58 .50449 Mdot
.58 .50455 Mdot
.58 .50482 Mdot
.58 .50514 Mdot
.58 .5052 Mdot
.58 .5052 Mdot
.58 .50529 Mdot
.58 .50541 Mdot
.58 .50575 Mdot
.58 .50621 Mdot
.58 .50623 Mdot
.58 .50628 Mdot
.58 .50661 Mdot
.58 .50662 Mdot
.58 .50672 Mdot
.58 .50685 Mdot
.58 .50708 Mdot
.58 .50739 Mdot
.58 .50745 Mdot
.58 .5075 Mdot
.58 .50827 Mdot
.58 .50834 Mdot
.58 .50838 Mdot
.58 .50885 Mdot
.58 .50903 Mdot
.58 .50913 Mdot
.58 .50938 Mdot
.58 .50982 Mdot
.58 .50993 Mdot
.58 .50997 Mdot
.58 .51013 Mdot
.58 .51081 Mdot
.58 .51097 Mdot
.58 .51157 Mdot
.58 .51172 Mdot
.58 .51234 Mdot
.58 .51253 Mdot
.58 .51307 Mdot
.58 .51375 Mdot
.58 .51381 Mdot
.58 .51382 Mdot
.58 .51411 Mdot
.58 .51412 Mdot
.58 .51489 Mdot
.58 .51491 Mdot
.58 .51502 Mdot
.58 .51524 Mdot
.58 .51571 Mdot
.58 .51674 Mdot
.58 .51699 Mdot
.58 .5173 Mdot
.58 .51738 Mdot
.58 .51788 Mdot
.58 .51828 Mdot
.58 .51831 Mdot
.58 .51866 Mdot
.58 .51885 Mdot
.58 .51897 Mdot
.58 .51898 Mdot
.58 .5196 Mdot
.58 .51961 Mdot
.58 .51972 Mdot
.58 .51981 Mdot
.58 .52026 Mdot
.58 .52081 Mdot
.58 .52093 Mdot
.58 .52097 Mdot
.58 .52099 Mdot
.58 .52102 Mdot
.58 .52185 Mdot
.58 .52192 Mdot
.58 .52207 Mdot
.58 .52305 Mdot
.58 .52307 Mdot
.58 .52317 Mdot
.58 .5235 Mdot
.58 .5237 Mdot
.58 .52388 Mdot
.58 .52402 Mdot
.58 .52434 Mdot
.58 .52466 Mdot
.58 .52478 Mdot
.58 .52518 Mdot
.58 .52524 Mdot
.58 .52541 Mdot
.58 .52581 Mdot
.58 .52582 Mdot
.58 .52583 Mdot
.58 .52616 Mdot
.58 .5265 Mdot
.58 .52653 Mdot
.58 .52711 Mdot
.58 .52717 Mdot
.58 .52733 Mdot
.58 .52736 Mdot
.58 .52803 Mdot
.58 .52814 Mdot
.58 .52832 Mdot
.58 .52859 Mdot
.58 .52903 Mdot
.58 .52905 Mdot
.58 .52912 Mdot
.58 .52916 Mdot
.58 .5292 Mdot
.58 .52923 Mdot
.58 .52962 Mdot
.58 .52991 Mdot
.58 .53035 Mdot
.58 .5312 Mdot
.58 .53141 Mdot
.58 .53187 Mdot
.58 .5323 Mdot
.58 .53275 Mdot
.58 .53289 Mdot
.58 .53365 Mdot
.58 .53371 Mdot
.58 .53378 Mdot
.58 .53387 Mdot
.58 .534 Mdot
.58 .53404 Mdot
.58 .53488 Mdot
.58 .53488 Mdot
.58 .53537 Mdot
.58 .53566 Mdot
.58 .5357 Mdot
.58 .5359 Mdot
.58 .53592 Mdot
.58 .53607 Mdot
.58 .53625 Mdot
.58 .53628 Mdot
.58 .53686 Mdot
.58 .53711 Mdot
.58 .53716 Mdot
.58 .53743 Mdot
.58 .53754 Mdot
.58 .53754 Mdot
.58 .5378 Mdot
.58 .53799 Mdot
.58 .53805 Mdot
.58 .53852 Mdot
.58 .53858 Mdot
.58 .53914 Mdot
.58 .53967 Mdot
.58 .53969 Mdot
.58 .53971 Mdot
.58 .54006 Mdot
.58 .54034 Mdot
.58 .54041 Mdot
.58 .54042 Mdot
.58 .54061 Mdot
.58 .54071 Mdot
.58 .5413 Mdot
.58 .54131 Mdot
.58 .54149 Mdot
.58 .54173 Mdot
.58 .54188 Mdot
.58 .54196 Mdot
.58 .54243 Mdot
.58 .54258 Mdot
.58 .54262 Mdot
.58 .54287 Mdot
.58 .54315 Mdot
.58 .5436 Mdot
.58 .54373 Mdot
.58 .54376 Mdot
.58 .54503 Mdot
.58 .54522 Mdot
.58 .54531 Mdot
.58 .546 Mdot
.58 .54618 Mdot
.58 .54629 Mdot
.58 .54632 Mdot
.58 .54635 Mdot
.58 .54639 Mdot
.58 .54653 Mdot
.58 .54688 Mdot
.58 .54713 Mdot
.58 .54726 Mdot
.58 .54745 Mdot
.58 .54756 Mdot
.58 .5476 Mdot
.58 .5477 Mdot
.58 .54782 Mdot
.58 .54782 Mdot
.58 .54797 Mdot
.58 .5482 Mdot
.58 .54844 Mdot
.58 .54845 Mdot
.58 .54856 Mdot
.58 .54874 Mdot
.58 .54906 Mdot
.58 .54909 Mdot
.58 .5493 Mdot
.58 .54944 Mdot
.58 .54987 Mdot
.58 .54993 Mdot
.58 .55004 Mdot
.58 .55018 Mdot
.58 .55037 Mdot
.58 .55065 Mdot
.58 .55066 Mdot
.58 .55073 Mdot
.58 .55098 Mdot
.58 .55106 Mdot
.58 .55111 Mdot
.58 .55142 Mdot
.58 .55152 Mdot
.58 .55155 Mdot
.58 .55162 Mdot
.58 .55164 Mdot
.58 .55197 Mdot
.58 .55208 Mdot
.58 .55208 Mdot
.58 .5521 Mdot
.58 .55224 Mdot
.58 .55224 Mdot
.58 .55227 Mdot
.58 .55235 Mdot
.58 .5526 Mdot
.58 .5527 Mdot
.58 .55274 Mdot
.58 .55274 Mdot
.58 .55274 Mdot
.58 .55275 Mdot
.58 .55277 Mdot
.58 .55283 Mdot
.58 .55284 Mdot
.58 .5529 Mdot
.58 .55291 Mdot
.58 .55293 Mdot
.58 .55294 Mdot
.58 .55295 Mdot
.58 .55296 Mdot
.58 .55297 Mdot
.58 .55303 Mdot
.58 .55308 Mdot
.58 .55313 Mdot
.58 .55313 Mdot
.58 .55316 Mdot
.58 .55318 Mdot
.58 .55319 Mdot
.58 .55321 Mdot
.58 .55323 Mdot
.58 .55337 Mdot
.58 .55341 Mdot
.58 .55351 Mdot
.58 .55352 Mdot
.58 .55357 Mdot
.58 .55358 Mdot
.58 .55358 Mdot
.58 .55361 Mdot
.58 .55362 Mdot
.58 .55364 Mdot
.58 .55364 Mdot
.58 .55369 Mdot
.58 .5537 Mdot
.58 .5537 Mdot
.58 .55372 Mdot
.58 .55372 Mdot
.58 .55373 Mdot
.58 .55375 Mdot
.58 .55377 Mdot
.58 .55378 Mdot
.58 .55379 Mdot
.58 .55383 Mdot
.58 .55383 Mdot
.58 .55383 Mdot
.58 .55384 Mdot
.58 .55384 Mdot
.58 .55384 Mdot
.58 .55386 Mdot
.58 .55386 Mdot
.58 .55386 Mdot
.58 .55387 Mdot
.58 .55387 Mdot
.58 .55388 Mdot
.58 .55388 Mdot
.58 .55388 Mdot
.582 .18001 Mdot
.582 .18002 Mdot
.582 .18003 Mdot
.582 .18003 Mdot
.582 .18005 Mdot
.582 .18007 Mdot
.582 .18008 Mdot
.582 .18008 Mdot
.582 .18017 Mdot
.582 .18018 Mdot
.582 .18022 Mdot
.582 .18024 Mdot
.582 .18025 Mdot
.582 .18025 Mdot
.582 .18028 Mdot
.582 .18036 Mdot
.582 .18036 Mdot
.582 .18037 Mdot
.582 .18052 Mdot
.582 .18052 Mdot
.582 .18056 Mdot
.582 .1807 Mdot
.582 .18074 Mdot
.582 .18078 Mdot
.582 .1808 Mdot
.582 .18085 Mdot
.582 .18088 Mdot
.582 .18093 Mdot
.582 .18112 Mdot
.582 .18121 Mdot
.582 .18121 Mdot
.582 .18123 Mdot
.582 .18124 Mdot
.582 .18125 Mdot
.582 .18141 Mdot
.582 .18153 Mdot
.582 .18154 Mdot
.582 .18168 Mdot
.582 .18181 Mdot
.582 .18182 Mdot
.582 .18194 Mdot
.582 .18201 Mdot
.582 .18202 Mdot
.582 .18217 Mdot
.582 .18236 Mdot
.582 .18238 Mdot
.582 .1824 Mdot
.582 .1827 Mdot
.582 .18344 Mdot
.582 .18363 Mdot
.582 .18377 Mdot
.582 .18383 Mdot
.582 .18387 Mdot
.582 .18388 Mdot
.582 .18389 Mdot
.582 .18443 Mdot
.582 .18508 Mdot
.582 .18516 Mdot
.582 .18528 Mdot
.582 .18558 Mdot
.582 .18591 Mdot
.582 .18595 Mdot
.582 .18611 Mdot
.582 .18612 Mdot
.582 .18628 Mdot
.582 .18644 Mdot
.582 .18723 Mdot
.582 .1874 Mdot
.582 .18756 Mdot
.582 .18786 Mdot
.582 .188 Mdot
.582 .18805 Mdot
.582 .18815 Mdot
.582 .1885 Mdot
.582 .18853 Mdot
.582 .18878 Mdot
.582 .18882 Mdot
.582 .18918 Mdot
.582 .18927 Mdot
.582 .18932 Mdot
.582 .19028 Mdot
.582 .19049 Mdot
.582 .19078 Mdot
.582 .19113 Mdot
.582 .19125 Mdot
.582 .19141 Mdot
.582 .19184 Mdot
.582 .19226 Mdot
.582 .19226 Mdot
.582 .19229 Mdot
.582 .19236 Mdot
.582 .19263 Mdot
.582 .19264 Mdot
.582 .19267 Mdot
.582 .19268 Mdot
.582 .19285 Mdot
.582 .19297 Mdot
.582 .19381 Mdot
.582 .19397 Mdot
.582 .19406 Mdot
.582 .19543 Mdot
.582 .19545 Mdot
.582 .19575 Mdot
.582 .19582 Mdot
.582 .19627 Mdot
.582 .19668 Mdot
.582 .19675 Mdot
.582 .19682 Mdot
.582 .19713 Mdot
.582 .1984 Mdot
.582 .19872 Mdot
.582 .19959 Mdot
.582 .19994 Mdot
.582 .2005 Mdot
.582 .20075 Mdot
.582 .20122 Mdot
.582 .20143 Mdot
.582 .20302 Mdot
.582 .20412 Mdot
.582 .20443 Mdot
.582 .20471 Mdot
.582 .2049 Mdot
.582 .20542 Mdot
.582 .20807 Mdot
.582 .20837 Mdot
.582 .2093 Mdot
.582 .21429 Mdot
.582 .21588 Mdot
.582 .21638 Mdot
.582 .21845 Mdot
.582 .21867 Mdot
.582 .22078 Mdot
.582 .22117 Mdot
.582 .22131 Mdot
.582 .2217 Mdot
.582 .22371 Mdot
.582 .22469 Mdot
.582 .22531 Mdot
.582 .22581 Mdot
.582 .22611 Mdot
.582 .22612 Mdot
.582 .22664 Mdot
.582 .22666 Mdot
.582 .22768 Mdot
.582 .2306 Mdot
.582 .23074 Mdot
.582 .23143 Mdot
.582 .23248 Mdot
.582 .23304 Mdot
.582 .23357 Mdot
.582 .23358 Mdot
.582 .2337 Mdot
.582 .2341 Mdot
.582 .23478 Mdot
.582 .23521 Mdot
.582 .23548 Mdot
.582 .23564 Mdot
.582 .24002 Mdot
.582 .24261 Mdot
.582 .24283 Mdot
.582 .24383 Mdot
.582 .24439 Mdot
.582 .24464 Mdot
.582 .24668 Mdot
.582 .2471 Mdot
.582 .24816 Mdot
.582 .24934 Mdot
.582 .25023 Mdot
.582 .25162 Mdot
.582 .25384 Mdot
.582 .25393 Mdot
.582 .25407 Mdot
.582 .25429 Mdot
.582 .25465 Mdot
.582 .25492 Mdot
.582 .2552 Mdot
.582 .25606 Mdot
.582 .25643 Mdot
.582 .25866 Mdot
.582 .25867 Mdot
.582 .25914 Mdot
.582 .25942 Mdot
.582 .2615 Mdot
.582 .26503 Mdot
.582 .27001 Mdot
.582 .27214 Mdot
.582 .27266 Mdot
.582 .27311 Mdot
.582 .27537 Mdot
.582 .27575 Mdot
.582 .27595 Mdot
.582 .27641 Mdot
.582 .27671 Mdot
.582 .27744 Mdot
.582 .27911 Mdot
.582 .27918 Mdot
.582 .27961 Mdot
.582 .28008 Mdot
.582 .28037 Mdot
.582 .28039 Mdot
.582 .2817 Mdot
.582 .28178 Mdot
.582 .28195 Mdot
.582 .28279 Mdot
.582 .28309 Mdot
.582 .28313 Mdot
.582 .28352 Mdot
.582 .28569 Mdot
.582 .28742 Mdot
.582 .28747 Mdot
.582 .28778 Mdot
.582 .29059 Mdot
.582 .29082 Mdot
.582 .29187 Mdot
.582 .29233 Mdot
.582 .29253 Mdot
.582 .29374 Mdot
.582 .29475 Mdot
.582 .29493 Mdot
.582 .2952 Mdot
.582 .2978 Mdot
.582 .29784 Mdot
.582 .29789 Mdot
.582 .29924 Mdot
.582 .29926 Mdot
.582 .30005 Mdot
.582 .30006 Mdot
.582 .30092 Mdot
.582 .30095 Mdot
.582 .301 Mdot
.582 .30136 Mdot
.582 .30223 Mdot
.582 .30237 Mdot
.582 .30255 Mdot
.582 .30266 Mdot
.582 .30299 Mdot
.582 .30363 Mdot
.582 .30472 Mdot
.582 .30524 Mdot
.582 .30543 Mdot
.582 .30549 Mdot
.582 .30555 Mdot
.582 .30706 Mdot
.582 .30724 Mdot
.582 .30757 Mdot
.582 .30799 Mdot
.582 .30802 Mdot
.582 .30873 Mdot
.582 .30992 Mdot
.582 .3109 Mdot
.582 .31195 Mdot
.582 .31202 Mdot
.582 .31233 Mdot
.582 .31332 Mdot
.582 .31339 Mdot
.582 .31421 Mdot
.582 .31421 Mdot
.582 .31522 Mdot
.582 .31597 Mdot
.582 .31696 Mdot
.582 .31697 Mdot
.582 .31761 Mdot
.582 .3184 Mdot
.582 .31909 Mdot
.582 .31928 Mdot
.582 .31931 Mdot
.582 .31968 Mdot
.582 .32092 Mdot
.582 .32247 Mdot
.582 .32322 Mdot
.582 .32331 Mdot
.582 .32332 Mdot
.582 .32538 Mdot
.582 .32667 Mdot
.582 .32673 Mdot
.582 .32696 Mdot
.582 .32698 Mdot
.582 .32855 Mdot
.582 .32879 Mdot
.582 .32899 Mdot
.582 .3294 Mdot
.582 .32957 Mdot
.582 .32964 Mdot
.582 .32976 Mdot
.582 .33022 Mdot
.582 .33105 Mdot
.582 .33115 Mdot
.582 .33122 Mdot
.582 .33257 Mdot
.582 .33291 Mdot
.582 .33329 Mdot
.582 .33342 Mdot
.582 .3336 Mdot
.582 .33406 Mdot
.582 .3345 Mdot
.582 .33454 Mdot
.582 .33461 Mdot
.582 .33489 Mdot
.582 .33493 Mdot
.582 .33512 Mdot
.582 .33801 Mdot
.582 .3388 Mdot
.582 .3392 Mdot
.582 .34032 Mdot
.582 .34283 Mdot
.582 .34408 Mdot
.582 .34516 Mdot
.582 .34551 Mdot
.582 .3478 Mdot
.582 .34867 Mdot
.582 .35199 Mdot
.582 .35331 Mdot
.582 .35459 Mdot
.582 .35472 Mdot
.582 .35599 Mdot
.582 .35622 Mdot
.582 .3563 Mdot
.582 .3577 Mdot
.582 .35826 Mdot
.582 .35906 Mdot
.582 .35907 Mdot
.582 .35994 Mdot
.582 .36153 Mdot
.582 .36253 Mdot
.582 .36312 Mdot
.582 .36318 Mdot
.582 .3677 Mdot
.582 .3683 Mdot
.582 .36857 Mdot
.582 .36967 Mdot
.582 .37038 Mdot
.582 .372 Mdot
.582 .37302 Mdot
.582 .37306 Mdot
.582 .37313 Mdot
.582 .37323 Mdot
.582 .37352 Mdot
.582 .37403 Mdot
.582 .37521 Mdot
.582 .37554 Mdot
.582 .37647 Mdot
.582 .37677 Mdot
.582 .38015 Mdot
.582 .38104 Mdot
.582 .38127 Mdot
.582 .38145 Mdot
.582 .38264 Mdot
.582 .38295 Mdot
.582 .38396 Mdot
.582 .38414 Mdot
.582 .38503 Mdot
.582 .38509 Mdot
.582 .38543 Mdot
.582 .38557 Mdot
.582 .38573 Mdot
.582 .38731 Mdot
.582 .38854 Mdot
.582 .38864 Mdot
.582 .38905 Mdot
.582 .38923 Mdot
.582 .38931 Mdot
.582 .38978 Mdot
.582 .39017 Mdot
.582 .39024 Mdot
.582 .39136 Mdot
.582 .39222 Mdot
.582 .39256 Mdot
.582 .39257 Mdot
.582 .39259 Mdot
.582 .39306 Mdot
.582 .39311 Mdot
.582 .39318 Mdot
.582 .39322 Mdot
.582 .39359 Mdot
.582 .394 Mdot
.582 .3942 Mdot
.582 .39427 Mdot
.582 .39429 Mdot
.582 .39489 Mdot
.582 .39496 Mdot
.582 .39508 Mdot
.582 .39524 Mdot
.582 .39525 Mdot
.582 .39551 Mdot
.582 .39596 Mdot
.582 .39675 Mdot
.582 .39723 Mdot
.582 .39756 Mdot
.582 .39756 Mdot
.582 .39793 Mdot
.582 .39821 Mdot
.582 .39858 Mdot
.582 .39858 Mdot
.582 .39881 Mdot
.582 .39911 Mdot
.582 .39943 Mdot
.582 .39944 Mdot
.582 .40003 Mdot
.582 .4006 Mdot
.582 .40087 Mdot
.582 .4009 Mdot
.582 .40091 Mdot
.582 .40213 Mdot
.582 .40223 Mdot
.582 .40224 Mdot
.582 .40281 Mdot
.582 .40289 Mdot
.582 .40296 Mdot
.582 .40311 Mdot
.582 .40318 Mdot
.582 .4032 Mdot
.582 .40324 Mdot
.582 .40341 Mdot
.582 .40371 Mdot
.582 .40377 Mdot
.582 .40425 Mdot
.582 .40437 Mdot
.582 .40451 Mdot
.582 .40456 Mdot
.582 .40462 Mdot
.582 .40479 Mdot
.582 .40495 Mdot
.582 .40496 Mdot
.582 .40498 Mdot
.582 .40508 Mdot
.582 .4051 Mdot
.582 .40517 Mdot
.582 .4062 Mdot
.582 .40648 Mdot
.582 .40662 Mdot
.582 .40702 Mdot
.582 .40791 Mdot
.582 .40835 Mdot
.582 .40886 Mdot
.582 .41113 Mdot
.582 .41159 Mdot
.582 .41204 Mdot
.582 .41209 Mdot
.582 .41253 Mdot
.582 .41264 Mdot
.582 .41361 Mdot
.582 .41446 Mdot
.582 .41481 Mdot
.582 .41503 Mdot
.582 .4169 Mdot
.582 .41846 Mdot
.582 .41848 Mdot
.582 .41851 Mdot
.582 .41861 Mdot
.582 .41879 Mdot
.582 .4192 Mdot
.582 .41974 Mdot
.582 .42187 Mdot
.582 .42272 Mdot
.582 .42277 Mdot
.582 .42283 Mdot
.582 .42337 Mdot
.582 .42379 Mdot
.582 .42383 Mdot
.582 .42403 Mdot
.582 .42436 Mdot
.582 .42438 Mdot
.582 .42476 Mdot
.582 .42518 Mdot
.582 .42519 Mdot
.582 .42553 Mdot
.582 .42598 Mdot
.582 .426 Mdot
.582 .42605 Mdot
.582 .4261 Mdot
.582 .42611 Mdot
.582 .42635 Mdot
.582 .4269 Mdot
.582 .42703 Mdot
.582 .42713 Mdot
.582 .42725 Mdot
.582 .42733 Mdot
.582 .42744 Mdot
.582 .42755 Mdot
.582 .42795 Mdot
.582 .42804 Mdot
.582 .42806 Mdot
.582 .42806 Mdot
.582 .42848 Mdot
.582 .42851 Mdot
.582 .42852 Mdot
.582 .42874 Mdot
.582 .42882 Mdot
.582 .42884 Mdot
.582 .42886 Mdot
.582 .42892 Mdot
.582 .42902 Mdot
.582 .42904 Mdot
.582 .4293 Mdot
.582 .42932 Mdot
.582 .42934 Mdot
.582 .4294 Mdot
.582 .42945 Mdot
.582 .42946 Mdot
.582 .42947 Mdot
.582 .4295 Mdot
.582 .45047 Mdot
.582 .45049 Mdot
.582 .4505 Mdot
.582 .4505 Mdot
.582 .45053 Mdot
.582 .45056 Mdot
.582 .45058 Mdot
.582 .45058 Mdot
.582 .45073 Mdot
.582 .45074 Mdot
.582 .4508 Mdot
.582 .45083 Mdot
.582 .45085 Mdot
.582 .45086 Mdot
.582 .4509 Mdot
.582 .45103 Mdot
.582 .45103 Mdot
.582 .45105 Mdot
.582 .45129 Mdot
.582 .45129 Mdot
.582 .45135 Mdot
.582 .45157 Mdot
.582 .45164 Mdot
.582 .4517 Mdot
.582 .45174 Mdot
.582 .45181 Mdot
.582 .45187 Mdot
.582 .45194 Mdot
.582 .45225 Mdot
.582 .45239 Mdot
.582 .45239 Mdot
.582 .45242 Mdot
.582 .45244 Mdot
.582 .45246 Mdot
.582 .45271 Mdot
.582 .4529 Mdot
.582 .4529 Mdot
.582 .45313 Mdot
.582 .45335 Mdot
.582 .45336 Mdot
.582 .45354 Mdot
.582 .45366 Mdot
.582 .45367 Mdot
.582 .45391 Mdot
.582 .45421 Mdot
.582 .45424 Mdot
.582 .45427 Mdot
.582 .45474 Mdot
.582 .45591 Mdot
.582 .4562 Mdot
.582 .45642 Mdot
.582 .45652 Mdot
.582 .45658 Mdot
.582 .45659 Mdot
.582 .45661 Mdot
.582 .45745 Mdot
.582 .45846 Mdot
.582 .45858 Mdot
.582 .45876 Mdot
.582 .45922 Mdot
.582 .45974 Mdot
.582 .4598 Mdot
.582 .46003 Mdot
.582 .46006 Mdot
.582 .46029 Mdot
.582 .46054 Mdot
.582 .46174 Mdot
.582 .46201 Mdot
.582 .46224 Mdot
.582 .4627 Mdot
.582 .46291 Mdot
.582 .46299 Mdot
.582 .46313 Mdot
.582 .46367 Mdot
.582 .4637 Mdot
.582 .46371 Mdot
.582 .46376 Mdot
.582 .46378 Mdot
.582 .46378 Mdot
.582 .46386 Mdot
.582 .46395 Mdot
.582 .46398 Mdot
.582 .46401 Mdot
.582 .46408 Mdot
.582 .46414 Mdot
.582 .46439 Mdot
.582 .46442 Mdot
.582 .46458 Mdot
.582 .46466 Mdot
.582 .46469 Mdot
.582 .4647 Mdot
.582 .46473 Mdot
.582 .46481 Mdot
.582 .46484 Mdot
.582 .46489 Mdot
.582 .46518 Mdot
.582 .46518 Mdot
.582 .46524 Mdot
.582 .46586 Mdot
.582 .46587 Mdot
.582 .46588 Mdot
.582 .46602 Mdot
.582 .46631 Mdot
.582 .46661 Mdot
.582 .46662 Mdot
.582 .46678 Mdot
.582 .46693 Mdot
.582 .46705 Mdot
.582 .46705 Mdot
.582 .46724 Mdot
.582 .46738 Mdot
.582 .46757 Mdot
.582 .46757 Mdot
.582 .46774 Mdot
.582 .46798 Mdot
.582 .46837 Mdot
.582 .4686 Mdot
.582 .46873 Mdot
.582 .46874 Mdot
.582 .46882 Mdot
.582 .46888 Mdot
.582 .46892 Mdot
.582 .46921 Mdot
.582 .46922 Mdot
.582 .46926 Mdot
.582 .46936 Mdot
.582 .46956 Mdot
.582 .46975 Mdot
.582 .46977 Mdot
.582 .46981 Mdot
.582 .46983 Mdot
.582 .47007 Mdot
.582 .47008 Mdot
.582 .47008 Mdot
.582 .47025 Mdot
.582 .47068 Mdot
.582 .47123 Mdot
.582 .47126 Mdot
.582 .47146 Mdot
.582 .47169 Mdot
.582 .47173 Mdot
.582 .47182 Mdot
.582 .47202 Mdot
.582 .47207 Mdot
.582 .47267 Mdot
.582 .47345 Mdot
.582 .47353 Mdot
.582 .47359 Mdot
.582 .47376 Mdot
.582 .47379 Mdot
.582 .47422 Mdot
.582 .47431 Mdot
.582 .4748 Mdot
.582 .47495 Mdot
.582 .47553 Mdot
.582 .47561 Mdot
.582 .47572 Mdot
.582 .47615 Mdot
.582 .47777 Mdot
.582 .47791 Mdot
.582 .47835 Mdot
.582 .47851 Mdot
.582 .47906 Mdot
.582 .47931 Mdot
.582 .47944 Mdot
.582 .47949 Mdot
.582 .47952 Mdot
.582 .47954 Mdot
.582 .48002 Mdot
.582 .48078 Mdot
.582 .48111 Mdot
.582 .48163 Mdot
.582 .48175 Mdot
.582 .48203 Mdot
.582 .48411 Mdot
.582 .48414 Mdot
.582 .48441 Mdot
.582 .48487 Mdot
.582 .48559 Mdot
.582 .48599 Mdot
.582 .48599 Mdot
.582 .48636 Mdot
.582 .48661 Mdot
.582 .48724 Mdot
.582 .48728 Mdot
.582 .48738 Mdot
.582 .48795 Mdot
.582 .48801 Mdot
.582 .48858 Mdot
.582 .48917 Mdot
.582 .49065 Mdot
.582 .49103 Mdot
.582 .49204 Mdot
.582 .49219 Mdot
.582 .49266 Mdot
.582 .49321 Mdot
.582 .4943 Mdot
.582 .49478 Mdot
.582 .49496 Mdot
.582 .4953 Mdot
.582 .49654 Mdot
.582 .49662 Mdot
.582 .49664 Mdot
.582 .49676 Mdot
.582 .49679 Mdot
.582 .4968 Mdot
.582 .49699 Mdot
.582 .49719 Mdot
.582 .49727 Mdot
.582 .49732 Mdot
.582 .49748 Mdot
.582 .49763 Mdot
.582 .4982 Mdot
.582 .49823 Mdot
.582 .49827 Mdot
.582 .49863 Mdot
.582 .49882 Mdot
.582 .49887 Mdot
.582 .4989 Mdot
.582 .49897 Mdot
.582 .49915 Mdot
.582 .49923 Mdot
.582 .49933 Mdot
.582 .49999 Mdot
.582 .5 Mdot
.582 .5001 Mdot
.582 .50012 Mdot
.582 .50066 Mdot
.582 .50152 Mdot
.582 .50153 Mdot
.582 .50157 Mdot
.582 .50188 Mdot
.582 .50252 Mdot
.582 .50304 Mdot
.582 .50319 Mdot
.582 .5032 Mdot
.582 .50328 Mdot
.582 .50357 Mdot
.582 .50389 Mdot
.582 .50416 Mdot
.582 .50416 Mdot
.582 .50456 Mdot
.582 .50487 Mdot
.582 .50529 Mdot
.582 .50529 Mdot
.582 .50562 Mdot
.582 .50565 Mdot
.582 .50606 Mdot
.582 .50618 Mdot
.582 .50621 Mdot
.582 .50664 Mdot
.582 .50703 Mdot
.582 .50752 Mdot
.582 .5078 Mdot
.582 .50782 Mdot
.582 .50798 Mdot
.582 .50812 Mdot
.582 .50819 Mdot
.582 .5088 Mdot
.582 .50882 Mdot
.582 .50885 Mdot
.582 .50892 Mdot
.582 .50913 Mdot
.582 .50957 Mdot
.582 .50983 Mdot
.582 .50996 Mdot
.582 .51 Mdot
.582 .51007 Mdot
.582 .51013 Mdot
.582 .51048 Mdot
.582 .51062 Mdot
.582 .51064 Mdot
.582 .51065 Mdot
.582 .51099 Mdot
.582 .511 Mdot
.582 .51131 Mdot
.582 .51132 Mdot
.582 .51186 Mdot
.582 .51187 Mdot
.582 .51189 Mdot
.582 .51292 Mdot
.582 .51302 Mdot
.582 .51309 Mdot
.582 .51349 Mdot
.582 .51396 Mdot
.582 .51404 Mdot
.582 .51422 Mdot
.582 .51463 Mdot
.582 .51472 Mdot
.582 .51582 Mdot
.582 .51594 Mdot
.582 .51595 Mdot
.582 .51663 Mdot
.582 .51746 Mdot
.582 .51762 Mdot
.582 .51763 Mdot
.582 .51775 Mdot
.582 .51807 Mdot
.582 .51813 Mdot
.582 .51817 Mdot
.582 .51867 Mdot
.582 .51867 Mdot
.582 .51878 Mdot
.582 .51897 Mdot
.582 .51913 Mdot
.582 .51916 Mdot
.582 .51979 Mdot
.582 .52007 Mdot
.582 .52018 Mdot
.582 .52036 Mdot
.582 .52043 Mdot
.582 .52058 Mdot
.582 .52144 Mdot
.582 .5216 Mdot
.582 .5218 Mdot
.582 .5226 Mdot
.582 .52447 Mdot
.582 .52578 Mdot
.582 .52655 Mdot
.582 .52665 Mdot
.582 .52682 Mdot
.582 .52683 Mdot
.582 .52765 Mdot
.582 .52779 Mdot
.582 .5281 Mdot
.582 .5282 Mdot
.582 .5283 Mdot
.582 .52843 Mdot
.582 .52851 Mdot
.582 .52857 Mdot
.582 .5286 Mdot
.582 .52941 Mdot
.582 .52992 Mdot
.582 .53024 Mdot
.582 .53066 Mdot
.582 .53105 Mdot
.582 .5312 Mdot
.582 .53194 Mdot
.582 .53203 Mdot
.582 .53223 Mdot
.582 .53259 Mdot
.582 .53267 Mdot
.582 .53359 Mdot
.582 .53516 Mdot
.582 .53521 Mdot
.582 .53531 Mdot
.582 .53546 Mdot
.582 .5357 Mdot
.582 .53584 Mdot
.582 .53588 Mdot
.582 .53589 Mdot
.582 .53608 Mdot
.582 .53627 Mdot
.582 .53664 Mdot
.582 .53689 Mdot
.582 .53694 Mdot
.582 .53796 Mdot
.582 .53832 Mdot
.582 .53833 Mdot
.582 .53851 Mdot
.582 .53851 Mdot
.582 .53862 Mdot
.582 .53879 Mdot
.582 .53901 Mdot
.582 .53935 Mdot
.582 .54005 Mdot
.582 .54019 Mdot
.582 .54023 Mdot
.582 .54037 Mdot
.582 .5411 Mdot
.582 .54118 Mdot
.582 .54189 Mdot
.582 .54206 Mdot
.582 .54261 Mdot
.582 .54432 Mdot
.582 .54464 Mdot
.582 .54474 Mdot
.582 .54564 Mdot
.582 .54582 Mdot
.582 .54588 Mdot
.582 .54598 Mdot
.582 .54608 Mdot
.582 .54645 Mdot
.582 .54699 Mdot
.582 .54706 Mdot
.582 .54722 Mdot
.582 .5473 Mdot
.582 .54749 Mdot
.582 .54761 Mdot
.582 .5479 Mdot
.582 .54801 Mdot
.582 .54844 Mdot
.582 .54854 Mdot
.582 .54857 Mdot
.582 .54859 Mdot
.582 .54872 Mdot
.582 .54888 Mdot
.582 .5489 Mdot
.582 .549 Mdot
.582 .54901 Mdot
.582 .54946 Mdot
.582 .54949 Mdot
.582 .54955 Mdot
.582 .54983 Mdot
.582 .54987 Mdot
.582 .54992 Mdot
.582 .54993 Mdot
.582 .54994 Mdot
.582 .54994 Mdot
.582 .55003 Mdot
.582 .55006 Mdot
.582 .55006 Mdot
.582 .55007 Mdot
.582 .55021 Mdot
.582 .55035 Mdot
.582 .5504 Mdot
.582 .55044 Mdot
.582 .55056 Mdot
.582 .55066 Mdot
.582 .55072 Mdot
.582 .55104 Mdot
.582 .55106 Mdot
.582 .55109 Mdot
.582 .55121 Mdot
.582 .55122 Mdot
.582 .5513 Mdot
.582 .55131 Mdot
.582 .55143 Mdot
.582 .55146 Mdot
.582 .55148 Mdot
.582 .55153 Mdot
.582 .55163 Mdot
.582 .55168 Mdot
.582 .55174 Mdot
.582 .552 Mdot
.582 .55205 Mdot
.582 .5521 Mdot
.582 .55211 Mdot
.582 .55216 Mdot
.582 .55217 Mdot
.582 .55228 Mdot
.582 .55238 Mdot
.582 .55242 Mdot
.582 .55244 Mdot
.582 .55266 Mdot
.582 .55284 Mdot
.582 .55284 Mdot
.582 .55284 Mdot
.582 .55286 Mdot
.582 .55288 Mdot
.582 .55292 Mdot
.582 .55299 Mdot
.582 .55323 Mdot
.582 .55333 Mdot
.582 .55333 Mdot
.582 .55334 Mdot
.582 .5534 Mdot
.582 .55345 Mdot
.582 .55346 Mdot
.582 .55348 Mdot
.582 .55352 Mdot
.582 .55352 Mdot
.582 .55356 Mdot
.582 .55361 Mdot
.582 .55361 Mdot
.582 .55365 Mdot
.582 .5537 Mdot
.582 .55371 Mdot
.582 .55371 Mdot
.582 .55372 Mdot
.582 .55372 Mdot
.582 .55375 Mdot
.582 .55381 Mdot
.582 .55383 Mdot
.582 .55384 Mdot
.582 .55385 Mdot
.582 .55386 Mdot
.582 .55387 Mdot
.582 .55389 Mdot
.582 .55393 Mdot
.582 .55394 Mdot
.582 .55394 Mdot
.582 .55399 Mdot
.582 .554 Mdot
.582 .554 Mdot
.582 .55402 Mdot
.582 .55403 Mdot
.582 .55403 Mdot
.582 .55404 Mdot
.582 .55404 Mdot
.582 .55406 Mdot
.582 .55406 Mdot
.582 .55409 Mdot
.582 .55409 Mdot
.582 .55409 Mdot
.582 .5541 Mdot
.582 .55411 Mdot
.582 .55411 Mdot
.582 .55411 Mdot
.582 .55411 Mdot
.584 .17937 Mdot
.584 .17938 Mdot
.584 .17938 Mdot
.584 .17938 Mdot
.584 .17938 Mdot
.584 .17942 Mdot
.584 .17943 Mdot
.584 .17946 Mdot
.584 .17947 Mdot
.584 .17947 Mdot
.584 .17953 Mdot
.584 .17957 Mdot
.584 .17957 Mdot
.584 .17965 Mdot
.584 .17967 Mdot
.584 .1797 Mdot
.584 .17992 Mdot
.584 .17996 Mdot
.584 .17998 Mdot
.584 .18008 Mdot
.584 .18009 Mdot
.584 .18012 Mdot
.584 .18012 Mdot
.584 .18029 Mdot
.584 .18051 Mdot
.584 .18055 Mdot
.584 .18064 Mdot
.584 .18065 Mdot
.584 .18067 Mdot
.584 .18078 Mdot
.584 .18081 Mdot
.584 .18097 Mdot
.584 .18101 Mdot
.584 .18111 Mdot
.584 .18124 Mdot
.584 .18134 Mdot
.584 .18138 Mdot
.584 .18146 Mdot
.584 .18171 Mdot
.584 .18189 Mdot
.584 .18218 Mdot
.584 .18223 Mdot
.584 .18229 Mdot
.584 .18259 Mdot
.584 .18275 Mdot
.584 .18301 Mdot
.584 .18301 Mdot
.584 .18301 Mdot
.584 .18311 Mdot
.584 .18344 Mdot
.584 .18354 Mdot
.584 .18414 Mdot
.584 .18445 Mdot
.584 .18475 Mdot
.584 .185 Mdot
.584 .18517 Mdot
.584 .18545 Mdot
.584 .18648 Mdot
.584 .18731 Mdot
.584 .1878 Mdot
.584 .18797 Mdot
.584 .18826 Mdot
.584 .18845 Mdot
.584 .18857 Mdot
.584 .18864 Mdot
.584 .18922 Mdot
.584 .18945 Mdot
.584 .18966 Mdot
.584 .18981 Mdot
.584 .18991 Mdot
.584 .18991 Mdot
.584 .19033 Mdot
.584 .19036 Mdot
.584 .19061 Mdot
.584 .19062 Mdot
.584 .19062 Mdot
.584 .19086 Mdot
.584 .19098 Mdot
.584 .19113 Mdot
.584 .19125 Mdot
.584 .19136 Mdot
.584 .19153 Mdot
.584 .19178 Mdot
.584 .1918 Mdot
.584 .19196 Mdot
.584 .19249 Mdot
.584 .19326 Mdot
.584 .19327 Mdot
.584 .19388 Mdot
.584 .1948 Mdot
.584 .19502 Mdot
.584 .19504 Mdot
.584 .1958 Mdot
.584 .19722 Mdot
.584 .19737 Mdot
.584 .19808 Mdot
.584 .19867 Mdot
.584 .1987 Mdot
.584 .19911 Mdot
.584 .19924 Mdot
.584 .19928 Mdot
.584 .19944 Mdot
.584 .20004 Mdot
.584 .20075 Mdot
.584 .20101 Mdot
.584 .20104 Mdot
.584 .20214 Mdot
.584 .20225 Mdot
.584 .20312 Mdot
.584 .20387 Mdot
.584 .20394 Mdot
.584 .20438 Mdot
.584 .20473 Mdot
.584 .20516 Mdot
.584 .2052 Mdot
.584 .20541 Mdot
.584 .20665 Mdot
.584 .20668 Mdot
.584 .20676 Mdot
.584 .20678 Mdot
.584 .2068 Mdot
.584 .20697 Mdot
.584 .21023 Mdot
.584 .2104 Mdot
.584 .21046 Mdot
.584 .2105 Mdot
.584 .21063 Mdot
.584 .21176 Mdot
.584 .21184 Mdot
.584 .2129 Mdot
.584 .21335 Mdot
.584 .21367 Mdot
.584 .21373 Mdot
.584 .21382 Mdot
.584 .21419 Mdot
.584 .21432 Mdot
.584 .21623 Mdot
.584 .21938 Mdot
.584 .22014 Mdot
.584 .22115 Mdot
.584 .22136 Mdot
.584 .22293 Mdot
.584 .22349 Mdot
.584 .22372 Mdot
.584 .22524 Mdot
.584 .22588 Mdot
.584 .22612 Mdot
.584 .22647 Mdot
.584 .22722 Mdot
.584 .22733 Mdot
.584 .22753 Mdot
.584 .22791 Mdot
.584 .23012 Mdot
.584 .23105 Mdot
.584 .23137 Mdot
.584 .23168 Mdot
.584 .2319 Mdot
.584 .23279 Mdot
.584 .23303 Mdot
.584 .23347 Mdot
.584 .23549 Mdot
.584 .23676 Mdot
.584 .23691 Mdot
.584 .23738 Mdot
.584 .23851 Mdot
.584 .24006 Mdot
.584 .24181 Mdot
.584 .24291 Mdot
.584 .24381 Mdot
.584 .24396 Mdot
.584 .24557 Mdot
.584 .24593 Mdot
.584 .24727 Mdot
.584 .24847 Mdot
.584 .24993 Mdot
.584 .25133 Mdot
.584 .2521 Mdot
.584 .25364 Mdot
.584 .25469 Mdot
.584 .25492 Mdot
.584 .25563 Mdot
.584 .25579 Mdot
.584 .25596 Mdot
.584 .25798 Mdot
.584 .25804 Mdot
.584 .25846 Mdot
.584 .25865 Mdot
.584 .26 Mdot
.584 .26045 Mdot
.584 .26253 Mdot
.584 .26445 Mdot
.584 .26627 Mdot
.584 .26731 Mdot
.584 .26806 Mdot
.584 .26815 Mdot
.584 .26817 Mdot
.584 .26821 Mdot
.584 .26833 Mdot
.584 .27073 Mdot
.584 .27186 Mdot
.584 .2722 Mdot
.584 .27341 Mdot
.584 .27526 Mdot
.584 .27646 Mdot
.584 .27821 Mdot
.584 .28019 Mdot
.584 .28127 Mdot
.584 .28186 Mdot
.584 .28265 Mdot
.584 .28364 Mdot
.584 .28381 Mdot
.584 .28393 Mdot
.584 .28406 Mdot
.584 .28461 Mdot
.584 .2849 Mdot
.584 .2854 Mdot
.584 .2854 Mdot
.584 .28619 Mdot
.584 .28854 Mdot
.584 .29109 Mdot
.584 .29217 Mdot
.584 .29418 Mdot
.584 .29497 Mdot
.584 .29516 Mdot
.584 .29567 Mdot
.584 .29597 Mdot
.584 .29673 Mdot
.584 .29683 Mdot
.584 .29791 Mdot
.584 .29882 Mdot
.584 .29944 Mdot
.584 .30037 Mdot
.584 .30113 Mdot
.584 .30202 Mdot
.584 .30268 Mdot
.584 .30287 Mdot
.584 .30498 Mdot
.584 .30513 Mdot
.584 .30573 Mdot
.584 .30679 Mdot
.584 .30722 Mdot
.584 .30801 Mdot
.584 .30802 Mdot
.584 .30818 Mdot
.584 .3101 Mdot
.584 .31012 Mdot
.584 .31093 Mdot
.584 .3114 Mdot
.584 .31143 Mdot
.584 .31198 Mdot
.584 .3123 Mdot
.584 .31323 Mdot
.584 .31443 Mdot
.584 .31464 Mdot
.584 .31472 Mdot
.584 .3152 Mdot
.584 .31531 Mdot
.584 .31677 Mdot
.584 .31722 Mdot
.584 .31724 Mdot
.584 .31731 Mdot
.584 .31774 Mdot
.584 .31822 Mdot
.584 .31833 Mdot
.584 .31896 Mdot
.584 .31932 Mdot
.584 .31951 Mdot
.584 .32054 Mdot
.584 .32143 Mdot
.584 .32288 Mdot
.584 .32288 Mdot
.584 .32366 Mdot
.584 .32488 Mdot
.584 .32539 Mdot
.584 .32626 Mdot
.584 .32652 Mdot
.584 .32839 Mdot
.584 .33012 Mdot
.584 .33033 Mdot
.584 .3307 Mdot
.584 .33092 Mdot
.584 .33107 Mdot
.584 .33115 Mdot
.584 .33211 Mdot
.584 .33235 Mdot
.584 .33252 Mdot
.584 .33311 Mdot
.584 .33341 Mdot
.584 .33342 Mdot
.584 .33369 Mdot
.584 .33381 Mdot
.584 .33466 Mdot
.584 .33468 Mdot
.584 .33484 Mdot
.584 .33616 Mdot
.584 .33764 Mdot
.584 .33786 Mdot
.584 .33856 Mdot
.584 .33995 Mdot
.584 .34056 Mdot
.584 .34106 Mdot
.584 .34109 Mdot
.584 .34143 Mdot
.584 .34155 Mdot
.584 .34171 Mdot
.584 .3422 Mdot
.584 .34298 Mdot
.584 .343 Mdot
.584 .34387 Mdot
.584 .34395 Mdot
.584 .34519 Mdot
.584 .34524 Mdot
.584 .34557 Mdot
.584 .34614 Mdot
.584 .34633 Mdot
.584 .34723 Mdot
.584 .34725 Mdot
.584 .34732 Mdot
.584 .34733 Mdot
.584 .34745 Mdot
.584 .35078 Mdot
.584 .35147 Mdot
.584 .35196 Mdot
.584 .352 Mdot
.584 .35206 Mdot
.584 .3523 Mdot
.584 .35238 Mdot
.584 .35595 Mdot
.584 .35655 Mdot
.584 .35667 Mdot
.584 .3579 Mdot
.584 .35889 Mdot
.584 .35925 Mdot
.584 .36016 Mdot
.584 .36037 Mdot
.584 .36157 Mdot
.584 .36252 Mdot
.584 .36299 Mdot
.584 .36504 Mdot
.584 .36512 Mdot
.584 .36536 Mdot
.584 .36757 Mdot
.584 .36854 Mdot
.584 .36862 Mdot
.584 .36939 Mdot
.584 .3702 Mdot
.584 .37145 Mdot
.584 .37317 Mdot
.584 .37364 Mdot
.584 .37375 Mdot
.584 .37414 Mdot
.584 .37515 Mdot
.584 .37534 Mdot
.584 .37542 Mdot
.584 .37602 Mdot
.584 .37714 Mdot
.584 .37876 Mdot
.584 .3792 Mdot
.584 .37956 Mdot
.584 .37957 Mdot
.584 .37959 Mdot
.584 .37963 Mdot
.584 .38177 Mdot
.584 .38304 Mdot
.584 .38376 Mdot
.584 .38556 Mdot
.584 .38596 Mdot
.584 .38603 Mdot
.584 .38608 Mdot
.584 .38646 Mdot
.584 .38666 Mdot
.584 .38892 Mdot
.584 .38934 Mdot
.584 .39043 Mdot
.584 .39111 Mdot
.584 .39115 Mdot
.584 .39251 Mdot
.584 .39313 Mdot
.584 .39339 Mdot
.584 .39346 Mdot
.584 .39426 Mdot
.584 .39494 Mdot
.584 .3954 Mdot
.584 .3954 Mdot
.584 .39546 Mdot
.584 .39618 Mdot
.584 .39619 Mdot
.584 .39649 Mdot
.584 .39666 Mdot
.584 .397 Mdot
.584 .39734 Mdot
.584 .39779 Mdot
.584 .39787 Mdot
.584 .39807 Mdot
.584 .39811 Mdot
.584 .39882 Mdot
.584 .39882 Mdot
.584 .39885 Mdot
.584 .39901 Mdot
.584 .39918 Mdot
.584 .39922 Mdot
.584 .39946 Mdot
.584 .39958 Mdot
.584 .39966 Mdot
.584 .40003 Mdot
.584 .40036 Mdot
.584 .40088 Mdot
.584 .40088 Mdot
.584 .40117 Mdot
.584 .40161 Mdot
.584 .40211 Mdot
.584 .4022 Mdot
.584 .40288 Mdot
.584 .4035 Mdot
.584 .40358 Mdot
.584 .40379 Mdot
.584 .40387 Mdot
.584 .40457 Mdot
.584 .40469 Mdot
.584 .40478 Mdot
.584 .40482 Mdot
.584 .40513 Mdot
.584 .40519 Mdot
.584 .40566 Mdot
.584 .40652 Mdot
.584 .40699 Mdot
.584 .40701 Mdot
.584 .40723 Mdot
.584 .40741 Mdot
.584 .40808 Mdot
.584 .40809 Mdot
.584 .40839 Mdot
.584 .40842 Mdot
.584 .40886 Mdot
.584 .40888 Mdot
.584 .40899 Mdot
.584 .40919 Mdot
.584 .40926 Mdot
.584 .40957 Mdot
.584 .40958 Mdot
.584 .40961 Mdot
.584 .40961 Mdot
.584 .40965 Mdot
.584 .41082 Mdot
.584 .41377 Mdot
.584 .41458 Mdot
.584 .41507 Mdot
.584 .41581 Mdot
.584 .41666 Mdot
.584 .41756 Mdot
.584 .41927 Mdot
.584 .41957 Mdot
.584 .42051 Mdot
.584 .42079 Mdot
.584 .42079 Mdot
.584 .4208 Mdot
.584 .42155 Mdot
.584 .42199 Mdot
.584 .42285 Mdot
.584 .42303 Mdot
.584 .42316 Mdot
.584 .42401 Mdot
.584 .42453 Mdot
.584 .42524 Mdot
.584 .42546 Mdot
.584 .42557 Mdot
.584 .42584 Mdot
.584 .42623 Mdot
.584 .4265 Mdot
.584 .42661 Mdot
.584 .42708 Mdot
.584 .42715 Mdot
.584 .42748 Mdot
.584 .42754 Mdot
.584 .42755 Mdot
.584 .42783 Mdot
.584 .42794 Mdot
.584 .42855 Mdot
.584 .42903 Mdot
.584 .42905 Mdot
.584 .42913 Mdot
.584 .42915 Mdot
.584 .42943 Mdot
.584 .42948 Mdot
.584 .42961 Mdot
.584 .43023 Mdot
.584 .43031 Mdot
.584 .43038 Mdot
.584 .43061 Mdot
.584 .43061 Mdot
.584 .43071 Mdot
.584 .43088 Mdot
.584 .43088 Mdot
.584 .43092 Mdot
.584 .43099 Mdot
.584 .43101 Mdot
.584 .43112 Mdot
.584 .43113 Mdot
.584 .43113 Mdot
.584 .43114 Mdot
.584 .43115 Mdot
.584 .44964 Mdot
.584 .44964 Mdot
.584 .44964 Mdot
.584 .44965 Mdot
.584 .44965 Mdot
.584 .44971 Mdot
.584 .44973 Mdot
.584 .44977 Mdot
.584 .44979 Mdot
.584 .44979 Mdot
.584 .44988 Mdot
.584 .44994 Mdot
.584 .44995 Mdot
.584 .45008 Mdot
.584 .45011 Mdot
.584 .45016 Mdot
.584 .45051 Mdot
.584 .45058 Mdot
.584 .45061 Mdot
.584 .45077 Mdot
.584 .45079 Mdot
.584 .45083 Mdot
.584 .45084 Mdot
.584 .45111 Mdot
.584 .45145 Mdot
.584 .45152 Mdot
.584 .45167 Mdot
.584 .45168 Mdot
.584 .45172 Mdot
.584 .4519 Mdot
.584 .45194 Mdot
.584 .4522 Mdot
.584 .45226 Mdot
.584 .45241 Mdot
.584 .45263 Mdot
.584 .45279 Mdot
.584 .45285 Mdot
.584 .45297 Mdot
.584 .45337 Mdot
.584 .45366 Mdot
.584 .45412 Mdot
.584 .4542 Mdot
.584 .45429 Mdot
.584 .45477 Mdot
.584 .45501 Mdot
.584 .45542 Mdot
.584 .45543 Mdot
.584 .45543 Mdot
.584 .45558 Mdot
.584 .45609 Mdot
.584 .45626 Mdot
.584 .45719 Mdot
.584 .45768 Mdot
.584 .45813 Mdot
.584 .45853 Mdot
.584 .45879 Mdot
.584 .45923 Mdot
.584 .4608 Mdot
.584 .46141 Mdot
.584 .46143 Mdot
.584 .46144 Mdot
.584 .46145 Mdot
.584 .46145 Mdot
.584 .46162 Mdot
.584 .46165 Mdot
.584 .46176 Mdot
.584 .46182 Mdot
.584 .46183 Mdot
.584 .46206 Mdot
.584 .46207 Mdot
.584 .46223 Mdot
.584 .46224 Mdot
.584 .46259 Mdot
.584 .46268 Mdot
.584 .4628 Mdot
.584 .46281 Mdot
.584 .46305 Mdot
.584 .4635 Mdot
.584 .46374 Mdot
.584 .46378 Mdot
.584 .46393 Mdot
.584 .46396 Mdot
.584 .46401 Mdot
.584 .46406 Mdot
.584 .46443 Mdot
.584 .46447 Mdot
.584 .46458 Mdot
.584 .46462 Mdot
.584 .46494 Mdot
.584 .46528 Mdot
.584 .46533 Mdot
.584 .46559 Mdot
.584 .46581 Mdot
.584 .46596 Mdot
.584 .46596 Mdot
.584 .46623 Mdot
.584 .4664 Mdot
.584 .46659 Mdot
.584 .46662 Mdot
.584 .46681 Mdot
.584 .46683 Mdot
.584 .46692 Mdot
.584 .467 Mdot
.584 .46701 Mdot
.584 .46701 Mdot
.584 .46737 Mdot
.584 .46739 Mdot
.584 .4675 Mdot
.584 .46754 Mdot
.584 .46776 Mdot
.584 .46794 Mdot
.584 .4681 Mdot
.584 .46819 Mdot
.584 .46835 Mdot
.584 .46835 Mdot
.584 .46871 Mdot
.584 .46874 Mdot
.584 .46874 Mdot
.584 .46897 Mdot
.584 .46931 Mdot
.584 .46971 Mdot
.584 .46975 Mdot
.584 .46988 Mdot
.584 .47019 Mdot
.584 .47086 Mdot
.584 .47088 Mdot
.584 .47122 Mdot
.584 .47176 Mdot
.584 .47197 Mdot
.584 .47307 Mdot
.584 .47317 Mdot
.584 .47336 Mdot
.584 .47338 Mdot
.584 .47342 Mdot
.584 .47361 Mdot
.584 .47449 Mdot
.584 .47484 Mdot
.584 .47545 Mdot
.584 .47647 Mdot
.584 .4765 Mdot
.584 .47651 Mdot
.584 .47651 Mdot
.584 .47668 Mdot
.584 .4769 Mdot
.584 .47767 Mdot
.584 .4782 Mdot
.584 .47848 Mdot
.584 .47852 Mdot
.584 .47861 Mdot
.584 .47909 Mdot
.584 .47927 Mdot
.584 .47932 Mdot
.584 .47955 Mdot
.584 .48035 Mdot
.584 .48094 Mdot
.584 .48131 Mdot
.584 .48167 Mdot
.584 .48171 Mdot
.584 .48216 Mdot
.584 .48318 Mdot
.584 .48329 Mdot
.584 .48333 Mdot
.584 .48427 Mdot
.584 .48448 Mdot
.584 .48492 Mdot
.584 .48546 Mdot
.584 .48556 Mdot
.584 .48597 Mdot
.584 .48614 Mdot
.584 .48659 Mdot
.584 .48714 Mdot
.584 .4872 Mdot
.584 .48747 Mdot
.584 .48906 Mdot
.584 .4891 Mdot
.584 .48921 Mdot
.584 .48923 Mdot
.584 .48925 Mdot
.584 .48947 Mdot
.584 .48978 Mdot
.584 .49125 Mdot
.584 .4913 Mdot
.584 .49131 Mdot
.584 .49134 Mdot
.584 .49135 Mdot
.584 .49174 Mdot
.584 .49182 Mdot
.584 .49207 Mdot
.584 .49222 Mdot
.584 .49224 Mdot
.584 .49278 Mdot
.584 .49282 Mdot
.584 .4932 Mdot
.584 .4932 Mdot
.584 .49355 Mdot
.584 .49376 Mdot
.584 .49383 Mdot
.584 .49388 Mdot
.584 .49403 Mdot
.584 .49404 Mdot
.584 .49426 Mdot
.584 .49452 Mdot
.584 .49512 Mdot
.584 .49542 Mdot
.584 .49552 Mdot
.584 .49615 Mdot
.584 .49672 Mdot
.584 .49679 Mdot
.584 .4968 Mdot
.584 .49716 Mdot
.584 .49721 Mdot
.584 .49732 Mdot
.584 .49733 Mdot
.584 .49746 Mdot
.584 .49771 Mdot
.584 .49778 Mdot
.584 .49788 Mdot
.584 .49829 Mdot
.584 .49832 Mdot
.584 .49839 Mdot
.584 .49848 Mdot
.584 .49864 Mdot
.584 .49873 Mdot
.584 .49946 Mdot
.584 .50024 Mdot
.584 .50035 Mdot
.584 .50071 Mdot
.584 .50093 Mdot
.584 .50144 Mdot
.584 .50176 Mdot
.584 .50177 Mdot
.584 .50237 Mdot
.584 .50273 Mdot
.584 .50316 Mdot
.584 .50324 Mdot
.584 .50339 Mdot
.584 .50365 Mdot
.584 .50369 Mdot
.584 .50389 Mdot
.584 .50407 Mdot
.584 .5041 Mdot
.584 .5041 Mdot
.584 .50429 Mdot
.584 .50489 Mdot
.584 .50494 Mdot
.584 .50513 Mdot
.584 .50516 Mdot
.584 .50525 Mdot
.584 .50574 Mdot
.584 .50612 Mdot
.584 .50625 Mdot
.584 .50648 Mdot
.584 .50649 Mdot
.584 .50668 Mdot
.584 .50701 Mdot
.584 .50701 Mdot
.584 .50779 Mdot
.584 .50785 Mdot
.584 .50786 Mdot
.584 .50818 Mdot
.584 .50835 Mdot
.584 .50878 Mdot
.584 .50902 Mdot
.584 .50908 Mdot
.584 .50992 Mdot
.584 .51 Mdot
.584 .51026 Mdot
.584 .51062 Mdot
.584 .51092 Mdot
.584 .51129 Mdot
.584 .51154 Mdot
.584 .51189 Mdot
.584 .51232 Mdot
.584 .51236 Mdot
.584 .51266 Mdot
.584 .51278 Mdot
.584 .51298 Mdot
.584 .51305 Mdot
.584 .51336 Mdot
.584 .51415 Mdot
.584 .51457 Mdot
.584 .51557 Mdot
.584 .51648 Mdot
.584 .51678 Mdot
.584 .51678 Mdot
.584 .51698 Mdot
.584 .51709 Mdot
.584 .5173 Mdot
.584 .51735 Mdot
.584 .5174 Mdot
.584 .51746 Mdot
.584 .51785 Mdot
.584 .51815 Mdot
.584 .51837 Mdot
.584 .51879 Mdot
.584 .51954 Mdot
.584 .52021 Mdot
.584 .52066 Mdot
.584 .52137 Mdot
.584 .52182 Mdot
.584 .52195 Mdot
.584 .52238 Mdot
.584 .52328 Mdot
.584 .52332 Mdot
.584 .52333 Mdot
.584 .52334 Mdot
.584 .52338 Mdot
.584 .52366 Mdot
.584 .52405 Mdot
.584 .52472 Mdot
.584 .52544 Mdot
.584 .52621 Mdot
.584 .52637 Mdot
.584 .52687 Mdot
.584 .52694 Mdot
.584 .5271 Mdot
.584 .52712 Mdot
.584 .52786 Mdot
.584 .52792 Mdot
.584 .52798 Mdot
.584 .52824 Mdot
.584 .52833 Mdot
.584 .52871 Mdot
.584 .52927 Mdot
.584 .52955 Mdot
.584 .53006 Mdot
.584 .53059 Mdot
.584 .53103 Mdot
.584 .53151 Mdot
.584 .53164 Mdot
.584 .53222 Mdot
.584 .53227 Mdot
.584 .5326 Mdot
.584 .53299 Mdot
.584 .53361 Mdot
.584 .53417 Mdot
.584 .53457 Mdot
.584 .53474 Mdot
.584 .53479 Mdot
.584 .53524 Mdot
.584 .53596 Mdot
.584 .53611 Mdot
.584 .5362 Mdot
.584 .53651 Mdot
.584 .53659 Mdot
.584 .5367 Mdot
.584 .53681 Mdot
.584 .53714 Mdot
.584 .53792 Mdot
.584 .53805 Mdot
.584 .53812 Mdot
.584 .53816 Mdot
.584 .53842 Mdot
.584 .53854 Mdot
.584 .53863 Mdot
.584 .53885 Mdot
.584 .53938 Mdot
.584 .53946 Mdot
.584 .53965 Mdot
.584 .5402 Mdot
.584 .54027 Mdot
.584 .54062 Mdot
.584 .54089 Mdot
.584 .54197 Mdot
.584 .54263 Mdot
.584 .54268 Mdot
.584 .54281 Mdot
.584 .54283 Mdot
.584 .54286 Mdot
.584 .54296 Mdot
.584 .54312 Mdot
.584 .54348 Mdot
.584 .54351 Mdot
.584 .5439 Mdot
.584 .54394 Mdot
.584 .54395 Mdot
.584 .54397 Mdot
.584 .54403 Mdot
.584 .54514 Mdot
.584 .5452 Mdot
.584 .54521 Mdot
.584 .54521 Mdot
.584 .54524 Mdot
.584 .54525 Mdot
.584 .54567 Mdot
.584 .54574 Mdot
.584 .54576 Mdot
.584 .5459 Mdot
.584 .54602 Mdot
.584 .54617 Mdot
.584 .5462 Mdot
.584 .54645 Mdot
.584 .54674 Mdot
.584 .54678 Mdot
.584 .54715 Mdot
.584 .54716 Mdot
.584 .54725 Mdot
.584 .54749 Mdot
.584 .54769 Mdot
.584 .54774 Mdot
.584 .54775 Mdot
.584 .5478 Mdot
.584 .54794 Mdot
.584 .54795 Mdot
.584 .54815 Mdot
.584 .54838 Mdot
.584 .54844 Mdot
.584 .54891 Mdot
.584 .54916 Mdot
.584 .54917 Mdot
.584 .54924 Mdot
.584 .54955 Mdot
.584 .54975 Mdot
.584 .54976 Mdot
.584 .55001 Mdot
.584 .55019 Mdot
.584 .55025 Mdot
.584 .55025 Mdot
.584 .55034 Mdot
.584 .55039 Mdot
.584 .55043 Mdot
.584 .55047 Mdot
.584 .55052 Mdot
.584 .55056 Mdot
.584 .55064 Mdot
.584 .55064 Mdot
.584 .55064 Mdot
.584 .55072 Mdot
.584 .55073 Mdot
.584 .55087 Mdot
.584 .55087 Mdot
.584 .55091 Mdot
.584 .55096 Mdot
.584 .55102 Mdot
.584 .5511 Mdot
.584 .55129 Mdot
.584 .55132 Mdot
.584 .55136 Mdot
.584 .55142 Mdot
.584 .55152 Mdot
.584 .55157 Mdot
.584 .55173 Mdot
.584 .55201 Mdot
.584 .55235 Mdot
.584 .55244 Mdot
.584 .55249 Mdot
.584 .55258 Mdot
.584 .55268 Mdot
.584 .55278 Mdot
.584 .55298 Mdot
.584 .55301 Mdot
.584 .55312 Mdot
.584 .55315 Mdot
.584 .55315 Mdot
.584 .55315 Mdot
.584 .55324 Mdot
.584 .55329 Mdot
.584 .55339 Mdot
.584 .55341 Mdot
.584 .55342 Mdot
.584 .55352 Mdot
.584 .55358 Mdot
.584 .55366 Mdot
.584 .55369 Mdot
.584 .5537 Mdot
.584 .55373 Mdot
.584 .55378 Mdot
.584 .55381 Mdot
.584 .55382 Mdot
.584 .55387 Mdot
.584 .55388 Mdot
.584 .55392 Mdot
.584 .55393 Mdot
.584 .55393 Mdot
.584 .55396 Mdot
.584 .55397 Mdot
.584 .55404 Mdot
.584 .5541 Mdot
.584 .5541 Mdot
.584 .55411 Mdot
.584 .55411 Mdot
.584 .55414 Mdot
.584 .55415 Mdot
.584 .55416 Mdot
.584 .55424 Mdot
.584 .55425 Mdot
.584 .55425 Mdot
.584 .55428 Mdot
.584 .55428 Mdot
.584 .55429 Mdot
.584 .55431 Mdot
.584 .55431 Mdot
.584 .55432 Mdot
.584 .55432 Mdot
.584 .55433 Mdot
.584 .55434 Mdot
.584 .55434 Mdot
.584 .55434 Mdot
.584 .55434 Mdot
.584 .55434 Mdot
.586 .17871 Mdot
.586 .17872 Mdot
.586 .17872 Mdot
.586 .17873 Mdot
.586 .17874 Mdot
.586 .17874 Mdot
.586 .17874 Mdot
.586 .17874 Mdot
.586 .17874 Mdot
.586 .17875 Mdot
.586 .17875 Mdot
.586 .17876 Mdot
.586 .17877 Mdot
.586 .17878 Mdot
.586 .1788 Mdot
.586 .17881 Mdot
.586 .17884 Mdot
.586 .17899 Mdot
.586 .17919 Mdot
.586 .17934 Mdot
.586 .17936 Mdot
.586 .1794 Mdot
.586 .17945 Mdot
.586 .17952 Mdot
.586 .17955 Mdot
.586 .17956 Mdot
.586 .17963 Mdot
.586 .17967 Mdot
.586 .17968 Mdot
.586 .17982 Mdot
.586 .17996 Mdot
.586 .18012 Mdot
.586 .18025 Mdot
.586 .18051 Mdot
.586 .18062 Mdot
.586 .18067 Mdot
.586 .1807 Mdot
.586 .18084 Mdot
.586 .18086 Mdot
.586 .18096 Mdot
.586 .18102 Mdot
.586 .18118 Mdot
.586 .18128 Mdot
.586 .18144 Mdot
.586 .18145 Mdot
.586 .18176 Mdot
.586 .18181 Mdot
.586 .18206 Mdot
.586 .18209 Mdot
.586 .18212 Mdot
.586 .18243 Mdot
.586 .18248 Mdot
.586 .18252 Mdot
.586 .18261 Mdot
.586 .18271 Mdot
.586 .18277 Mdot
.586 .18283 Mdot
.586 .18313 Mdot
.586 .18331 Mdot
.586 .18345 Mdot
.586 .18366 Mdot
.586 .1837 Mdot
.586 .1842 Mdot
.586 .18447 Mdot
.586 .18508 Mdot
.586 .18509 Mdot
.586 .1852 Mdot
.586 .18542 Mdot
.586 .18556 Mdot
.586 .18561 Mdot
.586 .18567 Mdot
.586 .1863 Mdot
.586 .18852 Mdot
.586 .1886 Mdot
.586 .18915 Mdot
.586 .1894 Mdot
.586 .18973 Mdot
.586 .19002 Mdot
.586 .19069 Mdot
.586 .19069 Mdot
.586 .19127 Mdot
.586 .19137 Mdot
.586 .19139 Mdot
.586 .19148 Mdot
.586 .1928 Mdot
.586 .19416 Mdot
.586 .19487 Mdot
.586 .19496 Mdot
.586 .19617 Mdot
.586 .19736 Mdot
.586 .19787 Mdot
.586 .19816 Mdot
.586 .19854 Mdot
.586 .19879 Mdot
.586 .19916 Mdot
.586 .19951 Mdot
.586 .20112 Mdot
.586 .20114 Mdot
.586 .20121 Mdot
.586 .20199 Mdot
.586 .20269 Mdot
.586 .20375 Mdot
.586 .20394 Mdot
.586 .20412 Mdot
.586 .20419 Mdot
.586 .20468 Mdot
.586 .20472 Mdot
.586 .20594 Mdot
.586 .20618 Mdot
.586 .20767 Mdot
.586 .20795 Mdot
.586 .20883 Mdot
.586 .20893 Mdot
.586 .20963 Mdot
.586 .21219 Mdot
.586 .21274 Mdot
.586 .21378 Mdot
.586 .2154 Mdot
.586 .21652 Mdot
.586 .21691 Mdot
.586 .21697 Mdot
.586 .21834 Mdot
.586 .2207 Mdot
.586 .22148 Mdot
.586 .22167 Mdot
.586 .22232 Mdot
.586 .22243 Mdot
.586 .22264 Mdot
.586 .22266 Mdot
.586 .22269 Mdot
.586 .22282 Mdot
.586 .22429 Mdot
.586 .22436 Mdot
.586 .22444 Mdot
.586 .22471 Mdot
.586 .22478 Mdot
.586 .22515 Mdot
.586 .22534 Mdot
.586 .22549 Mdot
.586 .22593 Mdot
.586 .22612 Mdot
.586 .22626 Mdot
.586 .22642 Mdot
.586 .2265 Mdot
.586 .22664 Mdot
.586 .2269 Mdot
.586 .22694 Mdot
.586 .22713 Mdot
.586 .22716 Mdot
.586 .22718 Mdot
.586 .22744 Mdot
.586 .22761 Mdot
.586 .22765 Mdot
.586 .22769 Mdot
.586 .22802 Mdot
.586 .22811 Mdot
.586 .22827 Mdot
.586 .2291 Mdot
.586 .22928 Mdot
.586 .22942 Mdot
.586 .23213 Mdot
.586 .23319 Mdot
.586 .23485 Mdot
.586 .23658 Mdot
.586 .23711 Mdot
.586 .23799 Mdot
.586 .23935 Mdot
.586 .24166 Mdot
.586 .24211 Mdot
.586 .24219 Mdot
.586 .24397 Mdot
.586 .2521 Mdot
.586 .25281 Mdot
.586 .25369 Mdot
.586 .2551 Mdot
.586 .25671 Mdot
.586 .25747 Mdot
.586 .25834 Mdot
.586 .25908 Mdot
.586 .25928 Mdot
.586 .2602 Mdot
.586 .26029 Mdot
.586 .26085 Mdot
.586 .26282 Mdot
.586 .26368 Mdot
.586 .26562 Mdot
.586 .26629 Mdot
.586 .26881 Mdot
.586 .26948 Mdot
.586 .27072 Mdot
.586 .27089 Mdot
.586 .27177 Mdot
.586 .27216 Mdot
.586 .27381 Mdot
.586 .27448 Mdot
.586 .27577 Mdot
.586 .27635 Mdot
.586 .27656 Mdot
.586 .27756 Mdot
.586 .28041 Mdot
.586 .28304 Mdot
.586 .28315 Mdot
.586 .28386 Mdot
.586 .28386 Mdot
.586 .28458 Mdot
.586 .28527 Mdot
.586 .28903 Mdot
.586 .28988 Mdot
.586 .29023 Mdot
.586 .29054 Mdot
.586 .29069 Mdot
.586 .29161 Mdot
.586 .29282 Mdot
.586 .29323 Mdot
.586 .29348 Mdot
.586 .29431 Mdot
.586 .29442 Mdot
.586 .29452 Mdot
.586 .29495 Mdot
.586 .29563 Mdot
.586 .2957 Mdot
.586 .29577 Mdot
.586 .29627 Mdot
.586 .29638 Mdot
.586 .29705 Mdot
.586 .29741 Mdot
.586 .29763 Mdot
.586 .29802 Mdot
.586 .29817 Mdot
.586 .2984 Mdot
.586 .29845 Mdot
.586 .29888 Mdot
.586 .29929 Mdot
.586 .30005 Mdot
.586 .30043 Mdot
.586 .30094 Mdot
.586 .30191 Mdot
.586 .30192 Mdot
.586 .3021 Mdot
.586 .30281 Mdot
.586 .30302 Mdot
.586 .3032 Mdot
.586 .30403 Mdot
.586 .30712 Mdot
.586 .30745 Mdot
.586 .30755 Mdot
.586 .3076 Mdot
.586 .30774 Mdot
.586 .30815 Mdot
.586 .30846 Mdot
.586 .30908 Mdot
.586 .30946 Mdot
.586 .31017 Mdot
.586 .31018 Mdot
.586 .31019 Mdot
.586 .31031 Mdot
.586 .31071 Mdot
.586 .31111 Mdot
.586 .31123 Mdot
.586 .31164 Mdot
.586 .31281 Mdot
.586 .31473 Mdot
.586 .31551 Mdot
.586 .31565 Mdot
.586 .31569 Mdot
.586 .31664 Mdot
.586 .31902 Mdot
.586 .31924 Mdot
.586 .32101 Mdot
.586 .32299 Mdot
.586 .32315 Mdot
.586 .32333 Mdot
.586 .32425 Mdot
.586 .32514 Mdot
.586 .326 Mdot
.586 .32733 Mdot
.586 .328 Mdot
.586 .32808 Mdot
.586 .33176 Mdot
.586 .33185 Mdot
.586 .33249 Mdot
.586 .33314 Mdot
.586 .33478 Mdot
.586 .3349 Mdot
.586 .33631 Mdot
.586 .33827 Mdot
.586 .33836 Mdot
.586 .33945 Mdot
.586 .34091 Mdot
.586 .34116 Mdot
.586 .34198 Mdot
.586 .34356 Mdot
.586 .34362 Mdot
.586 .34475 Mdot
.586 .34555 Mdot
.586 .34569 Mdot
.586 .34582 Mdot
.586 .34623 Mdot
.586 .34836 Mdot
.586 .34916 Mdot
.586 .3497 Mdot
.586 .35139 Mdot
.586 .35343 Mdot
.586 .35411 Mdot
.586 .35439 Mdot
.586 .35661 Mdot
.586 .35707 Mdot
.586 .35755 Mdot
.586 .35762 Mdot
.586 .35773 Mdot
.586 .35777 Mdot
.586 .35867 Mdot
.586 .35871 Mdot
.586 .35891 Mdot
.586 .35916 Mdot
.586 .35926 Mdot
.586 .35934 Mdot
.586 .35959 Mdot
.586 .35977 Mdot
.586 .35986 Mdot
.586 .3599 Mdot
.586 .35998 Mdot
.586 .36012 Mdot
.586 .36014 Mdot
.586 .36025 Mdot
.586 .36026 Mdot
.586 .36028 Mdot
.586 .36042 Mdot
.586 .36051 Mdot
.586 .36053 Mdot
.586 .36073 Mdot
.586 .36079 Mdot
.586 .36087 Mdot
.586 .36142 Mdot
.586 .36149 Mdot
.586 .36348 Mdot
.586 .36549 Mdot
.586 .36661 Mdot
.586 .36776 Mdot
.586 .36797 Mdot
.586 .36801 Mdot
.586 .36888 Mdot
.586 .37269 Mdot
.586 .37302 Mdot
.586 .37342 Mdot
.586 .37372 Mdot
.586 .37478 Mdot
.586 .37512 Mdot
.586 .37551 Mdot
.586 .37633 Mdot
.586 .37662 Mdot
.586 .37747 Mdot
.586 .37785 Mdot
.586 .37897 Mdot
.586 .38033 Mdot
.586 .38085 Mdot
.586 .38129 Mdot
.586 .38214 Mdot
.586 .38242 Mdot
.586 .38295 Mdot
.586 .38327 Mdot
.586 .38368 Mdot
.586 .38594 Mdot
.586 .38623 Mdot
.586 .38623 Mdot
.586 .38652 Mdot
.586 .38679 Mdot
.586 .38828 Mdot
.586 .38887 Mdot
.586 .38929 Mdot
.586 .39182 Mdot
.586 .39193 Mdot
.586 .39226 Mdot
.586 .39326 Mdot
.586 .39405 Mdot
.586 .39545 Mdot
.586 .39595 Mdot
.586 .39609 Mdot
.586 .39635 Mdot
.586 .39636 Mdot
.586 .39641 Mdot
.586 .3967 Mdot
.586 .39675 Mdot
.586 .3969 Mdot
.586 .39804 Mdot
.586 .39833 Mdot
.586 .39838 Mdot
.586 .3984 Mdot
.586 .39875 Mdot
.586 .39962 Mdot
.586 .40034 Mdot
.586 .40119 Mdot
.586 .40184 Mdot
.586 .40215 Mdot
.586 .40287 Mdot
.586 .4029 Mdot
.586 .40422 Mdot
.586 .40448 Mdot
.586 .40471 Mdot
.586 .40534 Mdot
.586 .40654 Mdot
.586 .40657 Mdot
.586 .40695 Mdot
.586 .40747 Mdot
.586 .40756 Mdot
.586 .40785 Mdot
.586 .40842 Mdot
.586 .40882 Mdot
.586 .40915 Mdot
.586 .40934 Mdot
.586 .41056 Mdot
.586 .41115 Mdot
.586 .41219 Mdot
.586 .41296 Mdot
.586 .41312 Mdot
.586 .41329 Mdot
.586 .41336 Mdot
.586 .41368 Mdot
.586 .41369 Mdot
.586 .41376 Mdot
.586 .41388 Mdot
.586 .414 Mdot
.586 .41406 Mdot
.586 .41411 Mdot
.586 .41413 Mdot
.586 .41418 Mdot
.586 .41419 Mdot
.586 .41423 Mdot
.586 .41423 Mdot
.586 .41424 Mdot
.586 .41432 Mdot
.586 .41432 Mdot
.586 .41439 Mdot
.586 .41441 Mdot
.586 .41444 Mdot
.586 .41463 Mdot
.586 .41466 Mdot
.586 .41643 Mdot
.586 .41721 Mdot
.586 .41863 Mdot
.586 .41877 Mdot
.586 .41936 Mdot
.586 .41977 Mdot
.586 .42029 Mdot
.586 .42114 Mdot
.586 .42132 Mdot
.586 .42147 Mdot
.586 .42176 Mdot
.586 .42204 Mdot
.586 .42215 Mdot
.586 .42229 Mdot
.586 .42317 Mdot
.586 .42327 Mdot
.586 .42336 Mdot
.586 .42407 Mdot
.586 .42422 Mdot
.586 .42509 Mdot
.586 .42512 Mdot
.586 .42558 Mdot
.586 .42585 Mdot
.586 .42633 Mdot
.586 .4265 Mdot
.586 .42678 Mdot
.586 .42683 Mdot
.586 .42722 Mdot
.586 .42732 Mdot
.586 .42746 Mdot
.586 .42776 Mdot
.586 .42853 Mdot
.586 .42889 Mdot
.586 .42935 Mdot
.586 .42973 Mdot
.586 .43014 Mdot
.586 .43015 Mdot
.586 .43029 Mdot
.586 .43046 Mdot
.586 .43049 Mdot
.586 .4306 Mdot
.586 .43079 Mdot
.586 .43093 Mdot
.586 .43105 Mdot
.586 .43111 Mdot
.586 .43153 Mdot
.586 .4321 Mdot
.586 .4325 Mdot
.586 .43261 Mdot
.586 .43264 Mdot
.586 .43268 Mdot
.586 .43272 Mdot
.586 .43274 Mdot
.586 .43276 Mdot
.586 .43277 Mdot
.586 .43279 Mdot
.586 .43279 Mdot
.586 .4328 Mdot
.586 .4328 Mdot
.586 .4328 Mdot
.586 .43283 Mdot
.586 .43286 Mdot
.586 .43286 Mdot
.586 .43288 Mdot
.586 .44875 Mdot
.586 .44876 Mdot
.586 .44876 Mdot
.586 .44878 Mdot
.586 .44879 Mdot
.586 .44879 Mdot
.586 .4488 Mdot
.586 .4488 Mdot
.586 .4488 Mdot
.586 .44881 Mdot
.586 .44882 Mdot
.586 .44883 Mdot
.586 .44884 Mdot
.586 .44886 Mdot
.586 .44889 Mdot
.586 .4489 Mdot
.586 .44897 Mdot
.586 .4492 Mdot
.586 .44952 Mdot
.586 .44976 Mdot
.586 .4498 Mdot
.586 .44986 Mdot
.586 .44994 Mdot
.586 .45006 Mdot
.586 .45011 Mdot
.586 .45013 Mdot
.586 .45023 Mdot
.586 .45031 Mdot
.586 .45031 Mdot
.586 .45055 Mdot
.586 .45076 Mdot
.586 .45102 Mdot
.586 .45123 Mdot
.586 .45166 Mdot
.586 .45183 Mdot
.586 .45191 Mdot
.586 .45196 Mdot
.586 .45218 Mdot
.586 .45221 Mdot
.586 .45236 Mdot
.586 .45246 Mdot
.586 .45273 Mdot
.586 .45288 Mdot
.586 .45313 Mdot
.586 .45315 Mdot
.586 .45364 Mdot
.586 .45372 Mdot
.586 .45411 Mdot
.586 .45416 Mdot
.586 .45422 Mdot
.586 .4547 Mdot
.586 .45478 Mdot
.586 .45484 Mdot
.586 .45499 Mdot
.586 .45515 Mdot
.586 .45523 Mdot
.586 .45533 Mdot
.586 .4558 Mdot
.586 .45608 Mdot
.586 .45631 Mdot
.586 .45663 Mdot
.586 .4567 Mdot
.586 .45748 Mdot
.586 .4579 Mdot
.586 .45885 Mdot
.586 .45886 Mdot
.586 .45896 Mdot
.586 .45898 Mdot
.586 .45899 Mdot
.586 .45902 Mdot
.586 .45903 Mdot
.586 .45907 Mdot
.586 .45907 Mdot
.586 .45908 Mdot
.586 .4591 Mdot
.586 .4591 Mdot
.586 .45913 Mdot
.586 .45914 Mdot
.586 .45917 Mdot
.586 .4592 Mdot
.586 .45926 Mdot
.586 .45933 Mdot
.586 .45936 Mdot
.586 .45937 Mdot
.586 .45954 Mdot
.586 .45958 Mdot
.586 .45967 Mdot
.586 .45975 Mdot
.586 .46016 Mdot
.586 .46071 Mdot
.586 .46103 Mdot
.586 .46167 Mdot
.586 .46177 Mdot
.586 .46194 Mdot
.586 .46215 Mdot
.586 .46245 Mdot
.586 .4626 Mdot
.586 .46265 Mdot
.586 .46292 Mdot
.586 .46312 Mdot
.586 .46313 Mdot
.586 .46375 Mdot
.586 .46408 Mdot
.586 .4642 Mdot
.586 .46433 Mdot
.586 .46501 Mdot
.586 .46503 Mdot
.586 .4654 Mdot
.586 .46556 Mdot
.586 .46589 Mdot
.586 .46632 Mdot
.586 .46669 Mdot
.586 .46714 Mdot
.586 .46731 Mdot
.586 .46732 Mdot
.586 .46735 Mdot
.586 .46749 Mdot
.586 .46807 Mdot
.586 .46815 Mdot
.586 .46817 Mdot
.586 .46832 Mdot
.586 .46835 Mdot
.586 .46848 Mdot
.586 .46855 Mdot
.586 .4688 Mdot
.586 .4695 Mdot
.586 .4699 Mdot
.586 .47039 Mdot
.586 .47056 Mdot
.586 .47061 Mdot
.586 .47186 Mdot
.586 .47207 Mdot
.586 .47236 Mdot
.586 .47309 Mdot
.586 .47322 Mdot
.586 .47336 Mdot
.586 .47336 Mdot
.586 .4735 Mdot
.586 .4746 Mdot
.586 .4748 Mdot
.586 .47496 Mdot
.586 .47521 Mdot
.586 .47535 Mdot
.586 .47576 Mdot
.586 .47597 Mdot
.586 .47622 Mdot
.586 .47687 Mdot
.586 .4774 Mdot
.586 .47758 Mdot
.586 .47799 Mdot
.586 .47813 Mdot
.586 .47852 Mdot
.586 .4787 Mdot
.586 .47886 Mdot
.586 .47936 Mdot
.586 .4795 Mdot
.586 .47969 Mdot
.586 .47984 Mdot
.586 .48163 Mdot
.586 .48203 Mdot
.586 .48204 Mdot
.586 .48215 Mdot
.586 .48267 Mdot
.586 .48319 Mdot
.586 .48411 Mdot
.586 .48502 Mdot
.586 .48506 Mdot
.586 .48531 Mdot
.586 .48535 Mdot
.586 .48537 Mdot
.586 .48546 Mdot
.586 .48547 Mdot
.586 .48551 Mdot
.586 .48558 Mdot
.586 .48558 Mdot
.586 .48559 Mdot
.586 .48564 Mdot
.586 .48565 Mdot
.586 .48571 Mdot
.586 .48575 Mdot
.586 .48577 Mdot
.586 .48581 Mdot
.586 .48589 Mdot
.586 .486 Mdot
.586 .48604 Mdot
.586 .48609 Mdot
.586 .4862 Mdot
.586 .48629 Mdot
.586 .4863 Mdot
.586 .48671 Mdot
.586 .48673 Mdot
.586 .48678 Mdot
.586 .48681 Mdot
.586 .48703 Mdot
.586 .48723 Mdot
.586 .48823 Mdot
.586 .48836 Mdot
.586 .48866 Mdot
.586 .48957 Mdot
.586 .49032 Mdot
.586 .49056 Mdot
.586 .49091 Mdot
.586 .49185 Mdot
.586 .49203 Mdot
.586 .49208 Mdot
.586 .49215 Mdot
.586 .49249 Mdot
.586 .49299 Mdot
.586 .49301 Mdot
.586 .4937 Mdot
.586 .49406 Mdot
.586 .49417 Mdot
.586 .4948 Mdot
.586 .49527 Mdot
.586 .49531 Mdot
.586 .49615 Mdot
.586 .49675 Mdot
.586 .4968 Mdot
.586 .4975 Mdot
.586 .49778 Mdot
.586 .49805 Mdot
.586 .49809 Mdot
.586 .49965 Mdot
.586 .49968 Mdot
.586 .49996 Mdot
.586 .50052 Mdot
.586 .50088 Mdot
.586 .50125 Mdot
.586 .50163 Mdot
.586 .50171 Mdot
.586 .50178 Mdot
.586 .5026 Mdot
.586 .50333 Mdot
.586 .50342 Mdot
.586 .5044 Mdot
.586 .50479 Mdot
.586 .5048 Mdot
.586 .50486 Mdot
.586 .50518 Mdot
.586 .50596 Mdot
.586 .50644 Mdot
.586 .50661 Mdot
.586 .50666 Mdot
.586 .50682 Mdot
.586 .50698 Mdot
.586 .50703 Mdot
.586 .50703 Mdot
.586 .50704 Mdot
.586 .50732 Mdot
.586 .50748 Mdot
.586 .50773 Mdot
.586 .50786 Mdot
.586 .50802 Mdot
.586 .50807 Mdot
.586 .5081 Mdot
.586 .50814 Mdot
.586 .50827 Mdot
.586 .50951 Mdot
.586 .50984 Mdot
.586 .50991 Mdot
.586 .51 Mdot
.586 .51028 Mdot
.586 .51035 Mdot
.586 .51036 Mdot
.586 .51074 Mdot
.586 .51094 Mdot
.586 .5111 Mdot
.586 .5114 Mdot
.586 .51156 Mdot
.586 .51173 Mdot
.586 .51175 Mdot
.586 .51184 Mdot
.586 .5119 Mdot
.586 .51206 Mdot
.586 .51214 Mdot
.586 .51228 Mdot
.586 .51255 Mdot
.586 .51259 Mdot
.586 .51279 Mdot
.586 .51281 Mdot
.586 .51284 Mdot
.586 .51311 Mdot
.586 .51328 Mdot
.586 .51332 Mdot
.586 .51336 Mdot
.586 .51369 Mdot
.586 .51378 Mdot
.586 .51395 Mdot
.586 .51442 Mdot
.586 .51478 Mdot
.586 .51484 Mdot
.586 .51496 Mdot
.586 .51509 Mdot
.586 .51542 Mdot
.586 .51688 Mdot
.586 .51715 Mdot
.586 .51742 Mdot
.586 .51742 Mdot
.586 .5177 Mdot
.586 .51774 Mdot
.586 .51875 Mdot
.586 .51983 Mdot
.586 .52021 Mdot
.586 .52029 Mdot
.586 .52052 Mdot
.586 .521 Mdot
.586 .52126 Mdot
.586 .52188 Mdot
.586 .52203 Mdot
.586 .52236 Mdot
.586 .52242 Mdot
.586 .52289 Mdot
.586 .52314 Mdot
.586 .52408 Mdot
.586 .52433 Mdot
.586 .52505 Mdot
.586 .52537 Mdot
.586 .5261 Mdot
.586 .52631 Mdot
.586 .52634 Mdot
.586 .52668 Mdot
.586 .52675 Mdot
.586 .52703 Mdot
.586 .52734 Mdot
.586 .52762 Mdot
.586 .52821 Mdot
.586 .52873 Mdot
.586 .52905 Mdot
.586 .52931 Mdot
.586 .53225 Mdot
.586 .53289 Mdot
.586 .53292 Mdot
.586 .53308 Mdot
.586 .53391 Mdot
.586 .53439 Mdot
.586 .5347 Mdot
.586 .53489 Mdot
.586 .53551 Mdot
.586 .53609 Mdot
.586 .53646 Mdot
.586 .53742 Mdot
.586 .53747 Mdot
.586 .53753 Mdot
.586 .53782 Mdot
.586 .53788 Mdot
.586 .53791 Mdot
.586 .53802 Mdot
.586 .53804 Mdot
.586 .53805 Mdot
.586 .53811 Mdot
.586 .5382 Mdot
.586 .53821 Mdot
.586 .53822 Mdot
.586 .53829 Mdot
.586 .5383 Mdot
.586 .53839 Mdot
.586 .53844 Mdot
.586 .53847 Mdot
.586 .53852 Mdot
.586 .53858 Mdot
.586 .53864 Mdot
.586 .5388 Mdot
.586 .53885 Mdot
.586 .53891 Mdot
.586 .53904 Mdot
.586 .53907 Mdot
.586 .53916 Mdot
.586 .53919 Mdot
.586 .53921 Mdot
.586 .53973 Mdot
.586 .53977 Mdot
.586 .53978 Mdot
.586 .53979 Mdot
.586 .53986 Mdot
.586 .5399 Mdot
.586 .54012 Mdot
.586 .54019 Mdot
.586 .54046 Mdot
.586 .54128 Mdot
.586 .54175 Mdot
.586 .54177 Mdot
.586 .54191 Mdot
.586 .54229 Mdot
.586 .54285 Mdot
.586 .5432 Mdot
.586 .54339 Mdot
.586 .54427 Mdot
.586 .5445 Mdot
.586 .54454 Mdot
.586 .54484 Mdot
.586 .54494 Mdot
.586 .54544 Mdot
.586 .54552 Mdot
.586 .54594 Mdot
.586 .54595 Mdot
.586 .54612 Mdot
.586 .54614 Mdot
.586 .5462 Mdot
.586 .54626 Mdot
.586 .54662 Mdot
.586 .54686 Mdot
.586 .54712 Mdot
.586 .54714 Mdot
.586 .54715 Mdot
.586 .54769 Mdot
.586 .54781 Mdot
.586 .54793 Mdot
.586 .54802 Mdot
.586 .54814 Mdot
.586 .54824 Mdot
.586 .54842 Mdot
.586 .54881 Mdot
.586 .54922 Mdot
.586 .54925 Mdot
.586 .54948 Mdot
.586 .54994 Mdot
.586 .55038 Mdot
.586 .55041 Mdot
.586 .55041 Mdot
.586 .55045 Mdot
.586 .55064 Mdot
.586 .55064 Mdot
.586 .55086 Mdot
.586 .55096 Mdot
.586 .55107 Mdot
.586 .55115 Mdot
.586 .55133 Mdot
.586 .55136 Mdot
.586 .55209 Mdot
.586 .5523 Mdot
.586 .55232 Mdot
.586 .55234 Mdot
.586 .55238 Mdot
.586 .55245 Mdot
.586 .55249 Mdot
.586 .55249 Mdot
.586 .5527 Mdot
.586 .55278 Mdot
.586 .55295 Mdot
.586 .55296 Mdot
.586 .55303 Mdot
.586 .55308 Mdot
.586 .55314 Mdot
.586 .55323 Mdot
.586 .55325 Mdot
.586 .55327 Mdot
.586 .55331 Mdot
.586 .55334 Mdot
.586 .55335 Mdot
.586 .55337 Mdot
.586 .55347 Mdot
.586 .55348 Mdot
.586 .55349 Mdot
.586 .55357 Mdot
.586 .55359 Mdot
.586 .55369 Mdot
.586 .55369 Mdot
.586 .55374 Mdot
.586 .55377 Mdot
.586 .55383 Mdot
.586 .55385 Mdot
.586 .55388 Mdot
.586 .55389 Mdot
.586 .55393 Mdot
.586 .55394 Mdot
.586 .55396 Mdot
.586 .55399 Mdot
.586 .55408 Mdot
.586 .55412 Mdot
.586 .55418 Mdot
.586 .55422 Mdot
.586 .55427 Mdot
.586 .55427 Mdot
.586 .55428 Mdot
.586 .5543 Mdot
.586 .55431 Mdot
.586 .55432 Mdot
.586 .55434 Mdot
.586 .55436 Mdot
.586 .55437 Mdot
.586 .55438 Mdot
.586 .55443 Mdot
.586 .55449 Mdot
.586 .55454 Mdot
.586 .55455 Mdot
.586 .55456 Mdot
.586 .55456 Mdot
.586 .55456 Mdot
.586 .55457 Mdot
.586 .55457 Mdot
.586 .55457 Mdot
.586 .55457 Mdot
.586 .55457 Mdot
.586 .55457 Mdot
.586 .55457 Mdot
.586 .55457 Mdot
.586 .55458 Mdot
.586 .55458 Mdot
.586 .55458 Mdot
.586 .55458 Mdot
.588 .17806 Mdot
.588 .17809 Mdot
.588 .1781 Mdot
.588 .17811 Mdot
.588 .17815 Mdot
.588 .17816 Mdot
.588 .17818 Mdot
.588 .17825 Mdot
.588 .1783 Mdot
.588 .1783 Mdot
.588 .17833 Mdot
.588 .17837 Mdot
.588 .17846 Mdot
.588 .1785 Mdot
.588 .1786 Mdot
.588 .17861 Mdot
.588 .17879 Mdot
.588 .17882 Mdot
.588 .17883 Mdot
.588 .17889 Mdot
.588 .17904 Mdot
.588 .17911 Mdot
.588 .1792 Mdot
.588 .17929 Mdot
.588 .17937 Mdot
.588 .17966 Mdot
.588 .17976 Mdot
.588 .17993 Mdot
.588 .1803 Mdot
.588 .1807 Mdot
.588 .18106 Mdot
.588 .1813 Mdot
.588 .18148 Mdot
.588 .18165 Mdot
.588 .18169 Mdot
.588 .18171 Mdot
.588 .18175 Mdot
.588 .18256 Mdot
.588 .18261 Mdot
.588 .18301 Mdot
.588 .18301 Mdot
.588 .18316 Mdot
.588 .18319 Mdot
.588 .18319 Mdot
.588 .18348 Mdot
.588 .18379 Mdot
.588 .18385 Mdot
.588 .18392 Mdot
.588 .1842 Mdot
.588 .18442 Mdot
.588 .18468 Mdot
.588 .18487 Mdot
.588 .18496 Mdot
.588 .185 Mdot
.588 .18535 Mdot
.588 .1855 Mdot
.588 .18556 Mdot
.588 .18578 Mdot
.588 .18611 Mdot
.588 .18655 Mdot
.588 .187 Mdot
.588 .18789 Mdot
.588 .18837 Mdot
.588 .18936 Mdot
.588 .18993 Mdot
.588 .19036 Mdot
.588 .19058 Mdot
.588 .1909 Mdot
.588 .19209 Mdot
.588 .19222 Mdot
.588 .19233 Mdot
.588 .1924 Mdot
.588 .19281 Mdot
.588 .1932 Mdot
.588 .19389 Mdot
.588 .1939 Mdot
.588 .19404 Mdot
.588 .19524 Mdot
.588 .19526 Mdot
.588 .19827 Mdot
.588 .19858 Mdot
.588 .19915 Mdot
.588 .19936 Mdot
.588 .20012 Mdot
.588 .20075 Mdot
.588 .20103 Mdot
.588 .20194 Mdot
.588 .20257 Mdot
.588 .20315 Mdot
.588 .20316 Mdot
.588 .20333 Mdot
.588 .20337 Mdot
.588 .20359 Mdot
.588 .20393 Mdot
.588 .20436 Mdot
.588 .2053 Mdot
.588 .20559 Mdot
.588 .20713 Mdot
.588 .20746 Mdot
.588 .20827 Mdot
.588 .20861 Mdot
.588 .2087 Mdot
.588 .20876 Mdot
.588 .21006 Mdot
.588 .21105 Mdot
.588 .21271 Mdot
.588 .21406 Mdot
.588 .2163 Mdot
.588 .21633 Mdot
.588 .21686 Mdot
.588 .21705 Mdot
.588 .21718 Mdot
.588 .21848 Mdot
.588 .219 Mdot
.588 .21923 Mdot
.588 .21967 Mdot
.588 .22018 Mdot
.588 .22057 Mdot
.588 .22112 Mdot
.588 .22117 Mdot
.588 .2214 Mdot
.588 .22196 Mdot
.588 .22241 Mdot
.588 .22247 Mdot
.588 .22286 Mdot
.588 .22298 Mdot
.588 .22314 Mdot
.588 .22327 Mdot
.588 .22397 Mdot
.588 .22431 Mdot
.588 .22539 Mdot
.588 .22717 Mdot
.588 .22807 Mdot
.588 .22807 Mdot
.588 .22819 Mdot
.588 .22819 Mdot
.588 .22836 Mdot
.588 .22858 Mdot
.588 .22863 Mdot
.588 .22879 Mdot
.588 .22916 Mdot
.588 .2295 Mdot
.588 .22953 Mdot
.588 .22981 Mdot
.588 .23067 Mdot
.588 .23089 Mdot
.588 .23184 Mdot
.588 .23245 Mdot
.588 .2325 Mdot
.588 .23254 Mdot
.588 .23273 Mdot
.588 .23314 Mdot
.588 .23363 Mdot
.588 .23468 Mdot
.588 .23498 Mdot
.588 .23505 Mdot
.588 .2355 Mdot
.588 .23559 Mdot
.588 .23625 Mdot
.588 .23631 Mdot
.588 .23754 Mdot
.588 .23777 Mdot
.588 .23791 Mdot
.588 .23937 Mdot
.588 .24072 Mdot
.588 .24127 Mdot
.588 .24141 Mdot
.588 .24164 Mdot
.588 .24167 Mdot
.588 .24191 Mdot
.588 .24291 Mdot
.588 .24294 Mdot
.588 .24333 Mdot
.588 .24358 Mdot
.588 .24396 Mdot
.588 .24397 Mdot
.588 .24468 Mdot
.588 .24513 Mdot
.588 .24597 Mdot
.588 .24658 Mdot
.588 .24673 Mdot
.588 .24719 Mdot
.588 .24759 Mdot
.588 .24795 Mdot
.588 .24857 Mdot
.588 .2489 Mdot
.588 .24891 Mdot
.588 .24909 Mdot
.588 .2499 Mdot
.588 .25021 Mdot
.588 .25048 Mdot
.588 .25194 Mdot
.588 .25205 Mdot
.588 .2527 Mdot
.588 .25304 Mdot
.588 .25308 Mdot
.588 .25331 Mdot
.588 .2535 Mdot
.588 .2546 Mdot
.588 .25462 Mdot
.588 .25465 Mdot
.588 .25497 Mdot
.588 .25547 Mdot
.588 .25604 Mdot
.588 .2569 Mdot
.588 .25697 Mdot
.588 .25697 Mdot
.588 .25903 Mdot
.588 .25922 Mdot
.588 .25978 Mdot
.588 .25984 Mdot
.588 .26007 Mdot
.588 .2601 Mdot
.588 .26036 Mdot
.588 .26068 Mdot
.588 .26081 Mdot
.588 .26194 Mdot
.588 .26368 Mdot
.588 .2637 Mdot
.588 .26508 Mdot
.588 .26852 Mdot
.588 .26885 Mdot
.588 .2694 Mdot
.588 .27159 Mdot
.588 .27235 Mdot
.588 .27247 Mdot
.588 .27248 Mdot
.588 .27408 Mdot
.588 .2743 Mdot
.588 .27539 Mdot
.588 .27557 Mdot
.588 .27628 Mdot
.588 .27887 Mdot
.588 .27995 Mdot
.588 .28008 Mdot
.588 .28009 Mdot
.588 .28111 Mdot
.588 .28157 Mdot
.588 .28167 Mdot
.588 .2818 Mdot
.588 .28332 Mdot
.588 .28572 Mdot
.588 .28626 Mdot
.588 .28845 Mdot
.588 .28888 Mdot
.588 .28916 Mdot
.588 .28925 Mdot
.588 .28944 Mdot
.588 .28993 Mdot
.588 .28997 Mdot
.588 .29011 Mdot
.588 .29037 Mdot
.588 .29073 Mdot
.588 .29106 Mdot
.588 .29147 Mdot
.588 .29159 Mdot
.588 .29167 Mdot
.588 .29215 Mdot
.588 .2926 Mdot
.588 .29261 Mdot
.588 .29291 Mdot
.588 .29291 Mdot
.588 .29519 Mdot
.588 .29523 Mdot
.588 .29531 Mdot
.588 .29818 Mdot
.588 .29912 Mdot
.588 .29988 Mdot
.588 .30131 Mdot
.588 .30186 Mdot
.588 .30267 Mdot
.588 .30274 Mdot
.588 .30364 Mdot
.588 .30371 Mdot
.588 .30443 Mdot
.588 .3055 Mdot
.588 .30585 Mdot
.588 .30627 Mdot
.588 .30658 Mdot
.588 .30765 Mdot
.588 .30781 Mdot
.588 .30901 Mdot
.588 .31052 Mdot
.588 .31114 Mdot
.588 .31127 Mdot
.588 .31253 Mdot
.588 .31275 Mdot
.588 .31304 Mdot
.588 .31382 Mdot
.588 .3152 Mdot
.588 .31558 Mdot
.588 .31641 Mdot
.588 .31704 Mdot
.588 .31729 Mdot
.588 .31846 Mdot
.588 .32077 Mdot
.588 .32155 Mdot
.588 .32205 Mdot
.588 .3224 Mdot
.588 .32292 Mdot
.588 .32438 Mdot
.588 .32446 Mdot
.588 .32537 Mdot
.588 .33015 Mdot
.588 .33071 Mdot
.588 .33342 Mdot
.588 .33403 Mdot
.588 .33449 Mdot
.588 .33653 Mdot
.588 .3373 Mdot
.588 .33918 Mdot
.588 .34201 Mdot
.588 .34324 Mdot
.588 .34465 Mdot
.588 .34512 Mdot
.588 .34571 Mdot
.588 .34588 Mdot
.588 .34612 Mdot
.588 .34711 Mdot
.588 .34732 Mdot
.588 .3484 Mdot
.588 .34941 Mdot
.588 .34947 Mdot
.588 .35038 Mdot
.588 .35103 Mdot
.588 .3521 Mdot
.588 .35467 Mdot
.588 .35479 Mdot
.588 .35487 Mdot
.588 .35565 Mdot
.588 .35595 Mdot
.588 .35635 Mdot
.588 .35665 Mdot
.588 .35687 Mdot
.588 .35719 Mdot
.588 .35834 Mdot
.588 .35842 Mdot
.588 .3596 Mdot
.588 .36058 Mdot
.588 .36113 Mdot
.588 .36122 Mdot
.588 .36134 Mdot
.588 .36136 Mdot
.588 .36145 Mdot
.588 .36165 Mdot
.588 .36183 Mdot
.588 .36185 Mdot
.588 .36245 Mdot
.588 .36353 Mdot
.588 .36374 Mdot
.588 .364 Mdot
.588 .36469 Mdot
.588 .36536 Mdot
.588 .36616 Mdot
.588 .36689 Mdot
.588 .36789 Mdot
.588 .368 Mdot
.588 .36802 Mdot
.588 .36862 Mdot
.588 .36863 Mdot
.588 .36882 Mdot
.588 .36968 Mdot
.588 .37037 Mdot
.588 .37065 Mdot
.588 .37101 Mdot
.588 .37146 Mdot
.588 .37154 Mdot
.588 .37192 Mdot
.588 .37218 Mdot
.588 .37285 Mdot
.588 .3732 Mdot
.588 .37337 Mdot
.588 .37348 Mdot
.588 .37356 Mdot
.588 .37408 Mdot
.588 .37423 Mdot
.588 .37512 Mdot
.588 .37604 Mdot
.588 .37649 Mdot
.588 .37651 Mdot
.588 .37682 Mdot
.588 .37806 Mdot
.588 .37807 Mdot
.588 .38141 Mdot
.588 .38178 Mdot
.588 .38484 Mdot
.588 .38489 Mdot
.588 .38839 Mdot
.588 .38861 Mdot
.588 .3888 Mdot
.588 .38882 Mdot
.588 .38897 Mdot
.588 .38912 Mdot
.588 .38948 Mdot
.588 .39085 Mdot
.588 .39089 Mdot
.588 .39199 Mdot
.588 .39235 Mdot
.588 .39318 Mdot
.588 .39339 Mdot
.588 .3937 Mdot
.588 .39409 Mdot
.588 .39436 Mdot
.588 .39738 Mdot
.588 .39756 Mdot
.588 .3985 Mdot
.588 .39913 Mdot
.588 .40039 Mdot
.588 .40068 Mdot
.588 .40206 Mdot
.588 .40377 Mdot
.588 .40494 Mdot
.588 .40515 Mdot
.588 .40604 Mdot
.588 .40631 Mdot
.588 .40841 Mdot
.588 .4089 Mdot
.588 .40907 Mdot
.588 .40984 Mdot
.588 .41021 Mdot
.588 .41059 Mdot
.588 .41113 Mdot
.588 .41151 Mdot
.588 .4124 Mdot
.588 .41247 Mdot
.588 .41284 Mdot
.588 .41298 Mdot
.588 .41308 Mdot
.588 .41316 Mdot
.588 .41327 Mdot
.588 .4137 Mdot
.588 .41463 Mdot
.588 .41472 Mdot
.588 .41475 Mdot
.588 .41481 Mdot
.588 .41509 Mdot
.588 .41554 Mdot
.588 .41562 Mdot
.588 .41586 Mdot
.588 .41637 Mdot
.588 .41662 Mdot
.588 .41697 Mdot
.588 .41701 Mdot
.588 .41721 Mdot
.588 .41722 Mdot
.588 .41758 Mdot
.588 .41782 Mdot
.588 .41804 Mdot
.588 .41819 Mdot
.588 .41822 Mdot
.588 .41835 Mdot
.588 .41844 Mdot
.588 .41879 Mdot
.588 .41885 Mdot
.588 .41891 Mdot
.588 .41909 Mdot
.588 .41914 Mdot
.588 .41992 Mdot
.588 .41992 Mdot
.588 .42003 Mdot
.588 .42046 Mdot
.588 .42046 Mdot
.588 .4216 Mdot
.588 .42173 Mdot
.588 .42407 Mdot
.588 .42419 Mdot
.588 .42424 Mdot
.588 .42437 Mdot
.588 .42485 Mdot
.588 .42535 Mdot
.588 .42604 Mdot
.588 .42707 Mdot
.588 .4282 Mdot
.588 .42926 Mdot
.588 .42974 Mdot
.588 .43004 Mdot
.588 .43086 Mdot
.588 .43109 Mdot
.588 .43135 Mdot
.588 .43161 Mdot
.588 .4318 Mdot
.588 .43223 Mdot
.588 .43239 Mdot
.588 .43244 Mdot
.588 .4325 Mdot
.588 .43301 Mdot
.588 .43305 Mdot
.588 .43332 Mdot
.588 .43343 Mdot
.588 .43369 Mdot
.588 .43381 Mdot
.588 .4339 Mdot
.588 .4339 Mdot
.588 .43403 Mdot
.588 .43425 Mdot
.588 .43429 Mdot
.588 .43432 Mdot
.588 .43445 Mdot
.588 .43447 Mdot
.588 .43449 Mdot
.588 .43457 Mdot
.588 .44788 Mdot
.588 .44793 Mdot
.588 .44794 Mdot
.588 .44795 Mdot
.588 .44802 Mdot
.588 .44804 Mdot
.588 .44807 Mdot
.588 .4482 Mdot
.588 .44827 Mdot
.588 .44827 Mdot
.588 .44832 Mdot
.588 .44839 Mdot
.588 .44854 Mdot
.588 .4486 Mdot
.588 .44876 Mdot
.588 .44878 Mdot
.588 .44907 Mdot
.588 .44911 Mdot
.588 .44914 Mdot
.588 .44922 Mdot
.588 .44947 Mdot
.588 .44958 Mdot
.588 .44973 Mdot
.588 .44988 Mdot
.588 .45001 Mdot
.588 .45047 Mdot
.588 .45064 Mdot
.588 .45091 Mdot
.588 .45151 Mdot
.588 .45215 Mdot
.588 .45273 Mdot
.588 .45311 Mdot
.588 .45339 Mdot
.588 .45365 Mdot
.588 .45372 Mdot
.588 .45375 Mdot
.588 .45382 Mdot
.588 .45511 Mdot
.588 .45518 Mdot
.588 .4558 Mdot
.588 .45581 Mdot
.588 .45604 Mdot
.588 .4561 Mdot
.588 .4561 Mdot
.588 .45652 Mdot
.588 .45655 Mdot
.588 .45665 Mdot
.588 .45668 Mdot
.588 .45671 Mdot
.588 .4569 Mdot
.588 .45695 Mdot
.588 .45702 Mdot
.588 .45704 Mdot
.588 .45712 Mdot
.588 .45724 Mdot
.588 .45737 Mdot
.588 .45756 Mdot
.588 .45757 Mdot
.588 .45768 Mdot
.588 .4577 Mdot
.588 .45789 Mdot
.588 .45802 Mdot
.588 .45829 Mdot
.588 .45842 Mdot
.588 .45847 Mdot
.588 .45871 Mdot
.588 .45886 Mdot
.588 .45889 Mdot
.588 .45891 Mdot
.588 .45895 Mdot
.588 .45945 Mdot
.588 .45968 Mdot
.588 .45974 Mdot
.588 .45978 Mdot
.588 .45983 Mdot
.588 .45991 Mdot
.588 .46011 Mdot
.588 .46014 Mdot
.588 .46062 Mdot
.588 .46081 Mdot
.588 .4611 Mdot
.588 .4613 Mdot
.588 .46149 Mdot
.588 .4619 Mdot
.588 .46199 Mdot
.588 .46225 Mdot
.588 .46334 Mdot
.588 .46348 Mdot
.588 .46394 Mdot
.588 .46405 Mdot
.588 .46465 Mdot
.588 .46553 Mdot
.588 .46624 Mdot
.588 .46638 Mdot
.588 .46703 Mdot
.588 .46735 Mdot
.588 .46782 Mdot
.588 .46791 Mdot
.588 .46943 Mdot
.588 .46956 Mdot
.588 .46976 Mdot
.588 .46991 Mdot
.588 .47002 Mdot
.588 .47043 Mdot
.588 .47061 Mdot
.588 .47115 Mdot
.588 .47117 Mdot
.588 .47185 Mdot
.588 .47203 Mdot
.588 .4721 Mdot
.588 .47217 Mdot
.588 .47218 Mdot
.588 .47227 Mdot
.588 .47238 Mdot
.588 .47409 Mdot
.588 .47412 Mdot
.588 .4756 Mdot
.588 .47577 Mdot
.588 .47738 Mdot
.588 .47738 Mdot
.588 .47797 Mdot
.588 .47812 Mdot
.588 .47812 Mdot
.588 .47834 Mdot
.588 .47877 Mdot
.588 .47919 Mdot
.588 .47926 Mdot
.588 .47951 Mdot
.588 .47955 Mdot
.588 .4796 Mdot
.588 .47968 Mdot
.588 .47984 Mdot
.588 .48015 Mdot
.588 .48028 Mdot
.588 .48045 Mdot
.588 .48049 Mdot
.588 .4807 Mdot
.588 .48087 Mdot
.588 .481 Mdot
.588 .48132 Mdot
.588 .48172 Mdot
.588 .48181 Mdot
.588 .48182 Mdot
.588 .4821 Mdot
.588 .4821 Mdot
.588 .48215 Mdot
.588 .48262 Mdot
.588 .48295 Mdot
.588 .48332 Mdot
.588 .48363 Mdot
.588 .48395 Mdot
.588 .48407 Mdot
.588 .48416 Mdot
.588 .48465 Mdot
.588 .48493 Mdot
.588 .48494 Mdot
.588 .48502 Mdot
.588 .48511 Mdot
.588 .48515 Mdot
.588 .48516 Mdot
.588 .48522 Mdot
.588 .48526 Mdot
.588 .48551 Mdot
.588 .48595 Mdot
.588 .48649 Mdot
.588 .48652 Mdot
.588 .48704 Mdot
.588 .48718 Mdot
.588 .48729 Mdot
.588 .48742 Mdot
.588 .4876 Mdot
.588 .48773 Mdot
.588 .48808 Mdot
.588 .48812 Mdot
.588 .48817 Mdot
.588 .48932 Mdot
.588 .48979 Mdot
.588 .49008 Mdot
.588 .49048 Mdot
.588 .49051 Mdot
.588 .49096 Mdot
.588 .49143 Mdot
.588 .49152 Mdot
.588 .49196 Mdot
.588 .49207 Mdot
.588 .49214 Mdot
.588 .4924 Mdot
.588 .4926 Mdot
.588 .49322 Mdot
.588 .49375 Mdot
.588 .49498 Mdot
.588 .49578 Mdot
.588 .49611 Mdot
.588 .49699 Mdot
.588 .49718 Mdot
.588 .49744 Mdot
.588 .49859 Mdot
.588 .49883 Mdot
.588 .50084 Mdot
.588 .50122 Mdot
.588 .50125 Mdot
.588 .50186 Mdot
.588 .50208 Mdot
.588 .50222 Mdot
.588 .50243 Mdot
.588 .50275 Mdot
.588 .50371 Mdot
.588 .50419 Mdot
.588 .50429 Mdot
.588 .50455 Mdot
.588 .50489 Mdot
.588 .50504 Mdot
.588 .50561 Mdot
.588 .50593 Mdot
.588 .50604 Mdot
.588 .50613 Mdot
.588 .50664 Mdot
.588 .5067 Mdot
.588 .50695 Mdot
.588 .50756 Mdot
.588 .50804 Mdot
.588 .50811 Mdot
.588 .50854 Mdot
.588 .50866 Mdot
.588 .50883 Mdot
.588 .50897 Mdot
.588 .5094 Mdot
.588 .50969 Mdot
.588 .50971 Mdot
.588 .51008 Mdot
.588 .5101 Mdot
.588 .51042 Mdot
.588 .51065 Mdot
.588 .51121 Mdot
.588 .51151 Mdot
.588 .51189 Mdot
.588 .51302 Mdot
.588 .51305 Mdot
.588 .51306 Mdot
.588 .51396 Mdot
.588 .51396 Mdot
.588 .51408 Mdot
.588 .51408 Mdot
.588 .51426 Mdot
.588 .51444 Mdot
.588 .51447 Mdot
.588 .51452 Mdot
.588 .51468 Mdot
.588 .51481 Mdot
.588 .51495 Mdot
.588 .51505 Mdot
.588 .5151 Mdot
.588 .51512 Mdot
.588 .51531 Mdot
.588 .51539 Mdot
.588 .51542 Mdot
.588 .51553 Mdot
.588 .5157 Mdot
.588 .51654 Mdot
.588 .51675 Mdot
.588 .51768 Mdot
.588 .51826 Mdot
.588 .51831 Mdot
.588 .51835 Mdot
.588 .51853 Mdot
.588 .51892 Mdot
.588 .51892 Mdot
.588 .51897 Mdot
.588 .51938 Mdot
.588 .52036 Mdot
.588 .52063 Mdot
.588 .5207 Mdot
.588 .52111 Mdot
.588 .5212 Mdot
.588 .5218 Mdot
.588 .5218 Mdot
.588 .52185 Mdot
.588 .52214 Mdot
.588 .52296 Mdot
.588 .52316 Mdot
.588 .52329 Mdot
.588 .52457 Mdot
.588 .52509 Mdot
.588 .52509 Mdot
.588 .52574 Mdot
.588 .52615 Mdot
.588 .5262 Mdot
.588 .52632 Mdot
.588 .52641 Mdot
.588 .52643 Mdot
.588 .52651 Mdot
.588 .52654 Mdot
.588 .52674 Mdot
.588 .52681 Mdot
.588 .52757 Mdot
.588 .52757 Mdot
.588 .52759 Mdot
.588 .52791 Mdot
.588 .52812 Mdot
.588 .5283 Mdot
.588 .52842 Mdot
.588 .52843 Mdot
.588 .52844 Mdot
.588 .52884 Mdot
.588 .52891 Mdot
.588 .52899 Mdot
.588 .52901 Mdot
.588 .52913 Mdot
.588 .52936 Mdot
.588 .52941 Mdot
.588 .52994 Mdot
.588 .53003 Mdot
.588 .53015 Mdot
.588 .53044 Mdot
.588 .53051 Mdot
.588 .53051 Mdot
.588 .53063 Mdot
.588 .53085 Mdot
.588 .53098 Mdot
.588 .53113 Mdot
.588 .53129 Mdot
.588 .53135 Mdot
.588 .53157 Mdot
.588 .53187 Mdot
.588 .53203 Mdot
.588 .53229 Mdot
.588 .53229 Mdot
.588 .53243 Mdot
.588 .53252 Mdot
.588 .53266 Mdot
.588 .53267 Mdot
.588 .53302 Mdot
.588 .53311 Mdot
.588 .53312 Mdot
.588 .5332 Mdot
.588 .53325 Mdot
.588 .53345 Mdot
.588 .53393 Mdot
.588 .53445 Mdot
.588 .5345 Mdot
.588 .53458 Mdot
.588 .53502 Mdot
.588 .53504 Mdot
.588 .53528 Mdot
.588 .53531 Mdot
.588 .53547 Mdot
.588 .53549 Mdot
.588 .5356 Mdot
.588 .53597 Mdot
.588 .53614 Mdot
.588 .53629 Mdot
.588 .53635 Mdot
.588 .53637 Mdot
.588 .53639 Mdot
.588 .5366 Mdot
.588 .53694 Mdot
.588 .53701 Mdot
.588 .53732 Mdot
.588 .53741 Mdot
.588 .53743 Mdot
.588 .53754 Mdot
.588 .53767 Mdot
.588 .53773 Mdot
.588 .53775 Mdot
.588 .53782 Mdot
.588 .53788 Mdot
.588 .53788 Mdot
.588 .53793 Mdot
.588 .53793 Mdot
.588 .53824 Mdot
.588 .53886 Mdot
.588 .53924 Mdot
.588 .53936 Mdot
.588 .5396 Mdot
.588 .53965 Mdot
.588 .5397 Mdot
.588 .53974 Mdot
.588 .53988 Mdot
.588 .5399 Mdot
.588 .54006 Mdot
.588 .54025 Mdot
.588 .54033 Mdot
.588 .54035 Mdot
.588 .54054 Mdot
.588 .54067 Mdot
.588 .54085 Mdot
.588 .541 Mdot
.588 .54108 Mdot
.588 .54126 Mdot
.588 .54171 Mdot
.588 .54175 Mdot
.588 .54182 Mdot
.588 .542 Mdot
.588 .54201 Mdot
.588 .54278 Mdot
.588 .54324 Mdot
.588 .54381 Mdot
.588 .54415 Mdot
.588 .54459 Mdot
.588 .54461 Mdot
.588 .54464 Mdot
.588 .54476 Mdot
.588 .54503 Mdot
.588 .54515 Mdot
.588 .54567 Mdot
.588 .54577 Mdot
.588 .54608 Mdot
.588 .54623 Mdot
.588 .54635 Mdot
.588 .54642 Mdot
.588 .54643 Mdot
.588 .54649 Mdot
.588 .54649 Mdot
.588 .54669 Mdot
.588 .5469 Mdot
.588 .54721 Mdot
.588 .5473 Mdot
.588 .54752 Mdot
.588 .54777 Mdot
.588 .54784 Mdot
.588 .54803 Mdot
.588 .54814 Mdot
.588 .54914 Mdot
.588 .54915 Mdot
.588 .54955 Mdot
.588 .5496 Mdot
.588 .5496 Mdot
.588 .54983 Mdot
.588 .54996 Mdot
.588 .5501 Mdot
.588 .55012 Mdot
.588 .55015 Mdot
.588 .5502 Mdot
.588 .5507 Mdot
.588 .55077 Mdot
.588 .55092 Mdot
.588 .55111 Mdot
.588 .55143 Mdot
.588 .55159 Mdot
.588 .55188 Mdot
.588 .55203 Mdot
.588 .55218 Mdot
.588 .55229 Mdot
.588 .55236 Mdot
.588 .55238 Mdot
.588 .55243 Mdot
.588 .55255 Mdot
.588 .55256 Mdot
.588 .55259 Mdot
.588 .55265 Mdot
.588 .55273 Mdot
.588 .55281 Mdot
.588 .5529 Mdot
.588 .55292 Mdot
.588 .55294 Mdot
.588 .55304 Mdot
.588 .55314 Mdot
.588 .55314 Mdot
.588 .55315 Mdot
.588 .5532 Mdot
.588 .5532 Mdot
.588 .55333 Mdot
.588 .55335 Mdot
.588 .55361 Mdot
.588 .55363 Mdot
.588 .55363 Mdot
.588 .55365 Mdot
.588 .5537 Mdot
.588 .55376 Mdot
.588 .55384 Mdot
.588 .55396 Mdot
.588 .55409 Mdot
.588 .55421 Mdot
.588 .55426 Mdot
.588 .5543 Mdot
.588 .55439 Mdot
.588 .55442 Mdot
.588 .55445 Mdot
.588 .55448 Mdot
.588 .5545 Mdot
.588 .55455 Mdot
.588 .55457 Mdot
.588 .55457 Mdot
.588 .55458 Mdot
.588 .55464 Mdot
.588 .55464 Mdot
.588 .55467 Mdot
.588 .55469 Mdot
.588 .55472 Mdot
.588 .55473 Mdot
.588 .55474 Mdot
.588 .55474 Mdot
.588 .55476 Mdot
.588 .55478 Mdot
.588 .55479 Mdot
.588 .55479 Mdot
.588 .5548 Mdot
.588 .55481 Mdot
.588 .55481 Mdot
.588 .55482 Mdot
.59 .17741 Mdot
.59 .17742 Mdot
.59 .17742 Mdot
.59 .17742 Mdot
.59 .17743 Mdot
.59 .17744 Mdot
.59 .17744 Mdot
.59 .17755 Mdot
.59 .17757 Mdot
.59 .1776 Mdot
.59 .17768 Mdot
.59 .1778 Mdot
.59 .17786 Mdot
.59 .1781 Mdot
.59 .17811 Mdot
.59 .17811 Mdot
.59 .17812 Mdot
.59 .17823 Mdot
.59 .17839 Mdot
.59 .17842 Mdot
.59 .17845 Mdot
.59 .17872 Mdot
.59 .17884 Mdot
.59 .17888 Mdot
.59 .1789 Mdot
.59 .17897 Mdot
.59 .17954 Mdot
.59 .17962 Mdot
.59 .18012 Mdot
.59 .18023 Mdot
.59 .18079 Mdot
.59 .18141 Mdot
.59 .18148 Mdot
.59 .18179 Mdot
.59 .1819 Mdot
.59 .182 Mdot
.59 .18213 Mdot
.59 .18232 Mdot
.59 .18302 Mdot
.59 .18443 Mdot
.59 .18453 Mdot
.59 .18467 Mdot
.59 .18487 Mdot
.59 .18509 Mdot
.59 .18513 Mdot
.59 .18637 Mdot
.59 .1869 Mdot
.59 .18718 Mdot
.59 .18734 Mdot
.59 .18735 Mdot
.59 .18745 Mdot
.59 .18756 Mdot
.59 .18765 Mdot
.59 .1877 Mdot
.59 .18792 Mdot
.59 .1881 Mdot
.59 .18836 Mdot
.59 .18858 Mdot
.59 .18878 Mdot
.59 .18889 Mdot
.59 .18932 Mdot
.59 .18962 Mdot
.59 .18996 Mdot
.59 .19018 Mdot
.59 .19019 Mdot
.59 .19035 Mdot
.59 .19038 Mdot
.59 .19046 Mdot
.59 .19052 Mdot
.59 .19052 Mdot
.59 .19132 Mdot
.59 .19136 Mdot
.59 .19139 Mdot
.59 .19144 Mdot
.59 .19234 Mdot
.59 .19266 Mdot
.59 .19324 Mdot
.59 .19328 Mdot
.59 .19379 Mdot
.59 .19431 Mdot
.59 .1946 Mdot
.59 .19471 Mdot
.59 .19562 Mdot
.59 .19584 Mdot
.59 .19605 Mdot
.59 .19633 Mdot
.59 .19645 Mdot
.59 .1966 Mdot
.59 .19661 Mdot
.59 .19673 Mdot
.59 .19775 Mdot
.59 .19832 Mdot
.59 .19857 Mdot
.59 .19883 Mdot
.59 .19908 Mdot
.59 .19919 Mdot
.59 .19967 Mdot
.59 .20092 Mdot
.59 .20131 Mdot
.59 .20159 Mdot
.59 .20176 Mdot
.59 .20216 Mdot
.59 .20317 Mdot
.59 .20375 Mdot
.59 .20435 Mdot
.59 .2046 Mdot
.59 .20554 Mdot
.59 .20614 Mdot
.59 .20635 Mdot
.59 .20638 Mdot
.59 .20644 Mdot
.59 .20698 Mdot
.59 .20717 Mdot
.59 .20742 Mdot
.59 .20773 Mdot
.59 .20839 Mdot
.59 .2088 Mdot
.59 .20963 Mdot
.59 .20969 Mdot
.59 .21033 Mdot
.59 .21202 Mdot
.59 .2123 Mdot
.59 .2123 Mdot
.59 .21233 Mdot
.59 .21243 Mdot
.59 .21303 Mdot
.59 .21337 Mdot
.59 .21461 Mdot
.59 .21471 Mdot
.59 .21621 Mdot
.59 .21957 Mdot
.59 .2196 Mdot
.59 .22002 Mdot
.59 .22043 Mdot
.59 .22064 Mdot
.59 .22083 Mdot
.59 .22139 Mdot
.59 .22211 Mdot
.59 .22288 Mdot
.59 .22348 Mdot
.59 .22453 Mdot
.59 .22511 Mdot
.59 .22519 Mdot
.59 .22638 Mdot
.59 .2283 Mdot
.59 .22944 Mdot
.59 .23116 Mdot
.59 .23121 Mdot
.59 .23176 Mdot
.59 .23225 Mdot
.59 .23272 Mdot
.59 .23294 Mdot
.59 .23387 Mdot
.59 .23395 Mdot
.59 .23405 Mdot
.59 .23555 Mdot
.59 .23581 Mdot
.59 .23625 Mdot
.59 .23713 Mdot
.59 .23719 Mdot
.59 .23719 Mdot
.59 .23831 Mdot
.59 .23885 Mdot
.59 .24101 Mdot
.59 .2412 Mdot
.59 .24157 Mdot
.59 .24171 Mdot
.59 .24356 Mdot
.59 .24492 Mdot
.59 .24519 Mdot
.59 .2458 Mdot
.59 .24592 Mdot
.59 .24666 Mdot
.59 .24704 Mdot
.59 .2472 Mdot
.59 .24738 Mdot
.59 .24773 Mdot
.59 .24779 Mdot
.59 .24807 Mdot
.59 .2482 Mdot
.59 .24885 Mdot
.59 .24981 Mdot
.59 .25008 Mdot
.59 .2514 Mdot
.59 .25195 Mdot
.59 .25199 Mdot
.59 .25265 Mdot
.59 .25411 Mdot
.59 .25422 Mdot
.59 .255 Mdot
.59 .25594 Mdot
.59 .25758 Mdot
.59 .25918 Mdot
.59 .25951 Mdot
.59 .26036 Mdot
.59 .26079 Mdot
.59 .26091 Mdot
.59 .26115 Mdot
.59 .26141 Mdot
.59 .26431 Mdot
.59 .2658 Mdot
.59 .26709 Mdot
.59 .26837 Mdot
.59 .2692 Mdot
.59 .26933 Mdot
.59 .26974 Mdot
.59 .26976 Mdot
.59 .2699 Mdot
.59 .27032 Mdot
.59 .27099 Mdot
.59 .27117 Mdot
.59 .27202 Mdot
.59 .27307 Mdot
.59 .27319 Mdot
.59 .2737 Mdot
.59 .27466 Mdot
.59 .27505 Mdot
.59 .27554 Mdot
.59 .2762 Mdot
.59 .27728 Mdot
.59 .27738 Mdot
.59 .27763 Mdot
.59 .2778 Mdot
.59 .27879 Mdot
.59 .27914 Mdot
.59 .28012 Mdot
.59 .28065 Mdot
.59 .28183 Mdot
.59 .28187 Mdot
.59 .28288 Mdot
.59 .28307 Mdot
.59 .28367 Mdot
.59 .28398 Mdot
.59 .28444 Mdot
.59 .28456 Mdot
.59 .28502 Mdot
.59 .28531 Mdot
.59 .28582 Mdot
.59 .28592 Mdot
.59 .28605 Mdot
.59 .28616 Mdot
.59 .28618 Mdot
.59 .28636 Mdot
.59 .28669 Mdot
.59 .28894 Mdot
.59 .2897 Mdot
.59 .29187 Mdot
.59 .29297 Mdot
.59 .29352 Mdot
.59 .29387 Mdot
.59 .29442 Mdot
.59 .29687 Mdot
.59 .29826 Mdot
.59 .29999 Mdot
.59 .30019 Mdot
.59 .30076 Mdot
.59 .30174 Mdot
.59 .30452 Mdot
.59 .30613 Mdot
.59 .30778 Mdot
.59 .30815 Mdot
.59 .30821 Mdot
.59 .30828 Mdot
.59 .30841 Mdot
.59 .30872 Mdot
.59 .31015 Mdot
.59 .31166 Mdot
.59 .31216 Mdot
.59 .31276 Mdot
.59 .31385 Mdot
.59 .31502 Mdot
.59 .31504 Mdot
.59 .31505 Mdot
.59 .31509 Mdot
.59 .31554 Mdot
.59 .31617 Mdot
.59 .31638 Mdot
.59 .31766 Mdot
.59 .31778 Mdot
.59 .31957 Mdot
.59 .32092 Mdot
.59 .32231 Mdot
.59 .32349 Mdot
.59 .32434 Mdot
.59 .32473 Mdot
.59 .32821 Mdot
.59 .32853 Mdot
.59 .3288 Mdot
.59 .32914 Mdot
.59 .33071 Mdot
.59 .33228 Mdot
.59 .33253 Mdot
.59 .33326 Mdot
.59 .33472 Mdot
.59 .33495 Mdot
.59 .33512 Mdot
.59 .33523 Mdot
.59 .33529 Mdot
.59 .33529 Mdot
.59 .33609 Mdot
.59 .33613 Mdot
.59 .33707 Mdot
.59 .33796 Mdot
.59 .33842 Mdot
.59 .33915 Mdot
.59 .34004 Mdot
.59 .34087 Mdot
.59 .34089 Mdot
.59 .34099 Mdot
.59 .34229 Mdot
.59 .34271 Mdot
.59 .3429 Mdot
.59 .34463 Mdot
.59 .34526 Mdot
.59 .34644 Mdot
.59 .34834 Mdot
.59 .34901 Mdot
.59 .34922 Mdot
.59 .34994 Mdot
.59 .35048 Mdot
.59 .35053 Mdot
.59 .35204 Mdot
.59 .35221 Mdot
.59 .35221 Mdot
.59 .35229 Mdot
.59 .35267 Mdot
.59 .35289 Mdot
.59 .35366 Mdot
.59 .35463 Mdot
.59 .35664 Mdot
.59 .35735 Mdot
.59 .35808 Mdot
.59 .35944 Mdot
.59 .35976 Mdot
.59 .3598 Mdot
.59 .36149 Mdot
.59 .363 Mdot
.59 .36331 Mdot
.59 .36357 Mdot
.59 .3644 Mdot
.59 .36444 Mdot
.59 .36449 Mdot
.59 .36525 Mdot
.59 .3656 Mdot
.59 .36607 Mdot
.59 .3669 Mdot
.59 .36805 Mdot
.59 .3683 Mdot
.59 .3709 Mdot
.59 .37115 Mdot
.59 .37118 Mdot
.59 .37131 Mdot
.59 .37167 Mdot
.59 .3731 Mdot
.59 .37341 Mdot
.59 .37407 Mdot
.59 .37412 Mdot
.59 .37489 Mdot
.59 .37562 Mdot
.59 .37708 Mdot
.59 .37718 Mdot
.59 .37729 Mdot
.59 .37854 Mdot
.59 .38026 Mdot
.59 .38061 Mdot
.59 .38067 Mdot
.59 .38108 Mdot
.59 .38136 Mdot
.59 .38143 Mdot
.59 .38227 Mdot
.59 .38288 Mdot
.59 .38304 Mdot
.59 .38324 Mdot
.59 .38351 Mdot
.59 .38395 Mdot
.59 .38456 Mdot
.59 .3847 Mdot
.59 .3858 Mdot
.59 .3862 Mdot
.59 .38651 Mdot
.59 .38664 Mdot
.59 .38705 Mdot
.59 .38716 Mdot
.59 .38736 Mdot
.59 .3874 Mdot
.59 .38745 Mdot
.59 .3875 Mdot
.59 .38751 Mdot
.59 .38758 Mdot
.59 .38771 Mdot
.59 .38889 Mdot
.59 .39016 Mdot
.59 .39037 Mdot
.59 .3905 Mdot
.59 .39072 Mdot
.59 .39219 Mdot
.59 .39313 Mdot
.59 .39576 Mdot
.59 .3959 Mdot
.59 .39595 Mdot
.59 .396 Mdot
.59 .39612 Mdot
.59 .39844 Mdot
.59 .39845 Mdot
.59 .39863 Mdot
.59 .39886 Mdot
.59 .39893 Mdot
.59 .3994 Mdot
.59 .39945 Mdot
.59 .40009 Mdot
.59 .40059 Mdot
.59 .40109 Mdot
.59 .40151 Mdot
.59 .40196 Mdot
.59 .40321 Mdot
.59 .40354 Mdot
.59 .4041 Mdot
.59 .40475 Mdot
.59 .40552 Mdot
.59 .40567 Mdot
.59 .40602 Mdot
.59 .40636 Mdot
.59 .40667 Mdot
.59 .40683 Mdot
.59 .40709 Mdot
.59 .4074 Mdot
.59 .4077 Mdot
.59 .40774 Mdot
.59 .40819 Mdot
.59 .40901 Mdot
.59 .41054 Mdot
.59 .41107 Mdot
.59 .41166 Mdot
.59 .41181 Mdot
.59 .41216 Mdot
.59 .41319 Mdot
.59 .41415 Mdot
.59 .41427 Mdot
.59 .41538 Mdot
.59 .41549 Mdot
.59 .41558 Mdot
.59 .41586 Mdot
.59 .41589 Mdot
.59 .41616 Mdot
.59 .4172 Mdot
.59 .4181 Mdot
.59 .41818 Mdot
.59 .41819 Mdot
.59 .41824 Mdot
.59 .42021 Mdot
.59 .42024 Mdot
.59 .42071 Mdot
.59 .42167 Mdot
.59 .42225 Mdot
.59 .42231 Mdot
.59 .42256 Mdot
.59 .42277 Mdot
.59 .42282 Mdot
.59 .42319 Mdot
.59 .42348 Mdot
.59 .42362 Mdot
.59 .42366 Mdot
.59 .42374 Mdot
.59 .42376 Mdot
.59 .42377 Mdot
.59 .42377 Mdot
.59 .4238 Mdot
.59 .42384 Mdot
.59 .42468 Mdot
.59 .42487 Mdot
.59 .42666 Mdot
.59 .42825 Mdot
.59 .42856 Mdot
.59 .42999 Mdot
.59 .43022 Mdot
.59 .43184 Mdot
.59 .43204 Mdot
.59 .4321 Mdot
.59 .43222 Mdot
.59 .43257 Mdot
.59 .43333 Mdot
.59 .4334 Mdot
.59 .4335 Mdot
.59 .43396 Mdot
.59 .43427 Mdot
.59 .4343 Mdot
.59 .4343 Mdot
.59 .43432 Mdot
.59 .435 Mdot
.59 .43517 Mdot
.59 .43551 Mdot
.59 .43573 Mdot
.59 .43582 Mdot
.59 .43589 Mdot
.59 .43618 Mdot
.59 .4362 Mdot
.59 .43623 Mdot
.59 .43623 Mdot
.59 .43624 Mdot
.59 .43625 Mdot
.59 .43626 Mdot
.59 .44701 Mdot
.59 .44702 Mdot
.59 .44702 Mdot
.59 .44703 Mdot
.59 .44703 Mdot
.59 .44705 Mdot
.59 .44705 Mdot
.59 .44723 Mdot
.59 .44727 Mdot
.59 .44732 Mdot
.59 .44745 Mdot
.59 .44764 Mdot
.59 .44774 Mdot
.59 .44813 Mdot
.59 .44814 Mdot
.59 .44814 Mdot
.59 .44816 Mdot
.59 .44834 Mdot
.59 .44861 Mdot
.59 .44866 Mdot
.59 .4487 Mdot
.59 .44913 Mdot
.59 .44934 Mdot
.59 .44941 Mdot
.59 .44944 Mdot
.59 .44955 Mdot
.59 .45047 Mdot
.59 .45061 Mdot
.59 .45141 Mdot
.59 .45159 Mdot
.59 .45248 Mdot
.59 .45347 Mdot
.59 .45358 Mdot
.59 .45404 Mdot
.59 .45407 Mdot
.59 .45408 Mdot
.59 .45408 Mdot
.59 .45409 Mdot
.59 .4541 Mdot
.59 .45415 Mdot
.59 .45417 Mdot
.59 .45424 Mdot
.59 .4544 Mdot
.59 .45461 Mdot
.59 .45464 Mdot
.59 .45475 Mdot
.59 .45488 Mdot
.59 .45492 Mdot
.59 .45524 Mdot
.59 .45576 Mdot
.59 .45602 Mdot
.59 .45604 Mdot
.59 .45711 Mdot
.59 .45713 Mdot
.59 .45714 Mdot
.59 .45718 Mdot
.59 .45767 Mdot
.59 .45823 Mdot
.59 .45837 Mdot
.59 .45839 Mdot
.59 .45854 Mdot
.59 .45859 Mdot
.59 .45864 Mdot
.59 .45924 Mdot
.59 .4593 Mdot
.59 .45982 Mdot
.59 .46036 Mdot
.59 .46054 Mdot
.59 .46063 Mdot
.59 .46094 Mdot
.59 .46122 Mdot
.59 .46202 Mdot
.59 .46245 Mdot
.59 .46269 Mdot
.59 .46271 Mdot
.59 .46286 Mdot
.59 .46302 Mdot
.59 .46316 Mdot
.59 .46324 Mdot
.59 .4634 Mdot
.59 .46358 Mdot
.59 .46376 Mdot
.59 .46384 Mdot
.59 .46424 Mdot
.59 .46457 Mdot
.59 .46486 Mdot
.59 .46503 Mdot
.59 .46567 Mdot
.59 .4659 Mdot
.59 .46612 Mdot
.59 .46637 Mdot
.59 .46662 Mdot
.59 .46695 Mdot
.59 .46697 Mdot
.59 .46721 Mdot
.59 .46725 Mdot
.59 .46737 Mdot
.59 .46746 Mdot
.59 .46746 Mdot
.59 .46863 Mdot
.59 .46869 Mdot
.59 .46871 Mdot
.59 .46874 Mdot
.59 .46881 Mdot
.59 .47012 Mdot
.59 .47059 Mdot
.59 .47132 Mdot
.59 .47143 Mdot
.59 .47149 Mdot
.59 .4716 Mdot
.59 .47222 Mdot
.59 .4728 Mdot
.59 .47286 Mdot
.59 .4729 Mdot
.59 .4729 Mdot
.59 .47292 Mdot
.59 .47295 Mdot
.59 .47297 Mdot
.59 .47306 Mdot
.59 .47312 Mdot
.59 .47332 Mdot
.59 .47338 Mdot
.59 .47354 Mdot
.59 .47373 Mdot
.59 .47426 Mdot
.59 .47433 Mdot
.59 .47463 Mdot
.59 .47484 Mdot
.59 .47497 Mdot
.59 .47507 Mdot
.59 .47515 Mdot
.59 .47544 Mdot
.59 .47584 Mdot
.59 .47588 Mdot
.59 .47601 Mdot
.59 .47621 Mdot
.59 .47624 Mdot
.59 .4764 Mdot
.59 .47722 Mdot
.59 .47782 Mdot
.59 .47787 Mdot
.59 .47792 Mdot
.59 .47861 Mdot
.59 .47896 Mdot
.59 .47932 Mdot
.59 .47965 Mdot
.59 .4798 Mdot
.59 .48047 Mdot
.59 .48064 Mdot
.59 .4807 Mdot
.59 .48071 Mdot
.59 .48083 Mdot
.59 .48204 Mdot
.59 .48215 Mdot
.59 .48268 Mdot
.59 .48306 Mdot
.59 .48328 Mdot
.59 .48344 Mdot
.59 .48379 Mdot
.59 .48382 Mdot
.59 .48383 Mdot
.59 .48421 Mdot
.59 .48433 Mdot
.59 .48447 Mdot
.59 .48516 Mdot
.59 .48593 Mdot
.59 .48595 Mdot
.59 .48609 Mdot
.59 .48671 Mdot
.59 .48704 Mdot
.59 .48736 Mdot
.59 .48826 Mdot
.59 .48869 Mdot
.59 .48903 Mdot
.59 .48913 Mdot
.59 .4893 Mdot
.59 .48933 Mdot
.59 .48933 Mdot
.59 .48941 Mdot
.59 .49008 Mdot
.59 .4901 Mdot
.59 .49034 Mdot
.59 .49066 Mdot
.59 .49075 Mdot
.59 .49105 Mdot
.59 .49188 Mdot
.59 .4924 Mdot
.59 .49267 Mdot
.59 .49343 Mdot
.59 .49351 Mdot
.59 .49369 Mdot
.59 .49426 Mdot
.59 .4943 Mdot
.59 .49431 Mdot
.59 .49466 Mdot
.59 .49505 Mdot
.59 .49536 Mdot
.59 .49556 Mdot
.59 .49594 Mdot
.59 .49635 Mdot
.59 .49636 Mdot
.59 .4967 Mdot
.59 .4967 Mdot
.59 .49673 Mdot
.59 .49678 Mdot
.59 .49685 Mdot
.59 .49695 Mdot
.59 .49757 Mdot
.59 .49788 Mdot
.59 .49799 Mdot
.59 .49865 Mdot
.59 .49931 Mdot
.59 .49946 Mdot
.59 .49957 Mdot
.59 .4997 Mdot
.59 .50116 Mdot
.59 .50132 Mdot
.59 .50168 Mdot
.59 .50217 Mdot
.59 .50274 Mdot
.59 .5033 Mdot
.59 .50404 Mdot
.59 .50409 Mdot
.59 .50462 Mdot
.59 .5047 Mdot
.59 .50496 Mdot
.59 .50514 Mdot
.59 .50516 Mdot
.59 .50516 Mdot
.59 .50517 Mdot
.59 .50565 Mdot
.59 .50609 Mdot
.59 .50633 Mdot
.59 .50654 Mdot
.59 .50715 Mdot
.59 .50773 Mdot
.59 .50785 Mdot
.59 .50791 Mdot
.59 .50793 Mdot
.59 .50796 Mdot
.59 .50811 Mdot
.59 .50877 Mdot
.59 .50941 Mdot
.59 .51052 Mdot
.59 .51091 Mdot
.59 .51114 Mdot
.59 .51122 Mdot
.59 .5119 Mdot
.59 .51245 Mdot
.59 .51341 Mdot
.59 .51363 Mdot
.59 .51377 Mdot
.59 .51398 Mdot
.59 .51441 Mdot
.59 .51526 Mdot
.59 .51555 Mdot
.59 .51642 Mdot
.59 .51655 Mdot
.59 .51662 Mdot
.59 .51663 Mdot
.59 .51667 Mdot
.59 .51672 Mdot
.59 .51676 Mdot
.59 .51695 Mdot
.59 .51707 Mdot
.59 .51724 Mdot
.59 .51729 Mdot
.59 .51747 Mdot
.59 .51759 Mdot
.59 .51782 Mdot
.59 .51789 Mdot
.59 .51828 Mdot
.59 .51829 Mdot
.59 .51874 Mdot
.59 .51895 Mdot
.59 .51932 Mdot
.59 .51945 Mdot
.59 .51983 Mdot
.59 .5199 Mdot
.59 .51999 Mdot
.59 .52003 Mdot
.59 .52044 Mdot
.59 .52069 Mdot
.59 .52087 Mdot
.59 .52102 Mdot
.59 .52138 Mdot
.59 .52158 Mdot
.59 .52162 Mdot
.59 .52202 Mdot
.59 .52234 Mdot
.59 .5224 Mdot
.59 .52265 Mdot
.59 .52281 Mdot
.59 .52287 Mdot
.59 .52287 Mdot
.59 .52303 Mdot
.59 .52308 Mdot
.59 .52339 Mdot
.59 .52387 Mdot
.59 .52434 Mdot
.59 .5249 Mdot
.59 .52597 Mdot
.59 .52607 Mdot
.59 .52616 Mdot
.59 .5262 Mdot
.59 .52636 Mdot
.59 .52667 Mdot
.59 .5268 Mdot
.59 .52738 Mdot
.59 .52798 Mdot
.59 .52833 Mdot
.59 .52861 Mdot
.59 .52865 Mdot
.59 .52919 Mdot
.59 .52943 Mdot
.59 .52944 Mdot
.59 .52964 Mdot
.59 .53012 Mdot
.59 .53022 Mdot
.59 .53056 Mdot
.59 .5308 Mdot
.59 .53084 Mdot
.59 .53095 Mdot
.59 .53097 Mdot
.59 .53109 Mdot
.59 .53116 Mdot
.59 .53122 Mdot
.59 .53135 Mdot
.59 .53162 Mdot
.59 .53167 Mdot
.59 .53188 Mdot
.59 .53198 Mdot
.59 .53247 Mdot
.59 .53313 Mdot
.59 .53318 Mdot
.59 .53332 Mdot
.59 .53338 Mdot
.59 .53415 Mdot
.59 .53434 Mdot
.59 .53474 Mdot
.59 .53474 Mdot
.59 .53476 Mdot
.59 .53508 Mdot
.59 .53523 Mdot
.59 .53532 Mdot
.59 .53586 Mdot
.59 .53589 Mdot
.59 .53592 Mdot
.59 .53625 Mdot
.59 .53632 Mdot
.59 .53649 Mdot
.59 .53666 Mdot
.59 .53685 Mdot
.59 .53687 Mdot
.59 .53748 Mdot
.59 .53788 Mdot
.59 .53855 Mdot
.59 .53896 Mdot
.59 .53899 Mdot
.59 .53919 Mdot
.59 .53956 Mdot
.59 .53977 Mdot
.59 .54004 Mdot
.59 .54028 Mdot
.59 .54048 Mdot
.59 .54054 Mdot
.59 .54062 Mdot
.59 .54076 Mdot
.59 .5409 Mdot
.59 .54091 Mdot
.59 .54207 Mdot
.59 .54259 Mdot
.59 .54262 Mdot
.59 .54305 Mdot
.59 .54317 Mdot
.59 .54337 Mdot
.59 .5434 Mdot
.59 .54341 Mdot
.59 .54341 Mdot
.59 .54351 Mdot
.59 .54409 Mdot
.59 .5443 Mdot
.59 .54433 Mdot
.59 .54461 Mdot
.59 .54475 Mdot
.59 .54497 Mdot
.59 .54508 Mdot
.59 .54516 Mdot
.59 .54523 Mdot
.59 .54541 Mdot
.59 .54543 Mdot
.59 .54544 Mdot
.59 .54551 Mdot
.59 .54571 Mdot
.59 .54603 Mdot
.59 .54612 Mdot
.59 .54632 Mdot
.59 .54651 Mdot
.59 .54686 Mdot
.59 .54699 Mdot
.59 .54705 Mdot
.59 .54714 Mdot
.59 .54727 Mdot
.59 .54769 Mdot
.59 .54786 Mdot
.59 .54789 Mdot
.59 .54797 Mdot
.59 .54806 Mdot
.59 .54814 Mdot
.59 .54834 Mdot
.59 .54868 Mdot
.59 .54872 Mdot
.59 .54872 Mdot
.59 .54877 Mdot
.59 .54881 Mdot
.59 .54891 Mdot
.59 .54898 Mdot
.59 .54905 Mdot
.59 .54935 Mdot
.59 .54939 Mdot
.59 .54949 Mdot
.59 .54966 Mdot
.59 .54983 Mdot
.59 .54984 Mdot
.59 .55004 Mdot
.59 .55014 Mdot
.59 .55044 Mdot
.59 .55046 Mdot
.59 .55047 Mdot
.59 .55048 Mdot
.59 .55075 Mdot
.59 .55075 Mdot
.59 .55077 Mdot
.59 .55079 Mdot
.59 .5508 Mdot
.59 .55085 Mdot
.59 .55086 Mdot
.59 .55093 Mdot
.59 .55105 Mdot
.59 .55114 Mdot
.59 .55129 Mdot
.59 .55132 Mdot
.59 .55139 Mdot
.59 .55146 Mdot
.59 .55155 Mdot
.59 .55161 Mdot
.59 .55168 Mdot
.59 .5517 Mdot
.59 .55173 Mdot
.59 .55176 Mdot
.59 .55179 Mdot
.59 .5518 Mdot
.59 .55185 Mdot
.59 .55194 Mdot
.59 .55212 Mdot
.59 .55253 Mdot
.59 .55254 Mdot
.59 .55261 Mdot
.59 .55268 Mdot
.59 .55273 Mdot
.59 .55276 Mdot
.59 .55322 Mdot
.59 .55345 Mdot
.59 .55351 Mdot
.59 .55356 Mdot
.59 .55359 Mdot
.59 .55362 Mdot
.59 .55373 Mdot
.59 .55375 Mdot
.59 .55395 Mdot
.59 .55413 Mdot
.59 .55417 Mdot
.59 .55433 Mdot
.59 .55436 Mdot
.59 .55454 Mdot
.59 .55457 Mdot
.59 .55457 Mdot
.59 .55459 Mdot
.59 .55463 Mdot
.59 .55472 Mdot
.59 .55472 Mdot
.59 .55473 Mdot
.59 .55479 Mdot
.59 .55482 Mdot
.59 .55483 Mdot
.59 .55483 Mdot
.59 .55483 Mdot
.59 .55491 Mdot
.59 .55493 Mdot
.59 .55497 Mdot
.59 .55499 Mdot
.59 .555 Mdot
.59 .55501 Mdot
.59 .55504 Mdot
.59 .55505 Mdot
.59 .55505 Mdot
.59 .55505 Mdot
.59 .55505 Mdot
.59 .55505 Mdot
.59 .55505 Mdot
.592 .17676 Mdot
.592 .17677 Mdot
.592 .17678 Mdot
.592 .17679 Mdot
.592 .17682 Mdot
.592 .17685 Mdot
.592 .17685 Mdot
.592 .17694 Mdot
.592 .17704 Mdot
.592 .1771 Mdot
.592 .17719 Mdot
.592 .17731 Mdot
.592 .17732 Mdot
.592 .17735 Mdot
.592 .17742 Mdot
.592 .17754 Mdot
.592 .17755 Mdot
.592 .17755 Mdot
.592 .17788 Mdot
.592 .17798 Mdot
.592 .17799 Mdot
.592 .17804 Mdot
.592 .17812 Mdot
.592 .17812 Mdot
.592 .17819 Mdot
.592 .17866 Mdot
.592 .17877 Mdot
.592 .17899 Mdot
.592 .17948 Mdot
.592 .17969 Mdot
.592 .17978 Mdot
.592 .18001 Mdot
.592 .1803 Mdot
.592 .18037 Mdot
.592 .18058 Mdot
.592 .18069 Mdot
.592 .18082 Mdot
.592 .18103 Mdot
.592 .18111 Mdot
.592 .18155 Mdot
.592 .18164 Mdot
.592 .18191 Mdot
.592 .18207 Mdot
.592 .18222 Mdot
.592 .18223 Mdot
.592 .18225 Mdot
.592 .1823 Mdot
.592 .18273 Mdot
.592 .18281 Mdot
.592 .18332 Mdot
.592 .18356 Mdot
.592 .18439 Mdot
.592 .18455 Mdot
.592 .18531 Mdot
.592 .18589 Mdot
.592 .18589 Mdot
.592 .18613 Mdot
.592 .18623 Mdot
.592 .18647 Mdot
.592 .18697 Mdot
.592 .18717 Mdot
.592 .18729 Mdot
.592 .18751 Mdot
.592 .18768 Mdot
.592 .18885 Mdot
.592 .18896 Mdot
.592 .18928 Mdot
.592 .19088 Mdot
.592 .19118 Mdot
.592 .19153 Mdot
.592 .19168 Mdot
.592 .19186 Mdot
.592 .1919 Mdot
.592 .19197 Mdot
.592 .19225 Mdot
.592 .19334 Mdot
.592 .19419 Mdot
.592 .19489 Mdot
.592 .19536 Mdot
.592 .19543 Mdot
.592 .19611 Mdot
.592 .19667 Mdot
.592 .19668 Mdot
.592 .19676 Mdot
.592 .19708 Mdot
.592 .19712 Mdot
.592 .19755 Mdot
.592 .19833 Mdot
.592 .19879 Mdot
.592 .19883 Mdot
.592 .19894 Mdot
.592 .19956 Mdot
.592 .20009 Mdot
.592 .20048 Mdot
.592 .20064 Mdot
.592 .20071 Mdot
.592 .20098 Mdot
.592 .20099 Mdot
.592 .20132 Mdot
.592 .20242 Mdot
.592 .20303 Mdot
.592 .2032 Mdot
.592 .20429 Mdot
.592 .20538 Mdot
.592 .20675 Mdot
.592 .20724 Mdot
.592 .20728 Mdot
.592 .2074 Mdot
.592 .20826 Mdot
.592 .20846 Mdot
.592 .20883 Mdot
.592 .20892 Mdot
.592 .20954 Mdot
.592 .20976 Mdot
.592 .21149 Mdot
.592 .21156 Mdot
.592 .21161 Mdot
.592 .213 Mdot
.592 .21329 Mdot
.592 .21349 Mdot
.592 .21363 Mdot
.592 .21373 Mdot
.592 .2155 Mdot
.592 .21569 Mdot
.592 .2159 Mdot
.592 .21635 Mdot
.592 .21771 Mdot
.592 .21857 Mdot
.592 .21966 Mdot
.592 .22128 Mdot
.592 .22209 Mdot
.592 .22365 Mdot
.592 .22404 Mdot
.592 .22637 Mdot
.592 .22697 Mdot
.592 .22705 Mdot
.592 .22768 Mdot
.592 .22795 Mdot
.592 .22804 Mdot
.592 .22804 Mdot
.592 .2288 Mdot
.592 .23062 Mdot
.592 .23128 Mdot
.592 .23133 Mdot
.592 .23146 Mdot
.592 .23332 Mdot
.592 .23373 Mdot
.592 .23418 Mdot
.592 .23432 Mdot
.592 .23433 Mdot
.592 .23567 Mdot
.592 .2377 Mdot
.592 .23858 Mdot
.592 .23898 Mdot
.592 .23964 Mdot
.592 .23969 Mdot
.592 .24129 Mdot
.592 .24167 Mdot
.592 .24177 Mdot
.592 .24233 Mdot
.592 .24247 Mdot
.592 .24264 Mdot
.592 .24272 Mdot
.592 .2429 Mdot
.592 .24332 Mdot
.592 .24395 Mdot
.592 .24514 Mdot
.592 .24609 Mdot
.592 .24841 Mdot
.592 .24871 Mdot
.592 .24891 Mdot
.592 .24904 Mdot
.592 .2495 Mdot
.592 .251 Mdot
.592 .25245 Mdot
.592 .25312 Mdot
.592 .25313 Mdot
.592 .25342 Mdot
.592 .25363 Mdot
.592 .25468 Mdot
.592 .25503 Mdot
.592 .25598 Mdot
.592 .25638 Mdot
.592 .25638 Mdot
.592 .25658 Mdot
.592 .25696 Mdot
.592 .25728 Mdot
.592 .25856 Mdot
.592 .25877 Mdot
.592 .25964 Mdot
.592 .26166 Mdot
.592 .26297 Mdot
.592 .26336 Mdot
.592 .26348 Mdot
.592 .26456 Mdot
.592 .26462 Mdot
.592 .26483 Mdot
.592 .26501 Mdot
.592 .26596 Mdot
.592 .26707 Mdot
.592 .26762 Mdot
.592 .26768 Mdot
.592 .26806 Mdot
.592 .27168 Mdot
.592 .27294 Mdot
.592 .27319 Mdot
.592 .27339 Mdot
.592 .27357 Mdot
.592 .27387 Mdot
.592 .27427 Mdot
.592 .27476 Mdot
.592 .27484 Mdot
.592 .27622 Mdot
.592 .27624 Mdot
.592 .27651 Mdot
.592 .27658 Mdot
.592 .27705 Mdot
.592 .27769 Mdot
.592 .27809 Mdot
.592 .2787 Mdot
.592 .28045 Mdot
.592 .28072 Mdot
.592 .28147 Mdot
.592 .28337 Mdot
.592 .2837 Mdot
.592 .28381 Mdot
.592 .28525 Mdot
.592 .2855 Mdot
.592 .28564 Mdot
.592 .28684 Mdot
.592 .28713 Mdot
.592 .28784 Mdot
.592 .28903 Mdot
.592 .29015 Mdot
.592 .29199 Mdot
.592 .29211 Mdot
.592 .29211 Mdot
.592 .29236 Mdot
.592 .29304 Mdot
.592 .29469 Mdot
.592 .29489 Mdot
.592 .29527 Mdot
.592 .29646 Mdot
.592 .29879 Mdot
.592 .30039 Mdot
.592 .3006 Mdot
.592 .30083 Mdot
.592 .3026 Mdot
.592 .30264 Mdot
.592 .30313 Mdot
.592 .30347 Mdot
.592 .30367 Mdot
.592 .3043 Mdot
.592 .30482 Mdot
.592 .30517 Mdot
.592 .30599 Mdot
.592 .30784 Mdot
.592 .3083 Mdot
.592 .30881 Mdot
.592 .31003 Mdot
.592 .31073 Mdot
.592 .31114 Mdot
.592 .31121 Mdot
.592 .31444 Mdot
.592 .31542 Mdot
.592 .31667 Mdot
.592 .31699 Mdot
.592 .31702 Mdot
.592 .31744 Mdot
.592 .31897 Mdot
.592 .3198 Mdot
.592 .32094 Mdot
.592 .32139 Mdot
.592 .32204 Mdot
.592 .32263 Mdot
.592 .32359 Mdot
.592 .32395 Mdot
.592 .32409 Mdot
.592 .32485 Mdot
.592 .32542 Mdot
.592 .32596 Mdot
.592 .32669 Mdot
.592 .32681 Mdot
.592 .32755 Mdot
.592 .32922 Mdot
.592 .3309 Mdot
.592 .3313 Mdot
.592 .33159 Mdot
.592 .33216 Mdot
.592 .33296 Mdot
.592 .33628 Mdot
.592 .33691 Mdot
.592 .33705 Mdot
.592 .33721 Mdot
.592 .33725 Mdot
.592 .33858 Mdot
.592 .34041 Mdot
.592 .34146 Mdot
.592 .34217 Mdot
.592 .3428 Mdot
.592 .34315 Mdot
.592 .34458 Mdot
.592 .34484 Mdot
.592 .34591 Mdot
.592 .34647 Mdot
.592 .34725 Mdot
.592 .34801 Mdot
.592 .34896 Mdot
.592 .34929 Mdot
.592 .34932 Mdot
.592 .3494 Mdot
.592 .35011 Mdot
.592 .35082 Mdot
.592 .35212 Mdot
.592 .35215 Mdot
.592 .35333 Mdot
.592 .35479 Mdot
.592 .35588 Mdot
.592 .35701 Mdot
.592 .35794 Mdot
.592 .36112 Mdot
.592 .3616 Mdot
.592 .36337 Mdot
.592 .36344 Mdot
.592 .36484 Mdot
.592 .3666 Mdot
.592 .36723 Mdot
.592 .36755 Mdot
.592 .36757 Mdot
.592 .36835 Mdot
.592 .36858 Mdot
.592 .36885 Mdot
.592 .36892 Mdot
.592 .36904 Mdot
.592 .37018 Mdot
.592 .37063 Mdot
.592 .37171 Mdot
.592 .37185 Mdot
.592 .372 Mdot
.592 .37221 Mdot
.592 .37355 Mdot
.592 .37386 Mdot
.592 .37386 Mdot
.592 .37399 Mdot
.592 .37455 Mdot
.592 .37531 Mdot
.592 .37761 Mdot
.592 .37818 Mdot
.592 .37886 Mdot
.592 .37888 Mdot
.592 .37897 Mdot
.592 .37992 Mdot
.592 .38015 Mdot
.592 .38018 Mdot
.592 .38184 Mdot
.592 .38247 Mdot
.592 .38255 Mdot
.592 .38262 Mdot
.592 .38275 Mdot
.592 .38291 Mdot
.592 .38311 Mdot
.592 .38314 Mdot
.592 .38382 Mdot
.592 .38404 Mdot
.592 .38446 Mdot
.592 .38541 Mdot
.592 .38552 Mdot
.592 .38582 Mdot
.592 .38732 Mdot
.592 .38747 Mdot
.592 .38794 Mdot
.592 .38806 Mdot
.592 .38833 Mdot
.592 .3888 Mdot
.592 .38994 Mdot
.592 .39121 Mdot
.592 .39254 Mdot
.592 .39315 Mdot
.592 .39323 Mdot
.592 .39332 Mdot
.592 .39398 Mdot
.592 .39418 Mdot
.592 .39431 Mdot
.592 .39462 Mdot
.592 .39481 Mdot
.592 .39495 Mdot
.592 .39525 Mdot
.592 .39611 Mdot
.592 .3963 Mdot
.592 .39701 Mdot
.592 .39716 Mdot
.592 .39718 Mdot
.592 .39873 Mdot
.592 .39918 Mdot
.592 .3993 Mdot
.592 .39931 Mdot
.592 .40002 Mdot
.592 .40073 Mdot
.592 .40089 Mdot
.592 .40113 Mdot
.592 .40134 Mdot
.592 .40182 Mdot
.592 .40187 Mdot
.592 .4028 Mdot
.592 .40284 Mdot
.592 .4031 Mdot
.592 .4037 Mdot
.592 .40444 Mdot
.592 .4062 Mdot
.592 .40653 Mdot
.592 .40701 Mdot
.592 .40765 Mdot
.592 .40802 Mdot
.592 .40861 Mdot
.592 .41004 Mdot
.592 .41031 Mdot
.592 .41076 Mdot
.592 .41103 Mdot
.592 .41173 Mdot
.592 .41174 Mdot
.592 .41215 Mdot
.592 .41303 Mdot
.592 .41342 Mdot
.592 .41564 Mdot
.592 .41611 Mdot
.592 .41693 Mdot
.592 .41749 Mdot
.592 .41751 Mdot
.592 .4181 Mdot
.592 .41851 Mdot
.592 .41857 Mdot
.592 .41864 Mdot
.592 .4192 Mdot
.592 .41944 Mdot
.592 .42068 Mdot
.592 .42091 Mdot
.592 .42214 Mdot
.592 .42217 Mdot
.592 .42219 Mdot
.592 .42223 Mdot
.592 .42229 Mdot
.592 .42236 Mdot
.592 .42237 Mdot
.592 .42282 Mdot
.592 .42318 Mdot
.592 .42328 Mdot
.592 .42379 Mdot
.592 .42401 Mdot
.592 .42405 Mdot
.592 .42414 Mdot
.592 .4243 Mdot
.592 .42512 Mdot
.592 .42558 Mdot
.592 .42581 Mdot
.592 .42584 Mdot
.592 .42628 Mdot
.592 .42639 Mdot
.592 .42679 Mdot
.592 .4271 Mdot
.592 .42716 Mdot
.592 .42768 Mdot
.592 .42784 Mdot
.592 .42788 Mdot
.592 .42788 Mdot
.592 .42813 Mdot
.592 .42837 Mdot
.592 .42842 Mdot
.592 .4285 Mdot
.592 .42858 Mdot
.592 .42874 Mdot
.592 .42938 Mdot
.592 .42964 Mdot
.592 .43024 Mdot
.592 .43165 Mdot
.592 .43228 Mdot
.592 .43258 Mdot
.592 .43393 Mdot
.592 .43412 Mdot
.592 .43413 Mdot
.592 .43433 Mdot
.592 .43449 Mdot
.592 .43452 Mdot
.592 .4348 Mdot
.592 .43574 Mdot
.592 .43575 Mdot
.592 .43576 Mdot
.592 .43609 Mdot
.592 .4363 Mdot
.592 .43638 Mdot
.592 .43642 Mdot
.592 .43677 Mdot
.592 .43702 Mdot
.592 .43717 Mdot
.592 .43747 Mdot
.592 .43771 Mdot
.592 .43773 Mdot
.592 .43781 Mdot
.592 .4379 Mdot
.592 .43792 Mdot
.592 .43795 Mdot
.592 .43797 Mdot
.592 .44612 Mdot
.592 .44614 Mdot
.592 .44615 Mdot
.592 .44616 Mdot
.592 .44621 Mdot
.592 .44626 Mdot
.592 .44627 Mdot
.592 .44641 Mdot
.592 .44659 Mdot
.592 .44668 Mdot
.592 .44682 Mdot
.592 .44702 Mdot
.592 .44705 Mdot
.592 .44709 Mdot
.592 .44721 Mdot
.592 .4474 Mdot
.592 .44741 Mdot
.592 .44742 Mdot
.592 .44796 Mdot
.592 .44812 Mdot
.592 .44814 Mdot
.592 .44823 Mdot
.592 .44835 Mdot
.592 .44835 Mdot
.592 .44846 Mdot
.592 .44923 Mdot
.592 .4494 Mdot
.592 .44977 Mdot
.592 .45057 Mdot
.592 .45091 Mdot
.592 .45105 Mdot
.592 .45141 Mdot
.592 .4515 Mdot
.592 .45154 Mdot
.592 .45159 Mdot
.592 .45162 Mdot
.592 .45176 Mdot
.592 .45189 Mdot
.592 .45189 Mdot
.592 .45192 Mdot
.592 .452 Mdot
.592 .4523 Mdot
.592 .45233 Mdot
.592 .4525 Mdot
.592 .45273 Mdot
.592 .45279 Mdot
.592 .45303 Mdot
.592 .45305 Mdot
.592 .45318 Mdot
.592 .45343 Mdot
.592 .45389 Mdot
.592 .45398 Mdot
.592 .45403 Mdot
.592 .45405 Mdot
.592 .45417 Mdot
.592 .45445 Mdot
.592 .45451 Mdot
.592 .4547 Mdot
.592 .45495 Mdot
.592 .45496 Mdot
.592 .45499 Mdot
.592 .45503 Mdot
.592 .45505 Mdot
.592 .45506 Mdot
.592 .45508 Mdot
.592 .45575 Mdot
.592 .45588 Mdot
.592 .45655 Mdot
.592 .45668 Mdot
.592 .45699 Mdot
.592 .45703 Mdot
.592 .45705 Mdot
.592 .45728 Mdot
.592 .45759 Mdot
.592 .45761 Mdot
.592 .45791 Mdot
.592 .45835 Mdot
.592 .4586 Mdot
.592 .45978 Mdot
.592 .45999 Mdot
.592 .46046 Mdot
.592 .46067 Mdot
.592 .46068 Mdot
.592 .46105 Mdot
.592 .46119 Mdot
.592 .46143 Mdot
.592 .46157 Mdot
.592 .46232 Mdot
.592 .46263 Mdot
.592 .46282 Mdot
.592 .46315 Mdot
.592 .4634 Mdot
.592 .46357 Mdot
.592 .46448 Mdot
.592 .46486 Mdot
.592 .46517 Mdot
.592 .46533 Mdot
.592 .4658 Mdot
.592 .46583 Mdot
.592 .46607 Mdot
.592 .46618 Mdot
.592 .4663 Mdot
.592 .46638 Mdot
.592 .46675 Mdot
.592 .4671 Mdot
.592 .46711 Mdot
.592 .46717 Mdot
.592 .4674 Mdot
.592 .46818 Mdot
.592 .46819 Mdot
.592 .46827 Mdot
.592 .46862 Mdot
.592 .46872 Mdot
.592 .46915 Mdot
.592 .4693 Mdot
.592 .46937 Mdot
.592 .46946 Mdot
.592 .46962 Mdot
.592 .46968 Mdot
.592 .46978 Mdot
.592 .47011 Mdot
.592 .47015 Mdot
.592 .4702 Mdot
.592 .4705 Mdot
.592 .47116 Mdot
.592 .47178 Mdot
.592 .47235 Mdot
.592 .47257 Mdot
.592 .47271 Mdot
.592 .47276 Mdot
.592 .47299 Mdot
.592 .47307 Mdot
.592 .4738 Mdot
.592 .47395 Mdot
.592 .474 Mdot
.592 .47446 Mdot
.592 .47466 Mdot
.592 .47477 Mdot
.592 .47509 Mdot
.592 .47511 Mdot
.592 .47521 Mdot
.592 .47529 Mdot
.592 .47535 Mdot
.592 .47538 Mdot
.592 .47542 Mdot
.592 .47572 Mdot
.592 .47652 Mdot
.592 .47653 Mdot
.592 .47664 Mdot
.592 .47709 Mdot
.592 .47714 Mdot
.592 .47715 Mdot
.592 .47747 Mdot
.592 .47774 Mdot
.592 .47883 Mdot
.592 .47919 Mdot
.592 .47945 Mdot
.592 .47952 Mdot
.592 .47952 Mdot
.592 .47966 Mdot
.592 .48029 Mdot
.592 .48039 Mdot
.592 .48046 Mdot
.592 .48052 Mdot
.592 .48102 Mdot
.592 .48123 Mdot
.592 .48177 Mdot
.592 .48182 Mdot
.592 .48185 Mdot
.592 .48198 Mdot
.592 .48208 Mdot
.592 .48244 Mdot
.592 .48246 Mdot
.592 .4826 Mdot
.592 .48289 Mdot
.592 .4837 Mdot
.592 .48434 Mdot
.592 .48437 Mdot
.592 .48518 Mdot
.592 .4854 Mdot
.592 .48684 Mdot
.592 .48726 Mdot
.592 .48777 Mdot
.592 .48825 Mdot
.592 .4889 Mdot
.592 .48943 Mdot
.592 .48944 Mdot
.592 .49002 Mdot
.592 .49033 Mdot
.592 .49065 Mdot
.592 .49068 Mdot
.592 .49069 Mdot
.592 .49084 Mdot
.592 .49125 Mdot
.592 .49159 Mdot
.592 .49193 Mdot
.592 .49218 Mdot
.592 .49264 Mdot
.592 .49276 Mdot
.592 .49338 Mdot
.592 .49353 Mdot
.592 .49381 Mdot
.592 .49411 Mdot
.592 .49457 Mdot
.592 .49536 Mdot
.592 .49593 Mdot
.592 .49594 Mdot
.592 .49601 Mdot
.592 .49607 Mdot
.592 .49634 Mdot
.592 .49776 Mdot
.592 .4981 Mdot
.592 .49834 Mdot
.592 .49846 Mdot
.592 .49863 Mdot
.592 .49934 Mdot
.592 .50004 Mdot
.592 .50035 Mdot
.592 .5004 Mdot
.592 .5007 Mdot
.592 .50093 Mdot
.592 .50117 Mdot
.592 .50148 Mdot
.592 .50154 Mdot
.592 .50169 Mdot
.592 .50209 Mdot
.592 .50234 Mdot
.592 .50261 Mdot
.592 .50279 Mdot
.592 .50326 Mdot
.592 .5036 Mdot
.592 .50423 Mdot
.592 .50441 Mdot
.592 .50442 Mdot
.592 .50455 Mdot
.592 .50506 Mdot
.592 .50546 Mdot
.592 .50678 Mdot
.592 .5068 Mdot
.592 .50697 Mdot
.592 .50725 Mdot
.592 .50775 Mdot
.592 .50795 Mdot
.592 .50813 Mdot
.592 .50888 Mdot
.592 .50921 Mdot
.592 .50935 Mdot
.592 .50955 Mdot
.592 .5098 Mdot
.592 .50988 Mdot
.592 .51002 Mdot
.592 .51022 Mdot
.592 .51023 Mdot
.592 .51093 Mdot
.592 .51102 Mdot
.592 .51111 Mdot
.592 .51174 Mdot
.592 .51266 Mdot
.592 .51313 Mdot
.592 .51328 Mdot
.592 .51335 Mdot
.592 .514 Mdot
.592 .51427 Mdot
.592 .51436 Mdot
.592 .51437 Mdot
.592 .51441 Mdot
.592 .51513 Mdot
.592 .51556 Mdot
.592 .51602 Mdot
.592 .5163 Mdot
.592 .51641 Mdot
.592 .51687 Mdot
.592 .51693 Mdot
.592 .51702 Mdot
.592 .51758 Mdot
.592 .51762 Mdot
.592 .51775 Mdot
.592 .51848 Mdot
.592 .51876 Mdot
.592 .51886 Mdot
.592 .51953 Mdot
.592 .51976 Mdot
.592 .51992 Mdot
.592 .52016 Mdot
.592 .52034 Mdot
.592 .52036 Mdot
.592 .52046 Mdot
.592 .52047 Mdot
.592 .52099 Mdot
.592 .52102 Mdot
.592 .52121 Mdot
.592 .52136 Mdot
.592 .52147 Mdot
.592 .52154 Mdot
.592 .52162 Mdot
.592 .52171 Mdot
.592 .52219 Mdot
.592 .52354 Mdot
.592 .52368 Mdot
.592 .52371 Mdot
.592 .52391 Mdot
.592 .52433 Mdot
.592 .52468 Mdot
.592 .52474 Mdot
.592 .52482 Mdot
.592 .52485 Mdot
.592 .52525 Mdot
.592 .52529 Mdot
.592 .52544 Mdot
.592 .52592 Mdot
.592 .52667 Mdot
.592 .52698 Mdot
.592 .52706 Mdot
.592 .52753 Mdot
.592 .52765 Mdot
.592 .52779 Mdot
.592 .52786 Mdot
.592 .52786 Mdot
.592 .52801 Mdot
.592 .52836 Mdot
.592 .52848 Mdot
.592 .52886 Mdot
.592 .52894 Mdot
.592 .52905 Mdot
.592 .52905 Mdot
.592 .5293 Mdot
.592 .52982 Mdot
.592 .53037 Mdot
.592 .53053 Mdot
.592 .53058 Mdot
.592 .53065 Mdot
.592 .53076 Mdot
.592 .53159 Mdot
.592 .53194 Mdot
.592 .53237 Mdot
.592 .53259 Mdot
.592 .53274 Mdot
.592 .53281 Mdot
.592 .53284 Mdot
.592 .5329 Mdot
.592 .53295 Mdot
.592 .53315 Mdot
.592 .53318 Mdot
.592 .53332 Mdot
.592 .53389 Mdot
.592 .53391 Mdot
.592 .53414 Mdot
.592 .53428 Mdot
.592 .5346 Mdot
.592 .53532 Mdot
.592 .53579 Mdot
.592 .53579 Mdot
.592 .53584 Mdot
.592 .536 Mdot
.592 .53614 Mdot
.592 .5368 Mdot
.592 .53685 Mdot
.592 .53686 Mdot
.592 .5371 Mdot
.592 .53773 Mdot
.592 .538 Mdot
.592 .538 Mdot
.592 .53803 Mdot
.592 .53813 Mdot
.592 .53835 Mdot
.592 .53837 Mdot
.592 .53858 Mdot
.592 .5394 Mdot
.592 .53953 Mdot
.592 .54007 Mdot
.592 .54035 Mdot
.592 .54091 Mdot
.592 .54129 Mdot
.592 .54159 Mdot
.592 .54206 Mdot
.592 .54221 Mdot
.592 .54228 Mdot
.592 .54235 Mdot
.592 .54295 Mdot
.592 .54299 Mdot
.592 .54304 Mdot
.592 .5431 Mdot
.592 .5432 Mdot
.592 .54368 Mdot
.592 .54369 Mdot
.592 .54372 Mdot
.592 .54431 Mdot
.592 .54438 Mdot
.592 .54459 Mdot
.592 .54463 Mdot
.592 .54475 Mdot
.592 .54482 Mdot
.592 .54511 Mdot
.592 .54515 Mdot
.592 .54516 Mdot
.592 .54533 Mdot
.592 .5458 Mdot
.592 .54616 Mdot
.592 .54653 Mdot
.592 .54659 Mdot
.592 .5468 Mdot
.592 .54717 Mdot
.592 .54728 Mdot
.592 .54728 Mdot
.592 .54737 Mdot
.592 .5474 Mdot
.592 .54745 Mdot
.592 .54758 Mdot
.592 .54776 Mdot
.592 .54797 Mdot
.592 .548 Mdot
.592 .54802 Mdot
.592 .54817 Mdot
.592 .54843 Mdot
.592 .54858 Mdot
.592 .54859 Mdot
.592 .54869 Mdot
.592 .54872 Mdot
.592 .54872 Mdot
.592 .54891 Mdot
.592 .54914 Mdot
.592 .54916 Mdot
.592 .54932 Mdot
.592 .54955 Mdot
.592 .54983 Mdot
.592 .5502 Mdot
.592 .55029 Mdot
.592 .55031 Mdot
.592 .55033 Mdot
.592 .55039 Mdot
.592 .55043 Mdot
.592 .55055 Mdot
.592 .55065 Mdot
.592 .55118 Mdot
.592 .55129 Mdot
.592 .55132 Mdot
.592 .55171 Mdot
.592 .55177 Mdot
.592 .55184 Mdot
.592 .55188 Mdot
.592 .55195 Mdot
.592 .55211 Mdot
.592 .55219 Mdot
.592 .55222 Mdot
.592 .5523 Mdot
.592 .5523 Mdot
.592 .55249 Mdot
.592 .55274 Mdot
.592 .5528 Mdot
.592 .55307 Mdot
.592 .55315 Mdot
.592 .55331 Mdot
.592 .55334 Mdot
.592 .55348 Mdot
.592 .5535 Mdot
.592 .5535 Mdot
.592 .55351 Mdot
.592 .55356 Mdot
.592 .55361 Mdot
.592 .5537 Mdot
.592 .55372 Mdot
.592 .55387 Mdot
.592 .5539 Mdot
.592 .55396 Mdot
.592 .55401 Mdot
.592 .55404 Mdot
.592 .55411 Mdot
.592 .55413 Mdot
.592 .55423 Mdot
.592 .5543 Mdot
.592 .55433 Mdot
.592 .5544 Mdot
.592 .55456 Mdot
.592 .55464 Mdot
.592 .55467 Mdot
.592 .55482 Mdot
.592 .55485 Mdot
.592 .55485 Mdot
.592 .55487 Mdot
.592 .55489 Mdot
.592 .55489 Mdot
.592 .55492 Mdot
.592 .55503 Mdot
.592 .55503 Mdot
.592 .55504 Mdot
.592 .55507 Mdot
.592 .5551 Mdot
.592 .55511 Mdot
.592 .55511 Mdot
.592 .55515 Mdot
.592 .55518 Mdot
.592 .5552 Mdot
.592 .55523 Mdot
.592 .55526 Mdot
.592 .55526 Mdot
.592 .55527 Mdot
.592 .55528 Mdot
.592 .55528 Mdot
.592 .55529 Mdot
.592 .55529 Mdot
.594 .17613 Mdot
.594 .17616 Mdot
.594 .17617 Mdot
.594 .17621 Mdot
.594 .17624 Mdot
.594 .17635 Mdot
.594 .17636 Mdot
.594 .17637 Mdot
.594 .17638 Mdot
.594 .17651 Mdot
.594 .17668 Mdot
.594 .17668 Mdot
.594 .17669 Mdot
.594 .17674 Mdot
.594 .17675 Mdot
.594 .17689 Mdot
.594 .17713 Mdot
.594 .17719 Mdot
.594 .17747 Mdot
.594 .17752 Mdot
.594 .17791 Mdot
.594 .17819 Mdot
.594 .17842 Mdot
.594 .17864 Mdot
.594 .17866 Mdot
.594 .17881 Mdot
.594 .17886 Mdot
.594 .1791 Mdot
.594 .1792 Mdot
.594 .17941 Mdot
.594 .17956 Mdot
.594 .1796 Mdot
.594 .17977 Mdot
.594 .17982 Mdot
.594 .17983 Mdot
.594 .17986 Mdot
.594 .17995 Mdot
.594 .18008 Mdot
.594 .18035 Mdot
.594 .18063 Mdot
.594 .18063 Mdot
.594 .18087 Mdot
.594 .18101 Mdot
.594 .18113 Mdot
.594 .18117 Mdot
.594 .18125 Mdot
.594 .18128 Mdot
.594 .1815 Mdot
.594 .18166 Mdot
.594 .18172 Mdot
.594 .1818 Mdot
.594 .18203 Mdot
.594 .1825 Mdot
.594 .18307 Mdot
.594 .18323 Mdot
.594 .18362 Mdot
.594 .18364 Mdot
.594 .18378 Mdot
.594 .18386 Mdot
.594 .18417 Mdot
.594 .18447 Mdot
.594 .18454 Mdot
.594 .18471 Mdot
.594 .18549 Mdot
.594 .18556 Mdot
.594 .18644 Mdot
.594 .18717 Mdot
.594 .18751 Mdot
.594 .18754 Mdot
.594 .18776 Mdot
.594 .189 Mdot
.594 .18959 Mdot
.594 .1896 Mdot
.594 .18997 Mdot
.594 .1907 Mdot
.594 .19131 Mdot
.594 .19147 Mdot
.594 .19148 Mdot
.594 .19149 Mdot
.594 .19176 Mdot
.594 .19264 Mdot
.594 .1931 Mdot
.594 .19492 Mdot
.594 .19521 Mdot
.594 .19557 Mdot
.594 .19598 Mdot
.594 .19622 Mdot
.594 .19692 Mdot
.594 .19706 Mdot
.594 .19751 Mdot
.594 .19811 Mdot
.594 .1982 Mdot
.594 .19821 Mdot
.594 .19878 Mdot
.594 .19913 Mdot
.594 .19917 Mdot
.594 .20015 Mdot
.594 .20026 Mdot
.594 .20099 Mdot
.594 .20137 Mdot
.594 .20269 Mdot
.594 .20287 Mdot
.594 .20319 Mdot
.594 .20376 Mdot
.594 .20511 Mdot
.594 .20514 Mdot
.594 .2062 Mdot
.594 .20786 Mdot
.594 .20929 Mdot
.594 .20961 Mdot
.594 .20992 Mdot
.594 .21093 Mdot
.594 .2113 Mdot
.594 .2113 Mdot
.594 .21269 Mdot
.594 .21351 Mdot
.594 .21408 Mdot
.594 .21423 Mdot
.594 .21433 Mdot
.594 .21434 Mdot
.594 .21513 Mdot
.594 .21593 Mdot
.594 .2161 Mdot
.594 .21648 Mdot
.594 .21715 Mdot
.594 .21876 Mdot
.594 .21916 Mdot
.594 .21948 Mdot
.594 .2195 Mdot
.594 .2211 Mdot
.594 .22291 Mdot
.594 .22354 Mdot
.594 .22364 Mdot
.594 .22595 Mdot
.594 .22676 Mdot
.594 .22682 Mdot
.594 .22691 Mdot
.594 .22769 Mdot
.594 .22792 Mdot
.594 .228 Mdot
.594 .22871 Mdot
.594 .22908 Mdot
.594 .22942 Mdot
.594 .22946 Mdot
.594 .23066 Mdot
.594 .23181 Mdot
.594 .23232 Mdot
.594 .23428 Mdot
.594 .23499 Mdot
.594 .23534 Mdot
.594 .23556 Mdot
.594 .23622 Mdot
.594 .23794 Mdot
.594 .23848 Mdot
.594 .23983 Mdot
.594 .23999 Mdot
.594 .2405 Mdot
.594 .24097 Mdot
.594 .24236 Mdot
.594 .24296 Mdot
.594 .2435 Mdot
.594 .24362 Mdot
.594 .24488 Mdot
.594 .2453 Mdot
.594 .24837 Mdot
.594 .24981 Mdot
.594 .25005 Mdot
.594 .25013 Mdot
.594 .25105 Mdot
.594 .25234 Mdot
.594 .25251 Mdot
.594 .25386 Mdot
.594 .25413 Mdot
.594 .25534 Mdot
.594 .25554 Mdot
.594 .25611 Mdot
.594 .25615 Mdot
.594 .25669 Mdot
.594 .25674 Mdot
.594 .25988 Mdot
.594 .2608 Mdot
.594 .26098 Mdot
.594 .26215 Mdot
.594 .26254 Mdot
.594 .2639 Mdot
.594 .26484 Mdot
.594 .26571 Mdot
.594 .26659 Mdot
.594 .26679 Mdot
.594 .26699 Mdot
.594 .26977 Mdot
.594 .26979 Mdot
.594 .27113 Mdot
.594 .27149 Mdot
.594 .27245 Mdot
.594 .27273 Mdot
.594 .27328 Mdot
.594 .27413 Mdot
.594 .27441 Mdot
.594 .27588 Mdot
.594 .27645 Mdot
.594 .27698 Mdot
.594 .27911 Mdot
.594 .28074 Mdot
.594 .28133 Mdot
.594 .28203 Mdot
.594 .28301 Mdot
.594 .2843 Mdot
.594 .28493 Mdot
.594 .2878 Mdot
.594 .28801 Mdot
.594 .2881 Mdot
.594 .28898 Mdot
.594 .28972 Mdot
.594 .28993 Mdot
.594 .29177 Mdot
.594 .29198 Mdot
.594 .29259 Mdot
.594 .29276 Mdot
.594 .29281 Mdot
.594 .29324 Mdot
.594 .29365 Mdot
.594 .29462 Mdot
.594 .29485 Mdot
.594 .29502 Mdot
.594 .29508 Mdot
.594 .29588 Mdot
.594 .29632 Mdot
.594 .29714 Mdot
.594 .29861 Mdot
.594 .30173 Mdot
.594 .30321 Mdot
.594 .30328 Mdot
.594 .30355 Mdot
.594 .30524 Mdot
.594 .3053 Mdot
.594 .30538 Mdot
.594 .30546 Mdot
.594 .3067 Mdot
.594 .30718 Mdot
.594 .30728 Mdot
.594 .30849 Mdot
.594 .31014 Mdot
.594 .31162 Mdot
.594 .31363 Mdot
.594 .31449 Mdot
.594 .31455 Mdot
.594 .31542 Mdot
.594 .31653 Mdot
.594 .31746 Mdot
.594 .3176 Mdot
.594 .3187 Mdot
.594 .32 Mdot
.594 .32051 Mdot
.594 .32056 Mdot
.594 .32099 Mdot
.594 .32151 Mdot
.594 .32243 Mdot
.594 .32251 Mdot
.594 .32283 Mdot
.594 .32293 Mdot
.594 .3239 Mdot
.594 .32438 Mdot
.594 .32502 Mdot
.594 .32541 Mdot
.594 .3258 Mdot
.594 .32615 Mdot
.594 .32661 Mdot
.594 .3273 Mdot
.594 .32884 Mdot
.594 .32887 Mdot
.594 .32916 Mdot
.594 .32956 Mdot
.594 .33118 Mdot
.594 .33127 Mdot
.594 .33228 Mdot
.594 .33347 Mdot
.594 .3335 Mdot
.594 .33562 Mdot
.594 .33563 Mdot
.594 .33744 Mdot
.594 .33745 Mdot
.594 .33745 Mdot
.594 .3377 Mdot
.594 .33851 Mdot
.594 .3405 Mdot
.594 .34075 Mdot
.594 .34139 Mdot
.594 .34227 Mdot
.594 .34263 Mdot
.594 .34311 Mdot
.594 .34317 Mdot
.594 .34318 Mdot
.594 .34393 Mdot
.594 .34467 Mdot
.594 .34667 Mdot
.594 .34731 Mdot
.594 .34899 Mdot
.594 .3501 Mdot
.594 .35209 Mdot
.594 .35233 Mdot
.594 .3537 Mdot
.594 .35405 Mdot
.594 .3542 Mdot
.594 .3542 Mdot
.594 .35468 Mdot
.594 .35516 Mdot
.594 .35526 Mdot
.594 .35682 Mdot
.594 .35725 Mdot
.594 .35917 Mdot
.594 .35951 Mdot
.594 .35957 Mdot
.594 .36083 Mdot
.594 .36126 Mdot
.594 .36176 Mdot
.594 .3623 Mdot
.594 .36267 Mdot
.594 .36332 Mdot
.594 .36516 Mdot
.594 .36581 Mdot
.594 .36613 Mdot
.594 .36725 Mdot
.594 .36845 Mdot
.594 .36912 Mdot
.594 .3694 Mdot
.594 .36971 Mdot
.594 .37031 Mdot
.594 .37051 Mdot
.594 .37193 Mdot
.594 .37259 Mdot
.594 .3727 Mdot
.594 .37373 Mdot
.594 .37381 Mdot
.594 .37516 Mdot
.594 .37541 Mdot
.594 .37543 Mdot
.594 .37569 Mdot
.594 .37746 Mdot
.594 .37878 Mdot
.594 .37918 Mdot
.594 .38001 Mdot
.594 .38125 Mdot
.594 .38126 Mdot
.594 .38196 Mdot
.594 .38236 Mdot
.594 .38316 Mdot
.594 .38399 Mdot
.594 .3842 Mdot
.594 .38506 Mdot
.594 .38594 Mdot
.594 .38661 Mdot
.594 .38712 Mdot
.594 .38849 Mdot
.594 .38924 Mdot
.594 .39041 Mdot
.594 .39043 Mdot
.594 .3906 Mdot
.594 .39075 Mdot
.594 .3913 Mdot
.594 .3916 Mdot
.594 .39177 Mdot
.594 .39264 Mdot
.594 .39381 Mdot
.594 .39437 Mdot
.594 .39515 Mdot
.594 .39518 Mdot
.594 .39521 Mdot
.594 .39567 Mdot
.594 .39585 Mdot
.594 .39588 Mdot
.594 .39633 Mdot
.594 .39748 Mdot
.594 .39822 Mdot
.594 .39961 Mdot
.594 .39966 Mdot
.594 .40006 Mdot
.594 .40053 Mdot
.594 .40071 Mdot
.594 .40073 Mdot
.594 .40107 Mdot
.594 .4014 Mdot
.594 .40143 Mdot
.594 .40158 Mdot
.594 .40233 Mdot
.594 .40247 Mdot
.594 .40261 Mdot
.594 .40273 Mdot
.594 .40315 Mdot
.594 .40455 Mdot
.594 .40491 Mdot
.594 .40533 Mdot
.594 .40609 Mdot
.594 .40609 Mdot
.594 .40673 Mdot
.594 .40682 Mdot
.594 .40781 Mdot
.594 .40789 Mdot
.594 .40855 Mdot
.594 .40871 Mdot
.594 .40874 Mdot
.594 .409 Mdot
.594 .40926 Mdot
.594 .40996 Mdot
.594 .41076 Mdot
.594 .41114 Mdot
.594 .41191 Mdot
.594 .41239 Mdot
.594 .41251 Mdot
.594 .41256 Mdot
.594 .41256 Mdot
.594 .41273 Mdot
.594 .41346 Mdot
.594 .41361 Mdot
.594 .41439 Mdot
.594 .41441 Mdot
.594 .41499 Mdot
.594 .41547 Mdot
.594 .41569 Mdot
.594 .41633 Mdot
.594 .41655 Mdot
.594 .41745 Mdot
.594 .41768 Mdot
.594 .41809 Mdot
.594 .41815 Mdot
.594 .41864 Mdot
.594 .41928 Mdot
.594 .41974 Mdot
.594 .42139 Mdot
.594 .42181 Mdot
.594 .42219 Mdot
.594 .42274 Mdot
.594 .42341 Mdot
.594 .42364 Mdot
.594 .42381 Mdot
.594 .42428 Mdot
.594 .42453 Mdot
.594 .42493 Mdot
.594 .42499 Mdot
.594 .42504 Mdot
.594 .42523 Mdot
.594 .42534 Mdot
.594 .42569 Mdot
.594 .42609 Mdot
.594 .42678 Mdot
.594 .42679 Mdot
.594 .42694 Mdot
.594 .42759 Mdot
.594 .42808 Mdot
.594 .42821 Mdot
.594 .42837 Mdot
.594 .42856 Mdot
.594 .42867 Mdot
.594 .42868 Mdot
.594 .42873 Mdot
.594 .42899 Mdot
.594 .42909 Mdot
.594 .42913 Mdot
.594 .42927 Mdot
.594 .42975 Mdot
.594 .42987 Mdot
.594 .43001 Mdot
.594 .43027 Mdot
.594 .43089 Mdot
.594 .43111 Mdot
.594 .43117 Mdot
.594 .43118 Mdot
.594 .43127 Mdot
.594 .43136 Mdot
.594 .43187 Mdot
.594 .432 Mdot
.594 .43227 Mdot
.594 .43243 Mdot
.594 .43249 Mdot
.594 .43249 Mdot
.594 .4328 Mdot
.594 .43285 Mdot
.594 .43312 Mdot
.594 .43312 Mdot
.594 .43378 Mdot
.594 .43458 Mdot
.594 .43568 Mdot
.594 .43581 Mdot
.594 .43662 Mdot
.594 .4368 Mdot
.594 .43746 Mdot
.594 .43785 Mdot
.594 .4379 Mdot
.594 .43802 Mdot
.594 .43806 Mdot
.594 .43806 Mdot
.594 .43853 Mdot
.594 .43891 Mdot
.594 .43893 Mdot
.594 .43897 Mdot
.594 .439 Mdot
.594 .43932 Mdot
.594 .43939 Mdot
.594 .4395 Mdot
.594 .43952 Mdot
.594 .43962 Mdot
.594 .44526 Mdot
.594 .44532 Mdot
.594 .44533 Mdot
.594 .4454 Mdot
.594 .44544 Mdot
.594 .44563 Mdot
.594 .44565 Mdot
.594 .44566 Mdot
.594 .44568 Mdot
.594 .4459 Mdot
.594 .44617 Mdot
.594 .44618 Mdot
.594 .4462 Mdot
.594 .44627 Mdot
.594 .4463 Mdot
.594 .44653 Mdot
.594 .44691 Mdot
.594 .44701 Mdot
.594 .44748 Mdot
.594 .44756 Mdot
.594 .44819 Mdot
.594 .44865 Mdot
.594 .44903 Mdot
.594 .44903 Mdot
.594 .44918 Mdot
.594 .44921 Mdot
.594 .44939 Mdot
.594 .44939 Mdot
.594 .44942 Mdot
.594 .44952 Mdot
.594 .44967 Mdot
.594 .44974 Mdot
.594 .45003 Mdot
.594 .45008 Mdot
.594 .45014 Mdot
.594 .45014 Mdot
.594 .45017 Mdot
.594 .4503 Mdot
.594 .45065 Mdot
.594 .4508 Mdot
.594 .45088 Mdot
.594 .45095 Mdot
.594 .45122 Mdot
.594 .4513 Mdot
.594 .45132 Mdot
.594 .45137 Mdot
.594 .45152 Mdot
.594 .45154 Mdot
.594 .45155 Mdot
.594 .45161 Mdot
.594 .45172 Mdot
.594 .45181 Mdot
.594 .45188 Mdot
.594 .45216 Mdot
.594 .45252 Mdot
.594 .4526 Mdot
.594 .45261 Mdot
.594 .453 Mdot
.594 .45322 Mdot
.594 .45341 Mdot
.594 .45347 Mdot
.594 .45357 Mdot
.594 .4536 Mdot
.594 .45364 Mdot
.594 .45386 Mdot
.594 .454 Mdot
.594 .45426 Mdot
.594 .45435 Mdot
.594 .45448 Mdot
.594 .45484 Mdot
.594 .45515 Mdot
.594 .45535 Mdot
.594 .45559 Mdot
.594 .45648 Mdot
.594 .45673 Mdot
.594 .45708 Mdot
.594 .45734 Mdot
.594 .45738 Mdot
.594 .4576 Mdot
.594 .45772 Mdot
.594 .45821 Mdot
.594 .45833 Mdot
.594 .45866 Mdot
.594 .45878 Mdot
.594 .45904 Mdot
.594 .45935 Mdot
.594 .45936 Mdot
.594 .45978 Mdot
.594 .45985 Mdot
.594 .46024 Mdot
.594 .46033 Mdot
.594 .46033 Mdot
.594 .46036 Mdot
.594 .46042 Mdot
.594 .46067 Mdot
.594 .46108 Mdot
.594 .46128 Mdot
.594 .4617 Mdot
.594 .46207 Mdot
.594 .4622 Mdot
.594 .46234 Mdot
.594 .46235 Mdot
.594 .46244 Mdot
.594 .46278 Mdot
.594 .46283 Mdot
.594 .46334 Mdot
.594 .46339 Mdot
.594 .46372 Mdot
.594 .46372 Mdot
.594 .46411 Mdot
.594 .46433 Mdot
.594 .46451 Mdot
.594 .46524 Mdot
.594 .46545 Mdot
.594 .46551 Mdot
.594 .46558 Mdot
.594 .46565 Mdot
.594 .46604 Mdot
.594 .46611 Mdot
.594 .46613 Mdot
.594 .46629 Mdot
.594 .46647 Mdot
.594 .46648 Mdot
.594 .46657 Mdot
.594 .46681 Mdot
.594 .46701 Mdot
.594 .46704 Mdot
.594 .46774 Mdot
.594 .46811 Mdot
.594 .46869 Mdot
.594 .46892 Mdot
.594 .46893 Mdot
.594 .46902 Mdot
.594 .46925 Mdot
.594 .46927 Mdot
.594 .46928 Mdot
.594 .46967 Mdot
.594 .46995 Mdot
.594 .47053 Mdot
.594 .47096 Mdot
.594 .47104 Mdot
.594 .47119 Mdot
.594 .47147 Mdot
.594 .47154 Mdot
.594 .47162 Mdot
.594 .47163 Mdot
.594 .47221 Mdot
.594 .47257 Mdot
.594 .47324 Mdot
.594 .47349 Mdot
.594 .47382 Mdot
.594 .47425 Mdot
.594 .47466 Mdot
.594 .47477 Mdot
.594 .47517 Mdot
.594 .47555 Mdot
.594 .47574 Mdot
.594 .47608 Mdot
.594 .47608 Mdot
.594 .47668 Mdot
.594 .47707 Mdot
.594 .47726 Mdot
.594 .47789 Mdot
.594 .47873 Mdot
.594 .47885 Mdot
.594 .47886 Mdot
.594 .47898 Mdot
.594 .47961 Mdot
.594 .47965 Mdot
.594 .48013 Mdot
.594 .48018 Mdot
.594 .48049 Mdot
.594 .48116 Mdot
.594 .48125 Mdot
.594 .48152 Mdot
.594 .48167 Mdot
.594 .4818 Mdot
.594 .48211 Mdot
.594 .48267 Mdot
.594 .48318 Mdot
.594 .48333 Mdot
.594 .48362 Mdot
.594 .48447 Mdot
.594 .48476 Mdot
.594 .48493 Mdot
.594 .48518 Mdot
.594 .4854 Mdot
.594 .4856 Mdot
.594 .48617 Mdot
.594 .4862 Mdot
.594 .48635 Mdot
.594 .48722 Mdot
.594 .48741 Mdot
.594 .48811 Mdot
.594 .48815 Mdot
.594 .48836 Mdot
.594 .48858 Mdot
.594 .48858 Mdot
.594 .48865 Mdot
.594 .4888 Mdot
.594 .48941 Mdot
.594 .48952 Mdot
.594 .4904 Mdot
.594 .49089 Mdot
.594 .49163 Mdot
.594 .49191 Mdot
.594 .49278 Mdot
.594 .4931 Mdot
.594 .49343 Mdot
.594 .49343 Mdot
.594 .49346 Mdot
.594 .49367 Mdot
.594 .49383 Mdot
.594 .49421 Mdot
.594 .49448 Mdot
.594 .49459 Mdot
.594 .49545 Mdot
.594 .49579 Mdot
.594 .4959 Mdot
.594 .4959 Mdot
.594 .49591 Mdot
.594 .49668 Mdot
.594 .49668 Mdot
.594 .49759 Mdot
.594 .4976 Mdot
.594 .4981 Mdot
.594 .49853 Mdot
.594 .49857 Mdot
.594 .49925 Mdot
.594 .49942 Mdot
.594 .49954 Mdot
.594 .49956 Mdot
.594 .5002 Mdot
.594 .50049 Mdot
.594 .50068 Mdot
.594 .50083 Mdot
.594 .50099 Mdot
.594 .50115 Mdot
.594 .50142 Mdot
.594 .50162 Mdot
.594 .50202 Mdot
.594 .50206 Mdot
.594 .5022 Mdot
.594 .50223 Mdot
.594 .50261 Mdot
.594 .50283 Mdot
.594 .50301 Mdot
.594 .50303 Mdot
.594 .50324 Mdot
.594 .50377 Mdot
.594 .50422 Mdot
.594 .50428 Mdot
.594 .50466 Mdot
.594 .50511 Mdot
.594 .50547 Mdot
.594 .5055 Mdot
.594 .50584 Mdot
.594 .50666 Mdot
.594 .50726 Mdot
.594 .50792 Mdot
.594 .50841 Mdot
.594 .50845 Mdot
.594 .50864 Mdot
.594 .50914 Mdot
.594 .50917 Mdot
.594 .5092 Mdot
.594 .50923 Mdot
.594 .5099 Mdot
.594 .51001 Mdot
.594 .51004 Mdot
.594 .51063 Mdot
.594 .51186 Mdot
.594 .51244 Mdot
.594 .51277 Mdot
.594 .51294 Mdot
.594 .51325 Mdot
.594 .51328 Mdot
.594 .51334 Mdot
.594 .51343 Mdot
.594 .51381 Mdot
.594 .51397 Mdot
.594 .51414 Mdot
.594 .51416 Mdot
.594 .51423 Mdot
.594 .51446 Mdot
.594 .51455 Mdot
.594 .51526 Mdot
.594 .51534 Mdot
.594 .51563 Mdot
.594 .51597 Mdot
.594 .51601 Mdot
.594 .51609 Mdot
.594 .51719 Mdot
.594 .51744 Mdot
.594 .51793 Mdot
.594 .5183 Mdot
.594 .51857 Mdot
.594 .5188 Mdot
.594 .51942 Mdot
.594 .52023 Mdot
.594 .52043 Mdot
.594 .52065 Mdot
.594 .5212 Mdot
.594 .5213 Mdot
.594 .52163 Mdot
.594 .52183 Mdot
.594 .52194 Mdot
.594 .5223 Mdot
.594 .52243 Mdot
.594 .52294 Mdot
.594 .52295 Mdot
.594 .52398 Mdot
.594 .52406 Mdot
.594 .52446 Mdot
.594 .52478 Mdot
.594 .52513 Mdot
.594 .52563 Mdot
.594 .52578 Mdot
.594 .52621 Mdot
.594 .52628 Mdot
.594 .52662 Mdot
.594 .52777 Mdot
.594 .52779 Mdot
.594 .52798 Mdot
.594 .528 Mdot
.594 .52821 Mdot
.594 .52828 Mdot
.594 .52872 Mdot
.594 .52882 Mdot
.594 .52931 Mdot
.594 .52937 Mdot
.594 .52984 Mdot
.594 .53017 Mdot
.594 .5302 Mdot
.594 .53029 Mdot
.594 .53081 Mdot
.594 .53192 Mdot
.594 .53207 Mdot
.594 .53252 Mdot
.594 .53256 Mdot
.594 .53276 Mdot
.594 .53297 Mdot
.594 .53347 Mdot
.594 .53363 Mdot
.594 .53381 Mdot
.594 .53387 Mdot
.594 .53435 Mdot
.594 .53454 Mdot
.594 .53516 Mdot
.594 .53539 Mdot
.594 .53547 Mdot
.594 .53559 Mdot
.594 .53584 Mdot
.594 .53653 Mdot
.594 .53671 Mdot
.594 .53711 Mdot
.594 .53754 Mdot
.594 .53755 Mdot
.594 .53767 Mdot
.594 .5378 Mdot
.594 .53805 Mdot
.594 .53807 Mdot
.594 .53816 Mdot
.594 .53843 Mdot
.594 .53846 Mdot
.594 .53848 Mdot
.594 .53876 Mdot
.594 .53957 Mdot
.594 .5396 Mdot
.594 .53982 Mdot
.594 .54045 Mdot
.594 .541 Mdot
.594 .54101 Mdot
.594 .54112 Mdot
.594 .54125 Mdot
.594 .54181 Mdot
.594 .54204 Mdot
.594 .54217 Mdot
.594 .54223 Mdot
.594 .5425 Mdot
.594 .54277 Mdot
.594 .54278 Mdot
.594 .54281 Mdot
.594 .54286 Mdot
.594 .54306 Mdot
.594 .54334 Mdot
.594 .54381 Mdot
.594 .54382 Mdot
.594 .54394 Mdot
.594 .54428 Mdot
.594 .54439 Mdot
.594 .5445 Mdot
.594 .54498 Mdot
.594 .54555 Mdot
.594 .5459 Mdot
.594 .54592 Mdot
.594 .54637 Mdot
.594 .54656 Mdot
.594 .54667 Mdot
.594 .54673 Mdot
.594 .54717 Mdot
.594 .5473 Mdot
.594 .54755 Mdot
.594 .54759 Mdot
.594 .54791 Mdot
.594 .54793 Mdot
.594 .54805 Mdot
.594 .54824 Mdot
.594 .54824 Mdot
.594 .54827 Mdot
.594 .54847 Mdot
.594 .54862 Mdot
.594 .54867 Mdot
.594 .5489 Mdot
.594 .54898 Mdot
.594 .54912 Mdot
.594 .54924 Mdot
.594 .54933 Mdot
.594 .54994 Mdot
.594 .55009 Mdot
.594 .55039 Mdot
.594 .55047 Mdot
.594 .55048 Mdot
.594 .55048 Mdot
.594 .55053 Mdot
.594 .55074 Mdot
.594 .55098 Mdot
.594 .5511 Mdot
.594 .5511 Mdot
.594 .5513 Mdot
.594 .55171 Mdot
.594 .55178 Mdot
.594 .55179 Mdot
.594 .5519 Mdot
.594 .55215 Mdot
.594 .55243 Mdot
.594 .55246 Mdot
.594 .55271 Mdot
.594 .55277 Mdot
.594 .55279 Mdot
.594 .55289 Mdot
.594 .55299 Mdot
.594 .55302 Mdot
.594 .55306 Mdot
.594 .55307 Mdot
.594 .5532 Mdot
.594 .55325 Mdot
.594 .55344 Mdot
.594 .55359 Mdot
.594 .55367 Mdot
.594 .55369 Mdot
.594 .55371 Mdot
.594 .55377 Mdot
.594 .55384 Mdot
.594 .55385 Mdot
.594 .55387 Mdot
.594 .55389 Mdot
.594 .55393 Mdot
.594 .55397 Mdot
.594 .55405 Mdot
.594 .55405 Mdot
.594 .55414 Mdot
.594 .55423 Mdot
.594 .55427 Mdot
.594 .5543 Mdot
.594 .55431 Mdot
.594 .55432 Mdot
.594 .55433 Mdot
.594 .55439 Mdot
.594 .5544 Mdot
.594 .55445 Mdot
.594 .55452 Mdot
.594 .55455 Mdot
.594 .55463 Mdot
.594 .55464 Mdot
.594 .55469 Mdot
.594 .5547 Mdot
.594 .55477 Mdot
.594 .55485 Mdot
.594 .55494 Mdot
.594 .55506 Mdot
.594 .55508 Mdot
.594 .55517 Mdot
.594 .55519 Mdot
.594 .55527 Mdot
.594 .55531 Mdot
.594 .55532 Mdot
.594 .55533 Mdot
.594 .55534 Mdot
.594 .55534 Mdot
.594 .55539 Mdot
.594 .55544 Mdot
.594 .55544 Mdot
.594 .55544 Mdot
.594 .55545 Mdot
.594 .55548 Mdot
.594 .55549 Mdot
.594 .5555 Mdot
.594 .55551 Mdot
.594 .55552 Mdot
.596 .17546 Mdot
.596 .17546 Mdot
.596 .17548 Mdot
.596 .17553 Mdot
.596 .1757 Mdot
.596 .17575 Mdot
.596 .17583 Mdot
.596 .17583 Mdot
.596 .17584 Mdot
.596 .17594 Mdot
.596 .17596 Mdot
.596 .17623 Mdot
.596 .17633 Mdot
.596 .17654 Mdot
.596 .17697 Mdot
.596 .177 Mdot
.596 .17702 Mdot
.596 .17707 Mdot
.596 .1775 Mdot
.596 .17773 Mdot
.596 .17785 Mdot
.596 .17793 Mdot
.596 .17811 Mdot
.596 .17819 Mdot
.596 .1785 Mdot
.596 .17864 Mdot
.596 .17884 Mdot
.596 .17889 Mdot
.596 .17909 Mdot
.596 .17946 Mdot
.596 .17979 Mdot
.596 .17996 Mdot
.596 .18001 Mdot
.596 .18007 Mdot
.596 .18026 Mdot
.596 .18036 Mdot
.596 .18048 Mdot
.596 .18085 Mdot
.596 .18112 Mdot
.596 .18119 Mdot
.596 .18134 Mdot
.596 .18138 Mdot
.596 .18182 Mdot
.596 .18187 Mdot
.596 .18225 Mdot
.596 .1827 Mdot
.596 .18317 Mdot
.596 .18376 Mdot
.596 .18389 Mdot
.596 .18453 Mdot
.596 .18454 Mdot
.596 .18483 Mdot
.596 .18495 Mdot
.596 .18556 Mdot
.596 .18572 Mdot
.596 .18607 Mdot
.596 .18655 Mdot
.596 .18662 Mdot
.596 .18817 Mdot
.596 .18822 Mdot
.596 .18865 Mdot
.596 .18878 Mdot
.596 .18892 Mdot
.596 .18924 Mdot
.596 .18934 Mdot
.596 .18951 Mdot
.596 .19099 Mdot
.596 .19285 Mdot
.596 .19314 Mdot
.596 .19393 Mdot
.596 .19431 Mdot
.596 .19433 Mdot
.596 .19437 Mdot
.596 .19509 Mdot
.596 .19515 Mdot
.596 .19519 Mdot
.596 .19519 Mdot
.596 .19548 Mdot
.596 .1957 Mdot
.596 .19575 Mdot
.596 .19587 Mdot
.596 .19603 Mdot
.596 .19605 Mdot
.596 .19646 Mdot
.596 .19837 Mdot
.596 .19877 Mdot
.596 .19889 Mdot
.596 .19922 Mdot
.596 .19933 Mdot
.596 .19971 Mdot
.596 .20046 Mdot
.596 .20088 Mdot
.596 .20124 Mdot
.596 .20138 Mdot
.596 .20205 Mdot
.596 .20253 Mdot
.596 .20292 Mdot
.596 .20301 Mdot
.596 .20421 Mdot
.596 .20438 Mdot
.596 .20468 Mdot
.596 .20516 Mdot
.596 .20535 Mdot
.596 .20558 Mdot
.596 .20559 Mdot
.596 .20842 Mdot
.596 .20874 Mdot
.596 .20969 Mdot
.596 .20985 Mdot
.596 .20986 Mdot
.596 .21009 Mdot
.596 .21054 Mdot
.596 .21113 Mdot
.596 .21168 Mdot
.596 .21208 Mdot
.596 .21267 Mdot
.596 .2127 Mdot
.596 .21379 Mdot
.596 .21434 Mdot
.596 .21475 Mdot
.596 .21575 Mdot
.596 .21709 Mdot
.596 .21801 Mdot
.596 .21861 Mdot
.596 .21947 Mdot
.596 .21951 Mdot
.596 .21971 Mdot
.596 .2199 Mdot
.596 .22094 Mdot
.596 .22268 Mdot
.596 .22386 Mdot
.596 .22581 Mdot
.596 .22632 Mdot
.596 .2265 Mdot
.596 .22729 Mdot
.596 .22743 Mdot
.596 .22844 Mdot
.596 .22959 Mdot
.596 .22973 Mdot
.596 .23006 Mdot
.596 .23116 Mdot
.596 .23136 Mdot
.596 .23169 Mdot
.596 .23329 Mdot
.596 .23382 Mdot
.596 .23394 Mdot
.596 .23475 Mdot
.596 .23505 Mdot
.596 .23586 Mdot
.596 .23676 Mdot
.596 .23688 Mdot
.596 .23688 Mdot
.596 .23766 Mdot
.596 .238 Mdot
.596 .23823 Mdot
.596 .23853 Mdot
.596 .23922 Mdot
.596 .24014 Mdot
.596 .24056 Mdot
.596 .24061 Mdot
.596 .24156 Mdot
.596 .24218 Mdot
.596 .243 Mdot
.596 .24453 Mdot
.596 .24525 Mdot
.596 .24556 Mdot
.596 .24642 Mdot
.596 .24716 Mdot
.596 .24764 Mdot
.596 .24836 Mdot
.596 .24904 Mdot
.596 .24972 Mdot
.596 .25017 Mdot
.596 .2505 Mdot
.596 .2513 Mdot
.596 .25131 Mdot
.596 .25136 Mdot
.596 .25276 Mdot
.596 .25283 Mdot
.596 .2539 Mdot
.596 .25407 Mdot
.596 .25474 Mdot
.596 .25491 Mdot
.596 .25661 Mdot
.596 .25803 Mdot
.596 .26023 Mdot
.596 .26034 Mdot
.596 .26045 Mdot
.596 .26131 Mdot
.596 .26347 Mdot
.596 .2651 Mdot
.596 .26544 Mdot
.596 .26581 Mdot
.596 .26625 Mdot
.596 .26636 Mdot
.596 .26696 Mdot
.596 .26717 Mdot
.596 .26905 Mdot
.596 .26905 Mdot
.596 .26934 Mdot
.596 .26967 Mdot
.596 .26988 Mdot
.596 .26999 Mdot
.596 .27117 Mdot
.596 .27151 Mdot
.596 .272 Mdot
.596 .27236 Mdot
.596 .27352 Mdot
.596 .27395 Mdot
.596 .27425 Mdot
.596 .27575 Mdot
.596 .27608 Mdot
.596 .2761 Mdot
.596 .27623 Mdot
.596 .27637 Mdot
.596 .27655 Mdot
.596 .27679 Mdot
.596 .27751 Mdot
.596 .27785 Mdot
.596 .27853 Mdot
.596 .28186 Mdot
.596 .28213 Mdot
.596 .28244 Mdot
.596 .28259 Mdot
.596 .28272 Mdot
.596 .28321 Mdot
.596 .28544 Mdot
.596 .28603 Mdot
.596 .28687 Mdot
.596 .28722 Mdot
.596 .28819 Mdot
.596 .28894 Mdot
.596 .29019 Mdot
.596 .29144 Mdot
.596 .29149 Mdot
.596 .29225 Mdot
.596 .29282 Mdot
.596 .29319 Mdot
.596 .29361 Mdot
.596 .29397 Mdot
.596 .29456 Mdot
.596 .29525 Mdot
.596 .29573 Mdot
.596 .29612 Mdot
.596 .29708 Mdot
.596 .29813 Mdot
.596 .30003 Mdot
.596 .30226 Mdot
.596 .30457 Mdot
.596 .30543 Mdot
.596 .30823 Mdot
.596 .30826 Mdot
.596 .31016 Mdot
.596 .3111 Mdot
.596 .31299 Mdot
.596 .31343 Mdot
.596 .31351 Mdot
.596 .31407 Mdot
.596 .31418 Mdot
.596 .31539 Mdot
.596 .31654 Mdot
.596 .3179 Mdot
.596 .31799 Mdot
.596 .31806 Mdot
.596 .3182 Mdot
.596 .31935 Mdot
.596 .32019 Mdot
.596 .32037 Mdot
.596 .32078 Mdot
.596 .32162 Mdot
.596 .3224 Mdot
.596 .32435 Mdot
.596 .32452 Mdot
.596 .32501 Mdot
.596 .3262 Mdot
.596 .32632 Mdot
.596 .32725 Mdot
.596 .32732 Mdot
.596 .32847 Mdot
.596 .33001 Mdot
.596 .3308 Mdot
.596 .33129 Mdot
.596 .33219 Mdot
.596 .33312 Mdot
.596 .3332 Mdot
.596 .33488 Mdot
.596 .336 Mdot
.596 .33757 Mdot
.596 .33926 Mdot
.596 .34051 Mdot
.596 .34056 Mdot
.596 .34116 Mdot
.596 .34121 Mdot
.596 .34124 Mdot
.596 .34171 Mdot
.596 .34418 Mdot
.596 .34443 Mdot
.596 .3448 Mdot
.596 .34536 Mdot
.596 .34593 Mdot
.596 .34714 Mdot
.596 .3472 Mdot
.596 .34882 Mdot
.596 .35178 Mdot
.596 .35193 Mdot
.596 .35318 Mdot
.596 .35354 Mdot
.596 .35356 Mdot
.596 .35423 Mdot
.596 .3548 Mdot
.596 .3554 Mdot
.596 .35619 Mdot
.596 .35707 Mdot
.596 .35756 Mdot
.596 .35839 Mdot
.596 .35936 Mdot
.596 .36106 Mdot
.596 .36133 Mdot
.596 .36184 Mdot
.596 .36192 Mdot
.596 .36245 Mdot
.596 .36305 Mdot
.596 .36386 Mdot
.596 .36494 Mdot
.596 .36567 Mdot
.596 .36582 Mdot
.596 .36623 Mdot
.596 .36711 Mdot
.596 .36728 Mdot
.596 .36739 Mdot
.596 .36851 Mdot
.596 .36854 Mdot
.596 .36929 Mdot
.596 .37073 Mdot
.596 .37127 Mdot
.596 .37183 Mdot
.596 .37216 Mdot
.596 .37299 Mdot
.596 .37314 Mdot
.596 .3735 Mdot
.596 .37353 Mdot
.596 .37415 Mdot
.596 .37418 Mdot
.596 .37466 Mdot
.596 .37474 Mdot
.596 .37511 Mdot
.596 .37752 Mdot
.596 .37965 Mdot
.596 .37998 Mdot
.596 .38028 Mdot
.596 .38141 Mdot
.596 .38149 Mdot
.596 .38154 Mdot
.596 .38203 Mdot
.596 .38237 Mdot
.596 .38252 Mdot
.596 .38316 Mdot
.596 .38389 Mdot
.596 .38403 Mdot
.596 .38403 Mdot
.596 .38414 Mdot
.596 .38431 Mdot
.596 .3846 Mdot
.596 .38501 Mdot
.596 .38644 Mdot
.596 .38657 Mdot
.596 .38662 Mdot
.596 .38775 Mdot
.596 .38882 Mdot
.596 .38911 Mdot
.596 .39007 Mdot
.596 .39009 Mdot
.596 .39038 Mdot
.596 .3909 Mdot
.596 .39104 Mdot
.596 .39126 Mdot
.596 .39186 Mdot
.596 .39262 Mdot
.596 .39333 Mdot
.596 .39503 Mdot
.596 .39638 Mdot
.596 .39639 Mdot
.596 .39744 Mdot
.596 .39829 Mdot
.596 .399 Mdot
.596 .39991 Mdot
.596 .39994 Mdot
.596 .39997 Mdot
.596 .40043 Mdot
.596 .40073 Mdot
.596 .4008 Mdot
.596 .40125 Mdot
.596 .40153 Mdot
.596 .40223 Mdot
.596 .40246 Mdot
.596 .40289 Mdot
.596 .40293 Mdot
.596 .40326 Mdot
.596 .40452 Mdot
.596 .40469 Mdot
.596 .40501 Mdot
.596 .40793 Mdot
.596 .40816 Mdot
.596 .40921 Mdot
.596 .40942 Mdot
.596 .40981 Mdot
.596 .41023 Mdot
.596 .41025 Mdot
.596 .41082 Mdot
.596 .41184 Mdot
.596 .41189 Mdot
.596 .41232 Mdot
.596 .41308 Mdot
.596 .41411 Mdot
.596 .41444 Mdot
.596 .41529 Mdot
.596 .41532 Mdot
.596 .4157 Mdot
.596 .41635 Mdot
.596 .4166 Mdot
.596 .41709 Mdot
.596 .41719 Mdot
.596 .41757 Mdot
.596 .41783 Mdot
.596 .41851 Mdot
.596 .41928 Mdot
.596 .41949 Mdot
.596 .4195 Mdot
.596 .41969 Mdot
.596 .41981 Mdot
.596 .42064 Mdot
.596 .42136 Mdot
.596 .42147 Mdot
.596 .42195 Mdot
.596 .4228 Mdot
.596 .42304 Mdot
.596 .42318 Mdot
.596 .42447 Mdot
.596 .42457 Mdot
.596 .4249 Mdot
.596 .425 Mdot
.596 .42523 Mdot
.596 .4253 Mdot
.596 .4255 Mdot
.596 .42576 Mdot
.596 .426 Mdot
.596 .42658 Mdot
.596 .42704 Mdot
.596 .4274 Mdot
.596 .42769 Mdot
.596 .42793 Mdot
.596 .42824 Mdot
.596 .42825 Mdot
.596 .42826 Mdot
.596 .42842 Mdot
.596 .42854 Mdot
.596 .42903 Mdot
.596 .42927 Mdot
.596 .42998 Mdot
.596 .43097 Mdot
.596 .43105 Mdot
.596 .43162 Mdot
.596 .43176 Mdot
.596 .43177 Mdot
.596 .43233 Mdot
.596 .43273 Mdot
.596 .43363 Mdot
.596 .43386 Mdot
.596 .43394 Mdot
.596 .43411 Mdot
.596 .43437 Mdot
.596 .4346 Mdot
.596 .43494 Mdot
.596 .43494 Mdot
.596 .435 Mdot
.596 .43505 Mdot
.596 .43558 Mdot
.596 .43562 Mdot
.596 .43608 Mdot
.596 .43681 Mdot
.596 .43694 Mdot
.596 .43701 Mdot
.596 .4371 Mdot
.596 .43739 Mdot
.596 .43786 Mdot
.596 .43796 Mdot
.596 .43797 Mdot
.596 .43832 Mdot
.596 .43892 Mdot
.596 .43919 Mdot
.596 .43995 Mdot
.596 .44001 Mdot
.596 .4403 Mdot
.596 .44033 Mdot
.596 .44034 Mdot
.596 .44054 Mdot
.596 .4407 Mdot
.596 .44116 Mdot
.596 .44133 Mdot
.596 .44137 Mdot
.596 .44137 Mdot
.596 .44434 Mdot
.596 .44434 Mdot
.596 .44436 Mdot
.596 .44446 Mdot
.596 .44473 Mdot
.596 .44483 Mdot
.596 .44495 Mdot
.596 .44496 Mdot
.596 .44497 Mdot
.596 .44514 Mdot
.596 .44517 Mdot
.596 .44562 Mdot
.596 .44578 Mdot
.596 .44613 Mdot
.596 .44634 Mdot
.596 .44634 Mdot
.596 .4464 Mdot
.596 .44668 Mdot
.596 .44684 Mdot
.596 .44689 Mdot
.596 .44693 Mdot
.596 .44701 Mdot
.596 .44743 Mdot
.596 .4477 Mdot
.596 .44772 Mdot
.596 .44803 Mdot
.596 .44805 Mdot
.596 .44809 Mdot
.596 .44809 Mdot
.596 .44829 Mdot
.596 .44842 Mdot
.596 .44857 Mdot
.596 .44866 Mdot
.596 .44871 Mdot
.596 .44884 Mdot
.596 .44935 Mdot
.596 .44959 Mdot
.596 .44991 Mdot
.596 .44991 Mdot
.596 .44999 Mdot
.596 .45031 Mdot
.596 .45036 Mdot
.596 .45092 Mdot
.596 .45132 Mdot
.596 .45145 Mdot
.596 .45173 Mdot
.596 .4518 Mdot
.596 .45188 Mdot
.596 .45189 Mdot
.596 .4519 Mdot
.596 .45207 Mdot
.596 .4522 Mdot
.596 .45237 Mdot
.596 .45256 Mdot
.596 .45282 Mdot
.596 .45314 Mdot
.596 .45328 Mdot
.596 .45342 Mdot
.596 .45353 Mdot
.596 .45357 Mdot
.596 .4537 Mdot
.596 .45375 Mdot
.596 .45394 Mdot
.596 .45399 Mdot
.596 .4547 Mdot
.596 .45478 Mdot
.596 .45491 Mdot
.596 .45537 Mdot
.596 .45564 Mdot
.596 .4557 Mdot
.596 .45609 Mdot
.596 .45654 Mdot
.596 .45661 Mdot
.596 .45671 Mdot
.596 .45672 Mdot
.596 .45683 Mdot
.596 .45725 Mdot
.596 .45761 Mdot
.596 .45775 Mdot
.596 .45796 Mdot
.596 .45801 Mdot
.596 .45827 Mdot
.596 .45841 Mdot
.596 .45875 Mdot
.596 .45896 Mdot
.596 .45897 Mdot
.596 .45943 Mdot
.596 .4596 Mdot
.596 .46015 Mdot
.596 .46055 Mdot
.596 .46078 Mdot
.596 .46081 Mdot
.596 .46134 Mdot
.596 .46164 Mdot
.596 .46165 Mdot
.596 .46187 Mdot
.596 .46207 Mdot
.596 .46219 Mdot
.596 .46273 Mdot
.596 .46285 Mdot
.596 .46436 Mdot
.596 .46453 Mdot
.596 .46462 Mdot
.596 .46526 Mdot
.596 .46543 Mdot
.596 .46545 Mdot
.596 .46567 Mdot
.596 .46579 Mdot
.596 .46615 Mdot
.596 .46629 Mdot
.596 .46652 Mdot
.596 .46655 Mdot
.596 .4667 Mdot
.596 .46694 Mdot
.596 .46695 Mdot
.596 .46697 Mdot
.596 .46743 Mdot
.596 .46779 Mdot
.596 .46822 Mdot
.596 .46874 Mdot
.596 .46875 Mdot
.596 .46942 Mdot
.596 .47027 Mdot
.596 .47062 Mdot
.596 .471 Mdot
.596 .47129 Mdot
.596 .4714 Mdot
.596 .47147 Mdot
.596 .47173 Mdot
.596 .47187 Mdot
.596 .47188 Mdot
.596 .47235 Mdot
.596 .4725 Mdot
.596 .47302 Mdot
.596 .47356 Mdot
.596 .47359 Mdot
.596 .47365 Mdot
.596 .47435 Mdot
.596 .47455 Mdot
.596 .47469 Mdot
.596 .47477 Mdot
.596 .47482 Mdot
.596 .47482 Mdot
.596 .47489 Mdot
.596 .47524 Mdot
.596 .47555 Mdot
.596 .47562 Mdot
.596 .47579 Mdot
.596 .47602 Mdot
.596 .47604 Mdot
.596 .47608 Mdot
.596 .47662 Mdot
.596 .47676 Mdot
.596 .47693 Mdot
.596 .47793 Mdot
.596 .47907 Mdot
.596 .47925 Mdot
.596 .47929 Mdot
.596 .47951 Mdot
.596 .47952 Mdot
.596 .47982 Mdot
.596 .47983 Mdot
.596 .48 Mdot
.596 .48046 Mdot
.596 .48061 Mdot
.596 .48087 Mdot
.596 .48112 Mdot
.596 .48179 Mdot
.596 .48214 Mdot
.596 .48215 Mdot
.596 .48267 Mdot
.596 .48272 Mdot
.596 .4828 Mdot
.596 .48321 Mdot
.596 .48339 Mdot
.596 .48346 Mdot
.596 .48379 Mdot
.596 .48429 Mdot
.596 .48466 Mdot
.596 .48493 Mdot
.596 .48517 Mdot
.596 .48521 Mdot
.596 .48544 Mdot
.596 .48557 Mdot
.596 .48633 Mdot
.596 .48677 Mdot
.596 .48714 Mdot
.596 .48736 Mdot
.596 .48776 Mdot
.596 .48811 Mdot
.596 .48838 Mdot
.596 .48863 Mdot
.596 .48893 Mdot
.596 .48894 Mdot
.596 .4891 Mdot
.596 .48965 Mdot
.596 .48972 Mdot
.596 .49103 Mdot
.596 .49174 Mdot
.596 .49177 Mdot
.596 .49229 Mdot
.596 .49254 Mdot
.596 .49279 Mdot
.596 .49295 Mdot
.596 .49306 Mdot
.596 .49413 Mdot
.596 .49433 Mdot
.596 .49434 Mdot
.596 .49436 Mdot
.596 .49463 Mdot
.596 .49465 Mdot
.596 .49519 Mdot
.596 .49591 Mdot
.596 .49658 Mdot
.596 .49706 Mdot
.596 .49777 Mdot
.596 .49781 Mdot
.596 .4982 Mdot
.596 .49858 Mdot
.596 .49879 Mdot
.596 .49912 Mdot
.596 .49977 Mdot
.596 .50025 Mdot
.596 .50028 Mdot
.596 .50067 Mdot
.596 .50072 Mdot
.596 .50121 Mdot
.596 .50142 Mdot
.596 .50149 Mdot
.596 .5023 Mdot
.596 .50262 Mdot
.596 .50297 Mdot
.596 .50314 Mdot
.596 .50321 Mdot
.596 .50356 Mdot
.596 .50403 Mdot
.596 .50409 Mdot
.596 .50411 Mdot
.596 .50415 Mdot
.596 .50471 Mdot
.596 .50518 Mdot
.596 .50567 Mdot
.596 .50572 Mdot
.596 .50594 Mdot
.596 .50598 Mdot
.596 .50616 Mdot
.596 .50692 Mdot
.596 .5073 Mdot
.596 .50807 Mdot
.596 .50808 Mdot
.596 .5092 Mdot
.596 .50955 Mdot
.596 .51047 Mdot
.596 .51135 Mdot
.596 .5121 Mdot
.596 .51251 Mdot
.596 .51289 Mdot
.596 .51304 Mdot
.596 .51323 Mdot
.596 .5135 Mdot
.596 .51373 Mdot
.596 .51387 Mdot
.596 .51404 Mdot
.596 .51418 Mdot
.596 .51441 Mdot
.596 .5147 Mdot
.596 .51472 Mdot
.596 .51521 Mdot
.596 .51569 Mdot
.596 .51598 Mdot
.596 .51635 Mdot
.596 .51649 Mdot
.596 .51682 Mdot
.596 .51704 Mdot
.596 .5179 Mdot
.596 .51809 Mdot
.596 .51814 Mdot
.596 .51819 Mdot
.596 .51831 Mdot
.596 .51841 Mdot
.596 .51968 Mdot
.596 .51994 Mdot
.596 .52007 Mdot
.596 .52034 Mdot
.596 .52044 Mdot
.596 .5205 Mdot
.596 .52056 Mdot
.596 .52061 Mdot
.596 .52061 Mdot
.596 .52074 Mdot
.596 .5213 Mdot
.596 .52142 Mdot
.596 .52158 Mdot
.596 .52202 Mdot
.596 .52215 Mdot
.596 .52233 Mdot
.596 .52246 Mdot
.596 .5229 Mdot
.596 .52295 Mdot
.596 .52302 Mdot
.596 .52315 Mdot
.596 .52325 Mdot
.596 .52326 Mdot
.596 .52396 Mdot
.596 .52403 Mdot
.596 .52426 Mdot
.596 .5243 Mdot
.596 .52446 Mdot
.596 .5246 Mdot
.596 .52473 Mdot
.596 .52533 Mdot
.596 .52613 Mdot
.596 .52644 Mdot
.596 .52649 Mdot
.596 .52653 Mdot
.596 .52733 Mdot
.596 .52786 Mdot
.596 .52847 Mdot
.596 .52854 Mdot
.596 .52878 Mdot
.596 .52884 Mdot
.596 .52923 Mdot
.596 .52926 Mdot
.596 .52976 Mdot
.596 .52979 Mdot
.596 .52979 Mdot
.596 .53008 Mdot
.596 .5302 Mdot
.596 .53036 Mdot
.596 .5306 Mdot
.596 .53085 Mdot
.596 .53111 Mdot
.596 .53128 Mdot
.596 .53155 Mdot
.596 .53186 Mdot
.596 .53197 Mdot
.596 .53223 Mdot
.596 .53278 Mdot
.596 .53307 Mdot
.596 .53329 Mdot
.596 .53363 Mdot
.596 .53365 Mdot
.596 .5338 Mdot
.596 .53413 Mdot
.596 .53437 Mdot
.596 .53448 Mdot
.596 .53456 Mdot
.596 .53468 Mdot
.596 .53495 Mdot
.596 .53496 Mdot
.596 .535 Mdot
.596 .53531 Mdot
.596 .5356 Mdot
.596 .53571 Mdot
.596 .53599 Mdot
.596 .53604 Mdot
.596 .53622 Mdot
.596 .53679 Mdot
.596 .5369 Mdot
.596 .53697 Mdot
.596 .53736 Mdot
.596 .53748 Mdot
.596 .53752 Mdot
.596 .53792 Mdot
.596 .53828 Mdot
.596 .53833 Mdot
.596 .5386 Mdot
.596 .53867 Mdot
.596 .53884 Mdot
.596 .53952 Mdot
.596 .53993 Mdot
.596 .54053 Mdot
.596 .54089 Mdot
.596 .54096 Mdot
.596 .54103 Mdot
.596 .54104 Mdot
.596 .54134 Mdot
.596 .54154 Mdot
.596 .54186 Mdot
.596 .54232 Mdot
.596 .54266 Mdot
.596 .5428 Mdot
.596 .54299 Mdot
.596 .54337 Mdot
.596 .54338 Mdot
.596 .54358 Mdot
.596 .54371 Mdot
.596 .5439 Mdot
.596 .5441 Mdot
.596 .54426 Mdot
.596 .54433 Mdot
.596 .54434 Mdot
.596 .54439 Mdot
.596 .54471 Mdot
.596 .54482 Mdot
.596 .54578 Mdot
.596 .54578 Mdot
.596 .54586 Mdot
.596 .54593 Mdot
.596 .54609 Mdot
.596 .54619 Mdot
.596 .54625 Mdot
.596 .54665 Mdot
.596 .54668 Mdot
.596 .54681 Mdot
.596 .54697 Mdot
.596 .5472 Mdot
.596 .54725 Mdot
.596 .54737 Mdot
.596 .54751 Mdot
.596 .54776 Mdot
.596 .54789 Mdot
.596 .54792 Mdot
.596 .54804 Mdot
.596 .54808 Mdot
.596 .54821 Mdot
.596 .54885 Mdot
.596 .54899 Mdot
.596 .54899 Mdot
.596 .54905 Mdot
.596 .54908 Mdot
.596 .5491 Mdot
.596 .54917 Mdot
.596 .54927 Mdot
.596 .54927 Mdot
.596 .54928 Mdot
.596 .5493 Mdot
.596 .54954 Mdot
.596 .54956 Mdot
.596 .54957 Mdot
.596 .54969 Mdot
.596 .54995 Mdot
.596 .55005 Mdot
.596 .55067 Mdot
.596 .55115 Mdot
.596 .55121 Mdot
.596 .55124 Mdot
.596 .55135 Mdot
.596 .5514 Mdot
.596 .55144 Mdot
.596 .55158 Mdot
.596 .5516 Mdot
.596 .55211 Mdot
.596 .55213 Mdot
.596 .55229 Mdot
.596 .5524 Mdot
.596 .55246 Mdot
.596 .55266 Mdot
.596 .5527 Mdot
.596 .55279 Mdot
.596 .5528 Mdot
.596 .55301 Mdot
.596 .55305 Mdot
.596 .55324 Mdot
.596 .5534 Mdot
.596 .55355 Mdot
.596 .55367 Mdot
.596 .55368 Mdot
.596 .55383 Mdot
.596 .55384 Mdot
.596 .55389 Mdot
.596 .55392 Mdot
.596 .554 Mdot
.596 .55412 Mdot
.596 .55416 Mdot
.596 .55419 Mdot
.596 .55426 Mdot
.596 .55428 Mdot
.596 .55429 Mdot
.596 .55435 Mdot
.596 .55445 Mdot
.596 .55458 Mdot
.596 .55464 Mdot
.596 .55466 Mdot
.596 .55472 Mdot
.596 .55477 Mdot
.596 .55487 Mdot
.596 .5549 Mdot
.596 .55495 Mdot
.596 .55498 Mdot
.596 .55502 Mdot
.596 .55509 Mdot
.596 .55523 Mdot
.596 .55525 Mdot
.596 .55526 Mdot
.596 .55527 Mdot
.596 .55541 Mdot
.596 .55547 Mdot
.596 .55551 Mdot
.596 .55559 Mdot
.596 .5556 Mdot
.596 .55563 Mdot
.596 .55564 Mdot
.596 .55564 Mdot
.596 .55566 Mdot
.596 .55568 Mdot
.596 .55573 Mdot
.596 .55575 Mdot
.596 .55576 Mdot
.596 .55576 Mdot
.598 .1748 Mdot
.598 .17481 Mdot
.598 .17482 Mdot
.598 .17485 Mdot
.598 .17486 Mdot
.598 .17486 Mdot
.598 .17492 Mdot
.598 .17499 Mdot
.598 .17506 Mdot
.598 .17512 Mdot
.598 .17531 Mdot
.598 .17538 Mdot
.598 .17552 Mdot
.598 .17553 Mdot
.598 .17573 Mdot
.598 .17599 Mdot
.598 .17605 Mdot
.598 .17613 Mdot
.598 .17622 Mdot
.598 .17653 Mdot
.598 .17664 Mdot
.598 .17695 Mdot
.598 .17702 Mdot
.598 .17707 Mdot
.598 .17728 Mdot
.598 .17737 Mdot
.598 .17748 Mdot
.598 .17764 Mdot
.598 .17784 Mdot
.598 .17807 Mdot
.598 .17878 Mdot
.598 .17906 Mdot
.598 .17926 Mdot
.598 .17927 Mdot
.598 .17941 Mdot
.598 .17986 Mdot
.598 .17993 Mdot
.598 .18038 Mdot
.598 .18049 Mdot
.598 .1807 Mdot
.598 .18137 Mdot
.598 .1814 Mdot
.598 .18215 Mdot
.598 .18221 Mdot
.598 .18256 Mdot
.598 .18312 Mdot
.598 .18329 Mdot
.598 .18344 Mdot
.598 .18347 Mdot
.598 .18421 Mdot
.598 .18429 Mdot
.598 .18439 Mdot
.598 .18444 Mdot
.598 .18454 Mdot
.598 .18466 Mdot
.598 .18483 Mdot
.598 .18494 Mdot
.598 .18499 Mdot
.598 .18545 Mdot
.598 .18594 Mdot
.598 .18595 Mdot
.598 .18627 Mdot
.598 .18656 Mdot
.598 .18665 Mdot
.598 .18724 Mdot
.598 .18758 Mdot
.598 .18796 Mdot
.598 .18804 Mdot
.598 .18866 Mdot
.598 .19087 Mdot
.598 .19128 Mdot
.598 .19259 Mdot
.598 .19365 Mdot
.598 .19415 Mdot
.598 .19572 Mdot
.598 .19642 Mdot
.598 .19675 Mdot
.598 .19678 Mdot
.598 .19686 Mdot
.598 .19736 Mdot
.598 .19777 Mdot
.598 .1988 Mdot
.598 .1992 Mdot
.598 .19957 Mdot
.598 .20002 Mdot
.598 .20026 Mdot
.598 .20114 Mdot
.598 .20129 Mdot
.598 .20198 Mdot
.598 .20415 Mdot
.598 .20458 Mdot
.598 .20497 Mdot
.598 .20505 Mdot
.598 .20612 Mdot
.598 .20626 Mdot
.598 .20631 Mdot
.598 .20826 Mdot
.598 .20847 Mdot
.598 .20911 Mdot
.598 .20912 Mdot
.598 .2094 Mdot
.598 .20985 Mdot
.598 .21158 Mdot
.598 .21316 Mdot
.598 .21326 Mdot
.598 .21357 Mdot
.598 .21358 Mdot
.598 .21398 Mdot
.598 .21414 Mdot
.598 .21453 Mdot
.598 .21455 Mdot
.598 .21571 Mdot
.598 .21649 Mdot
.598 .21727 Mdot
.598 .21776 Mdot
.598 .21809 Mdot
.598 .21818 Mdot
.598 .21868 Mdot
.598 .21896 Mdot
.598 .22052 Mdot
.598 .22055 Mdot
.598 .22059 Mdot
.598 .22076 Mdot
.598 .22324 Mdot
.598 .22412 Mdot
.598 .2252 Mdot
.598 .22543 Mdot
.598 .2256 Mdot
.598 .22589 Mdot
.598 .22677 Mdot
.598 .22691 Mdot
.598 .22759 Mdot
.598 .22904 Mdot
.598 .22913 Mdot
.598 .23033 Mdot
.598 .23046 Mdot
.598 .23059 Mdot
.598 .23062 Mdot
.598 .2324 Mdot
.598 .23443 Mdot
.598 .23511 Mdot
.598 .23532 Mdot
.598 .2378 Mdot
.598 .23886 Mdot
.598 .23907 Mdot
.598 .2395 Mdot
.598 .24001 Mdot
.598 .2407 Mdot
.598 .24184 Mdot
.598 .24218 Mdot
.598 .24267 Mdot
.598 .24303 Mdot
.598 .24343 Mdot
.598 .24403 Mdot
.598 .24462 Mdot
.598 .24499 Mdot
.598 .24568 Mdot
.598 .24686 Mdot
.598 .24735 Mdot
.598 .24826 Mdot
.598 .24953 Mdot
.598 .24977 Mdot
.598 .24998 Mdot
.598 .25008 Mdot
.598 .25059 Mdot
.598 .25191 Mdot
.598 .25326 Mdot
.598 .25417 Mdot
.598 .25498 Mdot
.598 .25609 Mdot
.598 .25663 Mdot
.598 .25679 Mdot
.598 .25688 Mdot
.598 .25758 Mdot
.598 .25952 Mdot
.598 .25956 Mdot
.598 .26093 Mdot
.598 .26112 Mdot
.598 .2614 Mdot
.598 .26231 Mdot
.598 .26301 Mdot
.598 .26334 Mdot
.598 .26358 Mdot
.598 .26378 Mdot
.598 .26383 Mdot
.598 .26588 Mdot
.598 .26616 Mdot
.598 .26635 Mdot
.598 .26817 Mdot
.598 .2682 Mdot
.598 .26829 Mdot
.598 .26933 Mdot
.598 .27113 Mdot
.598 .27237 Mdot
.598 .27288 Mdot
.598 .27346 Mdot
.598 .27455 Mdot
.598 .27962 Mdot
.598 .2827 Mdot
.598 .28413 Mdot
.598 .28422 Mdot
.598 .28454 Mdot
.598 .28488 Mdot
.598 .28543 Mdot
.598 .28595 Mdot
.598 .28633 Mdot
.598 .28647 Mdot
.598 .28797 Mdot
.598 .28819 Mdot
.598 .28944 Mdot
.598 .29148 Mdot
.598 .29197 Mdot
.598 .29267 Mdot
.598 .29353 Mdot
.598 .29376 Mdot
.598 .29412 Mdot
.598 .29462 Mdot
.598 .29643 Mdot
.598 .2972 Mdot
.598 .29766 Mdot
.598 .29827 Mdot
.598 .30095 Mdot
.598 .30115 Mdot
.598 .30287 Mdot
.598 .30351 Mdot
.598 .30492 Mdot
.598 .30529 Mdot
.598 .30585 Mdot
.598 .30645 Mdot
.598 .30816 Mdot
.598 .30834 Mdot
.598 .31024 Mdot
.598 .31071 Mdot
.598 .31082 Mdot
.598 .3109 Mdot
.598 .31421 Mdot
.598 .31519 Mdot
.598 .31598 Mdot
.598 .31736 Mdot
.598 .31761 Mdot
.598 .31852 Mdot
.598 .3188 Mdot
.598 .31961 Mdot
.598 .31988 Mdot
.598 .32057 Mdot
.598 .32118 Mdot
.598 .32207 Mdot
.598 .32425 Mdot
.598 .32525 Mdot
.598 .32623 Mdot
.598 .32752 Mdot
.598 .32756 Mdot
.598 .32867 Mdot
.598 .32913 Mdot
.598 .33025 Mdot
.598 .33029 Mdot
.598 .33117 Mdot
.598 .33128 Mdot
.598 .33139 Mdot
.598 .33145 Mdot
.598 .3319 Mdot
.598 .33202 Mdot
.598 .33315 Mdot
.598 .33453 Mdot
.598 .33487 Mdot
.598 .33526 Mdot
.598 .33595 Mdot
.598 .33804 Mdot
.598 .33957 Mdot
.598 .34048 Mdot
.598 .3409 Mdot
.598 .34218 Mdot
.598 .34274 Mdot
.598 .34301 Mdot
.598 .34303 Mdot
.598 .34309 Mdot
.598 .3438 Mdot
.598 .34488 Mdot
.598 .34548 Mdot
.598 .3463 Mdot
.598 .34641 Mdot
.598 .34841 Mdot
.598 .34897 Mdot
.598 .34903 Mdot
.598 .35114 Mdot
.598 .35128 Mdot
.598 .35169 Mdot
.598 .35323 Mdot
.598 .35445 Mdot
.598 .35479 Mdot
.598 .35503 Mdot
.598 .35617 Mdot
.598 .35715 Mdot
.598 .35743 Mdot
.598 .3576 Mdot
.598 .35849 Mdot
.598 .35861 Mdot
.598 .35997 Mdot
.598 .36103 Mdot
.598 .36187 Mdot
.598 .3623 Mdot
.598 .3631 Mdot
.598 .36372 Mdot
.598 .36378 Mdot
.598 .36385 Mdot
.598 .36579 Mdot
.598 .36623 Mdot
.598 .36883 Mdot
.598 .36938 Mdot
.598 .36954 Mdot
.598 .36994 Mdot
.598 .37012 Mdot
.598 .37041 Mdot
.598 .37085 Mdot
.598 .37172 Mdot
.598 .37194 Mdot
.598 .37293 Mdot
.598 .37314 Mdot
.598 .37318 Mdot
.598 .37609 Mdot
.598 .37615 Mdot
.598 .3765 Mdot
.598 .37735 Mdot
.598 .37794 Mdot
.598 .37814 Mdot
.598 .37883 Mdot
.598 .37907 Mdot
.598 .37915 Mdot
.598 .38003 Mdot
.598 .38015 Mdot
.598 .38099 Mdot
.598 .381 Mdot
.598 .38104 Mdot
.598 .38147 Mdot
.598 .38221 Mdot
.598 .38316 Mdot
.598 .38685 Mdot
.598 .38792 Mdot
.598 .38812 Mdot
.598 .38827 Mdot
.598 .38832 Mdot
.598 .38947 Mdot
.598 .39026 Mdot
.598 .39071 Mdot
.598 .39104 Mdot
.598 .39145 Mdot
.598 .39384 Mdot
.598 .39455 Mdot
.598 .39531 Mdot
.598 .39545 Mdot
.598 .39566 Mdot
.598 .39588 Mdot
.598 .39651 Mdot
.598 .39657 Mdot
.598 .39871 Mdot
.598 .40037 Mdot
.598 .40066 Mdot
.598 .40101 Mdot
.598 .40123 Mdot
.598 .40268 Mdot
.598 .40303 Mdot
.598 .40481 Mdot
.598 .40485 Mdot
.598 .40503 Mdot
.598 .40508 Mdot
.598 .40547 Mdot
.598 .40596 Mdot
.598 .40608 Mdot
.598 .40621 Mdot
.598 .40719 Mdot
.598 .40772 Mdot
.598 .40803 Mdot
.598 .40882 Mdot
.598 .40894 Mdot
.598 .40919 Mdot
.598 .41006 Mdot
.598 .41009 Mdot
.598 .41079 Mdot
.598 .41098 Mdot
.598 .411 Mdot
.598 .41245 Mdot
.598 .41286 Mdot
.598 .41379 Mdot
.598 .41394 Mdot
.598 .41425 Mdot
.598 .41429 Mdot
.598 .41476 Mdot
.598 .41512 Mdot
.598 .4154 Mdot
.598 .41555 Mdot
.598 .41582 Mdot
.598 .41603 Mdot
.598 .41608 Mdot
.598 .41796 Mdot
.598 .41815 Mdot
.598 .41821 Mdot
.598 .41831 Mdot
.598 .41876 Mdot
.598 .41917 Mdot
.598 .41925 Mdot
.598 .42024 Mdot
.598 .42038 Mdot
.598 .42087 Mdot
.598 .42094 Mdot
.598 .42158 Mdot
.598 .4219 Mdot
.598 .4219 Mdot
.598 .42192 Mdot
.598 .42206 Mdot
.598 .42264 Mdot
.598 .42425 Mdot
.598 .42432 Mdot
.598 .42437 Mdot
.598 .42477 Mdot
.598 .42504 Mdot
.598 .42519 Mdot
.598 .4253 Mdot
.598 .42625 Mdot
.598 .4265 Mdot
.598 .4268 Mdot
.598 .42687 Mdot
.598 .42718 Mdot
.598 .42791 Mdot
.598 .42847 Mdot
.598 .42857 Mdot
.598 .42869 Mdot
.598 .42876 Mdot
.598 .42925 Mdot
.598 .42998 Mdot
.598 .43006 Mdot
.598 .4302 Mdot
.598 .43037 Mdot
.598 .43041 Mdot
.598 .43097 Mdot
.598 .43108 Mdot
.598 .43135 Mdot
.598 .43178 Mdot
.598 .43202 Mdot
.598 .43273 Mdot
.598 .43321 Mdot
.598 .43381 Mdot
.598 .43447 Mdot
.598 .43454 Mdot
.598 .43489 Mdot
.598 .43503 Mdot
.598 .43525 Mdot
.598 .4353 Mdot
.598 .4355 Mdot
.598 .43572 Mdot
.598 .43583 Mdot
.598 .43583 Mdot
.598 .43608 Mdot
.598 .43668 Mdot
.598 .43682 Mdot
.598 .43691 Mdot
.598 .43696 Mdot
.598 .437 Mdot
.598 .43741 Mdot
.598 .43752 Mdot
.598 .4379 Mdot
.598 .43813 Mdot
.598 .4382 Mdot
.598 .43837 Mdot
.598 .43865 Mdot
.598 .4387 Mdot
.598 .43901 Mdot
.598 .4391 Mdot
.598 .43933 Mdot
.598 .43958 Mdot
.598 .43975 Mdot
.598 .44021 Mdot
.598 .44034 Mdot
.598 .44046 Mdot
.598 .44048 Mdot
.598 .44063 Mdot
.598 .44067 Mdot
.598 .44105 Mdot
.598 .44106 Mdot
.598 .44122 Mdot
.598 .44126 Mdot
.598 .44148 Mdot
.598 .44156 Mdot
.598 .44166 Mdot
.598 .44168 Mdot
.598 .44178 Mdot
.598 .44221 Mdot
.598 .44225 Mdot
.598 .4423 Mdot
.598 .44235 Mdot
.598 .44237 Mdot
.598 .44257 Mdot
.598 .44258 Mdot
.598 .44268 Mdot
.598 .44273 Mdot
.598 .44276 Mdot
.598 .44293 Mdot
.598 .44295 Mdot
.598 .44297 Mdot
.598 .44304 Mdot
.598 .44308 Mdot
.598 .4431 Mdot
.598 .44342 Mdot
.598 .44343 Mdot
.598 .44346 Mdot
.598 .4435 Mdot
.598 .44351 Mdot
.598 .44352 Mdot
.598 .44362 Mdot
.598 .44365 Mdot
.598 .44367 Mdot
.598 .44373 Mdot
.598 .44374 Mdot
.598 .44386 Mdot
.598 .44387 Mdot
.598 .4439 Mdot
.598 .44393 Mdot
.598 .44395 Mdot
.598 .4442 Mdot
.598 .44427 Mdot
.598 .44428 Mdot
.598 .44434 Mdot
.598 .44439 Mdot
.598 .44451 Mdot
.598 .44454 Mdot
.598 .44463 Mdot
.598 .44464 Mdot
.598 .44486 Mdot
.598 .44489 Mdot
.598 .44497 Mdot
.598 .44498 Mdot
.598 .44506 Mdot
.598 .44513 Mdot
.598 .4454 Mdot
.598 .4455 Mdot
.598 .44565 Mdot
.598 .44578 Mdot
.598 .44584 Mdot
.598 .44602 Mdot
.598 .44605 Mdot
.598 .44621 Mdot
.598 .44631 Mdot
.598 .44635 Mdot
.598 .44648 Mdot
.598 .4467 Mdot
.598 .44677 Mdot
.598 .44701 Mdot
.598 .44703 Mdot
.598 .44706 Mdot
.598 .44711 Mdot
.598 .44719 Mdot
.598 .44754 Mdot
.598 .44768 Mdot
.598 .44768 Mdot
.598 .44775 Mdot
.598 .44788 Mdot
.598 .44799 Mdot
.598 .44801 Mdot
.598 .44814 Mdot
.598 .44823 Mdot
.598 .44843 Mdot
.598 .44846 Mdot
.598 .44884 Mdot
.598 .44918 Mdot
.598 .44946 Mdot
.598 .44987 Mdot
.598 .45 Mdot
.598 .45025 Mdot
.598 .4504 Mdot
.598 .45046 Mdot
.598 .45078 Mdot
.598 .4508 Mdot
.598 .45089 Mdot
.598 .45098 Mdot
.598 .45102 Mdot
.598 .45143 Mdot
.598 .4517 Mdot
.598 .45174 Mdot
.598 .45181 Mdot
.598 .45187 Mdot
.598 .45218 Mdot
.598 .45259 Mdot
.598 .45276 Mdot
.598 .4528 Mdot
.598 .45297 Mdot
.598 .4531 Mdot
.598 .45363 Mdot
.598 .45369 Mdot
.598 .45377 Mdot
.598 .45392 Mdot
.598 .45415 Mdot
.598 .45417 Mdot
.598 .45421 Mdot
.598 .4551 Mdot
.598 .45541 Mdot
.598 .45549 Mdot
.598 .4555 Mdot
.598 .4555 Mdot
.598 .45568 Mdot
.598 .45603 Mdot
.598 .45606 Mdot
.598 .45633 Mdot
.598 .4564 Mdot
.598 .45694 Mdot
.598 .45698 Mdot
.598 .45721 Mdot
.598 .45745 Mdot
.598 .4575 Mdot
.598 .45753 Mdot
.598 .45764 Mdot
.598 .45865 Mdot
.598 .45867 Mdot
.598 .45878 Mdot
.598 .45893 Mdot
.598 .45901 Mdot
.598 .45916 Mdot
.598 .45935 Mdot
.598 .4596 Mdot
.598 .45962 Mdot
.598 .45978 Mdot
.598 .45987 Mdot
.598 .46036 Mdot
.598 .46058 Mdot
.598 .46134 Mdot
.598 .46135 Mdot
.598 .46145 Mdot
.598 .46181 Mdot
.598 .46183 Mdot
.598 .46229 Mdot
.598 .46241 Mdot
.598 .46248 Mdot
.598 .46289 Mdot
.598 .46305 Mdot
.598 .46333 Mdot
.598 .46383 Mdot
.598 .4639 Mdot
.598 .46396 Mdot
.598 .46421 Mdot
.598 .46442 Mdot
.598 .46444 Mdot
.598 .46453 Mdot
.598 .46455 Mdot
.598 .46547 Mdot
.598 .46565 Mdot
.598 .46639 Mdot
.598 .4665 Mdot
.598 .46667 Mdot
.598 .46682 Mdot
.598 .46766 Mdot
.598 .46874 Mdot
.598 .46877 Mdot
.598 .46919 Mdot
.598 .4693 Mdot
.598 .46937 Mdot
.598 .46975 Mdot
.598 .4701 Mdot
.598 .47128 Mdot
.598 .47149 Mdot
.598 .47165 Mdot
.598 .47187 Mdot
.598 .47225 Mdot
.598 .47282 Mdot
.598 .47284 Mdot
.598 .47292 Mdot
.598 .47301 Mdot
.598 .47354 Mdot
.598 .47532 Mdot
.598 .47578 Mdot
.598 .47613 Mdot
.598 .47634 Mdot
.598 .47636 Mdot
.598 .47636 Mdot
.598 .47676 Mdot
.598 .47682 Mdot
.598 .47724 Mdot
.598 .47728 Mdot
.598 .47739 Mdot
.598 .47772 Mdot
.598 .47781 Mdot
.598 .47809 Mdot
.598 .47849 Mdot
.598 .47866 Mdot
.598 .47869 Mdot
.598 .48005 Mdot
.598 .48007 Mdot
.598 .48017 Mdot
.598 .48063 Mdot
.598 .48074 Mdot
.598 .48114 Mdot
.598 .48135 Mdot
.598 .48148 Mdot
.598 .48156 Mdot
.598 .48175 Mdot
.598 .48182 Mdot
.598 .48207 Mdot
.598 .48328 Mdot
.598 .48348 Mdot
.598 .48436 Mdot
.598 .48439 Mdot
.598 .48442 Mdot
.598 .48471 Mdot
.598 .48507 Mdot
.598 .48527 Mdot
.598 .48564 Mdot
.598 .48612 Mdot
.598 .48674 Mdot
.598 .48679 Mdot
.598 .48719 Mdot
.598 .48727 Mdot
.598 .48739 Mdot
.598 .48783 Mdot
.598 .48834 Mdot
.598 .48845 Mdot
.598 .4886 Mdot
.598 .48914 Mdot
.598 .48983 Mdot
.598 .49001 Mdot
.598 .49007 Mdot
.598 .491 Mdot
.598 .49103 Mdot
.598 .49127 Mdot
.598 .49215 Mdot
.598 .49219 Mdot
.598 .49255 Mdot
.598 .49282 Mdot
.598 .49329 Mdot
.598 .49359 Mdot
.598 .49362 Mdot
.598 .49363 Mdot
.598 .49375 Mdot
.598 .49399 Mdot
.598 .49454 Mdot
.598 .49472 Mdot
.598 .49511 Mdot
.598 .49577 Mdot
.598 .49666 Mdot
.598 .49696 Mdot
.598 .49712 Mdot
.598 .49727 Mdot
.598 .49785 Mdot
.598 .49833 Mdot
.598 .49838 Mdot
.598 .49857 Mdot
.598 .4986 Mdot
.598 .49864 Mdot
.598 .49869 Mdot
.598 .49906 Mdot
.598 .49908 Mdot
.598 .49955 Mdot
.598 .49974 Mdot
.598 .50021 Mdot
.598 .50022 Mdot
.598 .50076 Mdot
.598 .50117 Mdot
.598 .50159 Mdot
.598 .50249 Mdot
.598 .50286 Mdot
.598 .50311 Mdot
.598 .50339 Mdot
.598 .50351 Mdot
.598 .50384 Mdot
.598 .50395 Mdot
.598 .50433 Mdot
.598 .50443 Mdot
.598 .50499 Mdot
.598 .50531 Mdot
.598 .50572 Mdot
.598 .50706 Mdot
.598 .50709 Mdot
.598 .50713 Mdot
.598 .50732 Mdot
.598 .50809 Mdot
.598 .50816 Mdot
.598 .50885 Mdot
.598 .50908 Mdot
.598 .50931 Mdot
.598 .50946 Mdot
.598 .51002 Mdot
.598 .51027 Mdot
.598 .51096 Mdot
.598 .51103 Mdot
.598 .51209 Mdot
.598 .51233 Mdot
.598 .51252 Mdot
.598 .51282 Mdot
.598 .51353 Mdot
.598 .51372 Mdot
.598 .51386 Mdot
.598 .51395 Mdot
.598 .51429 Mdot
.598 .51456 Mdot
.598 .51475 Mdot
.598 .51554 Mdot
.598 .51603 Mdot
.598 .51611 Mdot
.598 .51669 Mdot
.598 .51675 Mdot
.598 .51689 Mdot
.598 .51709 Mdot
.598 .5173 Mdot
.598 .51743 Mdot
.598 .51756 Mdot
.598 .51759 Mdot
.598 .51814 Mdot
.598 .51931 Mdot
.598 .52123 Mdot
.598 .52164 Mdot
.598 .52186 Mdot
.598 .52205 Mdot
.598 .52252 Mdot
.598 .52319 Mdot
.598 .52358 Mdot
.598 .52362 Mdot
.598 .52363 Mdot
.598 .5243 Mdot
.598 .52437 Mdot
.598 .52448 Mdot
.598 .52524 Mdot
.598 .52526 Mdot
.598 .52533 Mdot
.598 .52542 Mdot
.598 .52554 Mdot
.598 .5258 Mdot
.598 .52613 Mdot
.598 .52624 Mdot
.598 .52631 Mdot
.598 .52681 Mdot
.598 .52683 Mdot
.598 .52754 Mdot
.598 .52779 Mdot
.598 .52783 Mdot
.598 .52788 Mdot
.598 .52808 Mdot
.598 .52849 Mdot
.598 .52878 Mdot
.598 .52911 Mdot
.598 .5296 Mdot
.598 .53008 Mdot
.598 .53027 Mdot
.598 .5303 Mdot
.598 .53038 Mdot
.598 .53047 Mdot
.598 .53092 Mdot
.598 .53125 Mdot
.598 .53143 Mdot
.598 .53185 Mdot
.598 .5321 Mdot
.598 .53223 Mdot
.598 .53244 Mdot
.598 .53266 Mdot
.598 .5328 Mdot
.598 .53293 Mdot
.598 .5331 Mdot
.598 .53323 Mdot
.598 .53363 Mdot
.598 .53388 Mdot
.598 .53406 Mdot
.598 .53421 Mdot
.598 .53429 Mdot
.598 .53466 Mdot
.598 .53554 Mdot
.598 .53561 Mdot
.598 .53585 Mdot
.598 .53657 Mdot
.598 .53719 Mdot
.598 .53721 Mdot
.598 .53725 Mdot
.598 .5373 Mdot
.598 .53772 Mdot
.598 .53775 Mdot
.598 .53825 Mdot
.598 .53849 Mdot
.598 .53854 Mdot
.598 .53885 Mdot
.598 .53895 Mdot
.598 .53901 Mdot
.598 .53909 Mdot
.598 .53946 Mdot
.598 .53977 Mdot
.598 .54063 Mdot
.598 .54069 Mdot
.598 .5407 Mdot
.598 .54071 Mdot
.598 .54125 Mdot
.598 .54135 Mdot
.598 .54152 Mdot
.598 .54155 Mdot
.598 .54166 Mdot
.598 .54183 Mdot
.598 .5421 Mdot
.598 .54237 Mdot
.598 .54276 Mdot
.598 .54277 Mdot
.598 .5429 Mdot
.598 .54296 Mdot
.598 .54309 Mdot
.598 .5431 Mdot
.598 .5432 Mdot
.598 .54324 Mdot
.598 .54378 Mdot
.598 .54436 Mdot
.598 .54452 Mdot
.598 .54461 Mdot
.598 .54462 Mdot
.598 .54483 Mdot
.598 .54491 Mdot
.598 .54557 Mdot
.598 .54558 Mdot
.598 .54563 Mdot
.598 .54599 Mdot
.598 .54602 Mdot
.598 .54615 Mdot
.598 .5463 Mdot
.598 .54703 Mdot
.598 .54726 Mdot
.598 .54731 Mdot
.598 .5476 Mdot
.598 .54768 Mdot
.598 .54783 Mdot
.598 .54796 Mdot
.598 .54809 Mdot
.598 .54844 Mdot
.598 .54857 Mdot
.598 .54874 Mdot
.598 .54877 Mdot
.598 .54878 Mdot
.598 .54889 Mdot
.598 .54912 Mdot
.598 .54964 Mdot
.598 .54981 Mdot
.598 .55016 Mdot
.598 .5506 Mdot
.598 .55073 Mdot
.598 .55146 Mdot
.598 .55167 Mdot
.598 .55169 Mdot
.598 .55182 Mdot
.598 .55193 Mdot
.598 .55213 Mdot
.598 .55215 Mdot
.598 .55225 Mdot
.598 .55235 Mdot
.598 .55236 Mdot
.598 .55252 Mdot
.598 .55267 Mdot
.598 .55269 Mdot
.598 .55272 Mdot
.598 .55278 Mdot
.598 .55282 Mdot
.598 .55285 Mdot
.598 .55287 Mdot
.598 .5529 Mdot
.598 .55293 Mdot
.598 .55317 Mdot
.598 .55318 Mdot
.598 .55323 Mdot
.598 .55328 Mdot
.598 .55347 Mdot
.598 .55358 Mdot
.598 .5536 Mdot
.598 .55385 Mdot
.598 .55386 Mdot
.598 .55407 Mdot
.598 .55414 Mdot
.598 .55418 Mdot
.598 .55432 Mdot
.598 .55435 Mdot
.598 .5545 Mdot
.598 .55454 Mdot
.598 .55454 Mdot
.598 .55461 Mdot
.598 .5547 Mdot
.598 .55493 Mdot
.598 .55501 Mdot
.598 .55507 Mdot
.598 .55512 Mdot
.598 .55516 Mdot
.598 .55519 Mdot
.598 .55526 Mdot
.598 .55527 Mdot
.598 .55529 Mdot
.598 .5554 Mdot
.598 .55543 Mdot
.598 .55553 Mdot
.598 .55556 Mdot
.598 .55559 Mdot
.598 .55561 Mdot
.598 .55569 Mdot
.598 .55576 Mdot
.598 .55576 Mdot
.598 .55581 Mdot
.598 .55583 Mdot
.598 .55589 Mdot
.598 .55591 Mdot
.598 .55593 Mdot
.598 .55595 Mdot
.598 .55597 Mdot
.598 .55598 Mdot
.598 .55598 Mdot
.598 .55599 Mdot
.598 .55599 Mdot
.598 .55599 Mdot
.6 .17414 Mdot
.6 .17414 Mdot
.6 .17414 Mdot
.6 .17415 Mdot
.6 .17418 Mdot
.6 .17418 Mdot
.6 .1742 Mdot
.6 .17423 Mdot
.6 .17425 Mdot
.6 .1745 Mdot
.6 .17456 Mdot
.6 .17456 Mdot
.6 .17479 Mdot
.6 .17486 Mdot
.6 .1751 Mdot
.6 .17528 Mdot
.6 .17559 Mdot
.6 .17645 Mdot
.6 .17662 Mdot
.6 .17684 Mdot
.6 .17688 Mdot
.6 .17691 Mdot
.6 .17704 Mdot
.6 .17705 Mdot
.6 .17735 Mdot
.6 .17773 Mdot
.6 .17775 Mdot
.6 .17785 Mdot
.6 .17797 Mdot
.6 .17861 Mdot
.6 .17883 Mdot
.6 .17929 Mdot
.6 .17941 Mdot
.6 .18032 Mdot
.6 .18134 Mdot
.6 .18135 Mdot
.6 .18156 Mdot
.6 .18173 Mdot
.6 .18191 Mdot
.6 .18201 Mdot
.6 .18221 Mdot
.6 .18227 Mdot
.6 .18228 Mdot
.6 .18252 Mdot
.6 .18392 Mdot
.6 .18411 Mdot
.6 .18441 Mdot
.6 .18448 Mdot
.6 .1845 Mdot
.6 .18493 Mdot
.6 .18495 Mdot
.6 .18513 Mdot
.6 .18567 Mdot
.6 .18578 Mdot
.6 .18594 Mdot
.6 .18608 Mdot
.6 .18617 Mdot
.6 .18635 Mdot
.6 .18678 Mdot
.6 .18688 Mdot
.6 .18692 Mdot
.6 .18698 Mdot
.6 .18774 Mdot
.6 .18782 Mdot
.6 .18815 Mdot
.6 .18819 Mdot
.6 .18919 Mdot
.6 .19035 Mdot
.6 .19051 Mdot
.6 .19075 Mdot
.6 .19087 Mdot
.6 .19172 Mdot
.6 .19226 Mdot
.6 .1927 Mdot
.6 .19309 Mdot
.6 .19329 Mdot
.6 .19366 Mdot
.6 .19376 Mdot
.6 .19383 Mdot
.6 .19394 Mdot
.6 .19439 Mdot
.6 .19484 Mdot
.6 .19489 Mdot
.6 .19512 Mdot
.6 .19538 Mdot
.6 .19592 Mdot
.6 .19628 Mdot
.6 .19693 Mdot
.6 .19746 Mdot
.6 .19788 Mdot
.6 .19832 Mdot
.6 .19951 Mdot
.6 .19958 Mdot
.6 .20027 Mdot
.6 .20043 Mdot
.6 .2013 Mdot
.6 .20146 Mdot
.6 .20305 Mdot
.6 .20315 Mdot
.6 .20318 Mdot
.6 .20337 Mdot
.6 .20492 Mdot
.6 .20506 Mdot
.6 .20522 Mdot
.6 .20546 Mdot
.6 .20572 Mdot
.6 .20619 Mdot
.6 .20663 Mdot
.6 .20767 Mdot
.6 .20906 Mdot
.6 .20961 Mdot
.6 .20986 Mdot
.6 .21107 Mdot
.6 .2114 Mdot
.6 .21182 Mdot
.6 .21205 Mdot
.6 .2122 Mdot
.6 .21279 Mdot
.6 .21298 Mdot
.6 .21369 Mdot
.6 .21401 Mdot
.6 .21598 Mdot
.6 .21613 Mdot
.6 .21663 Mdot
.6 .21673 Mdot
.6 .21696 Mdot
.6 .22025 Mdot
.6 .22114 Mdot
.6 .22164 Mdot
.6 .22265 Mdot
.6 .22279 Mdot
.6 .2232 Mdot
.6 .22332 Mdot
.6 .22367 Mdot
.6 .2239 Mdot
.6 .22512 Mdot
.6 .22562 Mdot
.6 .22864 Mdot
.6 .2298 Mdot
.6 .23 Mdot
.6 .23076 Mdot
.6 .23229 Mdot
.6 .23329 Mdot
.6 .23331 Mdot
.6 .23446 Mdot
.6 .23459 Mdot
.6 .2351 Mdot
.6 .23663 Mdot
.6 .23678 Mdot
.6 .23852 Mdot
.6 .2395 Mdot
.6 .24179 Mdot
.6 .24274 Mdot
.6 .24381 Mdot
.6 .24425 Mdot
.6 .2509 Mdot
.6 .25164 Mdot
.6 .25189 Mdot
.6 .25196 Mdot
.6 .2543 Mdot
.6 .2549 Mdot
.6 .25648 Mdot
.6 .25777 Mdot
.6 .25939 Mdot
.6 .26144 Mdot
.6 .26182 Mdot
.6 .2637 Mdot
.6 .26415 Mdot
.6 .26429 Mdot
.6 .26455 Mdot
.6 .26565 Mdot
.6 .266 Mdot
.6 .26785 Mdot
.6 .26833 Mdot
.6 .26859 Mdot
.6 .26869 Mdot
.6 .26996 Mdot
.6 .27192 Mdot
.6 .27242 Mdot
.6 .27247 Mdot
.6 .27368 Mdot
.6 .274 Mdot
.6 .27441 Mdot
.6 .27563 Mdot
.6 .27584 Mdot
.6 .27602 Mdot
.6 .27606 Mdot
.6 .27642 Mdot
.6 .27688 Mdot
.6 .27694 Mdot
.6 .27733 Mdot
.6 .27943 Mdot
.6 .27953 Mdot
.6 .27975 Mdot
.6 .2799 Mdot
.6 .28196 Mdot
.6 .28228 Mdot
.6 .28237 Mdot
.6 .28319 Mdot
.6 .28333 Mdot
.6 .28397 Mdot
.6 .28406 Mdot
.6 .28438 Mdot
.6 .28449 Mdot
.6 .28528 Mdot
.6 .2853 Mdot
.6 .28578 Mdot
.6 .28813 Mdot
.6 .28843 Mdot
.6 .28878 Mdot
.6 .28965 Mdot
.6 .28967 Mdot
.6 .2911 Mdot
.6 .29246 Mdot
.6 .29265 Mdot
.6 .29341 Mdot
.6 .29515 Mdot
.6 .29536 Mdot
.6 .2961 Mdot
.6 .29672 Mdot
.6 .29806 Mdot
.6 .30035 Mdot
.6 .30133 Mdot
.6 .30195 Mdot
.6 .30289 Mdot
.6 .3032 Mdot
.6 .3043 Mdot
.6 .30435 Mdot
.6 .3047 Mdot
.6 .30717 Mdot
.6 .30744 Mdot
.6 .30751 Mdot
.6 .30812 Mdot
.6 .30867 Mdot
.6 .30879 Mdot
.6 .30961 Mdot
.6 .31007 Mdot
.6 .31124 Mdot
.6 .31139 Mdot
.6 .32037 Mdot
.6 .32085 Mdot
.6 .32095 Mdot
.6 .321 Mdot
.6 .3213 Mdot
.6 .3227 Mdot
.6 .32311 Mdot
.6 .32426 Mdot
.6 .32866 Mdot
.6 .32889 Mdot
.6 .32913 Mdot
.6 .32951 Mdot
.6 .32958 Mdot
.6 .33158 Mdot
.6 .33181 Mdot
.6 .33215 Mdot
.6 .33223 Mdot
.6 .33296 Mdot
.6 .33383 Mdot
.6 .33426 Mdot
.6 .3348 Mdot
.6 .3349 Mdot
.6 .33611 Mdot
.6 .33707 Mdot
.6 .33936 Mdot
.6 .33983 Mdot
.6 .3402 Mdot
.6 .34053 Mdot
.6 .34101 Mdot
.6 .34124 Mdot
.6 .34283 Mdot
.6 .34312 Mdot
.6 .34468 Mdot
.6 .34623 Mdot
.6 .34685 Mdot
.6 .34697 Mdot
.6 .34814 Mdot
.6 .34816 Mdot
.6 .34829 Mdot
.6 .34955 Mdot
.6 .34987 Mdot
.6 .35047 Mdot
.6 .35115 Mdot
.6 .35253 Mdot
.6 .35328 Mdot
.6 .35397 Mdot
.6 .35445 Mdot
.6 .35487 Mdot
.6 .35506 Mdot
.6 .3563 Mdot
.6 .35665 Mdot
.6 .35678 Mdot
.6 .35914 Mdot
.6 .35941 Mdot
.6 .35996 Mdot
.6 .36004 Mdot
.6 .36032 Mdot
.6 .36051 Mdot
.6 .36064 Mdot
.6 .36129 Mdot
.6 .36383 Mdot
.6 .36422 Mdot
.6 .36499 Mdot
.6 .36549 Mdot
.6 .3655 Mdot
.6 .36721 Mdot
.6 .36805 Mdot
.6 .36852 Mdot
.6 .36961 Mdot
.6 .37005 Mdot
.6 .37055 Mdot
.6 .37076 Mdot
.6 .37411 Mdot
.6 .37425 Mdot
.6 .37555 Mdot
.6 .3768 Mdot
.6 .37749 Mdot
.6 .37837 Mdot
.6 .37933 Mdot
.6 .37957 Mdot
.6 .37968 Mdot
.6 .38014 Mdot
.6 .38029 Mdot
.6 .38105 Mdot
.6 .38136 Mdot
.6 .38192 Mdot
.6 .38273 Mdot
.6 .38295 Mdot
.6 .38373 Mdot
.6 .38422 Mdot
.6 .38431 Mdot
.6 .38438 Mdot
.6 .38439 Mdot
.6 .38454 Mdot
.6 .38491 Mdot
.6 .38578 Mdot
.6 .38587 Mdot
.6 .38592 Mdot
.6 .38674 Mdot
.6 .3869 Mdot
.6 .38722 Mdot
.6 .38752 Mdot
.6 .38756 Mdot
.6 .38768 Mdot
.6 .38773 Mdot
.6 .38804 Mdot
.6 .38914 Mdot
.6 .38925 Mdot
.6 .38972 Mdot
.6 .38973 Mdot
.6 .39028 Mdot
.6 .3908 Mdot
.6 .39087 Mdot
.6 .39116 Mdot
.6 .39182 Mdot
.6 .3919 Mdot
.6 .39218 Mdot
.6 .39377 Mdot
.6 .39526 Mdot
.6 .39629 Mdot
.6 .39642 Mdot
.6 .39664 Mdot
.6 .39684 Mdot
.6 .39719 Mdot
.6 .39736 Mdot
.6 .39784 Mdot
.6 .40125 Mdot
.6 .40128 Mdot
.6 .40246 Mdot
.6 .4041 Mdot
.6 .40418 Mdot
.6 .40432 Mdot
.6 .40513 Mdot
.6 .40528 Mdot
.6 .40553 Mdot
.6 .40618 Mdot
.6 .40777 Mdot
.6 .40793 Mdot
.6 .40806 Mdot
.6 .40834 Mdot
.6 .40907 Mdot
.6 .40961 Mdot
.6 .41014 Mdot
.6 .4104 Mdot
.6 .41081 Mdot
.6 .41081 Mdot
.6 .41086 Mdot
.6 .41129 Mdot
.6 .41161 Mdot
.6 .41318 Mdot
.6 .4136 Mdot
.6 .41373 Mdot
.6 .41377 Mdot
.6 .41457 Mdot
.6 .41504 Mdot
.6 .41509 Mdot
.6 .41531 Mdot
.6 .41617 Mdot
.6 .4163 Mdot
.6 .41674 Mdot
.6 .41732 Mdot
.6 .41814 Mdot
.6 .41829 Mdot
.6 .41966 Mdot
.6 .42081 Mdot
.6 .42143 Mdot
.6 .42151 Mdot
.6 .42155 Mdot
.6 .4217 Mdot
.6 .42201 Mdot
.6 .4223 Mdot
.6 .42258 Mdot
.6 .42308 Mdot
.6 .42311 Mdot
.6 .42314 Mdot
.6 .42331 Mdot
.6 .42361 Mdot
.6 .42366 Mdot
.6 .42393 Mdot
.6 .42399 Mdot
.6 .42421 Mdot
.6 .42425 Mdot
.6 .42478 Mdot
.6 .42494 Mdot
.6 .42513 Mdot
.6 .42531 Mdot
.6 .42543 Mdot
.6 .42565 Mdot
.6 .42568 Mdot
.6 .42681 Mdot
.6 .42721 Mdot
.6 .42735 Mdot
.6 .42747 Mdot
.6 .42885 Mdot
.6 .42925 Mdot
.6 .42981 Mdot
.6 .43016 Mdot
.6 .43052 Mdot
.6 .4315 Mdot
.6 .43209 Mdot
.6 .43211 Mdot
.6 .43304 Mdot
.6 .43338 Mdot
.6 .43397 Mdot
.6 .43432 Mdot
.6 .43459 Mdot
.6 .43465 Mdot
.6 .43512 Mdot
.6 .43572 Mdot
.6 .43593 Mdot
.6 .43629 Mdot
.6 .43631 Mdot
.6 .43637 Mdot
.6 .43649 Mdot
.6 .43659 Mdot
.6 .43661 Mdot
.6 .43688 Mdot
.6 .43693 Mdot
.6 .437 Mdot
.6 .43706 Mdot
.6 .4371 Mdot
.6 .43718 Mdot
.6 .43719 Mdot
.6 .43758 Mdot
.6 .43777 Mdot
.6 .43781 Mdot
.6 .43829 Mdot
.6 .43843 Mdot
.6 .43886 Mdot
.6 .43941 Mdot
.6 .43974 Mdot
.6 .43986 Mdot
.6 .44047 Mdot
.6 .44075 Mdot
.6 .44088 Mdot
.6 .44089 Mdot
.6 .44091 Mdot
.6 .44095 Mdot
.6 .44108 Mdot
.6 .4411 Mdot
.6 .44116 Mdot
.6 .44119 Mdot
.6 .44133 Mdot
.6 .4414 Mdot
.6 .44163 Mdot
.6 .44178 Mdot
.6 .44197 Mdot
.6 .44209 Mdot
.6 .44213 Mdot
.6 .44235 Mdot
.6 .44249 Mdot
.6 .44249 Mdot
.6 .4425 Mdot
.6 .44252 Mdot
.6 .44256 Mdot
.6 .44257 Mdot
.6 .44259 Mdot
.6 .4426 Mdot
.6 .44265 Mdot
.6 .44267 Mdot
.6 .44281 Mdot
.6 .44288 Mdot
.6 .44292 Mdot
.6 .44301 Mdot
.6 .4431 Mdot
.6 .4432 Mdot
.6 .44321 Mdot
.6 .44359 Mdot
.6 .44364 Mdot
.6 .44367 Mdot
.6 .44371 Mdot
.6 .44384 Mdot
.6 .44398 Mdot
.6 .44411 Mdot
.6 .44413 Mdot
.6 .4442 Mdot
.6 .44432 Mdot
.6 .44441 Mdot
.6 .44454 Mdot
.6 .44458 Mdot
.6 .44467 Mdot
.6 .44468 Mdot
.6 .44472 Mdot
.6 .44473 Mdot
.6 .44481 Mdot
.6 .44483 Mdot
.6 .44484 Mdot
.6 .44485 Mdot
.6 .44492 Mdot
.6 .44509 Mdot
.6 .44545 Mdot
.6 .44551 Mdot
.6 .44571 Mdot
.6 .44603 Mdot
.6 .44628 Mdot
.6 .44637 Mdot
.6 .44664 Mdot
.6 .44667 Mdot
.6 .44678 Mdot
.6 .447 Mdot
.6 .44701 Mdot
.6 .44705 Mdot
.6 .44708 Mdot
.6 .44711 Mdot
.6 .44715 Mdot
.6 .44718 Mdot
.6 .44734 Mdot
.6 .44735 Mdot
.6 .44741 Mdot
.6 .44748 Mdot
.6 .44751 Mdot
.6 .44752 Mdot
.6 .44773 Mdot
.6 .44785 Mdot
.6 .4482 Mdot
.6 .44847 Mdot
.6 .4485 Mdot
.6 .44866 Mdot
.6 .44886 Mdot
.6 .4492 Mdot
.6 .44938 Mdot
.6 .44992 Mdot
.6 .44993 Mdot
.6 .45026 Mdot
.6 .45082 Mdot
.6 .45102 Mdot
.6 .45122 Mdot
.6 .45153 Mdot
.6 .45175 Mdot
.6 .45253 Mdot
.6 .45259 Mdot
.6 .45267 Mdot
.6 .45289 Mdot
.6 .45352 Mdot
.6 .45354 Mdot
.6 .45366 Mdot
.6 .45373 Mdot
.6 .45382 Mdot
.6 .45393 Mdot
.6 .45401 Mdot
.6 .45431 Mdot
.6 .45433 Mdot
.6 .45445 Mdot
.6 .45448 Mdot
.6 .45463 Mdot
.6 .45466 Mdot
.6 .45482 Mdot
.6 .45492 Mdot
.6 .45493 Mdot
.6 .45495 Mdot
.6 .45523 Mdot
.6 .45538 Mdot
.6 .45554 Mdot
.6 .4557 Mdot
.6 .45579 Mdot
.6 .45581 Mdot
.6 .45585 Mdot
.6 .45619 Mdot
.6 .45681 Mdot
.6 .45756 Mdot
.6 .45764 Mdot
.6 .45807 Mdot
.6 .45839 Mdot
.6 .45862 Mdot
.6 .45869 Mdot
.6 .45915 Mdot
.6 .45927 Mdot
.6 .45929 Mdot
.6 .45954 Mdot
.6 .45997 Mdot
.6 .45999 Mdot
.6 .46005 Mdot
.6 .46028 Mdot
.6 .46111 Mdot
.6 .46128 Mdot
.6 .4615 Mdot
.6 .46153 Mdot
.6 .46153 Mdot
.6 .46174 Mdot
.6 .46188 Mdot
.6 .46215 Mdot
.6 .46244 Mdot
.6 .46282 Mdot
.6 .46296 Mdot
.6 .46303 Mdot
.6 .46312 Mdot
.6 .46394 Mdot
.6 .46427 Mdot
.6 .4644 Mdot
.6 .46448 Mdot
.6 .46489 Mdot
.6 .46496 Mdot
.6 .46501 Mdot
.6 .46584 Mdot
.6 .46644 Mdot
.6 .46646 Mdot
.6 .46819 Mdot
.6 .46843 Mdot
.6 .46851 Mdot
.6 .46868 Mdot
.6 .46878 Mdot
.6 .4689 Mdot
.6 .46896 Mdot
.6 .46948 Mdot
.6 .47022 Mdot
.6 .471 Mdot
.6 .47114 Mdot
.6 .47118 Mdot
.6 .47151 Mdot
.6 .47165 Mdot
.6 .47168 Mdot
.6 .47194 Mdot
.6 .47221 Mdot
.6 .47221 Mdot
.6 .47244 Mdot
.6 .4725 Mdot
.6 .47303 Mdot
.6 .47319 Mdot
.6 .47321 Mdot
.6 .47327 Mdot
.6 .47329 Mdot
.6 .47343 Mdot
.6 .47359 Mdot
.6 .47367 Mdot
.6 .47406 Mdot
.6 .47409 Mdot
.6 .47413 Mdot
.6 .47455 Mdot
.6 .47473 Mdot
.6 .4748 Mdot
.6 .47481 Mdot
.6 .47484 Mdot
.6 .47489 Mdot
.6 .47512 Mdot
.6 .4755 Mdot
.6 .4756 Mdot
.6 .47599 Mdot
.6 .47626 Mdot
.6 .47641 Mdot
.6 .47677 Mdot
.6 .47684 Mdot
.6 .47706 Mdot
.6 .47711 Mdot
.6 .47723 Mdot
.6 .47768 Mdot
.6 .4781 Mdot
.6 .47843 Mdot
.6 .47902 Mdot
.6 .47962 Mdot
.6 .47969 Mdot
.6 .48126 Mdot
.6 .48135 Mdot
.6 .48158 Mdot
.6 .48179 Mdot
.6 .48229 Mdot
.6 .48251 Mdot
.6 .48289 Mdot
.6 .48368 Mdot
.6 .48368 Mdot
.6 .48391 Mdot
.6 .48426 Mdot
.6 .48444 Mdot
.6 .4856 Mdot
.6 .48589 Mdot
.6 .48595 Mdot
.6 .48603 Mdot
.6 .48616 Mdot
.6 .4862 Mdot
.6 .48645 Mdot
.6 .48657 Mdot
.6 .48763 Mdot
.6 .48768 Mdot
.6 .48784 Mdot
.6 .48839 Mdot
.6 .48848 Mdot
.6 .48867 Mdot
.6 .48888 Mdot
.6 .48919 Mdot
.6 .48952 Mdot
.6 .49013 Mdot
.6 .49043 Mdot
.6 .49069 Mdot
.6 .49084 Mdot
.6 .49139 Mdot
.6 .49144 Mdot
.6 .49145 Mdot
.6 .49197 Mdot
.6 .49202 Mdot
.6 .49229 Mdot
.6 .49296 Mdot
.6 .49364 Mdot
.6 .49377 Mdot
.6 .49446 Mdot
.6 .49455 Mdot
.6 .49476 Mdot
.6 .4949 Mdot
.6 .49506 Mdot
.6 .49526 Mdot
.6 .49625 Mdot
.6 .49665 Mdot
.6 .49717 Mdot
.6 .49721 Mdot
.6 .49744 Mdot
.6 .49762 Mdot
.6 .49799 Mdot
.6 .4983 Mdot
.6 .49834 Mdot
.6 .49848 Mdot
.6 .49857 Mdot
.6 .49942 Mdot
.6 .49944 Mdot
.6 .49961 Mdot
.6 .49971 Mdot
.6 .4998 Mdot
.6 .50164 Mdot
.6 .50211 Mdot
.6 .50228 Mdot
.6 .50287 Mdot
.6 .50299 Mdot
.6 .50301 Mdot
.6 .50305 Mdot
.6 .50325 Mdot
.6 .50691 Mdot
.6 .50697 Mdot
.6 .50744 Mdot
.6 .50763 Mdot
.6 .50796 Mdot
.6 .508 Mdot
.6 .50823 Mdot
.6 .50847 Mdot
.6 .5085 Mdot
.6 .50861 Mdot
.6 .50959 Mdot
.6 .50973 Mdot
.6 .50975 Mdot
.6 .51019 Mdot
.6 .51031 Mdot
.6 .51069 Mdot
.6 .51094 Mdot
.6 .51132 Mdot
.6 .51223 Mdot
.6 .51275 Mdot
.6 .51299 Mdot
.6 .51328 Mdot
.6 .51337 Mdot
.6 .51405 Mdot
.6 .51434 Mdot
.6 .51442 Mdot
.6 .51495 Mdot
.6 .5155 Mdot
.6 .51551 Mdot
.6 .51584 Mdot
.6 .51598 Mdot
.6 .5161 Mdot
.6 .517 Mdot
.6 .51719 Mdot
.6 .51719 Mdot
.6 .5175 Mdot
.6 .51754 Mdot
.6 .51766 Mdot
.6 .5177 Mdot
.6 .51794 Mdot
.6 .518 Mdot
.6 .51831 Mdot
.6 .51834 Mdot
.6 .51846 Mdot
.6 .51925 Mdot
.6 .51931 Mdot
.6 .51939 Mdot
.6 .51943 Mdot
.6 .52022 Mdot
.6 .52037 Mdot
.6 .5204 Mdot
.6 .52057 Mdot
.6 .52071 Mdot
.6 .52072 Mdot
.6 .52079 Mdot
.6 .52087 Mdot
.6 .52133 Mdot
.6 .52148 Mdot
.6 .5216 Mdot
.6 .52206 Mdot
.6 .52208 Mdot
.6 .52226 Mdot
.6 .523 Mdot
.6 .52347 Mdot
.6 .52351 Mdot
.6 .52361 Mdot
.6 .52379 Mdot
.6 .52447 Mdot
.6 .5246 Mdot
.6 .52501 Mdot
.6 .52511 Mdot
.6 .52516 Mdot
.6 .52532 Mdot
.6 .52602 Mdot
.6 .52616 Mdot
.6 .52691 Mdot
.6 .52751 Mdot
.6 .52798 Mdot
.6 .52856 Mdot
.6 .52877 Mdot
.6 .52962 Mdot
.6 .52965 Mdot
.6 .52974 Mdot
.6 .53001 Mdot
.6 .5324 Mdot
.6 .53256 Mdot
.6 .53294 Mdot
.6 .53328 Mdot
.6 .53409 Mdot
.6 .53444 Mdot
.6 .53506 Mdot
.6 .53511 Mdot
.6 .53565 Mdot
.6 .53583 Mdot
.6 .53588 Mdot
.6 .53628 Mdot
.6 .53629 Mdot
.6 .53664 Mdot
.6 .53718 Mdot
.6 .53745 Mdot
.6 .53751 Mdot
.6 .53792 Mdot
.6 .53897 Mdot
.6 .53915 Mdot
.6 .53957 Mdot
.6 .53965 Mdot
.6 .53977 Mdot
.6 .53981 Mdot
.6 .53995 Mdot
.6 .54 Mdot
.6 .54035 Mdot
.6 .54052 Mdot
.6 .54083 Mdot
.6 .54197 Mdot
.6 .54204 Mdot
.6 .54208 Mdot
.6 .54225 Mdot
.6 .5423 Mdot
.6 .54298 Mdot
.6 .54309 Mdot
.6 .54333 Mdot
.6 .54339 Mdot
.6 .5436 Mdot
.6 .54365 Mdot
.6 .54372 Mdot
.6 .54387 Mdot
.6 .54398 Mdot
.6 .54439 Mdot
.6 .54447 Mdot
.6 .54466 Mdot
.6 .54513 Mdot
.6 .54549 Mdot
.6 .54563 Mdot
.6 .54579 Mdot
.6 .54588 Mdot
.6 .54596 Mdot
.6 .54602 Mdot
.6 .54606 Mdot
.6 .54659 Mdot
.6 .54665 Mdot
.6 .54666 Mdot
.6 .54669 Mdot
.6 .54723 Mdot
.6 .54728 Mdot
.6 .54757 Mdot
.6 .54763 Mdot
.6 .54786 Mdot
.6 .54788 Mdot
.6 .54828 Mdot
.6 .54843 Mdot
.6 .54857 Mdot
.6 .54874 Mdot
.6 .54896 Mdot
.6 .54908 Mdot
.6 .54926 Mdot
.6 .54935 Mdot
.6 .54942 Mdot
.6 .54944 Mdot
.6 .54959 Mdot
.6 .54974 Mdot
.6 .54977 Mdot
.6 .5498 Mdot
.6 .54983 Mdot
.6 .54996 Mdot
.6 .55002 Mdot
.6 .55015 Mdot
.6 .5503 Mdot
.6 .55047 Mdot
.6 .55076 Mdot
.6 .5508 Mdot
.6 .55088 Mdot
.6 .55093 Mdot
.6 .55131 Mdot
.6 .55164 Mdot
.6 .55166 Mdot
.6 .55176 Mdot
.6 .55179 Mdot
.6 .55204 Mdot
.6 .55206 Mdot
.6 .55207 Mdot
.6 .55211 Mdot
.6 .55225 Mdot
.6 .55231 Mdot
.6 .55234 Mdot
.6 .55238 Mdot
.6 .55244 Mdot
.6 .55247 Mdot
.6 .55265 Mdot
.6 .55271 Mdot
.6 .55271 Mdot
.6 .55286 Mdot
.6 .55286 Mdot
.6 .55289 Mdot
.6 .55298 Mdot
.6 .55305 Mdot
.6 .5535 Mdot
.6 .55358 Mdot
.6 .55359 Mdot
.6 .5536 Mdot
.6 .55367 Mdot
.6 .5537 Mdot
.6 .55376 Mdot
.6 .55382 Mdot
.6 .55389 Mdot
.6 .55389 Mdot
.6 .55422 Mdot
.6 .55452 Mdot
.6 .55456 Mdot
.6 .55471 Mdot
.6 .55478 Mdot
.6 .55499 Mdot
.6 .55503 Mdot
.6 .55506 Mdot
.6 .55507 Mdot
.6 .55519 Mdot
.6 .55529 Mdot
.6 .55529 Mdot
.6 .55533 Mdot
.6 .55534 Mdot
.6 .55535 Mdot
.6 .55543 Mdot
.6 .55548 Mdot
.6 .55576 Mdot
.6 .55586 Mdot
.6 .55592 Mdot
.6 .556 Mdot
.6 .55602 Mdot
.6 .55609 Mdot
.6 .55609 Mdot
.6 .55611 Mdot
.6 .5562 Mdot
.6 .5562 Mdot
.6 .55621 Mdot
.6 .55622 Mdot
.6 .55622 Mdot
.6 .55622 Mdot
.6 .55623 Mdot
.6 .55623 Mdot
.6 .55623 Mdot
.6 .55623 Mdot
.602 .17348 Mdot
.602 .17351 Mdot
.602 .17354 Mdot
.602 .17364 Mdot
.602 .17367 Mdot
.602 .17373 Mdot
.602 .17376 Mdot
.602 .17381 Mdot
.602 .17383 Mdot
.602 .1739 Mdot
.602 .17391 Mdot
.602 .17393 Mdot
.602 .17395 Mdot
.602 .17405 Mdot
.602 .1741 Mdot
.602 .17417 Mdot
.602 .17435 Mdot
.602 .17437 Mdot
.602 .17439 Mdot
.602 .17474 Mdot
.602 .1748 Mdot
.602 .17482 Mdot
.602 .17487 Mdot
.602 .17493 Mdot
.602 .17509 Mdot
.602 .17537 Mdot
.602 .1755 Mdot
.602 .17576 Mdot
.602 .17618 Mdot
.602 .17618 Mdot
.602 .17645 Mdot
.602 .17662 Mdot
.602 .17665 Mdot
.602 .1767 Mdot
.602 .17735 Mdot
.602 .17759 Mdot
.602 .17762 Mdot
.602 .17772 Mdot
.602 .17795 Mdot
.602 .17797 Mdot
.602 .17815 Mdot
.602 .17869 Mdot
.602 .1788 Mdot
.602 .17933 Mdot
.602 .17936 Mdot
.602 .17942 Mdot
.602 .17945 Mdot
.602 .17965 Mdot
.602 .17995 Mdot
.602 .18002 Mdot
.602 .18028 Mdot
.602 .18035 Mdot
.602 .1807 Mdot
.602 .18078 Mdot
.602 .18079 Mdot
.602 .18165 Mdot
.602 .18229 Mdot
.602 .18297 Mdot
.602 .18435 Mdot
.602 .18441 Mdot
.602 .18477 Mdot
.602 .18506 Mdot
.602 .18535 Mdot
.602 .18567 Mdot
.602 .18572 Mdot
.602 .18586 Mdot
.602 .18587 Mdot
.602 .18745 Mdot
.602 .18873 Mdot
.602 .19102 Mdot
.602 .19199 Mdot
.602 .19321 Mdot
.602 .19367 Mdot
.602 .19535 Mdot
.602 .1956 Mdot
.602 .19561 Mdot
.602 .19601 Mdot
.602 .19616 Mdot
.602 .19661 Mdot
.602 .19715 Mdot
.602 .19913 Mdot
.602 .20017 Mdot
.602 .20205 Mdot
.602 .20208 Mdot
.602 .2021 Mdot
.602 .20226 Mdot
.602 .20273 Mdot
.602 .20283 Mdot
.602 .20296 Mdot
.602 .203 Mdot
.602 .20404 Mdot
.602 .20463 Mdot
.602 .20722 Mdot
.602 .20859 Mdot
.602 .20886 Mdot
.602 .20886 Mdot
.602 .20952 Mdot
.602 .21241 Mdot
.602 .21298 Mdot
.602 .21395 Mdot
.602 .21398 Mdot
.602 .21415 Mdot
.602 .21431 Mdot
.602 .21543 Mdot
.602 .21632 Mdot
.602 .21699 Mdot
.602 .21734 Mdot
.602 .21793 Mdot
.602 .21961 Mdot
.602 .22073 Mdot
.602 .22138 Mdot
.602 .22158 Mdot
.602 .22248 Mdot
.602 .22272 Mdot
.602 .22292 Mdot
.602 .22311 Mdot
.602 .2234 Mdot
.602 .22389 Mdot
.602 .22398 Mdot
.602 .22403 Mdot
.602 .2257 Mdot
.602 .22617 Mdot
.602 .22657 Mdot
.602 .22669 Mdot
.602 .22745 Mdot
.602 .22747 Mdot
.602 .22758 Mdot
.602 .22774 Mdot
.602 .22899 Mdot
.602 .22984 Mdot
.602 .23002 Mdot
.602 .23157 Mdot
.602 .23238 Mdot
.602 .23271 Mdot
.602 .23406 Mdot
.602 .23758 Mdot
.602 .23855 Mdot
.602 .23894 Mdot
.602 .24072 Mdot
.602 .24183 Mdot
.602 .24212 Mdot
.602 .24265 Mdot
.602 .24322 Mdot
.602 .24358 Mdot
.602 .24531 Mdot
.602 .24554 Mdot
.602 .24751 Mdot
.602 .24802 Mdot
.602 .24816 Mdot
.602 .25189 Mdot
.602 .25272 Mdot
.602 .254 Mdot
.602 .25523 Mdot
.602 .25589 Mdot
.602 .25751 Mdot
.602 .25834 Mdot
.602 .25845 Mdot
.602 .25881 Mdot
.602 .26128 Mdot
.602 .2618 Mdot
.602 .26254 Mdot
.602 .26266 Mdot
.602 .26358 Mdot
.602 .26575 Mdot
.602 .26592 Mdot
.602 .26679 Mdot
.602 .26958 Mdot
.602 .26961 Mdot
.602 .26969 Mdot
.602 .26976 Mdot
.602 .27155 Mdot
.602 .27453 Mdot
.602 .27516 Mdot
.602 .2779 Mdot
.602 .27874 Mdot
.602 .2808 Mdot
.602 .28377 Mdot
.602 .28415 Mdot
.602 .28478 Mdot
.602 .28524 Mdot
.602 .28743 Mdot
.602 .28762 Mdot
.602 .29069 Mdot
.602 .29112 Mdot
.602 .29141 Mdot
.602 .29146 Mdot
.602 .29159 Mdot
.602 .29258 Mdot
.602 .29346 Mdot
.602 .29379 Mdot
.602 .2942 Mdot
.602 .29443 Mdot
.602 .29485 Mdot
.602 .2961 Mdot
.602 .2962 Mdot
.602 .29719 Mdot
.602 .29879 Mdot
.602 .30054 Mdot
.602 .30069 Mdot
.602 .30093 Mdot
.602 .30216 Mdot
.602 .30224 Mdot
.602 .30304 Mdot
.602 .30356 Mdot
.602 .30409 Mdot
.602 .30416 Mdot
.602 .30429 Mdot
.602 .30474 Mdot
.602 .30489 Mdot
.602 .30516 Mdot
.602 .30607 Mdot
.602 .30721 Mdot
.602 .30775 Mdot
.602 .30953 Mdot
.602 .31213 Mdot
.602 .31262 Mdot
.602 .3137 Mdot
.602 .31469 Mdot
.602 .31574 Mdot
.602 .31728 Mdot
.602 .31768 Mdot
.602 .31816 Mdot
.602 .31892 Mdot
.602 .31988 Mdot
.602 .32083 Mdot
.602 .32142 Mdot
.602 .32177 Mdot
.602 .32366 Mdot
.602 .32428 Mdot
.602 .32563 Mdot
.602 .32649 Mdot
.602 .32744 Mdot
.602 .3278 Mdot
.602 .3279 Mdot
.602 .32838 Mdot
.602 .32849 Mdot
.602 .3285 Mdot
.602 .32962 Mdot
.602 .33123 Mdot
.602 .33286 Mdot
.602 .33357 Mdot
.602 .33421 Mdot
.602 .33441 Mdot
.602 .33442 Mdot
.602 .336 Mdot
.602 .34115 Mdot
.602 .34153 Mdot
.602 .34307 Mdot
.602 .34308 Mdot
.602 .34339 Mdot
.602 .34385 Mdot
.602 .34426 Mdot
.602 .34573 Mdot
.602 .34781 Mdot
.602 .34783 Mdot
.602 .34784 Mdot
.602 .34795 Mdot
.602 .34916 Mdot
.602 .34955 Mdot
.602 .35228 Mdot
.602 .35269 Mdot
.602 .3548 Mdot
.602 .35539 Mdot
.602 .35559 Mdot
.602 .35713 Mdot
.602 .35733 Mdot
.602 .35766 Mdot
.602 .3586 Mdot
.602 .36018 Mdot
.602 .36031 Mdot
.602 .36041 Mdot
.602 .36068 Mdot
.602 .36094 Mdot
.602 .36098 Mdot
.602 .36101 Mdot
.602 .36189 Mdot
.602 .36235 Mdot
.602 .36241 Mdot
.602 .36282 Mdot
.602 .36287 Mdot
.602 .36296 Mdot
.602 .3636 Mdot
.602 .36412 Mdot
.602 .36491 Mdot
.602 .36548 Mdot
.602 .36786 Mdot
.602 .36832 Mdot
.602 .36851 Mdot
.602 .36935 Mdot
.602 .37026 Mdot
.602 .37069 Mdot
.602 .37149 Mdot
.602 .37159 Mdot
.602 .37278 Mdot
.602 .37691 Mdot
.602 .37726 Mdot
.602 .37746 Mdot
.602 .37851 Mdot
.602 .37873 Mdot
.602 .37905 Mdot
.602 .38039 Mdot
.602 .38082 Mdot
.602 .38196 Mdot
.602 .38198 Mdot
.602 .38201 Mdot
.602 .38204 Mdot
.602 .38277 Mdot
.602 .38422 Mdot
.602 .38762 Mdot
.602 .38777 Mdot
.602 .38911 Mdot
.602 .39063 Mdot
.602 .39101 Mdot
.602 .39162 Mdot
.602 .39171 Mdot
.602 .39238 Mdot
.602 .39275 Mdot
.602 .39335 Mdot
.602 .3946 Mdot
.602 .39534 Mdot
.602 .39539 Mdot
.602 .39561 Mdot
.602 .39571 Mdot
.602 .39604 Mdot
.602 .39825 Mdot
.602 .39882 Mdot
.602 .39918 Mdot
.602 .39955 Mdot
.602 .40025 Mdot
.602 .40042 Mdot
.602 .40138 Mdot
.602 .40158 Mdot
.602 .40238 Mdot
.602 .40308 Mdot
.602 .40338 Mdot
.602 .40385 Mdot
.602 .40409 Mdot
.602 .40449 Mdot
.602 .40587 Mdot
.602 .4061 Mdot
.602 .40616 Mdot
.602 .40617 Mdot
.602 .40672 Mdot
.602 .40864 Mdot
.602 .40928 Mdot
.602 .40958 Mdot
.602 .41009 Mdot
.602 .4108 Mdot
.602 .41081 Mdot
.602 .41085 Mdot
.602 .41127 Mdot
.602 .4114 Mdot
.602 .41234 Mdot
.602 .41248 Mdot
.602 .4132 Mdot
.602 .41347 Mdot
.602 .41406 Mdot
.602 .41418 Mdot
.602 .4145 Mdot
.602 .41511 Mdot
.602 .41529 Mdot
.602 .41532 Mdot
.602 .41562 Mdot
.602 .41579 Mdot
.602 .4162 Mdot
.602 .41637 Mdot
.602 .41664 Mdot
.602 .41683 Mdot
.602 .41764 Mdot
.602 .4178 Mdot
.602 .41815 Mdot
.602 .41845 Mdot
.602 .4186 Mdot
.602 .41887 Mdot
.602 .41931 Mdot
.602 .4207 Mdot
.602 .42082 Mdot
.602 .42124 Mdot
.602 .42132 Mdot
.602 .42241 Mdot
.602 .42241 Mdot
.602 .42317 Mdot
.602 .42432 Mdot
.602 .42533 Mdot
.602 .42546 Mdot
.602 .42566 Mdot
.602 .42569 Mdot
.602 .42592 Mdot
.602 .42625 Mdot
.602 .42667 Mdot
.602 .42692 Mdot
.602 .42694 Mdot
.602 .42704 Mdot
.602 .42716 Mdot
.602 .4279 Mdot
.602 .4281 Mdot
.602 .42822 Mdot
.602 .42834 Mdot
.602 .42858 Mdot
.602 .42864 Mdot
.602 .42896 Mdot
.602 .42903 Mdot
.602 .42954 Mdot
.602 .42964 Mdot
.602 .4298 Mdot
.602 .42988 Mdot
.602 .43001 Mdot
.602 .43048 Mdot
.602 .43056 Mdot
.602 .43058 Mdot
.602 .43077 Mdot
.602 .43142 Mdot
.602 .43164 Mdot
.602 .43174 Mdot
.602 .43191 Mdot
.602 .43216 Mdot
.602 .43273 Mdot
.602 .43306 Mdot
.602 .43331 Mdot
.602 .43341 Mdot
.602 .43369 Mdot
.602 .4338 Mdot
.602 .43386 Mdot
.602 .43399 Mdot
.602 .43405 Mdot
.602 .43415 Mdot
.602 .43421 Mdot
.602 .43449 Mdot
.602 .43454 Mdot
.602 .43466 Mdot
.602 .43477 Mdot
.602 .43482 Mdot
.602 .43491 Mdot
.602 .43553 Mdot
.602 .43558 Mdot
.602 .43572 Mdot
.602 .43612 Mdot
.602 .43612 Mdot
.602 .43678 Mdot
.602 .43713 Mdot
.602 .43717 Mdot
.602 .43744 Mdot
.602 .43759 Mdot
.602 .43767 Mdot
.602 .43772 Mdot
.602 .43812 Mdot
.602 .43817 Mdot
.602 .43825 Mdot
.602 .43827 Mdot
.602 .4384 Mdot
.602 .43874 Mdot
.602 .43891 Mdot
.602 .43893 Mdot
.602 .43894 Mdot
.602 .43901 Mdot
.602 .43931 Mdot
.602 .4394 Mdot
.602 .43949 Mdot
.602 .43969 Mdot
.602 .4398 Mdot
.602 .43992 Mdot
.602 .44002 Mdot
.602 .44013 Mdot
.602 .44015 Mdot
.602 .44018 Mdot
.602 .4402 Mdot
.602 .4403 Mdot
.602 .44036 Mdot
.602 .4404 Mdot
.602 .44066 Mdot
.602 .44073 Mdot
.602 .44087 Mdot
.602 .44087 Mdot
.602 .4411 Mdot
.602 .44122 Mdot
.602 .44124 Mdot
.602 .44143 Mdot
.602 .44157 Mdot
.602 .44161 Mdot
.602 .44162 Mdot
.602 .44167 Mdot
.602 .44179 Mdot
.602 .44184 Mdot
.602 .44188 Mdot
.602 .44199 Mdot
.602 .44202 Mdot
.602 .44205 Mdot
.602 .44212 Mdot
.602 .44216 Mdot
.602 .4422 Mdot
.602 .44224 Mdot
.602 .44228 Mdot
.602 .44229 Mdot
.602 .4423 Mdot
.602 .44233 Mdot
.602 .44235 Mdot
.602 .44237 Mdot
.602 .44246 Mdot
.602 .44248 Mdot
.602 .44253 Mdot
.602 .44261 Mdot
.602 .44266 Mdot
.602 .44273 Mdot
.602 .4428 Mdot
.602 .44286 Mdot
.602 .443 Mdot
.602 .44302 Mdot
.602 .44304 Mdot
.602 .44306 Mdot
.602 .4431 Mdot
.602 .44369 Mdot
.602 .44379 Mdot
.602 .44382 Mdot
.602 .4439 Mdot
.602 .44401 Mdot
.602 .44402 Mdot
.602 .44408 Mdot
.602 .44412 Mdot
.602 .44416 Mdot
.602 .44418 Mdot
.602 .44429 Mdot
.602 .44442 Mdot
.602 .44452 Mdot
.602 .44463 Mdot
.602 .44475 Mdot
.602 .44476 Mdot
.602 .44483 Mdot
.602 .44496 Mdot
.602 .44496 Mdot
.602 .44505 Mdot
.602 .44508 Mdot
.602 .44524 Mdot
.602 .44526 Mdot
.602 .4453 Mdot
.602 .44535 Mdot
.602 .44537 Mdot
.602 .44539 Mdot
.602 .4454 Mdot
.602 .44546 Mdot
.602 .44552 Mdot
.602 .44559 Mdot
.602 .44566 Mdot
.602 .44577 Mdot
.602 .44582 Mdot
.602 .44588 Mdot
.602 .44605 Mdot
.602 .44609 Mdot
.602 .4461 Mdot
.602 .44611 Mdot
.602 .44621 Mdot
.602 .4464 Mdot
.602 .44648 Mdot
.602 .4465 Mdot
.602 .44654 Mdot
.602 .44657 Mdot
.602 .4468 Mdot
.602 .44683 Mdot
.602 .44688 Mdot
.602 .44696 Mdot
.602 .44712 Mdot
.602 .44715 Mdot
.602 .44735 Mdot
.602 .44773 Mdot
.602 .44773 Mdot
.602 .44796 Mdot
.602 .44804 Mdot
.602 .44806 Mdot
.602 .44842 Mdot
.602 .44848 Mdot
.602 .44851 Mdot
.602 .44857 Mdot
.602 .44863 Mdot
.602 .44866 Mdot
.602 .44882 Mdot
.602 .44886 Mdot
.602 .44891 Mdot
.602 .44895 Mdot
.602 .44903 Mdot
.602 .44906 Mdot
.602 .44912 Mdot
.602 .44928 Mdot
.602 .44934 Mdot
.602 .44948 Mdot
.602 .44967 Mdot
.602 .44999 Mdot
.602 .45013 Mdot
.602 .45023 Mdot
.602 .45029 Mdot
.602 .45041 Mdot
.602 .45078 Mdot
.602 .45088 Mdot
.602 .4509 Mdot
.602 .45094 Mdot
.602 .4512 Mdot
.602 .45128 Mdot
.602 .45133 Mdot
.602 .45141 Mdot
.602 .45147 Mdot
.602 .45175 Mdot
.602 .45179 Mdot
.602 .45197 Mdot
.602 .45201 Mdot
.602 .45214 Mdot
.602 .45221 Mdot
.602 .45228 Mdot
.602 .45238 Mdot
.602 .4528 Mdot
.602 .45286 Mdot
.602 .45292 Mdot
.602 .45293 Mdot
.602 .45307 Mdot
.602 .45331 Mdot
.602 .45349 Mdot
.602 .45361 Mdot
.602 .45363 Mdot
.602 .45374 Mdot
.602 .45381 Mdot
.602 .45437 Mdot
.602 .455 Mdot
.602 .45541 Mdot
.602 .45542 Mdot
.602 .45601 Mdot
.602 .45605 Mdot
.602 .45628 Mdot
.602 .45635 Mdot
.602 .4571 Mdot
.602 .45734 Mdot
.602 .45748 Mdot
.602 .45756 Mdot
.602 .45772 Mdot
.602 .45791 Mdot
.602 .458 Mdot
.602 .45843 Mdot
.602 .45853 Mdot
.602 .45868 Mdot
.602 .45877 Mdot
.602 .45899 Mdot
.602 .45908 Mdot
.602 .45924 Mdot
.602 .45925 Mdot
.602 .45935 Mdot
.602 .45967 Mdot
.602 .45984 Mdot
.602 .4599 Mdot
.602 .46022 Mdot
.602 .46036 Mdot
.602 .46074 Mdot
.602 .46082 Mdot
.602 .46131 Mdot
.602 .46138 Mdot
.602 .4616 Mdot
.602 .46162 Mdot
.602 .46162 Mdot
.602 .462 Mdot
.602 .46226 Mdot
.602 .46242 Mdot
.602 .46275 Mdot
.602 .46375 Mdot
.602 .46403 Mdot
.602 .46403 Mdot
.602 .46407 Mdot
.602 .46418 Mdot
.602 .4649 Mdot
.602 .4651 Mdot
.602 .46522 Mdot
.602 .46546 Mdot
.602 .46562 Mdot
.602 .46597 Mdot
.602 .46638 Mdot
.602 .46648 Mdot
.602 .46697 Mdot
.602 .46705 Mdot
.602 .46741 Mdot
.602 .4676 Mdot
.602 .46778 Mdot
.602 .46806 Mdot
.602 .46917 Mdot
.602 .46934 Mdot
.602 .46938 Mdot
.602 .46949 Mdot
.602 .46952 Mdot
.602 .46989 Mdot
.602 .47051 Mdot
.602 .4708 Mdot
.602 .47099 Mdot
.602 .47132 Mdot
.602 .47136 Mdot
.602 .47166 Mdot
.602 .47185 Mdot
.602 .47259 Mdot
.602 .47324 Mdot
.602 .47332 Mdot
.602 .47496 Mdot
.602 .47566 Mdot
.602 .47601 Mdot
.602 .47602 Mdot
.602 .47604 Mdot
.602 .47605 Mdot
.602 .47659 Mdot
.602 .4768 Mdot
.602 .47744 Mdot
.602 .47759 Mdot
.602 .47769 Mdot
.602 .47819 Mdot
.602 .47828 Mdot
.602 .47845 Mdot
.602 .48038 Mdot
.602 .48094 Mdot
.602 .48099 Mdot
.602 .48136 Mdot
.602 .48156 Mdot
.602 .48198 Mdot
.602 .48237 Mdot
.602 .48245 Mdot
.602 .48267 Mdot
.602 .48376 Mdot
.602 .48402 Mdot
.602 .48438 Mdot
.602 .48461 Mdot
.602 .48491 Mdot
.602 .48495 Mdot
.602 .48497 Mdot
.602 .48516 Mdot
.602 .48518 Mdot
.602 .48539 Mdot
.602 .48579 Mdot
.602 .4858 Mdot
.602 .48582 Mdot
.602 .48594 Mdot
.602 .48606 Mdot
.602 .48611 Mdot
.602 .48617 Mdot
.602 .48687 Mdot
.602 .4873 Mdot
.602 .48745 Mdot
.602 .48753 Mdot
.602 .48823 Mdot
.602 .48831 Mdot
.602 .48858 Mdot
.602 .48951 Mdot
.602 .4897 Mdot
.602 .4909 Mdot
.602 .49107 Mdot
.602 .4916 Mdot
.602 .49165 Mdot
.602 .49166 Mdot
.602 .49166 Mdot
.602 .49257 Mdot
.602 .49321 Mdot
.602 .49339 Mdot
.602 .49359 Mdot
.602 .49372 Mdot
.602 .49373 Mdot
.602 .49439 Mdot
.602 .49455 Mdot
.602 .49676 Mdot
.602 .49743 Mdot
.602 .49744 Mdot
.602 .49752 Mdot
.602 .49779 Mdot
.602 .49809 Mdot
.602 .49878 Mdot
.602 .49946 Mdot
.602 .49993 Mdot
.602 .49993 Mdot
.602 .49998 Mdot
.602 .50018 Mdot
.602 .50022 Mdot
.602 .50037 Mdot
.602 .50077 Mdot
.602 .50113 Mdot
.602 .50169 Mdot
.602 .50194 Mdot
.602 .50272 Mdot
.602 .50287 Mdot
.602 .50311 Mdot
.602 .5035 Mdot
.602 .5039 Mdot
.602 .50421 Mdot
.602 .5044 Mdot
.602 .50457 Mdot
.602 .5052 Mdot
.602 .50562 Mdot
.602 .50602 Mdot
.602 .50647 Mdot
.602 .50666 Mdot
.602 .50771 Mdot
.602 .50843 Mdot
.602 .50864 Mdot
.602 .5091 Mdot
.602 .50946 Mdot
.602 .50957 Mdot
.602 .50963 Mdot
.602 .50981 Mdot
.602 .50986 Mdot
.602 .50989 Mdot
.602 .5101 Mdot
.602 .51031 Mdot
.602 .51062 Mdot
.602 .51065 Mdot
.602 .51114 Mdot
.602 .51124 Mdot
.602 .5113 Mdot
.602 .51199 Mdot
.602 .51261 Mdot
.602 .513 Mdot
.602 .51304 Mdot
.602 .51353 Mdot
.602 .5137 Mdot
.602 .51379 Mdot
.602 .51395 Mdot
.602 .51407 Mdot
.602 .51442 Mdot
.602 .5148 Mdot
.602 .51485 Mdot
.602 .51487 Mdot
.602 .51498 Mdot
.602 .51515 Mdot
.602 .51634 Mdot
.602 .51641 Mdot
.602 .51726 Mdot
.602 .51743 Mdot
.602 .51767 Mdot
.602 .51782 Mdot
.602 .51895 Mdot
.602 .51974 Mdot
.602 .52005 Mdot
.602 .52109 Mdot
.602 .52133 Mdot
.602 .52244 Mdot
.602 .52311 Mdot
.602 .52314 Mdot
.602 .52317 Mdot
.602 .52318 Mdot
.602 .52422 Mdot
.602 .52454 Mdot
.602 .52461 Mdot
.602 .52541 Mdot
.602 .52575 Mdot
.602 .52579 Mdot
.602 .52607 Mdot
.602 .52626 Mdot
.602 .52716 Mdot
.602 .5273 Mdot
.602 .52733 Mdot
.602 .52764 Mdot
.602 .52823 Mdot
.602 .52847 Mdot
.602 .52892 Mdot
.602 .52939 Mdot
.602 .52969 Mdot
.602 .53103 Mdot
.602 .53108 Mdot
.602 .53127 Mdot
.602 .53197 Mdot
.602 .53206 Mdot
.602 .53267 Mdot
.602 .53281 Mdot
.602 .53301 Mdot
.602 .5332 Mdot
.602 .5333 Mdot
.602 .53369 Mdot
.602 .53433 Mdot
.602 .53447 Mdot
.602 .53481 Mdot
.602 .53605 Mdot
.602 .53653 Mdot
.602 .53664 Mdot
.602 .53693 Mdot
.602 .53747 Mdot
.602 .53753 Mdot
.602 .53783 Mdot
.602 .53827 Mdot
.602 .53832 Mdot
.602 .53836 Mdot
.602 .53837 Mdot
.602 .53863 Mdot
.602 .53868 Mdot
.602 .53882 Mdot
.602 .53898 Mdot
.602 .53956 Mdot
.602 .53957 Mdot
.602 .53961 Mdot
.602 .53977 Mdot
.602 .53988 Mdot
.602 .53994 Mdot
.602 .54001 Mdot
.602 .54009 Mdot
.602 .54041 Mdot
.602 .54048 Mdot
.602 .5407 Mdot
.602 .54109 Mdot
.602 .54166 Mdot
.602 .54187 Mdot
.602 .54198 Mdot
.602 .54221 Mdot
.602 .54252 Mdot
.602 .5429 Mdot
.602 .54296 Mdot
.602 .54302 Mdot
.602 .54303 Mdot
.602 .54336 Mdot
.602 .54355 Mdot
.602 .54453 Mdot
.602 .54476 Mdot
.602 .54476 Mdot
.602 .54485 Mdot
.602 .54531 Mdot
.602 .54619 Mdot
.602 .54639 Mdot
.602 .54674 Mdot
.602 .54675 Mdot
.602 .54679 Mdot
.602 .54683 Mdot
.602 .54699 Mdot
.602 .54704 Mdot
.602 .54705 Mdot
.602 .54706 Mdot
.602 .54769 Mdot
.602 .54804 Mdot
.602 .5487 Mdot
.602 .54888 Mdot
.602 .54903 Mdot
.602 .54908 Mdot
.602 .54921 Mdot
.602 .54921 Mdot
.602 .54929 Mdot
.602 .54986 Mdot
.602 .55001 Mdot
.602 .55041 Mdot
.602 .55073 Mdot
.602 .55149 Mdot
.602 .55191 Mdot
.602 .55243 Mdot
.602 .55243 Mdot
.602 .55248 Mdot
.602 .55249 Mdot
.602 .5526 Mdot
.602 .5527 Mdot
.602 .55279 Mdot
.602 .55291 Mdot
.602 .55293 Mdot
.602 .55338 Mdot
.602 .55355 Mdot
.602 .5536 Mdot
.602 .55381 Mdot
.602 .55409 Mdot
.602 .5541 Mdot
.602 .55412 Mdot
.602 .55423 Mdot
.602 .55426 Mdot
.602 .55434 Mdot
.602 .55437 Mdot
.602 .55446 Mdot
.602 .55453 Mdot
.602 .55454 Mdot
.602 .55456 Mdot
.602 .55457 Mdot
.602 .55474 Mdot
.602 .55478 Mdot
.602 .55495 Mdot
.602 .55501 Mdot
.602 .55502 Mdot
.602 .55509 Mdot
.602 .55512 Mdot
.602 .55513 Mdot
.602 .55521 Mdot
.602 .55542 Mdot
.602 .55544 Mdot
.602 .55545 Mdot
.602 .5555 Mdot
.602 .55559 Mdot
.602 .55559 Mdot
.602 .55573 Mdot
.602 .55581 Mdot
.602 .55585 Mdot
.602 .55594 Mdot
.602 .556 Mdot
.602 .55602 Mdot
.602 .55603 Mdot
.602 .55604 Mdot
.602 .55606 Mdot
.602 .55617 Mdot
.602 .55618 Mdot
.602 .55618 Mdot
.602 .55624 Mdot
.602 .55626 Mdot
.602 .55628 Mdot
.602 .55631 Mdot
.602 .55632 Mdot
.602 .55633 Mdot
.602 .55633 Mdot
.602 .55635 Mdot
.602 .55636 Mdot
.602 .55637 Mdot
.602 .55639 Mdot
.602 .55641 Mdot
.602 .55641 Mdot
.602 .55645 Mdot
.602 .55646 Mdot
.602 .55646 Mdot
.604 .17282 Mdot
.604 .17288 Mdot
.604 .17293 Mdot
.604 .17302 Mdot
.604 .17303 Mdot
.604 .17308 Mdot
.604 .17309 Mdot
.604 .17316 Mdot
.604 .17317 Mdot
.604 .17317 Mdot
.604 .17323 Mdot
.604 .17338 Mdot
.604 .17342 Mdot
.604 .1735 Mdot
.604 .17361 Mdot
.604 .17363 Mdot
.604 .17381 Mdot
.604 .1739 Mdot
.604 .17391 Mdot
.604 .17392 Mdot
.604 .17396 Mdot
.604 .174 Mdot
.604 .17452 Mdot
.604 .17462 Mdot
.604 .17468 Mdot
.604 .1755 Mdot
.604 .17592 Mdot
.604 .17603 Mdot
.604 .17611 Mdot
.604 .17686 Mdot
.604 .17686 Mdot
.604 .17693 Mdot
.604 .17696 Mdot
.604 .17764 Mdot
.604 .17775 Mdot
.604 .17806 Mdot
.604 .1782 Mdot
.604 .17938 Mdot
.604 .18019 Mdot
.604 .18067 Mdot
.604 .18092 Mdot
.604 .18149 Mdot
.604 .18203 Mdot
.604 .1826 Mdot
.604 .18281 Mdot
.604 .18291 Mdot
.604 .18328 Mdot
.604 .18352 Mdot
.604 .18396 Mdot
.604 .18418 Mdot
.604 .18449 Mdot
.604 .18471 Mdot
.604 .18562 Mdot
.604 .18563 Mdot
.604 .18577 Mdot
.604 .18586 Mdot
.604 .18598 Mdot
.604 .18729 Mdot
.604 .18755 Mdot
.604 .18792 Mdot
.604 .1896 Mdot
.604 .18982 Mdot
.604 .18987 Mdot
.604 .18992 Mdot
.604 .18998 Mdot
.604 .19069 Mdot
.604 .19132 Mdot
.604 .19132 Mdot
.604 .19196 Mdot
.604 .19247 Mdot
.604 .19305 Mdot
.604 .19327 Mdot
.604 .19352 Mdot
.604 .19588 Mdot
.604 .19599 Mdot
.604 .19721 Mdot
.604 .19724 Mdot
.604 .1989 Mdot
.604 .19895 Mdot
.604 .19898 Mdot
.604 .19927 Mdot
.604 .19934 Mdot
.604 .20037 Mdot
.604 .20038 Mdot
.604 .20147 Mdot
.604 .20165 Mdot
.604 .20188 Mdot
.604 .20213 Mdot
.604 .20259 Mdot
.604 .20263 Mdot
.604 .20323 Mdot
.604 .2034 Mdot
.604 .20349 Mdot
.604 .20476 Mdot
.604 .20489 Mdot
.604 .20685 Mdot
.604 .20772 Mdot
.604 .20816 Mdot
.604 .20944 Mdot
.604 .20959 Mdot
.604 .20977 Mdot
.604 .21139 Mdot
.604 .2116 Mdot
.604 .21221 Mdot
.604 .21558 Mdot
.604 .21614 Mdot
.604 .21653 Mdot
.604 .21729 Mdot
.604 .21739 Mdot
.604 .21874 Mdot
.604 .21882 Mdot
.604 .21922 Mdot
.604 .21922 Mdot
.604 .21944 Mdot
.604 .22012 Mdot
.604 .22311 Mdot
.604 .2234 Mdot
.604 .22351 Mdot
.604 .22358 Mdot
.604 .22364 Mdot
.604 .22438 Mdot
.604 .22558 Mdot
.604 .22616 Mdot
.604 .22662 Mdot
.604 .22762 Mdot
.604 .22804 Mdot
.604 .22892 Mdot
.604 .22999 Mdot
.604 .23109 Mdot
.604 .23119 Mdot
.604 .23192 Mdot
.604 .23202 Mdot
.604 .23204 Mdot
.604 .23401 Mdot
.604 .23439 Mdot
.604 .2349 Mdot
.604 .23501 Mdot
.604 .23567 Mdot
.604 .2358 Mdot
.604 .23594 Mdot
.604 .23617 Mdot
.604 .23652 Mdot
.604 .23655 Mdot
.604 .2373 Mdot
.604 .23778 Mdot
.604 .2395 Mdot
.604 .24004 Mdot
.604 .24014 Mdot
.604 .24285 Mdot
.604 .24303 Mdot
.604 .24304 Mdot
.604 .24346 Mdot
.604 .24366 Mdot
.604 .24393 Mdot
.604 .24427 Mdot
.604 .24534 Mdot
.604 .24538 Mdot
.604 .24557 Mdot
.604 .24587 Mdot
.604 .24627 Mdot
.604 .24694 Mdot
.604 .24706 Mdot
.604 .24735 Mdot
.604 .24744 Mdot
.604 .24875 Mdot
.604 .249 Mdot
.604 .24982 Mdot
.604 .25059 Mdot
.604 .25071 Mdot
.604 .25116 Mdot
.604 .25121 Mdot
.604 .25146 Mdot
.604 .25164 Mdot
.604 .25262 Mdot
.604 .25263 Mdot
.604 .25304 Mdot
.604 .25309 Mdot
.604 .25537 Mdot
.604 .2559 Mdot
.604 .257 Mdot
.604 .25721 Mdot
.604 .25932 Mdot
.604 .25954 Mdot
.604 .2604 Mdot
.604 .26083 Mdot
.604 .26137 Mdot
.604 .26482 Mdot
.604 .26493 Mdot
.604 .26582 Mdot
.604 .26609 Mdot
.604 .26665 Mdot
.604 .26791 Mdot
.604 .26799 Mdot
.604 .26884 Mdot
.604 .26942 Mdot
.604 .26976 Mdot
.604 .26993 Mdot
.604 .27009 Mdot
.604 .27171 Mdot
.604 .27176 Mdot
.604 .27196 Mdot
.604 .27324 Mdot
.604 .27418 Mdot
.604 .27427 Mdot
.604 .27612 Mdot
.604 .27632 Mdot
.604 .2765 Mdot
.604 .27794 Mdot
.604 .27848 Mdot
.604 .27915 Mdot
.604 .2792 Mdot
.604 .27944 Mdot
.604 .28132 Mdot
.604 .28157 Mdot
.604 .28285 Mdot
.604 .28298 Mdot
.604 .28307 Mdot
.604 .28416 Mdot
.604 .28439 Mdot
.604 .28571 Mdot
.604 .28613 Mdot
.604 .28624 Mdot
.604 .28648 Mdot
.604 .28716 Mdot
.604 .28781 Mdot
.604 .28884 Mdot
.604 .28948 Mdot
.604 .29057 Mdot
.604 .29233 Mdot
.604 .29255 Mdot
.604 .29322 Mdot
.604 .29443 Mdot
.604 .29456 Mdot
.604 .29597 Mdot
.604 .29636 Mdot
.604 .2992 Mdot
.604 .30119 Mdot
.604 .30135 Mdot
.604 .30146 Mdot
.604 .30149 Mdot
.604 .30155 Mdot
.604 .30185 Mdot
.604 .30261 Mdot
.604 .3058 Mdot
.604 .30656 Mdot
.604 .30965 Mdot
.604 .3108 Mdot
.604 .31237 Mdot
.604 .31267 Mdot
.604 .31279 Mdot
.604 .31325 Mdot
.604 .31328 Mdot
.604 .3133 Mdot
.604 .31362 Mdot
.604 .3144 Mdot
.604 .31461 Mdot
.604 .31495 Mdot
.604 .31549 Mdot
.604 .31839 Mdot
.604 .31868 Mdot
.604 .3208 Mdot
.604 .32191 Mdot
.604 .32347 Mdot
.604 .32366 Mdot
.604 .32499 Mdot
.604 .32951 Mdot
.604 .33259 Mdot
.604 .33308 Mdot
.604 .33331 Mdot
.604 .33481 Mdot
.604 .33483 Mdot
.604 .33706 Mdot
.604 .33879 Mdot
.604 .33893 Mdot
.604 .34009 Mdot
.604 .34063 Mdot
.604 .34106 Mdot
.604 .34477 Mdot
.604 .34601 Mdot
.604 .34604 Mdot
.604 .34706 Mdot
.604 .34706 Mdot
.604 .34782 Mdot
.604 .34859 Mdot
.604 .34902 Mdot
.604 .34913 Mdot
.604 .35301 Mdot
.604 .3542 Mdot
.604 .35433 Mdot
.604 .35469 Mdot
.604 .35698 Mdot
.604 .35769 Mdot
.604 .35844 Mdot
.604 .35871 Mdot
.604 .35883 Mdot
.604 .35921 Mdot
.604 .36097 Mdot
.604 .36107 Mdot
.604 .3611 Mdot
.604 .3615 Mdot
.604 .36243 Mdot
.604 .36318 Mdot
.604 .3634 Mdot
.604 .36385 Mdot
.604 .36439 Mdot
.604 .36536 Mdot
.604 .3672 Mdot
.604 .36726 Mdot
.604 .36761 Mdot
.604 .36762 Mdot
.604 .36798 Mdot
.604 .36933 Mdot
.604 .37068 Mdot
.604 .37088 Mdot
.604 .37125 Mdot
.604 .37174 Mdot
.604 .37184 Mdot
.604 .37198 Mdot
.604 .37252 Mdot
.604 .37328 Mdot
.604 .3734 Mdot
.604 .37415 Mdot
.604 .37449 Mdot
.604 .3752 Mdot
.604 .3762 Mdot
.604 .37643 Mdot
.604 .3769 Mdot
.604 .37699 Mdot
.604 .37835 Mdot
.604 .37876 Mdot
.604 .3802 Mdot
.604 .38062 Mdot
.604 .38096 Mdot
.604 .3823 Mdot
.604 .38304 Mdot
.604 .38406 Mdot
.604 .38479 Mdot
.604 .38488 Mdot
.604 .38495 Mdot
.604 .38552 Mdot
.604 .38573 Mdot
.604 .38744 Mdot
.604 .38749 Mdot
.604 .38753 Mdot
.604 .38795 Mdot
.604 .38855 Mdot
.604 .38871 Mdot
.604 .38876 Mdot
.604 .38885 Mdot
.604 .38936 Mdot
.604 .38975 Mdot
.604 .39108 Mdot
.604 .39116 Mdot
.604 .39192 Mdot
.604 .3926 Mdot
.604 .39449 Mdot
.604 .39451 Mdot
.604 .39609 Mdot
.604 .39637 Mdot
.604 .3975 Mdot
.604 .39848 Mdot
.604 .39863 Mdot
.604 .3988 Mdot
.604 .39893 Mdot
.604 .39941 Mdot
.604 .3996 Mdot
.604 .40251 Mdot
.604 .40299 Mdot
.604 .40458 Mdot
.604 .40565 Mdot
.604 .40591 Mdot
.604 .40643 Mdot
.604 .40721 Mdot
.604 .40781 Mdot
.604 .40786 Mdot
.604 .4103 Mdot
.604 .41066 Mdot
.604 .41066 Mdot
.604 .41092 Mdot
.604 .41133 Mdot
.604 .41137 Mdot
.604 .4127 Mdot
.604 .4131 Mdot
.604 .41405 Mdot
.604 .41429 Mdot
.604 .41468 Mdot
.604 .41545 Mdot
.604 .41558 Mdot
.604 .41623 Mdot
.604 .41689 Mdot
.604 .41751 Mdot
.604 .41754 Mdot
.604 .41778 Mdot
.604 .41824 Mdot
.604 .41888 Mdot
.604 .41931 Mdot
.604 .41957 Mdot
.604 .41961 Mdot
.604 .41986 Mdot
.604 .41997 Mdot
.604 .42022 Mdot
.604 .42055 Mdot
.604 .42063 Mdot
.604 .42128 Mdot
.604 .42142 Mdot
.604 .4219 Mdot
.604 .42261 Mdot
.604 .42286 Mdot
.604 .4232 Mdot
.604 .42345 Mdot
.604 .42347 Mdot
.604 .4235 Mdot
.604 .42369 Mdot
.604 .42376 Mdot
.604 .42434 Mdot
.604 .42435 Mdot
.604 .42437 Mdot
.604 .42471 Mdot
.604 .42478 Mdot
.604 .42481 Mdot
.604 .42512 Mdot
.604 .42559 Mdot
.604 .42585 Mdot
.604 .42725 Mdot
.604 .42773 Mdot
.604 .42837 Mdot
.604 .42942 Mdot
.604 .42958 Mdot
.604 .43057 Mdot
.604 .43101 Mdot
.604 .43121 Mdot
.604 .43123 Mdot
.604 .43218 Mdot
.604 .43287 Mdot
.604 .43301 Mdot
.604 .43341 Mdot
.604 .4338 Mdot
.604 .4343 Mdot
.604 .43451 Mdot
.604 .4346 Mdot
.604 .43498 Mdot
.604 .43521 Mdot
.604 .43531 Mdot
.604 .43535 Mdot
.604 .43555 Mdot
.604 .43557 Mdot
.604 .43579 Mdot
.604 .43584 Mdot
.604 .43625 Mdot
.604 .43634 Mdot
.604 .43645 Mdot
.604 .43654 Mdot
.604 .43655 Mdot
.604 .43662 Mdot
.604 .43665 Mdot
.604 .43684 Mdot
.604 .43685 Mdot
.604 .43685 Mdot
.604 .43697 Mdot
.604 .43699 Mdot
.604 .43701 Mdot
.604 .43727 Mdot
.604 .43801 Mdot
.604 .43823 Mdot
.604 .43859 Mdot
.604 .43899 Mdot
.604 .43914 Mdot
.604 .43921 Mdot
.604 .43922 Mdot
.604 .43955 Mdot
.604 .43979 Mdot
.604 .44011 Mdot
.604 .44036 Mdot
.604 .44052 Mdot
.604 .4406 Mdot
.604 .44064 Mdot
.604 .44065 Mdot
.604 .44072 Mdot
.604 .44073 Mdot
.604 .4408 Mdot
.604 .44082 Mdot
.604 .44096 Mdot
.604 .44099 Mdot
.604 .44103 Mdot
.604 .44106 Mdot
.604 .44109 Mdot
.604 .44117 Mdot
.604 .44122 Mdot
.604 .44122 Mdot
.604 .44123 Mdot
.604 .44132 Mdot
.604 .44158 Mdot
.604 .44166 Mdot
.604 .44178 Mdot
.604 .44197 Mdot
.604 .442 Mdot
.604 .4422 Mdot
.604 .44231 Mdot
.604 .4424 Mdot
.604 .44246 Mdot
.604 .44249 Mdot
.604 .4425 Mdot
.604 .44256 Mdot
.604 .44264 Mdot
.604 .44269 Mdot
.604 .44305 Mdot
.604 .44312 Mdot
.604 .44322 Mdot
.604 .44337 Mdot
.604 .44346 Mdot
.604 .44349 Mdot
.604 .4435 Mdot
.604 .44352 Mdot
.604 .44354 Mdot
.604 .44359 Mdot
.604 .44368 Mdot
.604 .44374 Mdot
.604 .44379 Mdot
.604 .444 Mdot
.604 .44417 Mdot
.604 .44429 Mdot
.604 .44489 Mdot
.604 .44497 Mdot
.604 .44511 Mdot
.604 .44516 Mdot
.604 .4452 Mdot
.604 .44523 Mdot
.604 .44528 Mdot
.604 .44537 Mdot
.604 .44552 Mdot
.604 .44571 Mdot
.604 .44585 Mdot
.604 .44604 Mdot
.604 .44604 Mdot
.604 .44608 Mdot
.604 .44617 Mdot
.604 .4464 Mdot
.604 .44661 Mdot
.604 .44674 Mdot
.604 .44717 Mdot
.604 .44732 Mdot
.604 .44733 Mdot
.604 .44734 Mdot
.604 .44741 Mdot
.604 .44741 Mdot
.604 .44742 Mdot
.604 .44753 Mdot
.604 .44754 Mdot
.604 .44758 Mdot
.604 .44759 Mdot
.604 .44764 Mdot
.604 .44771 Mdot
.604 .44776 Mdot
.604 .44799 Mdot
.604 .44802 Mdot
.604 .44815 Mdot
.604 .44816 Mdot
.604 .44828 Mdot
.604 .4483 Mdot
.604 .44836 Mdot
.604 .44849 Mdot
.604 .44871 Mdot
.604 .44876 Mdot
.604 .44888 Mdot
.604 .44916 Mdot
.604 .44938 Mdot
.604 .44961 Mdot
.604 .44969 Mdot
.604 .45008 Mdot
.604 .45062 Mdot
.604 .45063 Mdot
.604 .45075 Mdot
.604 .45099 Mdot
.604 .45155 Mdot
.604 .45164 Mdot
.604 .45222 Mdot
.604 .45258 Mdot
.604 .45285 Mdot
.604 .45363 Mdot
.604 .45377 Mdot
.604 .45403 Mdot
.604 .4542 Mdot
.604 .45421 Mdot
.604 .45425 Mdot
.604 .45444 Mdot
.604 .45445 Mdot
.604 .45446 Mdot
.604 .45477 Mdot
.604 .45481 Mdot
.604 .45492 Mdot
.604 .45493 Mdot
.604 .45495 Mdot
.604 .45508 Mdot
.604 .45527 Mdot
.604 .4554 Mdot
.604 .45579 Mdot
.604 .45605 Mdot
.604 .45613 Mdot
.604 .45648 Mdot
.604 .45652 Mdot
.604 .4567 Mdot
.604 .45683 Mdot
.604 .45689 Mdot
.604 .45703 Mdot
.604 .45705 Mdot
.604 .45719 Mdot
.604 .45742 Mdot
.604 .45777 Mdot
.604 .45802 Mdot
.604 .45815 Mdot
.604 .45816 Mdot
.604 .45849 Mdot
.604 .45885 Mdot
.604 .45919 Mdot
.604 .45926 Mdot
.604 .45967 Mdot
.604 .45988 Mdot
.604 .46 Mdot
.604 .4605 Mdot
.604 .46072 Mdot
.604 .46141 Mdot
.604 .46143 Mdot
.604 .46165 Mdot
.604 .46179 Mdot
.604 .46179 Mdot
.604 .46197 Mdot
.604 .46325 Mdot
.604 .46327 Mdot
.604 .46358 Mdot
.604 .46398 Mdot
.604 .46425 Mdot
.604 .46438 Mdot
.604 .46494 Mdot
.604 .46575 Mdot
.604 .46599 Mdot
.604 .46746 Mdot
.604 .46756 Mdot
.604 .4678 Mdot
.604 .46787 Mdot
.604 .46795 Mdot
.604 .46803 Mdot
.604 .46852 Mdot
.604 .46909 Mdot
.604 .46922 Mdot
.604 .47001 Mdot
.604 .47002 Mdot
.604 .47096 Mdot
.604 .47129 Mdot
.604 .47166 Mdot
.604 .47171 Mdot
.604 .47236 Mdot
.604 .47255 Mdot
.604 .4728 Mdot
.604 .47284 Mdot
.604 .47286 Mdot
.604 .47294 Mdot
.604 .47323 Mdot
.604 .47344 Mdot
.604 .47346 Mdot
.604 .47348 Mdot
.604 .47431 Mdot
.604 .47441 Mdot
.604 .47469 Mdot
.604 .47472 Mdot
.604 .47476 Mdot
.604 .47512 Mdot
.604 .47561 Mdot
.604 .47596 Mdot
.604 .4766 Mdot
.604 .47677 Mdot
.604 .47696 Mdot
.604 .47765 Mdot
.604 .47784 Mdot
.604 .47848 Mdot
.604 .47853 Mdot
.604 .47875 Mdot
.604 .47886 Mdot
.604 .47932 Mdot
.604 .47966 Mdot
.604 .47982 Mdot
.604 .48017 Mdot
.604 .48022 Mdot
.604 .48058 Mdot
.604 .48083 Mdot
.604 .48089 Mdot
.604 .48094 Mdot
.604 .48117 Mdot
.604 .48134 Mdot
.604 .48143 Mdot
.604 .48206 Mdot
.604 .48268 Mdot
.604 .48284 Mdot
.604 .48285 Mdot
.604 .48301 Mdot
.604 .48304 Mdot
.604 .48388 Mdot
.604 .48432 Mdot
.604 .48457 Mdot
.604 .48478 Mdot
.604 .48487 Mdot
.604 .48522 Mdot
.604 .48564 Mdot
.604 .48582 Mdot
.604 .48583 Mdot
.604 .48587 Mdot
.604 .48667 Mdot
.604 .48684 Mdot
.604 .4869 Mdot
.604 .48701 Mdot
.604 .48735 Mdot
.604 .48767 Mdot
.604 .48869 Mdot
.604 .48885 Mdot
.604 .48891 Mdot
.604 .48944 Mdot
.604 .49115 Mdot
.604 .4912 Mdot
.604 .49138 Mdot
.604 .49172 Mdot
.604 .49205 Mdot
.604 .49205 Mdot
.604 .4925 Mdot
.604 .49251 Mdot
.604 .49305 Mdot
.604 .49466 Mdot
.604 .49484 Mdot
.604 .49507 Mdot
.604 .49557 Mdot
.604 .49563 Mdot
.604 .49637 Mdot
.604 .49732 Mdot
.604 .49732 Mdot
.604 .49796 Mdot
.604 .49806 Mdot
.604 .49827 Mdot
.604 .49956 Mdot
.604 .50145 Mdot
.604 .502 Mdot
.604 .50208 Mdot
.604 .50272 Mdot
.604 .50318 Mdot
.604 .50405 Mdot
.604 .50417 Mdot
.604 .50535 Mdot
.604 .50557 Mdot
.604 .50571 Mdot
.604 .5058 Mdot
.604 .50611 Mdot
.604 .50624 Mdot
.604 .50625 Mdot
.604 .50626 Mdot
.604 .50645 Mdot
.604 .5065 Mdot
.604 .50662 Mdot
.604 .50725 Mdot
.604 .50771 Mdot
.604 .50895 Mdot
.604 .50926 Mdot
.604 .51053 Mdot
.604 .51083 Mdot
.604 .51095 Mdot
.604 .51097 Mdot
.604 .51098 Mdot
.604 .51103 Mdot
.604 .51109 Mdot
.604 .51187 Mdot
.604 .51299 Mdot
.604 .51314 Mdot
.604 .51369 Mdot
.604 .51374 Mdot
.604 .51422 Mdot
.604 .51448 Mdot
.604 .51456 Mdot
.604 .51524 Mdot
.604 .51567 Mdot
.604 .51591 Mdot
.604 .51631 Mdot
.604 .51656 Mdot
.604 .51682 Mdot
.604 .51691 Mdot
.604 .51696 Mdot
.604 .51712 Mdot
.604 .51763 Mdot
.604 .51771 Mdot
.604 .51813 Mdot
.604 .51817 Mdot
.604 .51821 Mdot
.604 .5187 Mdot
.604 .5188 Mdot
.604 .51951 Mdot
.604 .5196 Mdot
.604 .51962 Mdot
.604 .51988 Mdot
.604 .52008 Mdot
.604 .52063 Mdot
.604 .52069 Mdot
.604 .52077 Mdot
.604 .52147 Mdot
.604 .5215 Mdot
.604 .52185 Mdot
.604 .52233 Mdot
.604 .52241 Mdot
.604 .52243 Mdot
.604 .52303 Mdot
.604 .52309 Mdot
.604 .52316 Mdot
.604 .52328 Mdot
.604 .5235 Mdot
.604 .52381 Mdot
.604 .52384 Mdot
.604 .52431 Mdot
.604 .52452 Mdot
.604 .52462 Mdot
.604 .52495 Mdot
.604 .52499 Mdot
.604 .52626 Mdot
.604 .52646 Mdot
.604 .52662 Mdot
.604 .52693 Mdot
.604 .52702 Mdot
.604 .52779 Mdot
.604 .52787 Mdot
.604 .52826 Mdot
.604 .52846 Mdot
.604 .52929 Mdot
.604 .52931 Mdot
.604 .52946 Mdot
.604 .52946 Mdot
.604 .52981 Mdot
.604 .52988 Mdot
.604 .52997 Mdot
.604 .52999 Mdot
.604 .53015 Mdot
.604 .53019 Mdot
.604 .53047 Mdot
.604 .53077 Mdot
.604 .53086 Mdot
.604 .53133 Mdot
.604 .53136 Mdot
.604 .53146 Mdot
.604 .53151 Mdot
.604 .53175 Mdot
.604 .53189 Mdot
.604 .532 Mdot
.604 .53207 Mdot
.604 .53208 Mdot
.604 .53246 Mdot
.604 .53259 Mdot
.604 .53268 Mdot
.604 .53275 Mdot
.604 .53291 Mdot
.604 .53291 Mdot
.604 .53297 Mdot
.604 .53394 Mdot
.604 .53397 Mdot
.604 .53416 Mdot
.604 .53477 Mdot
.604 .53494 Mdot
.604 .53521 Mdot
.604 .53522 Mdot
.604 .53534 Mdot
.604 .53543 Mdot
.604 .53547 Mdot
.604 .53552 Mdot
.604 .53575 Mdot
.604 .53579 Mdot
.604 .53597 Mdot
.604 .5361 Mdot
.604 .5368 Mdot
.604 .5368 Mdot
.604 .53684 Mdot
.604 .53709 Mdot
.604 .53713 Mdot
.604 .53751 Mdot
.604 .53789 Mdot
.604 .5382 Mdot
.604 .53834 Mdot
.604 .53869 Mdot
.604 .53885 Mdot
.604 .53905 Mdot
.604 .53947 Mdot
.604 .53972 Mdot
.604 .53974 Mdot
.604 .53977 Mdot
.604 .53981 Mdot
.604 .53991 Mdot
.604 .54094 Mdot
.604 .54117 Mdot
.604 .54125 Mdot
.604 .54125 Mdot
.604 .54139 Mdot
.604 .54141 Mdot
.604 .54188 Mdot
.604 .54191 Mdot
.604 .54217 Mdot
.604 .54231 Mdot
.604 .5425 Mdot
.604 .54365 Mdot
.604 .54386 Mdot
.604 .54393 Mdot
.604 .54448 Mdot
.604 .54454 Mdot
.604 .54459 Mdot
.604 .54502 Mdot
.604 .54517 Mdot
.604 .54547 Mdot
.604 .54613 Mdot
.604 .54617 Mdot
.604 .5466 Mdot
.604 .54663 Mdot
.604 .54669 Mdot
.604 .54689 Mdot
.604 .5469 Mdot
.604 .54706 Mdot
.604 .54714 Mdot
.604 .54722 Mdot
.604 .54728 Mdot
.604 .54764 Mdot
.604 .54765 Mdot
.604 .54799 Mdot
.604 .54801 Mdot
.604 .54811 Mdot
.604 .54812 Mdot
.604 .54814 Mdot
.604 .54869 Mdot
.604 .5487 Mdot
.604 .54911 Mdot
.604 .54915 Mdot
.604 .54993 Mdot
.604 .55001 Mdot
.604 .55009 Mdot
.604 .55028 Mdot
.604 .55045 Mdot
.604 .55066 Mdot
.604 .55066 Mdot
.604 .55087 Mdot
.604 .5511 Mdot
.604 .55112 Mdot
.604 .55114 Mdot
.604 .55115 Mdot
.604 .55123 Mdot
.604 .55178 Mdot
.604 .5519 Mdot
.604 .55199 Mdot
.604 .55242 Mdot
.604 .55246 Mdot
.604 .55249 Mdot
.604 .55253 Mdot
.604 .55254 Mdot
.604 .55284 Mdot
.604 .55291 Mdot
.604 .55301 Mdot
.604 .55308 Mdot
.604 .55323 Mdot
.604 .5533 Mdot
.604 .55342 Mdot
.604 .55346 Mdot
.604 .55352 Mdot
.604 .55371 Mdot
.604 .55389 Mdot
.604 .55407 Mdot
.604 .55415 Mdot
.604 .55431 Mdot
.604 .55457 Mdot
.604 .55496 Mdot
.604 .55501 Mdot
.604 .55511 Mdot
.604 .55514 Mdot
.604 .55536 Mdot
.604 .55537 Mdot
.604 .55539 Mdot
.604 .55539 Mdot
.604 .55564 Mdot
.604 .55566 Mdot
.604 .5557 Mdot
.604 .55583 Mdot
.604 .5561 Mdot
.604 .55612 Mdot
.604 .55615 Mdot
.604 .55632 Mdot
.604 .55633 Mdot
.604 .55634 Mdot
.604 .55635 Mdot
.604 .55635 Mdot
.604 .55638 Mdot
.604 .55644 Mdot
.604 .55644 Mdot
.604 .55648 Mdot
.604 .55651 Mdot
.604 .55652 Mdot
.604 .55657 Mdot
.604 .55659 Mdot
.604 .55659 Mdot
.604 .55659 Mdot
.604 .55661 Mdot
.604 .55662 Mdot
.604 .55663 Mdot
.604 .55664 Mdot
.604 .55666 Mdot
.604 .55668 Mdot
.604 .5567 Mdot
.606 .17216 Mdot
.606 .17217 Mdot
.606 .17227 Mdot
.606 .17228 Mdot
.606 .17237 Mdot
.606 .17238 Mdot
.606 .17253 Mdot
.606 .17268 Mdot
.606 .17274 Mdot
.606 .17277 Mdot
.606 .1728 Mdot
.606 .17281 Mdot
.606 .17293 Mdot
.606 .17308 Mdot
.606 .17349 Mdot
.606 .17359 Mdot
.606 .17416 Mdot
.606 .17445 Mdot
.606 .17449 Mdot
.606 .17459 Mdot
.606 .17462 Mdot
.606 .17523 Mdot
.606 .17556 Mdot
.606 .17558 Mdot
.606 .17576 Mdot
.606 .1763 Mdot
.606 .1766 Mdot
.606 .17663 Mdot
.606 .17743 Mdot
.606 .17747 Mdot
.606 .17758 Mdot
.606 .17764 Mdot
.606 .1777 Mdot
.606 .17789 Mdot
.606 .17801 Mdot
.606 .17858 Mdot
.606 .17859 Mdot
.606 .17882 Mdot
.606 .17908 Mdot
.606 .17974 Mdot
.606 .17985 Mdot
.606 .18024 Mdot
.606 .1803 Mdot
.606 .18043 Mdot
.606 .18067 Mdot
.606 .18069 Mdot
.606 .18116 Mdot
.606 .18131 Mdot
.606 .18151 Mdot
.606 .18217 Mdot
.606 .18219 Mdot
.606 .1824 Mdot
.606 .18245 Mdot
.606 .18306 Mdot
.606 .1831 Mdot
.606 .18312 Mdot
.606 .18403 Mdot
.606 .18451 Mdot
.606 .18458 Mdot
.606 .18525 Mdot
.606 .18539 Mdot
.606 .18613 Mdot
.606 .18638 Mdot
.606 .18664 Mdot
.606 .18664 Mdot
.606 .18723 Mdot
.606 .18753 Mdot
.606 .18781 Mdot
.606 .18986 Mdot
.606 .18995 Mdot
.606 .19093 Mdot
.606 .19097 Mdot
.606 .19182 Mdot
.606 .19262 Mdot
.606 .19298 Mdot
.606 .19325 Mdot
.606 .19326 Mdot
.606 .19354 Mdot
.606 .19365 Mdot
.606 .19501 Mdot
.606 .19526 Mdot
.606 .19527 Mdot
.606 .19625 Mdot
.606 .19653 Mdot
.606 .19692 Mdot
.606 .19849 Mdot
.606 .19885 Mdot
.606 .19929 Mdot
.606 .20047 Mdot
.606 .20074 Mdot
.606 .20114 Mdot
.606 .20129 Mdot
.606 .20162 Mdot
.606 .20172 Mdot
.606 .2022 Mdot
.606 .20406 Mdot
.606 .20432 Mdot
.606 .20532 Mdot
.606 .20626 Mdot
.606 .20839 Mdot
.606 .20846 Mdot
.606 .209 Mdot
.606 .20957 Mdot
.606 .21242 Mdot
.606 .21332 Mdot
.606 .21465 Mdot
.606 .21521 Mdot
.606 .21574 Mdot
.606 .21586 Mdot
.606 .21587 Mdot
.606 .21672 Mdot
.606 .21697 Mdot
.606 .21834 Mdot
.606 .21903 Mdot
.606 .21939 Mdot
.606 .22029 Mdot
.606 .22086 Mdot
.606 .22268 Mdot
.606 .22377 Mdot
.606 .22465 Mdot
.606 .22474 Mdot
.606 .22623 Mdot
.606 .22672 Mdot
.606 .22674 Mdot
.606 .22699 Mdot
.606 .22737 Mdot
.606 .22737 Mdot
.606 .22797 Mdot
.606 .22802 Mdot
.606 .22842 Mdot
.606 .22865 Mdot
.606 .22881 Mdot
.606 .2291 Mdot
.606 .22921 Mdot
.606 .22949 Mdot
.606 .22951 Mdot
.606 .22989 Mdot
.606 .23011 Mdot
.606 .23081 Mdot
.606 .23123 Mdot
.606 .2327 Mdot
.606 .23316 Mdot
.606 .23429 Mdot
.606 .23485 Mdot
.606 .23498 Mdot
.606 .23539 Mdot
.606 .23563 Mdot
.606 .24086 Mdot
.606 .2411 Mdot
.606 .24166 Mdot
.606 .24177 Mdot
.606 .24182 Mdot
.606 .24205 Mdot
.606 .24214 Mdot
.606 .24219 Mdot
.606 .24238 Mdot
.606 .24365 Mdot
.606 .24505 Mdot
.606 .24741 Mdot
.606 .24752 Mdot
.606 .24756 Mdot
.606 .25071 Mdot
.606 .25091 Mdot
.606 .25361 Mdot
.606 .25381 Mdot
.606 .25395 Mdot
.606 .25404 Mdot
.606 .25415 Mdot
.606 .25436 Mdot
.606 .25469 Mdot
.606 .25489 Mdot
.606 .25501 Mdot
.606 .25502 Mdot
.606 .25528 Mdot
.606 .25656 Mdot
.606 .25714 Mdot
.606 .25811 Mdot
.606 .25891 Mdot
.606 .25911 Mdot
.606 .25949 Mdot
.606 .26087 Mdot
.606 .26287 Mdot
.606 .26724 Mdot
.606 .26969 Mdot
.606 .26992 Mdot
.606 .27002 Mdot
.606 .27029 Mdot
.606 .2713 Mdot
.606 .27162 Mdot
.606 .27188 Mdot
.606 .27302 Mdot
.606 .27331 Mdot
.606 .27584 Mdot
.606 .277 Mdot
.606 .27774 Mdot
.606 .28074 Mdot
.606 .28102 Mdot
.606 .28184 Mdot
.606 .28207 Mdot
.606 .2828 Mdot
.606 .28295 Mdot
.606 .28362 Mdot
.606 .2842 Mdot
.606 .28518 Mdot
.606 .28519 Mdot
.606 .28524 Mdot
.606 .28597 Mdot
.606 .28624 Mdot
.606 .287 Mdot
.606 .28724 Mdot
.606 .28742 Mdot
.606 .28802 Mdot
.606 .28907 Mdot
.606 .28922 Mdot
.606 .29009 Mdot
.606 .29045 Mdot
.606 .29078 Mdot
.606 .2908 Mdot
.606 .29163 Mdot
.606 .2918 Mdot
.606 .29209 Mdot
.606 .29219 Mdot
.606 .29245 Mdot
.606 .29251 Mdot
.606 .29382 Mdot
.606 .2944 Mdot
.606 .29643 Mdot
.606 .29774 Mdot
.606 .29781 Mdot
.606 .29804 Mdot
.606 .3004 Mdot
.606 .30073 Mdot
.606 .30211 Mdot
.606 .30319 Mdot
.606 .30338 Mdot
.606 .30354 Mdot
.606 .30835 Mdot
.606 .30993 Mdot
.606 .31148 Mdot
.606 .31157 Mdot
.606 .31231 Mdot
.606 .31241 Mdot
.606 .31343 Mdot
.606 .31419 Mdot
.606 .31479 Mdot
.606 .31535 Mdot
.606 .31917 Mdot
.606 .3199 Mdot
.606 .32227 Mdot
.606 .32231 Mdot
.606 .32265 Mdot
.606 .32416 Mdot
.606 .32576 Mdot
.606 .32947 Mdot
.606 .32955 Mdot
.606 .32971 Mdot
.606 .33004 Mdot
.606 .33181 Mdot
.606 .33211 Mdot
.606 .33434 Mdot
.606 .33645 Mdot
.606 .33754 Mdot
.606 .33938 Mdot
.606 .33946 Mdot
.606 .34033 Mdot
.606 .34169 Mdot
.606 .34198 Mdot
.606 .3422 Mdot
.606 .34243 Mdot
.606 .34252 Mdot
.606 .34357 Mdot
.606 .34376 Mdot
.606 .34377 Mdot
.606 .34451 Mdot
.606 .34755 Mdot
.606 .34841 Mdot
.606 .34873 Mdot
.606 .34997 Mdot
.606 .35014 Mdot
.606 .3514 Mdot
.606 .35273 Mdot
.606 .35277 Mdot
.606 .35311 Mdot
.606 .35345 Mdot
.606 .35569 Mdot
.606 .35646 Mdot
.606 .35678 Mdot
.606 .35708 Mdot
.606 .35715 Mdot
.606 .35763 Mdot
.606 .35778 Mdot
.606 .35961 Mdot
.606 .36194 Mdot
.606 .36198 Mdot
.606 .36334 Mdot
.606 .36365 Mdot
.606 .36428 Mdot
.606 .36443 Mdot
.606 .36462 Mdot
.606 .36473 Mdot
.606 .36508 Mdot
.606 .36529 Mdot
.606 .36602 Mdot
.606 .36624 Mdot
.606 .36679 Mdot
.606 .36707 Mdot
.606 .36744 Mdot
.606 .36992 Mdot
.606 .37003 Mdot
.606 .37029 Mdot
.606 .37034 Mdot
.606 .37037 Mdot
.606 .37054 Mdot
.606 .37121 Mdot
.606 .37185 Mdot
.606 .37292 Mdot
.606 .37296 Mdot
.606 .37447 Mdot
.606 .37574 Mdot
.606 .37581 Mdot
.606 .37612 Mdot
.606 .37627 Mdot
.606 .37759 Mdot
.606 .37793 Mdot
.606 .37802 Mdot
.606 .37818 Mdot
.606 .37876 Mdot
.606 .3796 Mdot
.606 .3814 Mdot
.606 .38249 Mdot
.606 .38254 Mdot
.606 .38329 Mdot
.606 .38386 Mdot
.606 .38562 Mdot
.606 .38691 Mdot
.606 .38732 Mdot
.606 .3876 Mdot
.606 .38766 Mdot
.606 .38849 Mdot
.606 .38853 Mdot
.606 .38931 Mdot
.606 .3904 Mdot
.606 .39053 Mdot
.606 .39098 Mdot
.606 .39115 Mdot
.606 .39119 Mdot
.606 .39202 Mdot
.606 .39278 Mdot
.606 .39327 Mdot
.606 .39438 Mdot
.606 .39489 Mdot
.606 .39529 Mdot
.606 .39542 Mdot
.606 .39831 Mdot
.606 .39834 Mdot
.606 .3986 Mdot
.606 .39928 Mdot
.606 .3995 Mdot
.606 .40469 Mdot
.606 .40477 Mdot
.606 .40489 Mdot
.606 .40551 Mdot
.606 .40639 Mdot
.606 .40712 Mdot
.606 .4075 Mdot
.606 .40813 Mdot
.606 .40816 Mdot
.606 .40893 Mdot
.606 .40911 Mdot
.606 .40918 Mdot
.606 .40921 Mdot
.606 .40965 Mdot
.606 .4099 Mdot
.606 .41094 Mdot
.606 .41124 Mdot
.606 .41135 Mdot
.606 .41183 Mdot
.606 .41225 Mdot
.606 .41272 Mdot
.606 .41284 Mdot
.606 .41296 Mdot
.606 .41409 Mdot
.606 .41419 Mdot
.606 .41421 Mdot
.606 .41438 Mdot
.606 .41443 Mdot
.606 .41505 Mdot
.606 .41585 Mdot
.606 .41663 Mdot
.606 .41668 Mdot
.606 .41678 Mdot
.606 .41697 Mdot
.606 .41721 Mdot
.606 .41748 Mdot
.606 .41769 Mdot
.606 .41853 Mdot
.606 .41857 Mdot
.606 .41865 Mdot
.606 .41867 Mdot
.606 .41868 Mdot
.606 .41896 Mdot
.606 .41956 Mdot
.606 .42006 Mdot
.606 .42049 Mdot
.606 .42051 Mdot
.606 .42062 Mdot
.606 .42067 Mdot
.606 .42123 Mdot
.606 .42126 Mdot
.606 .42131 Mdot
.606 .42239 Mdot
.606 .42322 Mdot
.606 .42381 Mdot
.606 .42424 Mdot
.606 .42447 Mdot
.606 .42546 Mdot
.606 .42561 Mdot
.606 .42567 Mdot
.606 .42568 Mdot
.606 .42596 Mdot
.606 .42638 Mdot
.606 .42675 Mdot
.606 .42692 Mdot
.606 .42807 Mdot
.606 .4284 Mdot
.606 .42847 Mdot
.606 .43025 Mdot
.606 .43029 Mdot
.606 .43105 Mdot
.606 .43117 Mdot
.606 .43172 Mdot
.606 .43174 Mdot
.606 .43175 Mdot
.606 .43199 Mdot
.606 .43234 Mdot
.606 .43244 Mdot
.606 .43248 Mdot
.606 .43294 Mdot
.606 .43298 Mdot
.606 .43302 Mdot
.606 .43341 Mdot
.606 .43344 Mdot
.606 .4335 Mdot
.606 .43373 Mdot
.606 .43427 Mdot
.606 .43429 Mdot
.606 .43432 Mdot
.606 .43438 Mdot
.606 .43447 Mdot
.606 .43456 Mdot
.606 .43463 Mdot
.606 .43496 Mdot
.606 .43497 Mdot
.606 .43506 Mdot
.606 .43527 Mdot
.606 .43544 Mdot
.606 .43559 Mdot
.606 .43565 Mdot
.606 .43584 Mdot
.606 .43624 Mdot
.606 .43695 Mdot
.606 .43729 Mdot
.606 .43736 Mdot
.606 .43746 Mdot
.606 .43832 Mdot
.606 .43894 Mdot
.606 .43925 Mdot
.606 .43945 Mdot
.606 .43953 Mdot
.606 .43966 Mdot
.606 .43969 Mdot
.606 .4397 Mdot
.606 .43987 Mdot
.606 .43988 Mdot
.606 .43989 Mdot
.606 .44004 Mdot
.606 .44006 Mdot
.606 .44033 Mdot
.606 .44034 Mdot
.606 .44037 Mdot
.606 .44043 Mdot
.606 .44057 Mdot
.606 .44067 Mdot
.606 .44073 Mdot
.606 .44079 Mdot
.606 .4408 Mdot
.606 .44087 Mdot
.606 .44101 Mdot
.606 .44126 Mdot
.606 .44137 Mdot
.606 .44195 Mdot
.606 .44206 Mdot
.606 .44213 Mdot
.606 .44216 Mdot
.606 .4422 Mdot
.606 .44244 Mdot
.606 .44263 Mdot
.606 .44305 Mdot
.606 .44308 Mdot
.606 .4431 Mdot
.606 .44318 Mdot
.606 .44325 Mdot
.606 .44339 Mdot
.606 .44346 Mdot
.606 .44351 Mdot
.606 .44356 Mdot
.606 .44357 Mdot
.606 .44358 Mdot
.606 .44358 Mdot
.606 .44358 Mdot
.606 .44358 Mdot
.606 .44358 Mdot
.606 .44359 Mdot
.606 .44359 Mdot
.606 .44362 Mdot
.606 .44365 Mdot
.606 .44369 Mdot
.606 .44378 Mdot
.606 .44382 Mdot
.606 .44387 Mdot
.606 .4439 Mdot
.606 .44414 Mdot
.606 .44425 Mdot
.606 .4444 Mdot
.606 .44442 Mdot
.606 .44448 Mdot
.606 .44488 Mdot
.606 .44518 Mdot
.606 .44544 Mdot
.606 .44548 Mdot
.606 .44549 Mdot
.606 .44577 Mdot
.606 .44589 Mdot
.606 .44596 Mdot
.606 .44601 Mdot
.606 .44612 Mdot
.606 .44631 Mdot
.606 .44667 Mdot
.606 .44717 Mdot
.606 .44722 Mdot
.606 .44727 Mdot
.606 .44746 Mdot
.606 .44787 Mdot
.606 .4481 Mdot
.606 .44821 Mdot
.606 .44824 Mdot
.606 .44833 Mdot
.606 .44843 Mdot
.606 .44854 Mdot
.606 .4486 Mdot
.606 .4486 Mdot
.606 .44879 Mdot
.606 .44883 Mdot
.606 .44888 Mdot
.606 .44893 Mdot
.606 .44897 Mdot
.606 .44899 Mdot
.606 .449 Mdot
.606 .4493 Mdot
.606 .44943 Mdot
.606 .44947 Mdot
.606 .44949 Mdot
.606 .44971 Mdot
.606 .44973 Mdot
.606 .44975 Mdot
.606 .45002 Mdot
.606 .45004 Mdot
.606 .4501 Mdot
.606 .45029 Mdot
.606 .45043 Mdot
.606 .45043 Mdot
.606 .45045 Mdot
.606 .45075 Mdot
.606 .45082 Mdot
.606 .45125 Mdot
.606 .45127 Mdot
.606 .45227 Mdot
.606 .45231 Mdot
.606 .45249 Mdot
.606 .45313 Mdot
.606 .45322 Mdot
.606 .45343 Mdot
.606 .45366 Mdot
.606 .45381 Mdot
.606 .45382 Mdot
.606 .45385 Mdot
.606 .45394 Mdot
.606 .45448 Mdot
.606 .45461 Mdot
.606 .45484 Mdot
.606 .45517 Mdot
.606 .45562 Mdot
.606 .45621 Mdot
.606 .45624 Mdot
.606 .45625 Mdot
.606 .45656 Mdot
.606 .45658 Mdot
.606 .45664 Mdot
.606 .45665 Mdot
.606 .45688 Mdot
.606 .45716 Mdot
.606 .45747 Mdot
.606 .45763 Mdot
.606 .45763 Mdot
.606 .45764 Mdot
.606 .45769 Mdot
.606 .45771 Mdot
.606 .45816 Mdot
.606 .45827 Mdot
.606 .45841 Mdot
.606 .45854 Mdot
.606 .45864 Mdot
.606 .4587 Mdot
.606 .45873 Mdot
.606 .45914 Mdot
.606 .45957 Mdot
.606 .4599 Mdot
.606 .45992 Mdot
.606 .46001 Mdot
.606 .46002 Mdot
.606 .46008 Mdot
.606 .46067 Mdot
.606 .46073 Mdot
.606 .46079 Mdot
.606 .46104 Mdot
.606 .46127 Mdot
.606 .46152 Mdot
.606 .46158 Mdot
.606 .46173 Mdot
.606 .46227 Mdot
.606 .4624 Mdot
.606 .46263 Mdot
.606 .46265 Mdot
.606 .46269 Mdot
.606 .46278 Mdot
.606 .46318 Mdot
.606 .46319 Mdot
.606 .46352 Mdot
.606 .46371 Mdot
.606 .46409 Mdot
.606 .46455 Mdot
.606 .46486 Mdot
.606 .46492 Mdot
.606 .46496 Mdot
.606 .4676 Mdot
.606 .46771 Mdot
.606 .46805 Mdot
.606 .46819 Mdot
.606 .4682 Mdot
.606 .46964 Mdot
.606 .46971 Mdot
.606 .46991 Mdot
.606 .47016 Mdot
.606 .47071 Mdot
.606 .47095 Mdot
.606 .47132 Mdot
.606 .47173 Mdot
.606 .47175 Mdot
.606 .47183 Mdot
.606 .47205 Mdot
.606 .47212 Mdot
.606 .47265 Mdot
.606 .47303 Mdot
.606 .47305 Mdot
.606 .47346 Mdot
.606 .47348 Mdot
.606 .47362 Mdot
.606 .47382 Mdot
.606 .47444 Mdot
.606 .47529 Mdot
.606 .47557 Mdot
.606 .47593 Mdot
.606 .47595 Mdot
.606 .47647 Mdot
.606 .47733 Mdot
.606 .47772 Mdot
.606 .478 Mdot
.606 .47807 Mdot
.606 .47811 Mdot
.606 .47827 Mdot
.606 .4789 Mdot
.606 .47897 Mdot
.606 .47912 Mdot
.606 .47915 Mdot
.606 .47974 Mdot
.606 .48044 Mdot
.606 .48047 Mdot
.606 .48096 Mdot
.606 .48126 Mdot
.606 .48157 Mdot
.606 .48165 Mdot
.606 .48166 Mdot
.606 .48169 Mdot
.606 .4818 Mdot
.606 .48186 Mdot
.606 .483 Mdot
.606 .48317 Mdot
.606 .4833 Mdot
.606 .48355 Mdot
.606 .48365 Mdot
.606 .48398 Mdot
.606 .48408 Mdot
.606 .48424 Mdot
.606 .48429 Mdot
.606 .48438 Mdot
.606 .48445 Mdot
.606 .48473 Mdot
.606 .48487 Mdot
.606 .48549 Mdot
.606 .48551 Mdot
.606 .48656 Mdot
.606 .48738 Mdot
.606 .48744 Mdot
.606 .48766 Mdot
.606 .48769 Mdot
.606 .48783 Mdot
.606 .48797 Mdot
.606 .48831 Mdot
.606 .48931 Mdot
.606 .48946 Mdot
.606 .48961 Mdot
.606 .48963 Mdot
.606 .49021 Mdot
.606 .49077 Mdot
.606 .49084 Mdot
.606 .49138 Mdot
.606 .49153 Mdot
.606 .4919 Mdot
.606 .49322 Mdot
.606 .49354 Mdot
.606 .49355 Mdot
.606 .49363 Mdot
.606 .49409 Mdot
.606 .49413 Mdot
.606 .49422 Mdot
.606 .49432 Mdot
.606 .49444 Mdot
.606 .49503 Mdot
.606 .4954 Mdot
.606 .49544 Mdot
.606 .49622 Mdot
.606 .49669 Mdot
.606 .49758 Mdot
.606 .49853 Mdot
.606 .49865 Mdot
.606 .4994 Mdot
.606 .49953 Mdot
.606 .4996 Mdot
.606 .49963 Mdot
.606 .50118 Mdot
.606 .50185 Mdot
.606 .50247 Mdot
.606 .50261 Mdot
.606 .50263 Mdot
.606 .5036 Mdot
.606 .5039 Mdot
.606 .50546 Mdot
.606 .50569 Mdot
.606 .50593 Mdot
.606 .50624 Mdot
.606 .50665 Mdot
.606 .50669 Mdot
.606 .50699 Mdot
.606 .50703 Mdot
.606 .50766 Mdot
.606 .50829 Mdot
.606 .51021 Mdot
.606 .51027 Mdot
.606 .51035 Mdot
.606 .51077 Mdot
.606 .51132 Mdot
.606 .51145 Mdot
.606 .51238 Mdot
.606 .51247 Mdot
.606 .5125 Mdot
.606 .51301 Mdot
.606 .5138 Mdot
.606 .51403 Mdot
.606 .51454 Mdot
.606 .51456 Mdot
.606 .51466 Mdot
.606 .5147 Mdot
.606 .51481 Mdot
.606 .51488 Mdot
.606 .5152 Mdot
.606 .51521 Mdot
.606 .51534 Mdot
.606 .51548 Mdot
.606 .51581 Mdot
.606 .51587 Mdot
.606 .51628 Mdot
.606 .51651 Mdot
.606 .51658 Mdot
.606 .51667 Mdot
.606 .51696 Mdot
.606 .51706 Mdot
.606 .51735 Mdot
.606 .51736 Mdot
.606 .51737 Mdot
.606 .51774 Mdot
.606 .51796 Mdot
.606 .51822 Mdot
.606 .51828 Mdot
.606 .51856 Mdot
.606 .51864 Mdot
.606 .51896 Mdot
.606 .51906 Mdot
.606 .5202 Mdot
.606 .52048 Mdot
.606 .52092 Mdot
.606 .52187 Mdot
.606 .52198 Mdot
.606 .52241 Mdot
.606 .5225 Mdot
.606 .52262 Mdot
.606 .523 Mdot
.606 .5231 Mdot
.606 .52314 Mdot
.606 .52322 Mdot
.606 .52414 Mdot
.606 .52575 Mdot
.606 .52649 Mdot
.606 .52699 Mdot
.606 .52713 Mdot
.606 .52721 Mdot
.606 .5275 Mdot
.606 .52785 Mdot
.606 .52806 Mdot
.606 .52853 Mdot
.606 .52862 Mdot
.606 .52863 Mdot
.606 .52867 Mdot
.606 .52875 Mdot
.606 .52887 Mdot
.606 .52894 Mdot
.606 .52898 Mdot
.606 .52901 Mdot
.606 .52907 Mdot
.606 .52914 Mdot
.606 .53012 Mdot
.606 .53019 Mdot
.606 .53132 Mdot
.606 .53134 Mdot
.606 .53138 Mdot
.606 .53222 Mdot
.606 .53272 Mdot
.606 .53318 Mdot
.606 .53324 Mdot
.606 .53326 Mdot
.606 .53329 Mdot
.606 .53337 Mdot
.606 .53339 Mdot
.606 .53343 Mdot
.606 .53363 Mdot
.606 .53372 Mdot
.606 .53557 Mdot
.606 .53565 Mdot
.606 .5358 Mdot
.606 .53584 Mdot
.606 .53604 Mdot
.606 .53644 Mdot
.606 .5366 Mdot
.606 .53711 Mdot
.606 .53726 Mdot
.606 .5375 Mdot
.606 .53758 Mdot
.606 .53771 Mdot
.606 .53772 Mdot
.606 .53782 Mdot
.606 .53786 Mdot
.606 .53796 Mdot
.606 .53801 Mdot
.606 .53809 Mdot
.606 .53823 Mdot
.606 .53825 Mdot
.606 .53846 Mdot
.606 .53846 Mdot
.606 .53859 Mdot
.606 .53868 Mdot
.606 .53869 Mdot
.606 .53886 Mdot
.606 .53938 Mdot
.606 .53941 Mdot
.606 .53971 Mdot
.606 .54009 Mdot
.606 .54072 Mdot
.606 .54091 Mdot
.606 .54122 Mdot
.606 .54135 Mdot
.606 .54158 Mdot
.606 .54205 Mdot
.606 .54214 Mdot
.606 .54243 Mdot
.606 .54243 Mdot
.606 .54247 Mdot
.606 .54266 Mdot
.606 .54285 Mdot
.606 .5433 Mdot
.606 .54361 Mdot
.606 .54457 Mdot
.606 .54477 Mdot
.606 .54495 Mdot
.606 .54498 Mdot
.606 .54569 Mdot
.606 .54601 Mdot
.606 .54635 Mdot
.606 .54644 Mdot
.606 .54706 Mdot
.606 .54722 Mdot
.606 .54726 Mdot
.606 .54737 Mdot
.606 .54742 Mdot
.606 .54755 Mdot
.606 .54764 Mdot
.606 .54803 Mdot
.606 .54818 Mdot
.606 .5483 Mdot
.606 .54883 Mdot
.606 .54896 Mdot
.606 .54905 Mdot
.606 .54937 Mdot
.606 .54938 Mdot
.606 .54946 Mdot
.606 .54991 Mdot
.606 .54995 Mdot
.606 .55004 Mdot
.606 .55005 Mdot
.606 .55013 Mdot
.606 .55025 Mdot
.606 .55052 Mdot
.606 .5508 Mdot
.606 .55081 Mdot
.606 .55114 Mdot
.606 .55117 Mdot
.606 .55184 Mdot
.606 .55193 Mdot
.606 .55203 Mdot
.606 .55222 Mdot
.606 .55231 Mdot
.606 .55239 Mdot
.606 .55263 Mdot
.606 .55268 Mdot
.606 .5529 Mdot
.606 .55292 Mdot
.606 .55308 Mdot
.606 .55338 Mdot
.606 .55338 Mdot
.606 .5534 Mdot
.606 .5536 Mdot
.606 .55361 Mdot
.606 .55368 Mdot
.606 .55369 Mdot
.606 .5539 Mdot
.606 .55397 Mdot
.606 .55402 Mdot
.606 .55417 Mdot
.606 .55418 Mdot
.606 .55426 Mdot
.606 .5543 Mdot
.606 .55432 Mdot
.606 .55445 Mdot
.606 .55448 Mdot
.606 .55469 Mdot
.606 .55478 Mdot
.606 .55485 Mdot
.606 .55486 Mdot
.606 .55504 Mdot
.606 .55508 Mdot
.606 .55514 Mdot
.606 .55516 Mdot
.606 .55518 Mdot
.606 .55522 Mdot
.606 .55523 Mdot
.606 .55549 Mdot
.606 .5555 Mdot
.606 .5556 Mdot
.606 .55577 Mdot
.606 .55583 Mdot
.606 .55584 Mdot
.606 .55595 Mdot
.606 .55614 Mdot
.606 .55615 Mdot
.606 .55618 Mdot
.606 .5562 Mdot
.606 .55629 Mdot
.606 .55647 Mdot
.606 .55651 Mdot
.606 .55664 Mdot
.606 .55669 Mdot
.606 .55672 Mdot
.606 .55673 Mdot
.606 .55674 Mdot
.606 .55675 Mdot
.606 .55677 Mdot
.606 .55682 Mdot
.606 .55687 Mdot
.606 .55687 Mdot
.606 .5569 Mdot
.606 .5569 Mdot
.606 .55693 Mdot
.606 .55693 Mdot
.608 .17149 Mdot
.608 .1715 Mdot
.608 .17152 Mdot
.608 .17157 Mdot
.608 .17159 Mdot
.608 .17163 Mdot
.608 .17181 Mdot
.608 .17193 Mdot
.608 .17195 Mdot
.608 .17202 Mdot
.608 .17204 Mdot
.608 .17204 Mdot
.608 .17214 Mdot
.608 .17224 Mdot
.608 .17233 Mdot
.608 .17268 Mdot
.608 .17279 Mdot
.608 .17282 Mdot
.608 .17305 Mdot
.608 .17307 Mdot
.608 .1731 Mdot
.608 .17317 Mdot
.608 .17318 Mdot
.608 .1732 Mdot
.608 .1734 Mdot
.608 .17397 Mdot
.608 .17397 Mdot
.608 .1743 Mdot
.608 .17483 Mdot
.608 .17494 Mdot
.608 .17537 Mdot
.608 .17538 Mdot
.608 .17539 Mdot
.608 .17567 Mdot
.608 .17579 Mdot
.608 .1758 Mdot
.608 .17633 Mdot
.608 .17661 Mdot
.608 .17665 Mdot
.608 .17686 Mdot
.608 .17697 Mdot
.608 .17718 Mdot
.608 .17726 Mdot
.608 .17768 Mdot
.608 .17813 Mdot
.608 .17851 Mdot
.608 .1799 Mdot
.608 .18011 Mdot
.608 .1802 Mdot
.608 .18098 Mdot
.608 .18166 Mdot
.608 .18204 Mdot
.608 .18226 Mdot
.608 .18254 Mdot
.608 .18255 Mdot
.608 .18379 Mdot
.608 .18491 Mdot
.608 .18501 Mdot
.608 .18564 Mdot
.608 .18588 Mdot
.608 .18591 Mdot
.608 .1861 Mdot
.608 .18612 Mdot
.608 .18749 Mdot
.608 .18814 Mdot
.608 .18878 Mdot
.608 .18919 Mdot
.608 .19007 Mdot
.608 .19073 Mdot
.608 .19124 Mdot
.608 .19188 Mdot
.608 .19197 Mdot
.608 .19227 Mdot
.608 .19353 Mdot
.608 .19358 Mdot
.608 .19359 Mdot
.608 .19383 Mdot
.608 .19443 Mdot
.608 .19527 Mdot
.608 .19562 Mdot
.608 .19573 Mdot
.608 .19574 Mdot
.608 .1959 Mdot
.608 .19601 Mdot
.608 .19636 Mdot
.608 .19685 Mdot
.608 .19703 Mdot
.608 .19703 Mdot
.608 .19709 Mdot
.608 .19747 Mdot
.608 .19753 Mdot
.608 .19826 Mdot
.608 .19855 Mdot
.608 .19926 Mdot
.608 .20231 Mdot
.608 .20306 Mdot
.608 .20309 Mdot
.608 .20387 Mdot
.608 .20417 Mdot
.608 .20599 Mdot
.608 .20624 Mdot
.608 .20754 Mdot
.608 .20755 Mdot
.608 .20765 Mdot
.608 .20771 Mdot
.608 .20799 Mdot
.608 .20833 Mdot
.608 .20857 Mdot
.608 .20902 Mdot
.608 .2092 Mdot
.608 .20953 Mdot
.608 .20979 Mdot
.608 .20992 Mdot
.608 .21083 Mdot
.608 .21295 Mdot
.608 .21449 Mdot
.608 .21485 Mdot
.608 .21524 Mdot
.608 .21715 Mdot
.608 .21722 Mdot
.608 .2186 Mdot
.608 .21877 Mdot
.608 .22047 Mdot
.608 .22118 Mdot
.608 .22145 Mdot
.608 .22193 Mdot
.608 .22287 Mdot
.608 .22374 Mdot
.608 .22388 Mdot
.608 .2239 Mdot
.608 .22461 Mdot
.608 .22488 Mdot
.608 .22568 Mdot
.608 .22595 Mdot
.608 .22648 Mdot
.608 .22731 Mdot
.608 .22925 Mdot
.608 .22988 Mdot
.608 .23069 Mdot
.608 .23127 Mdot
.608 .23393 Mdot
.608 .23475 Mdot
.608 .23727 Mdot
.608 .23736 Mdot
.608 .23742 Mdot
.608 .24043 Mdot
.608 .2406 Mdot
.608 .24101 Mdot
.608 .24126 Mdot
.608 .24222 Mdot
.608 .24323 Mdot
.608 .24517 Mdot
.608 .24589 Mdot
.608 .24677 Mdot
.608 .24723 Mdot
.608 .24779 Mdot
.608 .24798 Mdot
.608 .24806 Mdot
.608 .24947 Mdot
.608 .2495 Mdot
.608 .24954 Mdot
.608 .25075 Mdot
.608 .25115 Mdot
.608 .25245 Mdot
.608 .25274 Mdot
.608 .25314 Mdot
.608 .25345 Mdot
.608 .25513 Mdot
.608 .25568 Mdot
.608 .25582 Mdot
.608 .25619 Mdot
.608 .2562 Mdot
.608 .25628 Mdot
.608 .25723 Mdot
.608 .25749 Mdot
.608 .25763 Mdot
.608 .25801 Mdot
.608 .25979 Mdot
.608 .2609 Mdot
.608 .26113 Mdot
.608 .26346 Mdot
.608 .26424 Mdot
.608 .26483 Mdot
.608 .26497 Mdot
.608 .26518 Mdot
.608 .26535 Mdot
.608 .26539 Mdot
.608 .26545 Mdot
.608 .26627 Mdot
.608 .26779 Mdot
.608 .26882 Mdot
.608 .2714 Mdot
.608 .2716 Mdot
.608 .27344 Mdot
.608 .27508 Mdot
.608 .27961 Mdot
.608 .28019 Mdot
.608 .28147 Mdot
.608 .28149 Mdot
.608 .28167 Mdot
.608 .28194 Mdot
.608 .28265 Mdot
.608 .28378 Mdot
.608 .2851 Mdot
.608 .28541 Mdot
.608 .28566 Mdot
.608 .28791 Mdot
.608 .28818 Mdot
.608 .29052 Mdot
.608 .29115 Mdot
.608 .29177 Mdot
.608 .29271 Mdot
.608 .29412 Mdot
.608 .29413 Mdot
.608 .29484 Mdot
.608 .29487 Mdot
.608 .297 Mdot
.608 .29773 Mdot
.608 .2991 Mdot
.608 .29963 Mdot
.608 .29969 Mdot
.608 .30001 Mdot
.608 .30007 Mdot
.608 .30075 Mdot
.608 .30085 Mdot
.608 .30243 Mdot
.608 .30282 Mdot
.608 .30325 Mdot
.608 .3037 Mdot
.608 .3037 Mdot
.608 .30416 Mdot
.608 .305 Mdot
.608 .30633 Mdot
.608 .30681 Mdot
.608 .30707 Mdot
.608 .30789 Mdot
.608 .30903 Mdot
.608 .30952 Mdot
.608 .31375 Mdot
.608 .31423 Mdot
.608 .31683 Mdot
.608 .3181 Mdot
.608 .3183 Mdot
.608 .32031 Mdot
.608 .32213 Mdot
.608 .32234 Mdot
.608 .32317 Mdot
.608 .32368 Mdot
.608 .32481 Mdot
.608 .32525 Mdot
.608 .32566 Mdot
.608 .32581 Mdot
.608 .32615 Mdot
.608 .32805 Mdot
.608 .33023 Mdot
.608 .33117 Mdot
.608 .33195 Mdot
.608 .33293 Mdot
.608 .33549 Mdot
.608 .33633 Mdot
.608 .33898 Mdot
.608 .33935 Mdot
.608 .3401 Mdot
.608 .34065 Mdot
.608 .34107 Mdot
.608 .34159 Mdot
.608 .34167 Mdot
.608 .34191 Mdot
.608 .34291 Mdot
.608 .34295 Mdot
.608 .34314 Mdot
.608 .3436 Mdot
.608 .34424 Mdot
.608 .3445 Mdot
.608 .34459 Mdot
.608 .34471 Mdot
.608 .34479 Mdot
.608 .34506 Mdot
.608 .34541 Mdot
.608 .34555 Mdot
.608 .34555 Mdot
.608 .34558 Mdot
.608 .34587 Mdot
.608 .34591 Mdot
.608 .34714 Mdot
.608 .34971 Mdot
.608 .34973 Mdot
.608 .35044 Mdot
.608 .35161 Mdot
.608 .35257 Mdot
.608 .35348 Mdot
.608 .35359 Mdot
.608 .35395 Mdot
.608 .35402 Mdot
.608 .35582 Mdot
.608 .3567 Mdot
.608 .3582 Mdot
.608 .359 Mdot
.608 .3591 Mdot
.608 .3613 Mdot
.608 .36276 Mdot
.608 .36318 Mdot
.608 .3636 Mdot
.608 .37036 Mdot
.608 .37247 Mdot
.608 .37307 Mdot
.608 .37332 Mdot
.608 .37341 Mdot
.608 .37344 Mdot
.608 .37407 Mdot
.608 .37408 Mdot
.608 .3741 Mdot
.608 .37463 Mdot
.608 .37537 Mdot
.608 .3755 Mdot
.608 .37567 Mdot
.608 .37653 Mdot
.608 .37683 Mdot
.608 .37699 Mdot
.608 .37699 Mdot
.608 .37754 Mdot
.608 .37776 Mdot
.608 .37852 Mdot
.608 .37898 Mdot
.608 .37908 Mdot
.608 .38005 Mdot
.608 .38037 Mdot
.608 .38083 Mdot
.608 .38084 Mdot
.608 .38087 Mdot
.608 .38121 Mdot
.608 .38183 Mdot
.608 .38224 Mdot
.608 .38337 Mdot
.608 .38475 Mdot
.608 .38654 Mdot
.608 .38726 Mdot
.608 .38727 Mdot
.608 .38744 Mdot
.608 .38772 Mdot
.608 .38866 Mdot
.608 .38888 Mdot
.608 .38974 Mdot
.608 .38984 Mdot
.608 .39096 Mdot
.608 .3912 Mdot
.608 .39208 Mdot
.608 .39236 Mdot
.608 .39393 Mdot
.608 .39427 Mdot
.608 .39455 Mdot
.608 .39458 Mdot
.608 .39531 Mdot
.608 .39546 Mdot
.608 .39563 Mdot
.608 .39563 Mdot
.608 .39579 Mdot
.608 .39676 Mdot
.608 .39715 Mdot
.608 .39774 Mdot
.608 .40036 Mdot
.608 .4016 Mdot
.608 .40224 Mdot
.608 .40232 Mdot
.608 .40261 Mdot
.608 .40334 Mdot
.608 .40348 Mdot
.608 .40365 Mdot
.608 .40432 Mdot
.608 .40541 Mdot
.608 .40568 Mdot
.608 .40602 Mdot
.608 .40691 Mdot
.608 .40869 Mdot
.608 .40904 Mdot
.608 .40912 Mdot
.608 .40948 Mdot
.608 .40955 Mdot
.608 .40992 Mdot
.608 .41001 Mdot
.608 .41008 Mdot
.608 .41011 Mdot
.608 .4102 Mdot
.608 .41037 Mdot
.608 .41037 Mdot
.608 .41091 Mdot
.608 .4118 Mdot
.608 .41244 Mdot
.608 .41276 Mdot
.608 .41307 Mdot
.608 .41311 Mdot
.608 .41323 Mdot
.608 .41326 Mdot
.608 .41467 Mdot
.608 .41622 Mdot
.608 .41635 Mdot
.608 .4165 Mdot
.608 .41969 Mdot
.608 .4198 Mdot
.608 .41981 Mdot
.608 .42002 Mdot
.608 .42002 Mdot
.608 .42003 Mdot
.608 .42021 Mdot
.608 .42046 Mdot
.608 .42085 Mdot
.608 .42126 Mdot
.608 .42151 Mdot
.608 .4217 Mdot
.608 .42229 Mdot
.608 .42262 Mdot
.608 .42314 Mdot
.608 .4246 Mdot
.608 .42491 Mdot
.608 .42499 Mdot
.608 .42528 Mdot
.608 .42531 Mdot
.608 .42569 Mdot
.608 .42668 Mdot
.608 .42689 Mdot
.608 .4269 Mdot
.608 .42714 Mdot
.608 .4272 Mdot
.608 .42725 Mdot
.608 .42725 Mdot
.608 .42763 Mdot
.608 .42776 Mdot
.608 .42947 Mdot
.608 .4295 Mdot
.608 .4296 Mdot
.608 .42984 Mdot
.608 .42995 Mdot
.608 .43017 Mdot
.608 .43063 Mdot
.608 .43104 Mdot
.608 .43165 Mdot
.608 .43176 Mdot
.608 .43179 Mdot
.608 .43206 Mdot
.608 .43209 Mdot
.608 .43212 Mdot
.608 .43221 Mdot
.608 .43221 Mdot
.608 .4327 Mdot
.608 .43291 Mdot
.608 .43314 Mdot
.608 .43318 Mdot
.608 .43319 Mdot
.608 .43367 Mdot
.608 .43419 Mdot
.608 .43429 Mdot
.608 .43537 Mdot
.608 .43541 Mdot
.608 .43541 Mdot
.608 .43549 Mdot
.608 .43555 Mdot
.608 .43564 Mdot
.608 .43591 Mdot
.608 .43606 Mdot
.608 .43626 Mdot
.608 .43655 Mdot
.608 .43716 Mdot
.608 .43718 Mdot
.608 .43728 Mdot
.608 .43729 Mdot
.608 .43742 Mdot
.608 .43776 Mdot
.608 .43784 Mdot
.608 .43794 Mdot
.608 .43796 Mdot
.608 .43796 Mdot
.608 .43809 Mdot
.608 .43872 Mdot
.608 .43873 Mdot
.608 .43876 Mdot
.608 .43885 Mdot
.608 .43888 Mdot
.608 .43896 Mdot
.608 .43912 Mdot
.608 .43926 Mdot
.608 .43947 Mdot
.608 .43951 Mdot
.608 .43961 Mdot
.608 .43962 Mdot
.608 .43963 Mdot
.608 .43967 Mdot
.608 .43967 Mdot
.608 .43983 Mdot
.608 .43999 Mdot
.608 .44 Mdot
.608 .44 Mdot
.608 .44017 Mdot
.608 .44038 Mdot
.608 .44076 Mdot
.608 .44077 Mdot
.608 .4408 Mdot
.608 .44082 Mdot
.608 .44095 Mdot
.608 .441 Mdot
.608 .44139 Mdot
.608 .44142 Mdot
.608 .44147 Mdot
.608 .44159 Mdot
.608 .44162 Mdot
.608 .44165 Mdot
.608 .44166 Mdot
.608 .44166 Mdot
.608 .44199 Mdot
.608 .44206 Mdot
.608 .44237 Mdot
.608 .4425 Mdot
.608 .44295 Mdot
.608 .44295 Mdot
.608 .44325 Mdot
.608 .44351 Mdot
.608 .44389 Mdot
.608 .44433 Mdot
.608 .44441 Mdot
.608 .44459 Mdot
.608 .44483 Mdot
.608 .44483 Mdot
.608 .44532 Mdot
.608 .44533 Mdot
.608 .44534 Mdot
.608 .44557 Mdot
.608 .4458 Mdot
.608 .4458 Mdot
.608 .44602 Mdot
.608 .44602 Mdot
.608 .44631 Mdot
.608 .44691 Mdot
.608 .44698 Mdot
.608 .44698 Mdot
.608 .44699 Mdot
.608 .44705 Mdot
.608 .4471 Mdot
.608 .44729 Mdot
.608 .44737 Mdot
.608 .44738 Mdot
.608 .44743 Mdot
.608 .44745 Mdot
.608 .4478 Mdot
.608 .44796 Mdot
.608 .44808 Mdot
.608 .44816 Mdot
.608 .44832 Mdot
.608 .44837 Mdot
.608 .44841 Mdot
.608 .44845 Mdot
.608 .44845 Mdot
.608 .44847 Mdot
.608 .44909 Mdot
.608 .44915 Mdot
.608 .44944 Mdot
.608 .44972 Mdot
.608 .44972 Mdot
.608 .44974 Mdot
.608 .44987 Mdot
.608 .45 Mdot
.608 .45027 Mdot
.608 .45027 Mdot
.608 .45032 Mdot
.608 .45034 Mdot
.608 .45035 Mdot
.608 .45051 Mdot
.608 .45052 Mdot
.608 .45059 Mdot
.608 .45093 Mdot
.608 .45116 Mdot
.608 .45142 Mdot
.608 .45154 Mdot
.608 .4516 Mdot
.608 .45174 Mdot
.608 .45179 Mdot
.608 .45181 Mdot
.608 .45276 Mdot
.608 .45284 Mdot
.608 .45305 Mdot
.608 .45305 Mdot
.608 .45308 Mdot
.608 .45311 Mdot
.608 .45324 Mdot
.608 .45325 Mdot
.608 .45336 Mdot
.608 .45391 Mdot
.608 .45412 Mdot
.608 .45414 Mdot
.608 .4543 Mdot
.608 .45434 Mdot
.608 .45451 Mdot
.608 .45531 Mdot
.608 .45559 Mdot
.608 .45577 Mdot
.608 .45609 Mdot
.608 .45619 Mdot
.608 .45633 Mdot
.608 .45655 Mdot
.608 .45676 Mdot
.608 .4569 Mdot
.608 .45699 Mdot
.608 .457 Mdot
.608 .457 Mdot
.608 .45711 Mdot
.608 .45712 Mdot
.608 .45718 Mdot
.608 .45889 Mdot
.608 .45896 Mdot
.608 .45904 Mdot
.608 .45986 Mdot
.608 .4606 Mdot
.608 .46062 Mdot
.608 .46068 Mdot
.608 .4607 Mdot
.608 .46086 Mdot
.608 .46104 Mdot
.608 .46137 Mdot
.608 .46183 Mdot
.608 .46212 Mdot
.608 .46212 Mdot
.608 .46221 Mdot
.608 .46225 Mdot
.608 .46227 Mdot
.608 .4623 Mdot
.608 .46235 Mdot
.608 .46255 Mdot
.608 .46258 Mdot
.608 .46277 Mdot
.608 .46281 Mdot
.608 .46299 Mdot
.608 .46391 Mdot
.608 .46454 Mdot
.608 .46468 Mdot
.608 .46524 Mdot
.608 .46558 Mdot
.608 .46567 Mdot
.608 .46574 Mdot
.608 .46611 Mdot
.608 .46626 Mdot
.608 .4663 Mdot
.608 .46663 Mdot
.608 .46725 Mdot
.608 .46857 Mdot
.608 .46886 Mdot
.608 .46906 Mdot
.608 .46954 Mdot
.608 .46962 Mdot
.608 .46962 Mdot
.608 .4697 Mdot
.608 .46978 Mdot
.608 .47014 Mdot
.608 .47016 Mdot
.608 .47029 Mdot
.608 .47046 Mdot
.608 .47124 Mdot
.608 .47137 Mdot
.608 .47181 Mdot
.608 .47192 Mdot
.608 .47247 Mdot
.608 .47252 Mdot
.608 .47294 Mdot
.608 .47305 Mdot
.608 .47351 Mdot
.608 .47364 Mdot
.608 .47372 Mdot
.608 .47373 Mdot
.608 .47408 Mdot
.608 .47494 Mdot
.608 .4756 Mdot
.608 .47614 Mdot
.608 .47634 Mdot
.608 .47664 Mdot
.608 .4768 Mdot
.608 .47681 Mdot
.608 .47682 Mdot
.608 .47703 Mdot
.608 .47719 Mdot
.608 .47765 Mdot
.608 .47769 Mdot
.608 .47791 Mdot
.608 .47827 Mdot
.608 .47837 Mdot
.608 .47863 Mdot
.608 .47863 Mdot
.608 .47871 Mdot
.608 .47885 Mdot
.608 .47925 Mdot
.608 .47933 Mdot
.608 .47939 Mdot
.608 .47974 Mdot
.608 .47999 Mdot
.608 .48 Mdot
.608 .48 Mdot
.608 .48029 Mdot
.608 .48031 Mdot
.608 .48035 Mdot
.608 .48047 Mdot
.608 .48075 Mdot
.608 .48173 Mdot
.608 .48482 Mdot
.608 .48501 Mdot
.608 .4852 Mdot
.608 .48586 Mdot
.608 .48686 Mdot
.608 .4869 Mdot
.608 .48726 Mdot
.608 .48793 Mdot
.608 .48832 Mdot
.608 .48912 Mdot
.608 .48915 Mdot
.608 .48931 Mdot
.608 .48936 Mdot
.608 .48976 Mdot
.608 .49019 Mdot
.608 .4907 Mdot
.608 .49101 Mdot
.608 .49102 Mdot
.608 .49215 Mdot
.608 .49268 Mdot
.608 .4927 Mdot
.608 .49282 Mdot
.608 .49284 Mdot
.608 .49284 Mdot
.608 .4929 Mdot
.608 .49305 Mdot
.608 .49316 Mdot
.608 .4932 Mdot
.608 .49325 Mdot
.608 .49329 Mdot
.608 .4934 Mdot
.608 .49368 Mdot
.608 .49388 Mdot
.608 .49396 Mdot
.608 .49398 Mdot
.608 .49441 Mdot
.608 .49451 Mdot
.608 .49455 Mdot
.608 .49477 Mdot
.608 .49495 Mdot
.608 .49519 Mdot
.608 .49551 Mdot
.608 .49567 Mdot
.608 .4968 Mdot
.608 .49716 Mdot
.608 .49824 Mdot
.608 .49865 Mdot
.608 .49898 Mdot
.608 .49937 Mdot
.608 .50029 Mdot
.608 .50108 Mdot
.608 .50122 Mdot
.608 .50128 Mdot
.608 .50145 Mdot
.608 .50164 Mdot
.608 .5021 Mdot
.608 .50231 Mdot
.608 .50265 Mdot
.608 .50274 Mdot
.608 .50349 Mdot
.608 .50431 Mdot
.608 .50439 Mdot
.608 .50491 Mdot
.608 .50597 Mdot
.608 .50617 Mdot
.608 .50787 Mdot
.608 .50807 Mdot
.608 .50852 Mdot
.608 .50885 Mdot
.608 .50896 Mdot
.608 .50914 Mdot
.608 .50968 Mdot
.608 .51001 Mdot
.608 .51019 Mdot
.608 .51019 Mdot
.608 .51037 Mdot
.608 .51054 Mdot
.608 .51069 Mdot
.608 .51132 Mdot
.608 .51136 Mdot
.608 .51163 Mdot
.608 .51165 Mdot
.608 .51178 Mdot
.608 .5118 Mdot
.608 .51201 Mdot
.608 .51255 Mdot
.608 .51284 Mdot
.608 .51366 Mdot
.608 .51368 Mdot
.608 .51396 Mdot
.608 .51396 Mdot
.608 .51451 Mdot
.608 .51487 Mdot
.608 .51511 Mdot
.608 .51536 Mdot
.608 .51626 Mdot
.608 .51636 Mdot
.608 .51723 Mdot
.608 .51732 Mdot
.608 .51744 Mdot
.608 .51795 Mdot
.608 .51838 Mdot
.608 .51865 Mdot
.608 .51875 Mdot
.608 .51882 Mdot
.608 .51883 Mdot
.608 .51931 Mdot
.608 .51954 Mdot
.608 .52125 Mdot
.608 .52186 Mdot
.608 .52255 Mdot
.608 .52263 Mdot
.608 .52359 Mdot
.608 .52397 Mdot
.608 .52453 Mdot
.608 .52484 Mdot
.608 .52486 Mdot
.608 .52487 Mdot
.608 .52494 Mdot
.608 .52501 Mdot
.608 .52507 Mdot
.608 .52529 Mdot
.608 .52557 Mdot
.608 .52643 Mdot
.608 .52651 Mdot
.608 .52692 Mdot
.608 .52757 Mdot
.608 .52771 Mdot
.608 .52776 Mdot
.608 .52786 Mdot
.608 .52821 Mdot
.608 .52823 Mdot
.608 .52824 Mdot
.608 .52837 Mdot
.608 .52842 Mdot
.608 .52862 Mdot
.608 .52923 Mdot
.608 .52935 Mdot
.608 .52949 Mdot
.608 .52959 Mdot
.608 .53007 Mdot
.608 .53021 Mdot
.608 .53064 Mdot
.608 .53066 Mdot
.608 .53067 Mdot
.608 .53118 Mdot
.608 .53121 Mdot
.608 .53127 Mdot
.608 .53148 Mdot
.608 .53164 Mdot
.608 .53196 Mdot
.608 .53222 Mdot
.608 .53291 Mdot
.608 .53327 Mdot
.608 .53361 Mdot
.608 .5337 Mdot
.608 .53384 Mdot
.608 .5339 Mdot
.608 .53497 Mdot
.608 .53499 Mdot
.608 .53502 Mdot
.608 .53591 Mdot
.608 .5362 Mdot
.608 .53713 Mdot
.608 .53733 Mdot
.608 .53762 Mdot
.608 .53784 Mdot
.608 .53851 Mdot
.608 .5388 Mdot
.608 .53899 Mdot
.608 .53908 Mdot
.608 .53936 Mdot
.608 .53945 Mdot
.608 .5397 Mdot
.608 .5397 Mdot
.608 .53975 Mdot
.608 .54005 Mdot
.608 .54038 Mdot
.608 .54054 Mdot
.608 .54064 Mdot
.608 .54088 Mdot
.608 .54147 Mdot
.608 .54153 Mdot
.608 .542 Mdot
.608 .54202 Mdot
.608 .54267 Mdot
.608 .54281 Mdot
.608 .54293 Mdot
.608 .54346 Mdot
.608 .54418 Mdot
.608 .54449 Mdot
.608 .54453 Mdot
.608 .54462 Mdot
.608 .54473 Mdot
.608 .54479 Mdot
.608 .54494 Mdot
.608 .54502 Mdot
.608 .54514 Mdot
.608 .54523 Mdot
.608 .54525 Mdot
.608 .54529 Mdot
.608 .54529 Mdot
.608 .54573 Mdot
.608 .54581 Mdot
.608 .54643 Mdot
.608 .54653 Mdot
.608 .54679 Mdot
.608 .5468 Mdot
.608 .54705 Mdot
.608 .54807 Mdot
.608 .54831 Mdot
.608 .5484 Mdot
.608 .54865 Mdot
.608 .54867 Mdot
.608 .5488 Mdot
.608 .54882 Mdot
.608 .54882 Mdot
.608 .54888 Mdot
.608 .54904 Mdot
.608 .54916 Mdot
.608 .54919 Mdot
.608 .54925 Mdot
.608 .54925 Mdot
.608 .54929 Mdot
.608 .5494 Mdot
.608 .54968 Mdot
.608 .54988 Mdot
.608 .54996 Mdot
.608 .54996 Mdot
.608 .54998 Mdot
.608 .5504 Mdot
.608 .55049 Mdot
.608 .55053 Mdot
.608 .55074 Mdot
.608 .55091 Mdot
.608 .55112 Mdot
.608 .55141 Mdot
.608 .55155 Mdot
.608 .55176 Mdot
.608 .55197 Mdot
.608 .55242 Mdot
.608 .55243 Mdot
.608 .55249 Mdot
.608 .5525 Mdot
.608 .55258 Mdot
.608 .55278 Mdot
.608 .55282 Mdot
.608 .55318 Mdot
.608 .55359 Mdot
.608 .55359 Mdot
.608 .55368 Mdot
.608 .55376 Mdot
.608 .55388 Mdot
.608 .5541 Mdot
.608 .55436 Mdot
.608 .55438 Mdot
.608 .55445 Mdot
.608 .5549 Mdot
.608 .55503 Mdot
.608 .55517 Mdot
.608 .55531 Mdot
.608 .55534 Mdot
.608 .55541 Mdot
.608 .55544 Mdot
.608 .55551 Mdot
.608 .55552 Mdot
.608 .55561 Mdot
.608 .55578 Mdot
.608 .55578 Mdot
.608 .55583 Mdot
.608 .55591 Mdot
.608 .55592 Mdot
.608 .55592 Mdot
.608 .55606 Mdot
.608 .5561 Mdot
.608 .55627 Mdot
.608 .55637 Mdot
.608 .55637 Mdot
.608 .55656 Mdot
.608 .55662 Mdot
.608 .55663 Mdot
.608 .55663 Mdot
.608 .55666 Mdot
.608 .55666 Mdot
.608 .55667 Mdot
.608 .55675 Mdot
.608 .55675 Mdot
.608 .55679 Mdot
.608 .5569 Mdot
.608 .55693 Mdot
.608 .55696 Mdot
.608 .557 Mdot
.608 .557 Mdot
.608 .557 Mdot
.608 .55702 Mdot
.608 .55703 Mdot
.608 .55707 Mdot
.608 .55713 Mdot
.608 .55714 Mdot
.608 .55715 Mdot
.608 .55716 Mdot
.608 .55717 Mdot
.608 .55717 Mdot
.61 .17083 Mdot
.61 .17083 Mdot
.61 .17084 Mdot
.61 .17085 Mdot
.61 .17085 Mdot
.61 .17087 Mdot
.61 .17088 Mdot
.61 .1709 Mdot
.61 .17091 Mdot
.61 .17091 Mdot
.61 .17099 Mdot
.61 .17101 Mdot
.61 .17108 Mdot
.61 .17109 Mdot
.61 .17113 Mdot
.61 .1712 Mdot
.61 .17122 Mdot
.61 .17126 Mdot
.61 .17134 Mdot
.61 .17135 Mdot
.61 .1714 Mdot
.61 .17143 Mdot
.61 .17143 Mdot
.61 .17153 Mdot
.61 .17203 Mdot
.61 .17225 Mdot
.61 .17229 Mdot
.61 .17239 Mdot
.61 .17242 Mdot
.61 .17255 Mdot
.61 .17258 Mdot
.61 .17271 Mdot
.61 .17273 Mdot
.61 .17286 Mdot
.61 .1729 Mdot
.61 .17293 Mdot
.61 .17297 Mdot
.61 .17298 Mdot
.61 .17323 Mdot
.61 .17324 Mdot
.61 .17331 Mdot
.61 .17332 Mdot
.61 .17341 Mdot
.61 .17353 Mdot
.61 .17371 Mdot
.61 .17376 Mdot
.61 .17383 Mdot
.61 .17394 Mdot
.61 .17394 Mdot
.61 .17425 Mdot
.61 .17437 Mdot
.61 .17469 Mdot
.61 .1747 Mdot
.61 .17488 Mdot
.61 .17514 Mdot
.61 .17532 Mdot
.61 .1762 Mdot
.61 .17623 Mdot
.61 .17654 Mdot
.61 .17679 Mdot
.61 .17821 Mdot
.61 .17847 Mdot
.61 .17957 Mdot
.61 .18017 Mdot
.61 .18027 Mdot
.61 .18082 Mdot
.61 .18099 Mdot
.61 .18258 Mdot
.61 .18292 Mdot
.61 .18353 Mdot
.61 .1837 Mdot
.61 .18378 Mdot
.61 .1838 Mdot
.61 .18392 Mdot
.61 .18425 Mdot
.61 .18454 Mdot
.61 .18539 Mdot
.61 .18689 Mdot
.61 .18868 Mdot
.61 .1902 Mdot
.61 .19026 Mdot
.61 .19206 Mdot
.61 .19325 Mdot
.61 .19553 Mdot
.61 .19818 Mdot
.61 .19857 Mdot
.61 .1988 Mdot
.61 .19899 Mdot
.61 .19928 Mdot
.61 .20036 Mdot
.61 .20143 Mdot
.61 .2026 Mdot
.61 .2029 Mdot
.61 .20325 Mdot
.61 .20636 Mdot
.61 .21224 Mdot
.61 .21442 Mdot
.61 .21531 Mdot
.61 .21658 Mdot
.61 .21681 Mdot
.61 .21752 Mdot
.61 .21846 Mdot
.61 .21875 Mdot
.61 .21901 Mdot
.61 .21927 Mdot
.61 .21957 Mdot
.61 .22012 Mdot
.61 .22065 Mdot
.61 .22204 Mdot
.61 .22409 Mdot
.61 .22411 Mdot
.61 .22439 Mdot
.61 .22518 Mdot
.61 .2255 Mdot
.61 .22562 Mdot
.61 .2259 Mdot
.61 .22677 Mdot
.61 .22765 Mdot
.61 .22817 Mdot
.61 .22845 Mdot
.61 .22873 Mdot
.61 .22985 Mdot
.61 .22996 Mdot
.61 .23318 Mdot
.61 .23386 Mdot
.61 .23493 Mdot
.61 .23591 Mdot
.61 .23601 Mdot
.61 .23985 Mdot
.61 .23991 Mdot
.61 .23998 Mdot
.61 .24124 Mdot
.61 .24133 Mdot
.61 .24177 Mdot
.61 .24189 Mdot
.61 .24227 Mdot
.61 .2431 Mdot
.61 .24333 Mdot
.61 .24355 Mdot
.61 .24463 Mdot
.61 .24465 Mdot
.61 .24638 Mdot
.61 .24696 Mdot
.61 .24719 Mdot
.61 .2474 Mdot
.61 .24744 Mdot
.61 .24989 Mdot
.61 .2504 Mdot
.61 .25091 Mdot
.61 .25282 Mdot
.61 .25371 Mdot
.61 .25398 Mdot
.61 .25501 Mdot
.61 .25523 Mdot
.61 .2558 Mdot
.61 .25761 Mdot
.61 .25819 Mdot
.61 .25835 Mdot
.61 .25849 Mdot
.61 .25863 Mdot
.61 .26582 Mdot
.61 .2678 Mdot
.61 .26803 Mdot
.61 .27046 Mdot
.61 .27095 Mdot
.61 .27122 Mdot
.61 .27314 Mdot
.61 .27486 Mdot
.61 .27579 Mdot
.61 .2773 Mdot
.61 .27858 Mdot
.61 .28016 Mdot
.61 .28155 Mdot
.61 .28238 Mdot
.61 .28299 Mdot
.61 .28311 Mdot
.61 .28322 Mdot
.61 .28339 Mdot
.61 .28401 Mdot
.61 .28437 Mdot
.61 .28631 Mdot
.61 .28695 Mdot
.61 .28707 Mdot
.61 .28778 Mdot
.61 .28918 Mdot
.61 .2915 Mdot
.61 .29234 Mdot
.61 .29382 Mdot
.61 .29458 Mdot
.61 .2949 Mdot
.61 .29574 Mdot
.61 .29659 Mdot
.61 .29674 Mdot
.61 .29684 Mdot
.61 .29723 Mdot
.61 .2975 Mdot
.61 .29771 Mdot
.61 .29789 Mdot
.61 .29851 Mdot
.61 .29863 Mdot
.61 .2987 Mdot
.61 .2988 Mdot
.61 .29913 Mdot
.61 .29952 Mdot
.61 .29997 Mdot
.61 .30007 Mdot
.61 .30346 Mdot
.61 .30391 Mdot
.61 .3043 Mdot
.61 .30695 Mdot
.61 .3071 Mdot
.61 .30734 Mdot
.61 .30746 Mdot
.61 .30782 Mdot
.61 .30811 Mdot
.61 .30912 Mdot
.61 .3096 Mdot
.61 .3101 Mdot
.61 .31111 Mdot
.61 .31195 Mdot
.61 .31204 Mdot
.61 .31264 Mdot
.61 .31268 Mdot
.61 .31297 Mdot
.61 .3134 Mdot
.61 .31348 Mdot
.61 .31421 Mdot
.61 .31442 Mdot
.61 .31457 Mdot
.61 .31504 Mdot
.61 .31687 Mdot
.61 .31756 Mdot
.61 .31768 Mdot
.61 .31842 Mdot
.61 .31885 Mdot
.61 .3195 Mdot
.61 .32012 Mdot
.61 .3203 Mdot
.61 .32166 Mdot
.61 .32167 Mdot
.61 .3225 Mdot
.61 .32311 Mdot
.61 .32392 Mdot
.61 .32564 Mdot
.61 .32616 Mdot
.61 .32852 Mdot
.61 .33192 Mdot
.61 .3349 Mdot
.61 .33536 Mdot
.61 .34078 Mdot
.61 .34724 Mdot
.61 .34737 Mdot
.61 .34832 Mdot
.61 .34904 Mdot
.61 .34981 Mdot
.61 .35574 Mdot
.61 .357 Mdot
.61 .3575 Mdot
.61 .35821 Mdot
.61 .35834 Mdot
.61 .35873 Mdot
.61 .35924 Mdot
.61 .36014 Mdot
.61 .36116 Mdot
.61 .36225 Mdot
.61 .36239 Mdot
.61 .36296 Mdot
.61 .36317 Mdot
.61 .36361 Mdot
.61 .36446 Mdot
.61 .3646 Mdot
.61 .36516 Mdot
.61 .36679 Mdot
.61 .3681 Mdot
.61 .36995 Mdot
.61 .36998 Mdot
.61 .37001 Mdot
.61 .37089 Mdot
.61 .37145 Mdot
.61 .37155 Mdot
.61 .37214 Mdot
.61 .37215 Mdot
.61 .37293 Mdot
.61 .37319 Mdot
.61 .37329 Mdot
.61 .37704 Mdot
.61 .37781 Mdot
.61 .37824 Mdot
.61 .38122 Mdot
.61 .3833 Mdot
.61 .38341 Mdot
.61 .38522 Mdot
.61 .38582 Mdot
.61 .38632 Mdot
.61 .38693 Mdot
.61 .38779 Mdot
.61 .38803 Mdot
.61 .38812 Mdot
.61 .38842 Mdot
.61 .38856 Mdot
.61 .38954 Mdot
.61 .39158 Mdot
.61 .39316 Mdot
.61 .39322 Mdot
.61 .39326 Mdot
.61 .3934 Mdot
.61 .3935 Mdot
.61 .39358 Mdot
.61 .39387 Mdot
.61 .39398 Mdot
.61 .3941 Mdot
.61 .39425 Mdot
.61 .39441 Mdot
.61 .39445 Mdot
.61 .39569 Mdot
.61 .39586 Mdot
.61 .39696 Mdot
.61 .39701 Mdot
.61 .3971 Mdot
.61 .39714 Mdot
.61 .39728 Mdot
.61 .39774 Mdot
.61 .3981 Mdot
.61 .39879 Mdot
.61 .39901 Mdot
.61 .39913 Mdot
.61 .39931 Mdot
.61 .39965 Mdot
.61 .3997 Mdot
.61 .39987 Mdot
.61 .40076 Mdot
.61 .4008 Mdot
.61 .40107 Mdot
.61 .40167 Mdot
.61 .40173 Mdot
.61 .40221 Mdot
.61 .40222 Mdot
.61 .40251 Mdot
.61 .403 Mdot
.61 .40379 Mdot
.61 .40461 Mdot
.61 .40683 Mdot
.61 .40699 Mdot
.61 .40885 Mdot
.61 .41106 Mdot
.61 .41111 Mdot
.61 .41143 Mdot
.61 .41194 Mdot
.61 .41395 Mdot
.61 .41437 Mdot
.61 .41454 Mdot
.61 .41482 Mdot
.61 .41495 Mdot
.61 .41578 Mdot
.61 .41614 Mdot
.61 .41619 Mdot
.61 .41638 Mdot
.61 .41645 Mdot
.61 .41689 Mdot
.61 .41693 Mdot
.61 .41712 Mdot
.61 .41811 Mdot
.61 .41873 Mdot
.61 .41874 Mdot
.61 .41927 Mdot
.61 .41947 Mdot
.61 .41973 Mdot
.61 .41982 Mdot
.61 .42111 Mdot
.61 .42136 Mdot
.61 .42151 Mdot
.61 .4232 Mdot
.61 .42324 Mdot
.61 .42385 Mdot
.61 .42404 Mdot
.61 .42421 Mdot
.61 .42442 Mdot
.61 .42471 Mdot
.61 .42481 Mdot
.61 .42492 Mdot
.61 .42496 Mdot
.61 .42529 Mdot
.61 .4265 Mdot
.61 .42652 Mdot
.61 .42653 Mdot
.61 .42658 Mdot
.61 .42662 Mdot
.61 .42664 Mdot
.61 .42674 Mdot
.61 .42678 Mdot
.61 .42682 Mdot
.61 .42687 Mdot
.61 .42692 Mdot
.61 .42693 Mdot
.61 .42735 Mdot
.61 .4274 Mdot
.61 .42779 Mdot
.61 .42782 Mdot
.61 .42788 Mdot
.61 .42804 Mdot
.61 .42816 Mdot
.61 .42839 Mdot
.61 .42846 Mdot
.61 .4285 Mdot
.61 .42856 Mdot
.61 .42868 Mdot
.61 .42869 Mdot
.61 .42875 Mdot
.61 .42905 Mdot
.61 .42906 Mdot
.61 .42915 Mdot
.61 .42937 Mdot
.61 .42954 Mdot
.61 .42954 Mdot
.61 .42964 Mdot
.61 .4298 Mdot
.61 .43007 Mdot
.61 .43034 Mdot
.61 .43109 Mdot
.61 .43177 Mdot
.61 .43251 Mdot
.61 .43253 Mdot
.61 .43281 Mdot
.61 .43363 Mdot
.61 .43369 Mdot
.61 .43383 Mdot
.61 .43431 Mdot
.61 .43448 Mdot
.61 .43456 Mdot
.61 .4349 Mdot
.61 .43511 Mdot
.61 .43529 Mdot
.61 .43536 Mdot
.61 .43548 Mdot
.61 .43592 Mdot
.61 .436 Mdot
.61 .43605 Mdot
.61 .43663 Mdot
.61 .43664 Mdot
.61 .43685 Mdot
.61 .43692 Mdot
.61 .43698 Mdot
.61 .43714 Mdot
.61 .43718 Mdot
.61 .43723 Mdot
.61 .43734 Mdot
.61 .43776 Mdot
.61 .43777 Mdot
.61 .43779 Mdot
.61 .4378 Mdot
.61 .43781 Mdot
.61 .43784 Mdot
.61 .43785 Mdot
.61 .43788 Mdot
.61 .4379 Mdot
.61 .43791 Mdot
.61 .43805 Mdot
.61 .43807 Mdot
.61 .4382 Mdot
.61 .43821 Mdot
.61 .43823 Mdot
.61 .43828 Mdot
.61 .43832 Mdot
.61 .4384 Mdot
.61 .43843 Mdot
.61 .43844 Mdot
.61 .4385 Mdot
.61 .43851 Mdot
.61 .43853 Mdot
.61 .43863 Mdot
.61 .43864 Mdot
.61 .43867 Mdot
.61 .43874 Mdot
.61 .4388 Mdot
.61 .4388 Mdot
.61 .43883 Mdot
.61 .43889 Mdot
.61 .43898 Mdot
.61 .43908 Mdot
.61 .43933 Mdot
.61 .43983 Mdot
.61 .43992 Mdot
.61 .44021 Mdot
.61 .44023 Mdot
.61 .44028 Mdot
.61 .44044 Mdot
.61 .4405 Mdot
.61 .44053 Mdot
.61 .44065 Mdot
.61 .44072 Mdot
.61 .44078 Mdot
.61 .44081 Mdot
.61 .44085 Mdot
.61 .441 Mdot
.61 .44103 Mdot
.61 .44105 Mdot
.61 .44125 Mdot
.61 .44132 Mdot
.61 .44135 Mdot
.61 .44137 Mdot
.61 .44142 Mdot
.61 .44144 Mdot
.61 .44145 Mdot
.61 .44188 Mdot
.61 .4419 Mdot
.61 .44191 Mdot
.61 .44194 Mdot
.61 .44201 Mdot
.61 .44203 Mdot
.61 .4421 Mdot
.61 .44218 Mdot
.61 .44239 Mdot
.61 .4425 Mdot
.61 .4426 Mdot
.61 .44264 Mdot
.61 .4427 Mdot
.61 .44278 Mdot
.61 .44291 Mdot
.61 .44292 Mdot
.61 .44308 Mdot
.61 .4431 Mdot
.61 .44329 Mdot
.61 .44344 Mdot
.61 .44357 Mdot
.61 .44362 Mdot
.61 .44381 Mdot
.61 .44389 Mdot
.61 .44397 Mdot
.61 .44419 Mdot
.61 .44435 Mdot
.61 .44438 Mdot
.61 .44444 Mdot
.61 .44468 Mdot
.61 .44477 Mdot
.61 .44479 Mdot
.61 .44507 Mdot
.61 .44508 Mdot
.61 .44512 Mdot
.61 .44529 Mdot
.61 .44541 Mdot
.61 .44543 Mdot
.61 .44553 Mdot
.61 .44559 Mdot
.61 .44577 Mdot
.61 .44595 Mdot
.61 .44629 Mdot
.61 .44644 Mdot
.61 .44655 Mdot
.61 .44658 Mdot
.61 .4467 Mdot
.61 .44676 Mdot
.61 .44677 Mdot
.61 .44681 Mdot
.61 .44688 Mdot
.61 .44693 Mdot
.61 .44744 Mdot
.61 .44751 Mdot
.61 .44754 Mdot
.61 .44756 Mdot
.61 .44766 Mdot
.61 .44769 Mdot
.61 .44773 Mdot
.61 .44785 Mdot
.61 .44785 Mdot
.61 .44819 Mdot
.61 .44821 Mdot
.61 .44826 Mdot
.61 .44852 Mdot
.61 .44858 Mdot
.61 .44862 Mdot
.61 .44872 Mdot
.61 .44885 Mdot
.61 .44904 Mdot
.61 .44908 Mdot
.61 .44918 Mdot
.61 .44946 Mdot
.61 .44954 Mdot
.61 .44957 Mdot
.61 .45003 Mdot
.61 .45019 Mdot
.61 .4502 Mdot
.61 .45062 Mdot
.61 .451 Mdot
.61 .45142 Mdot
.61 .45158 Mdot
.61 .45173 Mdot
.61 .45182 Mdot
.61 .45187 Mdot
.61 .45187 Mdot
.61 .45196 Mdot
.61 .45209 Mdot
.61 .45214 Mdot
.61 .45215 Mdot
.61 .45231 Mdot
.61 .45234 Mdot
.61 .45235 Mdot
.61 .45242 Mdot
.61 .45245 Mdot
.61 .45247 Mdot
.61 .45251 Mdot
.61 .45264 Mdot
.61 .45271 Mdot
.61 .4528 Mdot
.61 .45283 Mdot
.61 .45285 Mdot
.61 .45306 Mdot
.61 .45309 Mdot
.61 .45332 Mdot
.61 .45333 Mdot
.61 .45336 Mdot
.61 .45338 Mdot
.61 .45341 Mdot
.61 .45343 Mdot
.61 .45348 Mdot
.61 .4535 Mdot
.61 .45351 Mdot
.61 .45354 Mdot
.61 .45355 Mdot
.61 .45356 Mdot
.61 .45423 Mdot
.61 .45441 Mdot
.61 .45443 Mdot
.61 .45449 Mdot
.61 .45455 Mdot
.61 .4547 Mdot
.61 .45482 Mdot
.61 .45491 Mdot
.61 .45502 Mdot
.61 .45535 Mdot
.61 .45537 Mdot
.61 .45629 Mdot
.61 .45637 Mdot
.61 .45651 Mdot
.61 .4572 Mdot
.61 .45725 Mdot
.61 .45739 Mdot
.61 .4575 Mdot
.61 .45778 Mdot
.61 .45779 Mdot
.61 .45812 Mdot
.61 .45865 Mdot
.61 .45875 Mdot
.61 .45877 Mdot
.61 .45901 Mdot
.61 .45904 Mdot
.61 .45914 Mdot
.61 .45917 Mdot
.61 .45936 Mdot
.61 .4598 Mdot
.61 .45987 Mdot
.61 .46002 Mdot
.61 .46011 Mdot
.61 .46033 Mdot
.61 .46139 Mdot
.61 .46166 Mdot
.61 .46182 Mdot
.61 .46185 Mdot
.61 .46299 Mdot
.61 .46396 Mdot
.61 .46404 Mdot
.61 .46518 Mdot
.61 .4656 Mdot
.61 .466 Mdot
.61 .46625 Mdot
.61 .4664 Mdot
.61 .4664 Mdot
.61 .46664 Mdot
.61 .46668 Mdot
.61 .46698 Mdot
.61 .46711 Mdot
.61 .46713 Mdot
.61 .46758 Mdot
.61 .46767 Mdot
.61 .46769 Mdot
.61 .46786 Mdot
.61 .46796 Mdot
.61 .46802 Mdot
.61 .46812 Mdot
.61 .46847 Mdot
.61 .46865 Mdot
.61 .46888 Mdot
.61 .46895 Mdot
.61 .46897 Mdot
.61 .46901 Mdot
.61 .46904 Mdot
.61 .46959 Mdot
.61 .46967 Mdot
.61 .47029 Mdot
.61 .47031 Mdot
.61 .47039 Mdot
.61 .47046 Mdot
.61 .47052 Mdot
.61 .47057 Mdot
.61 .47072 Mdot
.61 .47076 Mdot
.61 .4708 Mdot
.61 .47088 Mdot
.61 .47089 Mdot
.61 .47092 Mdot
.61 .4717 Mdot
.61 .4727 Mdot
.61 .47318 Mdot
.61 .47324 Mdot
.61 .47339 Mdot
.61 .47343 Mdot
.61 .47355 Mdot
.61 .47396 Mdot
.61 .47426 Mdot
.61 .4745 Mdot
.61 .47479 Mdot
.61 .47566 Mdot
.61 .47571 Mdot
.61 .4767 Mdot
.61 .47812 Mdot
.61 .47832 Mdot
.61 .47868 Mdot
.61 .48044 Mdot
.61 .48049 Mdot
.61 .48061 Mdot
.61 .48097 Mdot
.61 .48097 Mdot
.61 .48125 Mdot
.61 .48129 Mdot
.61 .48155 Mdot
.61 .48196 Mdot
.61 .48197 Mdot
.61 .48198 Mdot
.61 .48284 Mdot
.61 .48344 Mdot
.61 .48418 Mdot
.61 .48444 Mdot
.61 .4845 Mdot
.61 .48489 Mdot
.61 .48509 Mdot
.61 .48518 Mdot
.61 .48544 Mdot
.61 .4855 Mdot
.61 .48599 Mdot
.61 .48645 Mdot
.61 .48686 Mdot
.61 .48709 Mdot
.61 .48726 Mdot
.61 .48732 Mdot
.61 .48764 Mdot
.61 .48786 Mdot
.61 .48842 Mdot
.61 .49104 Mdot
.61 .49138 Mdot
.61 .49169 Mdot
.61 .49211 Mdot
.61 .49216 Mdot
.61 .49496 Mdot
.61 .49727 Mdot
.61 .49746 Mdot
.61 .49872 Mdot
.61 .50015 Mdot
.61 .50113 Mdot
.61 .50134 Mdot
.61 .50206 Mdot
.61 .50239 Mdot
.61 .50264 Mdot
.61 .50298 Mdot
.61 .50299 Mdot
.61 .50355 Mdot
.61 .50362 Mdot
.61 .50387 Mdot
.61 .50414 Mdot
.61 .50432 Mdot
.61 .50462 Mdot
.61 .50467 Mdot
.61 .50495 Mdot
.61 .50569 Mdot
.61 .50588 Mdot
.61 .50594 Mdot
.61 .50603 Mdot
.61 .50633 Mdot
.61 .50636 Mdot
.61 .50653 Mdot
.61 .50665 Mdot
.61 .50667 Mdot
.61 .50691 Mdot
.61 .50694 Mdot
.61 .50728 Mdot
.61 .50769 Mdot
.61 .50789 Mdot
.61 .50808 Mdot
.61 .50849 Mdot
.61 .5086 Mdot
.61 .50875 Mdot
.61 .50879 Mdot
.61 .50889 Mdot
.61 .50895 Mdot
.61 .51001 Mdot
.61 .51016 Mdot
.61 .51034 Mdot
.61 .51168 Mdot
.61 .51172 Mdot
.61 .51189 Mdot
.61 .51204 Mdot
.61 .51218 Mdot
.61 .51222 Mdot
.61 .51224 Mdot
.61 .51229 Mdot
.61 .51253 Mdot
.61 .5126 Mdot
.61 .51268 Mdot
.61 .51279 Mdot
.61 .51294 Mdot
.61 .51298 Mdot
.61 .51304 Mdot
.61 .51337 Mdot
.61 .5137 Mdot
.61 .51383 Mdot
.61 .51412 Mdot
.61 .5147 Mdot
.61 .51502 Mdot
.61 .51592 Mdot
.61 .51646 Mdot
.61 .51673 Mdot
.61 .51678 Mdot
.61 .51702 Mdot
.61 .51777 Mdot
.61 .5179 Mdot
.61 .51814 Mdot
.61 .51821 Mdot
.61 .51825 Mdot
.61 .51829 Mdot
.61 .51853 Mdot
.61 .51884 Mdot
.61 .51937 Mdot
.61 .51997 Mdot
.61 .52045 Mdot
.61 .52102 Mdot
.61 .52137 Mdot
.61 .52202 Mdot
.61 .52273 Mdot
.61 .52283 Mdot
.61 .52302 Mdot
.61 .52392 Mdot
.61 .52401 Mdot
.61 .52474 Mdot
.61 .52739 Mdot
.61 .52744 Mdot
.61 .52749 Mdot
.61 .52755 Mdot
.61 .52776 Mdot
.61 .52842 Mdot
.61 .52862 Mdot
.61 .5287 Mdot
.61 .52908 Mdot
.61 .52917 Mdot
.61 .5295 Mdot
.61 .53019 Mdot
.61 .53037 Mdot
.61 .53056 Mdot
.61 .53144 Mdot
.61 .53145 Mdot
.61 .53153 Mdot
.61 .53161 Mdot
.61 .53182 Mdot
.61 .53243 Mdot
.61 .53244 Mdot
.61 .53283 Mdot
.61 .53291 Mdot
.61 .53299 Mdot
.61 .53328 Mdot
.61 .53342 Mdot
.61 .53346 Mdot
.61 .53362 Mdot
.61 .53365 Mdot
.61 .5341 Mdot
.61 .53412 Mdot
.61 .53414 Mdot
.61 .5355 Mdot
.61 .53553 Mdot
.61 .53588 Mdot
.61 .53626 Mdot
.61 .5365 Mdot
.61 .53762 Mdot
.61 .53766 Mdot
.61 .53805 Mdot
.61 .53815 Mdot
.61 .53825 Mdot
.61 .53843 Mdot
.61 .53873 Mdot
.61 .53904 Mdot
.61 .53913 Mdot
.61 .53917 Mdot
.61 .53928 Mdot
.61 .53956 Mdot
.61 .53965 Mdot
.61 .53966 Mdot
.61 .54037 Mdot
.61 .54085 Mdot
.61 .54103 Mdot
.61 .54122 Mdot
.61 .54132 Mdot
.61 .54141 Mdot
.61 .5415 Mdot
.61 .5416 Mdot
.61 .54193 Mdot
.61 .54217 Mdot
.61 .54225 Mdot
.61 .54268 Mdot
.61 .54298 Mdot
.61 .54373 Mdot
.61 .54572 Mdot
.61 .54676 Mdot
.61 .54688 Mdot
.61 .54698 Mdot
.61 .54737 Mdot
.61 .54773 Mdot
.61 .54809 Mdot
.61 .54819 Mdot
.61 .54825 Mdot
.61 .54833 Mdot
.61 .54846 Mdot
.61 .54934 Mdot
.61 .5501 Mdot
.61 .55049 Mdot
.61 .55109 Mdot
.61 .55111 Mdot
.61 .5516 Mdot
.61 .55219 Mdot
.61 .55268 Mdot
.61 .55296 Mdot
.61 .55306 Mdot
.61 .55316 Mdot
.61 .5532 Mdot
.61 .55321 Mdot
.61 .55324 Mdot
.61 .55329 Mdot
.61 .55349 Mdot
.61 .5536 Mdot
.61 .55412 Mdot
.61 .55418 Mdot
.61 .55436 Mdot
.61 .55439 Mdot
.61 .55458 Mdot
.61 .55494 Mdot
.61 .55502 Mdot
.61 .55549 Mdot
.61 .55557 Mdot
.61 .55567 Mdot
.61 .55568 Mdot
.61 .55596 Mdot
.61 .55602 Mdot
.61 .5561 Mdot
.61 .55616 Mdot
.61 .55616 Mdot
.61 .55627 Mdot
.61 .5563 Mdot
.61 .5564 Mdot
.61 .55641 Mdot
.61 .55644 Mdot
.61 .55646 Mdot
.61 .55648 Mdot
.61 .55654 Mdot
.61 .55658 Mdot
.61 .55661 Mdot
.61 .55661 Mdot
.61 .55663 Mdot
.61 .55664 Mdot
.61 .55672 Mdot
.61 .55672 Mdot
.61 .55673 Mdot
.61 .55674 Mdot
.61 .55675 Mdot
.61 .5568 Mdot
.61 .5568 Mdot
.61 .55684 Mdot
.61 .55685 Mdot
.61 .5569 Mdot
.61 .55691 Mdot
.61 .55694 Mdot
.61 .55695 Mdot
.61 .55702 Mdot
.61 .55718 Mdot
.61 .55721 Mdot
.61 .55721 Mdot
.61 .55722 Mdot
.61 .55724 Mdot
.61 .55724 Mdot
.61 .55727 Mdot
.61 .55728 Mdot
.61 .55729 Mdot
.61 .55731 Mdot
.61 .55732 Mdot
.61 .55733 Mdot
.61 .55735 Mdot
.61 .55735 Mdot
.61 .55738 Mdot
.61 .55738 Mdot
.61 .55738 Mdot
.61 .55739 Mdot
.61 .55739 Mdot
.61 .5574 Mdot
.61 .5574 Mdot
.61 .5574 Mdot
.61 .55741 Mdot
.61 .55741 Mdot
.612 .17018 Mdot
.612 .17018 Mdot
.612 .17018 Mdot
.612 .17019 Mdot
.612 .17021 Mdot
.612 .17022 Mdot
.612 .17022 Mdot
.612 .17023 Mdot
.612 .17032 Mdot
.612 .17033 Mdot
.612 .17044 Mdot
.612 .17046 Mdot
.612 .17058 Mdot
.612 .17066 Mdot
.612 .17145 Mdot
.612 .17148 Mdot
.612 .17149 Mdot
.612 .17177 Mdot
.612 .17236 Mdot
.612 .17256 Mdot
.612 .17257 Mdot
.612 .17258 Mdot
.612 .17316 Mdot
.612 .17327 Mdot
.612 .17328 Mdot
.612 .17356 Mdot
.612 .17378 Mdot
.612 .17409 Mdot
.612 .17442 Mdot
.612 .1745 Mdot
.612 .17503 Mdot
.612 .17516 Mdot
.612 .17517 Mdot
.612 .17538 Mdot
.612 .17574 Mdot
.612 .17596 Mdot
.612 .17606 Mdot
.612 .17666 Mdot
.612 .17669 Mdot
.612 .1768 Mdot
.612 .17718 Mdot
.612 .17751 Mdot
.612 .17824 Mdot
.612 .17826 Mdot
.612 .17833 Mdot
.612 .17837 Mdot
.612 .17844 Mdot
.612 .1792 Mdot
.612 .17922 Mdot
.612 .18 Mdot
.612 .18 Mdot
.612 .18085 Mdot
.612 .18111 Mdot
.612 .18168 Mdot
.612 .18226 Mdot
.612 .18271 Mdot
.612 .18279 Mdot
.612 .18302 Mdot
.612 .18315 Mdot
.612 .18344 Mdot
.612 .18394 Mdot
.612 .18485 Mdot
.612 .1852 Mdot
.612 .18526 Mdot
.612 .1855 Mdot
.612 .18615 Mdot
.612 .1866 Mdot
.612 .18683 Mdot
.612 .18733 Mdot
.612 .18747 Mdot
.612 .18763 Mdot
.612 .18798 Mdot
.612 .18856 Mdot
.612 .18856 Mdot
.612 .18967 Mdot
.612 .18969 Mdot
.612 .19 Mdot
.612 .19023 Mdot
.612 .19098 Mdot
.612 .19213 Mdot
.612 .19239 Mdot
.612 .19241 Mdot
.612 .19303 Mdot
.612 .1933 Mdot
.612 .19346 Mdot
.612 .19351 Mdot
.612 .19361 Mdot
.612 .19373 Mdot
.612 .19389 Mdot
.612 .19391 Mdot
.612 .19427 Mdot
.612 .19487 Mdot
.612 .19489 Mdot
.612 .19499 Mdot
.612 .1955 Mdot
.612 .19559 Mdot
.612 .19579 Mdot
.612 .19585 Mdot
.612 .19617 Mdot
.612 .19641 Mdot
.612 .19695 Mdot
.612 .19712 Mdot
.612 .20005 Mdot
.612 .20013 Mdot
.612 .20022 Mdot
.612 .20087 Mdot
.612 .20134 Mdot
.612 .20219 Mdot
.612 .20335 Mdot
.612 .20569 Mdot
.612 .20728 Mdot
.612 .20764 Mdot
.612 .20837 Mdot
.612 .21081 Mdot
.612 .21112 Mdot
.612 .2116 Mdot
.612 .21493 Mdot
.612 .21534 Mdot
.612 .21569 Mdot
.612 .21728 Mdot
.612 .21883 Mdot
.612 .21951 Mdot
.612 .21972 Mdot
.612 .21983 Mdot
.612 .22079 Mdot
.612 .22125 Mdot
.612 .22185 Mdot
.612 .22479 Mdot
.612 .22537 Mdot
.612 .22605 Mdot
.612 .22618 Mdot
.612 .22696 Mdot
.612 .22732 Mdot
.612 .22773 Mdot
.612 .22814 Mdot
.612 .22849 Mdot
.612 .22849 Mdot
.612 .22896 Mdot
.612 .23292 Mdot
.612 .23324 Mdot
.612 .23349 Mdot
.612 .23395 Mdot
.612 .23404 Mdot
.612 .23569 Mdot
.612 .23993 Mdot
.612 .23996 Mdot
.612 .24017 Mdot
.612 .24153 Mdot
.612 .24169 Mdot
.612 .24186 Mdot
.612 .24425 Mdot
.612 .24583 Mdot
.612 .24699 Mdot
.612 .24768 Mdot
.612 .24779 Mdot
.612 .25057 Mdot
.612 .25328 Mdot
.612 .25328 Mdot
.612 .25366 Mdot
.612 .25404 Mdot
.612 .2545 Mdot
.612 .25723 Mdot
.612 .25774 Mdot
.612 .2578 Mdot
.612 .25828 Mdot
.612 .25912 Mdot
.612 .26 Mdot
.612 .26019 Mdot
.612 .26231 Mdot
.612 .26259 Mdot
.612 .26278 Mdot
.612 .26422 Mdot
.612 .26467 Mdot
.612 .26488 Mdot
.612 .26809 Mdot
.612 .26865 Mdot
.612 .2694 Mdot
.612 .26951 Mdot
.612 .27166 Mdot
.612 .27221 Mdot
.612 .27245 Mdot
.612 .27249 Mdot
.612 .27264 Mdot
.612 .2727 Mdot
.612 .27315 Mdot
.612 .27316 Mdot
.612 .27361 Mdot
.612 .27388 Mdot
.612 .27401 Mdot
.612 .2741 Mdot
.612 .27418 Mdot
.612 .27422 Mdot
.612 .27454 Mdot
.612 .27502 Mdot
.612 .27504 Mdot
.612 .27676 Mdot
.612 .27694 Mdot
.612 .27814 Mdot
.612 .27814 Mdot
.612 .27864 Mdot
.612 .27908 Mdot
.612 .27986 Mdot
.612 .28026 Mdot
.612 .28086 Mdot
.612 .28147 Mdot
.612 .28284 Mdot
.612 .28348 Mdot
.612 .28357 Mdot
.612 .28404 Mdot
.612 .28526 Mdot
.612 .28555 Mdot
.612 .28651 Mdot
.612 .28651 Mdot
.612 .28742 Mdot
.612 .28837 Mdot
.612 .28846 Mdot
.612 .28851 Mdot
.612 .2886 Mdot
.612 .28958 Mdot
.612 .29055 Mdot
.612 .2907 Mdot
.612 .29176 Mdot
.612 .29265 Mdot
.612 .29298 Mdot
.612 .2941 Mdot
.612 .29481 Mdot
.612 .29581 Mdot
.612 .29636 Mdot
.612 .29995 Mdot
.612 .30077 Mdot
.612 .30078 Mdot
.612 .30439 Mdot
.612 .30604 Mdot
.612 .30615 Mdot
.612 .30732 Mdot
.612 .308 Mdot
.612 .30999 Mdot
.612 .31029 Mdot
.612 .31063 Mdot
.612 .31075 Mdot
.612 .31088 Mdot
.612 .3128 Mdot
.612 .3129 Mdot
.612 .31408 Mdot
.612 .31715 Mdot
.612 .31962 Mdot
.612 .3201 Mdot
.612 .32013 Mdot
.612 .32014 Mdot
.612 .32143 Mdot
.612 .32165 Mdot
.612 .32265 Mdot
.612 .32381 Mdot
.612 .32483 Mdot
.612 .32504 Mdot
.612 .32594 Mdot
.612 .32642 Mdot
.612 .3273 Mdot
.612 .32802 Mdot
.612 .32941 Mdot
.612 .33059 Mdot
.612 .33339 Mdot
.612 .33478 Mdot
.612 .33491 Mdot
.612 .3357 Mdot
.612 .3369 Mdot
.612 .33695 Mdot
.612 .33839 Mdot
.612 .33883 Mdot
.612 .33909 Mdot
.612 .34082 Mdot
.612 .34083 Mdot
.612 .34189 Mdot
.612 .34279 Mdot
.612 .3437 Mdot
.612 .34414 Mdot
.612 .34496 Mdot
.612 .34599 Mdot
.612 .3465 Mdot
.612 .34857 Mdot
.612 .34907 Mdot
.612 .35069 Mdot
.612 .35217 Mdot
.612 .35762 Mdot
.612 .36012 Mdot
.612 .36105 Mdot
.612 .36136 Mdot
.612 .36289 Mdot
.612 .36318 Mdot
.612 .36359 Mdot
.612 .36417 Mdot
.612 .36458 Mdot
.612 .36499 Mdot
.612 .36693 Mdot
.612 .36709 Mdot
.612 .3672 Mdot
.612 .36742 Mdot
.612 .36825 Mdot
.612 .37025 Mdot
.612 .37097 Mdot
.612 .37112 Mdot
.612 .37291 Mdot
.612 .37343 Mdot
.612 .37374 Mdot
.612 .375 Mdot
.612 .37618 Mdot
.612 .3767 Mdot
.612 .3783 Mdot
.612 .37865 Mdot
.612 .37902 Mdot
.612 .3791 Mdot
.612 .37998 Mdot
.612 .3801 Mdot
.612 .38017 Mdot
.612 .38077 Mdot
.612 .38095 Mdot
.612 .38104 Mdot
.612 .38257 Mdot
.612 .38287 Mdot
.612 .38291 Mdot
.612 .38377 Mdot
.612 .3841 Mdot
.612 .38416 Mdot
.612 .38419 Mdot
.612 .38437 Mdot
.612 .38437 Mdot
.612 .38465 Mdot
.612 .38471 Mdot
.612 .38474 Mdot
.612 .38477 Mdot
.612 .38492 Mdot
.612 .3851 Mdot
.612 .38579 Mdot
.612 .38586 Mdot
.612 .38633 Mdot
.612 .38633 Mdot
.612 .38652 Mdot
.612 .38669 Mdot
.612 .38699 Mdot
.612 .38715 Mdot
.612 .38738 Mdot
.612 .38762 Mdot
.612 .38814 Mdot
.612 .38839 Mdot
.612 .38842 Mdot
.612 .3886 Mdot
.612 .38918 Mdot
.612 .39025 Mdot
.612 .39028 Mdot
.612 .39034 Mdot
.612 .39113 Mdot
.612 .39153 Mdot
.612 .3924 Mdot
.612 .39304 Mdot
.612 .39456 Mdot
.612 .39486 Mdot
.612 .39487 Mdot
.612 .39682 Mdot
.612 .39749 Mdot
.612 .39843 Mdot
.612 .39847 Mdot
.612 .39925 Mdot
.612 .39967 Mdot
.612 .40163 Mdot
.612 .4018 Mdot
.612 .40181 Mdot
.612 .40181 Mdot
.612 .40226 Mdot
.612 .40346 Mdot
.612 .40353 Mdot
.612 .40385 Mdot
.612 .40401 Mdot
.612 .40432 Mdot
.612 .40457 Mdot
.612 .40505 Mdot
.612 .40546 Mdot
.612 .40696 Mdot
.612 .40764 Mdot
.612 .40766 Mdot
.612 .40815 Mdot
.612 .4083 Mdot
.612 .40839 Mdot
.612 .40898 Mdot
.612 .40899 Mdot
.612 .40935 Mdot
.612 .40997 Mdot
.612 .41012 Mdot
.612 .41092 Mdot
.612 .41163 Mdot
.612 .41179 Mdot
.612 .41284 Mdot
.612 .41553 Mdot
.612 .41595 Mdot
.612 .41646 Mdot
.612 .41656 Mdot
.612 .41689 Mdot
.612 .41703 Mdot
.612 .41787 Mdot
.612 .41826 Mdot
.612 .41893 Mdot
.612 .41917 Mdot
.612 .41922 Mdot
.612 .41982 Mdot
.612 .41999 Mdot
.612 .42009 Mdot
.612 .42052 Mdot
.612 .42174 Mdot
.612 .42189 Mdot
.612 .42222 Mdot
.612 .4225 Mdot
.612 .42345 Mdot
.612 .42356 Mdot
.612 .42358 Mdot
.612 .42359 Mdot
.612 .42364 Mdot
.612 .42365 Mdot
.612 .42374 Mdot
.612 .42377 Mdot
.612 .42378 Mdot
.612 .42383 Mdot
.612 .42389 Mdot
.612 .4243 Mdot
.612 .42436 Mdot
.612 .42465 Mdot
.612 .42491 Mdot
.612 .42499 Mdot
.612 .42506 Mdot
.612 .42525 Mdot
.612 .42561 Mdot
.612 .42604 Mdot
.612 .42633 Mdot
.612 .42654 Mdot
.612 .42715 Mdot
.612 .42715 Mdot
.612 .42862 Mdot
.612 .42876 Mdot
.612 .42941 Mdot
.612 .42948 Mdot
.612 .42963 Mdot
.612 .43003 Mdot
.612 .43016 Mdot
.612 .43021 Mdot
.612 .43032 Mdot
.612 .43143 Mdot
.612 .4316 Mdot
.612 .43165 Mdot
.612 .43168 Mdot
.612 .43188 Mdot
.612 .432 Mdot
.612 .43221 Mdot
.612 .43226 Mdot
.612 .43423 Mdot
.612 .4344 Mdot
.612 .43444 Mdot
.612 .43455 Mdot
.612 .43534 Mdot
.612 .43554 Mdot
.612 .4356 Mdot
.612 .43563 Mdot
.612 .43619 Mdot
.612 .43624 Mdot
.612 .43645 Mdot
.612 .43677 Mdot
.612 .43681 Mdot
.612 .43682 Mdot
.612 .43682 Mdot
.612 .43684 Mdot
.612 .43684 Mdot
.612 .43687 Mdot
.612 .43688 Mdot
.612 .43689 Mdot
.612 .4369 Mdot
.612 .43706 Mdot
.612 .43709 Mdot
.612 .43727 Mdot
.612 .4373 Mdot
.612 .43732 Mdot
.612 .43739 Mdot
.612 .43751 Mdot
.612 .43766 Mdot
.612 .43775 Mdot
.612 .43783 Mdot
.612 .43854 Mdot
.612 .43859 Mdot
.612 .43888 Mdot
.612 .43902 Mdot
.612 .43907 Mdot
.612 .43908 Mdot
.612 .43908 Mdot
.612 .43912 Mdot
.612 .4395 Mdot
.612 .43956 Mdot
.612 .43958 Mdot
.612 .44047 Mdot
.612 .44054 Mdot
.612 .44058 Mdot
.612 .44092 Mdot
.612 .44094 Mdot
.612 .44095 Mdot
.612 .44114 Mdot
.612 .44116 Mdot
.612 .44154 Mdot
.612 .44156 Mdot
.612 .44169 Mdot
.612 .44171 Mdot
.612 .44196 Mdot
.612 .44214 Mdot
.612 .44216 Mdot
.612 .44232 Mdot
.612 .44263 Mdot
.612 .44301 Mdot
.612 .44305 Mdot
.612 .44306 Mdot
.612 .44327 Mdot
.612 .44353 Mdot
.612 .44409 Mdot
.612 .44422 Mdot
.612 .44422 Mdot
.612 .44465 Mdot
.612 .44501 Mdot
.612 .44503 Mdot
.612 .4451 Mdot
.612 .44511 Mdot
.612 .44533 Mdot
.612 .44534 Mdot
.612 .4457 Mdot
.612 .44574 Mdot
.612 .44626 Mdot
.612 .4463 Mdot
.612 .44652 Mdot
.612 .44655 Mdot
.612 .44666 Mdot
.612 .44683 Mdot
.612 .44686 Mdot
.612 .44727 Mdot
.612 .44731 Mdot
.612 .44752 Mdot
.612 .44756 Mdot
.612 .44784 Mdot
.612 .44788 Mdot
.612 .44806 Mdot
.612 .44818 Mdot
.612 .44821 Mdot
.612 .44853 Mdot
.612 .44855 Mdot
.612 .44858 Mdot
.612 .4487 Mdot
.612 .44915 Mdot
.612 .44921 Mdot
.612 .44923 Mdot
.612 .44933 Mdot
.612 .45044 Mdot
.612 .45047 Mdot
.612 .45059 Mdot
.612 .45066 Mdot
.612 .45077 Mdot
.612 .45079 Mdot
.612 .45082 Mdot
.612 .45091 Mdot
.612 .45154 Mdot
.612 .4516 Mdot
.612 .45163 Mdot
.612 .4517 Mdot
.612 .45192 Mdot
.612 .45201 Mdot
.612 .45204 Mdot
.612 .45241 Mdot
.612 .45249 Mdot
.612 .4533 Mdot
.612 .4533 Mdot
.612 .45364 Mdot
.612 .45375 Mdot
.612 .45391 Mdot
.612 .45415 Mdot
.612 .45435 Mdot
.612 .45445 Mdot
.612 .45449 Mdot
.612 .45454 Mdot
.612 .45467 Mdot
.612 .45483 Mdot
.612 .45487 Mdot
.612 .45509 Mdot
.612 .45512 Mdot
.612 .45515 Mdot
.612 .45516 Mdot
.612 .45517 Mdot
.612 .45522 Mdot
.612 .45522 Mdot
.612 .45526 Mdot
.612 .45526 Mdot
.612 .45527 Mdot
.612 .45533 Mdot
.612 .45585 Mdot
.612 .456 Mdot
.612 .45618 Mdot
.612 .45626 Mdot
.612 .45692 Mdot
.612 .45715 Mdot
.612 .4572 Mdot
.612 .4573 Mdot
.612 .45762 Mdot
.612 .45765 Mdot
.612 .45778 Mdot
.612 .45813 Mdot
.612 .45834 Mdot
.612 .45879 Mdot
.612 .45886 Mdot
.612 .45904 Mdot
.612 .45909 Mdot
.612 .45937 Mdot
.612 .45959 Mdot
.612 .461 Mdot
.612 .46155 Mdot
.612 .46164 Mdot
.612 .46201 Mdot
.612 .46243 Mdot
.612 .46251 Mdot
.612 .46283 Mdot
.612 .46301 Mdot
.612 .46302 Mdot
.612 .46332 Mdot
.612 .46337 Mdot
.612 .46345 Mdot
.612 .4637 Mdot
.612 .46371 Mdot
.612 .46406 Mdot
.612 .46483 Mdot
.612 .46504 Mdot
.612 .46529 Mdot
.612 .46541 Mdot
.612 .46557 Mdot
.612 .46565 Mdot
.612 .46582 Mdot
.612 .46585 Mdot
.612 .46646 Mdot
.612 .46669 Mdot
.612 .46669 Mdot
.612 .46669 Mdot
.612 .46678 Mdot
.612 .46777 Mdot
.612 .46798 Mdot
.612 .46837 Mdot
.612 .46839 Mdot
.612 .46886 Mdot
.612 .46919 Mdot
.612 .47016 Mdot
.612 .47016 Mdot
.612 .47031 Mdot
.612 .47107 Mdot
.612 .47138 Mdot
.612 .47181 Mdot
.612 .472 Mdot
.612 .47239 Mdot
.612 .47241 Mdot
.612 .47243 Mdot
.612 .47295 Mdot
.612 .47323 Mdot
.612 .47332 Mdot
.612 .47334 Mdot
.612 .47346 Mdot
.612 .47371 Mdot
.612 .47383 Mdot
.612 .47394 Mdot
.612 .47401 Mdot
.612 .47416 Mdot
.612 .47424 Mdot
.612 .47433 Mdot
.612 .47434 Mdot
.612 .47456 Mdot
.612 .4746 Mdot
.612 .47492 Mdot
.612 .47501 Mdot
.612 .47508 Mdot
.612 .4751 Mdot
.612 .47512 Mdot
.612 .47514 Mdot
.612 .47528 Mdot
.612 .47528 Mdot
.612 .47536 Mdot
.612 .47538 Mdot
.612 .4754 Mdot
.612 .47556 Mdot
.612 .47597 Mdot
.612 .476 Mdot
.612 .47614 Mdot
.612 .47687 Mdot
.612 .47691 Mdot
.612 .477 Mdot
.612 .47728 Mdot
.612 .47731 Mdot
.612 .47737 Mdot
.612 .47779 Mdot
.612 .47782 Mdot
.612 .478 Mdot
.612 .47816 Mdot
.612 .47892 Mdot
.612 .47916 Mdot
.612 .47971 Mdot
.612 .4803 Mdot
.612 .48045 Mdot
.612 .48068 Mdot
.612 .48152 Mdot
.612 .48159 Mdot
.612 .48192 Mdot
.612 .48284 Mdot
.612 .48322 Mdot
.612 .48332 Mdot
.612 .48337 Mdot
.612 .48344 Mdot
.612 .48433 Mdot
.612 .48451 Mdot
.612 .4847 Mdot
.612 .48496 Mdot
.612 .48515 Mdot
.612 .48528 Mdot
.612 .48597 Mdot
.612 .48611 Mdot
.612 .48653 Mdot
.612 .48765 Mdot
.612 .49007 Mdot
.612 .49072 Mdot
.612 .49143 Mdot
.612 .49165 Mdot
.612 .49255 Mdot
.612 .49277 Mdot
.612 .49322 Mdot
.612 .49357 Mdot
.612 .49376 Mdot
.612 .49415 Mdot
.612 .49454 Mdot
.612 .49499 Mdot
.612 .495 Mdot
.612 .49574 Mdot
.612 .49585 Mdot
.612 .49604 Mdot
.612 .49665 Mdot
.612 .49667 Mdot
.612 .49719 Mdot
.612 .49752 Mdot
.612 .49757 Mdot
.612 .49816 Mdot
.612 .49934 Mdot
.612 .49983 Mdot
.612 .50041 Mdot
.612 .50071 Mdot
.612 .50108 Mdot
.612 .50127 Mdot
.612 .50165 Mdot
.612 .50174 Mdot
.612 .50216 Mdot
.612 .50264 Mdot
.612 .50305 Mdot
.612 .50314 Mdot
.612 .50367 Mdot
.612 .50367 Mdot
.612 .50369 Mdot
.612 .50388 Mdot
.612 .50489 Mdot
.612 .50614 Mdot
.612 .50661 Mdot
.612 .50665 Mdot
.612 .50743 Mdot
.612 .50748 Mdot
.612 .50753 Mdot
.612 .50766 Mdot
.612 .50778 Mdot
.612 .50858 Mdot
.612 .50885 Mdot
.612 .50932 Mdot
.612 .50936 Mdot
.612 .51002 Mdot
.612 .51144 Mdot
.612 .51145 Mdot
.612 .51177 Mdot
.612 .51318 Mdot
.612 .51339 Mdot
.612 .51378 Mdot
.612 .51406 Mdot
.612 .5145 Mdot
.612 .51463 Mdot
.612 .51497 Mdot
.612 .51538 Mdot
.612 .51544 Mdot
.612 .51581 Mdot
.612 .51619 Mdot
.612 .51622 Mdot
.612 .51624 Mdot
.612 .51628 Mdot
.612 .51664 Mdot
.612 .51699 Mdot
.612 .51699 Mdot
.612 .51736 Mdot
.612 .51747 Mdot
.612 .51794 Mdot
.612 .51812 Mdot
.612 .51815 Mdot
.612 .5184 Mdot
.612 .51892 Mdot
.612 .51915 Mdot
.612 .51938 Mdot
.612 .51953 Mdot
.612 .51982 Mdot
.612 .51999 Mdot
.612 .52018 Mdot
.612 .52018 Mdot
.612 .52063 Mdot
.612 .5207 Mdot
.612 .52135 Mdot
.612 .52135 Mdot
.612 .52153 Mdot
.612 .52165 Mdot
.612 .52167 Mdot
.612 .5217 Mdot
.612 .52173 Mdot
.612 .52178 Mdot
.612 .52188 Mdot
.612 .52205 Mdot
.612 .52206 Mdot
.612 .52222 Mdot
.612 .52225 Mdot
.612 .5223 Mdot
.612 .52232 Mdot
.612 .52241 Mdot
.612 .52261 Mdot
.612 .52341 Mdot
.612 .52345 Mdot
.612 .52373 Mdot
.612 .52394 Mdot
.612 .52513 Mdot
.612 .52521 Mdot
.612 .52537 Mdot
.612 .5259 Mdot
.612 .52597 Mdot
.612 .52607 Mdot
.612 .52685 Mdot
.612 .52693 Mdot
.612 .52725 Mdot
.612 .52755 Mdot
.612 .52773 Mdot
.612 .52775 Mdot
.612 .52794 Mdot
.612 .52893 Mdot
.612 .52909 Mdot
.612 .52923 Mdot
.612 .52937 Mdot
.612 .52937 Mdot
.612 .53035 Mdot
.612 .53135 Mdot
.612 .53139 Mdot
.612 .53164 Mdot
.612 .53205 Mdot
.612 .53262 Mdot
.612 .53347 Mdot
.612 .53352 Mdot
.612 .53358 Mdot
.612 .53406 Mdot
.612 .53414 Mdot
.612 .53415 Mdot
.612 .53565 Mdot
.612 .53623 Mdot
.612 .53626 Mdot
.612 .53642 Mdot
.612 .53651 Mdot
.612 .53662 Mdot
.612 .538 Mdot
.612 .53817 Mdot
.612 .53817 Mdot
.612 .53829 Mdot
.612 .53843 Mdot
.612 .53857 Mdot
.612 .5387 Mdot
.612 .53897 Mdot
.612 .53902 Mdot
.612 .53925 Mdot
.612 .53945 Mdot
.612 .54047 Mdot
.612 .54067 Mdot
.612 .54083 Mdot
.612 .54116 Mdot
.612 .5412 Mdot
.612 .54127 Mdot
.612 .54151 Mdot
.612 .54204 Mdot
.612 .54258 Mdot
.612 .5427 Mdot
.612 .54284 Mdot
.612 .54397 Mdot
.612 .54413 Mdot
.612 .54424 Mdot
.612 .54507 Mdot
.612 .54531 Mdot
.612 .54543 Mdot
.612 .54597 Mdot
.612 .54676 Mdot
.612 .54715 Mdot
.612 .54743 Mdot
.612 .54759 Mdot
.612 .54781 Mdot
.612 .54784 Mdot
.612 .54786 Mdot
.612 .54884 Mdot
.612 .5489 Mdot
.612 .54907 Mdot
.612 .54915 Mdot
.612 .54926 Mdot
.612 .54928 Mdot
.612 .54935 Mdot
.612 .54938 Mdot
.612 .54955 Mdot
.612 .54958 Mdot
.612 .54959 Mdot
.612 .54978 Mdot
.612 .5499 Mdot
.612 .54991 Mdot
.612 .54996 Mdot
.612 .55 Mdot
.612 .55004 Mdot
.612 .55005 Mdot
.612 .5501 Mdot
.612 .55019 Mdot
.612 .5504 Mdot
.612 .55041 Mdot
.612 .55049 Mdot
.612 .55087 Mdot
.612 .55112 Mdot
.612 .55119 Mdot
.612 .5513 Mdot
.612 .5513 Mdot
.612 .55167 Mdot
.612 .55167 Mdot
.612 .55186 Mdot
.612 .55197 Mdot
.612 .55203 Mdot
.612 .55207 Mdot
.612 .55224 Mdot
.612 .55231 Mdot
.612 .55246 Mdot
.612 .55267 Mdot
.612 .55275 Mdot
.612 .55277 Mdot
.612 .55289 Mdot
.612 .55318 Mdot
.612 .55335 Mdot
.612 .55344 Mdot
.612 .55348 Mdot
.612 .55356 Mdot
.612 .55358 Mdot
.612 .55373 Mdot
.612 .55392 Mdot
.612 .55411 Mdot
.612 .55419 Mdot
.612 .55447 Mdot
.612 .55447 Mdot
.612 .55472 Mdot
.612 .55473 Mdot
.612 .55497 Mdot
.612 .55499 Mdot
.612 .55501 Mdot
.612 .55503 Mdot
.612 .55504 Mdot
.612 .55528 Mdot
.612 .55538 Mdot
.612 .55551 Mdot
.612 .55554 Mdot
.612 .55555 Mdot
.612 .55574 Mdot
.612 .55578 Mdot
.612 .55585 Mdot
.612 .55596 Mdot
.612 .55603 Mdot
.612 .55603 Mdot
.612 .55608 Mdot
.612 .55625 Mdot
.612 .55627 Mdot
.612 .55638 Mdot
.612 .55648 Mdot
.612 .55655 Mdot
.612 .55664 Mdot
.612 .55664 Mdot
.612 .55668 Mdot
.612 .55687 Mdot
.612 .55687 Mdot
.612 .55687 Mdot
.612 .55694 Mdot
.612 .55713 Mdot
.612 .55722 Mdot
.612 .55722 Mdot
.612 .55723 Mdot
.612 .55748 Mdot
.612 .55751 Mdot
.612 .55755 Mdot
.612 .55755 Mdot
.612 .55759 Mdot
.612 .55759 Mdot
.612 .55762 Mdot
.612 .55762 Mdot
.612 .55763 Mdot
.612 .55763 Mdot
.612 .55763 Mdot
.612 .55764 Mdot
.612 .55764 Mdot
.614 .1695 Mdot
.614 .1695 Mdot
.614 .1695 Mdot
.614 .16953 Mdot
.614 .16953 Mdot
.614 .16967 Mdot
.614 .16974 Mdot
.614 .16987 Mdot
.614 .17004 Mdot
.614 .1702 Mdot
.614 .17022 Mdot
.614 .17026 Mdot
.614 .17033 Mdot
.614 .17039 Mdot
.614 .17043 Mdot
.614 .17052 Mdot
.614 .17071 Mdot
.614 .17088 Mdot
.614 .17089 Mdot
.614 .17118 Mdot
.614 .17129 Mdot
.614 .17182 Mdot
.614 .17188 Mdot
.614 .17204 Mdot
.614 .17209 Mdot
.614 .17253 Mdot
.614 .17262 Mdot
.614 .1729 Mdot
.614 .17294 Mdot
.614 .17326 Mdot
.614 .17328 Mdot
.614 .1734 Mdot
.614 .17345 Mdot
.614 .17362 Mdot
.614 .17397 Mdot
.614 .17407 Mdot
.614 .17416 Mdot
.614 .17603 Mdot
.614 .17681 Mdot
.614 .17731 Mdot
.614 .17744 Mdot
.614 .17761 Mdot
.614 .17765 Mdot
.614 .17806 Mdot
.614 .17864 Mdot
.614 .17924 Mdot
.614 .17957 Mdot
.614 .18032 Mdot
.614 .1807 Mdot
.614 .18098 Mdot
.614 .18147 Mdot
.614 .18205 Mdot
.614 .18239 Mdot
.614 .18269 Mdot
.614 .1827 Mdot
.614 .18292 Mdot
.614 .18303 Mdot
.614 .18318 Mdot
.614 .18384 Mdot
.614 .18387 Mdot
.614 .18488 Mdot
.614 .18489 Mdot
.614 .18551 Mdot
.614 .18563 Mdot
.614 .18699 Mdot
.614 .18735 Mdot
.614 .1874 Mdot
.614 .18797 Mdot
.614 .18807 Mdot
.614 .18819 Mdot
.614 .18865 Mdot
.614 .19057 Mdot
.614 .19059 Mdot
.614 .19108 Mdot
.614 .19129 Mdot
.614 .19153 Mdot
.614 .19223 Mdot
.614 .19324 Mdot
.614 .19353 Mdot
.614 .19359 Mdot
.614 .19362 Mdot
.614 .19502 Mdot
.614 .19537 Mdot
.614 .19549 Mdot
.614 .1958 Mdot
.614 .19642 Mdot
.614 .19672 Mdot
.614 .19751 Mdot
.614 .19755 Mdot
.614 .19947 Mdot
.614 .20008 Mdot
.614 .20025 Mdot
.614 .20029 Mdot
.614 .20054 Mdot
.614 .20282 Mdot
.614 .2031 Mdot
.614 .20312 Mdot
.614 .20319 Mdot
.614 .20377 Mdot
.614 .20379 Mdot
.614 .20535 Mdot
.614 .20536 Mdot
.614 .20613 Mdot
.614 .20631 Mdot
.614 .20702 Mdot
.614 .20717 Mdot
.614 .20724 Mdot
.614 .20773 Mdot
.614 .20851 Mdot
.614 .20994 Mdot
.614 .21051 Mdot
.614 .21111 Mdot
.614 .2115 Mdot
.614 .2116 Mdot
.614 .21241 Mdot
.614 .21321 Mdot
.614 .21462 Mdot
.614 .21503 Mdot
.614 .2151 Mdot
.614 .21512 Mdot
.614 .21598 Mdot
.614 .21663 Mdot
.614 .21786 Mdot
.614 .21815 Mdot
.614 .21848 Mdot
.614 .21878 Mdot
.614 .21895 Mdot
.614 .21977 Mdot
.614 .21985 Mdot
.614 .22055 Mdot
.614 .22308 Mdot
.614 .22309 Mdot
.614 .22422 Mdot
.614 .22457 Mdot
.614 .22968 Mdot
.614 .22976 Mdot
.614 .2298 Mdot
.614 .23048 Mdot
.614 .23121 Mdot
.614 .23133 Mdot
.614 .23157 Mdot
.614 .23259 Mdot
.614 .23318 Mdot
.614 .23329 Mdot
.614 .2344 Mdot
.614 .23441 Mdot
.614 .23522 Mdot
.614 .23589 Mdot
.614 .23646 Mdot
.614 .23646 Mdot
.614 .23666 Mdot
.614 .23693 Mdot
.614 .23705 Mdot
.614 .2395 Mdot
.614 .23964 Mdot
.614 .24233 Mdot
.614 .24276 Mdot
.614 .24461 Mdot
.614 .24543 Mdot
.614 .24645 Mdot
.614 .24876 Mdot
.614 .24888 Mdot
.614 .24894 Mdot
.614 .24907 Mdot
.614 .24916 Mdot
.614 .24943 Mdot
.614 .25013 Mdot
.614 .25013 Mdot
.614 .25066 Mdot
.614 .25166 Mdot
.614 .25237 Mdot
.614 .25497 Mdot
.614 .25515 Mdot
.614 .25573 Mdot
.614 .25705 Mdot
.614 .25742 Mdot
.614 .25746 Mdot
.614 .25799 Mdot
.614 .25833 Mdot
.614 .25849 Mdot
.614 .26151 Mdot
.614 .26226 Mdot
.614 .26378 Mdot
.614 .26425 Mdot
.614 .26454 Mdot
.614 .26459 Mdot
.614 .26468 Mdot
.614 .26522 Mdot
.614 .2657 Mdot
.614 .2657 Mdot
.614 .2671 Mdot
.614 .26729 Mdot
.614 .26878 Mdot
.614 .26895 Mdot
.614 .2708 Mdot
.614 .27083 Mdot
.614 .27363 Mdot
.614 .27391 Mdot
.614 .27522 Mdot
.614 .27541 Mdot
.614 .27557 Mdot
.614 .27596 Mdot
.614 .27753 Mdot
.614 .27792 Mdot
.614 .27802 Mdot
.614 .27811 Mdot
.614 .27859 Mdot
.614 .27863 Mdot
.614 .27895 Mdot
.614 .28026 Mdot
.614 .28083 Mdot
.614 .28084 Mdot
.614 .28179 Mdot
.614 .28246 Mdot
.614 .2826 Mdot
.614 .28271 Mdot
.614 .28293 Mdot
.614 .28418 Mdot
.614 .28804 Mdot
.614 .28855 Mdot
.614 .28881 Mdot
.614 .29071 Mdot
.614 .29355 Mdot
.614 .29447 Mdot
.614 .29573 Mdot
.614 .29637 Mdot
.614 .29654 Mdot
.614 .29749 Mdot
.614 .2981 Mdot
.614 .30058 Mdot
.614 .30059 Mdot
.614 .3021 Mdot
.614 .30226 Mdot
.614 .30275 Mdot
.614 .30299 Mdot
.614 .30759 Mdot
.614 .30873 Mdot
.614 .30952 Mdot
.614 .30974 Mdot
.614 .31045 Mdot
.614 .31204 Mdot
.614 .31253 Mdot
.614 .31337 Mdot
.614 .31431 Mdot
.614 .31512 Mdot
.614 .31556 Mdot
.614 .31628 Mdot
.614 .31691 Mdot
.614 .31831 Mdot
.614 .3186 Mdot
.614 .32006 Mdot
.614 .32044 Mdot
.614 .32222 Mdot
.614 .3229 Mdot
.614 .32295 Mdot
.614 .32315 Mdot
.614 .32325 Mdot
.614 .32415 Mdot
.614 .32432 Mdot
.614 .32839 Mdot
.614 .32906 Mdot
.614 .32943 Mdot
.614 .3307 Mdot
.614 .3314 Mdot
.614 .33178 Mdot
.614 .33262 Mdot
.614 .33303 Mdot
.614 .33333 Mdot
.614 .33445 Mdot
.614 .33479 Mdot
.614 .33509 Mdot
.614 .33622 Mdot
.614 .33788 Mdot
.614 .34206 Mdot
.614 .34335 Mdot
.614 .34434 Mdot
.614 .34438 Mdot
.614 .34543 Mdot
.614 .34569 Mdot
.614 .34578 Mdot
.614 .346 Mdot
.614 .34644 Mdot
.614 .34665 Mdot
.614 .34854 Mdot
.614 .34895 Mdot
.614 .34906 Mdot
.614 .35092 Mdot
.614 .35098 Mdot
.614 .35134 Mdot
.614 .35135 Mdot
.614 .35292 Mdot
.614 .35509 Mdot
.614 .35542 Mdot
.614 .356 Mdot
.614 .35606 Mdot
.614 .35697 Mdot
.614 .35777 Mdot
.614 .35799 Mdot
.614 .35803 Mdot
.614 .35804 Mdot
.614 .35852 Mdot
.614 .35888 Mdot
.614 .35988 Mdot
.614 .36013 Mdot
.614 .3623 Mdot
.614 .36562 Mdot
.614 .36568 Mdot
.614 .36602 Mdot
.614 .36643 Mdot
.614 .36654 Mdot
.614 .36704 Mdot
.614 .36732 Mdot
.614 .36829 Mdot
.614 .36887 Mdot
.614 .37029 Mdot
.614 .37035 Mdot
.614 .37178 Mdot
.614 .37297 Mdot
.614 .37444 Mdot
.614 .37449 Mdot
.614 .37452 Mdot
.614 .37458 Mdot
.614 .37461 Mdot
.614 .37473 Mdot
.614 .37504 Mdot
.614 .37504 Mdot
.614 .37601 Mdot
.614 .37712 Mdot
.614 .37719 Mdot
.614 .37744 Mdot
.614 .378 Mdot
.614 .37815 Mdot
.614 .37817 Mdot
.614 .3786 Mdot
.614 .37986 Mdot
.614 .38016 Mdot
.614 .38079 Mdot
.614 .38112 Mdot
.614 .38116 Mdot
.614 .38222 Mdot
.614 .38288 Mdot
.614 .38537 Mdot
.614 .38551 Mdot
.614 .38566 Mdot
.614 .38627 Mdot
.614 .38642 Mdot
.614 .3865 Mdot
.614 .38668 Mdot
.614 .38733 Mdot
.614 .38755 Mdot
.614 .38792 Mdot
.614 .38817 Mdot
.614 .38883 Mdot
.614 .3903 Mdot
.614 .39049 Mdot
.614 .39059 Mdot
.614 .3913 Mdot
.614 .39236 Mdot
.614 .3927 Mdot
.614 .39316 Mdot
.614 .3934 Mdot
.614 .39404 Mdot
.614 .3955 Mdot
.614 .39556 Mdot
.614 .39574 Mdot
.614 .39583 Mdot
.614 .3979 Mdot
.614 .39851 Mdot
.614 .40033 Mdot
.614 .40058 Mdot
.614 .40081 Mdot
.614 .4013 Mdot
.614 .40192 Mdot
.614 .40268 Mdot
.614 .40304 Mdot
.614 .40335 Mdot
.614 .40506 Mdot
.614 .40519 Mdot
.614 .40587 Mdot
.614 .406 Mdot
.614 .40629 Mdot
.614 .40704 Mdot
.614 .40714 Mdot
.614 .40997 Mdot
.614 .41032 Mdot
.614 .41067 Mdot
.614 .41076 Mdot
.614 .41108 Mdot
.614 .41187 Mdot
.614 .41253 Mdot
.614 .41255 Mdot
.614 .41321 Mdot
.614 .41394 Mdot
.614 .41405 Mdot
.614 .41457 Mdot
.614 .41493 Mdot
.614 .41509 Mdot
.614 .41555 Mdot
.614 .41563 Mdot
.614 .41636 Mdot
.614 .41747 Mdot
.614 .41761 Mdot
.614 .41804 Mdot
.614 .41837 Mdot
.614 .41903 Mdot
.614 .41906 Mdot
.614 .41953 Mdot
.614 .41993 Mdot
.614 .42042 Mdot
.614 .42044 Mdot
.614 .42045 Mdot
.614 .42047 Mdot
.614 .42062 Mdot
.614 .42062 Mdot
.614 .42094 Mdot
.614 .42134 Mdot
.614 .42142 Mdot
.614 .42166 Mdot
.614 .42167 Mdot
.614 .42181 Mdot
.614 .42233 Mdot
.614 .42265 Mdot
.614 .42324 Mdot
.614 .42406 Mdot
.614 .42411 Mdot
.614 .42416 Mdot
.614 .42437 Mdot
.614 .42472 Mdot
.614 .42491 Mdot
.614 .425 Mdot
.614 .42522 Mdot
.614 .42571 Mdot
.614 .42577 Mdot
.614 .42604 Mdot
.614 .42639 Mdot
.614 .42666 Mdot
.614 .42752 Mdot
.614 .42755 Mdot
.614 .42824 Mdot
.614 .42845 Mdot
.614 .42905 Mdot
.614 .42921 Mdot
.614 .42958 Mdot
.614 .43091 Mdot
.614 .43095 Mdot
.614 .4313 Mdot
.614 .43133 Mdot
.614 .43228 Mdot
.614 .43255 Mdot
.614 .43266 Mdot
.614 .43292 Mdot
.614 .43337 Mdot
.614 .43362 Mdot
.614 .43365 Mdot
.614 .43383 Mdot
.614 .43395 Mdot
.614 .43401 Mdot
.614 .43443 Mdot
.614 .43481 Mdot
.614 .4355 Mdot
.614 .43581 Mdot
.614 .43581 Mdot
.614 .43581 Mdot
.614 .43582 Mdot
.614 .43587 Mdot
.614 .43587 Mdot
.614 .43612 Mdot
.614 .43614 Mdot
.614 .43623 Mdot
.614 .43623 Mdot
.614 .43628 Mdot
.614 .43645 Mdot
.614 .43676 Mdot
.614 .43704 Mdot
.614 .43707 Mdot
.614 .43714 Mdot
.614 .43726 Mdot
.614 .43736 Mdot
.614 .43743 Mdot
.614 .4376 Mdot
.614 .43762 Mdot
.614 .43783 Mdot
.614 .43793 Mdot
.614 .43822 Mdot
.614 .43823 Mdot
.614 .43853 Mdot
.614 .43874 Mdot
.614 .43892 Mdot
.614 .43938 Mdot
.614 .43951 Mdot
.614 .43952 Mdot
.614 .43985 Mdot
.614 .43994 Mdot
.614 .44007 Mdot
.614 .44022 Mdot
.614 .44031 Mdot
.614 .44032 Mdot
.614 .44044 Mdot
.614 .44096 Mdot
.614 .44106 Mdot
.614 .44118 Mdot
.614 .44121 Mdot
.614 .44169 Mdot
.614 .44176 Mdot
.614 .4423 Mdot
.614 .44234 Mdot
.614 .44235 Mdot
.614 .44254 Mdot
.614 .44262 Mdot
.614 .44267 Mdot
.614 .44285 Mdot
.614 .44292 Mdot
.614 .44333 Mdot
.614 .44344 Mdot
.614 .4435 Mdot
.614 .44367 Mdot
.614 .44371 Mdot
.614 .44381 Mdot
.614 .44384 Mdot
.614 .44389 Mdot
.614 .44394 Mdot
.614 .4441 Mdot
.614 .44417 Mdot
.614 .44445 Mdot
.614 .44456 Mdot
.614 .44475 Mdot
.614 .44543 Mdot
.614 .44556 Mdot
.614 .44586 Mdot
.614 .44593 Mdot
.614 .44608 Mdot
.614 .4464 Mdot
.614 .4464 Mdot
.614 .44648 Mdot
.614 .44697 Mdot
.614 .44737 Mdot
.614 .4475 Mdot
.614 .44827 Mdot
.614 .4483 Mdot
.614 .44834 Mdot
.614 .44853 Mdot
.614 .44871 Mdot
.614 .44911 Mdot
.614 .44932 Mdot
.614 .44956 Mdot
.614 .44959 Mdot
.614 .44966 Mdot
.614 .44976 Mdot
.614 .44978 Mdot
.614 .44992 Mdot
.614 .45018 Mdot
.614 .45033 Mdot
.614 .45039 Mdot
.614 .45054 Mdot
.614 .45107 Mdot
.614 .45109 Mdot
.614 .45128 Mdot
.614 .45131 Mdot
.614 .45205 Mdot
.614 .45225 Mdot
.614 .45234 Mdot
.614 .45268 Mdot
.614 .4528 Mdot
.614 .45318 Mdot
.614 .45319 Mdot
.614 .45367 Mdot
.614 .45382 Mdot
.614 .45401 Mdot
.614 .45416 Mdot
.614 .45419 Mdot
.614 .45446 Mdot
.614 .45458 Mdot
.614 .45463 Mdot
.614 .45474 Mdot
.614 .45493 Mdot
.614 .45504 Mdot
.614 .45507 Mdot
.614 .45509 Mdot
.614 .45554 Mdot
.614 .45586 Mdot
.614 .45604 Mdot
.614 .45632 Mdot
.614 .4564 Mdot
.614 .4564 Mdot
.614 .45653 Mdot
.614 .45657 Mdot
.614 .45679 Mdot
.614 .45696 Mdot
.614 .45696 Mdot
.614 .45704 Mdot
.614 .45705 Mdot
.614 .45706 Mdot
.614 .45707 Mdot
.614 .45733 Mdot
.614 .45755 Mdot
.614 .4578 Mdot
.614 .45781 Mdot
.614 .45817 Mdot
.614 .45834 Mdot
.614 .45858 Mdot
.614 .45865 Mdot
.614 .45924 Mdot
.614 .45962 Mdot
.614 .45967 Mdot
.614 .45991 Mdot
.614 .46 Mdot
.614 .46018 Mdot
.614 .46046 Mdot
.614 .46052 Mdot
.614 .4609 Mdot
.614 .46125 Mdot
.614 .46126 Mdot
.614 .46161 Mdot
.614 .46201 Mdot
.614 .46218 Mdot
.614 .46223 Mdot
.614 .46241 Mdot
.614 .4626 Mdot
.614 .46406 Mdot
.614 .46411 Mdot
.614 .46449 Mdot
.614 .46464 Mdot
.614 .46471 Mdot
.614 .46506 Mdot
.614 .46512 Mdot
.614 .46599 Mdot
.614 .46615 Mdot
.614 .46633 Mdot
.614 .46672 Mdot
.614 .46703 Mdot
.614 .46728 Mdot
.614 .46739 Mdot
.614 .46752 Mdot
.614 .46843 Mdot
.614 .46874 Mdot
.614 .46977 Mdot
.614 .46981 Mdot
.614 .4699 Mdot
.614 .46993 Mdot
.614 .47065 Mdot
.614 .47097 Mdot
.614 .47108 Mdot
.614 .47131 Mdot
.614 .47148 Mdot
.614 .472 Mdot
.614 .47235 Mdot
.614 .4724 Mdot
.614 .47249 Mdot
.614 .4732 Mdot
.614 .47352 Mdot
.614 .47365 Mdot
.614 .47382 Mdot
.614 .47393 Mdot
.614 .47424 Mdot
.614 .47433 Mdot
.614 .47437 Mdot
.614 .47444 Mdot
.614 .47474 Mdot
.614 .47481 Mdot
.614 .47487 Mdot
.614 .47607 Mdot
.614 .47638 Mdot
.614 .47689 Mdot
.614 .4769 Mdot
.614 .47706 Mdot
.614 .47736 Mdot
.614 .4775 Mdot
.614 .4781 Mdot
.614 .4783 Mdot
.614 .47831 Mdot
.614 .47838 Mdot
.614 .47864 Mdot
.614 .47876 Mdot
.614 .47879 Mdot
.614 .47931 Mdot
.614 .47977 Mdot
.614 .47977 Mdot
.614 .47991 Mdot
.614 .47997 Mdot
.614 .47998 Mdot
.614 .48001 Mdot
.614 .48002 Mdot
.614 .48005 Mdot
.614 .48073 Mdot
.614 .48128 Mdot
.614 .48194 Mdot
.614 .48197 Mdot
.614 .48262 Mdot
.614 .48289 Mdot
.614 .48334 Mdot
.614 .48346 Mdot
.614 .48369 Mdot
.614 .48374 Mdot
.614 .48393 Mdot
.614 .48408 Mdot
.614 .48411 Mdot
.614 .48561 Mdot
.614 .48659 Mdot
.614 .48671 Mdot
.614 .48716 Mdot
.614 .48731 Mdot
.614 .48753 Mdot
.614 .48753 Mdot
.614 .48755 Mdot
.614 .48765 Mdot
.614 .488 Mdot
.614 .48841 Mdot
.614 .48844 Mdot
.614 .48869 Mdot
.614 .48884 Mdot
.614 .4898 Mdot
.614 .49049 Mdot
.614 .4905 Mdot
.614 .49066 Mdot
.614 .49068 Mdot
.614 .4915 Mdot
.614 .49154 Mdot
.614 .49172 Mdot
.614 .49255 Mdot
.614 .49264 Mdot
.614 .49283 Mdot
.614 .49292 Mdot
.614 .49296 Mdot
.614 .49307 Mdot
.614 .49353 Mdot
.614 .49355 Mdot
.614 .49397 Mdot
.614 .49453 Mdot
.614 .49632 Mdot
.614 .49702 Mdot
.614 .4975 Mdot
.614 .49763 Mdot
.614 .49777 Mdot
.614 .49825 Mdot
.614 .49837 Mdot
.614 .49854 Mdot
.614 .4989 Mdot
.614 .49906 Mdot
.614 .49935 Mdot
.614 .49988 Mdot
.614 .50004 Mdot
.614 .50031 Mdot
.614 .502 Mdot
.614 .50207 Mdot
.614 .50245 Mdot
.614 .50248 Mdot
.614 .50257 Mdot
.614 .50259 Mdot
.614 .50287 Mdot
.614 .5036 Mdot
.614 .50375 Mdot
.614 .50435 Mdot
.614 .50447 Mdot
.614 .50504 Mdot
.614 .5053 Mdot
.614 .50559 Mdot
.614 .50577 Mdot
.614 .5061 Mdot
.614 .50647 Mdot
.614 .50681 Mdot
.614 .50701 Mdot
.614 .50765 Mdot
.614 .50793 Mdot
.614 .50802 Mdot
.614 .50834 Mdot
.614 .5088 Mdot
.614 .51062 Mdot
.614 .51072 Mdot
.614 .51091 Mdot
.614 .51097 Mdot
.614 .51157 Mdot
.614 .51157 Mdot
.614 .51255 Mdot
.614 .51279 Mdot
.614 .51316 Mdot
.614 .51322 Mdot
.614 .51347 Mdot
.614 .51396 Mdot
.614 .51432 Mdot
.614 .51542 Mdot
.614 .51615 Mdot
.614 .51626 Mdot
.614 .51645 Mdot
.614 .51793 Mdot
.614 .5184 Mdot
.614 .51849 Mdot
.614 .51853 Mdot
.614 .51859 Mdot
.614 .51884 Mdot
.614 .5192 Mdot
.614 .5192 Mdot
.614 .51942 Mdot
.614 .51992 Mdot
.614 .52004 Mdot
.614 .52005 Mdot
.614 .52023 Mdot
.614 .52027 Mdot
.614 .52031 Mdot
.614 .52045 Mdot
.614 .52104 Mdot
.614 .52119 Mdot
.614 .52125 Mdot
.614 .52132 Mdot
.614 .52181 Mdot
.614 .52192 Mdot
.614 .52296 Mdot
.614 .52297 Mdot
.614 .52366 Mdot
.614 .52373 Mdot
.614 .52428 Mdot
.614 .52435 Mdot
.614 .52487 Mdot
.614 .52487 Mdot
.614 .52504 Mdot
.614 .52524 Mdot
.614 .52528 Mdot
.614 .52529 Mdot
.614 .5254 Mdot
.614 .52557 Mdot
.614 .52614 Mdot
.614 .52641 Mdot
.614 .52751 Mdot
.614 .52757 Mdot
.614 .52769 Mdot
.614 .52789 Mdot
.614 .5279 Mdot
.614 .52804 Mdot
.614 .52852 Mdot
.614 .52873 Mdot
.614 .5288 Mdot
.614 .52974 Mdot
.614 .52999 Mdot
.614 .53035 Mdot
.614 .53054 Mdot
.614 .53054 Mdot
.614 .5308 Mdot
.614 .53089 Mdot
.614 .53093 Mdot
.614 .53097 Mdot
.614 .53099 Mdot
.614 .53104 Mdot
.614 .53186 Mdot
.614 .53223 Mdot
.614 .53252 Mdot
.614 .53318 Mdot
.614 .53333 Mdot
.614 .53429 Mdot
.614 .53434 Mdot
.614 .5352 Mdot
.614 .53524 Mdot
.614 .53534 Mdot
.614 .53541 Mdot
.614 .53541 Mdot
.614 .53561 Mdot
.614 .53585 Mdot
.614 .53613 Mdot
.614 .53613 Mdot
.614 .53652 Mdot
.614 .53656 Mdot
.614 .53677 Mdot
.614 .53712 Mdot
.614 .53721 Mdot
.614 .53725 Mdot
.614 .5375 Mdot
.614 .53774 Mdot
.614 .53776 Mdot
.614 .53779 Mdot
.614 .53956 Mdot
.614 .53968 Mdot
.614 .54007 Mdot
.614 .54007 Mdot
.614 .54095 Mdot
.614 .54119 Mdot
.614 .54121 Mdot
.614 .54149 Mdot
.614 .54155 Mdot
.614 .54166 Mdot
.614 .54177 Mdot
.614 .54187 Mdot
.614 .54229 Mdot
.614 .54251 Mdot
.614 .5428 Mdot
.614 .54281 Mdot
.614 .54284 Mdot
.614 .54297 Mdot
.614 .54346 Mdot
.614 .54373 Mdot
.614 .544 Mdot
.614 .54404 Mdot
.614 .54417 Mdot
.614 .54437 Mdot
.614 .54457 Mdot
.614 .54505 Mdot
.614 .54531 Mdot
.614 .54548 Mdot
.614 .5455 Mdot
.614 .54555 Mdot
.614 .54579 Mdot
.614 .54585 Mdot
.614 .54611 Mdot
.614 .54611 Mdot
.614 .54664 Mdot
.614 .54664 Mdot
.614 .54684 Mdot
.614 .54686 Mdot
.614 .54687 Mdot
.614 .54696 Mdot
.614 .54773 Mdot
.614 .54781 Mdot
.614 .54782 Mdot
.614 .54788 Mdot
.614 .54808 Mdot
.614 .54872 Mdot
.614 .54873 Mdot
.614 .549 Mdot
.614 .5491 Mdot
.614 .5493 Mdot
.614 .54941 Mdot
.614 .54945 Mdot
.614 .54956 Mdot
.614 .55003 Mdot
.614 .55003 Mdot
.614 .55006 Mdot
.614 .55015 Mdot
.614 .55049 Mdot
.614 .55072 Mdot
.614 .55079 Mdot
.614 .55086 Mdot
.614 .55103 Mdot
.614 .55103 Mdot
.614 .55166 Mdot
.614 .55181 Mdot
.614 .55185 Mdot
.614 .55189 Mdot
.614 .55208 Mdot
.614 .55209 Mdot
.614 .55221 Mdot
.614 .55265 Mdot
.614 .55269 Mdot
.614 .5529 Mdot
.614 .5529 Mdot
.614 .55323 Mdot
.614 .55324 Mdot
.614 .55346 Mdot
.614 .5535 Mdot
.614 .55354 Mdot
.614 .55361 Mdot
.614 .55362 Mdot
.614 .55371 Mdot
.614 .55382 Mdot
.614 .55401 Mdot
.614 .55417 Mdot
.614 .55426 Mdot
.614 .55439 Mdot
.614 .55463 Mdot
.614 .55474 Mdot
.614 .55493 Mdot
.614 .55512 Mdot
.614 .55525 Mdot
.614 .55526 Mdot
.614 .55532 Mdot
.614 .55536 Mdot
.614 .55552 Mdot
.614 .55578 Mdot
.614 .55638 Mdot
.614 .55641 Mdot
.614 .55644 Mdot
.614 .55655 Mdot
.614 .55661 Mdot
.614 .55663 Mdot
.614 .55666 Mdot
.614 .55667 Mdot
.614 .55677 Mdot
.614 .55679 Mdot
.614 .55688 Mdot
.614 .5569 Mdot
.614 .55705 Mdot
.614 .55706 Mdot
.614 .55711 Mdot
.614 .55713 Mdot
.614 .5573 Mdot
.614 .55734 Mdot
.614 .55743 Mdot
.614 .55743 Mdot
.614 .55749 Mdot
.614 .55755 Mdot
.614 .55758 Mdot
.614 .55759 Mdot
.614 .55761 Mdot
.614 .55763 Mdot
.614 .55765 Mdot
.614 .55765 Mdot
.614 .5577 Mdot
.614 .55776 Mdot
.614 .5578 Mdot
.614 .55782 Mdot
.614 .55787 Mdot
.614 .55787 Mdot
.614 .55788 Mdot
.614 .55788 Mdot
.614 .55788 Mdot
.616 .16883 Mdot
.616 .16883 Mdot
.616 .16883 Mdot
.616 .16884 Mdot
.616 .16884 Mdot
.616 .16886 Mdot
.616 .16893 Mdot
.616 .16908 Mdot
.616 .16908 Mdot
.616 .16913 Mdot
.616 .16922 Mdot
.616 .16933 Mdot
.616 .16943 Mdot
.616 .16969 Mdot
.616 .16983 Mdot
.616 .16989 Mdot
.616 .1702 Mdot
.616 .17047 Mdot
.616 .17065 Mdot
.616 .17068 Mdot
.616 .17093 Mdot
.616 .17095 Mdot
.616 .17124 Mdot
.616 .17124 Mdot
.616 .17125 Mdot
.616 .17138 Mdot
.616 .17196 Mdot
.616 .17227 Mdot
.616 .17245 Mdot
.616 .17246 Mdot
.616 .17247 Mdot
.616 .17262 Mdot
.616 .17263 Mdot
.616 .17273 Mdot
.616 .17276 Mdot
.616 .17287 Mdot
.616 .17389 Mdot
.616 .17403 Mdot
.616 .17472 Mdot
.616 .17482 Mdot
.616 .17519 Mdot
.616 .17565 Mdot
.616 .17625 Mdot
.616 .17647 Mdot
.616 .1767 Mdot
.616 .17689 Mdot
.616 .17715 Mdot
.616 .17746 Mdot
.616 .17753 Mdot
.616 .17774 Mdot
.616 .17779 Mdot
.616 .17787 Mdot
.616 .17807 Mdot
.616 .17847 Mdot
.616 .17871 Mdot
.616 .17916 Mdot
.616 .17931 Mdot
.616 .17961 Mdot
.616 .1798 Mdot
.616 .18029 Mdot
.616 .18073 Mdot
.616 .18086 Mdot
.616 .18095 Mdot
.616 .18117 Mdot
.616 .18167 Mdot
.616 .18273 Mdot
.616 .18324 Mdot
.616 .18345 Mdot
.616 .18606 Mdot
.616 .18609 Mdot
.616 .18663 Mdot
.616 .1868 Mdot
.616 .18708 Mdot
.616 .18841 Mdot
.616 .1891 Mdot
.616 .1897 Mdot
.616 .18975 Mdot
.616 .1903 Mdot
.616 .19073 Mdot
.616 .19161 Mdot
.616 .19211 Mdot
.616 .19215 Mdot
.616 .19238 Mdot
.616 .193 Mdot
.616 .19437 Mdot
.616 .19534 Mdot
.616 .19661 Mdot
.616 .19696 Mdot
.616 .19864 Mdot
.616 .19986 Mdot
.616 .19992 Mdot
.616 .20207 Mdot
.616 .20207 Mdot
.616 .20289 Mdot
.616 .20293 Mdot
.616 .20318 Mdot
.616 .20363 Mdot
.616 .20396 Mdot
.616 .20481 Mdot
.616 .20524 Mdot
.616 .20548 Mdot
.616 .20624 Mdot
.616 .20663 Mdot
.616 .20702 Mdot
.616 .20795 Mdot
.616 .20844 Mdot
.616 .20881 Mdot
.616 .20948 Mdot
.616 .21037 Mdot
.616 .21115 Mdot
.616 .21176 Mdot
.616 .21353 Mdot
.616 .21421 Mdot
.616 .21488 Mdot
.616 .2149 Mdot
.616 .21508 Mdot
.616 .21508 Mdot
.616 .2162 Mdot
.616 .21735 Mdot
.616 .21849 Mdot
.616 .21964 Mdot
.616 .21965 Mdot
.616 .21971 Mdot
.616 .22172 Mdot
.616 .22337 Mdot
.616 .2234 Mdot
.616 .22391 Mdot
.616 .2247 Mdot
.616 .22494 Mdot
.616 .22511 Mdot
.616 .22702 Mdot
.616 .2276 Mdot
.616 .22763 Mdot
.616 .22772 Mdot
.616 .22775 Mdot
.616 .22805 Mdot
.616 .22853 Mdot
.616 .22861 Mdot
.616 .22899 Mdot
.616 .22916 Mdot
.616 .22976 Mdot
.616 .23243 Mdot
.616 .23285 Mdot
.616 .2335 Mdot
.616 .23558 Mdot
.616 .2358 Mdot
.616 .23598 Mdot
.616 .23645 Mdot
.616 .23682 Mdot
.616 .23726 Mdot
.616 .23796 Mdot
.616 .23872 Mdot
.616 .23898 Mdot
.616 .24057 Mdot
.616 .24068 Mdot
.616 .2409 Mdot
.616 .24166 Mdot
.616 .24337 Mdot
.616 .24435 Mdot
.616 .24574 Mdot
.616 .24651 Mdot
.616 .24686 Mdot
.616 .24774 Mdot
.616 .24786 Mdot
.616 .24821 Mdot
.616 .24873 Mdot
.616 .2521 Mdot
.616 .2527 Mdot
.616 .25449 Mdot
.616 .25461 Mdot
.616 .25502 Mdot
.616 .25527 Mdot
.616 .25719 Mdot
.616 .25784 Mdot
.616 .25907 Mdot
.616 .25969 Mdot
.616 .2598 Mdot
.616 .26155 Mdot
.616 .26234 Mdot
.616 .26325 Mdot
.616 .26347 Mdot
.616 .26376 Mdot
.616 .26432 Mdot
.616 .26455 Mdot
.616 .26479 Mdot
.616 .26525 Mdot
.616 .26639 Mdot
.616 .26684 Mdot
.616 .26739 Mdot
.616 .26878 Mdot
.616 .27103 Mdot
.616 .27262 Mdot
.616 .27362 Mdot
.616 .27426 Mdot
.616 .27429 Mdot
.616 .27535 Mdot
.616 .27569 Mdot
.616 .27617 Mdot
.616 .27665 Mdot
.616 .27871 Mdot
.616 .2792 Mdot
.616 .28158 Mdot
.616 .28226 Mdot
.616 .28383 Mdot
.616 .28428 Mdot
.616 .28527 Mdot
.616 .28549 Mdot
.616 .28649 Mdot
.616 .28677 Mdot
.616 .28748 Mdot
.616 .28757 Mdot
.616 .28763 Mdot
.616 .28789 Mdot
.616 .28797 Mdot
.616 .28836 Mdot
.616 .28868 Mdot
.616 .28893 Mdot
.616 .28922 Mdot
.616 .28951 Mdot
.616 .2915 Mdot
.616 .2927 Mdot
.616 .29464 Mdot
.616 .29507 Mdot
.616 .29509 Mdot
.616 .29537 Mdot
.616 .29575 Mdot
.616 .29636 Mdot
.616 .29791 Mdot
.616 .29928 Mdot
.616 .29937 Mdot
.616 .29987 Mdot
.616 .30065 Mdot
.616 .30346 Mdot
.616 .30392 Mdot
.616 .30539 Mdot
.616 .30668 Mdot
.616 .30765 Mdot
.616 .30803 Mdot
.616 .30848 Mdot
.616 .30951 Mdot
.616 .30968 Mdot
.616 .30971 Mdot
.616 .3126 Mdot
.616 .31294 Mdot
.616 .31353 Mdot
.616 .31566 Mdot
.616 .31617 Mdot
.616 .31639 Mdot
.616 .31937 Mdot
.616 .31943 Mdot
.616 .32012 Mdot
.616 .32014 Mdot
.616 .32045 Mdot
.616 .32262 Mdot
.616 .32264 Mdot
.616 .32315 Mdot
.616 .3232 Mdot
.616 .32512 Mdot
.616 .32639 Mdot
.616 .32707 Mdot
.616 .32771 Mdot
.616 .3308 Mdot
.616 .33205 Mdot
.616 .33222 Mdot
.616 .33329 Mdot
.616 .33389 Mdot
.616 .33398 Mdot
.616 .33472 Mdot
.616 .33626 Mdot
.616 .33885 Mdot
.616 .33947 Mdot
.616 .33971 Mdot
.616 .34082 Mdot
.616 .34191 Mdot
.616 .34336 Mdot
.616 .34395 Mdot
.616 .34611 Mdot
.616 .34725 Mdot
.616 .3484 Mdot
.616 .34921 Mdot
.616 .35065 Mdot
.616 .35117 Mdot
.616 .35135 Mdot
.616 .35184 Mdot
.616 .35237 Mdot
.616 .35264 Mdot
.616 .35517 Mdot
.616 .35614 Mdot
.616 .35749 Mdot
.616 .35787 Mdot
.616 .35825 Mdot
.616 .35835 Mdot
.616 .35958 Mdot
.616 .3608 Mdot
.616 .36081 Mdot
.616 .36274 Mdot
.616 .36363 Mdot
.616 .36458 Mdot
.616 .36487 Mdot
.616 .36489 Mdot
.616 .36493 Mdot
.616 .36494 Mdot
.616 .36509 Mdot
.616 .36537 Mdot
.616 .36556 Mdot
.616 .36564 Mdot
.616 .36722 Mdot
.616 .36743 Mdot
.616 .36774 Mdot
.616 .36872 Mdot
.616 .36882 Mdot
.616 .36891 Mdot
.616 .36912 Mdot
.616 .3695 Mdot
.616 .37102 Mdot
.616 .37107 Mdot
.616 .37272 Mdot
.616 .37334 Mdot
.616 .37384 Mdot
.616 .37422 Mdot
.616 .37427 Mdot
.616 .37443 Mdot
.616 .37611 Mdot
.616 .37718 Mdot
.616 .37827 Mdot
.616 .37854 Mdot
.616 .37935 Mdot
.616 .3804 Mdot
.616 .38086 Mdot
.616 .38098 Mdot
.616 .3813 Mdot
.616 .3814 Mdot
.616 .38301 Mdot
.616 .3839 Mdot
.616 .38493 Mdot
.616 .38519 Mdot
.616 .38574 Mdot
.616 .38592 Mdot
.616 .38611 Mdot
.616 .38691 Mdot
.616 .3871 Mdot
.616 .38801 Mdot
.616 .38988 Mdot
.616 .39025 Mdot
.616 .39058 Mdot
.616 .39071 Mdot
.616 .3908 Mdot
.616 .39091 Mdot
.616 .39176 Mdot
.616 .39221 Mdot
.616 .39308 Mdot
.616 .39319 Mdot
.616 .39356 Mdot
.616 .39484 Mdot
.616 .39513 Mdot
.616 .39615 Mdot
.616 .39684 Mdot
.616 .39731 Mdot
.616 .39765 Mdot
.616 .39779 Mdot
.616 .39795 Mdot
.616 .39942 Mdot
.616 .39975 Mdot
.616 .40051 Mdot
.616 .40076 Mdot
.616 .40181 Mdot
.616 .40207 Mdot
.616 .40208 Mdot
.616 .40219 Mdot
.616 .40426 Mdot
.616 .40472 Mdot
.616 .40578 Mdot
.616 .40622 Mdot
.616 .40664 Mdot
.616 .40685 Mdot
.616 .40713 Mdot
.616 .40876 Mdot
.616 .40884 Mdot
.616 .41028 Mdot
.616 .41206 Mdot
.616 .41273 Mdot
.616 .41295 Mdot
.616 .41313 Mdot
.616 .41498 Mdot
.616 .41555 Mdot
.616 .41661 Mdot
.616 .41691 Mdot
.616 .41723 Mdot
.616 .41732 Mdot
.616 .41733 Mdot
.616 .41734 Mdot
.616 .41735 Mdot
.616 .4174 Mdot
.616 .41749 Mdot
.616 .41755 Mdot
.616 .41758 Mdot
.616 .41786 Mdot
.616 .41828 Mdot
.616 .41861 Mdot
.616 .41864 Mdot
.616 .41867 Mdot
.616 .41874 Mdot
.616 .41887 Mdot
.616 .41938 Mdot
.616 .41994 Mdot
.616 .42015 Mdot
.616 .42031 Mdot
.616 .42044 Mdot
.616 .42046 Mdot
.616 .42051 Mdot
.616 .42179 Mdot
.616 .42188 Mdot
.616 .42215 Mdot
.616 .4225 Mdot
.616 .42265 Mdot
.616 .4228 Mdot
.616 .42283 Mdot
.616 .42336 Mdot
.616 .424 Mdot
.616 .42409 Mdot
.616 .42427 Mdot
.616 .42433 Mdot
.616 .4244 Mdot
.616 .42466 Mdot
.616 .42472 Mdot
.616 .42577 Mdot
.616 .42595 Mdot
.616 .42599 Mdot
.616 .42627 Mdot
.616 .42671 Mdot
.616 .42675 Mdot
.616 .42687 Mdot
.616 .42739 Mdot
.616 .42797 Mdot
.616 .42812 Mdot
.616 .42824 Mdot
.616 .42883 Mdot
.616 .42919 Mdot
.616 .42927 Mdot
.616 .42971 Mdot
.616 .42971 Mdot
.616 .42975 Mdot
.616 .43044 Mdot
.616 .43059 Mdot
.616 .43109 Mdot
.616 .43131 Mdot
.616 .43245 Mdot
.616 .43305 Mdot
.616 .43327 Mdot
.616 .43335 Mdot
.616 .43341 Mdot
.616 .43403 Mdot
.616 .43422 Mdot
.616 .43468 Mdot
.616 .43482 Mdot
.616 .43482 Mdot
.616 .43483 Mdot
.616 .43483 Mdot
.616 .43485 Mdot
.616 .43488 Mdot
.616 .4349 Mdot
.616 .43491 Mdot
.616 .435 Mdot
.616 .43514 Mdot
.616 .43525 Mdot
.616 .43527 Mdot
.616 .43528 Mdot
.616 .43534 Mdot
.616 .43551 Mdot
.616 .43571 Mdot
.616 .43577 Mdot
.616 .43583 Mdot
.616 .43587 Mdot
.616 .43588 Mdot
.616 .4359 Mdot
.616 .43633 Mdot
.616 .43645 Mdot
.616 .43657 Mdot
.616 .43662 Mdot
.616 .43667 Mdot
.616 .43668 Mdot
.616 .43711 Mdot
.616 .43719 Mdot
.616 .43721 Mdot
.616 .43732 Mdot
.616 .43768 Mdot
.616 .43775 Mdot
.616 .43785 Mdot
.616 .438 Mdot
.616 .43801 Mdot
.616 .43805 Mdot
.616 .43848 Mdot
.616 .43852 Mdot
.616 .43884 Mdot
.616 .43902 Mdot
.616 .43902 Mdot
.616 .43903 Mdot
.616 .43927 Mdot
.616 .43949 Mdot
.616 .44027 Mdot
.616 .44072 Mdot
.616 .4408 Mdot
.616 .4408 Mdot
.616 .44093 Mdot
.616 .4411 Mdot
.616 .44112 Mdot
.616 .44114 Mdot
.616 .44139 Mdot
.616 .44141 Mdot
.616 .44159 Mdot
.616 .44164 Mdot
.616 .44182 Mdot
.616 .44187 Mdot
.616 .44216 Mdot
.616 .44281 Mdot
.616 .44288 Mdot
.616 .44354 Mdot
.616 .44356 Mdot
.616 .44379 Mdot
.616 .44416 Mdot
.616 .44454 Mdot
.616 .44458 Mdot
.616 .44497 Mdot
.616 .44513 Mdot
.616 .44569 Mdot
.616 .44576 Mdot
.616 .4458 Mdot
.616 .44652 Mdot
.616 .4469 Mdot
.616 .44738 Mdot
.616 .44747 Mdot
.616 .44752 Mdot
.616 .44777 Mdot
.616 .44785 Mdot
.616 .4479 Mdot
.616 .44815 Mdot
.616 .44818 Mdot
.616 .44827 Mdot
.616 .44859 Mdot
.616 .4486 Mdot
.616 .44863 Mdot
.616 .44866 Mdot
.616 .44894 Mdot
.616 .44902 Mdot
.616 .44915 Mdot
.616 .44916 Mdot
.616 .44928 Mdot
.616 .44954 Mdot
.616 .44965 Mdot
.616 .45 Mdot
.616 .45004 Mdot
.616 .45008 Mdot
.616 .4502 Mdot
.616 .45054 Mdot
.616 .45119 Mdot
.616 .45131 Mdot
.616 .45159 Mdot
.616 .45167 Mdot
.616 .45206 Mdot
.616 .45208 Mdot
.616 .45208 Mdot
.616 .45232 Mdot
.616 .45237 Mdot
.616 .45257 Mdot
.616 .4529 Mdot
.616 .45296 Mdot
.616 .45305 Mdot
.616 .45336 Mdot
.616 .45365 Mdot
.616 .45372 Mdot
.616 .45374 Mdot
.616 .45398 Mdot
.616 .45414 Mdot
.616 .45416 Mdot
.616 .45425 Mdot
.616 .45483 Mdot
.616 .45486 Mdot
.616 .45501 Mdot
.616 .45504 Mdot
.616 .45508 Mdot
.616 .45518 Mdot
.616 .45522 Mdot
.616 .45557 Mdot
.616 .45586 Mdot
.616 .45588 Mdot
.616 .45596 Mdot
.616 .45604 Mdot
.616 .45623 Mdot
.616 .45638 Mdot
.616 .45643 Mdot
.616 .45711 Mdot
.616 .45714 Mdot
.616 .45715 Mdot
.616 .45722 Mdot
.616 .45731 Mdot
.616 .45742 Mdot
.616 .45772 Mdot
.616 .458 Mdot
.616 .45806 Mdot
.616 .4581 Mdot
.616 .45812 Mdot
.616 .45813 Mdot
.616 .45831 Mdot
.616 .45854 Mdot
.616 .45868 Mdot
.616 .4587 Mdot
.616 .45873 Mdot
.616 .45878 Mdot
.616 .45881 Mdot
.616 .45881 Mdot
.616 .45882 Mdot
.616 .45882 Mdot
.616 .45887 Mdot
.616 .45904 Mdot
.616 .4592 Mdot
.616 .45976 Mdot
.616 .46006 Mdot
.616 .46103 Mdot
.616 .46113 Mdot
.616 .46125 Mdot
.616 .46159 Mdot
.616 .46252 Mdot
.616 .46327 Mdot
.616 .46331 Mdot
.616 .46415 Mdot
.616 .46429 Mdot
.616 .4644 Mdot
.616 .46462 Mdot
.616 .46484 Mdot
.616 .46538 Mdot
.616 .46562 Mdot
.616 .46667 Mdot
.616 .46672 Mdot
.616 .46672 Mdot
.616 .46686 Mdot
.616 .46738 Mdot
.616 .46751 Mdot
.616 .46789 Mdot
.616 .46806 Mdot
.616 .46879 Mdot
.616 .46887 Mdot
.616 .46894 Mdot
.616 .46911 Mdot
.616 .46935 Mdot
.616 .46969 Mdot
.616 .4702 Mdot
.616 .47034 Mdot
.616 .47097 Mdot
.616 .47115 Mdot
.616 .4712 Mdot
.616 .47163 Mdot
.616 .47185 Mdot
.616 .47227 Mdot
.616 .47232 Mdot
.616 .47237 Mdot
.616 .47243 Mdot
.616 .47259 Mdot
.616 .47277 Mdot
.616 .47368 Mdot
.616 .47412 Mdot
.616 .47421 Mdot
.616 .47459 Mdot
.616 .47469 Mdot
.616 .47477 Mdot
.616 .47504 Mdot
.616 .47516 Mdot
.616 .47565 Mdot
.616 .47608 Mdot
.616 .47685 Mdot
.616 .47689 Mdot
.616 .47704 Mdot
.616 .4771 Mdot
.616 .47732 Mdot
.616 .47782 Mdot
.616 .4782 Mdot
.616 .47833 Mdot
.616 .47884 Mdot
.616 .47934 Mdot
.616 .48013 Mdot
.616 .4802 Mdot
.616 .48022 Mdot
.616 .4804 Mdot
.616 .48063 Mdot
.616 .48092 Mdot
.616 .48168 Mdot
.616 .4817 Mdot
.616 .48241 Mdot
.616 .48258 Mdot
.616 .48268 Mdot
.616 .48272 Mdot
.616 .48276 Mdot
.616 .48321 Mdot
.616 .48336 Mdot
.616 .48345 Mdot
.616 .48379 Mdot
.616 .48417 Mdot
.616 .48421 Mdot
.616 .48429 Mdot
.616 .48442 Mdot
.616 .48449 Mdot
.616 .48449 Mdot
.616 .48451 Mdot
.616 .48452 Mdot
.616 .48465 Mdot
.616 .48508 Mdot
.616 .48548 Mdot
.616 .48636 Mdot
.616 .48636 Mdot
.616 .48691 Mdot
.616 .48746 Mdot
.616 .4875 Mdot
.616 .48767 Mdot
.616 .48784 Mdot
.616 .48844 Mdot
.616 .48887 Mdot
.616 .48999 Mdot
.616 .49011 Mdot
.616 .49034 Mdot
.616 .49055 Mdot
.616 .49063 Mdot
.616 .49086 Mdot
.616 .49149 Mdot
.616 .49185 Mdot
.616 .49235 Mdot
.616 .49284 Mdot
.616 .49378 Mdot
.616 .49403 Mdot
.616 .49466 Mdot
.616 .49512 Mdot
.616 .4956 Mdot
.616 .4957 Mdot
.616 .49596 Mdot
.616 .49706 Mdot
.616 .49772 Mdot
.616 .49803 Mdot
.616 .49807 Mdot
.616 .49832 Mdot
.616 .49877 Mdot
.616 .49884 Mdot
.616 .49937 Mdot
.616 .50065 Mdot
.616 .50092 Mdot
.616 .5012 Mdot
.616 .50173 Mdot
.616 .50252 Mdot
.616 .50254 Mdot
.616 .50275 Mdot
.616 .50276 Mdot
.616 .50365 Mdot
.616 .50378 Mdot
.616 .50378 Mdot
.616 .50407 Mdot
.616 .50409 Mdot
.616 .5053 Mdot
.616 .50539 Mdot
.616 .5056 Mdot
.616 .50646 Mdot
.616 .5067 Mdot
.616 .50684 Mdot
.616 .508 Mdot
.616 .50801 Mdot
.616 .50808 Mdot
.616 .50849 Mdot
.616 .50867 Mdot
.616 .50882 Mdot
.616 .50921 Mdot
.616 .50972 Mdot
.616 .5103 Mdot
.616 .51048 Mdot
.616 .51159 Mdot
.616 .5119 Mdot
.616 .5121 Mdot
.616 .51213 Mdot
.616 .51267 Mdot
.616 .51328 Mdot
.616 .51352 Mdot
.616 .51366 Mdot
.616 .51377 Mdot
.616 .51378 Mdot
.616 .51394 Mdot
.616 .5147 Mdot
.616 .51516 Mdot
.616 .51593 Mdot
.616 .51604 Mdot
.616 .51615 Mdot
.616 .51625 Mdot
.616 .51637 Mdot
.616 .51652 Mdot
.616 .51656 Mdot
.616 .51665 Mdot
.616 .51668 Mdot
.616 .51671 Mdot
.616 .51698 Mdot
.616 .51709 Mdot
.616 .51747 Mdot
.616 .51756 Mdot
.616 .51793 Mdot
.616 .51811 Mdot
.616 .5187 Mdot
.616 .51896 Mdot
.616 .51986 Mdot
.616 .52005 Mdot
.616 .52083 Mdot
.616 .52101 Mdot
.616 .52119 Mdot
.616 .52131 Mdot
.616 .52171 Mdot
.616 .52172 Mdot
.616 .52196 Mdot
.616 .52234 Mdot
.616 .52293 Mdot
.616 .52377 Mdot
.616 .52428 Mdot
.616 .52449 Mdot
.616 .52465 Mdot
.616 .52507 Mdot
.616 .52524 Mdot
.616 .52533 Mdot
.616 .52542 Mdot
.616 .52562 Mdot
.616 .52573 Mdot
.616 .52581 Mdot
.616 .52614 Mdot
.616 .52643 Mdot
.616 .52708 Mdot
.616 .52711 Mdot
.616 .52734 Mdot
.616 .52779 Mdot
.616 .52803 Mdot
.616 .52872 Mdot
.616 .52882 Mdot
.616 .52896 Mdot
.616 .52901 Mdot
.616 .52965 Mdot
.616 .52987 Mdot
.616 .53108 Mdot
.616 .53127 Mdot
.616 .5314 Mdot
.616 .53144 Mdot
.616 .53175 Mdot
.616 .53188 Mdot
.616 .53215 Mdot
.616 .53265 Mdot
.616 .533 Mdot
.616 .53361 Mdot
.616 .53388 Mdot
.616 .53395 Mdot
.616 .53399 Mdot
.616 .53456 Mdot
.616 .53465 Mdot
.616 .53492 Mdot
.616 .53516 Mdot
.616 .53532 Mdot
.616 .53545 Mdot
.616 .53561 Mdot
.616 .53567 Mdot
.616 .53575 Mdot
.616 .53648 Mdot
.616 .53671 Mdot
.616 .53686 Mdot
.616 .53779 Mdot
.616 .538 Mdot
.616 .53806 Mdot
.616 .53819 Mdot
.616 .53822 Mdot
.616 .53839 Mdot
.616 .53849 Mdot
.616 .5385 Mdot
.616 .53853 Mdot
.616 .53854 Mdot
.616 .53874 Mdot
.616 .5394 Mdot
.616 .53946 Mdot
.616 .53955 Mdot
.616 .53982 Mdot
.616 .53999 Mdot
.616 .54 Mdot
.616 .54057 Mdot
.616 .54126 Mdot
.616 .54129 Mdot
.616 .54129 Mdot
.616 .54168 Mdot
.616 .54207 Mdot
.616 .54247 Mdot
.616 .54285 Mdot
.616 .54285 Mdot
.616 .54291 Mdot
.616 .54292 Mdot
.616 .54314 Mdot
.616 .54337 Mdot
.616 .54398 Mdot
.616 .54418 Mdot
.616 .54445 Mdot
.616 .54475 Mdot
.616 .54497 Mdot
.616 .5451 Mdot
.616 .54527 Mdot
.616 .54558 Mdot
.616 .54571 Mdot
.616 .54584 Mdot
.616 .5461 Mdot
.616 .54618 Mdot
.616 .54632 Mdot
.616 .54661 Mdot
.616 .54672 Mdot
.616 .54687 Mdot
.616 .54695 Mdot
.616 .54697 Mdot
.616 .54724 Mdot
.616 .54724 Mdot
.616 .54796 Mdot
.616 .54798 Mdot
.616 .54839 Mdot
.616 .54894 Mdot
.616 .54906 Mdot
.616 .54948 Mdot
.616 .5498 Mdot
.616 .55025 Mdot
.616 .55046 Mdot
.616 .55054 Mdot
.616 .55055 Mdot
.616 .55071 Mdot
.616 .551 Mdot
.616 .55115 Mdot
.616 .55133 Mdot
.616 .55134 Mdot
.616 .55154 Mdot
.616 .55177 Mdot
.616 .5522 Mdot
.616 .5523 Mdot
.616 .55235 Mdot
.616 .55253 Mdot
.616 .55254 Mdot
.616 .55339 Mdot
.616 .55346 Mdot
.616 .55362 Mdot
.616 .55397 Mdot
.616 .55413 Mdot
.616 .5542 Mdot
.616 .55423 Mdot
.616 .55428 Mdot
.616 .55442 Mdot
.616 .55458 Mdot
.616 .55464 Mdot
.616 .55474 Mdot
.616 .55479 Mdot
.616 .55493 Mdot
.616 .55501 Mdot
.616 .55514 Mdot
.616 .5552 Mdot
.616 .55523 Mdot
.616 .55524 Mdot
.616 .55531 Mdot
.616 .55533 Mdot
.616 .55544 Mdot
.616 .55552 Mdot
.616 .55558 Mdot
.616 .55566 Mdot
.616 .55573 Mdot
.616 .55592 Mdot
.616 .55607 Mdot
.616 .55619 Mdot
.616 .55622 Mdot
.616 .55644 Mdot
.616 .55649 Mdot
.616 .55682 Mdot
.616 .55685 Mdot
.616 .55686 Mdot
.616 .5569 Mdot
.616 .5569 Mdot
.616 .55695 Mdot
.616 .55695 Mdot
.616 .55695 Mdot
.616 .55701 Mdot
.616 .55711 Mdot
.616 .55729 Mdot
.616 .55734 Mdot
.616 .55734 Mdot
.616 .55734 Mdot
.616 .55743 Mdot
.616 .55744 Mdot
.616 .55752 Mdot
.616 .55753 Mdot
.616 .55759 Mdot
.616 .55768 Mdot
.616 .55777 Mdot
.616 .55779 Mdot
.616 .55784 Mdot
.616 .55792 Mdot
.616 .55795 Mdot
.616 .55799 Mdot
.616 .55802 Mdot
.616 .55803 Mdot
.616 .55803 Mdot
.616 .55808 Mdot
.616 .5581 Mdot
.616 .55811 Mdot
.616 .55811 Mdot
.616 .55811 Mdot
.616 .55811 Mdot
.616 .55811 Mdot
.618 .16817 Mdot
.618 .16817 Mdot
.618 .16829 Mdot
.618 .1683 Mdot
.618 .16834 Mdot
.618 .16835 Mdot
.618 .16849 Mdot
.618 .16855 Mdot
.618 .16866 Mdot
.618 .16875 Mdot
.618 .16882 Mdot
.618 .16888 Mdot
.618 .16906 Mdot
.618 .16925 Mdot
.618 .16928 Mdot
.618 .16979 Mdot
.618 .16986 Mdot
.618 .16998 Mdot
.618 .17004 Mdot
.618 .17014 Mdot
.618 .17031 Mdot
.618 .1704 Mdot
.618 .1704 Mdot
.618 .17043 Mdot
.618 .17059 Mdot
.618 .17117 Mdot
.618 .17174 Mdot
.618 .1723 Mdot
.618 .17232 Mdot
.618 .1732 Mdot
.618 .17367 Mdot
.618 .17372 Mdot
.618 .17373 Mdot
.618 .17417 Mdot
.618 .17436 Mdot
.618 .17438 Mdot
.618 .17439 Mdot
.618 .17471 Mdot
.618 .17573 Mdot
.618 .17629 Mdot
.618 .17657 Mdot
.618 .17663 Mdot
.618 .17673 Mdot
.618 .17675 Mdot
.618 .17713 Mdot
.618 .1777 Mdot
.618 .17772 Mdot
.618 .17792 Mdot
.618 .17801 Mdot
.618 .17848 Mdot
.618 .17851 Mdot
.618 .17869 Mdot
.618 .17893 Mdot
.618 .17893 Mdot
.618 .17896 Mdot
.618 .17924 Mdot
.618 .1798 Mdot
.618 .17995 Mdot
.618 .18113 Mdot
.618 .1813 Mdot
.618 .18131 Mdot
.618 .18143 Mdot
.618 .18214 Mdot
.618 .18333 Mdot
.618 .18351 Mdot
.618 .18402 Mdot
.618 .18403 Mdot
.618 .18421 Mdot
.618 .18649 Mdot
.618 .18651 Mdot
.618 .18665 Mdot
.618 .18683 Mdot
.618 .18742 Mdot
.618 .18862 Mdot
.618 .18886 Mdot
.618 .18891 Mdot
.618 .18902 Mdot
.618 .18913 Mdot
.618 .1902 Mdot
.618 .19068 Mdot
.618 .1922 Mdot
.618 .19233 Mdot
.618 .19328 Mdot
.618 .19387 Mdot
.618 .19419 Mdot
.618 .19498 Mdot
.618 .19551 Mdot
.618 .19566 Mdot
.618 .1971 Mdot
.618 .19795 Mdot
.618 .19935 Mdot
.618 .19945 Mdot
.618 .20147 Mdot
.618 .20168 Mdot
.618 .20232 Mdot
.618 .20317 Mdot
.618 .20334 Mdot
.618 .20395 Mdot
.618 .20396 Mdot
.618 .20446 Mdot
.618 .20485 Mdot
.618 .20497 Mdot
.618 .20583 Mdot
.618 .20804 Mdot
.618 .20832 Mdot
.618 .20838 Mdot
.618 .2084 Mdot
.618 .20879 Mdot
.618 .20896 Mdot
.618 .20901 Mdot
.618 .20974 Mdot
.618 .20996 Mdot
.618 .21002 Mdot
.618 .21142 Mdot
.618 .21153 Mdot
.618 .21153 Mdot
.618 .2117 Mdot
.618 .21245 Mdot
.618 .21248 Mdot
.618 .2126 Mdot
.618 .21284 Mdot
.618 .21348 Mdot
.618 .21381 Mdot
.618 .2141 Mdot
.618 .21498 Mdot
.618 .21537 Mdot
.618 .21652 Mdot
.618 .2171 Mdot
.618 .21815 Mdot
.618 .21947 Mdot
.618 .22004 Mdot
.618 .22071 Mdot
.618 .22193 Mdot
.618 .2231 Mdot
.618 .22321 Mdot
.618 .22587 Mdot
.618 .22612 Mdot
.618 .22622 Mdot
.618 .2264 Mdot
.618 .22836 Mdot
.618 .2287 Mdot
.618 .22934 Mdot
.618 .23028 Mdot
.618 .23179 Mdot
.618 .23318 Mdot
.618 .23366 Mdot
.618 .23424 Mdot
.618 .23487 Mdot
.618 .23582 Mdot
.618 .23602 Mdot
.618 .23614 Mdot
.618 .23747 Mdot
.618 .23863 Mdot
.618 .23871 Mdot
.618 .23963 Mdot
.618 .24108 Mdot
.618 .24252 Mdot
.618 .24306 Mdot
.618 .24339 Mdot
.618 .24382 Mdot
.618 .24411 Mdot
.618 .24565 Mdot
.618 .24654 Mdot
.618 .24719 Mdot
.618 .24818 Mdot
.618 .24895 Mdot
.618 .24996 Mdot
.618 .25019 Mdot
.618 .25085 Mdot
.618 .25234 Mdot
.618 .25357 Mdot
.618 .25374 Mdot
.618 .25701 Mdot
.618 .25859 Mdot
.618 .25921 Mdot
.618 .25942 Mdot
.618 .26025 Mdot
.618 .2606 Mdot
.618 .26141 Mdot
.618 .26221 Mdot
.618 .26224 Mdot
.618 .26236 Mdot
.618 .26314 Mdot
.618 .26336 Mdot
.618 .26519 Mdot
.618 .26527 Mdot
.618 .26551 Mdot
.618 .26581 Mdot
.618 .26631 Mdot
.618 .26724 Mdot
.618 .26869 Mdot
.618 .26969 Mdot
.618 .27026 Mdot
.618 .27126 Mdot
.618 .27173 Mdot
.618 .2723 Mdot
.618 .27295 Mdot
.618 .27376 Mdot
.618 .2762 Mdot
.618 .27653 Mdot
.618 .27827 Mdot
.618 .28044 Mdot
.618 .28045 Mdot
.618 .28291 Mdot
.618 .28302 Mdot
.618 .28458 Mdot
.618 .28549 Mdot
.618 .28578 Mdot
.618 .28654 Mdot
.618 .28665 Mdot
.618 .28688 Mdot
.618 .28804 Mdot
.618 .29071 Mdot
.618 .29121 Mdot
.618 .29149 Mdot
.618 .29216 Mdot
.618 .29443 Mdot
.618 .29448 Mdot
.618 .29832 Mdot
.618 .29921 Mdot
.618 .29938 Mdot
.618 .29969 Mdot
.618 .30224 Mdot
.618 .30293 Mdot
.618 .30319 Mdot
.618 .30631 Mdot
.618 .30819 Mdot
.618 .30978 Mdot
.618 .31168 Mdot
.618 .3121 Mdot
.618 .31218 Mdot
.618 .31315 Mdot
.618 .31351 Mdot
.618 .31406 Mdot
.618 .31453 Mdot
.618 .31647 Mdot
.618 .31659 Mdot
.618 .31814 Mdot
.618 .31908 Mdot
.618 .3195 Mdot
.618 .31971 Mdot
.618 .31979 Mdot
.618 .32015 Mdot
.618 .32142 Mdot
.618 .32254 Mdot
.618 .32506 Mdot
.618 .32579 Mdot
.618 .3259 Mdot
.618 .32685 Mdot
.618 .32687 Mdot
.618 .3287 Mdot
.618 .32942 Mdot
.618 .32977 Mdot
.618 .32984 Mdot
.618 .32997 Mdot
.618 .33045 Mdot
.618 .33113 Mdot
.618 .33202 Mdot
.618 .33205 Mdot
.618 .33252 Mdot
.618 .33252 Mdot
.618 .33285 Mdot
.618 .33362 Mdot
.618 .33482 Mdot
.618 .335 Mdot
.618 .33582 Mdot
.618 .33695 Mdot
.618 .33712 Mdot
.618 .33775 Mdot
.618 .33975 Mdot
.618 .33988 Mdot
.618 .34003 Mdot
.618 .34053 Mdot
.618 .3417 Mdot
.618 .34174 Mdot
.618 .34192 Mdot
.618 .34276 Mdot
.618 .34313 Mdot
.618 .34438 Mdot
.618 .3455 Mdot
.618 .34928 Mdot
.618 .35065 Mdot
.618 .35119 Mdot
.618 .35184 Mdot
.618 .35221 Mdot
.618 .35336 Mdot
.618 .35484 Mdot
.618 .35488 Mdot
.618 .35512 Mdot
.618 .35522 Mdot
.618 .35525 Mdot
.618 .35669 Mdot
.618 .35669 Mdot
.618 .35679 Mdot
.618 .35721 Mdot
.618 .35722 Mdot
.618 .35729 Mdot
.618 .35797 Mdot
.618 .35813 Mdot
.618 .35976 Mdot
.618 .36032 Mdot
.618 .36126 Mdot
.618 .36131 Mdot
.618 .36166 Mdot
.618 .36229 Mdot
.618 .3629 Mdot
.618 .36295 Mdot
.618 .36441 Mdot
.618 .36456 Mdot
.618 .36552 Mdot
.618 .366 Mdot
.618 .36645 Mdot
.618 .36835 Mdot
.618 .36864 Mdot
.618 .36918 Mdot
.618 .36924 Mdot
.618 .37038 Mdot
.618 .37042 Mdot
.618 .37215 Mdot
.618 .37253 Mdot
.618 .37273 Mdot
.618 .37285 Mdot
.618 .37354 Mdot
.618 .37542 Mdot
.618 .3758 Mdot
.618 .37644 Mdot
.618 .37703 Mdot
.618 .37906 Mdot
.618 .37975 Mdot
.618 .37989 Mdot
.618 .38022 Mdot
.618 .38055 Mdot
.618 .38061 Mdot
.618 .38093 Mdot
.618 .38102 Mdot
.618 .38176 Mdot
.618 .38179 Mdot
.618 .38259 Mdot
.618 .38356 Mdot
.618 .38418 Mdot
.618 .38459 Mdot
.618 .38517 Mdot
.618 .38612 Mdot
.618 .38692 Mdot
.618 .38775 Mdot
.618 .38874 Mdot
.618 .38978 Mdot
.618 .39007 Mdot
.618 .39011 Mdot
.618 .3902 Mdot
.618 .39063 Mdot
.618 .39301 Mdot
.618 .39302 Mdot
.618 .39443 Mdot
.618 .39476 Mdot
.618 .39586 Mdot
.618 .3962 Mdot
.618 .39924 Mdot
.618 .39939 Mdot
.618 .39942 Mdot
.618 .39976 Mdot
.618 .40008 Mdot
.618 .40025 Mdot
.618 .40097 Mdot
.618 .40184 Mdot
.618 .40199 Mdot
.618 .40206 Mdot
.618 .40209 Mdot
.618 .40222 Mdot
.618 .40418 Mdot
.618 .40455 Mdot
.618 .40562 Mdot
.618 .40579 Mdot
.618 .40602 Mdot
.618 .40634 Mdot
.618 .40688 Mdot
.618 .40729 Mdot
.618 .40735 Mdot
.618 .40763 Mdot
.618 .40897 Mdot
.618 .41012 Mdot
.618 .41054 Mdot
.618 .41092 Mdot
.618 .41266 Mdot
.618 .41284 Mdot
.618 .41416 Mdot
.618 .41419 Mdot
.618 .41421 Mdot
.618 .41469 Mdot
.618 .41472 Mdot
.618 .41487 Mdot
.618 .41489 Mdot
.618 .41512 Mdot
.618 .41517 Mdot
.618 .4159 Mdot
.618 .41622 Mdot
.618 .41624 Mdot
.618 .41676 Mdot
.618 .41678 Mdot
.618 .41727 Mdot
.618 .41732 Mdot
.618 .41764 Mdot
.618 .4178 Mdot
.618 .41795 Mdot
.618 .41886 Mdot
.618 .41888 Mdot
.618 .41926 Mdot
.618 .41927 Mdot
.618 .41984 Mdot
.618 .41997 Mdot
.618 .42004 Mdot
.618 .42031 Mdot
.618 .42106 Mdot
.618 .42127 Mdot
.618 .42147 Mdot
.618 .42214 Mdot
.618 .42242 Mdot
.618 .42264 Mdot
.618 .42266 Mdot
.618 .42276 Mdot
.618 .42279 Mdot
.618 .42304 Mdot
.618 .42331 Mdot
.618 .42363 Mdot
.618 .42398 Mdot
.618 .42448 Mdot
.618 .42502 Mdot
.618 .42535 Mdot
.618 .42579 Mdot
.618 .42581 Mdot
.618 .42598 Mdot
.618 .42677 Mdot
.618 .42677 Mdot
.618 .42724 Mdot
.618 .42772 Mdot
.618 .42884 Mdot
.618 .42889 Mdot
.618 .42971 Mdot
.618 .42976 Mdot
.618 .42978 Mdot
.618 .42979 Mdot
.618 .42983 Mdot
.618 .43049 Mdot
.618 .43097 Mdot
.618 .43102 Mdot
.618 .4311 Mdot
.618 .43164 Mdot
.618 .43208 Mdot
.618 .43247 Mdot
.618 .43261 Mdot
.618 .43274 Mdot
.618 .43332 Mdot
.618 .43338 Mdot
.618 .43383 Mdot
.618 .43384 Mdot
.618 .43406 Mdot
.618 .43407 Mdot
.618 .43414 Mdot
.618 .43416 Mdot
.618 .43441 Mdot
.618 .43451 Mdot
.618 .4347 Mdot
.618 .43487 Mdot
.618 .43488 Mdot
.618 .43499 Mdot
.618 .43504 Mdot
.618 .4351 Mdot
.618 .4354 Mdot
.618 .43541 Mdot
.618 .43554 Mdot
.618 .43554 Mdot
.618 .43573 Mdot
.618 .43578 Mdot
.618 .4358 Mdot
.618 .43614 Mdot
.618 .43621 Mdot
.618 .43628 Mdot
.618 .43651 Mdot
.618 .43668 Mdot
.618 .43668 Mdot
.618 .43681 Mdot
.618 .43701 Mdot
.618 .43713 Mdot
.618 .4373 Mdot
.618 .43748 Mdot
.618 .4376 Mdot
.618 .43774 Mdot
.618 .43775 Mdot
.618 .43781 Mdot
.618 .43808 Mdot
.618 .4384 Mdot
.618 .43878 Mdot
.618 .43909 Mdot
.618 .43912 Mdot
.618 .43951 Mdot
.618 .43973 Mdot
.618 .43989 Mdot
.618 .44007 Mdot
.618 .44085 Mdot
.618 .44103 Mdot
.618 .44107 Mdot
.618 .44107 Mdot
.618 .44115 Mdot
.618 .44133 Mdot
.618 .44206 Mdot
.618 .44219 Mdot
.618 .44244 Mdot
.618 .44252 Mdot
.618 .44257 Mdot
.618 .4429 Mdot
.618 .44298 Mdot
.618 .44301 Mdot
.618 .44307 Mdot
.618 .44337 Mdot
.618 .44345 Mdot
.618 .44348 Mdot
.618 .44361 Mdot
.618 .44422 Mdot
.618 .44454 Mdot
.618 .44458 Mdot
.618 .44459 Mdot
.618 .44464 Mdot
.618 .44487 Mdot
.618 .44491 Mdot
.618 .44506 Mdot
.618 .44514 Mdot
.618 .44556 Mdot
.618 .44566 Mdot
.618 .44571 Mdot
.618 .44584 Mdot
.618 .4464 Mdot
.618 .44649 Mdot
.618 .44662 Mdot
.618 .44684 Mdot
.618 .44704 Mdot
.618 .44726 Mdot
.618 .44779 Mdot
.618 .44825 Mdot
.618 .44834 Mdot
.618 .44847 Mdot
.618 .44851 Mdot
.618 .44855 Mdot
.618 .44876 Mdot
.618 .4489 Mdot
.618 .4489 Mdot
.618 .44897 Mdot
.618 .44918 Mdot
.618 .44927 Mdot
.618 .45012 Mdot
.618 .45016 Mdot
.618 .45048 Mdot
.618 .45056 Mdot
.618 .45064 Mdot
.618 .45085 Mdot
.618 .4511 Mdot
.618 .4514 Mdot
.618 .45145 Mdot
.618 .45148 Mdot
.618 .45175 Mdot
.618 .45211 Mdot
.618 .45213 Mdot
.618 .45214 Mdot
.618 .45215 Mdot
.618 .45218 Mdot
.618 .45263 Mdot
.618 .45266 Mdot
.618 .45328 Mdot
.618 .45355 Mdot
.618 .4538 Mdot
.618 .45381 Mdot
.618 .45424 Mdot
.618 .45433 Mdot
.618 .45434 Mdot
.618 .45458 Mdot
.618 .45476 Mdot
.618 .45506 Mdot
.618 .45533 Mdot
.618 .45552 Mdot
.618 .4557 Mdot
.618 .45584 Mdot
.618 .45598 Mdot
.618 .45599 Mdot
.618 .45605 Mdot
.618 .45606 Mdot
.618 .45618 Mdot
.618 .45633 Mdot
.618 .45669 Mdot
.618 .4568 Mdot
.618 .45691 Mdot
.618 .45732 Mdot
.618 .45746 Mdot
.618 .4575 Mdot
.618 .45757 Mdot
.618 .45787 Mdot
.618 .45788 Mdot
.618 .45809 Mdot
.618 .4581 Mdot
.618 .45858 Mdot
.618 .45866 Mdot
.618 .45874 Mdot
.618 .45892 Mdot
.618 .45894 Mdot
.618 .4592 Mdot
.618 .45921 Mdot
.618 .45949 Mdot
.618 .4595 Mdot
.618 .45967 Mdot
.618 .46005 Mdot
.618 .46008 Mdot
.618 .4602 Mdot
.618 .46021 Mdot
.618 .46029 Mdot
.618 .46031 Mdot
.618 .46056 Mdot
.618 .46057 Mdot
.618 .46058 Mdot
.618 .46128 Mdot
.618 .46137 Mdot
.618 .46228 Mdot
.618 .46247 Mdot
.618 .46269 Mdot
.618 .46329 Mdot
.618 .46398 Mdot
.618 .46412 Mdot
.618 .46415 Mdot
.618 .46436 Mdot
.618 .46464 Mdot
.618 .4648 Mdot
.618 .46492 Mdot
.618 .46501 Mdot
.618 .46555 Mdot
.618 .46574 Mdot
.618 .46674 Mdot
.618 .4668 Mdot
.618 .46681 Mdot
.618 .46685 Mdot
.618 .46692 Mdot
.618 .46736 Mdot
.618 .46773 Mdot
.618 .46781 Mdot
.618 .46797 Mdot
.618 .46815 Mdot
.618 .46816 Mdot
.618 .46823 Mdot
.618 .46975 Mdot
.618 .46992 Mdot
.618 .47046 Mdot
.618 .47062 Mdot
.618 .47131 Mdot
.618 .47132 Mdot
.618 .47248 Mdot
.618 .4727 Mdot
.618 .47274 Mdot
.618 .47276 Mdot
.618 .4729 Mdot
.618 .4734 Mdot
.618 .47388 Mdot
.618 .47428 Mdot
.618 .47467 Mdot
.618 .47513 Mdot
.618 .4754 Mdot
.618 .4756 Mdot
.618 .47589 Mdot
.618 .47636 Mdot
.618 .47674 Mdot
.618 .47675 Mdot
.618 .4771 Mdot
.618 .47714 Mdot
.618 .47729 Mdot
.618 .47732 Mdot
.618 .47748 Mdot
.618 .47764 Mdot
.618 .4777 Mdot
.618 .47803 Mdot
.618 .47898 Mdot
.618 .47926 Mdot
.618 .47956 Mdot
.618 .47974 Mdot
.618 .48061 Mdot
.618 .48093 Mdot
.618 .48099 Mdot
.618 .48108 Mdot
.618 .48126 Mdot
.618 .48205 Mdot
.618 .48207 Mdot
.618 .4826 Mdot
.618 .48262 Mdot
.618 .48287 Mdot
.618 .48301 Mdot
.618 .48387 Mdot
.618 .48408 Mdot
.618 .48429 Mdot
.618 .48473 Mdot
.618 .4848 Mdot
.618 .48546 Mdot
.618 .48548 Mdot
.618 .48575 Mdot
.618 .48604 Mdot
.618 .4862 Mdot
.618 .48622 Mdot
.618 .48664 Mdot
.618 .48689 Mdot
.618 .48762 Mdot
.618 .48769 Mdot
.618 .48799 Mdot
.618 .48802 Mdot
.618 .48803 Mdot
.618 .48822 Mdot
.618 .48826 Mdot
.618 .48826 Mdot
.618 .4889 Mdot
.618 .48892 Mdot
.618 .48896 Mdot
.618 .48907 Mdot
.618 .48908 Mdot
.618 .48974 Mdot
.618 .49024 Mdot
.618 .49041 Mdot
.618 .49069 Mdot
.618 .49093 Mdot
.618 .49153 Mdot
.618 .49317 Mdot
.618 .49365 Mdot
.618 .49419 Mdot
.618 .49435 Mdot
.618 .49471 Mdot
.618 .49479 Mdot
.618 .49481 Mdot
.618 .49531 Mdot
.618 .49552 Mdot
.618 .49558 Mdot
.618 .49564 Mdot
.618 .49649 Mdot
.618 .49676 Mdot
.618 .49683 Mdot
.618 .49731 Mdot
.618 .49766 Mdot
.618 .49773 Mdot
.618 .49824 Mdot
.618 .49856 Mdot
.618 .4987 Mdot
.618 .4987 Mdot
.618 .4989 Mdot
.618 .49891 Mdot
.618 .49928 Mdot
.618 .49957 Mdot
.618 .49977 Mdot
.618 .49982 Mdot
.618 .49985 Mdot
.618 .5 Mdot
.618 .5003 Mdot
.618 .50106 Mdot
.618 .50107 Mdot
.618 .50146 Mdot
.618 .5015 Mdot
.618 .50181 Mdot
.618 .50285 Mdot
.618 .50331 Mdot
.618 .50383 Mdot
.618 .50397 Mdot
.618 .50401 Mdot
.618 .50409 Mdot
.618 .50426 Mdot
.618 .50465 Mdot
.618 .50528 Mdot
.618 .50533 Mdot
.618 .50611 Mdot
.618 .5063 Mdot
.618 .50652 Mdot
.618 .50667 Mdot
.618 .50706 Mdot
.618 .50709 Mdot
.618 .50726 Mdot
.618 .50802 Mdot
.618 .50866 Mdot
.618 .5094 Mdot
.618 .51064 Mdot
.618 .51074 Mdot
.618 .51102 Mdot
.618 .51202 Mdot
.618 .51214 Mdot
.618 .51221 Mdot
.618 .51256 Mdot
.618 .51405 Mdot
.618 .51407 Mdot
.618 .51495 Mdot
.618 .51521 Mdot
.618 .51532 Mdot
.618 .51551 Mdot
.618 .51654 Mdot
.618 .51699 Mdot
.618 .51708 Mdot
.618 .51712 Mdot
.618 .51741 Mdot
.618 .51752 Mdot
.618 .51786 Mdot
.618 .51846 Mdot
.618 .5185 Mdot
.618 .51944 Mdot
.618 .51944 Mdot
.618 .52026 Mdot
.618 .52091 Mdot
.618 .52104 Mdot
.618 .52195 Mdot
.618 .52225 Mdot
.618 .5225 Mdot
.618 .52271 Mdot
.618 .52289 Mdot
.618 .52326 Mdot
.618 .52347 Mdot
.618 .52384 Mdot
.618 .52438 Mdot
.618 .52472 Mdot
.618 .52491 Mdot
.618 .52502 Mdot
.618 .52511 Mdot
.618 .52513 Mdot
.618 .52581 Mdot
.618 .52589 Mdot
.618 .52617 Mdot
.618 .52622 Mdot
.618 .52623 Mdot
.618 .52653 Mdot
.618 .52682 Mdot
.618 .52695 Mdot
.618 .52725 Mdot
.618 .52733 Mdot
.618 .52756 Mdot
.618 .52813 Mdot
.618 .52931 Mdot
.618 .52938 Mdot
.618 .52982 Mdot
.618 .53036 Mdot
.618 .5306 Mdot
.618 .53068 Mdot
.618 .53104 Mdot
.618 .53132 Mdot
.618 .53167 Mdot
.618 .5319 Mdot
.618 .53222 Mdot
.618 .53277 Mdot
.618 .53287 Mdot
.618 .53303 Mdot
.618 .53315 Mdot
.618 .53334 Mdot
.618 .53385 Mdot
.618 .53436 Mdot
.618 .53468 Mdot
.618 .53471 Mdot
.618 .53512 Mdot
.618 .53559 Mdot
.618 .53563 Mdot
.618 .5357 Mdot
.618 .53604 Mdot
.618 .53626 Mdot
.618 .53646 Mdot
.618 .53663 Mdot
.618 .53712 Mdot
.618 .53764 Mdot
.618 .53797 Mdot
.618 .53819 Mdot
.618 .53831 Mdot
.618 .53899 Mdot
.618 .53905 Mdot
.618 .53909 Mdot
.618 .53917 Mdot
.618 .54009 Mdot
.618 .54013 Mdot
.618 .54053 Mdot
.618 .54095 Mdot
.618 .54118 Mdot
.618 .54122 Mdot
.618 .54138 Mdot
.618 .54183 Mdot
.618 .54219 Mdot
.618 .54239 Mdot
.618 .54278 Mdot
.618 .54291 Mdot
.618 .54321 Mdot
.618 .54331 Mdot
.618 .54342 Mdot
.618 .54364 Mdot
.618 .54372 Mdot
.618 .54376 Mdot
.618 .54377 Mdot
.618 .54403 Mdot
.618 .54408 Mdot
.618 .54408 Mdot
.618 .54412 Mdot
.618 .5446 Mdot
.618 .54462 Mdot
.618 .54469 Mdot
.618 .54493 Mdot
.618 .54495 Mdot
.618 .54501 Mdot
.618 .54514 Mdot
.618 .54515 Mdot
.618 .54517 Mdot
.618 .54526 Mdot
.618 .54601 Mdot
.618 .5463 Mdot
.618 .54634 Mdot
.618 .54647 Mdot
.618 .54663 Mdot
.618 .54664 Mdot
.618 .54684 Mdot
.618 .5469 Mdot
.618 .54719 Mdot
.618 .5474 Mdot
.618 .54747 Mdot
.618 .54814 Mdot
.618 .54817 Mdot
.618 .54864 Mdot
.618 .54892 Mdot
.618 .5494 Mdot
.618 .54963 Mdot
.618 .54989 Mdot
.618 .55 Mdot
.618 .55019 Mdot
.618 .5505 Mdot
.618 .55055 Mdot
.618 .55105 Mdot
.618 .5512 Mdot
.618 .55155 Mdot
.618 .55159 Mdot
.618 .55163 Mdot
.618 .55165 Mdot
.618 .55172 Mdot
.618 .55212 Mdot
.618 .55231 Mdot
.618 .55237 Mdot
.618 .55242 Mdot
.618 .55242 Mdot
.618 .55317 Mdot
.618 .55322 Mdot
.618 .55323 Mdot
.618 .55339 Mdot
.618 .55345 Mdot
.618 .55384 Mdot
.618 .55407 Mdot
.618 .55411 Mdot
.618 .55411 Mdot
.618 .55417 Mdot
.618 .55455 Mdot
.618 .5546 Mdot
.618 .55478 Mdot
.618 .55487 Mdot
.618 .55488 Mdot
.618 .55488 Mdot
.618 .55496 Mdot
.618 .55502 Mdot
.618 .55503 Mdot
.618 .55518 Mdot
.618 .55521 Mdot
.618 .55527 Mdot
.618 .55528 Mdot
.618 .55547 Mdot
.618 .55559 Mdot
.618 .5556 Mdot
.618 .55563 Mdot
.618 .55565 Mdot
.618 .55574 Mdot
.618 .55592 Mdot
.618 .55625 Mdot
.618 .55635 Mdot
.618 .55635 Mdot
.618 .55636 Mdot
.618 .55642 Mdot
.618 .55656 Mdot
.618 .55657 Mdot
.618 .55658 Mdot
.618 .55673 Mdot
.618 .55702 Mdot
.618 .55702 Mdot
.618 .5572 Mdot
.618 .55738 Mdot
.618 .55757 Mdot
.618 .55762 Mdot
.618 .55763 Mdot
.618 .55763 Mdot
.618 .55766 Mdot
.618 .55771 Mdot
.618 .55775 Mdot
.618 .55777 Mdot
.618 .5578 Mdot
.618 .55783 Mdot
.618 .55799 Mdot
.618 .558 Mdot
.618 .55806 Mdot
.618 .55812 Mdot
.618 .55814 Mdot
.618 .55816 Mdot
.618 .55819 Mdot
.618 .55822 Mdot
.618 .55824 Mdot
.618 .55829 Mdot
.618 .55829 Mdot
.618 .5583 Mdot
.618 .55831 Mdot
.618 .55835 Mdot
.618 .55835 Mdot
.62 .16749 Mdot
.62 .16751 Mdot
.62 .16755 Mdot
.62 .16757 Mdot
.62 .16772 Mdot
.62 .16788 Mdot
.62 .16789 Mdot
.62 .16798 Mdot
.62 .16809 Mdot
.62 .16826 Mdot
.62 .16849 Mdot
.62 .16872 Mdot
.62 .16874 Mdot
.62 .16933 Mdot
.62 .16946 Mdot
.62 .1695 Mdot
.62 .16955 Mdot
.62 .16961 Mdot
.62 .16963 Mdot
.62 .16973 Mdot
.62 .16999 Mdot
.62 .17004 Mdot
.62 .17018 Mdot
.62 .1707 Mdot
.62 .17177 Mdot
.62 .17185 Mdot
.62 .17199 Mdot
.62 .17202 Mdot
.62 .17256 Mdot
.62 .17277 Mdot
.62 .17337 Mdot
.62 .17338 Mdot
.62 .17339 Mdot
.62 .17369 Mdot
.62 .17376 Mdot
.62 .17394 Mdot
.62 .17423 Mdot
.62 .17438 Mdot
.62 .17447 Mdot
.62 .17474 Mdot
.62 .17495 Mdot
.62 .17544 Mdot
.62 .17546 Mdot
.62 .1762 Mdot
.62 .17647 Mdot
.62 .17705 Mdot
.62 .17884 Mdot
.62 .17967 Mdot
.62 .18003 Mdot
.62 .18009 Mdot
.62 .18009 Mdot
.62 .18038 Mdot
.62 .1805 Mdot
.62 .18093 Mdot
.62 .18126 Mdot
.62 .18146 Mdot
.62 .18172 Mdot
.62 .18193 Mdot
.62 .18226 Mdot
.62 .18263 Mdot
.62 .18274 Mdot
.62 .18282 Mdot
.62 .18289 Mdot
.62 .18303 Mdot
.62 .18338 Mdot
.62 .1835 Mdot
.62 .18401 Mdot
.62 .18433 Mdot
.62 .18503 Mdot
.62 .18806 Mdot
.62 .18825 Mdot
.62 .1888 Mdot
.62 .18898 Mdot
.62 .18946 Mdot
.62 .19091 Mdot
.62 .19135 Mdot
.62 .19166 Mdot
.62 .19294 Mdot
.62 .19339 Mdot
.62 .19419 Mdot
.62 .19419 Mdot
.62 .19459 Mdot
.62 .19528 Mdot
.62 .19555 Mdot
.62 .19667 Mdot
.62 .19669 Mdot
.62 .19711 Mdot
.62 .19723 Mdot
.62 .19792 Mdot
.62 .19807 Mdot
.62 .20095 Mdot
.62 .20129 Mdot
.62 .20202 Mdot
.62 .20231 Mdot
.62 .20276 Mdot
.62 .20283 Mdot
.62 .203 Mdot
.62 .20435 Mdot
.62 .20453 Mdot
.62 .20481 Mdot
.62 .20524 Mdot
.62 .20746 Mdot
.62 .20795 Mdot
.62 .20808 Mdot
.62 .20979 Mdot
.62 .20988 Mdot
.62 .20991 Mdot
.62 .21061 Mdot
.62 .21065 Mdot
.62 .21188 Mdot
.62 .21212 Mdot
.62 .21223 Mdot
.62 .21311 Mdot
.62 .21337 Mdot
.62 .21352 Mdot
.62 .21352 Mdot
.62 .21396 Mdot
.62 .21428 Mdot
.62 .21441 Mdot
.62 .21559 Mdot
.62 .21594 Mdot
.62 .21599 Mdot
.62 .21707 Mdot
.62 .21764 Mdot
.62 .21799 Mdot
.62 .21801 Mdot
.62 .21887 Mdot
.62 .21896 Mdot
.62 .22002 Mdot
.62 .22184 Mdot
.62 .22244 Mdot
.62 .22324 Mdot
.62 .22336 Mdot
.62 .22382 Mdot
.62 .22509 Mdot
.62 .22588 Mdot
.62 .22609 Mdot
.62 .22618 Mdot
.62 .22659 Mdot
.62 .22669 Mdot
.62 .22888 Mdot
.62 .2289 Mdot
.62 .2289 Mdot
.62 .22922 Mdot
.62 .22942 Mdot
.62 .22951 Mdot
.62 .23014 Mdot
.62 .23163 Mdot
.62 .23186 Mdot
.62 .2338 Mdot
.62 .23567 Mdot
.62 .23696 Mdot
.62 .23757 Mdot
.62 .23785 Mdot
.62 .23839 Mdot
.62 .23842 Mdot
.62 .23869 Mdot
.62 .24018 Mdot
.62 .24074 Mdot
.62 .24091 Mdot
.62 .24214 Mdot
.62 .24317 Mdot
.62 .24351 Mdot
.62 .2467 Mdot
.62 .24738 Mdot
.62 .24751 Mdot
.62 .24789 Mdot
.62 .24816 Mdot
.62 .24876 Mdot
.62 .25055 Mdot
.62 .25168 Mdot
.62 .25172 Mdot
.62 .25182 Mdot
.62 .25197 Mdot
.62 .25305 Mdot
.62 .25346 Mdot
.62 .25385 Mdot
.62 .25472 Mdot
.62 .25518 Mdot
.62 .25698 Mdot
.62 .25749 Mdot
.62 .25798 Mdot
.62 .25877 Mdot
.62 .25941 Mdot
.62 .25948 Mdot
.62 .2599 Mdot
.62 .26081 Mdot
.62 .2615 Mdot
.62 .26153 Mdot
.62 .26192 Mdot
.62 .26194 Mdot
.62 .26298 Mdot
.62 .26306 Mdot
.62 .26618 Mdot
.62 .26711 Mdot
.62 .26929 Mdot
.62 .26984 Mdot
.62 .27012 Mdot
.62 .27013 Mdot
.62 .2709 Mdot
.62 .27185 Mdot
.62 .27369 Mdot
.62 .27588 Mdot
.62 .27631 Mdot
.62 .27646 Mdot
.62 .27899 Mdot
.62 .27959 Mdot
.62 .27989 Mdot
.62 .28034 Mdot
.62 .28045 Mdot
.62 .28096 Mdot
.62 .28179 Mdot
.62 .282 Mdot
.62 .28225 Mdot
.62 .28277 Mdot
.62 .28361 Mdot
.62 .28361 Mdot
.62 .28367 Mdot
.62 .28491 Mdot
.62 .28883 Mdot
.62 .28886 Mdot
.62 .2895 Mdot
.62 .28976 Mdot
.62 .29013 Mdot
.62 .29026 Mdot
.62 .29087 Mdot
.62 .29112 Mdot
.62 .29169 Mdot
.62 .2926 Mdot
.62 .29382 Mdot
.62 .2941 Mdot
.62 .29623 Mdot
.62 .2973 Mdot
.62 .29856 Mdot
.62 .29889 Mdot
.62 .29898 Mdot
.62 .30104 Mdot
.62 .30109 Mdot
.62 .30275 Mdot
.62 .30782 Mdot
.62 .30841 Mdot
.62 .31082 Mdot
.62 .31106 Mdot
.62 .31246 Mdot
.62 .31349 Mdot
.62 .31356 Mdot
.62 .31402 Mdot
.62 .31455 Mdot
.62 .31616 Mdot
.62 .3187 Mdot
.62 .31926 Mdot
.62 .31941 Mdot
.62 .31969 Mdot
.62 .32031 Mdot
.62 .32041 Mdot
.62 .32379 Mdot
.62 .32418 Mdot
.62 .3251 Mdot
.62 .32636 Mdot
.62 .32637 Mdot
.62 .32681 Mdot
.62 .32757 Mdot
.62 .33012 Mdot
.62 .33044 Mdot
.62 .33113 Mdot
.62 .334 Mdot
.62 .33473 Mdot
.62 .33485 Mdot
.62 .33559 Mdot
.62 .33689 Mdot
.62 .337 Mdot
.62 .33713 Mdot
.62 .33727 Mdot
.62 .3423 Mdot
.62 .34267 Mdot
.62 .34378 Mdot
.62 .34412 Mdot
.62 .34528 Mdot
.62 .34561 Mdot
.62 .34618 Mdot
.62 .34646 Mdot
.62 .34694 Mdot
.62 .34828 Mdot
.62 .34884 Mdot
.62 .35071 Mdot
.62 .35138 Mdot
.62 .35157 Mdot
.62 .3519 Mdot
.62 .352 Mdot
.62 .35283 Mdot
.62 .35294 Mdot
.62 .35311 Mdot
.62 .35337 Mdot
.62 .35469 Mdot
.62 .35604 Mdot
.62 .35735 Mdot
.62 .35742 Mdot
.62 .3579 Mdot
.62 .35805 Mdot
.62 .35813 Mdot
.62 .35837 Mdot
.62 .35945 Mdot
.62 .35948 Mdot
.62 .36036 Mdot
.62 .36055 Mdot
.62 .36101 Mdot
.62 .36161 Mdot
.62 .36254 Mdot
.62 .36325 Mdot
.62 .36355 Mdot
.62 .36468 Mdot
.62 .36473 Mdot
.62 .36493 Mdot
.62 .36605 Mdot
.62 .36606 Mdot
.62 .36666 Mdot
.62 .36737 Mdot
.62 .3684 Mdot
.62 .37027 Mdot
.62 .37054 Mdot
.62 .37159 Mdot
.62 .37166 Mdot
.62 .37221 Mdot
.62 .37267 Mdot
.62 .37282 Mdot
.62 .37423 Mdot
.62 .37458 Mdot
.62 .37474 Mdot
.62 .37512 Mdot
.62 .37637 Mdot
.62 .37639 Mdot
.62 .37643 Mdot
.62 .3765 Mdot
.62 .37696 Mdot
.62 .37766 Mdot
.62 .3786 Mdot
.62 .37882 Mdot
.62 .37902 Mdot
.62 .37981 Mdot
.62 .38048 Mdot
.62 .38064 Mdot
.62 .38065 Mdot
.62 .3811 Mdot
.62 .38273 Mdot
.62 .3836 Mdot
.62 .38381 Mdot
.62 .38393 Mdot
.62 .38393 Mdot
.62 .38461 Mdot
.62 .38533 Mdot
.62 .38634 Mdot
.62 .38737 Mdot
.62 .38761 Mdot
.62 .38772 Mdot
.62 .38793 Mdot
.62 .38813 Mdot
.62 .38844 Mdot
.62 .38962 Mdot
.62 .39109 Mdot
.62 .3911 Mdot
.62 .39158 Mdot
.62 .39163 Mdot
.62 .39249 Mdot
.62 .39304 Mdot
.62 .39383 Mdot
.62 .39483 Mdot
.62 .39557 Mdot
.62 .39822 Mdot
.62 .39965 Mdot
.62 .40021 Mdot
.62 .40185 Mdot
.62 .4022 Mdot
.62 .40241 Mdot
.62 .40713 Mdot
.62 .40767 Mdot
.62 .4082 Mdot
.62 .41046 Mdot
.62 .41096 Mdot
.62 .41107 Mdot
.62 .41126 Mdot
.62 .41136 Mdot
.62 .41152 Mdot
.62 .41197 Mdot
.62 .41216 Mdot
.62 .41302 Mdot
.62 .41308 Mdot
.62 .41319 Mdot
.62 .41354 Mdot
.62 .41359 Mdot
.62 .41412 Mdot
.62 .41457 Mdot
.62 .41502 Mdot
.62 .41525 Mdot
.62 .41536 Mdot
.62 .41571 Mdot
.62 .41608 Mdot
.62 .41623 Mdot
.62 .41643 Mdot
.62 .41698 Mdot
.62 .41746 Mdot
.62 .41747 Mdot
.62 .41754 Mdot
.62 .41791 Mdot
.62 .41792 Mdot
.62 .41812 Mdot
.62 .41835 Mdot
.62 .41869 Mdot
.62 .41932 Mdot
.62 .4194 Mdot
.62 .41975 Mdot
.62 .41978 Mdot
.62 .42016 Mdot
.62 .42063 Mdot
.62 .42075 Mdot
.62 .42134 Mdot
.62 .42138 Mdot
.62 .42153 Mdot
.62 .42177 Mdot
.62 .42208 Mdot
.62 .42215 Mdot
.62 .42222 Mdot
.62 .4227 Mdot
.62 .42275 Mdot
.62 .4229 Mdot
.62 .42373 Mdot
.62 .4238 Mdot
.62 .42407 Mdot
.62 .4243 Mdot
.62 .42498 Mdot
.62 .42506 Mdot
.62 .42517 Mdot
.62 .42523 Mdot
.62 .42534 Mdot
.62 .42573 Mdot
.62 .42621 Mdot
.62 .42622 Mdot
.62 .42639 Mdot
.62 .42686 Mdot
.62 .42745 Mdot
.62 .4277 Mdot
.62 .4299 Mdot
.62 .43154 Mdot
.62 .43172 Mdot
.62 .4319 Mdot
.62 .43265 Mdot
.62 .43282 Mdot
.62 .43285 Mdot
.62 .43292 Mdot
.62 .43295 Mdot
.62 .43315 Mdot
.62 .43322 Mdot
.62 .4335 Mdot
.62 .43352 Mdot
.62 .43356 Mdot
.62 .43368 Mdot
.62 .43387 Mdot
.62 .43417 Mdot
.62 .43425 Mdot
.62 .43429 Mdot
.62 .43441 Mdot
.62 .43458 Mdot
.62 .43483 Mdot
.62 .43499 Mdot
.62 .43502 Mdot
.62 .43515 Mdot
.62 .43562 Mdot
.62 .43565 Mdot
.62 .43576 Mdot
.62 .4359 Mdot
.62 .43606 Mdot
.62 .4363 Mdot
.62 .43636 Mdot
.62 .43644 Mdot
.62 .43655 Mdot
.62 .43659 Mdot
.62 .43676 Mdot
.62 .43683 Mdot
.62 .43713 Mdot
.62 .43722 Mdot
.62 .4373 Mdot
.62 .43755 Mdot
.62 .43759 Mdot
.62 .43761 Mdot
.62 .43778 Mdot
.62 .43816 Mdot
.62 .43845 Mdot
.62 .43975 Mdot
.62 .43982 Mdot
.62 .43988 Mdot
.62 .44013 Mdot
.62 .44031 Mdot
.62 .44044 Mdot
.62 .44068 Mdot
.62 .44069 Mdot
.62 .44073 Mdot
.62 .44088 Mdot
.62 .44115 Mdot
.62 .44116 Mdot
.62 .4412 Mdot
.62 .44125 Mdot
.62 .44167 Mdot
.62 .44183 Mdot
.62 .44189 Mdot
.62 .44202 Mdot
.62 .44261 Mdot
.62 .4427 Mdot
.62 .44289 Mdot
.62 .44296 Mdot
.62 .44305 Mdot
.62 .44306 Mdot
.62 .44307 Mdot
.62 .44308 Mdot
.62 .44331 Mdot
.62 .44359 Mdot
.62 .44368 Mdot
.62 .44371 Mdot
.62 .44393 Mdot
.62 .44402 Mdot
.62 .44414 Mdot
.62 .44429 Mdot
.62 .44451 Mdot
.62 .44466 Mdot
.62 .44471 Mdot
.62 .44475 Mdot
.62 .44487 Mdot
.62 .44492 Mdot
.62 .44534 Mdot
.62 .44538 Mdot
.62 .44572 Mdot
.62 .44572 Mdot
.62 .44574 Mdot
.62 .44577 Mdot
.62 .44577 Mdot
.62 .44593 Mdot
.62 .44605 Mdot
.62 .44636 Mdot
.62 .44651 Mdot
.62 .44655 Mdot
.62 .44658 Mdot
.62 .4475 Mdot
.62 .44772 Mdot
.62 .44782 Mdot
.62 .44783 Mdot
.62 .44809 Mdot
.62 .44827 Mdot
.62 .44879 Mdot
.62 .44887 Mdot
.62 .44894 Mdot
.62 .44896 Mdot
.62 .44922 Mdot
.62 .4494 Mdot
.62 .44964 Mdot
.62 .44971 Mdot
.62 .44973 Mdot
.62 .45012 Mdot
.62 .45035 Mdot
.62 .45064 Mdot
.62 .45106 Mdot
.62 .45116 Mdot
.62 .45126 Mdot
.62 .45217 Mdot
.62 .45339 Mdot
.62 .45353 Mdot
.62 .45385 Mdot
.62 .45411 Mdot
.62 .45421 Mdot
.62 .45421 Mdot
.62 .45447 Mdot
.62 .45469 Mdot
.62 .45475 Mdot
.62 .45478 Mdot
.62 .45484 Mdot
.62 .45488 Mdot
.62 .45525 Mdot
.62 .45538 Mdot
.62 .45552 Mdot
.62 .45556 Mdot
.62 .45601 Mdot
.62 .45609 Mdot
.62 .45612 Mdot
.62 .45639 Mdot
.62 .45642 Mdot
.62 .45646 Mdot
.62 .45663 Mdot
.62 .45675 Mdot
.62 .45684 Mdot
.62 .45686 Mdot
.62 .45718 Mdot
.62 .45724 Mdot
.62 .45749 Mdot
.62 .4577 Mdot
.62 .45771 Mdot
.62 .4579 Mdot
.62 .45794 Mdot
.62 .45828 Mdot
.62 .45846 Mdot
.62 .45858 Mdot
.62 .45869 Mdot
.62 .45869 Mdot
.62 .45889 Mdot
.62 .45893 Mdot
.62 .45893 Mdot
.62 .45919 Mdot
.62 .45948 Mdot
.62 .45958 Mdot
.62 .45966 Mdot
.62 .45986 Mdot
.62 .46005 Mdot
.62 .4601 Mdot
.62 .46023 Mdot
.62 .46046 Mdot
.62 .46069 Mdot
.62 .46097 Mdot
.62 .461 Mdot
.62 .46118 Mdot
.62 .46124 Mdot
.62 .46127 Mdot
.62 .46172 Mdot
.62 .46182 Mdot
.62 .46205 Mdot
.62 .46214 Mdot
.62 .46219 Mdot
.62 .46229 Mdot
.62 .46235 Mdot
.62 .46261 Mdot
.62 .46377 Mdot
.62 .46404 Mdot
.62 .46432 Mdot
.62 .46672 Mdot
.62 .46683 Mdot
.62 .46701 Mdot
.62 .46783 Mdot
.62 .46811 Mdot
.62 .46882 Mdot
.62 .47014 Mdot
.62 .47051 Mdot
.62 .471 Mdot
.62 .47138 Mdot
.62 .47165 Mdot
.62 .47208 Mdot
.62 .4721 Mdot
.62 .47233 Mdot
.62 .47234 Mdot
.62 .47305 Mdot
.62 .47362 Mdot
.62 .47378 Mdot
.62 .47387 Mdot
.62 .47398 Mdot
.62 .47403 Mdot
.62 .47414 Mdot
.62 .47464 Mdot
.62 .47513 Mdot
.62 .47547 Mdot
.62 .47579 Mdot
.62 .4758 Mdot
.62 .47585 Mdot
.62 .47595 Mdot
.62 .47637 Mdot
.62 .47714 Mdot
.62 .47735 Mdot
.62 .47736 Mdot
.62 .47743 Mdot
.62 .47775 Mdot
.62 .47812 Mdot
.62 .47822 Mdot
.62 .47832 Mdot
.62 .47876 Mdot
.62 .47909 Mdot
.62 .4793 Mdot
.62 .47934 Mdot
.62 .47935 Mdot
.62 .47936 Mdot
.62 .47995 Mdot
.62 .48012 Mdot
.62 .4802 Mdot
.62 .48036 Mdot
.62 .48101 Mdot
.62 .48108 Mdot
.62 .4813 Mdot
.62 .48155 Mdot
.62 .48159 Mdot
.62 .48207 Mdot
.62 .48219 Mdot
.62 .48305 Mdot
.62 .48352 Mdot
.62 .48385 Mdot
.62 .48412 Mdot
.62 .48412 Mdot
.62 .48463 Mdot
.62 .48472 Mdot
.62 .48474 Mdot
.62 .48526 Mdot
.62 .48539 Mdot
.62 .48571 Mdot
.62 .48613 Mdot
.62 .4864 Mdot
.62 .4866 Mdot
.62 .48669 Mdot
.62 .48709 Mdot
.62 .4871 Mdot
.62 .48758 Mdot
.62 .48769 Mdot
.62 .48772 Mdot
.62 .48779 Mdot
.62 .48801 Mdot
.62 .48803 Mdot
.62 .48862 Mdot
.62 .48921 Mdot
.62 .4898 Mdot
.62 .48991 Mdot
.62 .48999 Mdot
.62 .49003 Mdot
.62 .4904 Mdot
.62 .49044 Mdot
.62 .49059 Mdot
.62 .49067 Mdot
.62 .49096 Mdot
.62 .49178 Mdot
.62 .49203 Mdot
.62 .49261 Mdot
.62 .49282 Mdot
.62 .49294 Mdot
.62 .49318 Mdot
.62 .49333 Mdot
.62 .49383 Mdot
.62 .49397 Mdot
.62 .49445 Mdot
.62 .49461 Mdot
.62 .49676 Mdot
.62 .49681 Mdot
.62 .49687 Mdot
.62 .49692 Mdot
.62 .49747 Mdot
.62 .49778 Mdot
.62 .49783 Mdot
.62 .49814 Mdot
.62 .49934 Mdot
.62 .49963 Mdot
.62 .49976 Mdot
.62 .50082 Mdot
.62 .50114 Mdot
.62 .50132 Mdot
.62 .50133 Mdot
.62 .50185 Mdot
.62 .50223 Mdot
.62 .50239 Mdot
.62 .50377 Mdot
.62 .50382 Mdot
.62 .50407 Mdot
.62 .50418 Mdot
.62 .50424 Mdot
.62 .50447 Mdot
.62 .5055 Mdot
.62 .50615 Mdot
.62 .50637 Mdot
.62 .50656 Mdot
.62 .50658 Mdot
.62 .507 Mdot
.62 .50756 Mdot
.62 .50766 Mdot
.62 .50862 Mdot
.62 .50885 Mdot
.62 .51086 Mdot
.62 .51152 Mdot
.62 .51154 Mdot
.62 .51235 Mdot
.62 .51238 Mdot
.62 .51251 Mdot
.62 .513 Mdot
.62 .51342 Mdot
.62 .51425 Mdot
.62 .51436 Mdot
.62 .51483 Mdot
.62 .51518 Mdot
.62 .5154 Mdot
.62 .5155 Mdot
.62 .51573 Mdot
.62 .51578 Mdot
.62 .51592 Mdot
.62 .51603 Mdot
.62 .51627 Mdot
.62 .51628 Mdot
.62 .51778 Mdot
.62 .51826 Mdot
.62 .51828 Mdot
.62 .51828 Mdot
.62 .5186 Mdot
.62 .5188 Mdot
.62 .51889 Mdot
.62 .51897 Mdot
.62 .51928 Mdot
.62 .51948 Mdot
.62 .51952 Mdot
.62 .51969 Mdot
.62 .5198 Mdot
.62 .52003 Mdot
.62 .52098 Mdot
.62 .52104 Mdot
.62 .5212 Mdot
.62 .52202 Mdot
.62 .52271 Mdot
.62 .52306 Mdot
.62 .52335 Mdot
.62 .52335 Mdot
.62 .52346 Mdot
.62 .52366 Mdot
.62 .52447 Mdot
.62 .52481 Mdot
.62 .52596 Mdot
.62 .52599 Mdot
.62 .52637 Mdot
.62 .52638 Mdot
.62 .52652 Mdot
.62 .52653 Mdot
.62 .52678 Mdot
.62 .52711 Mdot
.62 .52727 Mdot
.62 .52729 Mdot
.62 .52753 Mdot
.62 .52782 Mdot
.62 .52799 Mdot
.62 .52818 Mdot
.62 .52883 Mdot
.62 .529 Mdot
.62 .52931 Mdot
.62 .52946 Mdot
.62 .5296 Mdot
.62 .52999 Mdot
.62 .53005 Mdot
.62 .53008 Mdot
.62 .5301 Mdot
.62 .5305 Mdot
.62 .53114 Mdot
.62 .53136 Mdot
.62 .53146 Mdot
.62 .53159 Mdot
.62 .53164 Mdot
.62 .53188 Mdot
.62 .53302 Mdot
.62 .53314 Mdot
.62 .53351 Mdot
.62 .53394 Mdot
.62 .534 Mdot
.62 .5342 Mdot
.62 .53473 Mdot
.62 .53482 Mdot
.62 .53483 Mdot
.62 .53502 Mdot
.62 .53512 Mdot
.62 .53533 Mdot
.62 .53579 Mdot
.62 .53644 Mdot
.62 .53712 Mdot
.62 .5372 Mdot
.62 .53772 Mdot
.62 .53794 Mdot
.62 .53797 Mdot
.62 .53804 Mdot
.62 .53815 Mdot
.62 .53815 Mdot
.62 .53816 Mdot
.62 .53892 Mdot
.62 .53895 Mdot
.62 .5391 Mdot
.62 .53913 Mdot
.62 .5392 Mdot
.62 .53947 Mdot
.62 .53991 Mdot
.62 .54007 Mdot
.62 .54011 Mdot
.62 .54039 Mdot
.62 .54059 Mdot
.62 .54122 Mdot
.62 .54158 Mdot
.62 .54161 Mdot
.62 .54191 Mdot
.62 .54191 Mdot
.62 .54203 Mdot
.62 .54223 Mdot
.62 .5426 Mdot
.62 .54261 Mdot
.62 .54273 Mdot
.62 .54313 Mdot
.62 .54318 Mdot
.62 .54329 Mdot
.62 .54344 Mdot
.62 .54344 Mdot
.62 .54349 Mdot
.62 .54358 Mdot
.62 .54388 Mdot
.62 .54391 Mdot
.62 .54399 Mdot
.62 .54441 Mdot
.62 .54442 Mdot
.62 .54466 Mdot
.62 .54467 Mdot
.62 .5447 Mdot
.62 .54528 Mdot
.62 .54532 Mdot
.62 .54549 Mdot
.62 .54623 Mdot
.62 .54638 Mdot
.62 .54647 Mdot
.62 .54653 Mdot
.62 .54699 Mdot
.62 .54704 Mdot
.62 .54707 Mdot
.62 .54722 Mdot
.62 .54731 Mdot
.62 .54756 Mdot
.62 .54767 Mdot
.62 .54863 Mdot
.62 .54868 Mdot
.62 .54891 Mdot
.62 .54895 Mdot
.62 .54909 Mdot
.62 .54909 Mdot
.62 .54946 Mdot
.62 .54955 Mdot
.62 .54978 Mdot
.62 .54991 Mdot
.62 .54991 Mdot
.62 .55018 Mdot
.62 .55033 Mdot
.62 .55075 Mdot
.62 .55085 Mdot
.62 .55099 Mdot
.62 .55147 Mdot
.62 .55163 Mdot
.62 .55169 Mdot
.62 .55187 Mdot
.62 .55193 Mdot
.62 .55292 Mdot
.62 .55315 Mdot
.62 .55326 Mdot
.62 .55342 Mdot
.62 .55346 Mdot
.62 .55357 Mdot
.62 .55362 Mdot
.62 .55364 Mdot
.62 .55367 Mdot
.62 .55371 Mdot
.62 .55383 Mdot
.62 .55393 Mdot
.62 .554 Mdot
.62 .55409 Mdot
.62 .55415 Mdot
.62 .55426 Mdot
.62 .5544 Mdot
.62 .55443 Mdot
.62 .55453 Mdot
.62 .55453 Mdot
.62 .55455 Mdot
.62 .55467 Mdot
.62 .55494 Mdot
.62 .55552 Mdot
.62 .5557 Mdot
.62 .55579 Mdot
.62 .55603 Mdot
.62 .55603 Mdot
.62 .55619 Mdot
.62 .55626 Mdot
.62 .55635 Mdot
.62 .55638 Mdot
.62 .55642 Mdot
.62 .55652 Mdot
.62 .55657 Mdot
.62 .5566 Mdot
.62 .55669 Mdot
.62 .5567 Mdot
.62 .5567 Mdot
.62 .55689 Mdot
.62 .55696 Mdot
.62 .55713 Mdot
.62 .55714 Mdot
.62 .55719 Mdot
.62 .55721 Mdot
.62 .55756 Mdot
.62 .55772 Mdot
.62 .55777 Mdot
.62 .55778 Mdot
.62 .55787 Mdot
.62 .5579 Mdot
.62 .55791 Mdot
.62 .55793 Mdot
.62 .55794 Mdot
.62 .55795 Mdot
.62 .558 Mdot
.62 .55819 Mdot
.62 .55819 Mdot
.62 .55826 Mdot
.62 .55834 Mdot
.62 .55839 Mdot
.62 .55843 Mdot
.62 .55846 Mdot
.62 .55846 Mdot
.62 .55851 Mdot
.62 .55856 Mdot
.62 .55856 Mdot
.62 .55858 Mdot
.62 .55858 Mdot
.622 .16681 Mdot
.622 .16682 Mdot
.622 .16682 Mdot
.622 .1669 Mdot
.622 .16692 Mdot
.622 .16701 Mdot
.622 .16712 Mdot
.622 .16715 Mdot
.622 .16721 Mdot
.622 .16721 Mdot
.622 .16739 Mdot
.622 .16752 Mdot
.622 .16791 Mdot
.622 .16803 Mdot
.622 .16812 Mdot
.622 .16831 Mdot
.622 .16852 Mdot
.622 .16862 Mdot
.622 .16906 Mdot
.622 .16907 Mdot
.622 .16951 Mdot
.622 .16984 Mdot
.622 .17014 Mdot
.622 .17026 Mdot
.622 .17065 Mdot
.622 .17074 Mdot
.622 .17093 Mdot
.622 .17108 Mdot
.622 .17175 Mdot
.622 .1719 Mdot
.622 .17219 Mdot
.622 .1726 Mdot
.622 .17271 Mdot
.622 .17284 Mdot
.622 .173 Mdot
.622 .17302 Mdot
.622 .17315 Mdot
.622 .1737 Mdot
.622 .17395 Mdot
.622 .17508 Mdot
.622 .17509 Mdot
.622 .17559 Mdot
.622 .17668 Mdot
.622 .17699 Mdot
.622 .17745 Mdot
.622 .17807 Mdot
.622 .17836 Mdot
.622 .17851 Mdot
.622 .17946 Mdot
.622 .17992 Mdot
.622 .18022 Mdot
.622 .18036 Mdot
.622 .18042 Mdot
.622 .1808 Mdot
.622 .18086 Mdot
.622 .18095 Mdot
.622 .18112 Mdot
.622 .18116 Mdot
.622 .18165 Mdot
.622 .18177 Mdot
.622 .18192 Mdot
.622 .1822 Mdot
.622 .18223 Mdot
.622 .18224 Mdot
.622 .18274 Mdot
.622 .18324 Mdot
.622 .18357 Mdot
.622 .18361 Mdot
.622 .18362 Mdot
.622 .18377 Mdot
.622 .18454 Mdot
.622 .18475 Mdot
.622 .18484 Mdot
.622 .1856 Mdot
.622 .18608 Mdot
.622 .18663 Mdot
.622 .18667 Mdot
.622 .18705 Mdot
.622 .18723 Mdot
.622 .18727 Mdot
.622 .18775 Mdot
.622 .18917 Mdot
.622 .18951 Mdot
.622 .19084 Mdot
.622 .19095 Mdot
.622 .19139 Mdot
.622 .19233 Mdot
.622 .19267 Mdot
.622 .19374 Mdot
.622 .19383 Mdot
.622 .19399 Mdot
.622 .19543 Mdot
.622 .19574 Mdot
.622 .19679 Mdot
.622 .19699 Mdot
.622 .1983 Mdot
.622 .19851 Mdot
.622 .19884 Mdot
.622 .19943 Mdot
.622 .19985 Mdot
.622 .19986 Mdot
.622 .20002 Mdot
.622 .20042 Mdot
.622 .20186 Mdot
.622 .20215 Mdot
.622 .20333 Mdot
.622 .2035 Mdot
.622 .20363 Mdot
.622 .20371 Mdot
.622 .20443 Mdot
.622 .20512 Mdot
.622 .20659 Mdot
.622 .20732 Mdot
.622 .20775 Mdot
.622 .20812 Mdot
.622 .20831 Mdot
.622 .20843 Mdot
.622 .20896 Mdot
.622 .20902 Mdot
.622 .20929 Mdot
.622 .20973 Mdot
.622 .21013 Mdot
.622 .21015 Mdot
.622 .21135 Mdot
.622 .21318 Mdot
.622 .2134 Mdot
.622 .21383 Mdot
.622 .21391 Mdot
.622 .2143 Mdot
.622 .21456 Mdot
.622 .21535 Mdot
.622 .21569 Mdot
.622 .21639 Mdot
.622 .21659 Mdot
.622 .21733 Mdot
.622 .21755 Mdot
.622 .21788 Mdot
.622 .2194 Mdot
.622 .22027 Mdot
.622 .22059 Mdot
.622 .22092 Mdot
.622 .22278 Mdot
.622 .22391 Mdot
.622 .22587 Mdot
.622 .22691 Mdot
.622 .22831 Mdot
.622 .22924 Mdot
.622 .22935 Mdot
.622 .22937 Mdot
.622 .23021 Mdot
.622 .23208 Mdot
.622 .23262 Mdot
.622 .23289 Mdot
.622 .2349 Mdot
.622 .23548 Mdot
.622 .23581 Mdot
.622 .23584 Mdot
.622 .2362 Mdot
.622 .23807 Mdot
.622 .23855 Mdot
.622 .23878 Mdot
.622 .23883 Mdot
.622 .23911 Mdot
.622 .23944 Mdot
.622 .23976 Mdot
.622 .24218 Mdot
.622 .24264 Mdot
.622 .24536 Mdot
.622 .24845 Mdot
.622 .2486 Mdot
.622 .24887 Mdot
.622 .2498 Mdot
.622 .24993 Mdot
.622 .25108 Mdot
.622 .25472 Mdot
.622 .25567 Mdot
.622 .25645 Mdot
.622 .25724 Mdot
.622 .25742 Mdot
.622 .25793 Mdot
.622 .25803 Mdot
.622 .25859 Mdot
.622 .25964 Mdot
.622 .25976 Mdot
.622 .26169 Mdot
.622 .2625 Mdot
.622 .26438 Mdot
.622 .26527 Mdot
.622 .26535 Mdot
.622 .26618 Mdot
.622 .26636 Mdot
.622 .26752 Mdot
.622 .26763 Mdot
.622 .26828 Mdot
.622 .26963 Mdot
.622 .27056 Mdot
.622 .27174 Mdot
.622 .2725 Mdot
.622 .27274 Mdot
.622 .27343 Mdot
.622 .27484 Mdot
.622 .2786 Mdot
.622 .27953 Mdot
.622 .2797 Mdot
.622 .28 Mdot
.622 .28044 Mdot
.622 .28091 Mdot
.622 .28192 Mdot
.622 .28195 Mdot
.622 .28226 Mdot
.622 .28312 Mdot
.622 .28358 Mdot
.622 .28456 Mdot
.622 .28473 Mdot
.622 .28847 Mdot
.622 .29028 Mdot
.622 .29124 Mdot
.622 .29127 Mdot
.622 .29454 Mdot
.622 .29488 Mdot
.622 .29578 Mdot
.622 .29662 Mdot
.622 .29972 Mdot
.622 .30115 Mdot
.622 .30155 Mdot
.622 .3049 Mdot
.622 .30506 Mdot
.622 .30583 Mdot
.622 .30673 Mdot
.622 .30691 Mdot
.622 .30916 Mdot
.622 .30968 Mdot
.622 .30981 Mdot
.622 .31348 Mdot
.622 .31349 Mdot
.622 .31441 Mdot
.622 .31503 Mdot
.622 .31716 Mdot
.622 .31773 Mdot
.622 .3186 Mdot
.622 .3197 Mdot
.622 .31972 Mdot
.622 .32072 Mdot
.622 .32201 Mdot
.622 .32299 Mdot
.622 .32374 Mdot
.622 .32487 Mdot
.622 .3251 Mdot
.622 .32556 Mdot
.622 .32618 Mdot
.622 .32635 Mdot
.622 .32653 Mdot
.622 .32698 Mdot
.622 .32809 Mdot
.622 .32955 Mdot
.622 .33017 Mdot
.622 .33145 Mdot
.622 .33181 Mdot
.622 .33232 Mdot
.622 .33299 Mdot
.622 .33521 Mdot
.622 .33534 Mdot
.622 .3354 Mdot
.622 .33583 Mdot
.622 .33592 Mdot
.622 .33658 Mdot
.622 .33669 Mdot
.622 .33684 Mdot
.622 .33709 Mdot
.622 .33713 Mdot
.622 .33837 Mdot
.622 .33837 Mdot
.622 .33917 Mdot
.622 .33935 Mdot
.622 .34007 Mdot
.622 .34047 Mdot
.622 .34093 Mdot
.622 .34096 Mdot
.622 .34127 Mdot
.622 .34141 Mdot
.622 .34145 Mdot
.622 .34183 Mdot
.622 .34294 Mdot
.622 .3442 Mdot
.622 .34428 Mdot
.622 .34637 Mdot
.622 .34647 Mdot
.622 .34768 Mdot
.622 .34853 Mdot
.622 .3494 Mdot
.622 .35013 Mdot
.622 .3504 Mdot
.622 .35076 Mdot
.622 .35258 Mdot
.622 .35281 Mdot
.622 .35324 Mdot
.622 .35453 Mdot
.622 .35496 Mdot
.622 .35521 Mdot
.622 .35542 Mdot
.622 .3556 Mdot
.622 .3559 Mdot
.622 .35594 Mdot
.622 .35609 Mdot
.622 .35657 Mdot
.622 .35658 Mdot
.622 .35726 Mdot
.622 .35862 Mdot
.622 .35867 Mdot
.622 .35888 Mdot
.622 .35902 Mdot
.622 .35963 Mdot
.622 .3605 Mdot
.622 .36203 Mdot
.622 .3622 Mdot
.622 .36388 Mdot
.622 .36485 Mdot
.622 .36536 Mdot
.622 .36604 Mdot
.622 .36649 Mdot
.622 .36655 Mdot
.622 .36655 Mdot
.622 .36785 Mdot
.622 .3696 Mdot
.622 .36977 Mdot
.622 .37062 Mdot
.622 .37084 Mdot
.622 .37095 Mdot
.622 .37097 Mdot
.622 .37109 Mdot
.622 .37124 Mdot
.622 .37139 Mdot
.622 .37247 Mdot
.622 .37387 Mdot
.622 .37521 Mdot
.622 .37528 Mdot
.622 .37579 Mdot
.622 .37634 Mdot
.622 .37787 Mdot
.622 .37899 Mdot
.622 .37991 Mdot
.622 .38075 Mdot
.622 .38107 Mdot
.622 .38262 Mdot
.622 .38309 Mdot
.622 .38339 Mdot
.622 .38392 Mdot
.622 .38429 Mdot
.622 .38475 Mdot
.622 .38505 Mdot
.622 .3874 Mdot
.622 .38776 Mdot
.622 .38794 Mdot
.622 .38811 Mdot
.622 .38829 Mdot
.622 .38912 Mdot
.622 .3893 Mdot
.622 .38966 Mdot
.622 .3918 Mdot
.622 .39215 Mdot
.622 .39336 Mdot
.622 .39349 Mdot
.622 .39382 Mdot
.622 .39577 Mdot
.622 .39591 Mdot
.622 .39717 Mdot
.622 .39783 Mdot
.622 .39881 Mdot
.622 .39886 Mdot
.622 .40016 Mdot
.622 .40195 Mdot
.622 .40233 Mdot
.622 .40314 Mdot
.622 .40436 Mdot
.622 .40457 Mdot
.622 .4047 Mdot
.622 .40523 Mdot
.622 .40573 Mdot
.622 .40595 Mdot
.622 .40639 Mdot
.622 .40651 Mdot
.622 .40691 Mdot
.622 .40767 Mdot
.622 .40771 Mdot
.622 .40773 Mdot
.622 .40813 Mdot
.622 .40817 Mdot
.622 .40822 Mdot
.622 .40832 Mdot
.622 .40874 Mdot
.622 .40932 Mdot
.622 .40945 Mdot
.622 .40962 Mdot
.622 .40977 Mdot
.622 .40978 Mdot
.622 .41074 Mdot
.622 .41148 Mdot
.622 .41188 Mdot
.622 .41217 Mdot
.622 .41246 Mdot
.622 .4127 Mdot
.622 .4128 Mdot
.622 .41352 Mdot
.622 .41375 Mdot
.622 .41418 Mdot
.622 .41448 Mdot
.622 .41464 Mdot
.622 .41465 Mdot
.622 .41486 Mdot
.622 .41486 Mdot
.622 .41509 Mdot
.622 .41554 Mdot
.622 .41556 Mdot
.622 .41563 Mdot
.622 .41567 Mdot
.622 .41668 Mdot
.622 .41673 Mdot
.622 .41729 Mdot
.622 .41778 Mdot
.622 .41816 Mdot
.622 .41924 Mdot
.622 .4196 Mdot
.622 .41963 Mdot
.622 .41964 Mdot
.622 .41968 Mdot
.622 .41978 Mdot
.622 .42014 Mdot
.622 .4206 Mdot
.622 .42107 Mdot
.622 .42142 Mdot
.622 .42193 Mdot
.622 .42288 Mdot
.622 .42298 Mdot
.622 .4235 Mdot
.622 .42365 Mdot
.622 .42375 Mdot
.622 .42393 Mdot
.622 .42508 Mdot
.622 .42519 Mdot
.622 .42525 Mdot
.622 .42531 Mdot
.622 .42564 Mdot
.622 .42582 Mdot
.622 .42653 Mdot
.622 .42705 Mdot
.622 .42784 Mdot
.622 .42789 Mdot
.622 .42831 Mdot
.622 .42885 Mdot
.622 .4293 Mdot
.622 .42989 Mdot
.622 .43002 Mdot
.622 .43069 Mdot
.622 .43115 Mdot
.622 .43122 Mdot
.622 .43154 Mdot
.622 .43179 Mdot
.622 .4318 Mdot
.622 .43181 Mdot
.622 .43194 Mdot
.622 .43197 Mdot
.622 .43201 Mdot
.622 .43215 Mdot
.622 .43234 Mdot
.622 .43238 Mdot
.622 .43249 Mdot
.622 .43249 Mdot
.622 .43281 Mdot
.622 .43306 Mdot
.622 .43338 Mdot
.622 .43347 Mdot
.622 .43374 Mdot
.622 .43381 Mdot
.622 .43396 Mdot
.622 .43406 Mdot
.622 .43411 Mdot
.622 .43411 Mdot
.622 .43419 Mdot
.622 .43419 Mdot
.622 .43444 Mdot
.622 .43481 Mdot
.622 .435 Mdot
.622 .43516 Mdot
.622 .43565 Mdot
.622 .43577 Mdot
.622 .43579 Mdot
.622 .43596 Mdot
.622 .43656 Mdot
.622 .43714 Mdot
.622 .43766 Mdot
.622 .4377 Mdot
.622 .43787 Mdot
.622 .43828 Mdot
.622 .43855 Mdot
.622 .43871 Mdot
.622 .43889 Mdot
.622 .43905 Mdot
.622 .43925 Mdot
.622 .43929 Mdot
.622 .4397 Mdot
.622 .43981 Mdot
.622 .44044 Mdot
.622 .44046 Mdot
.622 .44067 Mdot
.622 .44069 Mdot
.622 .44071 Mdot
.622 .44071 Mdot
.622 .44121 Mdot
.622 .44131 Mdot
.622 .44191 Mdot
.622 .44211 Mdot
.622 .44232 Mdot
.622 .4426 Mdot
.622 .44264 Mdot
.622 .44285 Mdot
.622 .44293 Mdot
.622 .44316 Mdot
.622 .44372 Mdot
.622 .4438 Mdot
.622 .44399 Mdot
.622 .44422 Mdot
.622 .44438 Mdot
.622 .44471 Mdot
.622 .44484 Mdot
.622 .44578 Mdot
.622 .44613 Mdot
.622 .44615 Mdot
.622 .44616 Mdot
.622 .44629 Mdot
.622 .44666 Mdot
.622 .44672 Mdot
.622 .44698 Mdot
.622 .44719 Mdot
.622 .44754 Mdot
.622 .44787 Mdot
.622 .44887 Mdot
.622 .44904 Mdot
.622 .44932 Mdot
.622 .44987 Mdot
.622 .44987 Mdot
.622 .44991 Mdot
.622 .44994 Mdot
.622 .45008 Mdot
.622 .45028 Mdot
.622 .45032 Mdot
.622 .4511 Mdot
.622 .45136 Mdot
.622 .45154 Mdot
.622 .45158 Mdot
.622 .45183 Mdot
.622 .45221 Mdot
.622 .45228 Mdot
.622 .45261 Mdot
.622 .45286 Mdot
.622 .45316 Mdot
.622 .45339 Mdot
.622 .45341 Mdot
.622 .45385 Mdot
.622 .45413 Mdot
.622 .45452 Mdot
.622 .45462 Mdot
.622 .4548 Mdot
.622 .45483 Mdot
.622 .45486 Mdot
.622 .45493 Mdot
.622 .45555 Mdot
.622 .45565 Mdot
.622 .4557 Mdot
.622 .45579 Mdot
.622 .45606 Mdot
.622 .45612 Mdot
.622 .45664 Mdot
.622 .45691 Mdot
.622 .4571 Mdot
.622 .45735 Mdot
.622 .4576 Mdot
.622 .45779 Mdot
.622 .45784 Mdot
.622 .45786 Mdot
.622 .45787 Mdot
.622 .45789 Mdot
.622 .45808 Mdot
.622 .45865 Mdot
.622 .45885 Mdot
.622 .45912 Mdot
.622 .45941 Mdot
.622 .45944 Mdot
.622 .45997 Mdot
.622 .45999 Mdot
.622 .46003 Mdot
.622 .46004 Mdot
.622 .46028 Mdot
.622 .4604 Mdot
.622 .4604 Mdot
.622 .46051 Mdot
.622 .46052 Mdot
.622 .4606 Mdot
.622 .46076 Mdot
.622 .46098 Mdot
.622 .4611 Mdot
.622 .46148 Mdot
.622 .46153 Mdot
.622 .46166 Mdot
.622 .46181 Mdot
.622 .46196 Mdot
.622 .46217 Mdot
.622 .46255 Mdot
.622 .46305 Mdot
.622 .46305 Mdot
.622 .46313 Mdot
.622 .46322 Mdot
.622 .46329 Mdot
.622 .46358 Mdot
.622 .4638 Mdot
.622 .46385 Mdot
.622 .46388 Mdot
.622 .46389 Mdot
.622 .4641 Mdot
.622 .46411 Mdot
.622 .46413 Mdot
.622 .46452 Mdot
.622 .46473 Mdot
.622 .46479 Mdot
.622 .46501 Mdot
.622 .46512 Mdot
.622 .46538 Mdot
.622 .46565 Mdot
.622 .46571 Mdot
.622 .46582 Mdot
.622 .46644 Mdot
.622 .46685 Mdot
.622 .46704 Mdot
.622 .46794 Mdot
.622 .46859 Mdot
.622 .46861 Mdot
.622 .4691 Mdot
.622 .46943 Mdot
.622 .47005 Mdot
.622 .47013 Mdot
.622 .47108 Mdot
.622 .47125 Mdot
.622 .47131 Mdot
.622 .4719 Mdot
.622 .47207 Mdot
.622 .47311 Mdot
.622 .47329 Mdot
.622 .47338 Mdot
.622 .47378 Mdot
.622 .47387 Mdot
.622 .47395 Mdot
.622 .47403 Mdot
.622 .4742 Mdot
.622 .47534 Mdot
.622 .47548 Mdot
.622 .4757 Mdot
.622 .47587 Mdot
.622 .47613 Mdot
.622 .47627 Mdot
.622 .47649 Mdot
.622 .47723 Mdot
.622 .47738 Mdot
.622 .47778 Mdot
.622 .47821 Mdot
.622 .47873 Mdot
.622 .47945 Mdot
.622 .47971 Mdot
.622 .47995 Mdot
.622 .47998 Mdot
.622 .4806 Mdot
.622 .48125 Mdot
.622 .48175 Mdot
.622 .48182 Mdot
.622 .48188 Mdot
.622 .48194 Mdot
.622 .48195 Mdot
.622 .482 Mdot
.622 .4821 Mdot
.622 .48249 Mdot
.622 .48257 Mdot
.622 .48337 Mdot
.622 .48396 Mdot
.622 .48397 Mdot
.622 .48399 Mdot
.622 .4842 Mdot
.622 .4845 Mdot
.622 .48474 Mdot
.622 .48518 Mdot
.622 .48593 Mdot
.622 .48601 Mdot
.622 .48669 Mdot
.622 .48708 Mdot
.622 .48736 Mdot
.622 .48742 Mdot
.622 .48752 Mdot
.622 .48753 Mdot
.622 .48814 Mdot
.622 .48844 Mdot
.622 .48845 Mdot
.622 .48866 Mdot
.622 .48873 Mdot
.622 .48874 Mdot
.622 .48888 Mdot
.622 .48896 Mdot
.622 .48905 Mdot
.622 .48916 Mdot
.622 .48935 Mdot
.622 .48992 Mdot
.622 .49011 Mdot
.622 .49021 Mdot
.622 .49101 Mdot
.622 .49116 Mdot
.622 .49128 Mdot
.622 .4916 Mdot
.622 .49198 Mdot
.622 .49235 Mdot
.622 .49287 Mdot
.622 .49292 Mdot
.622 .49382 Mdot
.622 .49385 Mdot
.622 .4944 Mdot
.622 .49487 Mdot
.622 .49504 Mdot
.622 .49505 Mdot
.622 .49511 Mdot
.622 .49524 Mdot
.622 .49526 Mdot
.622 .49545 Mdot
.622 .49562 Mdot
.622 .49593 Mdot
.622 .49601 Mdot
.622 .49635 Mdot
.622 .49635 Mdot
.622 .49687 Mdot
.622 .49689 Mdot
.622 .497 Mdot
.622 .49706 Mdot
.622 .49711 Mdot
.622 .49739 Mdot
.622 .49742 Mdot
.622 .4976 Mdot
.622 .49763 Mdot
.622 .49768 Mdot
.622 .49862 Mdot
.622 .4989 Mdot
.622 .49911 Mdot
.622 .49926 Mdot
.622 .4998 Mdot
.622 .50006 Mdot
.622 .50067 Mdot
.622 .50113 Mdot
.622 .50131 Mdot
.622 .50139 Mdot
.622 .50146 Mdot
.622 .50171 Mdot
.622 .5019 Mdot
.622 .502 Mdot
.622 .50246 Mdot
.622 .50277 Mdot
.622 .50317 Mdot
.622 .5037 Mdot
.622 .50411 Mdot
.622 .50412 Mdot
.622 .50457 Mdot
.622 .50492 Mdot
.622 .50515 Mdot
.622 .50601 Mdot
.622 .50626 Mdot
.622 .50663 Mdot
.622 .50664 Mdot
.622 .50811 Mdot
.622 .50816 Mdot
.622 .50837 Mdot
.622 .50927 Mdot
.622 .50934 Mdot
.622 .5097 Mdot
.622 .51 Mdot
.622 .51006 Mdot
.622 .51139 Mdot
.622 .51155 Mdot
.622 .51211 Mdot
.622 .51332 Mdot
.622 .51364 Mdot
.622 .51399 Mdot
.622 .51413 Mdot
.622 .51539 Mdot
.622 .5154 Mdot
.622 .51577 Mdot
.622 .51647 Mdot
.622 .5179 Mdot
.622 .51796 Mdot
.622 .51834 Mdot
.622 .51851 Mdot
.622 .51884 Mdot
.622 .51895 Mdot
.622 .51897 Mdot
.622 .51935 Mdot
.622 .51952 Mdot
.622 .51969 Mdot
.622 .51981 Mdot
.622 .51987 Mdot
.622 .52022 Mdot
.622 .52163 Mdot
.622 .52216 Mdot
.622 .52242 Mdot
.622 .52251 Mdot
.622 .52279 Mdot
.622 .52323 Mdot
.622 .52357 Mdot
.622 .52407 Mdot
.622 .52432 Mdot
.622 .52435 Mdot
.622 .52478 Mdot
.622 .52485 Mdot
.622 .52515 Mdot
.622 .52518 Mdot
.622 .52551 Mdot
.622 .5262 Mdot
.622 .5265 Mdot
.622 .5272 Mdot
.622 .52725 Mdot
.622 .52763 Mdot
.622 .52783 Mdot
.622 .52787 Mdot
.622 .52806 Mdot
.622 .52812 Mdot
.622 .52841 Mdot
.622 .52869 Mdot
.622 .52904 Mdot
.622 .53035 Mdot
.622 .53076 Mdot
.622 .53081 Mdot
.622 .53114 Mdot
.622 .53124 Mdot
.622 .53129 Mdot
.622 .5324 Mdot
.622 .53336 Mdot
.622 .53352 Mdot
.622 .53438 Mdot
.622 .5345 Mdot
.622 .53461 Mdot
.622 .53471 Mdot
.622 .53473 Mdot
.622 .53481 Mdot
.622 .53498 Mdot
.622 .53564 Mdot
.622 .53576 Mdot
.622 .53577 Mdot
.622 .53589 Mdot
.622 .53609 Mdot
.622 .53679 Mdot
.622 .53689 Mdot
.622 .53708 Mdot
.622 .53773 Mdot
.622 .53802 Mdot
.622 .53803 Mdot
.622 .53807 Mdot
.622 .53839 Mdot
.622 .53888 Mdot
.622 .53924 Mdot
.622 .53991 Mdot
.622 .5403 Mdot
.622 .54094 Mdot
.622 .54106 Mdot
.622 .54117 Mdot
.622 .54146 Mdot
.622 .54198 Mdot
.622 .5421 Mdot
.622 .54217 Mdot
.622 .54242 Mdot
.622 .54249 Mdot
.622 .54273 Mdot
.622 .54285 Mdot
.622 .54311 Mdot
.622 .5432 Mdot
.622 .54334 Mdot
.622 .54336 Mdot
.622 .54351 Mdot
.622 .54358 Mdot
.622 .5442 Mdot
.622 .54461 Mdot
.622 .54462 Mdot
.622 .54475 Mdot
.622 .5449 Mdot
.622 .54499 Mdot
.622 .54501 Mdot
.622 .54519 Mdot
.622 .54523 Mdot
.622 .54529 Mdot
.622 .54542 Mdot
.622 .54556 Mdot
.622 .54581 Mdot
.622 .5463 Mdot
.622 .54653 Mdot
.622 .54677 Mdot
.622 .5468 Mdot
.622 .54684 Mdot
.622 .5469 Mdot
.622 .54729 Mdot
.622 .54739 Mdot
.622 .54787 Mdot
.622 .548 Mdot
.622 .54806 Mdot
.622 .54806 Mdot
.622 .5482 Mdot
.622 .5484 Mdot
.622 .54858 Mdot
.622 .54901 Mdot
.622 .54908 Mdot
.622 .54943 Mdot
.622 .54953 Mdot
.622 .55001 Mdot
.622 .55006 Mdot
.622 .55009 Mdot
.622 .55044 Mdot
.622 .55055 Mdot
.622 .55086 Mdot
.622 .55101 Mdot
.622 .55105 Mdot
.622 .55148 Mdot
.622 .55159 Mdot
.622 .55206 Mdot
.622 .55221 Mdot
.622 .55223 Mdot
.622 .55229 Mdot
.622 .55241 Mdot
.622 .55242 Mdot
.622 .55261 Mdot
.622 .55276 Mdot
.622 .55301 Mdot
.622 .55304 Mdot
.622 .55311 Mdot
.622 .55336 Mdot
.622 .55341 Mdot
.622 .55341 Mdot
.622 .55342 Mdot
.622 .55353 Mdot
.622 .55369 Mdot
.622 .55385 Mdot
.622 .55386 Mdot
.622 .55387 Mdot
.622 .55396 Mdot
.622 .55401 Mdot
.622 .55405 Mdot
.622 .55421 Mdot
.622 .55422 Mdot
.622 .55428 Mdot
.622 .5543 Mdot
.622 .55432 Mdot
.622 .55445 Mdot
.622 .55447 Mdot
.622 .55451 Mdot
.622 .55461 Mdot
.622 .55476 Mdot
.622 .55506 Mdot
.622 .55511 Mdot
.622 .55521 Mdot
.622 .55541 Mdot
.622 .55556 Mdot
.622 .55566 Mdot
.622 .55601 Mdot
.622 .55617 Mdot
.622 .55617 Mdot
.622 .55654 Mdot
.622 .55662 Mdot
.622 .55679 Mdot
.622 .55683 Mdot
.622 .55684 Mdot
.622 .55689 Mdot
.622 .55693 Mdot
.622 .55697 Mdot
.622 .5571 Mdot
.622 .5572 Mdot
.622 .55724 Mdot
.622 .55746 Mdot
.622 .5575 Mdot
.622 .55757 Mdot
.622 .55759 Mdot
.622 .55772 Mdot
.622 .55776 Mdot
.622 .55785 Mdot
.622 .55796 Mdot
.622 .5581 Mdot
.622 .5581 Mdot
.622 .55824 Mdot
.622 .55828 Mdot
.622 .55834 Mdot
.622 .5584 Mdot
.622 .55843 Mdot
.622 .55847 Mdot
.622 .55859 Mdot
.622 .55864 Mdot
.622 .55869 Mdot
.622 .5587 Mdot
.622 .55871 Mdot
.622 .55872 Mdot
.622 .55876 Mdot
.622 .55879 Mdot
.622 .55879 Mdot
.622 .55882 Mdot
.622 .55882 Mdot
.622 .55882 Mdot
.624 .16623 Mdot
.624 .16623 Mdot
.624 .16627 Mdot
.624 .16627 Mdot
.624 .16631 Mdot
.624 .16647 Mdot
.624 .16647 Mdot
.624 .16679 Mdot
.624 .16683 Mdot
.624 .16689 Mdot
.624 .16691 Mdot
.624 .16738 Mdot
.624 .16739 Mdot
.624 .16741 Mdot
.624 .16771 Mdot
.624 .16774 Mdot
.624 .16795 Mdot
.624 .16811 Mdot
.624 .16835 Mdot
.624 .16874 Mdot
.624 .16888 Mdot
.624 .16911 Mdot
.624 .16919 Mdot
.624 .16926 Mdot
.624 .16989 Mdot
.624 .17024 Mdot
.624 .17026 Mdot
.624 .17033 Mdot
.624 .1706 Mdot
.624 .17085 Mdot
.624 .17182 Mdot
.624 .172 Mdot
.624 .17216 Mdot
.624 .17222 Mdot
.624 .17227 Mdot
.624 .17246 Mdot
.624 .17252 Mdot
.624 .17263 Mdot
.624 .17268 Mdot
.624 .17301 Mdot
.624 .1731 Mdot
.624 .17367 Mdot
.624 .17411 Mdot
.624 .17488 Mdot
.624 .17492 Mdot
.624 .17497 Mdot
.624 .175 Mdot
.624 .17508 Mdot
.624 .17518 Mdot
.624 .17575 Mdot
.624 .17599 Mdot
.624 .17634 Mdot
.624 .17689 Mdot
.624 .17729 Mdot
.624 .17736 Mdot
.624 .17743 Mdot
.624 .17898 Mdot
.624 .17931 Mdot
.624 .17945 Mdot
.624 .17977 Mdot
.624 .17982 Mdot
.624 .18053 Mdot
.624 .18103 Mdot
.624 .18131 Mdot
.624 .18158 Mdot
.624 .1817 Mdot
.624 .18171 Mdot
.624 .18188 Mdot
.624 .18269 Mdot
.624 .18325 Mdot
.624 .18366 Mdot
.624 .18406 Mdot
.624 .1851 Mdot
.624 .18595 Mdot
.624 .18706 Mdot
.624 .18712 Mdot
.624 .18735 Mdot
.624 .18809 Mdot
.624 .1881 Mdot
.624 .18884 Mdot
.624 .19053 Mdot
.624 .19063 Mdot
.624 .19092 Mdot
.624 .19116 Mdot
.624 .19127 Mdot
.624 .19168 Mdot
.624 .19232 Mdot
.624 .19312 Mdot
.624 .194 Mdot
.624 .19514 Mdot
.624 .1956 Mdot
.624 .19605 Mdot
.624 .19667 Mdot
.624 .19881 Mdot
.624 .1995 Mdot
.624 .19963 Mdot
.624 .20005 Mdot
.624 .20005 Mdot
.624 .20044 Mdot
.624 .20049 Mdot
.624 .20107 Mdot
.624 .20167 Mdot
.624 .20376 Mdot
.624 .20462 Mdot
.624 .20487 Mdot
.624 .20593 Mdot
.624 .20703 Mdot
.624 .20794 Mdot
.624 .20832 Mdot
.624 .20909 Mdot
.624 .20926 Mdot
.624 .20977 Mdot
.624 .21099 Mdot
.624 .21101 Mdot
.624 .21196 Mdot
.624 .21231 Mdot
.624 .21426 Mdot
.624 .21427 Mdot
.624 .21501 Mdot
.624 .21652 Mdot
.624 .21722 Mdot
.624 .21729 Mdot
.624 .21787 Mdot
.624 .21841 Mdot
.624 .22007 Mdot
.624 .22077 Mdot
.624 .22153 Mdot
.624 .22288 Mdot
.624 .22377 Mdot
.624 .22426 Mdot
.624 .22455 Mdot
.624 .22694 Mdot
.624 .22698 Mdot
.624 .22733 Mdot
.624 .22758 Mdot
.624 .22797 Mdot
.624 .22875 Mdot
.624 .2288 Mdot
.624 .22961 Mdot
.624 .22962 Mdot
.624 .23041 Mdot
.624 .23135 Mdot
.624 .23166 Mdot
.624 .23288 Mdot
.624 .23365 Mdot
.624 .23481 Mdot
.624 .23491 Mdot
.624 .23708 Mdot
.624 .23773 Mdot
.624 .23824 Mdot
.624 .23824 Mdot
.624 .23914 Mdot
.624 .24106 Mdot
.624 .24147 Mdot
.624 .24251 Mdot
.624 .24336 Mdot
.624 .24373 Mdot
.624 .24401 Mdot
.624 .24417 Mdot
.624 .24445 Mdot
.624 .24452 Mdot
.624 .24481 Mdot
.624 .24518 Mdot
.624 .24582 Mdot
.624 .24668 Mdot
.624 .24709 Mdot
.624 .24732 Mdot
.624 .24762 Mdot
.624 .24866 Mdot
.624 .24955 Mdot
.624 .25012 Mdot
.624 .25027 Mdot
.624 .25109 Mdot
.624 .25207 Mdot
.624 .25394 Mdot
.624 .25581 Mdot
.624 .25666 Mdot
.624 .25728 Mdot
.624 .25885 Mdot
.624 .25886 Mdot
.624 .25992 Mdot
.624 .26011 Mdot
.624 .26063 Mdot
.624 .26171 Mdot
.624 .26215 Mdot
.624 .26711 Mdot
.624 .26738 Mdot
.624 .26931 Mdot
.624 .26972 Mdot
.624 .27033 Mdot
.624 .27111 Mdot
.624 .27173 Mdot
.624 .2723 Mdot
.624 .27352 Mdot
.624 .27543 Mdot
.624 .27544 Mdot
.624 .2762 Mdot
.624 .27625 Mdot
.624 .27784 Mdot
.624 .27872 Mdot
.624 .2808 Mdot
.624 .28081 Mdot
.624 .28258 Mdot
.624 .28294 Mdot
.624 .28308 Mdot
.624 .28341 Mdot
.624 .28517 Mdot
.624 .28561 Mdot
.624 .28621 Mdot
.624 .28661 Mdot
.624 .28689 Mdot
.624 .28777 Mdot
.624 .28781 Mdot
.624 .28792 Mdot
.624 .28944 Mdot
.624 .29033 Mdot
.624 .29108 Mdot
.624 .29144 Mdot
.624 .29176 Mdot
.624 .29202 Mdot
.624 .29397 Mdot
.624 .29443 Mdot
.624 .29523 Mdot
.624 .29643 Mdot
.624 .29657 Mdot
.624 .29721 Mdot
.624 .29753 Mdot
.624 .29903 Mdot
.624 .29945 Mdot
.624 .301 Mdot
.624 .30106 Mdot
.624 .30276 Mdot
.624 .30283 Mdot
.624 .30489 Mdot
.624 .30688 Mdot
.624 .31121 Mdot
.624 .31156 Mdot
.624 .3116 Mdot
.624 .31193 Mdot
.624 .31309 Mdot
.624 .31474 Mdot
.624 .31494 Mdot
.624 .31696 Mdot
.624 .31794 Mdot
.624 .31802 Mdot
.624 .32129 Mdot
.624 .32344 Mdot
.624 .32348 Mdot
.624 .32448 Mdot
.624 .3265 Mdot
.624 .3266 Mdot
.624 .32667 Mdot
.624 .32702 Mdot
.624 .32719 Mdot
.624 .32725 Mdot
.624 .32783 Mdot
.624 .32916 Mdot
.624 .33017 Mdot
.624 .33035 Mdot
.624 .33048 Mdot
.624 .33294 Mdot
.624 .33301 Mdot
.624 .33541 Mdot
.624 .33613 Mdot
.624 .3366 Mdot
.624 .33687 Mdot
.624 .33711 Mdot
.624 .33739 Mdot
.624 .33812 Mdot
.624 .33861 Mdot
.624 .33897 Mdot
.624 .34089 Mdot
.624 .34201 Mdot
.624 .34317 Mdot
.624 .34444 Mdot
.624 .34473 Mdot
.624 .3449 Mdot
.624 .34498 Mdot
.624 .34528 Mdot
.624 .34801 Mdot
.624 .35012 Mdot
.624 .35057 Mdot
.624 .35092 Mdot
.624 .35116 Mdot
.624 .35119 Mdot
.624 .35156 Mdot
.624 .35193 Mdot
.624 .35321 Mdot
.624 .35372 Mdot
.624 .35387 Mdot
.624 .35449 Mdot
.624 .35514 Mdot
.624 .35566 Mdot
.624 .35641 Mdot
.624 .3567 Mdot
.624 .35739 Mdot
.624 .35958 Mdot
.624 .36038 Mdot
.624 .36079 Mdot
.624 .36109 Mdot
.624 .36258 Mdot
.624 .36297 Mdot
.624 .36365 Mdot
.624 .36433 Mdot
.624 .36448 Mdot
.624 .36565 Mdot
.624 .36567 Mdot
.624 .36584 Mdot
.624 .36615 Mdot
.624 .36653 Mdot
.624 .36655 Mdot
.624 .36694 Mdot
.624 .36732 Mdot
.624 .36884 Mdot
.624 .36943 Mdot
.624 .37094 Mdot
.624 .37239 Mdot
.624 .37339 Mdot
.624 .37371 Mdot
.624 .37374 Mdot
.624 .37485 Mdot
.624 .37495 Mdot
.624 .37508 Mdot
.624 .37591 Mdot
.624 .37615 Mdot
.624 .37621 Mdot
.624 .37776 Mdot
.624 .37854 Mdot
.624 .37915 Mdot
.624 .38023 Mdot
.624 .38052 Mdot
.624 .38113 Mdot
.624 .38398 Mdot
.624 .38415 Mdot
.624 .38469 Mdot
.624 .38493 Mdot
.624 .38563 Mdot
.624 .38637 Mdot
.624 .38666 Mdot
.624 .38729 Mdot
.624 .38909 Mdot
.624 .3894 Mdot
.624 .39023 Mdot
.624 .3906 Mdot
.624 .39103 Mdot
.624 .39165 Mdot
.624 .39198 Mdot
.624 .39226 Mdot
.624 .39239 Mdot
.624 .39251 Mdot
.624 .3926 Mdot
.624 .39332 Mdot
.624 .39421 Mdot
.624 .3945 Mdot
.624 .39461 Mdot
.624 .39531 Mdot
.624 .39587 Mdot
.624 .39589 Mdot
.624 .39652 Mdot
.624 .3995 Mdot
.624 .39964 Mdot
.624 .39975 Mdot
.624 .40186 Mdot
.624 .40188 Mdot
.624 .40412 Mdot
.624 .40482 Mdot
.624 .40485 Mdot
.624 .40487 Mdot
.624 .40499 Mdot
.624 .40505 Mdot
.624 .40507 Mdot
.624 .40527 Mdot
.624 .40614 Mdot
.624 .40618 Mdot
.624 .40786 Mdot
.624 .4081 Mdot
.624 .40835 Mdot
.624 .40843 Mdot
.624 .40853 Mdot
.624 .40906 Mdot
.624 .41048 Mdot
.624 .41091 Mdot
.624 .41106 Mdot
.624 .41109 Mdot
.624 .41119 Mdot
.624 .41281 Mdot
.624 .41296 Mdot
.624 .41308 Mdot
.624 .41317 Mdot
.624 .41329 Mdot
.624 .41384 Mdot
.624 .41401 Mdot
.624 .41406 Mdot
.624 .41449 Mdot
.624 .41466 Mdot
.624 .41491 Mdot
.624 .41501 Mdot
.624 .41523 Mdot
.624 .41596 Mdot
.624 .41623 Mdot
.624 .41646 Mdot
.624 .41709 Mdot
.624 .41731 Mdot
.624 .41804 Mdot
.624 .41814 Mdot
.624 .41827 Mdot
.624 .41828 Mdot
.624 .41903 Mdot
.624 .41973 Mdot
.624 .42021 Mdot
.624 .42054 Mdot
.624 .42064 Mdot
.624 .42065 Mdot
.624 .42102 Mdot
.624 .42105 Mdot
.624 .42109 Mdot
.624 .42145 Mdot
.624 .42147 Mdot
.624 .42224 Mdot
.624 .42279 Mdot
.624 .42309 Mdot
.624 .42408 Mdot
.624 .42426 Mdot
.624 .42434 Mdot
.624 .42457 Mdot
.624 .42482 Mdot
.624 .42512 Mdot
.624 .42582 Mdot
.624 .42609 Mdot
.624 .42621 Mdot
.624 .42656 Mdot
.624 .42667 Mdot
.624 .4268 Mdot
.624 .42684 Mdot
.624 .42754 Mdot
.624 .42777 Mdot
.624 .42795 Mdot
.624 .42796 Mdot
.624 .42817 Mdot
.624 .42915 Mdot
.624 .42924 Mdot
.624 .43092 Mdot
.624 .43093 Mdot
.624 .43099 Mdot
.624 .431 Mdot
.624 .43106 Mdot
.624 .43135 Mdot
.624 .43136 Mdot
.624 .43192 Mdot
.624 .432 Mdot
.624 .43211 Mdot
.624 .43214 Mdot
.624 .43232 Mdot
.624 .43279 Mdot
.624 .43298 Mdot
.624 .43299 Mdot
.624 .43303 Mdot
.624 .43357 Mdot
.624 .43362 Mdot
.624 .43366 Mdot
.624 .43369 Mdot
.624 .43373 Mdot
.624 .43391 Mdot
.624 .43399 Mdot
.624 .43413 Mdot
.624 .43418 Mdot
.624 .43427 Mdot
.624 .4343 Mdot
.624 .43462 Mdot
.624 .43471 Mdot
.624 .435 Mdot
.624 .43507 Mdot
.624 .43531 Mdot
.624 .43539 Mdot
.624 .43539 Mdot
.624 .43565 Mdot
.624 .43588 Mdot
.624 .43604 Mdot
.624 .43618 Mdot
.624 .43619 Mdot
.624 .43631 Mdot
.624 .43646 Mdot
.624 .43691 Mdot
.624 .43734 Mdot
.624 .4374 Mdot
.624 .43743 Mdot
.624 .43759 Mdot
.624 .43769 Mdot
.624 .43793 Mdot
.624 .43802 Mdot
.624 .43806 Mdot
.624 .43818 Mdot
.624 .43827 Mdot
.624 .43851 Mdot
.624 .43865 Mdot
.624 .43865 Mdot
.624 .43908 Mdot
.624 .44013 Mdot
.624 .44029 Mdot
.624 .44058 Mdot
.624 .44059 Mdot
.624 .44076 Mdot
.624 .4408 Mdot
.624 .44091 Mdot
.624 .44104 Mdot
.624 .44106 Mdot
.624 .44117 Mdot
.624 .44134 Mdot
.624 .44145 Mdot
.624 .44154 Mdot
.624 .44184 Mdot
.624 .44187 Mdot
.624 .44192 Mdot
.624 .44196 Mdot
.624 .44216 Mdot
.624 .44224 Mdot
.624 .4428 Mdot
.624 .44296 Mdot
.624 .44339 Mdot
.624 .44341 Mdot
.624 .44393 Mdot
.624 .44466 Mdot
.624 .44468 Mdot
.624 .44554 Mdot
.624 .44559 Mdot
.624 .44597 Mdot
.624 .44605 Mdot
.624 .44613 Mdot
.624 .44619 Mdot
.624 .44631 Mdot
.624 .44632 Mdot
.624 .44649 Mdot
.624 .44658 Mdot
.624 .44743 Mdot
.624 .44751 Mdot
.624 .44765 Mdot
.624 .44785 Mdot
.624 .44798 Mdot
.624 .44804 Mdot
.624 .44813 Mdot
.624 .44818 Mdot
.624 .44843 Mdot
.624 .44868 Mdot
.624 .44884 Mdot
.624 .44902 Mdot
.624 .44929 Mdot
.624 .44934 Mdot
.624 .44947 Mdot
.624 .44952 Mdot
.624 .44973 Mdot
.624 .44991 Mdot
.624 .44997 Mdot
.624 .45001 Mdot
.624 .45013 Mdot
.624 .45023 Mdot
.624 .45025 Mdot
.624 .45027 Mdot
.624 .45076 Mdot
.624 .45102 Mdot
.624 .45274 Mdot
.624 .45279 Mdot
.624 .45333 Mdot
.624 .45345 Mdot
.624 .45345 Mdot
.624 .45355 Mdot
.624 .45368 Mdot
.624 .45406 Mdot
.624 .45408 Mdot
.624 .45416 Mdot
.624 .45421 Mdot
.624 .4544 Mdot
.624 .45447 Mdot
.624 .45462 Mdot
.624 .455 Mdot
.624 .45517 Mdot
.624 .4553 Mdot
.624 .45542 Mdot
.624 .45547 Mdot
.624 .45556 Mdot
.624 .4561 Mdot
.624 .45626 Mdot
.624 .45656 Mdot
.624 .45698 Mdot
.624 .45699 Mdot
.624 .45718 Mdot
.624 .4572 Mdot
.624 .45722 Mdot
.624 .45742 Mdot
.624 .45742 Mdot
.624 .45748 Mdot
.624 .45765 Mdot
.624 .45791 Mdot
.624 .45828 Mdot
.624 .45868 Mdot
.624 .45869 Mdot
.624 .45876 Mdot
.624 .45881 Mdot
.624 .4592 Mdot
.624 .45931 Mdot
.624 .45964 Mdot
.624 .45977 Mdot
.624 .45991 Mdot
.624 .46029 Mdot
.624 .46041 Mdot
.624 .46046 Mdot
.624 .46059 Mdot
.624 .46069 Mdot
.624 .46091 Mdot
.624 .46093 Mdot
.624 .46102 Mdot
.624 .46131 Mdot
.624 .46137 Mdot
.624 .46142 Mdot
.624 .46148 Mdot
.624 .46156 Mdot
.624 .46241 Mdot
.624 .46246 Mdot
.624 .46247 Mdot
.624 .46255 Mdot
.624 .46277 Mdot
.624 .4635 Mdot
.624 .46378 Mdot
.624 .46383 Mdot
.624 .46387 Mdot
.624 .464 Mdot
.624 .46412 Mdot
.624 .46498 Mdot
.624 .465 Mdot
.624 .46544 Mdot
.624 .46555 Mdot
.624 .46556 Mdot
.624 .46559 Mdot
.624 .46565 Mdot
.624 .46566 Mdot
.624 .46568 Mdot
.624 .46603 Mdot
.624 .46716 Mdot
.624 .46717 Mdot
.624 .46823 Mdot
.624 .46829 Mdot
.624 .46835 Mdot
.624 .46983 Mdot
.624 .47015 Mdot
.624 .47016 Mdot
.624 .47043 Mdot
.624 .47077 Mdot
.624 .47083 Mdot
.624 .47097 Mdot
.624 .47141 Mdot
.624 .47176 Mdot
.624 .47181 Mdot
.624 .47186 Mdot
.624 .47193 Mdot
.624 .47206 Mdot
.624 .47222 Mdot
.624 .47253 Mdot
.624 .47274 Mdot
.624 .47292 Mdot
.624 .47332 Mdot
.624 .47347 Mdot
.624 .47434 Mdot
.624 .47464 Mdot
.624 .47478 Mdot
.624 .47513 Mdot
.624 .47547 Mdot
.624 .47558 Mdot
.624 .47584 Mdot
.624 .47592 Mdot
.624 .47727 Mdot
.624 .47756 Mdot
.624 .4777 Mdot
.624 .47821 Mdot
.624 .4785 Mdot
.624 .47886 Mdot
.624 .47958 Mdot
.624 .47961 Mdot
.624 .47973 Mdot
.624 .48011 Mdot
.624 .48017 Mdot
.624 .48022 Mdot
.624 .48074 Mdot
.624 .48075 Mdot
.624 .4809 Mdot
.624 .48136 Mdot
.624 .48202 Mdot
.624 .48272 Mdot
.624 .48299 Mdot
.624 .48368 Mdot
.624 .48386 Mdot
.624 .48403 Mdot
.624 .48404 Mdot
.624 .48421 Mdot
.624 .48436 Mdot
.624 .48443 Mdot
.624 .48444 Mdot
.624 .48497 Mdot
.624 .48504 Mdot
.624 .48535 Mdot
.624 .48565 Mdot
.624 .48583 Mdot
.624 .4865 Mdot
.624 .48663 Mdot
.624 .48682 Mdot
.624 .48717 Mdot
.624 .48815 Mdot
.624 .48845 Mdot
.624 .48858 Mdot
.624 .48891 Mdot
.624 .48915 Mdot
.624 .48943 Mdot
.624 .48971 Mdot
.624 .48977 Mdot
.624 .49 Mdot
.624 .49056 Mdot
.624 .49072 Mdot
.624 .49088 Mdot
.624 .49089 Mdot
.624 .491 Mdot
.624 .49115 Mdot
.624 .49135 Mdot
.624 .49227 Mdot
.624 .49345 Mdot
.624 .49358 Mdot
.624 .49361 Mdot
.624 .49369 Mdot
.624 .49381 Mdot
.624 .49436 Mdot
.624 .49485 Mdot
.624 .49533 Mdot
.624 .49615 Mdot
.624 .4963 Mdot
.624 .49651 Mdot
.624 .49682 Mdot
.624 .49694 Mdot
.624 .49704 Mdot
.624 .49716 Mdot
.624 .49735 Mdot
.624 .49766 Mdot
.624 .49867 Mdot
.624 .4987 Mdot
.624 .49973 Mdot
.624 .49978 Mdot
.624 .49986 Mdot
.624 .50028 Mdot
.624 .50083 Mdot
.624 .50107 Mdot
.624 .5011 Mdot
.624 .50116 Mdot
.624 .50131 Mdot
.624 .50134 Mdot
.624 .50138 Mdot
.624 .50221 Mdot
.624 .50262 Mdot
.624 .50264 Mdot
.624 .50352 Mdot
.624 .50485 Mdot
.624 .50489 Mdot
.624 .50529 Mdot
.624 .5061 Mdot
.624 .50618 Mdot
.624 .50685 Mdot
.624 .50731 Mdot
.624 .50745 Mdot
.624 .50746 Mdot
.624 .5076 Mdot
.624 .50933 Mdot
.624 .51012 Mdot
.624 .51093 Mdot
.624 .51096 Mdot
.624 .51163 Mdot
.624 .51165 Mdot
.624 .51226 Mdot
.624 .51242 Mdot
.624 .51301 Mdot
.624 .51313 Mdot
.624 .51338 Mdot
.624 .51344 Mdot
.624 .51391 Mdot
.624 .51421 Mdot
.624 .5144 Mdot
.624 .51515 Mdot
.624 .51525 Mdot
.624 .51537 Mdot
.624 .51551 Mdot
.624 .5158 Mdot
.624 .51614 Mdot
.624 .51672 Mdot
.624 .51676 Mdot
.624 .51678 Mdot
.624 .51712 Mdot
.624 .51723 Mdot
.624 .51738 Mdot
.624 .51761 Mdot
.624 .51778 Mdot
.624 .51844 Mdot
.624 .51857 Mdot
.624 .51862 Mdot
.624 .51876 Mdot
.624 .51943 Mdot
.624 .51943 Mdot
.624 .52022 Mdot
.624 .52055 Mdot
.624 .52115 Mdot
.624 .52117 Mdot
.624 .52145 Mdot
.624 .52145 Mdot
.624 .52217 Mdot
.624 .52262 Mdot
.624 .52284 Mdot
.624 .52306 Mdot
.624 .52336 Mdot
.624 .52358 Mdot
.624 .52373 Mdot
.624 .52445 Mdot
.624 .52455 Mdot
.624 .52637 Mdot
.624 .52653 Mdot
.624 .52692 Mdot
.624 .52712 Mdot
.624 .52719 Mdot
.624 .52757 Mdot
.624 .52757 Mdot
.624 .52815 Mdot
.624 .52837 Mdot
.624 .52868 Mdot
.624 .52935 Mdot
.624 .53003 Mdot
.624 .53038 Mdot
.624 .53068 Mdot
.624 .53073 Mdot
.624 .53093 Mdot
.624 .53126 Mdot
.624 .53163 Mdot
.624 .53173 Mdot
.624 .53182 Mdot
.624 .53196 Mdot
.624 .53227 Mdot
.624 .5325 Mdot
.624 .53263 Mdot
.624 .53273 Mdot
.624 .53276 Mdot
.624 .53285 Mdot
.624 .53291 Mdot
.624 .53301 Mdot
.624 .53314 Mdot
.624 .53345 Mdot
.624 .53381 Mdot
.624 .53396 Mdot
.624 .53464 Mdot
.624 .53495 Mdot
.624 .53495 Mdot
.624 .53513 Mdot
.624 .53536 Mdot
.624 .53612 Mdot
.624 .53616 Mdot
.624 .53656 Mdot
.624 .53683 Mdot
.624 .53726 Mdot
.624 .53737 Mdot
.624 .53769 Mdot
.624 .53797 Mdot
.624 .53797 Mdot
.624 .53825 Mdot
.624 .53827 Mdot
.624 .53854 Mdot
.624 .53868 Mdot
.624 .53876 Mdot
.624 .53888 Mdot
.624 .5389 Mdot
.624 .53972 Mdot
.624 .53982 Mdot
.624 .53999 Mdot
.624 .5403 Mdot
.624 .54076 Mdot
.624 .54102 Mdot
.624 .54126 Mdot
.624 .54183 Mdot
.624 .54201 Mdot
.624 .54221 Mdot
.624 .54224 Mdot
.624 .54248 Mdot
.624 .54299 Mdot
.624 .54324 Mdot
.624 .54325 Mdot
.624 .54391 Mdot
.624 .54402 Mdot
.624 .54434 Mdot
.624 .54435 Mdot
.624 .54476 Mdot
.624 .54494 Mdot
.624 .54499 Mdot
.624 .54525 Mdot
.624 .54538 Mdot
.624 .54569 Mdot
.624 .54606 Mdot
.624 .54641 Mdot
.624 .5465 Mdot
.624 .54678 Mdot
.624 .54748 Mdot
.624 .54768 Mdot
.624 .54788 Mdot
.624 .54789 Mdot
.624 .54802 Mdot
.624 .54802 Mdot
.624 .54816 Mdot
.624 .5482 Mdot
.624 .54844 Mdot
.624 .54915 Mdot
.624 .54935 Mdot
.624 .5495 Mdot
.624 .54965 Mdot
.624 .55003 Mdot
.624 .55032 Mdot
.624 .55058 Mdot
.624 .55079 Mdot
.624 .55093 Mdot
.624 .55096 Mdot
.624 .55104 Mdot
.624 .55114 Mdot
.624 .55117 Mdot
.624 .55173 Mdot
.624 .55197 Mdot
.624 .55197 Mdot
.624 .55221 Mdot
.624 .55229 Mdot
.624 .55231 Mdot
.624 .55267 Mdot
.624 .55295 Mdot
.624 .55329 Mdot
.624 .55342 Mdot
.624 .55355 Mdot
.624 .55373 Mdot
.624 .554 Mdot
.624 .55405 Mdot
.624 .55406 Mdot
.624 .55409 Mdot
.624 .55418 Mdot
.624 .55427 Mdot
.624 .55444 Mdot
.624 .55466 Mdot
.624 .55468 Mdot
.624 .55478 Mdot
.624 .55483 Mdot
.624 .55494 Mdot
.624 .55544 Mdot
.624 .55546 Mdot
.624 .55548 Mdot
.624 .55561 Mdot
.624 .55579 Mdot
.624 .5559 Mdot
.624 .55598 Mdot
.624 .55616 Mdot
.624 .55619 Mdot
.624 .55622 Mdot
.624 .55623 Mdot
.624 .55625 Mdot
.624 .55626 Mdot
.624 .55651 Mdot
.624 .55665 Mdot
.624 .55683 Mdot
.624 .55686 Mdot
.624 .55697 Mdot
.624 .55698 Mdot
.624 .55702 Mdot
.624 .55704 Mdot
.624 .5571 Mdot
.624 .55711 Mdot
.624 .55711 Mdot
.624 .55713 Mdot
.624 .55719 Mdot
.624 .55724 Mdot
.624 .55755 Mdot
.624 .55763 Mdot
.624 .55772 Mdot
.624 .55774 Mdot
.624 .55775 Mdot
.624 .55786 Mdot
.624 .55806 Mdot
.624 .55808 Mdot
.624 .55811 Mdot
.624 .55818 Mdot
.624 .55823 Mdot
.624 .55835 Mdot
.624 .55843 Mdot
.624 .55848 Mdot
.624 .55855 Mdot
.624 .55856 Mdot
.624 .55865 Mdot
.624 .55866 Mdot
.624 .55866 Mdot
.624 .55881 Mdot
.624 .55882 Mdot
.624 .55884 Mdot
.624 .55885 Mdot
.624 .55895 Mdot
.624 .55895 Mdot
.624 .559 Mdot
.624 .55901 Mdot
.624 .55902 Mdot
.624 .55903 Mdot
.624 .55903 Mdot
.626 .16546 Mdot
.626 .16553 Mdot
.626 .16561 Mdot
.626 .16569 Mdot
.626 .16573 Mdot
.626 .16587 Mdot
.626 .16592 Mdot
.626 .16592 Mdot
.626 .16607 Mdot
.626 .16607 Mdot
.626 .1662 Mdot
.626 .16631 Mdot
.626 .16632 Mdot
.626 .16635 Mdot
.626 .16646 Mdot
.626 .16646 Mdot
.626 .16653 Mdot
.626 .16664 Mdot
.626 .16685 Mdot
.626 .16694 Mdot
.626 .1671 Mdot
.626 .16714 Mdot
.626 .16732 Mdot
.626 .16757 Mdot
.626 .16765 Mdot
.626 .16777 Mdot
.626 .16786 Mdot
.626 .16789 Mdot
.626 .16795 Mdot
.626 .16806 Mdot
.626 .16818 Mdot
.626 .16831 Mdot
.626 .16851 Mdot
.626 .16858 Mdot
.626 .16891 Mdot
.626 .16894 Mdot
.626 .16896 Mdot
.626 .16912 Mdot
.626 .16951 Mdot
.626 .16968 Mdot
.626 .17029 Mdot
.626 .1703 Mdot
.626 .17049 Mdot
.626 .17066 Mdot
.626 .17086 Mdot
.626 .17098 Mdot
.626 .171 Mdot
.626 .17105 Mdot
.626 .1715 Mdot
.626 .17166 Mdot
.626 .17195 Mdot
.626 .17256 Mdot
.626 .17266 Mdot
.626 .17287 Mdot
.626 .17298 Mdot
.626 .17304 Mdot
.626 .17318 Mdot
.626 .17345 Mdot
.626 .17363 Mdot
.626 .174 Mdot
.626 .17445 Mdot
.626 .17464 Mdot
.626 .17479 Mdot
.626 .17491 Mdot
.626 .17564 Mdot
.626 .17578 Mdot
.626 .17615 Mdot
.626 .17686 Mdot
.626 .17748 Mdot
.626 .17925 Mdot
.626 .18012 Mdot
.626 .18095 Mdot
.626 .18117 Mdot
.626 .18213 Mdot
.626 .18245 Mdot
.626 .18272 Mdot
.626 .18392 Mdot
.626 .18405 Mdot
.626 .18457 Mdot
.626 .18495 Mdot
.626 .18514 Mdot
.626 .18523 Mdot
.626 .18546 Mdot
.626 .18626 Mdot
.626 .18708 Mdot
.626 .18817 Mdot
.626 .18846 Mdot
.626 .18903 Mdot
.626 .18922 Mdot
.626 .18992 Mdot
.626 .19008 Mdot
.626 .19043 Mdot
.626 .19483 Mdot
.626 .19528 Mdot
.626 .1955 Mdot
.626 .1959 Mdot
.626 .19629 Mdot
.626 .19779 Mdot
.626 .19976 Mdot
.626 .20015 Mdot
.626 .20015 Mdot
.626 .2002 Mdot
.626 .20082 Mdot
.626 .20244 Mdot
.626 .20277 Mdot
.626 .20308 Mdot
.626 .20326 Mdot
.626 .20333 Mdot
.626 .20387 Mdot
.626 .20393 Mdot
.626 .20394 Mdot
.626 .20423 Mdot
.626 .20469 Mdot
.626 .20552 Mdot
.626 .2057 Mdot
.626 .20701 Mdot
.626 .20737 Mdot
.626 .20823 Mdot
.626 .2083 Mdot
.626 .20856 Mdot
.626 .20859 Mdot
.626 .20911 Mdot
.626 .21001 Mdot
.626 .21129 Mdot
.626 .21169 Mdot
.626 .21176 Mdot
.626 .21195 Mdot
.626 .2121 Mdot
.626 .21442 Mdot
.626 .2153 Mdot
.626 .21594 Mdot
.626 .21686 Mdot
.626 .21749 Mdot
.626 .21821 Mdot
.626 .22078 Mdot
.626 .22113 Mdot
.626 .22224 Mdot
.626 .22302 Mdot
.626 .22325 Mdot
.626 .22391 Mdot
.626 .2244 Mdot
.626 .22489 Mdot
.626 .22499 Mdot
.626 .22517 Mdot
.626 .22518 Mdot
.626 .22546 Mdot
.626 .2276 Mdot
.626 .22911 Mdot
.626 .23 Mdot
.626 .23077 Mdot
.626 .23565 Mdot
.626 .23623 Mdot
.626 .2369 Mdot
.626 .23759 Mdot
.626 .23765 Mdot
.626 .23955 Mdot
.626 .24052 Mdot
.626 .24331 Mdot
.626 .24625 Mdot
.626 .25107 Mdot
.626 .25283 Mdot
.626 .25391 Mdot
.626 .25515 Mdot
.626 .25647 Mdot
.626 .25684 Mdot
.626 .25717 Mdot
.626 .25799 Mdot
.626 .25846 Mdot
.626 .25979 Mdot
.626 .25994 Mdot
.626 .26136 Mdot
.626 .26166 Mdot
.626 .26187 Mdot
.626 .26332 Mdot
.626 .26472 Mdot
.626 .26476 Mdot
.626 .26667 Mdot
.626 .27728 Mdot
.626 .27932 Mdot
.626 .2807 Mdot
.626 .28168 Mdot
.626 .2857 Mdot
.626 .28963 Mdot
.626 .2899 Mdot
.626 .29004 Mdot
.626 .29151 Mdot
.626 .29227 Mdot
.626 .29228 Mdot
.626 .29248 Mdot
.626 .29279 Mdot
.626 .29305 Mdot
.626 .29439 Mdot
.626 .29574 Mdot
.626 .2966 Mdot
.626 .29702 Mdot
.626 .29756 Mdot
.626 .29801 Mdot
.626 .29821 Mdot
.626 .2985 Mdot
.626 .29993 Mdot
.626 .30038 Mdot
.626 .3013 Mdot
.626 .3019 Mdot
.626 .30231 Mdot
.626 .30244 Mdot
.626 .30348 Mdot
.626 .30446 Mdot
.626 .30533 Mdot
.626 .30562 Mdot
.626 .30724 Mdot
.626 .30885 Mdot
.626 .31173 Mdot
.626 .3138 Mdot
.626 .31383 Mdot
.626 .31455 Mdot
.626 .31513 Mdot
.626 .31558 Mdot
.626 .3161 Mdot
.626 .31635 Mdot
.626 .3174 Mdot
.626 .31822 Mdot
.626 .31871 Mdot
.626 .31935 Mdot
.626 .32009 Mdot
.626 .32023 Mdot
.626 .32074 Mdot
.626 .32157 Mdot
.626 .32223 Mdot
.626 .32233 Mdot
.626 .32263 Mdot
.626 .32334 Mdot
.626 .32465 Mdot
.626 .32467 Mdot
.626 .32585 Mdot
.626 .32675 Mdot
.626 .32715 Mdot
.626 .32855 Mdot
.626 .32863 Mdot
.626 .32882 Mdot
.626 .32915 Mdot
.626 .32939 Mdot
.626 .32984 Mdot
.626 .33039 Mdot
.626 .33061 Mdot
.626 .33079 Mdot
.626 .33094 Mdot
.626 .33177 Mdot
.626 .33193 Mdot
.626 .3331 Mdot
.626 .33375 Mdot
.626 .33553 Mdot
.626 .33713 Mdot
.626 .3382 Mdot
.626 .33848 Mdot
.626 .33974 Mdot
.626 .33985 Mdot
.626 .34029 Mdot
.626 .3406 Mdot
.626 .34083 Mdot
.626 .34101 Mdot
.626 .34166 Mdot
.626 .3423 Mdot
.626 .34314 Mdot
.626 .34336 Mdot
.626 .3438 Mdot
.626 .34394 Mdot
.626 .34445 Mdot
.626 .34457 Mdot
.626 .34482 Mdot
.626 .34791 Mdot
.626 .34822 Mdot
.626 .34836 Mdot
.626 .34863 Mdot
.626 .34889 Mdot
.626 .34987 Mdot
.626 .35112 Mdot
.626 .35137 Mdot
.626 .35139 Mdot
.626 .35178 Mdot
.626 .35278 Mdot
.626 .35297 Mdot
.626 .35316 Mdot
.626 .35363 Mdot
.626 .35367 Mdot
.626 .35368 Mdot
.626 .35385 Mdot
.626 .35412 Mdot
.626 .35461 Mdot
.626 .35547 Mdot
.626 .35568 Mdot
.626 .35621 Mdot
.626 .35635 Mdot
.626 .35717 Mdot
.626 .35788 Mdot
.626 .35814 Mdot
.626 .35832 Mdot
.626 .36038 Mdot
.626 .36305 Mdot
.626 .36361 Mdot
.626 .364 Mdot
.626 .36445 Mdot
.626 .36469 Mdot
.626 .36493 Mdot
.626 .36497 Mdot
.626 .36507 Mdot
.626 .36507 Mdot
.626 .36625 Mdot
.626 .36739 Mdot
.626 .36775 Mdot
.626 .37002 Mdot
.626 .37028 Mdot
.626 .37058 Mdot
.626 .3709 Mdot
.626 .37093 Mdot
.626 .37221 Mdot
.626 .37344 Mdot
.626 .37677 Mdot
.626 .37796 Mdot
.626 .37902 Mdot
.626 .37918 Mdot
.626 .37931 Mdot
.626 .37965 Mdot
.626 .37984 Mdot
.626 .38102 Mdot
.626 .38122 Mdot
.626 .38236 Mdot
.626 .38314 Mdot
.626 .38856 Mdot
.626 .39189 Mdot
.626 .39199 Mdot
.626 .39204 Mdot
.626 .39293 Mdot
.626 .39368 Mdot
.626 .39443 Mdot
.626 .39458 Mdot
.626 .39512 Mdot
.626 .39563 Mdot
.626 .39612 Mdot
.626 .39634 Mdot
.626 .39649 Mdot
.626 .39653 Mdot
.626 .39756 Mdot
.626 .39767 Mdot
.626 .39824 Mdot
.626 .39881 Mdot
.626 .40056 Mdot
.626 .40081 Mdot
.626 .40101 Mdot
.626 .40135 Mdot
.626 .40144 Mdot
.626 .4018 Mdot
.626 .40226 Mdot
.626 .40248 Mdot
.626 .40278 Mdot
.626 .40296 Mdot
.626 .40325 Mdot
.626 .40347 Mdot
.626 .40351 Mdot
.626 .40386 Mdot
.626 .40431 Mdot
.626 .40431 Mdot
.626 .40472 Mdot
.626 .40503 Mdot
.626 .40517 Mdot
.626 .40565 Mdot
.626 .40567 Mdot
.626 .40574 Mdot
.626 .40585 Mdot
.626 .40641 Mdot
.626 .40646 Mdot
.626 .4068 Mdot
.626 .40719 Mdot
.626 .40742 Mdot
.626 .40856 Mdot
.626 .40902 Mdot
.626 .40962 Mdot
.626 .40987 Mdot
.626 .41009 Mdot
.626 .4103 Mdot
.626 .41058 Mdot
.626 .4108 Mdot
.626 .41085 Mdot
.626 .41106 Mdot
.626 .41115 Mdot
.626 .41218 Mdot
.626 .41228 Mdot
.626 .41242 Mdot
.626 .41284 Mdot
.626 .41325 Mdot
.626 .41334 Mdot
.626 .41347 Mdot
.626 .41387 Mdot
.626 .41393 Mdot
.626 .4141 Mdot
.626 .41425 Mdot
.626 .41442 Mdot
.626 .415 Mdot
.626 .4155 Mdot
.626 .41565 Mdot
.626 .41633 Mdot
.626 .4174 Mdot
.626 .41753 Mdot
.626 .41768 Mdot
.626 .41776 Mdot
.626 .41785 Mdot
.626 .41865 Mdot
.626 .41877 Mdot
.626 .41952 Mdot
.626 .4196 Mdot
.626 .4197 Mdot
.626 .41981 Mdot
.626 .41982 Mdot
.626 .42065 Mdot
.626 .42248 Mdot
.626 .42258 Mdot
.626 .42269 Mdot
.626 .42314 Mdot
.626 .42358 Mdot
.626 .42384 Mdot
.626 .42562 Mdot
.626 .42672 Mdot
.626 .42675 Mdot
.626 .42677 Mdot
.626 .42706 Mdot
.626 .42731 Mdot
.626 .42756 Mdot
.626 .42778 Mdot
.626 .42818 Mdot
.626 .42823 Mdot
.626 .42825 Mdot
.626 .42859 Mdot
.626 .42862 Mdot
.626 .42966 Mdot
.626 .42973 Mdot
.626 .42984 Mdot
.626 .42999 Mdot
.626 .43014 Mdot
.626 .43021 Mdot
.626 .43031 Mdot
.626 .43037 Mdot
.626 .43046 Mdot
.626 .43054 Mdot
.626 .43055 Mdot
.626 .43067 Mdot
.626 .43082 Mdot
.626 .43082 Mdot
.626 .43105 Mdot
.626 .4311 Mdot
.626 .43126 Mdot
.626 .43127 Mdot
.626 .43129 Mdot
.626 .43133 Mdot
.626 .43151 Mdot
.626 .43153 Mdot
.626 .43164 Mdot
.626 .43184 Mdot
.626 .43222 Mdot
.626 .43237 Mdot
.626 .43266 Mdot
.626 .43273 Mdot
.626 .43297 Mdot
.626 .43298 Mdot
.626 .43305 Mdot
.626 .43342 Mdot
.626 .4335 Mdot
.626 .43364 Mdot
.626 .43378 Mdot
.626 .43381 Mdot
.626 .43385 Mdot
.626 .43401 Mdot
.626 .43406 Mdot
.626 .43417 Mdot
.626 .43436 Mdot
.626 .43453 Mdot
.626 .43458 Mdot
.626 .43481 Mdot
.626 .43516 Mdot
.626 .43521 Mdot
.626 .43525 Mdot
.626 .43528 Mdot
.626 .43562 Mdot
.626 .43587 Mdot
.626 .43593 Mdot
.626 .43597 Mdot
.626 .43597 Mdot
.626 .43625 Mdot
.626 .43689 Mdot
.626 .43693 Mdot
.626 .43723 Mdot
.626 .43732 Mdot
.626 .43829 Mdot
.626 .4383 Mdot
.626 .4383 Mdot
.626 .4384 Mdot
.626 .43848 Mdot
.626 .43857 Mdot
.626 .43864 Mdot
.626 .4388 Mdot
.626 .4388 Mdot
.626 .43892 Mdot
.626 .43893 Mdot
.626 .43928 Mdot
.626 .4395 Mdot
.626 .43952 Mdot
.626 .43962 Mdot
.626 .43977 Mdot
.626 .43983 Mdot
.626 .4404 Mdot
.626 .4404 Mdot
.626 .44068 Mdot
.626 .44069 Mdot
.626 .44093 Mdot
.626 .44116 Mdot
.626 .4413 Mdot
.626 .44142 Mdot
.626 .44174 Mdot
.626 .44222 Mdot
.626 .44228 Mdot
.626 .44231 Mdot
.626 .44239 Mdot
.626 .44243 Mdot
.626 .44272 Mdot
.626 .44274 Mdot
.626 .44294 Mdot
.626 .44304 Mdot
.626 .44329 Mdot
.626 .44359 Mdot
.626 .44364 Mdot
.626 .44374 Mdot
.626 .44405 Mdot
.626 .44464 Mdot
.626 .44467 Mdot
.626 .44518 Mdot
.626 .44535 Mdot
.626 .44542 Mdot
.626 .44544 Mdot
.626 .44575 Mdot
.626 .44594 Mdot
.626 .44601 Mdot
.626 .44622 Mdot
.626 .44636 Mdot
.626 .44653 Mdot
.626 .44686 Mdot
.626 .44689 Mdot
.626 .44738 Mdot
.626 .44745 Mdot
.626 .44745 Mdot
.626 .44758 Mdot
.626 .44763 Mdot
.626 .44768 Mdot
.626 .44774 Mdot
.626 .4483 Mdot
.626 .44854 Mdot
.626 .44907 Mdot
.626 .44927 Mdot
.626 .44947 Mdot
.626 .4495 Mdot
.626 .44988 Mdot
.626 .45029 Mdot
.626 .4503 Mdot
.626 .4505 Mdot
.626 .45075 Mdot
.626 .45076 Mdot
.626 .4517 Mdot
.626 .45181 Mdot
.626 .45205 Mdot
.626 .45221 Mdot
.626 .45224 Mdot
.626 .45261 Mdot
.626 .45318 Mdot
.626 .4532 Mdot
.626 .45339 Mdot
.626 .45339 Mdot
.626 .45342 Mdot
.626 .45364 Mdot
.626 .45377 Mdot
.626 .4539 Mdot
.626 .45404 Mdot
.626 .4542 Mdot
.626 .45421 Mdot
.626 .45423 Mdot
.626 .45483 Mdot
.626 .45579 Mdot
.626 .45593 Mdot
.626 .45617 Mdot
.626 .45642 Mdot
.626 .45648 Mdot
.626 .45653 Mdot
.626 .45751 Mdot
.626 .45796 Mdot
.626 .45796 Mdot
.626 .45802 Mdot
.626 .45807 Mdot
.626 .45812 Mdot
.626 .45851 Mdot
.626 .45858 Mdot
.626 .459 Mdot
.626 .45905 Mdot
.626 .45909 Mdot
.626 .45917 Mdot
.626 .45924 Mdot
.626 .45981 Mdot
.626 .46017 Mdot
.626 .46024 Mdot
.626 .46051 Mdot
.626 .46081 Mdot
.626 .4609 Mdot
.626 .46098 Mdot
.626 .46106 Mdot
.626 .4611 Mdot
.626 .46131 Mdot
.626 .46138 Mdot
.626 .46142 Mdot
.626 .46164 Mdot
.626 .46185 Mdot
.626 .46193 Mdot
.626 .46198 Mdot
.626 .46251 Mdot
.626 .46256 Mdot
.626 .46267 Mdot
.626 .46269 Mdot
.626 .46281 Mdot
.626 .46295 Mdot
.626 .46306 Mdot
.626 .46318 Mdot
.626 .4633 Mdot
.626 .46362 Mdot
.626 .46385 Mdot
.626 .46444 Mdot
.626 .46455 Mdot
.626 .46475 Mdot
.626 .46493 Mdot
.626 .46495 Mdot
.626 .46524 Mdot
.626 .46529 Mdot
.626 .46533 Mdot
.626 .46534 Mdot
.626 .46558 Mdot
.626 .46565 Mdot
.626 .46581 Mdot
.626 .46602 Mdot
.626 .46602 Mdot
.626 .46625 Mdot
.626 .46642 Mdot
.626 .46644 Mdot
.626 .46656 Mdot
.626 .4667 Mdot
.626 .46679 Mdot
.626 .46694 Mdot
.626 .46705 Mdot
.626 .46728 Mdot
.626 .46747 Mdot
.626 .46751 Mdot
.626 .46768 Mdot
.626 .46778 Mdot
.626 .46791 Mdot
.626 .46878 Mdot
.626 .46906 Mdot
.626 .46935 Mdot
.626 .4694 Mdot
.626 .46991 Mdot
.626 .46993 Mdot
.626 .47 Mdot
.626 .47011 Mdot
.626 .47035 Mdot
.626 .47061 Mdot
.626 .47087 Mdot
.626 .47094 Mdot
.626 .47131 Mdot
.626 .47168 Mdot
.626 .47212 Mdot
.626 .47214 Mdot
.626 .47219 Mdot
.626 .47381 Mdot
.626 .4764 Mdot
.626 .47677 Mdot
.626 .47731 Mdot
.626 .4774 Mdot
.626 .47796 Mdot
.626 .47805 Mdot
.626 .47821 Mdot
.626 .47827 Mdot
.626 .47834 Mdot
.626 .47884 Mdot
.626 .4794 Mdot
.626 .48094 Mdot
.626 .48151 Mdot
.626 .4821 Mdot
.626 .48212 Mdot
.626 .48226 Mdot
.626 .4824 Mdot
.626 .48252 Mdot
.626 .48355 Mdot
.626 .48372 Mdot
.626 .48424 Mdot
.626 .48477 Mdot
.626 .48478 Mdot
.626 .48482 Mdot
.626 .48484 Mdot
.626 .48495 Mdot
.626 .48506 Mdot
.626 .48526 Mdot
.626 .48543 Mdot
.626 .48568 Mdot
.626 .48688 Mdot
.626 .4878 Mdot
.626 .48788 Mdot
.626 .488 Mdot
.626 .48831 Mdot
.626 .48867 Mdot
.626 .48874 Mdot
.626 .48897 Mdot
.626 .48906 Mdot
.626 .48944 Mdot
.626 .48966 Mdot
.626 .48978 Mdot
.626 .48986 Mdot
.626 .48986 Mdot
.626 .48987 Mdot
.626 .49008 Mdot
.626 .49017 Mdot
.626 .49025 Mdot
.626 .49069 Mdot
.626 .49086 Mdot
.626 .49087 Mdot
.626 .49098 Mdot
.626 .49152 Mdot
.626 .49195 Mdot
.626 .49206 Mdot
.626 .49218 Mdot
.626 .49224 Mdot
.626 .49237 Mdot
.626 .49371 Mdot
.626 .49382 Mdot
.626 .49387 Mdot
.626 .49409 Mdot
.626 .49415 Mdot
.626 .49434 Mdot
.626 .49443 Mdot
.626 .49479 Mdot
.626 .49507 Mdot
.626 .49534 Mdot
.626 .49542 Mdot
.626 .49552 Mdot
.626 .49565 Mdot
.626 .49584 Mdot
.626 .49588 Mdot
.626 .49642 Mdot
.626 .49654 Mdot
.626 .49699 Mdot
.626 .49767 Mdot
.626 .49841 Mdot
.626 .49869 Mdot
.626 .49918 Mdot
.626 .49924 Mdot
.626 .49959 Mdot
.626 .49966 Mdot
.626 .49973 Mdot
.626 .49982 Mdot
.626 .50005 Mdot
.626 .50024 Mdot
.626 .50034 Mdot
.626 .50047 Mdot
.626 .50055 Mdot
.626 .50058 Mdot
.626 .50117 Mdot
.626 .50133 Mdot
.626 .5017 Mdot
.626 .50219 Mdot
.626 .5022 Mdot
.626 .50274 Mdot
.626 .50303 Mdot
.626 .50315 Mdot
.626 .50319 Mdot
.626 .50346 Mdot
.626 .5038 Mdot
.626 .50401 Mdot
.626 .50407 Mdot
.626 .50437 Mdot
.626 .50463 Mdot
.626 .50483 Mdot
.626 .50516 Mdot
.626 .50559 Mdot
.626 .50569 Mdot
.626 .5059 Mdot
.626 .50608 Mdot
.626 .50631 Mdot
.626 .5066 Mdot
.626 .50662 Mdot
.626 .50745 Mdot
.626 .5086 Mdot
.626 .50924 Mdot
.626 .50988 Mdot
.626 .51 Mdot
.626 .51034 Mdot
.626 .51072 Mdot
.626 .51114 Mdot
.626 .51119 Mdot
.626 .51135 Mdot
.626 .51158 Mdot
.626 .51194 Mdot
.626 .51212 Mdot
.626 .51268 Mdot
.626 .51279 Mdot
.626 .51287 Mdot
.626 .51304 Mdot
.626 .51326 Mdot
.626 .51342 Mdot
.626 .51375 Mdot
.626 .51428 Mdot
.626 .5148 Mdot
.626 .5149 Mdot
.626 .51502 Mdot
.626 .51509 Mdot
.626 .5151 Mdot
.626 .51539 Mdot
.626 .51596 Mdot
.626 .51601 Mdot
.626 .51611 Mdot
.626 .51762 Mdot
.626 .51915 Mdot
.626 .51951 Mdot
.626 .52004 Mdot
.626 .5208 Mdot
.626 .52475 Mdot
.626 .52545 Mdot
.626 .52547 Mdot
.626 .52598 Mdot
.626 .52651 Mdot
.626 .52659 Mdot
.626 .5267 Mdot
.626 .52722 Mdot
.626 .52727 Mdot
.626 .52776 Mdot
.626 .52793 Mdot
.626 .52822 Mdot
.626 .52834 Mdot
.626 .52848 Mdot
.626 .52895 Mdot
.626 .5294 Mdot
.626 .52979 Mdot
.626 .53043 Mdot
.626 .53215 Mdot
.626 .53319 Mdot
.626 .53418 Mdot
.626 .53452 Mdot
.626 .53519 Mdot
.626 .53521 Mdot
.626 .53546 Mdot
.626 .53569 Mdot
.626 .5359 Mdot
.626 .5376 Mdot
.626 .53787 Mdot
.626 .53818 Mdot
.626 .5387 Mdot
.626 .53944 Mdot
.626 .53954 Mdot
.626 .53954 Mdot
.626 .5396 Mdot
.626 .53964 Mdot
.626 .53981 Mdot
.626 .53997 Mdot
.626 .5402 Mdot
.626 .54028 Mdot
.626 .54055 Mdot
.626 .54093 Mdot
.626 .54105 Mdot
.626 .54193 Mdot
.626 .54218 Mdot
.626 .54239 Mdot
.626 .5427 Mdot
.626 .54292 Mdot
.626 .54322 Mdot
.626 .54401 Mdot
.626 .54406 Mdot
.626 .54412 Mdot
.626 .54415 Mdot
.626 .54428 Mdot
.626 .54471 Mdot
.626 .54502 Mdot
.626 .54519 Mdot
.626 .5452 Mdot
.626 .54529 Mdot
.626 .54531 Mdot
.626 .5456 Mdot
.626 .54572 Mdot
.626 .54616 Mdot
.626 .54622 Mdot
.626 .5465 Mdot
.626 .54666 Mdot
.626 .54675 Mdot
.626 .54676 Mdot
.626 .54677 Mdot
.626 .54696 Mdot
.626 .54698 Mdot
.626 .54704 Mdot
.626 .54714 Mdot
.626 .54725 Mdot
.626 .54779 Mdot
.626 .548 Mdot
.626 .54802 Mdot
.626 .54802 Mdot
.626 .54815 Mdot
.626 .5488 Mdot
.626 .5493 Mdot
.626 .54943 Mdot
.626 .54956 Mdot
.626 .54963 Mdot
.626 .54978 Mdot
.626 .55123 Mdot
.626 .55134 Mdot
.626 .5514 Mdot
.626 .55162 Mdot
.626 .55169 Mdot
.626 .55188 Mdot
.626 .55197 Mdot
.626 .55233 Mdot
.626 .55259 Mdot
.626 .55286 Mdot
.626 .55293 Mdot
.626 .55296 Mdot
.626 .55302 Mdot
.626 .55314 Mdot
.626 .55332 Mdot
.626 .55336 Mdot
.626 .55375 Mdot
.626 .55383 Mdot
.626 .55394 Mdot
.626 .55425 Mdot
.626 .55432 Mdot
.626 .55459 Mdot
.626 .55487 Mdot
.626 .55544 Mdot
.626 .55565 Mdot
.626 .55587 Mdot
.626 .55599 Mdot
.626 .55604 Mdot
.626 .55627 Mdot
.626 .55631 Mdot
.626 .55636 Mdot
.626 .55642 Mdot
.626 .55657 Mdot
.626 .55668 Mdot
.626 .55674 Mdot
.626 .55683 Mdot
.626 .55687 Mdot
.626 .55689 Mdot
.626 .55693 Mdot
.626 .55699 Mdot
.626 .55703 Mdot
.626 .55722 Mdot
.626 .55731 Mdot
.626 .55736 Mdot
.626 .55751 Mdot
.626 .55753 Mdot
.626 .55753 Mdot
.626 .55757 Mdot
.626 .55764 Mdot
.626 .55769 Mdot
.626 .55775 Mdot
.626 .55775 Mdot
.626 .55795 Mdot
.626 .558 Mdot
.626 .55813 Mdot
.626 .55818 Mdot
.626 .55818 Mdot
.626 .55819 Mdot
.626 .5583 Mdot
.626 .55832 Mdot
.626 .55839 Mdot
.626 .55843 Mdot
.626 .55847 Mdot
.626 .5585 Mdot
.626 .55852 Mdot
.626 .55853 Mdot
.626 .55856 Mdot
.626 .5586 Mdot
.626 .55862 Mdot
.626 .5587 Mdot
.626 .55876 Mdot
.626 .55877 Mdot
.626 .55882 Mdot
.626 .55885 Mdot
.626 .55892 Mdot
.626 .55895 Mdot
.626 .55897 Mdot
.626 .55898 Mdot
.626 .55901 Mdot
.626 .55902 Mdot
.626 .55902 Mdot
.626 .55906 Mdot
.626 .5591 Mdot
.626 .5591 Mdot
.626 .55915 Mdot
.626 .55915 Mdot
.626 .55916 Mdot
.626 .55921 Mdot
.626 .55922 Mdot
.626 .55925 Mdot
.626 .55927 Mdot
.626 .55929 Mdot
.628 .16479 Mdot
.628 .16508 Mdot
.628 .30516 Mdot
.628 .30963 Mdot
.628 .39765 Mdot
.628 .39923 Mdot
.628 .42869 Mdot
.628 .42921 Mdot
.628 .46865 Mdot
.628 .46944 Mdot
.628 .50834 Mdot
.628 .51011 Mdot
.628 .55943 Mdot
.628 .55952 Mdot
.63 .16411 Mdot
.63 .16412 Mdot
.63 .16412 Mdot
.63 .16413 Mdot
.63 .16417 Mdot
.63 .16418 Mdot
.63 .16424 Mdot
.63 .16425 Mdot
.63 .16433 Mdot
.63 .16434 Mdot
.63 .16445 Mdot
.63 .16457 Mdot
.63 .16461 Mdot
.63 .16464 Mdot
.63 .1647 Mdot
.63 .16475 Mdot
.63 .16479 Mdot
.63 .16485 Mdot
.63 .1649 Mdot
.63 .165 Mdot
.63 .16506 Mdot
.63 .16543 Mdot
.63 .16564 Mdot
.63 .16576 Mdot
.63 .16608 Mdot
.63 .1662 Mdot
.63 .16628 Mdot
.63 .16631 Mdot
.63 .16633 Mdot
.63 .16651 Mdot
.63 .16678 Mdot
.63 .16687 Mdot
.63 .16688 Mdot
.63 .16688 Mdot
.63 .16697 Mdot
.63 .1674 Mdot
.63 .16749 Mdot
.63 .16758 Mdot
.63 .16786 Mdot
.63 .16787 Mdot
.63 .16789 Mdot
.63 .168 Mdot
.63 .16977 Mdot
.63 .17016 Mdot
.63 .17052 Mdot
.63 .17081 Mdot
.63 .17117 Mdot
.63 .17152 Mdot
.63 .17195 Mdot
.63 .17202 Mdot
.63 .17211 Mdot
.63 .17216 Mdot
.63 .17254 Mdot
.63 .17255 Mdot
.63 .17266 Mdot
.63 .17273 Mdot
.63 .17283 Mdot
.63 .17396 Mdot
.63 .17434 Mdot
.63 .17453 Mdot
.63 .17537 Mdot
.63 .1757 Mdot
.63 .17634 Mdot
.63 .17697 Mdot
.63 .17733 Mdot
.63 .17918 Mdot
.63 .1793 Mdot
.63 .1795 Mdot
.63 .17977 Mdot
.63 .18063 Mdot
.63 .18136 Mdot
.63 .18138 Mdot
.63 .1816 Mdot
.63 .18163 Mdot
.63 .18216 Mdot
.63 .18282 Mdot
.63 .18287 Mdot
.63 .18302 Mdot
.63 .18335 Mdot
.63 .18381 Mdot
.63 .18434 Mdot
.63 .18451 Mdot
.63 .18502 Mdot
.63 .1852 Mdot
.63 .18584 Mdot
.63 .18649 Mdot
.63 .18908 Mdot
.63 .1912 Mdot
.63 .1918 Mdot
.63 .19207 Mdot
.63 .19238 Mdot
.63 .19262 Mdot
.63 .19306 Mdot
.63 .19364 Mdot
.63 .19372 Mdot
.63 .19442 Mdot
.63 .19457 Mdot
.63 .19488 Mdot
.63 .19578 Mdot
.63 .19591 Mdot
.63 .19671 Mdot
.63 .19701 Mdot
.63 .19747 Mdot
.63 .19799 Mdot
.63 .19824 Mdot
.63 .20112 Mdot
.63 .20148 Mdot
.63 .2015 Mdot
.63 .20204 Mdot
.63 .20396 Mdot
.63 .20403 Mdot
.63 .20448 Mdot
.63 .20462 Mdot
.63 .20468 Mdot
.63 .20541 Mdot
.63 .2056 Mdot
.63 .20561 Mdot
.63 .20575 Mdot
.63 .20732 Mdot
.63 .20771 Mdot
.63 .20825 Mdot
.63 .20829 Mdot
.63 .20831 Mdot
.63 .20894 Mdot
.63 .20938 Mdot
.63 .21167 Mdot
.63 .212 Mdot
.63 .21478 Mdot
.63 .21485 Mdot
.63 .21505 Mdot
.63 .21697 Mdot
.63 .21713 Mdot
.63 .2177 Mdot
.63 .21856 Mdot
.63 .21856 Mdot
.63 .22263 Mdot
.63 .22513 Mdot
.63 .22581 Mdot
.63 .22605 Mdot
.63 .22706 Mdot
.63 .229 Mdot
.63 .22963 Mdot
.63 .23083 Mdot
.63 .23269 Mdot
.63 .23415 Mdot
.63 .23513 Mdot
.63 .23573 Mdot
.63 .23586 Mdot
.63 .23609 Mdot
.63 .23612 Mdot
.63 .23648 Mdot
.63 .23669 Mdot
.63 .23684 Mdot
.63 .23891 Mdot
.63 .23975 Mdot
.63 .24039 Mdot
.63 .24103 Mdot
.63 .24175 Mdot
.63 .24236 Mdot
.63 .24241 Mdot
.63 .24294 Mdot
.63 .2436 Mdot
.63 .24452 Mdot
.63 .24569 Mdot
.63 .24606 Mdot
.63 .24705 Mdot
.63 .24714 Mdot
.63 .24731 Mdot
.63 .24742 Mdot
.63 .24748 Mdot
.63 .24887 Mdot
.63 .25029 Mdot
.63 .25059 Mdot
.63 .25151 Mdot
.63 .25199 Mdot
.63 .25211 Mdot
.63 .25244 Mdot
.63 .25366 Mdot
.63 .2557 Mdot
.63 .25643 Mdot
.63 .25912 Mdot
.63 .2608 Mdot
.63 .26118 Mdot
.63 .26148 Mdot
.63 .2617 Mdot
.63 .2626 Mdot
.63 .26267 Mdot
.63 .26268 Mdot
.63 .26324 Mdot
.63 .26359 Mdot
.63 .26363 Mdot
.63 .2651 Mdot
.63 .26758 Mdot
.63 .26806 Mdot
.63 .26867 Mdot
.63 .27134 Mdot
.63 .27175 Mdot
.63 .27327 Mdot
.63 .27621 Mdot
.63 .27675 Mdot
.63 .27869 Mdot
.63 .27937 Mdot
.63 .28104 Mdot
.63 .28123 Mdot
.63 .28346 Mdot
.63 .2841 Mdot
.63 .28603 Mdot
.63 .28625 Mdot
.63 .28668 Mdot
.63 .28821 Mdot
.63 .28835 Mdot
.63 .28901 Mdot
.63 .28966 Mdot
.63 .2906 Mdot
.63 .29153 Mdot
.63 .29501 Mdot
.63 .29519 Mdot
.63 .29524 Mdot
.63 .29526 Mdot
.63 .29578 Mdot
.63 .29595 Mdot
.63 .29613 Mdot
.63 .297 Mdot
.63 .29719 Mdot
.63 .29843 Mdot
.63 .29848 Mdot
.63 .29855 Mdot
.63 .29875 Mdot
.63 .30023 Mdot
.63 .30209 Mdot
.63 .30271 Mdot
.63 .30292 Mdot
.63 .30315 Mdot
.63 .30335 Mdot
.63 .30387 Mdot
.63 .30421 Mdot
.63 .30489 Mdot
.63 .30561 Mdot
.63 .30634 Mdot
.63 .30646 Mdot
.63 .30726 Mdot
.63 .30884 Mdot
.63 .30981 Mdot
.63 .30991 Mdot
.63 .30993 Mdot
.63 .31094 Mdot
.63 .31239 Mdot
.63 .31403 Mdot
.63 .31449 Mdot
.63 .31571 Mdot
.63 .31719 Mdot
.63 .31813 Mdot
.63 .31897 Mdot
.63 .32002 Mdot
.63 .32062 Mdot
.63 .32081 Mdot
.63 .32084 Mdot
.63 .32593 Mdot
.63 .32702 Mdot
.63 .32791 Mdot
.63 .32894 Mdot
.63 .32913 Mdot
.63 .3292 Mdot
.63 .32969 Mdot
.63 .32991 Mdot
.63 .33004 Mdot
.63 .33291 Mdot
.63 .33327 Mdot
.63 .33493 Mdot
.63 .3367 Mdot
.63 .33724 Mdot
.63 .33801 Mdot
.63 .33865 Mdot
.63 .33886 Mdot
.63 .33888 Mdot
.63 .33989 Mdot
.63 .33993 Mdot
.63 .34006 Mdot
.63 .34034 Mdot
.63 .34072 Mdot
.63 .34114 Mdot
.63 .34168 Mdot
.63 .34233 Mdot
.63 .34283 Mdot
.63 .34688 Mdot
.63 .3471 Mdot
.63 .34726 Mdot
.63 .34756 Mdot
.63 .34795 Mdot
.63 .348 Mdot
.63 .34847 Mdot
.63 .34857 Mdot
.63 .34878 Mdot
.63 .34945 Mdot
.63 .35016 Mdot
.63 .35078 Mdot
.63 .35094 Mdot
.63 .35136 Mdot
.63 .35271 Mdot
.63 .35294 Mdot
.63 .35327 Mdot
.63 .35471 Mdot
.63 .35482 Mdot
.63 .35524 Mdot
.63 .35688 Mdot
.63 .35689 Mdot
.63 .35748 Mdot
.63 .35873 Mdot
.63 .36039 Mdot
.63 .36042 Mdot
.63 .36053 Mdot
.63 .36152 Mdot
.63 .3619 Mdot
.63 .36234 Mdot
.63 .3683 Mdot
.63 .36983 Mdot
.63 .37028 Mdot
.63 .37071 Mdot
.63 .37105 Mdot
.63 .37263 Mdot
.63 .37291 Mdot
.63 .37323 Mdot
.63 .37349 Mdot
.63 .37375 Mdot
.63 .37403 Mdot
.63 .37493 Mdot
.63 .37551 Mdot
.63 .37555 Mdot
.63 .3757 Mdot
.63 .37688 Mdot
.63 .37739 Mdot
.63 .37759 Mdot
.63 .37778 Mdot
.63 .37942 Mdot
.63 .38052 Mdot
.63 .38147 Mdot
.63 .38194 Mdot
.63 .38232 Mdot
.63 .38407 Mdot
.63 .3843 Mdot
.63 .3855 Mdot
.63 .38608 Mdot
.63 .38741 Mdot
.63 .38815 Mdot
.63 .3891 Mdot
.63 .38994 Mdot
.63 .39017 Mdot
.63 .39089 Mdot
.63 .39113 Mdot
.63 .39169 Mdot
.63 .39174 Mdot
.63 .39257 Mdot
.63 .39417 Mdot
.63 .39424 Mdot
.63 .39426 Mdot
.63 .39426 Mdot
.63 .39445 Mdot
.63 .39451 Mdot
.63 .39457 Mdot
.63 .39489 Mdot
.63 .39496 Mdot
.63 .39542 Mdot
.63 .39545 Mdot
.63 .39552 Mdot
.63 .39605 Mdot
.63 .39671 Mdot
.63 .39693 Mdot
.63 .397 Mdot
.63 .39709 Mdot
.63 .39716 Mdot
.63 .39734 Mdot
.63 .39746 Mdot
.63 .3977 Mdot
.63 .39796 Mdot
.63 .39821 Mdot
.63 .39826 Mdot
.63 .39854 Mdot
.63 .39909 Mdot
.63 .39944 Mdot
.63 .39983 Mdot
.63 .40149 Mdot
.63 .402 Mdot
.63 .40233 Mdot
.63 .40262 Mdot
.63 .40326 Mdot
.63 .40501 Mdot
.63 .40538 Mdot
.63 .40568 Mdot
.63 .4061 Mdot
.63 .40612 Mdot
.63 .40628 Mdot
.63 .4064 Mdot
.63 .40738 Mdot
.63 .4075 Mdot
.63 .40806 Mdot
.63 .40883 Mdot
.63 .40931 Mdot
.63 .40938 Mdot
.63 .40939 Mdot
.63 .40987 Mdot
.63 .41 Mdot
.63 .41014 Mdot
.63 .41054 Mdot
.63 .41206 Mdot
.63 .41213 Mdot
.63 .41219 Mdot
.63 .41259 Mdot
.63 .41269 Mdot
.63 .41292 Mdot
.63 .41315 Mdot
.63 .41418 Mdot
.63 .41466 Mdot
.63 .4147 Mdot
.63 .41484 Mdot
.63 .41538 Mdot
.63 .41538 Mdot
.63 .41558 Mdot
.63 .41658 Mdot
.63 .41704 Mdot
.63 .41718 Mdot
.63 .41914 Mdot
.63 .41965 Mdot
.63 .41993 Mdot
.63 .42066 Mdot
.63 .42076 Mdot
.63 .42085 Mdot
.63 .42093 Mdot
.63 .42151 Mdot
.63 .42152 Mdot
.63 .42157 Mdot
.63 .42196 Mdot
.63 .42279 Mdot
.63 .42374 Mdot
.63 .42478 Mdot
.63 .42632 Mdot
.63 .42655 Mdot
.63 .42663 Mdot
.63 .42681 Mdot
.63 .4271 Mdot
.63 .42763 Mdot
.63 .42765 Mdot
.63 .42765 Mdot
.63 .42766 Mdot
.63 .42772 Mdot
.63 .42774 Mdot
.63 .42776 Mdot
.63 .42786 Mdot
.63 .42788 Mdot
.63 .42804 Mdot
.63 .42804 Mdot
.63 .42807 Mdot
.63 .42824 Mdot
.63 .42846 Mdot
.63 .42853 Mdot
.63 .42856 Mdot
.63 .42858 Mdot
.63 .42861 Mdot
.63 .42867 Mdot
.63 .42871 Mdot
.63 .42879 Mdot
.63 .42887 Mdot
.63 .42897 Mdot
.63 .42906 Mdot
.63 .42924 Mdot
.63 .42936 Mdot
.63 .42948 Mdot
.63 .43003 Mdot
.63 .4302 Mdot
.63 .43031 Mdot
.63 .4304 Mdot
.63 .43061 Mdot
.63 .43119 Mdot
.63 .43131 Mdot
.63 .43141 Mdot
.63 .43155 Mdot
.63 .43161 Mdot
.63 .43165 Mdot
.63 .43197 Mdot
.63 .43201 Mdot
.63 .43245 Mdot
.63 .43261 Mdot
.63 .43263 Mdot
.63 .43263 Mdot
.63 .43279 Mdot
.63 .43288 Mdot
.63 .43354 Mdot
.63 .43356 Mdot
.63 .43373 Mdot
.63 .4338 Mdot
.63 .43388 Mdot
.63 .43438 Mdot
.63 .43439 Mdot
.63 .43444 Mdot
.63 .43462 Mdot
.63 .43462 Mdot
.63 .43604 Mdot
.63 .43613 Mdot
.63 .43637 Mdot
.63 .43646 Mdot
.63 .43666 Mdot
.63 .43681 Mdot
.63 .43708 Mdot
.63 .43775 Mdot
.63 .43834 Mdot
.63 .43837 Mdot
.63 .43843 Mdot
.63 .43902 Mdot
.63 .43903 Mdot
.63 .43905 Mdot
.63 .43933 Mdot
.63 .43957 Mdot
.63 .43961 Mdot
.63 .43994 Mdot
.63 .44018 Mdot
.63 .44048 Mdot
.63 .44079 Mdot
.63 .44155 Mdot
.63 .44158 Mdot
.63 .44166 Mdot
.63 .44176 Mdot
.63 .44181 Mdot
.63 .4419 Mdot
.63 .44234 Mdot
.63 .44256 Mdot
.63 .44257 Mdot
.63 .44276 Mdot
.63 .44288 Mdot
.63 .44306 Mdot
.63 .44344 Mdot
.63 .44498 Mdot
.63 .44562 Mdot
.63 .44596 Mdot
.63 .44606 Mdot
.63 .4467 Mdot
.63 .447 Mdot
.63 .4472 Mdot
.63 .44736 Mdot
.63 .44753 Mdot
.63 .44754 Mdot
.63 .44791 Mdot
.63 .44792 Mdot
.63 .44864 Mdot
.63 .4488 Mdot
.63 .44888 Mdot
.63 .44899 Mdot
.63 .44905 Mdot
.63 .44918 Mdot
.63 .44924 Mdot
.63 .45004 Mdot
.63 .4505 Mdot
.63 .45064 Mdot
.63 .45101 Mdot
.63 .4515 Mdot
.63 .45189 Mdot
.63 .45245 Mdot
.63 .45251 Mdot
.63 .4529 Mdot
.63 .45335 Mdot
.63 .45338 Mdot
.63 .45341 Mdot
.63 .45368 Mdot
.63 .45387 Mdot
.63 .45421 Mdot
.63 .45437 Mdot
.63 .45447 Mdot
.63 .45451 Mdot
.63 .45464 Mdot
.63 .45547 Mdot
.63 .45604 Mdot
.63 .45655 Mdot
.63 .457 Mdot
.63 .45721 Mdot
.63 .45723 Mdot
.63 .45724 Mdot
.63 .45755 Mdot
.63 .45759 Mdot
.63 .45764 Mdot
.63 .4577 Mdot
.63 .45808 Mdot
.63 .45823 Mdot
.63 .4585 Mdot
.63 .45954 Mdot
.63 .45962 Mdot
.63 .45986 Mdot
.63 .46039 Mdot
.63 .46049 Mdot
.63 .46049 Mdot
.63 .46077 Mdot
.63 .46085 Mdot
.63 .46087 Mdot
.63 .46112 Mdot
.63 .46165 Mdot
.63 .46178 Mdot
.63 .46189 Mdot
.63 .46195 Mdot
.63 .46215 Mdot
.63 .46218 Mdot
.63 .46222 Mdot
.63 .46301 Mdot
.63 .46321 Mdot
.63 .46328 Mdot
.63 .46335 Mdot
.63 .4636 Mdot
.63 .4636 Mdot
.63 .46364 Mdot
.63 .46388 Mdot
.63 .46428 Mdot
.63 .46457 Mdot
.63 .46463 Mdot
.63 .46513 Mdot
.63 .46519 Mdot
.63 .46527 Mdot
.63 .46528 Mdot
.63 .46549 Mdot
.63 .46565 Mdot
.63 .46584 Mdot
.63 .46672 Mdot
.63 .46704 Mdot
.63 .46719 Mdot
.63 .46735 Mdot
.63 .46761 Mdot
.63 .46844 Mdot
.63 .46863 Mdot
.63 .4688 Mdot
.63 .46908 Mdot
.63 .46922 Mdot
.63 .46924 Mdot
.63 .46937 Mdot
.63 .46949 Mdot
.63 .46961 Mdot
.63 .46967 Mdot
.63 .46976 Mdot
.63 .4698 Mdot
.63 .46984 Mdot
.63 .46988 Mdot
.63 .46998 Mdot
.63 .47031 Mdot
.63 .47057 Mdot
.63 .47061 Mdot
.63 .47062 Mdot
.63 .47085 Mdot
.63 .47088 Mdot
.63 .47104 Mdot
.63 .47107 Mdot
.63 .4711 Mdot
.63 .47119 Mdot
.63 .47119 Mdot
.63 .4712 Mdot
.63 .47123 Mdot
.63 .47202 Mdot
.63 .47242 Mdot
.63 .47244 Mdot
.63 .47272 Mdot
.63 .47283 Mdot
.63 .47318 Mdot
.63 .47329 Mdot
.63 .4737 Mdot
.63 .47416 Mdot
.63 .47451 Mdot
.63 .47515 Mdot
.63 .47543 Mdot
.63 .476 Mdot
.63 .47611 Mdot
.63 .47694 Mdot
.63 .47712 Mdot
.63 .47734 Mdot
.63 .47779 Mdot
.63 .4783 Mdot
.63 .47907 Mdot
.63 .47916 Mdot
.63 .47925 Mdot
.63 .47949 Mdot
.63 .48004 Mdot
.63 .48011 Mdot
.63 .48013 Mdot
.63 .4804 Mdot
.63 .48081 Mdot
.63 .48095 Mdot
.63 .48106 Mdot
.63 .48119 Mdot
.63 .48133 Mdot
.63 .48146 Mdot
.63 .48219 Mdot
.63 .48234 Mdot
.63 .48254 Mdot
.63 .48275 Mdot
.63 .48345 Mdot
.63 .48614 Mdot
.63 .48634 Mdot
.63 .48651 Mdot
.63 .48695 Mdot
.63 .487 Mdot
.63 .48701 Mdot
.63 .48775 Mdot
.63 .48831 Mdot
.63 .48857 Mdot
.63 .48857 Mdot
.63 .48929 Mdot
.63 .48948 Mdot
.63 .48953 Mdot
.63 .49016 Mdot
.63 .49031 Mdot
.63 .49041 Mdot
.63 .491 Mdot
.63 .49118 Mdot
.63 .49125 Mdot
.63 .49152 Mdot
.63 .49183 Mdot
.63 .49212 Mdot
.63 .49221 Mdot
.63 .49226 Mdot
.63 .49246 Mdot
.63 .49248 Mdot
.63 .49265 Mdot
.63 .49278 Mdot
.63 .49285 Mdot
.63 .49294 Mdot
.63 .49469 Mdot
.63 .4949 Mdot
.63 .49518 Mdot
.63 .49541 Mdot
.63 .49559 Mdot
.63 .49575 Mdot
.63 .49587 Mdot
.63 .49592 Mdot
.63 .49594 Mdot
.63 .49637 Mdot
.63 .49638 Mdot
.63 .49647 Mdot
.63 .49674 Mdot
.63 .49706 Mdot
.63 .49729 Mdot
.63 .49804 Mdot
.63 .49873 Mdot
.63 .49888 Mdot
.63 .50008 Mdot
.63 .50014 Mdot
.63 .50023 Mdot
.63 .50043 Mdot
.63 .50046 Mdot
.63 .50054 Mdot
.63 .50096 Mdot
.63 .50133 Mdot
.63 .50178 Mdot
.63 .50387 Mdot
.63 .50388 Mdot
.63 .50396 Mdot
.63 .5042 Mdot
.63 .50463 Mdot
.63 .50497 Mdot
.63 .50535 Mdot
.63 .50595 Mdot
.63 .50644 Mdot
.63 .50663 Mdot
.63 .50729 Mdot
.63 .50787 Mdot
.63 .50827 Mdot
.63 .50828 Mdot
.63 .50831 Mdot
.63 .5087 Mdot
.63 .50933 Mdot
.63 .50965 Mdot
.63 .50969 Mdot
.63 .50998 Mdot
.63 .51027 Mdot
.63 .51054 Mdot
.63 .51067 Mdot
.63 .51087 Mdot
.63 .51095 Mdot
.63 .51104 Mdot
.63 .51113 Mdot
.63 .51137 Mdot
.63 .5121 Mdot
.63 .51268 Mdot
.63 .51275 Mdot
.63 .51278 Mdot
.63 .5128 Mdot
.63 .51328 Mdot
.63 .51336 Mdot
.63 .5137 Mdot
.63 .51377 Mdot
.63 .51383 Mdot
.63 .51404 Mdot
.63 .51404 Mdot
.63 .51406 Mdot
.63 .51413 Mdot
.63 .51548 Mdot
.63 .51583 Mdot
.63 .51619 Mdot
.63 .51644 Mdot
.63 .51669 Mdot
.63 .51675 Mdot
.63 .51733 Mdot
.63 .5175 Mdot
.63 .51758 Mdot
.63 .51831 Mdot
.63 .51856 Mdot
.63 .5194 Mdot
.63 .51947 Mdot
.63 .5201 Mdot
.63 .52036 Mdot
.63 .52109 Mdot
.63 .52129 Mdot
.63 .52239 Mdot
.63 .52295 Mdot
.63 .5231 Mdot
.63 .52409 Mdot
.63 .52432 Mdot
.63 .52449 Mdot
.63 .52541 Mdot
.63 .52595 Mdot
.63 .52596 Mdot
.63 .52609 Mdot
.63 .52629 Mdot
.63 .5263 Mdot
.63 .52633 Mdot
.63 .52665 Mdot
.63 .52673 Mdot
.63 .52684 Mdot
.63 .52698 Mdot
.63 .52759 Mdot
.63 .52857 Mdot
.63 .52883 Mdot
.63 .52957 Mdot
.63 .53001 Mdot
.63 .53013 Mdot
.63 .53017 Mdot
.63 .53034 Mdot
.63 .53067 Mdot
.63 .53078 Mdot
.63 .53129 Mdot
.63 .53178 Mdot
.63 .5318 Mdot
.63 .53185 Mdot
.63 .5319 Mdot
.63 .53194 Mdot
.63 .53229 Mdot
.63 .53242 Mdot
.63 .53284 Mdot
.63 .53316 Mdot
.63 .5334 Mdot
.63 .53358 Mdot
.63 .5336 Mdot
.63 .53382 Mdot
.63 .53407 Mdot
.63 .5343 Mdot
.63 .53452 Mdot
.63 .53482 Mdot
.63 .53555 Mdot
.63 .5356 Mdot
.63 .53567 Mdot
.63 .5358 Mdot
.63 .53581 Mdot
.63 .53589 Mdot
.63 .53594 Mdot
.63 .53615 Mdot
.63 .53649 Mdot
.63 .537 Mdot
.63 .53765 Mdot
.63 .53806 Mdot
.63 .53828 Mdot
.63 .53895 Mdot
.63 .5393 Mdot
.63 .53938 Mdot
.63 .53962 Mdot
.63 .54048 Mdot
.63 .54187 Mdot
.63 .54187 Mdot
.63 .54216 Mdot
.63 .54236 Mdot
.63 .54241 Mdot
.63 .54306 Mdot
.63 .54313 Mdot
.63 .54316 Mdot
.63 .5441 Mdot
.63 .54421 Mdot
.63 .54498 Mdot
.63 .54513 Mdot
.63 .54534 Mdot
.63 .54535 Mdot
.63 .54536 Mdot
.63 .54554 Mdot
.63 .54567 Mdot
.63 .5462 Mdot
.63 .54625 Mdot
.63 .54625 Mdot
.63 .54632 Mdot
.63 .54656 Mdot
.63 .54658 Mdot
.63 .54662 Mdot
.63 .54678 Mdot
.63 .5468 Mdot
.63 .54744 Mdot
.63 .54762 Mdot
.63 .54763 Mdot
.63 .54775 Mdot
.63 .5487 Mdot
.63 .54879 Mdot
.63 .54896 Mdot
.63 .54911 Mdot
.63 .54921 Mdot
.63 .54948 Mdot
.63 .54952 Mdot
.63 .54981 Mdot
.63 .54992 Mdot
.63 .54997 Mdot
.63 .5502 Mdot
.63 .55022 Mdot
.63 .55042 Mdot
.63 .55056 Mdot
.63 .55064 Mdot
.63 .55074 Mdot
.63 .55083 Mdot
.63 .55103 Mdot
.63 .55172 Mdot
.63 .55257 Mdot
.63 .55278 Mdot
.63 .55299 Mdot
.63 .55305 Mdot
.63 .55321 Mdot
.63 .55327 Mdot
.63 .55344 Mdot
.63 .55359 Mdot
.63 .5537 Mdot
.63 .55375 Mdot
.63 .55376 Mdot
.63 .55397 Mdot
.63 .55415 Mdot
.63 .55416 Mdot
.63 .55423 Mdot
.63 .55424 Mdot
.63 .55447 Mdot
.63 .55475 Mdot
.63 .55484 Mdot
.63 .5549 Mdot
.63 .55494 Mdot
.63 .55554 Mdot
.63 .55565 Mdot
.63 .55586 Mdot
.63 .55606 Mdot
.63 .55617 Mdot
.63 .55644 Mdot
.63 .5565 Mdot
.63 .55662 Mdot
.63 .55698 Mdot
.63 .55702 Mdot
.63 .55704 Mdot
.63 .55707 Mdot
.63 .55708 Mdot
.63 .5572 Mdot
.63 .55722 Mdot
.63 .55724 Mdot
.63 .55726 Mdot
.63 .5574 Mdot
.63 .55752 Mdot
.63 .55763 Mdot
.63 .55772 Mdot
.63 .55784 Mdot
.63 .55796 Mdot
.63 .55853 Mdot
.63 .55856 Mdot
.63 .55857 Mdot
.63 .55857 Mdot
.63 .55866 Mdot
.63 .55869 Mdot
.63 .55872 Mdot
.63 .55885 Mdot
.63 .55888 Mdot
.63 .55888 Mdot
.63 .55889 Mdot
.63 .55891 Mdot
.63 .559 Mdot
.63 .55906 Mdot
.63 .55906 Mdot
.63 .55907 Mdot
.63 .5591 Mdot
.63 .55914 Mdot
.63 .55924 Mdot
.63 .55928 Mdot
.63 .55934 Mdot
.63 .55946 Mdot
.63 .55948 Mdot
.63 .55951 Mdot
.63 .55953 Mdot
.63 .55955 Mdot
.63 .55956 Mdot
.63 .55957 Mdot
.63 .5596 Mdot
.63 .5596 Mdot
.63 .55962 Mdot
.63 .55966 Mdot
.63 .55969 Mdot
.63 .55969 Mdot
.63 .55972 Mdot
.63 .55972 Mdot
.63 .55974 Mdot
.63 .55974 Mdot
.63 .55976 Mdot
.63 .55976 Mdot
.63 .55976 Mdot
.63 .55976 Mdot
.632 .16343 Mdot
.632 .16344 Mdot
.632 .16347 Mdot
.632 .16348 Mdot
.632 .16349 Mdot
.632 .16349 Mdot
.632 .16352 Mdot
.632 .16352 Mdot
.632 .16367 Mdot
.632 .1637 Mdot
.632 .16379 Mdot
.632 .16388 Mdot
.632 .16395 Mdot
.632 .16399 Mdot
.632 .16413 Mdot
.632 .16427 Mdot
.632 .16441 Mdot
.632 .16444 Mdot
.632 .16465 Mdot
.632 .16484 Mdot
.632 .16499 Mdot
.632 .16508 Mdot
.632 .16521 Mdot
.632 .16531 Mdot
.632 .16547 Mdot
.632 .16559 Mdot
.632 .16579 Mdot
.632 .1659 Mdot
.632 .16612 Mdot
.632 .16672 Mdot
.632 .16677 Mdot
.632 .16697 Mdot
.632 .16707 Mdot
.632 .16713 Mdot
.632 .1673 Mdot
.632 .1675 Mdot
.632 .16775 Mdot
.632 .16805 Mdot
.632 .16818 Mdot
.632 .16833 Mdot
.632 .16853 Mdot
.632 .16879 Mdot
.632 .1689 Mdot
.632 .16901 Mdot
.632 .16924 Mdot
.632 .16993 Mdot
.632 .16995 Mdot
.632 .17007 Mdot
.632 .17023 Mdot
.632 .17092 Mdot
.632 .17132 Mdot
.632 .17164 Mdot
.632 .17208 Mdot
.632 .17216 Mdot
.632 .17279 Mdot
.632 .17282 Mdot
.632 .17358 Mdot
.632 .17361 Mdot
.632 .17382 Mdot
.632 .17388 Mdot
.632 .17401 Mdot
.632 .17402 Mdot
.632 .17413 Mdot
.632 .17431 Mdot
.632 .17439 Mdot
.632 .17471 Mdot
.632 .17481 Mdot
.632 .17501 Mdot
.632 .17568 Mdot
.632 .17579 Mdot
.632 .17642 Mdot
.632 .17651 Mdot
.632 .17671 Mdot
.632 .17723 Mdot
.632 .17749 Mdot
.632 .17816 Mdot
.632 .17819 Mdot
.632 .17852 Mdot
.632 .17866 Mdot
.632 .17875 Mdot
.632 .17876 Mdot
.632 .17964 Mdot
.632 .17971 Mdot
.632 .17986 Mdot
.632 .18081 Mdot
.632 .18294 Mdot
.632 .18296 Mdot
.632 .18322 Mdot
.632 .18353 Mdot
.632 .18454 Mdot
.632 .18557 Mdot
.632 .18564 Mdot
.632 .18575 Mdot
.632 .18619 Mdot
.632 .18619 Mdot
.632 .18629 Mdot
.632 .18677 Mdot
.632 .18706 Mdot
.632 .18825 Mdot
.632 .1897 Mdot
.632 .18982 Mdot
.632 .19056 Mdot
.632 .19079 Mdot
.632 .19111 Mdot
.632 .19159 Mdot
.632 .19255 Mdot
.632 .19312 Mdot
.632 .19319 Mdot
.632 .1939 Mdot
.632 .19549 Mdot
.632 .19866 Mdot
.632 .20025 Mdot
.632 .20161 Mdot
.632 .20219 Mdot
.632 .2043 Mdot
.632 .20531 Mdot
.632 .20626 Mdot
.632 .2089 Mdot
.632 .20922 Mdot
.632 .20967 Mdot
.632 .20994 Mdot
.632 .21065 Mdot
.632 .21295 Mdot
.632 .21378 Mdot
.632 .21401 Mdot
.632 .21471 Mdot
.632 .21545 Mdot
.632 .21625 Mdot
.632 .21933 Mdot
.632 .22041 Mdot
.632 .22102 Mdot
.632 .22121 Mdot
.632 .22242 Mdot
.632 .22259 Mdot
.632 .22519 Mdot
.632 .22568 Mdot
.632 .22769 Mdot
.632 .23113 Mdot
.632 .23249 Mdot
.632 .23511 Mdot
.632 .2392 Mdot
.632 .23936 Mdot
.632 .24017 Mdot
.632 .24306 Mdot
.632 .24527 Mdot
.632 .2519 Mdot
.632 .25213 Mdot
.632 .2534 Mdot
.632 .25348 Mdot
.632 .25407 Mdot
.632 .25447 Mdot
.632 .25699 Mdot
.632 .26049 Mdot
.632 .2625 Mdot
.632 .26466 Mdot
.632 .26547 Mdot
.632 .27105 Mdot
.632 .27138 Mdot
.632 .2716 Mdot
.632 .27341 Mdot
.632 .27494 Mdot
.632 .27528 Mdot
.632 .27542 Mdot
.632 .27622 Mdot
.632 .27929 Mdot
.632 .28013 Mdot
.632 .28112 Mdot
.632 .28167 Mdot
.632 .28307 Mdot
.632 .28399 Mdot
.632 .28411 Mdot
.632 .2848 Mdot
.632 .28501 Mdot
.632 .28512 Mdot
.632 .28554 Mdot
.632 .28574 Mdot
.632 .28587 Mdot
.632 .28588 Mdot
.632 .28609 Mdot
.632 .28632 Mdot
.632 .28636 Mdot
.632 .28801 Mdot
.632 .28864 Mdot
.632 .28905 Mdot
.632 .28957 Mdot
.632 .29049 Mdot
.632 .29071 Mdot
.632 .29091 Mdot
.632 .2919 Mdot
.632 .29258 Mdot
.632 .29298 Mdot
.632 .2933 Mdot
.632 .29354 Mdot
.632 .29566 Mdot
.632 .29785 Mdot
.632 .29812 Mdot
.632 .29859 Mdot
.632 .29888 Mdot
.632 .29991 Mdot
.632 .30016 Mdot
.632 .30058 Mdot
.632 .30198 Mdot
.632 .30253 Mdot
.632 .30389 Mdot
.632 .30425 Mdot
.632 .3069 Mdot
.632 .30693 Mdot
.632 .30731 Mdot
.632 .30733 Mdot
.632 .30768 Mdot
.632 .30918 Mdot
.632 .30964 Mdot
.632 .31058 Mdot
.632 .31248 Mdot
.632 .31267 Mdot
.632 .31327 Mdot
.632 .31431 Mdot
.632 .31493 Mdot
.632 .31615 Mdot
.632 .31686 Mdot
.632 .31848 Mdot
.632 .31875 Mdot
.632 .32064 Mdot
.632 .32189 Mdot
.632 .32198 Mdot
.632 .32257 Mdot
.632 .32266 Mdot
.632 .32297 Mdot
.632 .32334 Mdot
.632 .32378 Mdot
.632 .32427 Mdot
.632 .32563 Mdot
.632 .32579 Mdot
.632 .32716 Mdot
.632 .32992 Mdot
.632 .33077 Mdot
.632 .33081 Mdot
.632 .33201 Mdot
.632 .33257 Mdot
.632 .33468 Mdot
.632 .33476 Mdot
.632 .33547 Mdot
.632 .33572 Mdot
.632 .33638 Mdot
.632 .33682 Mdot
.632 .3369 Mdot
.632 .33771 Mdot
.632 .33777 Mdot
.632 .34053 Mdot
.632 .34054 Mdot
.632 .34076 Mdot
.632 .34101 Mdot
.632 .34267 Mdot
.632 .34309 Mdot
.632 .34316 Mdot
.632 .34352 Mdot
.632 .34375 Mdot
.632 .34567 Mdot
.632 .34575 Mdot
.632 .34627 Mdot
.632 .34764 Mdot
.632 .34802 Mdot
.632 .34807 Mdot
.632 .34854 Mdot
.632 .34958 Mdot
.632 .35159 Mdot
.632 .35372 Mdot
.632 .35495 Mdot
.632 .35608 Mdot
.632 .35772 Mdot
.632 .35797 Mdot
.632 .35811 Mdot
.632 .3585 Mdot
.632 .35973 Mdot
.632 .36017 Mdot
.632 .36029 Mdot
.632 .36065 Mdot
.632 .36146 Mdot
.632 .36302 Mdot
.632 .36386 Mdot
.632 .36631 Mdot
.632 .36709 Mdot
.632 .3687 Mdot
.632 .36933 Mdot
.632 .37052 Mdot
.632 .37234 Mdot
.632 .37242 Mdot
.632 .37403 Mdot
.632 .37777 Mdot
.632 .37839 Mdot
.632 .37842 Mdot
.632 .37986 Mdot
.632 .38127 Mdot
.632 .38207 Mdot
.632 .38325 Mdot
.632 .38541 Mdot
.632 .38563 Mdot
.632 .38632 Mdot
.632 .38703 Mdot
.632 .38709 Mdot
.632 .38739 Mdot
.632 .38855 Mdot
.632 .38886 Mdot
.632 .38923 Mdot
.632 .38944 Mdot
.632 .38996 Mdot
.632 .3903 Mdot
.632 .3906 Mdot
.632 .39068 Mdot
.632 .39072 Mdot
.632 .39088 Mdot
.632 .39095 Mdot
.632 .391 Mdot
.632 .391 Mdot
.632 .39108 Mdot
.632 .39116 Mdot
.632 .39118 Mdot
.632 .39179 Mdot
.632 .39202 Mdot
.632 .39216 Mdot
.632 .39269 Mdot
.632 .39277 Mdot
.632 .3932 Mdot
.632 .39345 Mdot
.632 .3936 Mdot
.632 .39371 Mdot
.632 .3938 Mdot
.632 .39456 Mdot
.632 .39535 Mdot
.632 .39572 Mdot
.632 .39608 Mdot
.632 .39617 Mdot
.632 .39632 Mdot
.632 .3975 Mdot
.632 .39856 Mdot
.632 .39857 Mdot
.632 .3987 Mdot
.632 .39883 Mdot
.632 .39936 Mdot
.632 .39952 Mdot
.632 .39985 Mdot
.632 .40051 Mdot
.632 .40057 Mdot
.632 .40078 Mdot
.632 .40114 Mdot
.632 .40136 Mdot
.632 .40203 Mdot
.632 .40268 Mdot
.632 .40375 Mdot
.632 .40379 Mdot
.632 .40399 Mdot
.632 .40412 Mdot
.632 .4044 Mdot
.632 .40457 Mdot
.632 .40503 Mdot
.632 .40555 Mdot
.632 .40649 Mdot
.632 .40678 Mdot
.632 .40679 Mdot
.632 .40719 Mdot
.632 .40812 Mdot
.632 .40844 Mdot
.632 .40866 Mdot
.632 .40884 Mdot
.632 .40911 Mdot
.632 .41006 Mdot
.632 .41006 Mdot
.632 .41013 Mdot
.632 .41021 Mdot
.632 .41077 Mdot
.632 .41091 Mdot
.632 .41093 Mdot
.632 .41106 Mdot
.632 .41113 Mdot
.632 .4118 Mdot
.632 .41197 Mdot
.632 .41242 Mdot
.632 .41255 Mdot
.632 .41257 Mdot
.632 .41307 Mdot
.632 .41444 Mdot
.632 .41485 Mdot
.632 .41522 Mdot
.632 .41576 Mdot
.632 .41589 Mdot
.632 .41602 Mdot
.632 .41657 Mdot
.632 .41661 Mdot
.632 .41673 Mdot
.632 .41699 Mdot
.632 .4175 Mdot
.632 .41858 Mdot
.632 .41884 Mdot
.632 .41957 Mdot
.632 .41996 Mdot
.632 .42056 Mdot
.632 .42059 Mdot
.632 .42111 Mdot
.632 .42234 Mdot
.632 .42255 Mdot
.632 .42302 Mdot
.632 .42348 Mdot
.632 .42375 Mdot
.632 .42514 Mdot
.632 .42537 Mdot
.632 .42539 Mdot
.632 .42586 Mdot
.632 .42597 Mdot
.632 .42609 Mdot
.632 .42616 Mdot
.632 .42633 Mdot
.632 .42654 Mdot
.632 .42656 Mdot
.632 .42658 Mdot
.632 .42663 Mdot
.632 .42665 Mdot
.632 .42667 Mdot
.632 .42667 Mdot
.632 .42669 Mdot
.632 .42672 Mdot
.632 .42672 Mdot
.632 .427 Mdot
.632 .42705 Mdot
.632 .42722 Mdot
.632 .42739 Mdot
.632 .42752 Mdot
.632 .42755 Mdot
.632 .42758 Mdot
.632 .42783 Mdot
.632 .42809 Mdot
.632 .42836 Mdot
.632 .42841 Mdot
.632 .42879 Mdot
.632 .42914 Mdot
.632 .42915 Mdot
.632 .42919 Mdot
.632 .42923 Mdot
.632 .4294 Mdot
.632 .42946 Mdot
.632 .42956 Mdot
.632 .4298 Mdot
.632 .42987 Mdot
.632 .42999 Mdot
.632 .43006 Mdot
.632 .43028 Mdot
.632 .43049 Mdot
.632 .43085 Mdot
.632 .43086 Mdot
.632 .43092 Mdot
.632 .43106 Mdot
.632 .43112 Mdot
.632 .43144 Mdot
.632 .43198 Mdot
.632 .43252 Mdot
.632 .43261 Mdot
.632 .43292 Mdot
.632 .43292 Mdot
.632 .43295 Mdot
.632 .43297 Mdot
.632 .43316 Mdot
.632 .4332 Mdot
.632 .43321 Mdot
.632 .43325 Mdot
.632 .43328 Mdot
.632 .43355 Mdot
.632 .4337 Mdot
.632 .43375 Mdot
.632 .43375 Mdot
.632 .43392 Mdot
.632 .43437 Mdot
.632 .43463 Mdot
.632 .43485 Mdot
.632 .43489 Mdot
.632 .43513 Mdot
.632 .43522 Mdot
.632 .43539 Mdot
.632 .43574 Mdot
.632 .43583 Mdot
.632 .43607 Mdot
.632 .4362 Mdot
.632 .4364 Mdot
.632 .43641 Mdot
.632 .43659 Mdot
.632 .43699 Mdot
.632 .43706 Mdot
.632 .43738 Mdot
.632 .43746 Mdot
.632 .43793 Mdot
.632 .43801 Mdot
.632 .43801 Mdot
.632 .43821 Mdot
.632 .43825 Mdot
.632 .43827 Mdot
.632 .43845 Mdot
.632 .43874 Mdot
.632 .4393 Mdot
.632 .43958 Mdot
.632 .43993 Mdot
.632 .44022 Mdot
.632 .44054 Mdot
.632 .44055 Mdot
.632 .44064 Mdot
.632 .44064 Mdot
.632 .44066 Mdot
.632 .44082 Mdot
.632 .44082 Mdot
.632 .44112 Mdot
.632 .44119 Mdot
.632 .44172 Mdot
.632 .44195 Mdot
.632 .44205 Mdot
.632 .44208 Mdot
.632 .44226 Mdot
.632 .44227 Mdot
.632 .44271 Mdot
.632 .4428 Mdot
.632 .44313 Mdot
.632 .44313 Mdot
.632 .44316 Mdot
.632 .44317 Mdot
.632 .44322 Mdot
.632 .44353 Mdot
.632 .44372 Mdot
.632 .44387 Mdot
.632 .44401 Mdot
.632 .44427 Mdot
.632 .44432 Mdot
.632 .44441 Mdot
.632 .44452 Mdot
.632 .44457 Mdot
.632 .4446 Mdot
.632 .44475 Mdot
.632 .44483 Mdot
.632 .44492 Mdot
.632 .44503 Mdot
.632 .44525 Mdot
.632 .44526 Mdot
.632 .44526 Mdot
.632 .44546 Mdot
.632 .44551 Mdot
.632 .44577 Mdot
.632 .44577 Mdot
.632 .44589 Mdot
.632 .44608 Mdot
.632 .44643 Mdot
.632 .4466 Mdot
.632 .4466 Mdot
.632 .4467 Mdot
.632 .44671 Mdot
.632 .44676 Mdot
.632 .44676 Mdot
.632 .44695 Mdot
.632 .44732 Mdot
.632 .44748 Mdot
.632 .44807 Mdot
.632 .44822 Mdot
.632 .44822 Mdot
.632 .44826 Mdot
.632 .44853 Mdot
.632 .44858 Mdot
.632 .44876 Mdot
.632 .44913 Mdot
.632 .44932 Mdot
.632 .44946 Mdot
.632 .4498 Mdot
.632 .45001 Mdot
.632 .45013 Mdot
.632 .45063 Mdot
.632 .45063 Mdot
.632 .45065 Mdot
.632 .45089 Mdot
.632 .45093 Mdot
.632 .45093 Mdot
.632 .45108 Mdot
.632 .45109 Mdot
.632 .45109 Mdot
.632 .45162 Mdot
.632 .4521 Mdot
.632 .4522 Mdot
.632 .45224 Mdot
.632 .45268 Mdot
.632 .45279 Mdot
.632 .45301 Mdot
.632 .45314 Mdot
.632 .45316 Mdot
.632 .45319 Mdot
.632 .45406 Mdot
.632 .45453 Mdot
.632 .45462 Mdot
.632 .45473 Mdot
.632 .45482 Mdot
.632 .45486 Mdot
.632 .45493 Mdot
.632 .45498 Mdot
.632 .45524 Mdot
.632 .45525 Mdot
.632 .45538 Mdot
.632 .45613 Mdot
.632 .45627 Mdot
.632 .45652 Mdot
.632 .45677 Mdot
.632 .45689 Mdot
.632 .45754 Mdot
.632 .45783 Mdot
.632 .45784 Mdot
.632 .45816 Mdot
.632 .45837 Mdot
.632 .45876 Mdot
.632 .45889 Mdot
.632 .45946 Mdot
.632 .45973 Mdot
.632 .45987 Mdot
.632 .45994 Mdot
.632 .45996 Mdot
.632 .46025 Mdot
.632 .46031 Mdot
.632 .46038 Mdot
.632 .46066 Mdot
.632 .46086 Mdot
.632 .46107 Mdot
.632 .46179 Mdot
.632 .46205 Mdot
.632 .46205 Mdot
.632 .46212 Mdot
.632 .46236 Mdot
.632 .46245 Mdot
.632 .46279 Mdot
.632 .46283 Mdot
.632 .46289 Mdot
.632 .4629 Mdot
.632 .46298 Mdot
.632 .46326 Mdot
.632 .4633 Mdot
.632 .46334 Mdot
.632 .46334 Mdot
.632 .46383 Mdot
.632 .46397 Mdot
.632 .46406 Mdot
.632 .46417 Mdot
.632 .46434 Mdot
.632 .46481 Mdot
.632 .46502 Mdot
.632 .46502 Mdot
.632 .46517 Mdot
.632 .46565 Mdot
.632 .46591 Mdot
.632 .46614 Mdot
.632 .46623 Mdot
.632 .46637 Mdot
.632 .46644 Mdot
.632 .46654 Mdot
.632 .46655 Mdot
.632 .4671 Mdot
.632 .46742 Mdot
.632 .46776 Mdot
.632 .46786 Mdot
.632 .46805 Mdot
.632 .46815 Mdot
.632 .46818 Mdot
.632 .46851 Mdot
.632 .46868 Mdot
.632 .46875 Mdot
.632 .46902 Mdot
.632 .46908 Mdot
.632 .46915 Mdot
.632 .46915 Mdot
.632 .46968 Mdot
.632 .47026 Mdot
.632 .47033 Mdot
.632 .47037 Mdot
.632 .47056 Mdot
.632 .47074 Mdot
.632 .47112 Mdot
.632 .4715 Mdot
.632 .47154 Mdot
.632 .47159 Mdot
.632 .47167 Mdot
.632 .47179 Mdot
.632 .472 Mdot
.632 .47204 Mdot
.632 .47229 Mdot
.632 .47236 Mdot
.632 .47248 Mdot
.632 .47277 Mdot
.632 .47278 Mdot
.632 .47282 Mdot
.632 .47286 Mdot
.632 .47286 Mdot
.632 .47288 Mdot
.632 .47292 Mdot
.632 .47299 Mdot
.632 .47301 Mdot
.632 .47305 Mdot
.632 .4732 Mdot
.632 .47336 Mdot
.632 .47361 Mdot
.632 .47371 Mdot
.632 .47389 Mdot
.632 .47404 Mdot
.632 .4746 Mdot
.632 .47474 Mdot
.632 .47477 Mdot
.632 .47511 Mdot
.632 .47544 Mdot
.632 .47554 Mdot
.632 .47657 Mdot
.632 .47713 Mdot
.632 .47751 Mdot
.632 .47817 Mdot
.632 .47885 Mdot
.632 .47886 Mdot
.632 .47915 Mdot
.632 .48089 Mdot
.632 .48163 Mdot
.632 .48166 Mdot
.632 .4825 Mdot
.632 .48305 Mdot
.632 .48333 Mdot
.632 .48406 Mdot
.632 .48442 Mdot
.632 .48552 Mdot
.632 .4859 Mdot
.632 .4866 Mdot
.632 .48696 Mdot
.632 .48712 Mdot
.632 .48718 Mdot
.632 .48737 Mdot
.632 .48792 Mdot
.632 .48809 Mdot
.632 .48815 Mdot
.632 .48826 Mdot
.632 .48899 Mdot
.632 .48949 Mdot
.632 .49003 Mdot
.632 .49096 Mdot
.632 .49184 Mdot
.632 .49229 Mdot
.632 .49249 Mdot
.632 .49251 Mdot
.632 .49268 Mdot
.632 .49327 Mdot
.632 .49349 Mdot
.632 .49353 Mdot
.632 .49435 Mdot
.632 .49445 Mdot
.632 .4946 Mdot
.632 .49464 Mdot
.632 .49481 Mdot
.632 .49552 Mdot
.632 .49563 Mdot
.632 .49572 Mdot
.632 .49573 Mdot
.632 .4969 Mdot
.632 .49692 Mdot
.632 .49726 Mdot
.632 .4973 Mdot
.632 .49748 Mdot
.632 .49776 Mdot
.632 .49787 Mdot
.632 .49816 Mdot
.632 .4982 Mdot
.632 .49908 Mdot
.632 .49932 Mdot
.632 .49982 Mdot
.632 .49983 Mdot
.632 .50018 Mdot
.632 .50133 Mdot
.632 .5019 Mdot
.632 .50196 Mdot
.632 .50252 Mdot
.632 .50272 Mdot
.632 .5029 Mdot
.632 .50305 Mdot
.632 .50318 Mdot
.632 .50322 Mdot
.632 .50346 Mdot
.632 .5035 Mdot
.632 .504 Mdot
.632 .50477 Mdot
.632 .50488 Mdot
.632 .50554 Mdot
.632 .50582 Mdot
.632 .50632 Mdot
.632 .50656 Mdot
.632 .50698 Mdot
.632 .50722 Mdot
.632 .5073 Mdot
.632 .50806 Mdot
.632 .50844 Mdot
.632 .50862 Mdot
.632 .50921 Mdot
.632 .50935 Mdot
.632 .50936 Mdot
.632 .50951 Mdot
.632 .50952 Mdot
.632 .51057 Mdot
.632 .51071 Mdot
.632 .51125 Mdot
.632 .51146 Mdot
.632 .51201 Mdot
.632 .51218 Mdot
.632 .51227 Mdot
.632 .51268 Mdot
.632 .51279 Mdot
.632 .51297 Mdot
.632 .51307 Mdot
.632 .51393 Mdot
.632 .51475 Mdot
.632 .51484 Mdot
.632 .51496 Mdot
.632 .51512 Mdot
.632 .51538 Mdot
.632 .51576 Mdot
.632 .51583 Mdot
.632 .51592 Mdot
.632 .51627 Mdot
.632 .51647 Mdot
.632 .51663 Mdot
.632 .51687 Mdot
.632 .5175 Mdot
.632 .51751 Mdot
.632 .5176 Mdot
.632 .51768 Mdot
.632 .51769 Mdot
.632 .51773 Mdot
.632 .51781 Mdot
.632 .51797 Mdot
.632 .51801 Mdot
.632 .51809 Mdot
.632 .51836 Mdot
.632 .5184 Mdot
.632 .51875 Mdot
.632 .51928 Mdot
.632 .51949 Mdot
.632 .51986 Mdot
.632 .52017 Mdot
.632 .52133 Mdot
.632 .52163 Mdot
.632 .52168 Mdot
.632 .5218 Mdot
.632 .52238 Mdot
.632 .52305 Mdot
.632 .52313 Mdot
.632 .52325 Mdot
.632 .52531 Mdot
.632 .52561 Mdot
.632 .5264 Mdot
.632 .52713 Mdot
.632 .5284 Mdot
.632 .52931 Mdot
.632 .52946 Mdot
.632 .52967 Mdot
.632 .5297 Mdot
.632 .53015 Mdot
.632 .53024 Mdot
.632 .53261 Mdot
.632 .53339 Mdot
.632 .53441 Mdot
.632 .53469 Mdot
.632 .53475 Mdot
.632 .53619 Mdot
.632 .5371 Mdot
.632 .53757 Mdot
.632 .53877 Mdot
.632 .53933 Mdot
.632 .53946 Mdot
.632 .53963 Mdot
.632 .54052 Mdot
.632 .54058 Mdot
.632 .54099 Mdot
.632 .54106 Mdot
.632 .54127 Mdot
.632 .54164 Mdot
.632 .54269 Mdot
.632 .54296 Mdot
.632 .54321 Mdot
.632 .54345 Mdot
.632 .54352 Mdot
.632 .54381 Mdot
.632 .54458 Mdot
.632 .54482 Mdot
.632 .54491 Mdot
.632 .54506 Mdot
.632 .54517 Mdot
.632 .54606 Mdot
.632 .54638 Mdot
.632 .54671 Mdot
.632 .54742 Mdot
.632 .54761 Mdot
.632 .54806 Mdot
.632 .54859 Mdot
.632 .54964 Mdot
.632 .55016 Mdot
.632 .5504 Mdot
.632 .55042 Mdot
.632 .55061 Mdot
.632 .55092 Mdot
.632 .55108 Mdot
.632 .55119 Mdot
.632 .55126 Mdot
.632 .5515 Mdot
.632 .55154 Mdot
.632 .55202 Mdot
.632 .5524 Mdot
.632 .5525 Mdot
.632 .55266 Mdot
.632 .55269 Mdot
.632 .55269 Mdot
.632 .55283 Mdot
.632 .55287 Mdot
.632 .55289 Mdot
.632 .55323 Mdot
.632 .55356 Mdot
.632 .55365 Mdot
.632 .55374 Mdot
.632 .55374 Mdot
.632 .55444 Mdot
.632 .55474 Mdot
.632 .55479 Mdot
.632 .55482 Mdot
.632 .5551 Mdot
.632 .5551 Mdot
.632 .55513 Mdot
.632 .55518 Mdot
.632 .55528 Mdot
.632 .55529 Mdot
.632 .55551 Mdot
.632 .55559 Mdot
.632 .55576 Mdot
.632 .55583 Mdot
.632 .55585 Mdot
.632 .55605 Mdot
.632 .55609 Mdot
.632 .55631 Mdot
.632 .55637 Mdot
.632 .5564 Mdot
.632 .55651 Mdot
.632 .55653 Mdot
.632 .55659 Mdot
.632 .55662 Mdot
.632 .55663 Mdot
.632 .55667 Mdot
.632 .55669 Mdot
.632 .55676 Mdot
.632 .55677 Mdot
.632 .55701 Mdot
.632 .55702 Mdot
.632 .55722 Mdot
.632 .55725 Mdot
.632 .55738 Mdot
.632 .55749 Mdot
.632 .55762 Mdot
.632 .55784 Mdot
.632 .55789 Mdot
.632 .55793 Mdot
.632 .55793 Mdot
.632 .55815 Mdot
.632 .55823 Mdot
.632 .55826 Mdot
.632 .5583 Mdot
.632 .55838 Mdot
.632 .55844 Mdot
.632 .55849 Mdot
.632 .55853 Mdot
.632 .55863 Mdot
.632 .55871 Mdot
.632 .55877 Mdot
.632 .55883 Mdot
.632 .55884 Mdot
.632 .55887 Mdot
.632 .55894 Mdot
.632 .55896 Mdot
.632 .55915 Mdot
.632 .55921 Mdot
.632 .55925 Mdot
.632 .55931 Mdot
.632 .55935 Mdot
.632 .5594 Mdot
.632 .55943 Mdot
.632 .55948 Mdot
.632 .5595 Mdot
.632 .55955 Mdot
.632 .55961 Mdot
.632 .55968 Mdot
.632 .55969 Mdot
.632 .55973 Mdot
.632 .55978 Mdot
.632 .55982 Mdot
.632 .55983 Mdot
.632 .55986 Mdot
.632 .55988 Mdot
.632 .55991 Mdot
.632 .55992 Mdot
.632 .55997 Mdot
.632 .55997 Mdot
.632 .55998 Mdot
.632 .55998 Mdot
.632 .55998 Mdot
.632 .55999 Mdot
.632 .56 Mdot
.632 .56 Mdot
.634 .16276 Mdot
.634 .16277 Mdot
.634 .16278 Mdot
.634 .16285 Mdot
.634 .16295 Mdot
.634 .16298 Mdot
.634 .16298 Mdot
.634 .16301 Mdot
.634 .1632 Mdot
.634 .16339 Mdot
.634 .1635 Mdot
.634 .16353 Mdot
.634 .16392 Mdot
.634 .16459 Mdot
.634 .16498 Mdot
.634 .16501 Mdot
.634 .16509 Mdot
.634 .16514 Mdot
.634 .16561 Mdot
.634 .16603 Mdot
.634 .16658 Mdot
.634 .16674 Mdot
.634 .16697 Mdot
.634 .16743 Mdot
.634 .1675 Mdot
.634 .16763 Mdot
.634 .16771 Mdot
.634 .16774 Mdot
.634 .16778 Mdot
.634 .16786 Mdot
.634 .1679 Mdot
.634 .16803 Mdot
.634 .16819 Mdot
.634 .16847 Mdot
.634 .16878 Mdot
.634 .16949 Mdot
.634 .16955 Mdot
.634 .16973 Mdot
.634 .16989 Mdot
.634 .17018 Mdot
.634 .17025 Mdot
.634 .17134 Mdot
.634 .17156 Mdot
.634 .17157 Mdot
.634 .17194 Mdot
.634 .17239 Mdot
.634 .17286 Mdot
.634 .17292 Mdot
.634 .17402 Mdot
.634 .17441 Mdot
.634 .17445 Mdot
.634 .17639 Mdot
.634 .17645 Mdot
.634 .17729 Mdot
.634 .17785 Mdot
.634 .17882 Mdot
.634 .17896 Mdot
.634 .17912 Mdot
.634 .17925 Mdot
.634 .17932 Mdot
.634 .17997 Mdot
.634 .18023 Mdot
.634 .18057 Mdot
.634 .18099 Mdot
.634 .18109 Mdot
.634 .18113 Mdot
.634 .1813 Mdot
.634 .18166 Mdot
.634 .18215 Mdot
.634 .18226 Mdot
.634 .1825 Mdot
.634 .18337 Mdot
.634 .18369 Mdot
.634 .18389 Mdot
.634 .18474 Mdot
.634 .18486 Mdot
.634 .18499 Mdot
.634 .18501 Mdot
.634 .18522 Mdot
.634 .1853 Mdot
.634 .1858 Mdot
.634 .18618 Mdot
.634 .18672 Mdot
.634 .18674 Mdot
.634 .18678 Mdot
.634 .18717 Mdot
.634 .18733 Mdot
.634 .18814 Mdot
.634 .18838 Mdot
.634 .18978 Mdot
.634 .19017 Mdot
.634 .19045 Mdot
.634 .1919 Mdot
.634 .19271 Mdot
.634 .19295 Mdot
.634 .19313 Mdot
.634 .1932 Mdot
.634 .1938 Mdot
.634 .19402 Mdot
.634 .19416 Mdot
.634 .19549 Mdot
.634 .1956 Mdot
.634 .19566 Mdot
.634 .19595 Mdot
.634 .19603 Mdot
.634 .1966 Mdot
.634 .19876 Mdot
.634 .1994 Mdot
.634 .19955 Mdot
.634 .19962 Mdot
.634 .20025 Mdot
.634 .20073 Mdot
.634 .20156 Mdot
.634 .20259 Mdot
.634 .2029 Mdot
.634 .20365 Mdot
.634 .20463 Mdot
.634 .2047 Mdot
.634 .20508 Mdot
.634 .2059 Mdot
.634 .20631 Mdot
.634 .2067 Mdot
.634 .20671 Mdot
.634 .20695 Mdot
.634 .20718 Mdot
.634 .2079 Mdot
.634 .20814 Mdot
.634 .20915 Mdot
.634 .21083 Mdot
.634 .21207 Mdot
.634 .21593 Mdot
.634 .21641 Mdot
.634 .21694 Mdot
.634 .21977 Mdot
.634 .21985 Mdot
.634 .22375 Mdot
.634 .22415 Mdot
.634 .22419 Mdot
.634 .22437 Mdot
.634 .22514 Mdot
.634 .22517 Mdot
.634 .22548 Mdot
.634 .22611 Mdot
.634 .22612 Mdot
.634 .22628 Mdot
.634 .22713 Mdot
.634 .22805 Mdot
.634 .22903 Mdot
.634 .22933 Mdot
.634 .2296 Mdot
.634 .23167 Mdot
.634 .23295 Mdot
.634 .233 Mdot
.634 .23301 Mdot
.634 .23322 Mdot
.634 .23359 Mdot
.634 .23459 Mdot
.634 .23621 Mdot
.634 .23627 Mdot
.634 .23653 Mdot
.634 .24025 Mdot
.634 .24093 Mdot
.634 .24157 Mdot
.634 .24225 Mdot
.634 .24295 Mdot
.634 .24382 Mdot
.634 .24412 Mdot
.634 .2447 Mdot
.634 .24499 Mdot
.634 .24663 Mdot
.634 .2475 Mdot
.634 .24822 Mdot
.634 .24822 Mdot
.634 .24825 Mdot
.634 .24883 Mdot
.634 .24978 Mdot
.634 .25051 Mdot
.634 .25094 Mdot
.634 .25142 Mdot
.634 .25142 Mdot
.634 .25225 Mdot
.634 .26002 Mdot
.634 .26058 Mdot
.634 .26124 Mdot
.634 .26137 Mdot
.634 .26228 Mdot
.634 .26354 Mdot
.634 .26511 Mdot
.634 .26548 Mdot
.634 .26601 Mdot
.634 .26794 Mdot
.634 .26805 Mdot
.634 .269 Mdot
.634 .26954 Mdot
.634 .26959 Mdot
.634 .26971 Mdot
.634 .26986 Mdot
.634 .27041 Mdot
.634 .27187 Mdot
.634 .27303 Mdot
.634 .27362 Mdot
.634 .27374 Mdot
.634 .27407 Mdot
.634 .2752 Mdot
.634 .27536 Mdot
.634 .27537 Mdot
.634 .27556 Mdot
.634 .27664 Mdot
.634 .27803 Mdot
.634 .27847 Mdot
.634 .2785 Mdot
.634 .27859 Mdot
.634 .27895 Mdot
.634 .27924 Mdot
.634 .28003 Mdot
.634 .28035 Mdot
.634 .28047 Mdot
.634 .28188 Mdot
.634 .28268 Mdot
.634 .28469 Mdot
.634 .28516 Mdot
.634 .28642 Mdot
.634 .28696 Mdot
.634 .28747 Mdot
.634 .28792 Mdot
.634 .28794 Mdot
.634 .28966 Mdot
.634 .29026 Mdot
.634 .29051 Mdot
.634 .29059 Mdot
.634 .29204 Mdot
.634 .29247 Mdot
.634 .29272 Mdot
.634 .29291 Mdot
.634 .2931 Mdot
.634 .29322 Mdot
.634 .29335 Mdot
.634 .29445 Mdot
.634 .29485 Mdot
.634 .29514 Mdot
.634 .29617 Mdot
.634 .29805 Mdot
.634 .29817 Mdot
.634 .2994 Mdot
.634 .30288 Mdot
.634 .30336 Mdot
.634 .30542 Mdot
.634 .30565 Mdot
.634 .30959 Mdot
.634 .30998 Mdot
.634 .31026 Mdot
.634 .31129 Mdot
.634 .31215 Mdot
.634 .31244 Mdot
.634 .31378 Mdot
.634 .31529 Mdot
.634 .31669 Mdot
.634 .31961 Mdot
.634 .31967 Mdot
.634 .32101 Mdot
.634 .32436 Mdot
.634 .32448 Mdot
.634 .32487 Mdot
.634 .32506 Mdot
.634 .32645 Mdot
.634 .32799 Mdot
.634 .32846 Mdot
.634 .32984 Mdot
.634 .33168 Mdot
.634 .33329 Mdot
.634 .33529 Mdot
.634 .33667 Mdot
.634 .33783 Mdot
.634 .33794 Mdot
.634 .33857 Mdot
.634 .3397 Mdot
.634 .34041 Mdot
.634 .3405 Mdot
.634 .34069 Mdot
.634 .34165 Mdot
.634 .34181 Mdot
.634 .34256 Mdot
.634 .3429 Mdot
.634 .34328 Mdot
.634 .34357 Mdot
.634 .34398 Mdot
.634 .34401 Mdot
.634 .34518 Mdot
.634 .34644 Mdot
.634 .34663 Mdot
.634 .34889 Mdot
.634 .34912 Mdot
.634 .35005 Mdot
.634 .35027 Mdot
.634 .35033 Mdot
.634 .35069 Mdot
.634 .35242 Mdot
.634 .35251 Mdot
.634 .35321 Mdot
.634 .35371 Mdot
.634 .35431 Mdot
.634 .35493 Mdot
.634 .35549 Mdot
.634 .35553 Mdot
.634 .35621 Mdot
.634 .35644 Mdot
.634 .35666 Mdot
.634 .35693 Mdot
.634 .35732 Mdot
.634 .35892 Mdot
.634 .35958 Mdot
.634 .36159 Mdot
.634 .36184 Mdot
.634 .3621 Mdot
.634 .36353 Mdot
.634 .36357 Mdot
.634 .36548 Mdot
.634 .36567 Mdot
.634 .36569 Mdot
.634 .36615 Mdot
.634 .36616 Mdot
.634 .36631 Mdot
.634 .36669 Mdot
.634 .36798 Mdot
.634 .36812 Mdot
.634 .36991 Mdot
.634 .37008 Mdot
.634 .37126 Mdot
.634 .37128 Mdot
.634 .37362 Mdot
.634 .37459 Mdot
.634 .37472 Mdot
.634 .37496 Mdot
.634 .37615 Mdot
.634 .37645 Mdot
.634 .37645 Mdot
.634 .37671 Mdot
.634 .37741 Mdot
.634 .37759 Mdot
.634 .37779 Mdot
.634 .37813 Mdot
.634 .38128 Mdot
.634 .38218 Mdot
.634 .38268 Mdot
.634 .38329 Mdot
.634 .38365 Mdot
.634 .3844 Mdot
.634 .38514 Mdot
.634 .38535 Mdot
.634 .38591 Mdot
.634 .38658 Mdot
.634 .38663 Mdot
.634 .38675 Mdot
.634 .38718 Mdot
.634 .38724 Mdot
.634 .38725 Mdot
.634 .38732 Mdot
.634 .38773 Mdot
.634 .38825 Mdot
.634 .38842 Mdot
.634 .38846 Mdot
.634 .38859 Mdot
.634 .38912 Mdot
.634 .38917 Mdot
.634 .38969 Mdot
.634 .39073 Mdot
.634 .39137 Mdot
.634 .39156 Mdot
.634 .39277 Mdot
.634 .39342 Mdot
.634 .39357 Mdot
.634 .39373 Mdot
.634 .3938 Mdot
.634 .39443 Mdot
.634 .39453 Mdot
.634 .3949 Mdot
.634 .39557 Mdot
.634 .39562 Mdot
.634 .39606 Mdot
.634 .39729 Mdot
.634 .39746 Mdot
.634 .39964 Mdot
.634 .39978 Mdot
.634 .39988 Mdot
.634 .40024 Mdot
.634 .40053 Mdot
.634 .40063 Mdot
.634 .40311 Mdot
.634 .40313 Mdot
.634 .40359 Mdot
.634 .40473 Mdot
.634 .40477 Mdot
.634 .4049 Mdot
.634 .40496 Mdot
.634 .40544 Mdot
.634 .40612 Mdot
.634 .40658 Mdot
.634 .40775 Mdot
.634 .40842 Mdot
.634 .40927 Mdot
.634 .40931 Mdot
.634 .40952 Mdot
.634 .41016 Mdot
.634 .41023 Mdot
.634 .41055 Mdot
.634 .4106 Mdot
.634 .41096 Mdot
.634 .41118 Mdot
.634 .4122 Mdot
.634 .41303 Mdot
.634 .41342 Mdot
.634 .41354 Mdot
.634 .41412 Mdot
.634 .41415 Mdot
.634 .41454 Mdot
.634 .41474 Mdot
.634 .41494 Mdot
.634 .41514 Mdot
.634 .41537 Mdot
.634 .41551 Mdot
.634 .4156 Mdot
.634 .41573 Mdot
.634 .41626 Mdot
.634 .41713 Mdot
.634 .41722 Mdot
.634 .41777 Mdot
.634 .41847 Mdot
.634 .41863 Mdot
.634 .41868 Mdot
.634 .41881 Mdot
.634 .41923 Mdot
.634 .41986 Mdot
.634 .41992 Mdot
.634 .4203 Mdot
.634 .42031 Mdot
.634 .42107 Mdot
.634 .42139 Mdot
.634 .42151 Mdot
.634 .4219 Mdot
.634 .422 Mdot
.634 .42231 Mdot
.634 .42358 Mdot
.634 .42403 Mdot
.634 .42435 Mdot
.634 .42459 Mdot
.634 .4253 Mdot
.634 .42536 Mdot
.634 .4255 Mdot
.634 .42552 Mdot
.634 .42552 Mdot
.634 .42555 Mdot
.634 .42568 Mdot
.634 .42585 Mdot
.634 .4259 Mdot
.634 .42592 Mdot
.634 .42596 Mdot
.634 .42615 Mdot
.634 .42632 Mdot
.634 .42666 Mdot
.634 .42687 Mdot
.634 .42693 Mdot
.634 .42732 Mdot
.634 .42754 Mdot
.634 .42764 Mdot
.634 .42766 Mdot
.634 .4279 Mdot
.634 .42802 Mdot
.634 .42824 Mdot
.634 .4284 Mdot
.634 .4288 Mdot
.634 .42886 Mdot
.634 .42957 Mdot
.634 .42962 Mdot
.634 .42977 Mdot
.634 .42986 Mdot
.634 .43071 Mdot
.634 .43124 Mdot
.634 .43147 Mdot
.634 .4317 Mdot
.634 .43245 Mdot
.634 .43274 Mdot
.634 .43315 Mdot
.634 .43336 Mdot
.634 .4337 Mdot
.634 .43397 Mdot
.634 .4341 Mdot
.634 .43433 Mdot
.634 .43447 Mdot
.634 .43453 Mdot
.634 .4346 Mdot
.634 .43474 Mdot
.634 .43479 Mdot
.634 .43482 Mdot
.634 .43486 Mdot
.634 .43504 Mdot
.634 .43533 Mdot
.634 .43535 Mdot
.634 .43582 Mdot
.634 .43584 Mdot
.634 .43602 Mdot
.634 .43623 Mdot
.634 .43625 Mdot
.634 .43638 Mdot
.634 .43663 Mdot
.634 .43678 Mdot
.634 .43762 Mdot
.634 .43772 Mdot
.634 .43804 Mdot
.634 .43832 Mdot
.634 .43883 Mdot
.634 .43895 Mdot
.634 .43902 Mdot
.634 .44003 Mdot
.634 .44086 Mdot
.634 .44123 Mdot
.634 .44125 Mdot
.634 .44142 Mdot
.634 .44171 Mdot
.634 .44172 Mdot
.634 .44185 Mdot
.634 .4419 Mdot
.634 .44266 Mdot
.634 .443 Mdot
.634 .44347 Mdot
.634 .44358 Mdot
.634 .44545 Mdot
.634 .44612 Mdot
.634 .44619 Mdot
.634 .4462 Mdot
.634 .44637 Mdot
.634 .44717 Mdot
.634 .44774 Mdot
.634 .44902 Mdot
.634 .4491 Mdot
.634 .44932 Mdot
.634 .44933 Mdot
.634 .44945 Mdot
.634 .44955 Mdot
.634 .44983 Mdot
.634 .4501 Mdot
.634 .45014 Mdot
.634 .45076 Mdot
.634 .45095 Mdot
.634 .45187 Mdot
.634 .45213 Mdot
.634 .45347 Mdot
.634 .45369 Mdot
.634 .45378 Mdot
.634 .4539 Mdot
.634 .45397 Mdot
.634 .4541 Mdot
.634 .45417 Mdot
.634 .45428 Mdot
.634 .45492 Mdot
.634 .45535 Mdot
.634 .45538 Mdot
.634 .45577 Mdot
.634 .4559 Mdot
.634 .45607 Mdot
.634 .45632 Mdot
.634 .457 Mdot
.634 .45717 Mdot
.634 .45722 Mdot
.634 .45743 Mdot
.634 .45749 Mdot
.634 .45766 Mdot
.634 .45807 Mdot
.634 .45807 Mdot
.634 .45828 Mdot
.634 .45831 Mdot
.634 .45864 Mdot
.634 .45887 Mdot
.634 .45893 Mdot
.634 .45896 Mdot
.634 .45904 Mdot
.634 .45941 Mdot
.634 .45971 Mdot
.634 .45975 Mdot
.634 .46021 Mdot
.634 .46049 Mdot
.634 .46055 Mdot
.634 .4606 Mdot
.634 .46068 Mdot
.634 .46079 Mdot
.634 .4609 Mdot
.634 .461 Mdot
.634 .46111 Mdot
.634 .46132 Mdot
.634 .46133 Mdot
.634 .46163 Mdot
.634 .46169 Mdot
.634 .4619 Mdot
.634 .46233 Mdot
.634 .46285 Mdot
.634 .46297 Mdot
.634 .46315 Mdot
.634 .46318 Mdot
.634 .46334 Mdot
.634 .46338 Mdot
.634 .46371 Mdot
.634 .46382 Mdot
.634 .46384 Mdot
.634 .46427 Mdot
.634 .46461 Mdot
.634 .46521 Mdot
.634 .46544 Mdot
.634 .46579 Mdot
.634 .46603 Mdot
.634 .46606 Mdot
.634 .46613 Mdot
.634 .46615 Mdot
.634 .46672 Mdot
.634 .46696 Mdot
.634 .46697 Mdot
.634 .4682 Mdot
.634 .46825 Mdot
.634 .4684 Mdot
.634 .46858 Mdot
.634 .46863 Mdot
.634 .4687 Mdot
.634 .46978 Mdot
.634 .46986 Mdot
.634 .47047 Mdot
.634 .47068 Mdot
.634 .47071 Mdot
.634 .47104 Mdot
.634 .47122 Mdot
.634 .47127 Mdot
.634 .47158 Mdot
.634 .47161 Mdot
.634 .47169 Mdot
.634 .47176 Mdot
.634 .47208 Mdot
.634 .47266 Mdot
.634 .47276 Mdot
.634 .47307 Mdot
.634 .47357 Mdot
.634 .47382 Mdot
.634 .47384 Mdot
.634 .4741 Mdot
.634 .47416 Mdot
.634 .47418 Mdot
.634 .47426 Mdot
.634 .47451 Mdot
.634 .47471 Mdot
.634 .47474 Mdot
.634 .47475 Mdot
.634 .47478 Mdot
.634 .47498 Mdot
.634 .47504 Mdot
.634 .47506 Mdot
.634 .47538 Mdot
.634 .47565 Mdot
.634 .47575 Mdot
.634 .4761 Mdot
.634 .47646 Mdot
.634 .47663 Mdot
.634 .47692 Mdot
.634 .47715 Mdot
.634 .47758 Mdot
.634 .47905 Mdot
.634 .47922 Mdot
.634 .47931 Mdot
.634 .47939 Mdot
.634 .47972 Mdot
.634 .47984 Mdot
.634 .47984 Mdot
.634 .47998 Mdot
.634 .48053 Mdot
.634 .48064 Mdot
.634 .4807 Mdot
.634 .48115 Mdot
.634 .48222 Mdot
.634 .48223 Mdot
.634 .48277 Mdot
.634 .48285 Mdot
.634 .48366 Mdot
.634 .48373 Mdot
.634 .48431 Mdot
.634 .48449 Mdot
.634 .48455 Mdot
.634 .48456 Mdot
.634 .48477 Mdot
.634 .48478 Mdot
.634 .48486 Mdot
.634 .48572 Mdot
.634 .48574 Mdot
.634 .48638 Mdot
.634 .4865 Mdot
.634 .48661 Mdot
.634 .48751 Mdot
.634 .4878 Mdot
.634 .48851 Mdot
.634 .48868 Mdot
.634 .4888 Mdot
.634 .4889 Mdot
.634 .489 Mdot
.634 .4893 Mdot
.634 .48932 Mdot
.634 .48956 Mdot
.634 .48983 Mdot
.634 .4901 Mdot
.634 .49032 Mdot
.634 .49062 Mdot
.634 .49066 Mdot
.634 .49142 Mdot
.634 .49158 Mdot
.634 .4916 Mdot
.634 .4917 Mdot
.634 .4921 Mdot
.634 .4922 Mdot
.634 .49318 Mdot
.634 .49326 Mdot
.634 .4938 Mdot
.634 .4943 Mdot
.634 .49432 Mdot
.634 .49449 Mdot
.634 .49461 Mdot
.634 .49478 Mdot
.634 .49492 Mdot
.634 .49524 Mdot
.634 .49531 Mdot
.634 .49572 Mdot
.634 .4958 Mdot
.634 .49584 Mdot
.634 .49614 Mdot
.634 .49662 Mdot
.634 .49689 Mdot
.634 .49693 Mdot
.634 .49742 Mdot
.634 .498 Mdot
.634 .49884 Mdot
.634 .49951 Mdot
.634 .50028 Mdot
.634 .50085 Mdot
.634 .50104 Mdot
.634 .50168 Mdot
.634 .50225 Mdot
.634 .50233 Mdot
.634 .50249 Mdot
.634 .50254 Mdot
.634 .50391 Mdot
.634 .50445 Mdot
.634 .50448 Mdot
.634 .50566 Mdot
.634 .50622 Mdot
.634 .50683 Mdot
.634 .50737 Mdot
.634 .50748 Mdot
.634 .50783 Mdot
.634 .50824 Mdot
.634 .50835 Mdot
.634 .50851 Mdot
.634 .51007 Mdot
.634 .51016 Mdot
.634 .51097 Mdot
.634 .51116 Mdot
.634 .51252 Mdot
.634 .513 Mdot
.634 .51305 Mdot
.634 .51378 Mdot
.634 .51418 Mdot
.634 .51429 Mdot
.634 .51444 Mdot
.634 .51487 Mdot
.634 .51492 Mdot
.634 .51496 Mdot
.634 .51504 Mdot
.634 .51511 Mdot
.634 .51521 Mdot
.634 .51537 Mdot
.634 .51593 Mdot
.634 .51596 Mdot
.634 .51605 Mdot
.634 .51628 Mdot
.634 .51694 Mdot
.634 .51695 Mdot
.634 .51712 Mdot
.634 .51732 Mdot
.634 .51752 Mdot
.634 .518 Mdot
.634 .51818 Mdot
.634 .51894 Mdot
.634 .51924 Mdot
.634 .51977 Mdot
.634 .51982 Mdot
.634 .51994 Mdot
.634 .52024 Mdot
.634 .52035 Mdot
.634 .52048 Mdot
.634 .52052 Mdot
.634 .52053 Mdot
.634 .52069 Mdot
.634 .52121 Mdot
.634 .52162 Mdot
.634 .52169 Mdot
.634 .52169 Mdot
.634 .52175 Mdot
.634 .52217 Mdot
.634 .5223 Mdot
.634 .52234 Mdot
.634 .52256 Mdot
.634 .52299 Mdot
.634 .52353 Mdot
.634 .52373 Mdot
.634 .52379 Mdot
.634 .52383 Mdot
.634 .52385 Mdot
.634 .52405 Mdot
.634 .5244 Mdot
.634 .52444 Mdot
.634 .52515 Mdot
.634 .52535 Mdot
.634 .52548 Mdot
.634 .52606 Mdot
.634 .52652 Mdot
.634 .52685 Mdot
.634 .5269 Mdot
.634 .52714 Mdot
.634 .52734 Mdot
.634 .53015 Mdot
.634 .53045 Mdot
.634 .53045 Mdot
.634 .53062 Mdot
.634 .53077 Mdot
.634 .53103 Mdot
.634 .53137 Mdot
.634 .53158 Mdot
.634 .53159 Mdot
.634 .53159 Mdot
.634 .53185 Mdot
.634 .53216 Mdot
.634 .53274 Mdot
.634 .53284 Mdot
.634 .53305 Mdot
.634 .53315 Mdot
.634 .53346 Mdot
.634 .53371 Mdot
.634 .53395 Mdot
.634 .53418 Mdot
.634 .53442 Mdot
.634 .53572 Mdot
.634 .53581 Mdot
.634 .53583 Mdot
.634 .5364 Mdot
.634 .53675 Mdot
.634 .53688 Mdot
.634 .53695 Mdot
.634 .53696 Mdot
.634 .53697 Mdot
.634 .53742 Mdot
.634 .53813 Mdot
.634 .53823 Mdot
.634 .53833 Mdot
.634 .53867 Mdot
.634 .53899 Mdot
.634 .53928 Mdot
.634 .53934 Mdot
.634 .53934 Mdot
.634 .53956 Mdot
.634 .53966 Mdot
.634 .53968 Mdot
.634 .53994 Mdot
.634 .54 Mdot
.634 .54002 Mdot
.634 .54015 Mdot
.634 .54149 Mdot
.634 .54152 Mdot
.634 .54248 Mdot
.634 .54266 Mdot
.634 .54282 Mdot
.634 .54413 Mdot
.634 .54455 Mdot
.634 .54512 Mdot
.634 .54546 Mdot
.634 .54554 Mdot
.634 .54578 Mdot
.634 .54586 Mdot
.634 .54593 Mdot
.634 .54594 Mdot
.634 .54607 Mdot
.634 .54621 Mdot
.634 .54648 Mdot
.634 .54661 Mdot
.634 .54663 Mdot
.634 .54696 Mdot
.634 .54721 Mdot
.634 .54731 Mdot
.634 .54765 Mdot
.634 .54793 Mdot
.634 .54809 Mdot
.634 .5483 Mdot
.634 .54832 Mdot
.634 .54837 Mdot
.634 .54858 Mdot
.634 .5493 Mdot
.634 .54949 Mdot
.634 .54951 Mdot
.634 .54961 Mdot
.634 .54963 Mdot
.634 .54967 Mdot
.634 .5501 Mdot
.634 .55015 Mdot
.634 .55022 Mdot
.634 .55042 Mdot
.634 .55044 Mdot
.634 .5505 Mdot
.634 .55058 Mdot
.634 .55085 Mdot
.634 .55132 Mdot
.634 .55141 Mdot
.634 .55154 Mdot
.634 .552 Mdot
.634 .55208 Mdot
.634 .55234 Mdot
.634 .55239 Mdot
.634 .55252 Mdot
.634 .55254 Mdot
.634 .55254 Mdot
.634 .55272 Mdot
.634 .55284 Mdot
.634 .553 Mdot
.634 .55303 Mdot
.634 .5531 Mdot
.634 .55311 Mdot
.634 .55315 Mdot
.634 .55318 Mdot
.634 .55346 Mdot
.634 .55353 Mdot
.634 .55363 Mdot
.634 .55391 Mdot
.634 .55399 Mdot
.634 .55403 Mdot
.634 .55419 Mdot
.634 .5543 Mdot
.634 .55436 Mdot
.634 .55437 Mdot
.634 .5544 Mdot
.634 .55454 Mdot
.634 .55465 Mdot
.634 .55473 Mdot
.634 .55494 Mdot
.634 .55497 Mdot
.634 .555 Mdot
.634 .55506 Mdot
.634 .5551 Mdot
.634 .55542 Mdot
.634 .5556 Mdot
.634 .55587 Mdot
.634 .55588 Mdot
.634 .55651 Mdot
.634 .55652 Mdot
.634 .55665 Mdot
.634 .557 Mdot
.634 .55702 Mdot
.634 .55717 Mdot
.634 .55731 Mdot
.634 .55743 Mdot
.634 .55743 Mdot
.634 .5575 Mdot
.634 .55785 Mdot
.634 .55787 Mdot
.634 .55797 Mdot
.634 .55802 Mdot
.634 .55808 Mdot
.634 .5581 Mdot
.634 .55832 Mdot
.634 .55842 Mdot
.634 .55851 Mdot
.634 .55856 Mdot
.634 .5586 Mdot
.634 .55861 Mdot
.634 .55864 Mdot
.634 .55865 Mdot
.634 .55866 Mdot
.634 .55869 Mdot
.634 .55873 Mdot
.634 .55875 Mdot
.634 .5589 Mdot
.634 .55897 Mdot
.634 .55902 Mdot
.634 .55919 Mdot
.634 .55933 Mdot
.634 .55948 Mdot
.634 .55949 Mdot
.634 .55952 Mdot
.634 .55953 Mdot
.634 .55965 Mdot
.634 .55986 Mdot
.634 .55999 Mdot
.634 .56 Mdot
.634 .56003 Mdot
.634 .56009 Mdot
.634 .56015 Mdot
.634 .56016 Mdot
.634 .56016 Mdot
.634 .56017 Mdot
.634 .5602 Mdot
.634 .56022 Mdot
.634 .56023 Mdot
.634 .56023 Mdot
.636 .16207 Mdot
.636 .16209 Mdot
.636 .16218 Mdot
.636 .16224 Mdot
.636 .16232 Mdot
.636 .16233 Mdot
.636 .16237 Mdot
.636 .16241 Mdot
.636 .16247 Mdot
.636 .1625 Mdot
.636 .16262 Mdot
.636 .16262 Mdot
.636 .1627 Mdot
.636 .16277 Mdot
.636 .1629 Mdot
.636 .16299 Mdot
.636 .16308 Mdot
.636 .16313 Mdot
.636 .16314 Mdot
.636 .16317 Mdot
.636 .16351 Mdot
.636 .16365 Mdot
.636 .16379 Mdot
.636 .16383 Mdot
.636 .1641 Mdot
.636 .16419 Mdot
.636 .16421 Mdot
.636 .16454 Mdot
.636 .16469 Mdot
.636 .16477 Mdot
.636 .16514 Mdot
.636 .16516 Mdot
.636 .16516 Mdot
.636 .16536 Mdot
.636 .16564 Mdot
.636 .16588 Mdot
.636 .16598 Mdot
.636 .16609 Mdot
.636 .16666 Mdot
.636 .16684 Mdot
.636 .16768 Mdot
.636 .16785 Mdot
.636 .16788 Mdot
.636 .16824 Mdot
.636 .16829 Mdot
.636 .16831 Mdot
.636 .16875 Mdot
.636 .16925 Mdot
.636 .16926 Mdot
.636 .16959 Mdot
.636 .16989 Mdot
.636 .1711 Mdot
.636 .17126 Mdot
.636 .17174 Mdot
.636 .17354 Mdot
.636 .17399 Mdot
.636 .17484 Mdot
.636 .17566 Mdot
.636 .17608 Mdot
.636 .17631 Mdot
.636 .1764 Mdot
.636 .17676 Mdot
.636 .17696 Mdot
.636 .177 Mdot
.636 .17707 Mdot
.636 .17731 Mdot
.636 .17733 Mdot
.636 .17746 Mdot
.636 .17749 Mdot
.636 .17783 Mdot
.636 .17795 Mdot
.636 .17829 Mdot
.636 .17865 Mdot
.636 .17877 Mdot
.636 .17889 Mdot
.636 .17991 Mdot
.636 .18099 Mdot
.636 .1813 Mdot
.636 .18148 Mdot
.636 .18177 Mdot
.636 .18238 Mdot
.636 .18311 Mdot
.636 .1834 Mdot
.636 .184 Mdot
.636 .18531 Mdot
.636 .18535 Mdot
.636 .18567 Mdot
.636 .186 Mdot
.636 .18685 Mdot
.636 .187 Mdot
.636 .18701 Mdot
.636 .18723 Mdot
.636 .18726 Mdot
.636 .1874 Mdot
.636 .18756 Mdot
.636 .18827 Mdot
.636 .18948 Mdot
.636 .19016 Mdot
.636 .19053 Mdot
.636 .19066 Mdot
.636 .19137 Mdot
.636 .19155 Mdot
.636 .19225 Mdot
.636 .19246 Mdot
.636 .19249 Mdot
.636 .19301 Mdot
.636 .1932 Mdot
.636 .1933 Mdot
.636 .19361 Mdot
.636 .19383 Mdot
.636 .19518 Mdot
.636 .19519 Mdot
.636 .1953 Mdot
.636 .19661 Mdot
.636 .19758 Mdot
.636 .19864 Mdot
.636 .19908 Mdot
.636 .19928 Mdot
.636 .20138 Mdot
.636 .20193 Mdot
.636 .20197 Mdot
.636 .20405 Mdot
.636 .20632 Mdot
.636 .20642 Mdot
.636 .20662 Mdot
.636 .20728 Mdot
.636 .20755 Mdot
.636 .20856 Mdot
.636 .2088 Mdot
.636 .21193 Mdot
.636 .21269 Mdot
.636 .21416 Mdot
.636 .21621 Mdot
.636 .2169 Mdot
.636 .21849 Mdot
.636 .21948 Mdot
.636 .22007 Mdot
.636 .22028 Mdot
.636 .22082 Mdot
.636 .221 Mdot
.636 .22143 Mdot
.636 .22171 Mdot
.636 .22317 Mdot
.636 .22339 Mdot
.636 .22472 Mdot
.636 .22604 Mdot
.636 .22783 Mdot
.636 .22832 Mdot
.636 .22846 Mdot
.636 .22893 Mdot
.636 .23143 Mdot
.636 .23151 Mdot
.636 .23281 Mdot
.636 .23608 Mdot
.636 .23633 Mdot
.636 .23743 Mdot
.636 .23895 Mdot
.636 .24047 Mdot
.636 .24117 Mdot
.636 .24258 Mdot
.636 .24286 Mdot
.636 .24466 Mdot
.636 .24533 Mdot
.636 .24806 Mdot
.636 .24869 Mdot
.636 .25035 Mdot
.636 .25245 Mdot
.636 .25326 Mdot
.636 .2534 Mdot
.636 .25407 Mdot
.636 .25565 Mdot
.636 .256 Mdot
.636 .25782 Mdot
.636 .26057 Mdot
.636 .2612 Mdot
.636 .26373 Mdot
.636 .26532 Mdot
.636 .26544 Mdot
.636 .26571 Mdot
.636 .26695 Mdot
.636 .26785 Mdot
.636 .26786 Mdot
.636 .26872 Mdot
.636 .26906 Mdot
.636 .26913 Mdot
.636 .2696 Mdot
.636 .26962 Mdot
.636 .26975 Mdot
.636 .27022 Mdot
.636 .27035 Mdot
.636 .27082 Mdot
.636 .27117 Mdot
.636 .27163 Mdot
.636 .27299 Mdot
.636 .27311 Mdot
.636 .2732 Mdot
.636 .27339 Mdot
.636 .27339 Mdot
.636 .27438 Mdot
.636 .27462 Mdot
.636 .27464 Mdot
.636 .27564 Mdot
.636 .27633 Mdot
.636 .27764 Mdot
.636 .27895 Mdot
.636 .27984 Mdot
.636 .28036 Mdot
.636 .28109 Mdot
.636 .28111 Mdot
.636 .28123 Mdot
.636 .28147 Mdot
.636 .28176 Mdot
.636 .2821 Mdot
.636 .28241 Mdot
.636 .28281 Mdot
.636 .28362 Mdot
.636 .28694 Mdot
.636 .28768 Mdot
.636 .28918 Mdot
.636 .28956 Mdot
.636 .29068 Mdot
.636 .2913 Mdot
.636 .29132 Mdot
.636 .29197 Mdot
.636 .29383 Mdot
.636 .29501 Mdot
.636 .29563 Mdot
.636 .29616 Mdot
.636 .29755 Mdot
.636 .29787 Mdot
.636 .2987 Mdot
.636 .2996 Mdot
.636 .29972 Mdot
.636 .30051 Mdot
.636 .3017 Mdot
.636 .30173 Mdot
.636 .30223 Mdot
.636 .3031 Mdot
.636 .30378 Mdot
.636 .30438 Mdot
.636 .30487 Mdot
.636 .30544 Mdot
.636 .30607 Mdot
.636 .30664 Mdot
.636 .30888 Mdot
.636 .31018 Mdot
.636 .31263 Mdot
.636 .31291 Mdot
.636 .313 Mdot
.636 .31348 Mdot
.636 .31426 Mdot
.636 .31463 Mdot
.636 .31547 Mdot
.636 .31614 Mdot
.636 .31645 Mdot
.636 .31793 Mdot
.636 .31912 Mdot
.636 .31939 Mdot
.636 .32065 Mdot
.636 .32144 Mdot
.636 .32147 Mdot
.636 .32148 Mdot
.636 .32284 Mdot
.636 .32324 Mdot
.636 .3245 Mdot
.636 .32581 Mdot
.636 .32611 Mdot
.636 .32663 Mdot
.636 .32803 Mdot
.636 .32804 Mdot
.636 .33054 Mdot
.636 .33308 Mdot
.636 .33354 Mdot
.636 .33584 Mdot
.636 .33645 Mdot
.636 .33649 Mdot
.636 .33678 Mdot
.636 .33725 Mdot
.636 .33737 Mdot
.636 .33799 Mdot
.636 .33809 Mdot
.636 .33998 Mdot
.636 .34025 Mdot
.636 .34063 Mdot
.636 .34112 Mdot
.636 .34193 Mdot
.636 .3439 Mdot
.636 .34453 Mdot
.636 .34481 Mdot
.636 .34555 Mdot
.636 .34712 Mdot
.636 .34878 Mdot
.636 .34917 Mdot
.636 .35026 Mdot
.636 .35168 Mdot
.636 .35396 Mdot
.636 .35428 Mdot
.636 .35551 Mdot
.636 .35678 Mdot
.636 .35695 Mdot
.636 .35731 Mdot
.636 .35801 Mdot
.636 .35814 Mdot
.636 .35982 Mdot
.636 .36098 Mdot
.636 .36318 Mdot
.636 .36367 Mdot
.636 .36407 Mdot
.636 .36433 Mdot
.636 .36442 Mdot
.636 .36547 Mdot
.636 .36622 Mdot
.636 .36684 Mdot
.636 .36792 Mdot
.636 .36798 Mdot
.636 .3682 Mdot
.636 .36938 Mdot
.636 .37144 Mdot
.636 .37155 Mdot
.636 .37204 Mdot
.636 .37367 Mdot
.636 .37428 Mdot
.636 .3744 Mdot
.636 .3766 Mdot
.636 .37842 Mdot
.636 .37876 Mdot
.636 .37881 Mdot
.636 .37973 Mdot
.636 .37987 Mdot
.636 .38295 Mdot
.636 .38357 Mdot
.636 .38362 Mdot
.636 .38372 Mdot
.636 .38421 Mdot
.636 .38455 Mdot
.636 .38456 Mdot
.636 .38489 Mdot
.636 .38502 Mdot
.636 .38505 Mdot
.636 .38524 Mdot
.636 .38529 Mdot
.636 .38547 Mdot
.636 .38551 Mdot
.636 .3857 Mdot
.636 .38583 Mdot
.636 .38601 Mdot
.636 .38657 Mdot
.636 .38668 Mdot
.636 .38668 Mdot
.636 .38705 Mdot
.636 .38714 Mdot
.636 .38715 Mdot
.636 .38753 Mdot
.636 .38779 Mdot
.636 .38828 Mdot
.636 .38877 Mdot
.636 .3893 Mdot
.636 .38957 Mdot
.636 .38962 Mdot
.636 .38982 Mdot
.636 .38994 Mdot
.636 .39006 Mdot
.636 .3905 Mdot
.636 .39172 Mdot
.636 .39254 Mdot
.636 .39268 Mdot
.636 .39308 Mdot
.636 .39331 Mdot
.636 .39355 Mdot
.636 .39422 Mdot
.636 .39505 Mdot
.636 .39555 Mdot
.636 .39566 Mdot
.636 .39596 Mdot
.636 .39628 Mdot
.636 .39702 Mdot
.636 .39751 Mdot
.636 .39814 Mdot
.636 .39834 Mdot
.636 .39876 Mdot
.636 .39999 Mdot
.636 .40084 Mdot
.636 .40094 Mdot
.636 .40097 Mdot
.636 .4014 Mdot
.636 .40153 Mdot
.636 .40205 Mdot
.636 .40216 Mdot
.636 .40267 Mdot
.636 .40307 Mdot
.636 .40316 Mdot
.636 .40359 Mdot
.636 .40386 Mdot
.636 .40388 Mdot
.636 .40434 Mdot
.636 .40447 Mdot
.636 .4049 Mdot
.636 .40545 Mdot
.636 .40563 Mdot
.636 .4061 Mdot
.636 .40695 Mdot
.636 .4078 Mdot
.636 .40795 Mdot
.636 .40872 Mdot
.636 .40893 Mdot
.636 .40894 Mdot
.636 .40904 Mdot
.636 .4092 Mdot
.636 .40944 Mdot
.636 .41011 Mdot
.636 .41019 Mdot
.636 .41032 Mdot
.636 .41195 Mdot
.636 .41247 Mdot
.636 .41302 Mdot
.636 .41315 Mdot
.636 .41351 Mdot
.636 .41473 Mdot
.636 .41484 Mdot
.636 .41524 Mdot
.636 .41566 Mdot
.636 .41571 Mdot
.636 .41583 Mdot
.636 .41704 Mdot
.636 .41776 Mdot
.636 .41792 Mdot
.636 .41805 Mdot
.636 .41813 Mdot
.636 .41851 Mdot
.636 .4193 Mdot
.636 .41932 Mdot
.636 .41978 Mdot
.636 .42049 Mdot
.636 .42065 Mdot
.636 .42118 Mdot
.636 .42138 Mdot
.636 .42214 Mdot
.636 .42316 Mdot
.636 .4232 Mdot
.636 .42441 Mdot
.636 .42446 Mdot
.636 .42461 Mdot
.636 .42473 Mdot
.636 .42488 Mdot
.636 .42489 Mdot
.636 .42495 Mdot
.636 .42497 Mdot
.636 .42504 Mdot
.636 .4251 Mdot
.636 .42514 Mdot
.636 .4252 Mdot
.636 .42538 Mdot
.636 .42542 Mdot
.636 .42542 Mdot
.636 .42557 Mdot
.636 .4257 Mdot
.636 .42594 Mdot
.636 .4261 Mdot
.636 .42627 Mdot
.636 .42636 Mdot
.636 .42638 Mdot
.636 .42644 Mdot
.636 .42652 Mdot
.636 .42706 Mdot
.636 .42733 Mdot
.636 .42758 Mdot
.636 .42766 Mdot
.636 .42815 Mdot
.636 .42831 Mdot
.636 .42835 Mdot
.636 .42844 Mdot
.636 .42879 Mdot
.636 .42895 Mdot
.636 .42916 Mdot
.636 .42922 Mdot
.636 .42936 Mdot
.636 .43004 Mdot
.636 .43007 Mdot
.636 .43008 Mdot
.636 .43022 Mdot
.636 .43026 Mdot
.636 .43043 Mdot
.636 .43094 Mdot
.636 .43123 Mdot
.636 .43137 Mdot
.636 .43155 Mdot
.636 .4316 Mdot
.636 .43176 Mdot
.636 .43232 Mdot
.636 .43262 Mdot
.636 .43269 Mdot
.636 .43278 Mdot
.636 .43286 Mdot
.636 .43307 Mdot
.636 .4331 Mdot
.636 .43314 Mdot
.636 .43368 Mdot
.636 .43385 Mdot
.636 .43408 Mdot
.636 .43419 Mdot
.636 .4346 Mdot
.636 .43476 Mdot
.636 .4349 Mdot
.636 .43496 Mdot
.636 .43536 Mdot
.636 .4356 Mdot
.636 .43569 Mdot
.636 .43572 Mdot
.636 .43584 Mdot
.636 .43611 Mdot
.636 .43611 Mdot
.636 .4365 Mdot
.636 .4368 Mdot
.636 .43738 Mdot
.636 .4374 Mdot
.636 .43798 Mdot
.636 .43803 Mdot
.636 .4385 Mdot
.636 .43976 Mdot
.636 .44044 Mdot
.636 .44063 Mdot
.636 .4409 Mdot
.636 .44147 Mdot
.636 .44172 Mdot
.636 .44296 Mdot
.636 .44354 Mdot
.636 .44425 Mdot
.636 .44483 Mdot
.636 .44524 Mdot
.636 .44558 Mdot
.636 .44644 Mdot
.636 .44703 Mdot
.636 .44743 Mdot
.636 .44841 Mdot
.636 .44911 Mdot
.636 .4495 Mdot
.636 .4495 Mdot
.636 .44965 Mdot
.636 .44993 Mdot
.636 .45026 Mdot
.636 .45058 Mdot
.636 .45065 Mdot
.636 .45077 Mdot
.636 .45087 Mdot
.636 .45117 Mdot
.636 .45121 Mdot
.636 .45133 Mdot
.636 .45142 Mdot
.636 .45146 Mdot
.636 .45163 Mdot
.636 .45202 Mdot
.636 .45223 Mdot
.636 .45277 Mdot
.636 .45279 Mdot
.636 .45338 Mdot
.636 .45358 Mdot
.636 .45377 Mdot
.636 .45482 Mdot
.636 .45544 Mdot
.636 .45559 Mdot
.636 .45567 Mdot
.636 .45661 Mdot
.636 .45664 Mdot
.636 .45718 Mdot
.636 .45759 Mdot
.636 .4577 Mdot
.636 .45798 Mdot
.636 .45806 Mdot
.636 .45844 Mdot
.636 .45868 Mdot
.636 .45869 Mdot
.636 .45912 Mdot
.636 .45931 Mdot
.636 .45936 Mdot
.636 .45943 Mdot
.636 .45951 Mdot
.636 .45989 Mdot
.636 .46052 Mdot
.636 .46059 Mdot
.636 .46061 Mdot
.636 .46083 Mdot
.636 .46104 Mdot
.636 .4611 Mdot
.636 .46174 Mdot
.636 .46192 Mdot
.636 .46199 Mdot
.636 .46227 Mdot
.636 .46254 Mdot
.636 .46338 Mdot
.636 .46345 Mdot
.636 .46349 Mdot
.636 .46384 Mdot
.636 .46396 Mdot
.636 .46404 Mdot
.636 .46409 Mdot
.636 .4641 Mdot
.636 .4642 Mdot
.636 .4646 Mdot
.636 .46468 Mdot
.636 .46511 Mdot
.636 .46554 Mdot
.636 .46578 Mdot
.636 .46587 Mdot
.636 .46614 Mdot
.636 .46636 Mdot
.636 .46643 Mdot
.636 .46666 Mdot
.636 .46667 Mdot
.636 .4668 Mdot
.636 .46702 Mdot
.636 .46707 Mdot
.636 .46727 Mdot
.636 .46753 Mdot
.636 .46758 Mdot
.636 .46784 Mdot
.636 .4679 Mdot
.636 .46812 Mdot
.636 .46813 Mdot
.636 .46818 Mdot
.636 .46861 Mdot
.636 .46922 Mdot
.636 .46943 Mdot
.636 .46952 Mdot
.636 .46983 Mdot
.636 .47008 Mdot
.636 .47044 Mdot
.636 .4706 Mdot
.636 .47074 Mdot
.636 .4708 Mdot
.636 .47104 Mdot
.636 .47145 Mdot
.636 .47178 Mdot
.636 .47189 Mdot
.636 .472 Mdot
.636 .4722 Mdot
.636 .47227 Mdot
.636 .47266 Mdot
.636 .47325 Mdot
.636 .47347 Mdot
.636 .47353 Mdot
.636 .47359 Mdot
.636 .47368 Mdot
.636 .47371 Mdot
.636 .47384 Mdot
.636 .47409 Mdot
.636 .47433 Mdot
.636 .47456 Mdot
.636 .47469 Mdot
.636 .47487 Mdot
.636 .47487 Mdot
.636 .47491 Mdot
.636 .47509 Mdot
.636 .47509 Mdot
.636 .47514 Mdot
.636 .47541 Mdot
.636 .4755 Mdot
.636 .47556 Mdot
.636 .47565 Mdot
.636 .47567 Mdot
.636 .47576 Mdot
.636 .47578 Mdot
.636 .47587 Mdot
.636 .47588 Mdot
.636 .47595 Mdot
.636 .4761 Mdot
.636 .47611 Mdot
.636 .47627 Mdot
.636 .4765 Mdot
.636 .47655 Mdot
.636 .47657 Mdot
.636 .47687 Mdot
.636 .47831 Mdot
.636 .47838 Mdot
.636 .47881 Mdot
.636 .47884 Mdot
.636 .47899 Mdot
.636 .47984 Mdot
.636 .48086 Mdot
.636 .48091 Mdot
.636 .48119 Mdot
.636 .48195 Mdot
.636 .48217 Mdot
.636 .48222 Mdot
.636 .48316 Mdot
.636 .4837 Mdot
.636 .4838 Mdot
.636 .48383 Mdot
.636 .48431 Mdot
.636 .4846 Mdot
.636 .48493 Mdot
.636 .48541 Mdot
.636 .48545 Mdot
.636 .48557 Mdot
.636 .48575 Mdot
.636 .48596 Mdot
.636 .48695 Mdot
.636 .48747 Mdot
.636 .48821 Mdot
.636 .48827 Mdot
.636 .48858 Mdot
.636 .48874 Mdot
.636 .48881 Mdot
.636 .48937 Mdot
.636 .48991 Mdot
.636 .49005 Mdot
.636 .49105 Mdot
.636 .49167 Mdot
.636 .49214 Mdot
.636 .49231 Mdot
.636 .49303 Mdot
.636 .4937 Mdot
.636 .49402 Mdot
.636 .49414 Mdot
.636 .49441 Mdot
.636 .49525 Mdot
.636 .49559 Mdot
.636 .49581 Mdot
.636 .49597 Mdot
.636 .49608 Mdot
.636 .49688 Mdot
.636 .49692 Mdot
.636 .49719 Mdot
.636 .49723 Mdot
.636 .49743 Mdot
.636 .49755 Mdot
.636 .49757 Mdot
.636 .49783 Mdot
.636 .49879 Mdot
.636 .49898 Mdot
.636 .50004 Mdot
.636 .50108 Mdot
.636 .50108 Mdot
.636 .50166 Mdot
.636 .50187 Mdot
.636 .502 Mdot
.636 .50253 Mdot
.636 .50305 Mdot
.636 .50321 Mdot
.636 .50377 Mdot
.636 .50377 Mdot
.636 .50379 Mdot
.636 .50411 Mdot
.636 .50462 Mdot
.636 .50473 Mdot
.636 .50521 Mdot
.636 .50581 Mdot
.636 .50593 Mdot
.636 .5062 Mdot
.636 .50654 Mdot
.636 .50669 Mdot
.636 .507 Mdot
.636 .5072 Mdot
.636 .50723 Mdot
.636 .50734 Mdot
.636 .50832 Mdot
.636 .50884 Mdot
.636 .50972 Mdot
.636 .50995 Mdot
.636 .5102 Mdot
.636 .51042 Mdot
.636 .51062 Mdot
.636 .51085 Mdot
.636 .51112 Mdot
.636 .51146 Mdot
.636 .51166 Mdot
.636 .51167 Mdot
.636 .51213 Mdot
.636 .51244 Mdot
.636 .51249 Mdot
.636 .51284 Mdot
.636 .51316 Mdot
.636 .51329 Mdot
.636 .51383 Mdot
.636 .51403 Mdot
.636 .51427 Mdot
.636 .51473 Mdot
.636 .51544 Mdot
.636 .51569 Mdot
.636 .5157 Mdot
.636 .51594 Mdot
.636 .51637 Mdot
.636 .51652 Mdot
.636 .51709 Mdot
.636 .51737 Mdot
.636 .51863 Mdot
.636 .51893 Mdot
.636 .51909 Mdot
.636 .5192 Mdot
.636 .51933 Mdot
.636 .51944 Mdot
.636 .51953 Mdot
.636 .51958 Mdot
.636 .51958 Mdot
.636 .51986 Mdot
.636 .52006 Mdot
.636 .52039 Mdot
.636 .52088 Mdot
.636 .52137 Mdot
.636 .52163 Mdot
.636 .522 Mdot
.636 .52201 Mdot
.636 .5221 Mdot
.636 .52246 Mdot
.636 .52247 Mdot
.636 .52254 Mdot
.636 .52257 Mdot
.636 .52262 Mdot
.636 .52312 Mdot
.636 .52329 Mdot
.636 .52342 Mdot
.636 .5236 Mdot
.636 .52364 Mdot
.636 .52381 Mdot
.636 .52386 Mdot
.636 .52387 Mdot
.636 .52404 Mdot
.636 .52407 Mdot
.636 .5242 Mdot
.636 .52451 Mdot
.636 .52452 Mdot
.636 .52485 Mdot
.636 .5253 Mdot
.636 .5254 Mdot
.636 .52545 Mdot
.636 .52603 Mdot
.636 .52695 Mdot
.636 .52718 Mdot
.636 .52818 Mdot
.636 .52884 Mdot
.636 .52896 Mdot
.636 .52953 Mdot
.636 .52977 Mdot
.636 .52982 Mdot
.636 .53011 Mdot
.636 .53087 Mdot
.636 .53146 Mdot
.636 .53168 Mdot
.636 .53266 Mdot
.636 .53289 Mdot
.636 .53353 Mdot
.636 .53363 Mdot
.636 .53413 Mdot
.636 .53437 Mdot
.636 .53491 Mdot
.636 .53544 Mdot
.636 .53583 Mdot
.636 .53591 Mdot
.636 .53706 Mdot
.636 .53751 Mdot
.636 .53753 Mdot
.636 .5384 Mdot
.636 .53856 Mdot
.636 .53861 Mdot
.636 .53878 Mdot
.636 .5394 Mdot
.636 .53985 Mdot
.636 .54031 Mdot
.636 .54038 Mdot
.636 .54088 Mdot
.636 .54098 Mdot
.636 .54113 Mdot
.636 .54119 Mdot
.636 .54137 Mdot
.636 .54145 Mdot
.636 .54165 Mdot
.636 .54198 Mdot
.636 .54253 Mdot
.636 .54276 Mdot
.636 .54345 Mdot
.636 .54395 Mdot
.636 .54421 Mdot
.636 .54526 Mdot
.636 .54534 Mdot
.636 .54568 Mdot
.636 .54577 Mdot
.636 .54599 Mdot
.636 .54606 Mdot
.636 .54609 Mdot
.636 .54685 Mdot
.636 .54754 Mdot
.636 .54756 Mdot
.636 .54774 Mdot
.636 .54844 Mdot
.636 .5485 Mdot
.636 .54865 Mdot
.636 .549 Mdot
.636 .54932 Mdot
.636 .54975 Mdot
.636 .54979 Mdot
.636 .54979 Mdot
.636 .55024 Mdot
.636 .55031 Mdot
.636 .55041 Mdot
.636 .55045 Mdot
.636 .55051 Mdot
.636 .55068 Mdot
.636 .55069 Mdot
.636 .55076 Mdot
.636 .55099 Mdot
.636 .55105 Mdot
.636 .55128 Mdot
.636 .55132 Mdot
.636 .55144 Mdot
.636 .55166 Mdot
.636 .55206 Mdot
.636 .55229 Mdot
.636 .55234 Mdot
.636 .55239 Mdot
.636 .5524 Mdot
.636 .55247 Mdot
.636 .55247 Mdot
.636 .55252 Mdot
.636 .5528 Mdot
.636 .55291 Mdot
.636 .55301 Mdot
.636 .55302 Mdot
.636 .55345 Mdot
.636 .55364 Mdot
.636 .55374 Mdot
.636 .55397 Mdot
.636 .55417 Mdot
.636 .55427 Mdot
.636 .55432 Mdot
.636 .55443 Mdot
.636 .55477 Mdot
.636 .5551 Mdot
.636 .55514 Mdot
.636 .55518 Mdot
.636 .5553 Mdot
.636 .5554 Mdot
.636 .55545 Mdot
.636 .55556 Mdot
.636 .55556 Mdot
.636 .5556 Mdot
.636 .55561 Mdot
.636 .55569 Mdot
.636 .55571 Mdot
.636 .55573 Mdot
.636 .55579 Mdot
.636 .5559 Mdot
.636 .55593 Mdot
.636 .55601 Mdot
.636 .55614 Mdot
.636 .5564 Mdot
.636 .55668 Mdot
.636 .55682 Mdot
.636 .5574 Mdot
.636 .55755 Mdot
.636 .5576 Mdot
.636 .55799 Mdot
.636 .55808 Mdot
.636 .55819 Mdot
.636 .55819 Mdot
.636 .55835 Mdot
.636 .55849 Mdot
.636 .5585 Mdot
.636 .55851 Mdot
.636 .55863 Mdot
.636 .55864 Mdot
.636 .55869 Mdot
.636 .55896 Mdot
.636 .55902 Mdot
.636 .55919 Mdot
.636 .55923 Mdot
.636 .55926 Mdot
.636 .55934 Mdot
.636 .55943 Mdot
.636 .55949 Mdot
.636 .55949 Mdot
.636 .5595 Mdot
.636 .55962 Mdot
.636 .55964 Mdot
.636 .55969 Mdot
.636 .55979 Mdot
.636 .5598 Mdot
.636 .55983 Mdot
.636 .55991 Mdot
.636 .55992 Mdot
.636 .55997 Mdot
.636 .56001 Mdot
.636 .56012 Mdot
.636 .56013 Mdot
.636 .56013 Mdot
.636 .56015 Mdot
.636 .56018 Mdot
.636 .56021 Mdot
.636 .56025 Mdot
.636 .56027 Mdot
.636 .5603 Mdot
.636 .5603 Mdot
.636 .56033 Mdot
.636 .56034 Mdot
.636 .56036 Mdot
.636 .56037 Mdot
.636 .56037 Mdot
.636 .56039 Mdot
.636 .56039 Mdot
.636 .56041 Mdot
.636 .56043 Mdot
.636 .56046 Mdot
.636 .56047 Mdot
.638 .16138 Mdot
.638 .16141 Mdot
.638 .16151 Mdot
.638 .16158 Mdot
.638 .16174 Mdot
.638 .16178 Mdot
.638 .16182 Mdot
.638 .1619 Mdot
.638 .16209 Mdot
.638 .16209 Mdot
.638 .16212 Mdot
.638 .16236 Mdot
.638 .1624 Mdot
.638 .16241 Mdot
.638 .16242 Mdot
.638 .16264 Mdot
.638 .16265 Mdot
.638 .16267 Mdot
.638 .163 Mdot
.638 .16301 Mdot
.638 .16306 Mdot
.638 .16309 Mdot
.638 .16335 Mdot
.638 .1635 Mdot
.638 .16356 Mdot
.638 .16383 Mdot
.638 .16389 Mdot
.638 .16411 Mdot
.638 .16423 Mdot
.638 .16432 Mdot
.638 .16438 Mdot
.638 .16444 Mdot
.638 .16517 Mdot
.638 .16558 Mdot
.638 .16561 Mdot
.638 .16578 Mdot
.638 .16593 Mdot
.638 .16613 Mdot
.638 .16634 Mdot
.638 .16635 Mdot
.638 .16679 Mdot
.638 .16691 Mdot
.638 .16698 Mdot
.638 .1671 Mdot
.638 .16736 Mdot
.638 .16825 Mdot
.638 .16849 Mdot
.638 .16868 Mdot
.638 .16958 Mdot
.638 .17011 Mdot
.638 .17084 Mdot
.638 .17107 Mdot
.638 .17137 Mdot
.638 .17213 Mdot
.638 .17243 Mdot
.638 .17258 Mdot
.638 .17274 Mdot
.638 .17302 Mdot
.638 .17397 Mdot
.638 .17398 Mdot
.638 .17495 Mdot
.638 .17591 Mdot
.638 .17609 Mdot
.638 .17641 Mdot
.638 .17682 Mdot
.638 .17694 Mdot
.638 .17704 Mdot
.638 .17738 Mdot
.638 .17752 Mdot
.638 .1784 Mdot
.638 .1787 Mdot
.638 .17903 Mdot
.638 .17974 Mdot
.638 .18021 Mdot
.638 .1804 Mdot
.638 .18049 Mdot
.638 .18078 Mdot
.638 .18112 Mdot
.638 .18151 Mdot
.638 .18228 Mdot
.638 .18249 Mdot
.638 .1829 Mdot
.638 .18369 Mdot
.638 .18449 Mdot
.638 .18456 Mdot
.638 .18466 Mdot
.638 .18478 Mdot
.638 .18485 Mdot
.638 .18528 Mdot
.638 .18548 Mdot
.638 .18713 Mdot
.638 .18781 Mdot
.638 .1891 Mdot
.638 .18933 Mdot
.638 .18965 Mdot
.638 .19006 Mdot
.638 .19028 Mdot
.638 .19042 Mdot
.638 .19049 Mdot
.638 .19153 Mdot
.638 .19155 Mdot
.638 .19189 Mdot
.638 .19335 Mdot
.638 .19343 Mdot
.638 .19354 Mdot
.638 .19451 Mdot
.638 .19543 Mdot
.638 .19668 Mdot
.638 .19701 Mdot
.638 .19712 Mdot
.638 .1978 Mdot
.638 .19785 Mdot
.638 .198 Mdot
.638 .19934 Mdot
.638 .19942 Mdot
.638 .19971 Mdot
.638 .20139 Mdot
.638 .20192 Mdot
.638 .20239 Mdot
.638 .20445 Mdot
.638 .20508 Mdot
.638 .20563 Mdot
.638 .20665 Mdot
.638 .20729 Mdot
.638 .20769 Mdot
.638 .20798 Mdot
.638 .21038 Mdot
.638 .21066 Mdot
.638 .21078 Mdot
.638 .21261 Mdot
.638 .2129 Mdot
.638 .21313 Mdot
.638 .21414 Mdot
.638 .21521 Mdot
.638 .21556 Mdot
.638 .21626 Mdot
.638 .21626 Mdot
.638 .21721 Mdot
.638 .21792 Mdot
.638 .21916 Mdot
.638 .21985 Mdot
.638 .22008 Mdot
.638 .2208 Mdot
.638 .22265 Mdot
.638 .22315 Mdot
.638 .22341 Mdot
.638 .22729 Mdot
.638 .22764 Mdot
.638 .22815 Mdot
.638 .23197 Mdot
.638 .23221 Mdot
.638 .23301 Mdot
.638 .23304 Mdot
.638 .23443 Mdot
.638 .2349 Mdot
.638 .23621 Mdot
.638 .23809 Mdot
.638 .23885 Mdot
.638 .23951 Mdot
.638 .2412 Mdot
.638 .24256 Mdot
.638 .24484 Mdot
.638 .24772 Mdot
.638 .24808 Mdot
.638 .25017 Mdot
.638 .25034 Mdot
.638 .25217 Mdot
.638 .25378 Mdot
.638 .25568 Mdot
.638 .25568 Mdot
.638 .25603 Mdot
.638 .25676 Mdot
.638 .25728 Mdot
.638 .2574 Mdot
.638 .25755 Mdot
.638 .25851 Mdot
.638 .25872 Mdot
.638 .26038 Mdot
.638 .26073 Mdot
.638 .2613 Mdot
.638 .26196 Mdot
.638 .26313 Mdot
.638 .2634 Mdot
.638 .26371 Mdot
.638 .26487 Mdot
.638 .26491 Mdot
.638 .26572 Mdot
.638 .26581 Mdot
.638 .26584 Mdot
.638 .26626 Mdot
.638 .26632 Mdot
.638 .26851 Mdot
.638 .26858 Mdot
.638 .26981 Mdot
.638 .27051 Mdot
.638 .27056 Mdot
.638 .27066 Mdot
.638 .27081 Mdot
.638 .27108 Mdot
.638 .2713 Mdot
.638 .27404 Mdot
.638 .27419 Mdot
.638 .27451 Mdot
.638 .27465 Mdot
.638 .27816 Mdot
.638 .27944 Mdot
.638 .27969 Mdot
.638 .28047 Mdot
.638 .28059 Mdot
.638 .2809 Mdot
.638 .281 Mdot
.638 .2811 Mdot
.638 .28147 Mdot
.638 .28286 Mdot
.638 .28382 Mdot
.638 .28481 Mdot
.638 .28721 Mdot
.638 .28808 Mdot
.638 .28988 Mdot
.638 .29045 Mdot
.638 .29171 Mdot
.638 .29226 Mdot
.638 .29255 Mdot
.638 .29323 Mdot
.638 .29358 Mdot
.638 .29417 Mdot
.638 .29452 Mdot
.638 .29524 Mdot
.638 .29665 Mdot
.638 .29677 Mdot
.638 .29708 Mdot
.638 .29858 Mdot
.638 .29911 Mdot
.638 .29985 Mdot
.638 .29999 Mdot
.638 .30099 Mdot
.638 .30109 Mdot
.638 .30181 Mdot
.638 .30186 Mdot
.638 .30188 Mdot
.638 .30204 Mdot
.638 .30393 Mdot
.638 .30459 Mdot
.638 .30656 Mdot
.638 .3089 Mdot
.638 .31013 Mdot
.638 .31217 Mdot
.638 .31322 Mdot
.638 .31369 Mdot
.638 .31494 Mdot
.638 .31495 Mdot
.638 .31507 Mdot
.638 .31697 Mdot
.638 .318 Mdot
.638 .31826 Mdot
.638 .31931 Mdot
.638 .32007 Mdot
.638 .32021 Mdot
.638 .32071 Mdot
.638 .32114 Mdot
.638 .32356 Mdot
.638 .32411 Mdot
.638 .32479 Mdot
.638 .32566 Mdot
.638 .32595 Mdot
.638 .32791 Mdot
.638 .32931 Mdot
.638 .33109 Mdot
.638 .33143 Mdot
.638 .33228 Mdot
.638 .3326 Mdot
.638 .33276 Mdot
.638 .33293 Mdot
.638 .3342 Mdot
.638 .33609 Mdot
.638 .33626 Mdot
.638 .33888 Mdot
.638 .33949 Mdot
.638 .34004 Mdot
.638 .34011 Mdot
.638 .34035 Mdot
.638 .34063 Mdot
.638 .34094 Mdot
.638 .34155 Mdot
.638 .34172 Mdot
.638 .34204 Mdot
.638 .34265 Mdot
.638 .34326 Mdot
.638 .34331 Mdot
.638 .34347 Mdot
.638 .34519 Mdot
.638 .34567 Mdot
.638 .34658 Mdot
.638 .34823 Mdot
.638 .34845 Mdot
.638 .34941 Mdot
.638 .35015 Mdot
.638 .35073 Mdot
.638 .3515 Mdot
.638 .35334 Mdot
.638 .35643 Mdot
.638 .35787 Mdot
.638 .35802 Mdot
.638 .35946 Mdot
.638 .36182 Mdot
.638 .36283 Mdot
.638 .36318 Mdot
.638 .3638 Mdot
.638 .36414 Mdot
.638 .36461 Mdot
.638 .3655 Mdot
.638 .36574 Mdot
.638 .3681 Mdot
.638 .36985 Mdot
.638 .37033 Mdot
.638 .37046 Mdot
.638 .37095 Mdot
.638 .37116 Mdot
.638 .37174 Mdot
.638 .37257 Mdot
.638 .3729 Mdot
.638 .37392 Mdot
.638 .3745 Mdot
.638 .37668 Mdot
.638 .3777 Mdot
.638 .37777 Mdot
.638 .37995 Mdot
.638 .38009 Mdot
.638 .38038 Mdot
.638 .38059 Mdot
.638 .38064 Mdot
.638 .3807 Mdot
.638 .38108 Mdot
.638 .38117 Mdot
.638 .38196 Mdot
.638 .38219 Mdot
.638 .38245 Mdot
.638 .38291 Mdot
.638 .38301 Mdot
.638 .38359 Mdot
.638 .38392 Mdot
.638 .38395 Mdot
.638 .38396 Mdot
.638 .38413 Mdot
.638 .38415 Mdot
.638 .3855 Mdot
.638 .38576 Mdot
.638 .38578 Mdot
.638 .38588 Mdot
.638 .38598 Mdot
.638 .3871 Mdot
.638 .38716 Mdot
.638 .38728 Mdot
.638 .38733 Mdot
.638 .38865 Mdot
.638 .38913 Mdot
.638 .38922 Mdot
.638 .38951 Mdot
.638 .38956 Mdot
.638 .38967 Mdot
.638 .3897 Mdot
.638 .38974 Mdot
.638 .39111 Mdot
.638 .39199 Mdot
.638 .3923 Mdot
.638 .39295 Mdot
.638 .39316 Mdot
.638 .39361 Mdot
.638 .39381 Mdot
.638 .39392 Mdot
.638 .39416 Mdot
.638 .39429 Mdot
.638 .3945 Mdot
.638 .39542 Mdot
.638 .39554 Mdot
.638 .39607 Mdot
.638 .39625 Mdot
.638 .39652 Mdot
.638 .39657 Mdot
.638 .39692 Mdot
.638 .39696 Mdot
.638 .39721 Mdot
.638 .39723 Mdot
.638 .39729 Mdot
.638 .39969 Mdot
.638 .40118 Mdot
.638 .40134 Mdot
.638 .40182 Mdot
.638 .40291 Mdot
.638 .40327 Mdot
.638 .40353 Mdot
.638 .40358 Mdot
.638 .40375 Mdot
.638 .40472 Mdot
.638 .40552 Mdot
.638 .40618 Mdot
.638 .40666 Mdot
.638 .40776 Mdot
.638 .40781 Mdot
.638 .40787 Mdot
.638 .40829 Mdot
.638 .40893 Mdot
.638 .40898 Mdot
.638 .40986 Mdot
.638 .41024 Mdot
.638 .41026 Mdot
.638 .41044 Mdot
.638 .41054 Mdot
.638 .4108 Mdot
.638 .4109 Mdot
.638 .41111 Mdot
.638 .41131 Mdot
.638 .41133 Mdot
.638 .41195 Mdot
.638 .41211 Mdot
.638 .41303 Mdot
.638 .41334 Mdot
.638 .41377 Mdot
.638 .41403 Mdot
.638 .41463 Mdot
.638 .41617 Mdot
.638 .41741 Mdot
.638 .41774 Mdot
.638 .41786 Mdot
.638 .41806 Mdot
.638 .41817 Mdot
.638 .41946 Mdot
.638 .42039 Mdot
.638 .42046 Mdot
.638 .42065 Mdot
.638 .42154 Mdot
.638 .42225 Mdot
.638 .42258 Mdot
.638 .42331 Mdot
.638 .42336 Mdot
.638 .42346 Mdot
.638 .42354 Mdot
.638 .42368 Mdot
.638 .42371 Mdot
.638 .42397 Mdot
.638 .42404 Mdot
.638 .42413 Mdot
.638 .42428 Mdot
.638 .42431 Mdot
.638 .42462 Mdot
.638 .42462 Mdot
.638 .42467 Mdot
.638 .42512 Mdot
.638 .4252 Mdot
.638 .42521 Mdot
.638 .42524 Mdot
.638 .42528 Mdot
.638 .42564 Mdot
.638 .42566 Mdot
.638 .4257 Mdot
.638 .42571 Mdot
.638 .4263 Mdot
.638 .42633 Mdot
.638 .42642 Mdot
.638 .42644 Mdot
.638 .42647 Mdot
.638 .42694 Mdot
.638 .42723 Mdot
.638 .42733 Mdot
.638 .42782 Mdot
.638 .42786 Mdot
.638 .42794 Mdot
.638 .42805 Mdot
.638 .42835 Mdot
.638 .42856 Mdot
.638 .42862 Mdot
.638 .42872 Mdot
.638 .42883 Mdot
.638 .42885 Mdot
.638 .42894 Mdot
.638 .42895 Mdot
.638 .42974 Mdot
.638 .43028 Mdot
.638 .43043 Mdot
.638 .43079 Mdot
.638 .43099 Mdot
.638 .43101 Mdot
.638 .43106 Mdot
.638 .43138 Mdot
.638 .43164 Mdot
.638 .43186 Mdot
.638 .43201 Mdot
.638 .43237 Mdot
.638 .43239 Mdot
.638 .43241 Mdot
.638 .43277 Mdot
.638 .43306 Mdot
.638 .43319 Mdot
.638 .43328 Mdot
.638 .4334 Mdot
.638 .43354 Mdot
.638 .43375 Mdot
.638 .4338 Mdot
.638 .4341 Mdot
.638 .4342 Mdot
.638 .43443 Mdot
.638 .43463 Mdot
.638 .43565 Mdot
.638 .43569 Mdot
.638 .43579 Mdot
.638 .43622 Mdot
.638 .43655 Mdot
.638 .43661 Mdot
.638 .43714 Mdot
.638 .43815 Mdot
.638 .43853 Mdot
.638 .43907 Mdot
.638 .43926 Mdot
.638 .43937 Mdot
.638 .43987 Mdot
.638 .43999 Mdot
.638 .44005 Mdot
.638 .44034 Mdot
.638 .44075 Mdot
.638 .44082 Mdot
.638 .44127 Mdot
.638 .44163 Mdot
.638 .44259 Mdot
.638 .44284 Mdot
.638 .44288 Mdot
.638 .44304 Mdot
.638 .44311 Mdot
.638 .44337 Mdot
.638 .44364 Mdot
.638 .44412 Mdot
.638 .44564 Mdot
.638 .44573 Mdot
.638 .44576 Mdot
.638 .44645 Mdot
.638 .44692 Mdot
.638 .44736 Mdot
.638 .4474 Mdot
.638 .44747 Mdot
.638 .44775 Mdot
.638 .44782 Mdot
.638 .44823 Mdot
.638 .44902 Mdot
.638 .44932 Mdot
.638 .44984 Mdot
.638 .44986 Mdot
.638 .45044 Mdot
.638 .45055 Mdot
.638 .45073 Mdot
.638 .4509 Mdot
.638 .45119 Mdot
.638 .45132 Mdot
.638 .45148 Mdot
.638 .4517 Mdot
.638 .45198 Mdot
.638 .45246 Mdot
.638 .45258 Mdot
.638 .45277 Mdot
.638 .45316 Mdot
.638 .45359 Mdot
.638 .45365 Mdot
.638 .45377 Mdot
.638 .45408 Mdot
.638 .45419 Mdot
.638 .45496 Mdot
.638 .45535 Mdot
.638 .45559 Mdot
.638 .45611 Mdot
.638 .45644 Mdot
.638 .45657 Mdot
.638 .45704 Mdot
.638 .45722 Mdot
.638 .4576 Mdot
.638 .45807 Mdot
.638 .45818 Mdot
.638 .45821 Mdot
.638 .45871 Mdot
.638 .45939 Mdot
.638 .45945 Mdot
.638 .45955 Mdot
.638 .45961 Mdot
.638 .45979 Mdot
.638 .46044 Mdot
.638 .46124 Mdot
.638 .46155 Mdot
.638 .46169 Mdot
.638 .46191 Mdot
.638 .46208 Mdot
.638 .46255 Mdot
.638 .46263 Mdot
.638 .46295 Mdot
.638 .46296 Mdot
.638 .46307 Mdot
.638 .46317 Mdot
.638 .46323 Mdot
.638 .46336 Mdot
.638 .46341 Mdot
.638 .4635 Mdot
.638 .46351 Mdot
.638 .46371 Mdot
.638 .46416 Mdot
.638 .46419 Mdot
.638 .46451 Mdot
.638 .46472 Mdot
.638 .46475 Mdot
.638 .46478 Mdot
.638 .46534 Mdot
.638 .46558 Mdot
.638 .46592 Mdot
.638 .46632 Mdot
.638 .46681 Mdot
.638 .4669 Mdot
.638 .46692 Mdot
.638 .46705 Mdot
.638 .46723 Mdot
.638 .46778 Mdot
.638 .46801 Mdot
.638 .4681 Mdot
.638 .46884 Mdot
.638 .47002 Mdot
.638 .47005 Mdot
.638 .47006 Mdot
.638 .47019 Mdot
.638 .47021 Mdot
.638 .47038 Mdot
.638 .4704 Mdot
.638 .47053 Mdot
.638 .47062 Mdot
.638 .47089 Mdot
.638 .47094 Mdot
.638 .47139 Mdot
.638 .4715 Mdot
.638 .47156 Mdot
.638 .47168 Mdot
.638 .47173 Mdot
.638 .47183 Mdot
.638 .47205 Mdot
.638 .47215 Mdot
.638 .47246 Mdot
.638 .47262 Mdot
.638 .47304 Mdot
.638 .4737 Mdot
.638 .47372 Mdot
.638 .47374 Mdot
.638 .47379 Mdot
.638 .47381 Mdot
.638 .47395 Mdot
.638 .474 Mdot
.638 .47423 Mdot
.638 .47486 Mdot
.638 .47488 Mdot
.638 .47494 Mdot
.638 .47497 Mdot
.638 .4755 Mdot
.638 .47555 Mdot
.638 .4756 Mdot
.638 .47561 Mdot
.638 .47573 Mdot
.638 .47637 Mdot
.638 .47638 Mdot
.638 .47646 Mdot
.638 .47647 Mdot
.638 .47648 Mdot
.638 .47664 Mdot
.638 .47691 Mdot
.638 .47696 Mdot
.638 .47718 Mdot
.638 .4773 Mdot
.638 .4774 Mdot
.638 .47778 Mdot
.638 .47782 Mdot
.638 .47803 Mdot
.638 .47805 Mdot
.638 .47815 Mdot
.638 .47829 Mdot
.638 .47835 Mdot
.638 .47937 Mdot
.638 .4794 Mdot
.638 .47988 Mdot
.638 .48088 Mdot
.638 .48115 Mdot
.638 .48162 Mdot
.638 .48177 Mdot
.638 .48215 Mdot
.638 .48242 Mdot
.638 .48251 Mdot
.638 .48274 Mdot
.638 .4828 Mdot
.638 .48302 Mdot
.638 .48382 Mdot
.638 .48488 Mdot
.638 .48499 Mdot
.638 .48539 Mdot
.638 .4856 Mdot
.638 .48575 Mdot
.638 .48603 Mdot
.638 .48619 Mdot
.638 .48664 Mdot
.638 .48769 Mdot
.638 .48833 Mdot
.638 .4884 Mdot
.638 .48903 Mdot
.638 .49039 Mdot
.638 .49119 Mdot
.638 .49153 Mdot
.638 .49178 Mdot
.638 .4921 Mdot
.638 .49251 Mdot
.638 .49261 Mdot
.638 .49332 Mdot
.638 .49371 Mdot
.638 .49392 Mdot
.638 .49465 Mdot
.638 .49472 Mdot
.638 .49475 Mdot
.638 .49501 Mdot
.638 .49526 Mdot
.638 .4954 Mdot
.638 .49547 Mdot
.638 .49573 Mdot
.638 .49586 Mdot
.638 .49598 Mdot
.638 .49608 Mdot
.638 .49611 Mdot
.638 .49635 Mdot
.638 .4966 Mdot
.638 .49771 Mdot
.638 .49778 Mdot
.638 .49857 Mdot
.638 .4991 Mdot
.638 .49917 Mdot
.638 .49924 Mdot
.638 .49938 Mdot
.638 .49973 Mdot
.638 .49987 Mdot
.638 .50061 Mdot
.638 .50119 Mdot
.638 .50199 Mdot
.638 .50211 Mdot
.638 .50247 Mdot
.638 .50275 Mdot
.638 .50297 Mdot
.638 .50396 Mdot
.638 .50414 Mdot
.638 .50434 Mdot
.638 .50439 Mdot
.638 .5047 Mdot
.638 .50513 Mdot
.638 .50524 Mdot
.638 .50565 Mdot
.638 .50642 Mdot
.638 .50647 Mdot
.638 .50647 Mdot
.638 .50697 Mdot
.638 .50716 Mdot
.638 .50758 Mdot
.638 .50839 Mdot
.638 .50888 Mdot
.638 .50981 Mdot
.638 .51058 Mdot
.638 .51084 Mdot
.638 .51158 Mdot
.638 .51165 Mdot
.638 .51165 Mdot
.638 .51168 Mdot
.638 .51195 Mdot
.638 .51199 Mdot
.638 .51239 Mdot
.638 .51244 Mdot
.638 .51273 Mdot
.638 .51293 Mdot
.638 .51352 Mdot
.638 .51364 Mdot
.638 .51368 Mdot
.638 .51423 Mdot
.638 .51451 Mdot
.638 .51464 Mdot
.638 .51487 Mdot
.638 .51501 Mdot
.638 .51527 Mdot
.638 .51538 Mdot
.638 .51559 Mdot
.638 .51607 Mdot
.638 .51629 Mdot
.638 .51698 Mdot
.638 .51731 Mdot
.638 .51822 Mdot
.638 .5186 Mdot
.638 .51896 Mdot
.638 .51948 Mdot
.638 .51963 Mdot
.638 .51966 Mdot
.638 .5197 Mdot
.638 .51981 Mdot
.638 .51986 Mdot
.638 .52015 Mdot
.638 .52025 Mdot
.638 .52073 Mdot
.638 .52204 Mdot
.638 .52209 Mdot
.638 .52221 Mdot
.638 .52227 Mdot
.638 .52328 Mdot
.638 .52336 Mdot
.638 .52347 Mdot
.638 .52352 Mdot
.638 .52356 Mdot
.638 .52357 Mdot
.638 .52383 Mdot
.638 .52429 Mdot
.638 .52431 Mdot
.638 .52512 Mdot
.638 .52514 Mdot
.638 .5253 Mdot
.638 .5253 Mdot
.638 .52534 Mdot
.638 .52563 Mdot
.638 .52565 Mdot
.638 .52608 Mdot
.638 .52619 Mdot
.638 .52629 Mdot
.638 .52671 Mdot
.638 .52695 Mdot
.638 .52716 Mdot
.638 .52729 Mdot
.638 .52789 Mdot
.638 .52797 Mdot
.638 .52831 Mdot
.638 .52837 Mdot
.638 .52841 Mdot
.638 .5286 Mdot
.638 .52886 Mdot
.638 .52899 Mdot
.638 .52899 Mdot
.638 .52967 Mdot
.638 .53025 Mdot
.638 .53091 Mdot
.638 .53097 Mdot
.638 .53171 Mdot
.638 .53184 Mdot
.638 .53286 Mdot
.638 .53367 Mdot
.638 .53415 Mdot
.638 .53474 Mdot
.638 .53497 Mdot
.638 .53524 Mdot
.638 .5359 Mdot
.638 .53636 Mdot
.638 .53652 Mdot
.638 .53701 Mdot
.638 .53702 Mdot
.638 .53729 Mdot
.638 .53738 Mdot
.638 .5387 Mdot
.638 .53888 Mdot
.638 .539 Mdot
.638 .54033 Mdot
.638 .54042 Mdot
.638 .54059 Mdot
.638 .54122 Mdot
.638 .54147 Mdot
.638 .54155 Mdot
.638 .54179 Mdot
.638 .54221 Mdot
.638 .54245 Mdot
.638 .54277 Mdot
.638 .54277 Mdot
.638 .54301 Mdot
.638 .54313 Mdot
.638 .54349 Mdot
.638 .54383 Mdot
.638 .54391 Mdot
.638 .54401 Mdot
.638 .54462 Mdot
.638 .54466 Mdot
.638 .54476 Mdot
.638 .54557 Mdot
.638 .54566 Mdot
.638 .5458 Mdot
.638 .54601 Mdot
.638 .54635 Mdot
.638 .54653 Mdot
.638 .54675 Mdot
.638 .54743 Mdot
.638 .54759 Mdot
.638 .54776 Mdot
.638 .54832 Mdot
.638 .54842 Mdot
.638 .54844 Mdot
.638 .54889 Mdot
.638 .54894 Mdot
.638 .54895 Mdot
.638 .54918 Mdot
.638 .54922 Mdot
.638 .54932 Mdot
.638 .54974 Mdot
.638 .55004 Mdot
.638 .55036 Mdot
.638 .55039 Mdot
.638 .55042 Mdot
.638 .5509 Mdot
.638 .55101 Mdot
.638 .55102 Mdot
.638 .55136 Mdot
.638 .55138 Mdot
.638 .55143 Mdot
.638 .5515 Mdot
.638 .55163 Mdot
.638 .55174 Mdot
.638 .55181 Mdot
.638 .55223 Mdot
.638 .55246 Mdot
.638 .55299 Mdot
.638 .55306 Mdot
.638 .5532 Mdot
.638 .55322 Mdot
.638 .55326 Mdot
.638 .55329 Mdot
.638 .55331 Mdot
.638 .55358 Mdot
.638 .55383 Mdot
.638 .55396 Mdot
.638 .55403 Mdot
.638 .55428 Mdot
.638 .55441 Mdot
.638 .55452 Mdot
.638 .55461 Mdot
.638 .55464 Mdot
.638 .5547 Mdot
.638 .55485 Mdot
.638 .55508 Mdot
.638 .55519 Mdot
.638 .55528 Mdot
.638 .55557 Mdot
.638 .55561 Mdot
.638 .55572 Mdot
.638 .55575 Mdot
.638 .55579 Mdot
.638 .55592 Mdot
.638 .55603 Mdot
.638 .55608 Mdot
.638 .55639 Mdot
.638 .5567 Mdot
.638 .55671 Mdot
.638 .55701 Mdot
.638 .5571 Mdot
.638 .55715 Mdot
.638 .5572 Mdot
.638 .55729 Mdot
.638 .55754 Mdot
.638 .55763 Mdot
.638 .55771 Mdot
.638 .55794 Mdot
.638 .55811 Mdot
.638 .5584 Mdot
.638 .55846 Mdot
.638 .55853 Mdot
.638 .55882 Mdot
.638 .5589 Mdot
.638 .55893 Mdot
.638 .55896 Mdot
.638 .55899 Mdot
.638 .55913 Mdot
.638 .55914 Mdot
.638 .5592 Mdot
.638 .55927 Mdot
.638 .55931 Mdot
.638 .55937 Mdot
.638 .55938 Mdot
.638 .55951 Mdot
.638 .55974 Mdot
.638 .55976 Mdot
.638 .55978 Mdot
.638 .55981 Mdot
.638 .55984 Mdot
.638 .55991 Mdot
.638 .55993 Mdot
.638 .56002 Mdot
.638 .56004 Mdot
.638 .56009 Mdot
.638 .56017 Mdot
.638 .56017 Mdot
.638 .56019 Mdot
.638 .5602 Mdot
.638 .5603 Mdot
.638 .56031 Mdot
.638 .56031 Mdot
.638 .56038 Mdot
.638 .56038 Mdot
.638 .56038 Mdot
.638 .5604 Mdot
.638 .56047 Mdot
.638 .56048 Mdot
.638 .56048 Mdot
.638 .56054 Mdot
.638 .56057 Mdot
.638 .56058 Mdot
.638 .56059 Mdot
.638 .56064 Mdot
.638 .56067 Mdot
.638 .5607 Mdot
.638 .5607 Mdot
.64 .16071 Mdot
.64 .16073 Mdot
.64 .16077 Mdot
.64 .16079 Mdot
.64 .16094 Mdot
.64 .16103 Mdot
.64 .16115 Mdot
.64 .16116 Mdot
.64 .16136 Mdot
.64 .16138 Mdot
.64 .16142 Mdot
.64 .16144 Mdot
.64 .16165 Mdot
.64 .16166 Mdot
.64 .16184 Mdot
.64 .1619 Mdot
.64 .16192 Mdot
.64 .16206 Mdot
.64 .16212 Mdot
.64 .1622 Mdot
.64 .1623 Mdot
.64 .16271 Mdot
.64 .16272 Mdot
.64 .16281 Mdot
.64 .16293 Mdot
.64 .16316 Mdot
.64 .16344 Mdot
.64 .16363 Mdot
.64 .16381 Mdot
.64 .1639 Mdot
.64 .16396 Mdot
.64 .16474 Mdot
.64 .16521 Mdot
.64 .16533 Mdot
.64 .16547 Mdot
.64 .1662 Mdot
.64 .16625 Mdot
.64 .16638 Mdot
.64 .16694 Mdot
.64 .16699 Mdot
.64 .167 Mdot
.64 .16757 Mdot
.64 .16828 Mdot
.64 .16872 Mdot
.64 .16978 Mdot
.64 .17028 Mdot
.64 .17071 Mdot
.64 .171 Mdot
.64 .17105 Mdot
.64 .17107 Mdot
.64 .17113 Mdot
.64 .17209 Mdot
.64 .17309 Mdot
.64 .17425 Mdot
.64 .17431 Mdot
.64 .17465 Mdot
.64 .17483 Mdot
.64 .17493 Mdot
.64 .17494 Mdot
.64 .17521 Mdot
.64 .1754 Mdot
.64 .17561 Mdot
.64 .17638 Mdot
.64 .1769 Mdot
.64 .17691 Mdot
.64 .17703 Mdot
.64 .17825 Mdot
.64 .17828 Mdot
.64 .17893 Mdot
.64 .1794 Mdot
.64 .17974 Mdot
.64 .18008 Mdot
.64 .18044 Mdot
.64 .181 Mdot
.64 .18103 Mdot
.64 .1814 Mdot
.64 .18278 Mdot
.64 .183 Mdot
.64 .18301 Mdot
.64 .18377 Mdot
.64 .18412 Mdot
.64 .18488 Mdot
.64 .18517 Mdot
.64 .18563 Mdot
.64 .18701 Mdot
.64 .1873 Mdot
.64 .18752 Mdot
.64 .18894 Mdot
.64 .1891 Mdot
.64 .19118 Mdot
.64 .19149 Mdot
.64 .1919 Mdot
.64 .19208 Mdot
.64 .19279 Mdot
.64 .19383 Mdot
.64 .19413 Mdot
.64 .19524 Mdot
.64 .19591 Mdot
.64 .19667 Mdot
.64 .19669 Mdot
.64 .19736 Mdot
.64 .19792 Mdot
.64 .19901 Mdot
.64 .19968 Mdot
.64 .20033 Mdot
.64 .20042 Mdot
.64 .20094 Mdot
.64 .20094 Mdot
.64 .20099 Mdot
.64 .20149 Mdot
.64 .20154 Mdot
.64 .20283 Mdot
.64 .20294 Mdot
.64 .20306 Mdot
.64 .20377 Mdot
.64 .20406 Mdot
.64 .20457 Mdot
.64 .20485 Mdot
.64 .20768 Mdot
.64 .20777 Mdot
.64 .20809 Mdot
.64 .20864 Mdot
.64 .20894 Mdot
.64 .20918 Mdot
.64 .21184 Mdot
.64 .2121 Mdot
.64 .21211 Mdot
.64 .21303 Mdot
.64 .21383 Mdot
.64 .21389 Mdot
.64 .21436 Mdot
.64 .2151 Mdot
.64 .21519 Mdot
.64 .21526 Mdot
.64 .21557 Mdot
.64 .21578 Mdot
.64 .21608 Mdot
.64 .2161 Mdot
.64 .21744 Mdot
.64 .21984 Mdot
.64 .22168 Mdot
.64 .22185 Mdot
.64 .22226 Mdot
.64 .2241 Mdot
.64 .22525 Mdot
.64 .22572 Mdot
.64 .22622 Mdot
.64 .22624 Mdot
.64 .22666 Mdot
.64 .2277 Mdot
.64 .22836 Mdot
.64 .23134 Mdot
.64 .23308 Mdot
.64 .23376 Mdot
.64 .23405 Mdot
.64 .2343 Mdot
.64 .23474 Mdot
.64 .23519 Mdot
.64 .23555 Mdot
.64 .23734 Mdot
.64 .23776 Mdot
.64 .23778 Mdot
.64 .23995 Mdot
.64 .24004 Mdot
.64 .24148 Mdot
.64 .24212 Mdot
.64 .24279 Mdot
.64 .24376 Mdot
.64 .24536 Mdot
.64 .24555 Mdot
.64 .24634 Mdot
.64 .2467 Mdot
.64 .24689 Mdot
.64 .24713 Mdot
.64 .24744 Mdot
.64 .24958 Mdot
.64 .25037 Mdot
.64 .25056 Mdot
.64 .25057 Mdot
.64 .25081 Mdot
.64 .25245 Mdot
.64 .25273 Mdot
.64 .25547 Mdot
.64 .25548 Mdot
.64 .25573 Mdot
.64 .25592 Mdot
.64 .25597 Mdot
.64 .25635 Mdot
.64 .25658 Mdot
.64 .25703 Mdot
.64 .25904 Mdot
.64 .25963 Mdot
.64 .2598 Mdot
.64 .2614 Mdot
.64 .26155 Mdot
.64 .2624 Mdot
.64 .26247 Mdot
.64 .26253 Mdot
.64 .2633 Mdot
.64 .26359 Mdot
.64 .26361 Mdot
.64 .26392 Mdot
.64 .26475 Mdot
.64 .2654 Mdot
.64 .26573 Mdot
.64 .26614 Mdot
.64 .26662 Mdot
.64 .26773 Mdot
.64 .26792 Mdot
.64 .26916 Mdot
.64 .26963 Mdot
.64 .27212 Mdot
.64 .27247 Mdot
.64 .27541 Mdot
.64 .27542 Mdot
.64 .27558 Mdot
.64 .27696 Mdot
.64 .27698 Mdot
.64 .27773 Mdot
.64 .27868 Mdot
.64 .28032 Mdot
.64 .28043 Mdot
.64 .28043 Mdot
.64 .28161 Mdot
.64 .28224 Mdot
.64 .28235 Mdot
.64 .28284 Mdot
.64 .2829 Mdot
.64 .28509 Mdot
.64 .28622 Mdot
.64 .28627 Mdot
.64 .28659 Mdot
.64 .28767 Mdot
.64 .28896 Mdot
.64 .28953 Mdot
.64 .29134 Mdot
.64 .29215 Mdot
.64 .29234 Mdot
.64 .29243 Mdot
.64 .29379 Mdot
.64 .2948 Mdot
.64 .29692 Mdot
.64 .29732 Mdot
.64 .29847 Mdot
.64 .29896 Mdot
.64 .30076 Mdot
.64 .30214 Mdot
.64 .3042 Mdot
.64 .3043 Mdot
.64 .30721 Mdot
.64 .30964 Mdot
.64 .31031 Mdot
.64 .3111 Mdot
.64 .31249 Mdot
.64 .31307 Mdot
.64 .31475 Mdot
.64 .31483 Mdot
.64 .31501 Mdot
.64 .31508 Mdot
.64 .31594 Mdot
.64 .31655 Mdot
.64 .31675 Mdot
.64 .31682 Mdot
.64 .31745 Mdot
.64 .31767 Mdot
.64 .31794 Mdot
.64 .31904 Mdot
.64 .3193 Mdot
.64 .32011 Mdot
.64 .32148 Mdot
.64 .32166 Mdot
.64 .32179 Mdot
.64 .32404 Mdot
.64 .32447 Mdot
.64 .32676 Mdot
.64 .32678 Mdot
.64 .32757 Mdot
.64 .33095 Mdot
.64 .33184 Mdot
.64 .33191 Mdot
.64 .33398 Mdot
.64 .33552 Mdot
.64 .3358 Mdot
.64 .33605 Mdot
.64 .33622 Mdot
.64 .33713 Mdot
.64 .33878 Mdot
.64 .3388 Mdot
.64 .33975 Mdot
.64 .34003 Mdot
.64 .3406 Mdot
.64 .34137 Mdot
.64 .3432 Mdot
.64 .34346 Mdot
.64 .34402 Mdot
.64 .34424 Mdot
.64 .34457 Mdot
.64 .34576 Mdot
.64 .3469 Mdot
.64 .34701 Mdot
.64 .34861 Mdot
.64 .34899 Mdot
.64 .34945 Mdot
.64 .351 Mdot
.64 .35188 Mdot
.64 .35368 Mdot
.64 .35406 Mdot
.64 .35442 Mdot
.64 .35476 Mdot
.64 .35603 Mdot
.64 .3562 Mdot
.64 .35819 Mdot
.64 .3587 Mdot
.64 .35886 Mdot
.64 .36039 Mdot
.64 .36053 Mdot
.64 .36053 Mdot
.64 .36142 Mdot
.64 .36215 Mdot
.64 .36241 Mdot
.64 .36324 Mdot
.64 .36442 Mdot
.64 .36539 Mdot
.64 .36646 Mdot
.64 .36701 Mdot
.64 .36815 Mdot
.64 .36981 Mdot
.64 .37103 Mdot
.64 .37153 Mdot
.64 .37266 Mdot
.64 .37362 Mdot
.64 .37365 Mdot
.64 .37454 Mdot
.64 .37483 Mdot
.64 .376 Mdot
.64 .37633 Mdot
.64 .37648 Mdot
.64 .37666 Mdot
.64 .37679 Mdot
.64 .37767 Mdot
.64 .37807 Mdot
.64 .37818 Mdot
.64 .37885 Mdot
.64 .37896 Mdot
.64 .38007 Mdot
.64 .38007 Mdot
.64 .38017 Mdot
.64 .38042 Mdot
.64 .38051 Mdot
.64 .38149 Mdot
.64 .38173 Mdot
.64 .38179 Mdot
.64 .38242 Mdot
.64 .38282 Mdot
.64 .38287 Mdot
.64 .38317 Mdot
.64 .38328 Mdot
.64 .38341 Mdot
.64 .38411 Mdot
.64 .38446 Mdot
.64 .38488 Mdot
.64 .38543 Mdot
.64 .38561 Mdot
.64 .38656 Mdot
.64 .3878 Mdot
.64 .3878 Mdot
.64 .38786 Mdot
.64 .38838 Mdot
.64 .38839 Mdot
.64 .38867 Mdot
.64 .38902 Mdot
.64 .38963 Mdot
.64 .38967 Mdot
.64 .3901 Mdot
.64 .39037 Mdot
.64 .39055 Mdot
.64 .39058 Mdot
.64 .39193 Mdot
.64 .39299 Mdot
.64 .39364 Mdot
.64 .394 Mdot
.64 .39403 Mdot
.64 .39452 Mdot
.64 .39488 Mdot
.64 .39563 Mdot
.64 .39699 Mdot
.64 .39747 Mdot
.64 .39823 Mdot
.64 .39924 Mdot
.64 .40009 Mdot
.64 .40032 Mdot
.64 .40107 Mdot
.64 .40127 Mdot
.64 .40185 Mdot
.64 .40187 Mdot
.64 .40253 Mdot
.64 .40255 Mdot
.64 .40331 Mdot
.64 .4034 Mdot
.64 .40424 Mdot
.64 .40515 Mdot
.64 .40733 Mdot
.64 .40763 Mdot
.64 .40765 Mdot
.64 .40834 Mdot
.64 .40895 Mdot
.64 .40903 Mdot
.64 .40994 Mdot
.64 .41054 Mdot
.64 .4108 Mdot
.64 .4114 Mdot
.64 .41149 Mdot
.64 .41167 Mdot
.64 .41175 Mdot
.64 .41186 Mdot
.64 .41225 Mdot
.64 .41262 Mdot
.64 .41266 Mdot
.64 .41331 Mdot
.64 .41485 Mdot
.64 .41562 Mdot
.64 .41567 Mdot
.64 .41632 Mdot
.64 .41738 Mdot
.64 .41797 Mdot
.64 .41867 Mdot
.64 .4192 Mdot
.64 .41957 Mdot
.64 .42051 Mdot
.64 .42104 Mdot
.64 .42165 Mdot
.64 .42174 Mdot
.64 .42223 Mdot
.64 .42228 Mdot
.64 .42233 Mdot
.64 .42238 Mdot
.64 .42266 Mdot
.64 .42283 Mdot
.64 .42304 Mdot
.64 .42308 Mdot
.64 .42344 Mdot
.64 .42344 Mdot
.64 .42348 Mdot
.64 .42356 Mdot
.64 .42359 Mdot
.64 .42398 Mdot
.64 .424 Mdot
.64 .42433 Mdot
.64 .42435 Mdot
.64 .42445 Mdot
.64 .42448 Mdot
.64 .42452 Mdot
.64 .42475 Mdot
.64 .42486 Mdot
.64 .425 Mdot
.64 .42518 Mdot
.64 .42555 Mdot
.64 .42595 Mdot
.64 .42597 Mdot
.64 .42614 Mdot
.64 .42623 Mdot
.64 .42634 Mdot
.64 .42656 Mdot
.64 .4267 Mdot
.64 .42678 Mdot
.64 .42684 Mdot
.64 .42729 Mdot
.64 .42763 Mdot
.64 .42784 Mdot
.64 .42796 Mdot
.64 .42797 Mdot
.64 .42813 Mdot
.64 .42825 Mdot
.64 .42849 Mdot
.64 .42934 Mdot
.64 .42967 Mdot
.64 .42994 Mdot
.64 .43002 Mdot
.64 .43026 Mdot
.64 .43033 Mdot
.64 .43052 Mdot
.64 .43074 Mdot
.64 .43099 Mdot
.64 .43129 Mdot
.64 .43159 Mdot
.64 .4323 Mdot
.64 .43241 Mdot
.64 .43263 Mdot
.64 .43283 Mdot
.64 .43335 Mdot
.64 .43344 Mdot
.64 .43363 Mdot
.64 .43366 Mdot
.64 .43372 Mdot
.64 .43375 Mdot
.64 .43378 Mdot
.64 .43403 Mdot
.64 .43405 Mdot
.64 .43477 Mdot
.64 .4356 Mdot
.64 .43579 Mdot
.64 .43602 Mdot
.64 .4362 Mdot
.64 .43632 Mdot
.64 .4368 Mdot
.64 .4379 Mdot
.64 .43852 Mdot
.64 .43868 Mdot
.64 .43873 Mdot
.64 .43906 Mdot
.64 .43927 Mdot
.64 .43956 Mdot
.64 .43986 Mdot
.64 .43989 Mdot
.64 .44021 Mdot
.64 .44031 Mdot
.64 .44072 Mdot
.64 .44081 Mdot
.64 .4409 Mdot
.64 .44093 Mdot
.64 .44104 Mdot
.64 .44172 Mdot
.64 .44185 Mdot
.64 .44189 Mdot
.64 .44271 Mdot
.64 .44376 Mdot
.64 .44441 Mdot
.64 .44533 Mdot
.64 .44641 Mdot
.64 .44643 Mdot
.64 .44651 Mdot
.64 .44708 Mdot
.64 .44738 Mdot
.64 .44756 Mdot
.64 .44758 Mdot
.64 .44804 Mdot
.64 .44823 Mdot
.64 .44834 Mdot
.64 .4487 Mdot
.64 .44959 Mdot
.64 .44966 Mdot
.64 .44989 Mdot
.64 .45 Mdot
.64 .45087 Mdot
.64 .45087 Mdot
.64 .45101 Mdot
.64 .45108 Mdot
.64 .45121 Mdot
.64 .45125 Mdot
.64 .45139 Mdot
.64 .45154 Mdot
.64 .45223 Mdot
.64 .4524 Mdot
.64 .45293 Mdot
.64 .45297 Mdot
.64 .4531 Mdot
.64 .45314 Mdot
.64 .45347 Mdot
.64 .45394 Mdot
.64 .45422 Mdot
.64 .45429 Mdot
.64 .45484 Mdot
.64 .45492 Mdot
.64 .45499 Mdot
.64 .45517 Mdot
.64 .45554 Mdot
.64 .45609 Mdot
.64 .45619 Mdot
.64 .45667 Mdot
.64 .45758 Mdot
.64 .45763 Mdot
.64 .45796 Mdot
.64 .45824 Mdot
.64 .45874 Mdot
.64 .45894 Mdot
.64 .45921 Mdot
.64 .45958 Mdot
.64 .45989 Mdot
.64 .46045 Mdot
.64 .46079 Mdot
.64 .46082 Mdot
.64 .46122 Mdot
.64 .46202 Mdot
.64 .46235 Mdot
.64 .46237 Mdot
.64 .46257 Mdot
.64 .46277 Mdot
.64 .46283 Mdot
.64 .46286 Mdot
.64 .46296 Mdot
.64 .463 Mdot
.64 .46331 Mdot
.64 .46345 Mdot
.64 .46376 Mdot
.64 .46422 Mdot
.64 .46426 Mdot
.64 .46457 Mdot
.64 .46492 Mdot
.64 .46494 Mdot
.64 .46509 Mdot
.64 .46619 Mdot
.64 .46665 Mdot
.64 .46707 Mdot
.64 .46711 Mdot
.64 .46749 Mdot
.64 .46751 Mdot
.64 .46783 Mdot
.64 .46785 Mdot
.64 .46814 Mdot
.64 .46824 Mdot
.64 .46861 Mdot
.64 .46872 Mdot
.64 .46914 Mdot
.64 .46964 Mdot
.64 .47001 Mdot
.64 .47025 Mdot
.64 .47092 Mdot
.64 .47129 Mdot
.64 .47146 Mdot
.64 .4717 Mdot
.64 .47172 Mdot
.64 .47189 Mdot
.64 .47221 Mdot
.64 .47272 Mdot
.64 .47338 Mdot
.64 .47339 Mdot
.64 .47347 Mdot
.64 .4736 Mdot
.64 .47381 Mdot
.64 .47383 Mdot
.64 .47413 Mdot
.64 .4743 Mdot
.64 .47443 Mdot
.64 .47443 Mdot
.64 .47468 Mdot
.64 .47471 Mdot
.64 .47471 Mdot
.64 .4753 Mdot
.64 .47575 Mdot
.64 .47584 Mdot
.64 .4761 Mdot
.64 .4763 Mdot
.64 .47646 Mdot
.64 .4768 Mdot
.64 .47686 Mdot
.64 .47691 Mdot
.64 .47705 Mdot
.64 .47708 Mdot
.64 .47726 Mdot
.64 .47756 Mdot
.64 .47759 Mdot
.64 .4777 Mdot
.64 .47816 Mdot
.64 .4782 Mdot
.64 .47832 Mdot
.64 .47837 Mdot
.64 .47837 Mdot
.64 .47889 Mdot
.64 .47894 Mdot
.64 .47925 Mdot
.64 .4793 Mdot
.64 .47949 Mdot
.64 .4799 Mdot
.64 .47996 Mdot
.64 .48004 Mdot
.64 .48011 Mdot
.64 .48026 Mdot
.64 .4808 Mdot
.64 .48094 Mdot
.64 .48135 Mdot
.64 .48136 Mdot
.64 .4818 Mdot
.64 .48232 Mdot
.64 .48255 Mdot
.64 .4831 Mdot
.64 .48386 Mdot
.64 .48438 Mdot
.64 .48462 Mdot
.64 .48511 Mdot
.64 .48555 Mdot
.64 .48607 Mdot
.64 .48645 Mdot
.64 .48656 Mdot
.64 .48689 Mdot
.64 .48728 Mdot
.64 .48728 Mdot
.64 .48734 Mdot
.64 .48802 Mdot
.64 .48809 Mdot
.64 .48832 Mdot
.64 .4892 Mdot
.64 .48927 Mdot
.64 .48983 Mdot
.64 .48998 Mdot
.64 .49013 Mdot
.64 .4903 Mdot
.64 .49109 Mdot
.64 .49147 Mdot
.64 .49214 Mdot
.64 .49234 Mdot
.64 .49251 Mdot
.64 .4932 Mdot
.64 .49324 Mdot
.64 .49373 Mdot
.64 .49424 Mdot
.64 .49439 Mdot
.64 .49448 Mdot
.64 .49472 Mdot
.64 .49483 Mdot
.64 .49561 Mdot
.64 .49594 Mdot
.64 .49618 Mdot
.64 .4963 Mdot
.64 .4967 Mdot
.64 .49671 Mdot
.64 .4974 Mdot
.64 .49778 Mdot
.64 .49785 Mdot
.64 .49796 Mdot
.64 .49808 Mdot
.64 .49873 Mdot
.64 .49959 Mdot
.64 .49962 Mdot
.64 .49999 Mdot
.64 .50138 Mdot
.64 .50171 Mdot
.64 .50172 Mdot
.64 .50266 Mdot
.64 .50283 Mdot
.64 .50375 Mdot
.64 .5038 Mdot
.64 .50388 Mdot
.64 .50443 Mdot
.64 .50476 Mdot
.64 .50487 Mdot
.64 .50531 Mdot
.64 .50542 Mdot
.64 .50551 Mdot
.64 .50577 Mdot
.64 .50579 Mdot
.64 .50587 Mdot
.64 .50612 Mdot
.64 .50646 Mdot
.64 .50649 Mdot
.64 .50657 Mdot
.64 .5066 Mdot
.64 .50727 Mdot
.64 .5075 Mdot
.64 .50805 Mdot
.64 .50837 Mdot
.64 .50864 Mdot
.64 .5096 Mdot
.64 .51075 Mdot
.64 .51079 Mdot
.64 .51159 Mdot
.64 .51213 Mdot
.64 .51283 Mdot
.64 .51302 Mdot
.64 .51347 Mdot
.64 .51363 Mdot
.64 .51445 Mdot
.64 .51484 Mdot
.64 .51536 Mdot
.64 .51539 Mdot
.64 .51547 Mdot
.64 .51578 Mdot
.64 .51647 Mdot
.64 .51669 Mdot
.64 .51718 Mdot
.64 .51759 Mdot
.64 .51771 Mdot
.64 .51773 Mdot
.64 .51816 Mdot
.64 .51899 Mdot
.64 .51901 Mdot
.64 .5192 Mdot
.64 .51924 Mdot
.64 .51947 Mdot
.64 .51992 Mdot
.64 .51992 Mdot
.64 .51996 Mdot
.64 .52058 Mdot
.64 .52093 Mdot
.64 .52121 Mdot
.64 .52122 Mdot
.64 .52173 Mdot
.64 .52179 Mdot
.64 .5218 Mdot
.64 .52289 Mdot
.64 .52302 Mdot
.64 .52394 Mdot
.64 .52411 Mdot
.64 .52457 Mdot
.64 .52464 Mdot
.64 .52505 Mdot
.64 .52522 Mdot
.64 .52537 Mdot
.64 .5255 Mdot
.64 .52574 Mdot
.64 .52604 Mdot
.64 .52615 Mdot
.64 .52616 Mdot
.64 .52626 Mdot
.64 .52654 Mdot
.64 .52657 Mdot
.64 .52659 Mdot
.64 .5269 Mdot
.64 .52696 Mdot
.64 .52754 Mdot
.64 .5276 Mdot
.64 .52781 Mdot
.64 .52854 Mdot
.64 .5287 Mdot
.64 .52879 Mdot
.64 .52892 Mdot
.64 .52894 Mdot
.64 .52901 Mdot
.64 .5291 Mdot
.64 .5291 Mdot
.64 .53009 Mdot
.64 .53019 Mdot
.64 .53078 Mdot
.64 .53086 Mdot
.64 .53086 Mdot
.64 .53093 Mdot
.64 .53121 Mdot
.64 .53198 Mdot
.64 .53209 Mdot
.64 .53217 Mdot
.64 .53224 Mdot
.64 .53237 Mdot
.64 .53265 Mdot
.64 .53271 Mdot
.64 .53328 Mdot
.64 .53362 Mdot
.64 .53386 Mdot
.64 .53409 Mdot
.64 .53459 Mdot
.64 .53462 Mdot
.64 .53538 Mdot
.64 .53539 Mdot
.64 .53554 Mdot
.64 .53617 Mdot
.64 .53629 Mdot
.64 .53645 Mdot
.64 .5366 Mdot
.64 .53669 Mdot
.64 .53679 Mdot
.64 .53703 Mdot
.64 .53763 Mdot
.64 .53866 Mdot
.64 .53889 Mdot
.64 .53925 Mdot
.64 .53939 Mdot
.64 .5394 Mdot
.64 .53957 Mdot
.64 .53973 Mdot
.64 .54013 Mdot
.64 .54076 Mdot
.64 .5409 Mdot
.64 .54096 Mdot
.64 .54158 Mdot
.64 .5424 Mdot
.64 .54286 Mdot
.64 .54286 Mdot
.64 .54296 Mdot
.64 .54303 Mdot
.64 .54314 Mdot
.64 .54316 Mdot
.64 .5432 Mdot
.64 .54345 Mdot
.64 .5436 Mdot
.64 .54362 Mdot
.64 .54389 Mdot
.64 .5442 Mdot
.64 .54421 Mdot
.64 .5443 Mdot
.64 .54519 Mdot
.64 .54527 Mdot
.64 .54537 Mdot
.64 .54556 Mdot
.64 .54566 Mdot
.64 .54569 Mdot
.64 .54664 Mdot
.64 .54673 Mdot
.64 .5469 Mdot
.64 .547 Mdot
.64 .54724 Mdot
.64 .54728 Mdot
.64 .54731 Mdot
.64 .54774 Mdot
.64 .54776 Mdot
.64 .54792 Mdot
.64 .54794 Mdot
.64 .54794 Mdot
.64 .54811 Mdot
.64 .54814 Mdot
.64 .54836 Mdot
.64 .54858 Mdot
.64 .54894 Mdot
.64 .54912 Mdot
.64 .54935 Mdot
.64 .54935 Mdot
.64 .5496 Mdot
.64 .54982 Mdot
.64 .55019 Mdot
.64 .55029 Mdot
.64 .55063 Mdot
.64 .55086 Mdot
.64 .55092 Mdot
.64 .55106 Mdot
.64 .55116 Mdot
.64 .55184 Mdot
.64 .55189 Mdot
.64 .55235 Mdot
.64 .55243 Mdot
.64 .55252 Mdot
.64 .55297 Mdot
.64 .55312 Mdot
.64 .55321 Mdot
.64 .55346 Mdot
.64 .55357 Mdot
.64 .55382 Mdot
.64 .55382 Mdot
.64 .55389 Mdot
.64 .55434 Mdot
.64 .55446 Mdot
.64 .55447 Mdot
.64 .55465 Mdot
.64 .55477 Mdot
.64 .55488 Mdot
.64 .55498 Mdot
.64 .55514 Mdot
.64 .55535 Mdot
.64 .55535 Mdot
.64 .55575 Mdot
.64 .55579 Mdot
.64 .55579 Mdot
.64 .55596 Mdot
.64 .5562 Mdot
.64 .55627 Mdot
.64 .55633 Mdot
.64 .55642 Mdot
.64 .55642 Mdot
.64 .55645 Mdot
.64 .55651 Mdot
.64 .55662 Mdot
.64 .55664 Mdot
.64 .55701 Mdot
.64 .55733 Mdot
.64 .55763 Mdot
.64 .55766 Mdot
.64 .55766 Mdot
.64 .55768 Mdot
.64 .55777 Mdot
.64 .55791 Mdot
.64 .55807 Mdot
.64 .5584 Mdot
.64 .55854 Mdot
.64 .55877 Mdot
.64 .55895 Mdot
.64 .55895 Mdot
.64 .55897 Mdot
.64 .55915 Mdot
.64 .55919 Mdot
.64 .5592 Mdot
.64 .55943 Mdot
.64 .55948 Mdot
.64 .55952 Mdot
.64 .55967 Mdot
.64 .55991 Mdot
.64 .55993 Mdot
.64 .55996 Mdot
.64 .56002 Mdot
.64 .56008 Mdot
.64 .56016 Mdot
.64 .56024 Mdot
.64 .56027 Mdot
.64 .5603 Mdot
.64 .56031 Mdot
.64 .56044 Mdot
.64 .56047 Mdot
.64 .56049 Mdot
.64 .56051 Mdot
.64 .56056 Mdot
.64 .56056 Mdot
.64 .56058 Mdot
.64 .56064 Mdot
.64 .56064 Mdot
.64 .56071 Mdot
.64 .56071 Mdot
.64 .56073 Mdot
.64 .56073 Mdot
.64 .56079 Mdot
.64 .5608 Mdot
.64 .56084 Mdot
.64 .56086 Mdot
.64 .56091 Mdot
.64 .56092 Mdot
.64 .56093 Mdot
.64 .56094 Mdot
.642 .16001 Mdot
.642 .16002 Mdot
.642 .16002 Mdot
.642 .16016 Mdot
.642 .1602 Mdot
.642 .1602 Mdot
.642 .16028 Mdot
.642 .16052 Mdot
.642 .16069 Mdot
.642 .16094 Mdot
.642 .16108 Mdot
.642 .16125 Mdot
.642 .16163 Mdot
.642 .16186 Mdot
.642 .16201 Mdot
.642 .16208 Mdot
.642 .16254 Mdot
.642 .16258 Mdot
.642 .16356 Mdot
.642 .16369 Mdot
.642 .16385 Mdot
.642 .16398 Mdot
.642 .16437 Mdot
.642 .16463 Mdot
.642 .16481 Mdot
.642 .16485 Mdot
.642 .16537 Mdot
.642 .16551 Mdot
.642 .16607 Mdot
.642 .16609 Mdot
.642 .1661 Mdot
.642 .16611 Mdot
.642 .1663 Mdot
.642 .16654 Mdot
.642 .1666 Mdot
.642 .16689 Mdot
.642 .16691 Mdot
.642 .16697 Mdot
.642 .16704 Mdot
.642 .16716 Mdot
.642 .16817 Mdot
.642 .1684 Mdot
.642 .16845 Mdot
.642 .16869 Mdot
.642 .16876 Mdot
.642 .16877 Mdot
.642 .16903 Mdot
.642 .16951 Mdot
.642 .17 Mdot
.642 .17068 Mdot
.642 .17077 Mdot
.642 .17087 Mdot
.642 .17183 Mdot
.642 .17323 Mdot
.642 .17325 Mdot
.642 .17342 Mdot
.642 .17385 Mdot
.642 .17397 Mdot
.642 .17438 Mdot
.642 .17586 Mdot
.642 .17619 Mdot
.642 .17693 Mdot
.642 .17712 Mdot
.642 .17725 Mdot
.642 .17751 Mdot
.642 .17755 Mdot
.642 .17842 Mdot
.642 .17892 Mdot
.642 .179 Mdot
.642 .17919 Mdot
.642 .18001 Mdot
.642 .18002 Mdot
.642 .18024 Mdot
.642 .18133 Mdot
.642 .18291 Mdot
.642 .18306 Mdot
.642 .18329 Mdot
.642 .18358 Mdot
.642 .18383 Mdot
.642 .18386 Mdot
.642 .18428 Mdot
.642 .18454 Mdot
.642 .18456 Mdot
.642 .18483 Mdot
.642 .18547 Mdot
.642 .18563 Mdot
.642 .18648 Mdot
.642 .18709 Mdot
.642 .18881 Mdot
.642 .18917 Mdot
.642 .18931 Mdot
.642 .19071 Mdot
.642 .19108 Mdot
.642 .19147 Mdot
.642 .19162 Mdot
.642 .19272 Mdot
.642 .19338 Mdot
.642 .19389 Mdot
.642 .19409 Mdot
.642 .1941 Mdot
.642 .1954 Mdot
.642 .196 Mdot
.642 .1971 Mdot
.642 .19761 Mdot
.642 .19798 Mdot
.642 .19811 Mdot
.642 .20005 Mdot
.642 .20075 Mdot
.642 .20138 Mdot
.642 .20145 Mdot
.642 .20212 Mdot
.642 .20326 Mdot
.642 .20329 Mdot
.642 .20421 Mdot
.642 .20617 Mdot
.642 .20731 Mdot
.642 .20754 Mdot
.642 .20799 Mdot
.642 .20838 Mdot
.642 .21018 Mdot
.642 .21043 Mdot
.642 .21168 Mdot
.642 .2117 Mdot
.642 .21185 Mdot
.642 .21208 Mdot
.642 .21209 Mdot
.642 .2121 Mdot
.642 .21533 Mdot
.642 .21629 Mdot
.642 .21709 Mdot
.642 .21818 Mdot
.642 .21908 Mdot
.642 .21928 Mdot
.642 .22156 Mdot
.642 .22319 Mdot
.642 .22334 Mdot
.642 .22376 Mdot
.642 .22414 Mdot
.642 .22454 Mdot
.642 .22742 Mdot
.642 .22756 Mdot
.642 .22889 Mdot
.642 .22904 Mdot
.642 .22976 Mdot
.642 .23021 Mdot
.642 .23059 Mdot
.642 .23096 Mdot
.642 .23227 Mdot
.642 .23237 Mdot
.642 .2325 Mdot
.642 .2331 Mdot
.642 .23311 Mdot
.642 .2352 Mdot
.642 .23583 Mdot
.642 .23702 Mdot
.642 .23707 Mdot
.642 .23707 Mdot
.642 .23808 Mdot
.642 .23895 Mdot
.642 .23927 Mdot
.642 .23945 Mdot
.642 .23953 Mdot
.642 .2406 Mdot
.642 .24067 Mdot
.642 .241 Mdot
.642 .24103 Mdot
.642 .24114 Mdot
.642 .24373 Mdot
.642 .24388 Mdot
.642 .24625 Mdot
.642 .24718 Mdot
.642 .24745 Mdot
.642 .24751 Mdot
.642 .24814 Mdot
.642 .24831 Mdot
.642 .24848 Mdot
.642 .24975 Mdot
.642 .25109 Mdot
.642 .25128 Mdot
.642 .25146 Mdot
.642 .25166 Mdot
.642 .25173 Mdot
.642 .25251 Mdot
.642 .25414 Mdot
.642 .25468 Mdot
.642 .2572 Mdot
.642 .25721 Mdot
.642 .25733 Mdot
.642 .25741 Mdot
.642 .25742 Mdot
.642 .25807 Mdot
.642 .2582 Mdot
.642 .2596 Mdot
.642 .25972 Mdot
.642 .26034 Mdot
.642 .26193 Mdot
.642 .26259 Mdot
.642 .26297 Mdot
.642 .26301 Mdot
.642 .26377 Mdot
.642 .26521 Mdot
.642 .26618 Mdot
.642 .26735 Mdot
.642 .26736 Mdot
.642 .26749 Mdot
.642 .26893 Mdot
.642 .26903 Mdot
.642 .26929 Mdot
.642 .26953 Mdot
.642 .27197 Mdot
.642 .273 Mdot
.642 .27312 Mdot
.642 .27379 Mdot
.642 .27398 Mdot
.642 .275 Mdot
.642 .27621 Mdot
.642 .27808 Mdot
.642 .27815 Mdot
.642 .27856 Mdot
.642 .27933 Mdot
.642 .28214 Mdot
.642 .28253 Mdot
.642 .28265 Mdot
.642 .28325 Mdot
.642 .2858 Mdot
.642 .28808 Mdot
.642 .28881 Mdot
.642 .29027 Mdot
.642 .29047 Mdot
.642 .29095 Mdot
.642 .29159 Mdot
.642 .29265 Mdot
.642 .29348 Mdot
.642 .29353 Mdot
.642 .29383 Mdot
.642 .29427 Mdot
.642 .29547 Mdot
.642 .29572 Mdot
.642 .29779 Mdot
.642 .29887 Mdot
.642 .29903 Mdot
.642 .29941 Mdot
.642 .30173 Mdot
.642 .30221 Mdot
.642 .3032 Mdot
.642 .30537 Mdot
.642 .30596 Mdot
.642 .306 Mdot
.642 .30856 Mdot
.642 .30889 Mdot
.642 .30947 Mdot
.642 .31171 Mdot
.642 .31405 Mdot
.642 .31688 Mdot
.642 .318 Mdot
.642 .32034 Mdot
.642 .32286 Mdot
.642 .32308 Mdot
.642 .3256 Mdot
.642 .32642 Mdot
.642 .32646 Mdot
.642 .32648 Mdot
.642 .32675 Mdot
.642 .32717 Mdot
.642 .3276 Mdot
.642 .32767 Mdot
.642 .32792 Mdot
.642 .32951 Mdot
.642 .32956 Mdot
.642 .32986 Mdot
.642 .32995 Mdot
.642 .33027 Mdot
.642 .33084 Mdot
.642 .33139 Mdot
.642 .33215 Mdot
.642 .33236 Mdot
.642 .33337 Mdot
.642 .33481 Mdot
.642 .33497 Mdot
.642 .33726 Mdot
.642 .33755 Mdot
.642 .3382 Mdot
.642 .33837 Mdot
.642 .33848 Mdot
.642 .33874 Mdot
.642 .34011 Mdot
.642 .34078 Mdot
.642 .34079 Mdot
.642 .34096 Mdot
.642 .34315 Mdot
.642 .34332 Mdot
.642 .34354 Mdot
.642 .34372 Mdot
.642 .34374 Mdot
.642 .34426 Mdot
.642 .34446 Mdot
.642 .34564 Mdot
.642 .34724 Mdot
.642 .34749 Mdot
.642 .34758 Mdot
.642 .34981 Mdot
.642 .35022 Mdot
.642 .35148 Mdot
.642 .35252 Mdot
.642 .35304 Mdot
.642 .35312 Mdot
.642 .35466 Mdot
.642 .35609 Mdot
.642 .35662 Mdot
.642 .35868 Mdot
.642 .35888 Mdot
.642 .36082 Mdot
.642 .36247 Mdot
.642 .36295 Mdot
.642 .36433 Mdot
.642 .36443 Mdot
.642 .36835 Mdot
.642 .36895 Mdot
.642 .36902 Mdot
.642 .36935 Mdot
.642 .37048 Mdot
.642 .37085 Mdot
.642 .37206 Mdot
.642 .37258 Mdot
.642 .3726 Mdot
.642 .3726 Mdot
.642 .37304 Mdot
.642 .37342 Mdot
.642 .37355 Mdot
.642 .37363 Mdot
.642 .37367 Mdot
.642 .37412 Mdot
.642 .3743 Mdot
.642 .37435 Mdot
.642 .37545 Mdot
.642 .37552 Mdot
.642 .37651 Mdot
.642 .37729 Mdot
.642 .37796 Mdot
.642 .37865 Mdot
.642 .37873 Mdot
.642 .37974 Mdot
.642 .38105 Mdot
.642 .38105 Mdot
.642 .38131 Mdot
.642 .38136 Mdot
.642 .38191 Mdot
.642 .38196 Mdot
.642 .38309 Mdot
.642 .38323 Mdot
.642 .38325 Mdot
.642 .38355 Mdot
.642 .3841 Mdot
.642 .38448 Mdot
.642 .38498 Mdot
.642 .38557 Mdot
.642 .38668 Mdot
.642 .38712 Mdot
.642 .38737 Mdot
.642 .38897 Mdot
.642 .38943 Mdot
.642 .39065 Mdot
.642 .39087 Mdot
.642 .3918 Mdot
.642 .39263 Mdot
.642 .39289 Mdot
.642 .39342 Mdot
.642 .39366 Mdot
.642 .39456 Mdot
.642 .39458 Mdot
.642 .39527 Mdot
.642 .39536 Mdot
.642 .39609 Mdot
.642 .39653 Mdot
.642 .39667 Mdot
.642 .39748 Mdot
.642 .39765 Mdot
.642 .39799 Mdot
.642 .39897 Mdot
.642 .39997 Mdot
.642 .40017 Mdot
.642 .40294 Mdot
.642 .40309 Mdot
.642 .40388 Mdot
.642 .40481 Mdot
.642 .40566 Mdot
.642 .40605 Mdot
.642 .40644 Mdot
.642 .40697 Mdot
.642 .40699 Mdot
.642 .40709 Mdot
.642 .40712 Mdot
.642 .40722 Mdot
.642 .40741 Mdot
.642 .40792 Mdot
.642 .40826 Mdot
.642 .40874 Mdot
.642 .40879 Mdot
.642 .40955 Mdot
.642 .40986 Mdot
.642 .40992 Mdot
.642 .40996 Mdot
.642 .41072 Mdot
.642 .41078 Mdot
.642 .4115 Mdot
.642 .41156 Mdot
.642 .41163 Mdot
.642 .41169 Mdot
.642 .4117 Mdot
.642 .41193 Mdot
.642 .41232 Mdot
.642 .41285 Mdot
.642 .41293 Mdot
.642 .41296 Mdot
.642 .41369 Mdot
.642 .41424 Mdot
.642 .41457 Mdot
.642 .41528 Mdot
.642 .41574 Mdot
.642 .41782 Mdot
.642 .41843 Mdot
.642 .41846 Mdot
.642 .41973 Mdot
.642 .41995 Mdot
.642 .42054 Mdot
.642 .4211 Mdot
.642 .42111 Mdot
.642 .42111 Mdot
.642 .42125 Mdot
.642 .42137 Mdot
.642 .42142 Mdot
.642 .42144 Mdot
.642 .42145 Mdot
.642 .4216 Mdot
.642 .42166 Mdot
.642 .42168 Mdot
.642 .42205 Mdot
.642 .42238 Mdot
.642 .42284 Mdot
.642 .42307 Mdot
.642 .4231 Mdot
.642 .42342 Mdot
.642 .42384 Mdot
.642 .42385 Mdot
.642 .42413 Mdot
.642 .42451 Mdot
.642 .42455 Mdot
.642 .42456 Mdot
.642 .42483 Mdot
.642 .42496 Mdot
.642 .42512 Mdot
.642 .42567 Mdot
.642 .42581 Mdot
.642 .42589 Mdot
.642 .42703 Mdot
.642 .42759 Mdot
.642 .42768 Mdot
.642 .42785 Mdot
.642 .42793 Mdot
.642 .42822 Mdot
.642 .42823 Mdot
.642 .42845 Mdot
.642 .42848 Mdot
.642 .4289 Mdot
.642 .42917 Mdot
.642 .42933 Mdot
.642 .42965 Mdot
.642 .42998 Mdot
.642 .43004 Mdot
.642 .43099 Mdot
.642 .43125 Mdot
.642 .43183 Mdot
.642 .43195 Mdot
.642 .43208 Mdot
.642 .43226 Mdot
.642 .43226 Mdot
.642 .43229 Mdot
.642 .4323 Mdot
.642 .43234 Mdot
.642 .43267 Mdot
.642 .43283 Mdot
.642 .43285 Mdot
.642 .4331 Mdot
.642 .43322 Mdot
.642 .43323 Mdot
.642 .43373 Mdot
.642 .43378 Mdot
.642 .4338 Mdot
.642 .4338 Mdot
.642 .43387 Mdot
.642 .434 Mdot
.642 .43421 Mdot
.642 .43463 Mdot
.642 .43581 Mdot
.642 .436 Mdot
.642 .43601 Mdot
.642 .43643 Mdot
.642 .43651 Mdot
.642 .43693 Mdot
.642 .43699 Mdot
.642 .43707 Mdot
.642 .43707 Mdot
.642 .43753 Mdot
.642 .43779 Mdot
.642 .43821 Mdot
.642 .43839 Mdot
.642 .43924 Mdot
.642 .43933 Mdot
.642 .43947 Mdot
.642 .44044 Mdot
.642 .44059 Mdot
.642 .44078 Mdot
.642 .4411 Mdot
.642 .44138 Mdot
.642 .44177 Mdot
.642 .44244 Mdot
.642 .44258 Mdot
.642 .44296 Mdot
.642 .44301 Mdot
.642 .44356 Mdot
.642 .44378 Mdot
.642 .4442 Mdot
.642 .44439 Mdot
.642 .44447 Mdot
.642 .44467 Mdot
.642 .4447 Mdot
.642 .44477 Mdot
.642 .44485 Mdot
.642 .44489 Mdot
.642 .4449 Mdot
.642 .44502 Mdot
.642 .44507 Mdot
.642 .44518 Mdot
.642 .44542 Mdot
.642 .44555 Mdot
.642 .44587 Mdot
.642 .4459 Mdot
.642 .44612 Mdot
.642 .44659 Mdot
.642 .44681 Mdot
.642 .44697 Mdot
.642 .44791 Mdot
.642 .44799 Mdot
.642 .44862 Mdot
.642 .44886 Mdot
.642 .44931 Mdot
.642 .44987 Mdot
.642 .44998 Mdot
.642 .45064 Mdot
.642 .45111 Mdot
.642 .45111 Mdot
.642 .45142 Mdot
.642 .45163 Mdot
.642 .45164 Mdot
.642 .45196 Mdot
.642 .45206 Mdot
.642 .45213 Mdot
.642 .4522 Mdot
.642 .45357 Mdot
.642 .45381 Mdot
.642 .45404 Mdot
.642 .45418 Mdot
.642 .45438 Mdot
.642 .45452 Mdot
.642 .45483 Mdot
.642 .45557 Mdot
.642 .45587 Mdot
.642 .45617 Mdot
.642 .4562 Mdot
.642 .45655 Mdot
.642 .45655 Mdot
.642 .45697 Mdot
.642 .45771 Mdot
.642 .45772 Mdot
.642 .45785 Mdot
.642 .45794 Mdot
.642 .45832 Mdot
.642 .45863 Mdot
.642 .45875 Mdot
.642 .45942 Mdot
.642 .45944 Mdot
.642 .45975 Mdot
.642 .46084 Mdot
.642 .46109 Mdot
.642 .46145 Mdot
.642 .46163 Mdot
.642 .46191 Mdot
.642 .46229 Mdot
.642 .46231 Mdot
.642 .46235 Mdot
.642 .46262 Mdot
.642 .46282 Mdot
.642 .46294 Mdot
.642 .46294 Mdot
.642 .46297 Mdot
.642 .46301 Mdot
.642 .46304 Mdot
.642 .46341 Mdot
.642 .46344 Mdot
.642 .46383 Mdot
.642 .46385 Mdot
.642 .46388 Mdot
.642 .46404 Mdot
.642 .46443 Mdot
.642 .46446 Mdot
.642 .4647 Mdot
.642 .46487 Mdot
.642 .46513 Mdot
.642 .46523 Mdot
.642 .46528 Mdot
.642 .46529 Mdot
.642 .46534 Mdot
.642 .46535 Mdot
.642 .46562 Mdot
.642 .46582 Mdot
.642 .46602 Mdot
.642 .46644 Mdot
.642 .46691 Mdot
.642 .46731 Mdot
.642 .46739 Mdot
.642 .46877 Mdot
.642 .46886 Mdot
.642 .46936 Mdot
.642 .46984 Mdot
.642 .47001 Mdot
.642 .47009 Mdot
.642 .47049 Mdot
.642 .47056 Mdot
.642 .47077 Mdot
.642 .47113 Mdot
.642 .47118 Mdot
.642 .47151 Mdot
.642 .47152 Mdot
.642 .47196 Mdot
.642 .47208 Mdot
.642 .47234 Mdot
.642 .47246 Mdot
.642 .47286 Mdot
.642 .47331 Mdot
.642 .47342 Mdot
.642 .474 Mdot
.642 .47423 Mdot
.642 .47499 Mdot
.642 .47511 Mdot
.642 .47532 Mdot
.642 .47585 Mdot
.642 .47613 Mdot
.642 .47637 Mdot
.642 .47655 Mdot
.642 .47681 Mdot
.642 .47695 Mdot
.642 .47696 Mdot
.642 .47703 Mdot
.642 .47756 Mdot
.642 .47758 Mdot
.642 .47784 Mdot
.642 .47786 Mdot
.642 .47798 Mdot
.642 .47799 Mdot
.642 .4786 Mdot
.642 .47907 Mdot
.642 .4791 Mdot
.642 .47943 Mdot
.642 .47974 Mdot
.642 .4801 Mdot
.642 .48056 Mdot
.642 .48059 Mdot
.642 .4811 Mdot
.642 .48112 Mdot
.642 .4812 Mdot
.642 .48141 Mdot
.642 .48143 Mdot
.642 .48146 Mdot
.642 .48153 Mdot
.642 .4817 Mdot
.642 .4819 Mdot
.642 .4819 Mdot
.642 .48191 Mdot
.642 .48215 Mdot
.642 .4827 Mdot
.642 .48287 Mdot
.642 .48339 Mdot
.642 .48353 Mdot
.642 .48357 Mdot
.642 .48384 Mdot
.642 .48561 Mdot
.642 .48565 Mdot
.642 .48627 Mdot
.642 .48648 Mdot
.642 .48722 Mdot
.642 .48808 Mdot
.642 .48817 Mdot
.642 .48908 Mdot
.642 .48931 Mdot
.642 .48994 Mdot
.642 .49061 Mdot
.642 .49065 Mdot
.642 .49088 Mdot
.642 .49132 Mdot
.642 .49187 Mdot
.642 .49205 Mdot
.642 .49301 Mdot
.642 .49305 Mdot
.642 .49316 Mdot
.642 .49385 Mdot
.642 .49435 Mdot
.642 .49444 Mdot
.642 .49466 Mdot
.642 .49467 Mdot
.642 .49475 Mdot
.642 .49484 Mdot
.642 .49491 Mdot
.642 .49584 Mdot
.642 .49592 Mdot
.642 .49592 Mdot
.642 .4962 Mdot
.642 .49678 Mdot
.642 .49689 Mdot
.642 .49694 Mdot
.642 .49701 Mdot
.642 .49728 Mdot
.642 .49741 Mdot
.642 .49837 Mdot
.642 .49844 Mdot
.642 .49904 Mdot
.642 .49946 Mdot
.642 .49954 Mdot
.642 .49986 Mdot
.642 .50009 Mdot
.642 .50033 Mdot
.642 .50046 Mdot
.642 .50049 Mdot
.642 .50062 Mdot
.642 .50064 Mdot
.642 .50129 Mdot
.642 .5014 Mdot
.642 .50143 Mdot
.642 .5016 Mdot
.642 .50178 Mdot
.642 .50189 Mdot
.642 .5019 Mdot
.642 .50191 Mdot
.642 .50225 Mdot
.642 .50328 Mdot
.642 .50337 Mdot
.642 .50439 Mdot
.642 .50534 Mdot
.642 .50579 Mdot
.642 .50693 Mdot
.642 .50787 Mdot
.642 .50876 Mdot
.642 .50899 Mdot
.642 .50912 Mdot
.642 .51013 Mdot
.642 .51014 Mdot
.642 .51038 Mdot
.642 .51123 Mdot
.642 .51162 Mdot
.642 .5118 Mdot
.642 .51271 Mdot
.642 .51285 Mdot
.642 .51292 Mdot
.642 .51334 Mdot
.642 .51414 Mdot
.642 .51424 Mdot
.642 .5147 Mdot
.642 .51487 Mdot
.642 .51498 Mdot
.642 .515 Mdot
.642 .51532 Mdot
.642 .51573 Mdot
.642 .51597 Mdot
.642 .51616 Mdot
.642 .51623 Mdot
.642 .51679 Mdot
.642 .51707 Mdot
.642 .51794 Mdot
.642 .5189 Mdot
.642 .51913 Mdot
.642 .51917 Mdot
.642 .51932 Mdot
.642 .52037 Mdot
.642 .52066 Mdot
.642 .52082 Mdot
.642 .52084 Mdot
.642 .52154 Mdot
.642 .52199 Mdot
.642 .52237 Mdot
.642 .52244 Mdot
.642 .52269 Mdot
.642 .52274 Mdot
.642 .52312 Mdot
.642 .52402 Mdot
.642 .52411 Mdot
.642 .5242 Mdot
.642 .52424 Mdot
.642 .52477 Mdot
.642 .52482 Mdot
.642 .52482 Mdot
.642 .52525 Mdot
.642 .5256 Mdot
.642 .52613 Mdot
.642 .52641 Mdot
.642 .52642 Mdot
.642 .52656 Mdot
.642 .5268 Mdot
.642 .52738 Mdot
.642 .5276 Mdot
.642 .52765 Mdot
.642 .52816 Mdot
.642 .5282 Mdot
.642 .52844 Mdot
.642 .52844 Mdot
.642 .52847 Mdot
.642 .52851 Mdot
.642 .52852 Mdot
.642 .52942 Mdot
.642 .52962 Mdot
.642 .5302 Mdot
.642 .53048 Mdot
.642 .53051 Mdot
.642 .53058 Mdot
.642 .53064 Mdot
.642 .53071 Mdot
.642 .53119 Mdot
.642 .53164 Mdot
.642 .5317 Mdot
.642 .53176 Mdot
.642 .53199 Mdot
.642 .53201 Mdot
.642 .5321 Mdot
.642 .53243 Mdot
.642 .53327 Mdot
.642 .53333 Mdot
.642 .53424 Mdot
.642 .53428 Mdot
.642 .53429 Mdot
.642 .5344 Mdot
.642 .53443 Mdot
.642 .53481 Mdot
.642 .53483 Mdot
.642 .5349 Mdot
.642 .53501 Mdot
.642 .53532 Mdot
.642 .53567 Mdot
.642 .53567 Mdot
.642 .53569 Mdot
.642 .5361 Mdot
.642 .53632 Mdot
.642 .53705 Mdot
.642 .53705 Mdot
.642 .53726 Mdot
.642 .53731 Mdot
.642 .53734 Mdot
.642 .53779 Mdot
.642 .53792 Mdot
.642 .53805 Mdot
.642 .53821 Mdot
.642 .53846 Mdot
.642 .53851 Mdot
.642 .53897 Mdot
.642 .53902 Mdot
.642 .54001 Mdot
.642 .54014 Mdot
.642 .54027 Mdot
.642 .54042 Mdot
.642 .54047 Mdot
.642 .54103 Mdot
.642 .5418 Mdot
.642 .54187 Mdot
.642 .54218 Mdot
.642 .54255 Mdot
.642 .54282 Mdot
.642 .54315 Mdot
.642 .54424 Mdot
.642 .54424 Mdot
.642 .54424 Mdot
.642 .54432 Mdot
.642 .54437 Mdot
.642 .54438 Mdot
.642 .5448 Mdot
.642 .54488 Mdot
.642 .54549 Mdot
.642 .54562 Mdot
.642 .54577 Mdot
.642 .54584 Mdot
.642 .54623 Mdot
.642 .54688 Mdot
.642 .54719 Mdot
.642 .5472 Mdot
.642 .54758 Mdot
.642 .5478 Mdot
.642 .54782 Mdot
.642 .54803 Mdot
.642 .54826 Mdot
.642 .5489 Mdot
.642 .54895 Mdot
.642 .54907 Mdot
.642 .54924 Mdot
.642 .5496 Mdot
.642 .5498 Mdot
.642 .55022 Mdot
.642 .55023 Mdot
.642 .55029 Mdot
.642 .55046 Mdot
.642 .55068 Mdot
.642 .55104 Mdot
.642 .55109 Mdot
.642 .55122 Mdot
.642 .55134 Mdot
.642 .55179 Mdot
.642 .55184 Mdot
.642 .55196 Mdot
.642 .55252 Mdot
.642 .55271 Mdot
.642 .55299 Mdot
.642 .55304 Mdot
.642 .55325 Mdot
.642 .55334 Mdot
.642 .55335 Mdot
.642 .55343 Mdot
.642 .55357 Mdot
.642 .55357 Mdot
.642 .55366 Mdot
.642 .55375 Mdot
.642 .55382 Mdot
.642 .55387 Mdot
.642 .55438 Mdot
.642 .55474 Mdot
.642 .55481 Mdot
.642 .55481 Mdot
.642 .55508 Mdot
.642 .55514 Mdot
.642 .55516 Mdot
.642 .55532 Mdot
.642 .5556 Mdot
.642 .55562 Mdot
.642 .5557 Mdot
.642 .55574 Mdot
.642 .5558 Mdot
.642 .55604 Mdot
.642 .55614 Mdot
.642 .55662 Mdot
.642 .55675 Mdot
.642 .55679 Mdot
.642 .55692 Mdot
.642 .55698 Mdot
.642 .55699 Mdot
.642 .55743 Mdot
.642 .55774 Mdot
.642 .55777 Mdot
.642 .5578 Mdot
.642 .55802 Mdot
.642 .55817 Mdot
.642 .55833 Mdot
.642 .55841 Mdot
.642 .55841 Mdot
.642 .55843 Mdot
.642 .55851 Mdot
.642 .55852 Mdot
.642 .5586 Mdot
.642 .55892 Mdot
.642 .55896 Mdot
.642 .55898 Mdot
.642 .559 Mdot
.642 .559 Mdot
.642 .5591 Mdot
.642 .55912 Mdot
.642 .55919 Mdot
.642 .55925 Mdot
.642 .55926 Mdot
.642 .55926 Mdot
.642 .55926 Mdot
.642 .55944 Mdot
.642 .55949 Mdot
.642 .55965 Mdot
.642 .55966 Mdot
.642 .55972 Mdot
.642 .5598 Mdot
.642 .55993 Mdot
.642 .55997 Mdot
.642 .56002 Mdot
.642 .56006 Mdot
.642 .56037 Mdot
.642 .56038 Mdot
.642 .56053 Mdot
.642 .56055 Mdot
.642 .56059 Mdot
.642 .56067 Mdot
.642 .56079 Mdot
.642 .56084 Mdot
.642 .56088 Mdot
.642 .56096 Mdot
.642 .56102 Mdot
.642 .56109 Mdot
.642 .56112 Mdot
.642 .56112 Mdot
.642 .56113 Mdot
.642 .56117 Mdot
.642 .56117 Mdot
.642 .56118 Mdot
.644 .15933 Mdot
.644 .15933 Mdot
.644 .15938 Mdot
.644 .15945 Mdot
.644 .15949 Mdot
.644 .15964 Mdot
.644 .15965 Mdot
.644 .1598 Mdot
.644 .15984 Mdot
.644 .16 Mdot
.644 .1602 Mdot
.644 .16026 Mdot
.644 .16032 Mdot
.644 .16033 Mdot
.644 .16037 Mdot
.644 .16058 Mdot
.644 .16059 Mdot
.644 .16139 Mdot
.644 .16167 Mdot
.644 .16188 Mdot
.644 .16231 Mdot
.644 .16261 Mdot
.644 .16267 Mdot
.644 .16275 Mdot
.644 .16281 Mdot
.644 .16288 Mdot
.644 .16315 Mdot
.644 .16317 Mdot
.644 .16344 Mdot
.644 .16489 Mdot
.644 .16557 Mdot
.644 .16617 Mdot
.644 .16631 Mdot
.644 .16771 Mdot
.644 .16773 Mdot
.644 .16789 Mdot
.644 .16864 Mdot
.644 .16887 Mdot
.644 .16894 Mdot
.644 .16915 Mdot
.644 .16951 Mdot
.644 .16973 Mdot
.644 .17014 Mdot
.644 .17033 Mdot
.644 .17056 Mdot
.644 .17182 Mdot
.644 .17197 Mdot
.644 .17213 Mdot
.644 .17226 Mdot
.644 .17235 Mdot
.644 .17264 Mdot
.644 .17268 Mdot
.644 .17297 Mdot
.644 .17344 Mdot
.644 .17419 Mdot
.644 .17442 Mdot
.644 .17444 Mdot
.644 .17498 Mdot
.644 .17576 Mdot
.644 .17591 Mdot
.644 .17645 Mdot
.644 .17709 Mdot
.644 .17731 Mdot
.644 .17764 Mdot
.644 .17796 Mdot
.644 .179 Mdot
.644 .17901 Mdot
.644 .17964 Mdot
.644 .17977 Mdot
.644 .17998 Mdot
.644 .18014 Mdot
.644 .18036 Mdot
.644 .18051 Mdot
.644 .18078 Mdot
.644 .18171 Mdot
.644 .18252 Mdot
.644 .18293 Mdot
.644 .18373 Mdot
.644 .18381 Mdot
.644 .18471 Mdot
.644 .1864 Mdot
.644 .18736 Mdot
.644 .18748 Mdot
.644 .18857 Mdot
.644 .18943 Mdot
.644 .19025 Mdot
.644 .19045 Mdot
.644 .19058 Mdot
.644 .19136 Mdot
.644 .19465 Mdot
.644 .1956 Mdot
.644 .19708 Mdot
.644 .19882 Mdot
.644 .19999 Mdot
.644 .20004 Mdot
.644 .20016 Mdot
.644 .2002 Mdot
.644 .20075 Mdot
.644 .20114 Mdot
.644 .2014 Mdot
.644 .20142 Mdot
.644 .20439 Mdot
.644 .20526 Mdot
.644 .20548 Mdot
.644 .20587 Mdot
.644 .20694 Mdot
.644 .20709 Mdot
.644 .20776 Mdot
.644 .2086 Mdot
.644 .20916 Mdot
.644 .20928 Mdot
.644 .20933 Mdot
.644 .21024 Mdot
.644 .21087 Mdot
.644 .21094 Mdot
.644 .21154 Mdot
.644 .21161 Mdot
.644 .21189 Mdot
.644 .21317 Mdot
.644 .21419 Mdot
.644 .21442 Mdot
.644 .21518 Mdot
.644 .21541 Mdot
.644 .21547 Mdot
.644 .21547 Mdot
.644 .21562 Mdot
.644 .21769 Mdot
.644 .21799 Mdot
.644 .22063 Mdot
.644 .2218 Mdot
.644 .22288 Mdot
.644 .22295 Mdot
.644 .22371 Mdot
.644 .2256 Mdot
.644 .22756 Mdot
.644 .22764 Mdot
.644 .22808 Mdot
.644 .22813 Mdot
.644 .22877 Mdot
.644 .22928 Mdot
.644 .22938 Mdot
.644 .22961 Mdot
.644 .2301 Mdot
.644 .23046 Mdot
.644 .23213 Mdot
.644 .23221 Mdot
.644 .23319 Mdot
.644 .23376 Mdot
.644 .23415 Mdot
.644 .23442 Mdot
.644 .23446 Mdot
.644 .23473 Mdot
.644 .23473 Mdot
.644 .23642 Mdot
.644 .23661 Mdot
.644 .23687 Mdot
.644 .23765 Mdot
.644 .23766 Mdot
.644 .23769 Mdot
.644 .2381 Mdot
.644 .23816 Mdot
.644 .23927 Mdot
.644 .23962 Mdot
.644 .24001 Mdot
.644 .24031 Mdot
.644 .24104 Mdot
.644 .24126 Mdot
.644 .24127 Mdot
.644 .24166 Mdot
.644 .24194 Mdot
.644 .24214 Mdot
.644 .24245 Mdot
.644 .24323 Mdot
.644 .24349 Mdot
.644 .24425 Mdot
.644 .24472 Mdot
.644 .24475 Mdot
.644 .24494 Mdot
.644 .2454 Mdot
.644 .24548 Mdot
.644 .24634 Mdot
.644 .24635 Mdot
.644 .24664 Mdot
.644 .24689 Mdot
.644 .2486 Mdot
.644 .24865 Mdot
.644 .24939 Mdot
.644 .24943 Mdot
.644 .25033 Mdot
.644 .25121 Mdot
.644 .25212 Mdot
.644 .25267 Mdot
.644 .25395 Mdot
.644 .2541 Mdot
.644 .25512 Mdot
.644 .2552 Mdot
.644 .25523 Mdot
.644 .25635 Mdot
.644 .25715 Mdot
.644 .25718 Mdot
.644 .25786 Mdot
.644 .25833 Mdot
.644 .25836 Mdot
.644 .25842 Mdot
.644 .26039 Mdot
.644 .26098 Mdot
.644 .26264 Mdot
.644 .26265 Mdot
.644 .2628 Mdot
.644 .26335 Mdot
.644 .26343 Mdot
.644 .26345 Mdot
.644 .26413 Mdot
.644 .26516 Mdot
.644 .26605 Mdot
.644 .26663 Mdot
.644 .2692 Mdot
.644 .26928 Mdot
.644 .26941 Mdot
.644 .26996 Mdot
.644 .27385 Mdot
.644 .27391 Mdot
.644 .2745 Mdot
.644 .27481 Mdot
.644 .27542 Mdot
.644 .27613 Mdot
.644 .27663 Mdot
.644 .27676 Mdot
.644 .27703 Mdot
.644 .27755 Mdot
.644 .2784 Mdot
.644 .27867 Mdot
.644 .27913 Mdot
.644 .28015 Mdot
.644 .28028 Mdot
.644 .28147 Mdot
.644 .2817 Mdot
.644 .2824 Mdot
.644 .28286 Mdot
.644 .28314 Mdot
.644 .28347 Mdot
.644 .2853 Mdot
.644 .28554 Mdot
.644 .28575 Mdot
.644 .28684 Mdot
.644 .28709 Mdot
.644 .28743 Mdot
.644 .28855 Mdot
.644 .29236 Mdot
.644 .2945 Mdot
.644 .29469 Mdot
.644 .29571 Mdot
.644 .29682 Mdot
.644 .29775 Mdot
.644 .30108 Mdot
.644 .30222 Mdot
.644 .30323 Mdot
.644 .30418 Mdot
.644 .3062 Mdot
.644 .30869 Mdot
.644 .30956 Mdot
.644 .31069 Mdot
.644 .31147 Mdot
.644 .31298 Mdot
.644 .31302 Mdot
.644 .31407 Mdot
.644 .31562 Mdot
.644 .31606 Mdot
.644 .31606 Mdot
.644 .31624 Mdot
.644 .31691 Mdot
.644 .31916 Mdot
.644 .31982 Mdot
.644 .32181 Mdot
.644 .32192 Mdot
.644 .32208 Mdot
.644 .32219 Mdot
.644 .32282 Mdot
.644 .32285 Mdot
.644 .32667 Mdot
.644 .3275 Mdot
.644 .32769 Mdot
.644 .32951 Mdot
.644 .3297 Mdot
.644 .33086 Mdot
.644 .3316 Mdot
.644 .33183 Mdot
.644 .33404 Mdot
.644 .33419 Mdot
.644 .33435 Mdot
.644 .33448 Mdot
.644 .33485 Mdot
.644 .33655 Mdot
.644 .33705 Mdot
.644 .33836 Mdot
.644 .33909 Mdot
.644 .34049 Mdot
.644 .34111 Mdot
.644 .34157 Mdot
.644 .34169 Mdot
.644 .34483 Mdot
.644 .34602 Mdot
.644 .34669 Mdot
.644 .34677 Mdot
.644 .34751 Mdot
.644 .34934 Mdot
.644 .3547 Mdot
.644 .35501 Mdot
.644 .35753 Mdot
.644 .35786 Mdot
.644 .35843 Mdot
.644 .35852 Mdot
.644 .35887 Mdot
.644 .35932 Mdot
.644 .3605 Mdot
.644 .36054 Mdot
.644 .36103 Mdot
.644 .3622 Mdot
.644 .36231 Mdot
.644 .36269 Mdot
.644 .36284 Mdot
.644 .36643 Mdot
.644 .36646 Mdot
.644 .36884 Mdot
.644 .36886 Mdot
.644 .36916 Mdot
.644 .36954 Mdot
.644 .36976 Mdot
.644 .36992 Mdot
.644 .37067 Mdot
.644 .3707 Mdot
.644 .37156 Mdot
.644 .37182 Mdot
.644 .37182 Mdot
.644 .37275 Mdot
.644 .37309 Mdot
.644 .37311 Mdot
.644 .37394 Mdot
.644 .3741 Mdot
.644 .37423 Mdot
.644 .37464 Mdot
.644 .37464 Mdot
.644 .37492 Mdot
.644 .37501 Mdot
.644 .37514 Mdot
.644 .37547 Mdot
.644 .3761 Mdot
.644 .37618 Mdot
.644 .37641 Mdot
.644 .37689 Mdot
.644 .3777 Mdot
.644 .37804 Mdot
.644 .37913 Mdot
.644 .37936 Mdot
.644 .38083 Mdot
.644 .38115 Mdot
.644 .38162 Mdot
.644 .38165 Mdot
.644 .38242 Mdot
.644 .38265 Mdot
.644 .38336 Mdot
.644 .3836 Mdot
.644 .38461 Mdot
.644 .38585 Mdot
.644 .3861 Mdot
.644 .38759 Mdot
.644 .38781 Mdot
.644 .38816 Mdot
.644 .38861 Mdot
.644 .38895 Mdot
.644 .38936 Mdot
.644 .38953 Mdot
.644 .39073 Mdot
.644 .3909 Mdot
.644 .391 Mdot
.644 .39112 Mdot
.644 .39179 Mdot
.644 .39187 Mdot
.644 .39195 Mdot
.644 .39234 Mdot
.644 .39256 Mdot
.644 .39296 Mdot
.644 .39551 Mdot
.644 .3959 Mdot
.644 .3978 Mdot
.644 .39815 Mdot
.644 .39848 Mdot
.644 .40073 Mdot
.644 .401 Mdot
.644 .40151 Mdot
.644 .40153 Mdot
.644 .40188 Mdot
.644 .40451 Mdot
.644 .40455 Mdot
.644 .4046 Mdot
.644 .40464 Mdot
.644 .40485 Mdot
.644 .40755 Mdot
.644 .40787 Mdot
.644 .4086 Mdot
.644 .40865 Mdot
.644 .4096 Mdot
.644 .41003 Mdot
.644 .41074 Mdot
.644 .41113 Mdot
.644 .4128 Mdot
.644 .41304 Mdot
.644 .41539 Mdot
.644 .4155 Mdot
.644 .41631 Mdot
.644 .41642 Mdot
.644 .41675 Mdot
.644 .41729 Mdot
.644 .41745 Mdot
.644 .4192 Mdot
.644 .41999 Mdot
.644 .41999 Mdot
.644 .42009 Mdot
.644 .42021 Mdot
.644 .42028 Mdot
.644 .42033 Mdot
.644 .42058 Mdot
.644 .42059 Mdot
.644 .42087 Mdot
.644 .42095 Mdot
.644 .42125 Mdot
.644 .42136 Mdot
.644 .42137 Mdot
.644 .42163 Mdot
.644 .42169 Mdot
.644 .42173 Mdot
.644 .42186 Mdot
.644 .42186 Mdot
.644 .42195 Mdot
.644 .42198 Mdot
.644 .42202 Mdot
.644 .42213 Mdot
.644 .42234 Mdot
.644 .42236 Mdot
.644 .42259 Mdot
.644 .42285 Mdot
.644 .42296 Mdot
.644 .42331 Mdot
.644 .42386 Mdot
.644 .42396 Mdot
.644 .42412 Mdot
.644 .42413 Mdot
.644 .42438 Mdot
.644 .42445 Mdot
.644 .42468 Mdot
.644 .42476 Mdot
.644 .42508 Mdot
.644 .42548 Mdot
.644 .42557 Mdot
.644 .42605 Mdot
.644 .42612 Mdot
.644 .42623 Mdot
.644 .42637 Mdot
.644 .42648 Mdot
.644 .42662 Mdot
.644 .42706 Mdot
.644 .42712 Mdot
.644 .42715 Mdot
.644 .42719 Mdot
.644 .4274 Mdot
.644 .42743 Mdot
.644 .42765 Mdot
.644 .42873 Mdot
.644 .42935 Mdot
.644 .42957 Mdot
.644 .4303 Mdot
.644 .43038 Mdot
.644 .43055 Mdot
.644 .43152 Mdot
.644 .43154 Mdot
.644 .43155 Mdot
.644 .43157 Mdot
.644 .43251 Mdot
.644 .43262 Mdot
.644 .43286 Mdot
.644 .43287 Mdot
.644 .43318 Mdot
.644 .43355 Mdot
.644 .43368 Mdot
.644 .43507 Mdot
.644 .43537 Mdot
.644 .43541 Mdot
.644 .43569 Mdot
.644 .43575 Mdot
.644 .43669 Mdot
.644 .43703 Mdot
.644 .43703 Mdot
.644 .43714 Mdot
.644 .43723 Mdot
.644 .43728 Mdot
.644 .43744 Mdot
.644 .43756 Mdot
.644 .43794 Mdot
.644 .43794 Mdot
.644 .43812 Mdot
.644 .43858 Mdot
.644 .43891 Mdot
.644 .43895 Mdot
.644 .43947 Mdot
.644 .43967 Mdot
.644 .43974 Mdot
.644 .44001 Mdot
.644 .4404 Mdot
.644 .44041 Mdot
.644 .44084 Mdot
.644 .44107 Mdot
.644 .44111 Mdot
.644 .4418 Mdot
.644 .44224 Mdot
.644 .4423 Mdot
.644 .44232 Mdot
.644 .44254 Mdot
.644 .4426 Mdot
.644 .44287 Mdot
.644 .44315 Mdot
.644 .44337 Mdot
.644 .44352 Mdot
.644 .44399 Mdot
.644 .44401 Mdot
.644 .44402 Mdot
.644 .44409 Mdot
.644 .44458 Mdot
.644 .4454 Mdot
.644 .44541 Mdot
.644 .44625 Mdot
.644 .44638 Mdot
.644 .44639 Mdot
.644 .44643 Mdot
.644 .44667 Mdot
.644 .44707 Mdot
.644 .4471 Mdot
.644 .44723 Mdot
.644 .44748 Mdot
.644 .44785 Mdot
.644 .44801 Mdot
.644 .44833 Mdot
.644 .44877 Mdot
.644 .44888 Mdot
.644 .44925 Mdot
.644 .44928 Mdot
.644 .44933 Mdot
.644 .44939 Mdot
.644 .44958 Mdot
.644 .45012 Mdot
.644 .45049 Mdot
.644 .45127 Mdot
.644 .45134 Mdot
.644 .45155 Mdot
.644 .45173 Mdot
.644 .45192 Mdot
.644 .45244 Mdot
.644 .45245 Mdot
.644 .45247 Mdot
.644 .453 Mdot
.644 .4531 Mdot
.644 .45354 Mdot
.644 .45366 Mdot
.644 .454 Mdot
.644 .45471 Mdot
.644 .45473 Mdot
.644 .45484 Mdot
.644 .45491 Mdot
.644 .45546 Mdot
.644 .45577 Mdot
.644 .45598 Mdot
.644 .4562 Mdot
.644 .45632 Mdot
.644 .4565 Mdot
.644 .4565 Mdot
.644 .45658 Mdot
.644 .45693 Mdot
.644 .45712 Mdot
.644 .45718 Mdot
.644 .45732 Mdot
.644 .45756 Mdot
.644 .45762 Mdot
.644 .45764 Mdot
.644 .4578 Mdot
.644 .45797 Mdot
.644 .45797 Mdot
.644 .45852 Mdot
.644 .45912 Mdot
.644 .46004 Mdot
.644 .46012 Mdot
.644 .46041 Mdot
.644 .46058 Mdot
.644 .46063 Mdot
.644 .46106 Mdot
.644 .46111 Mdot
.644 .46233 Mdot
.644 .46246 Mdot
.644 .46332 Mdot
.644 .46352 Mdot
.644 .46388 Mdot
.644 .4641 Mdot
.644 .46459 Mdot
.644 .46461 Mdot
.644 .46498 Mdot
.644 .46515 Mdot
.644 .46651 Mdot
.644 .46662 Mdot
.644 .46663 Mdot
.644 .46666 Mdot
.644 .46668 Mdot
.644 .46799 Mdot
.644 .46817 Mdot
.644 .46818 Mdot
.644 .46844 Mdot
.644 .46857 Mdot
.644 .46968 Mdot
.644 .46984 Mdot
.644 .47002 Mdot
.644 .47095 Mdot
.644 .47114 Mdot
.644 .47238 Mdot
.644 .47258 Mdot
.644 .47268 Mdot
.644 .47287 Mdot
.644 .47291 Mdot
.644 .47295 Mdot
.644 .47327 Mdot
.644 .47333 Mdot
.644 .47338 Mdot
.644 .47346 Mdot
.644 .47403 Mdot
.644 .47412 Mdot
.644 .47432 Mdot
.644 .47448 Mdot
.644 .47469 Mdot
.644 .47486 Mdot
.644 .47496 Mdot
.644 .47567 Mdot
.644 .47579 Mdot
.644 .47638 Mdot
.644 .47686 Mdot
.644 .47697 Mdot
.644 .4773 Mdot
.644 .47741 Mdot
.644 .47778 Mdot
.644 .47779 Mdot
.644 .47801 Mdot
.644 .47816 Mdot
.644 .47885 Mdot
.644 .47895 Mdot
.644 .47946 Mdot
.644 .47962 Mdot
.644 .47999 Mdot
.644 .48022 Mdot
.644 .48032 Mdot
.644 .48036 Mdot
.644 .48065 Mdot
.644 .4808 Mdot
.644 .48087 Mdot
.644 .4809 Mdot
.644 .48104 Mdot
.644 .48104 Mdot
.644 .48122 Mdot
.644 .48128 Mdot
.644 .48136 Mdot
.644 .48174 Mdot
.644 .48175 Mdot
.644 .4819 Mdot
.644 .48233 Mdot
.644 .48233 Mdot
.644 .48245 Mdot
.644 .48284 Mdot
.644 .48285 Mdot
.644 .4832 Mdot
.644 .48327 Mdot
.644 .48337 Mdot
.644 .48354 Mdot
.644 .48368 Mdot
.644 .48369 Mdot
.644 .48476 Mdot
.644 .48478 Mdot
.644 .48639 Mdot
.644 .48645 Mdot
.644 .48662 Mdot
.644 .48667 Mdot
.644 .48719 Mdot
.644 .48741 Mdot
.644 .48743 Mdot
.644 .48795 Mdot
.644 .48815 Mdot
.644 .48831 Mdot
.644 .48834 Mdot
.644 .4886 Mdot
.644 .48874 Mdot
.644 .48985 Mdot
.644 .48999 Mdot
.644 .49232 Mdot
.644 .49311 Mdot
.644 .49342 Mdot
.644 .49346 Mdot
.644 .49374 Mdot
.644 .49425 Mdot
.644 .49559 Mdot
.644 .49564 Mdot
.644 .49584 Mdot
.644 .4961 Mdot
.644 .49669 Mdot
.644 .497 Mdot
.644 .49755 Mdot
.644 .49776 Mdot
.644 .49847 Mdot
.644 .49863 Mdot
.644 .49868 Mdot
.644 .49875 Mdot
.644 .49881 Mdot
.644 .49973 Mdot
.644 .49983 Mdot
.644 .50013 Mdot
.644 .50061 Mdot
.644 .5007 Mdot
.644 .50144 Mdot
.644 .50152 Mdot
.644 .50186 Mdot
.644 .50343 Mdot
.644 .50344 Mdot
.644 .5037 Mdot
.644 .50374 Mdot
.644 .5038 Mdot
.644 .50385 Mdot
.644 .50466 Mdot
.644 .50492 Mdot
.644 .50583 Mdot
.644 .5061 Mdot
.644 .50617 Mdot
.644 .50617 Mdot
.644 .50635 Mdot
.644 .50697 Mdot
.644 .50739 Mdot
.644 .50741 Mdot
.644 .50801 Mdot
.644 .50832 Mdot
.644 .50877 Mdot
.644 .50911 Mdot
.644 .5101 Mdot
.644 .51089 Mdot
.644 .51127 Mdot
.644 .51166 Mdot
.644 .5121 Mdot
.644 .5134 Mdot
.644 .51376 Mdot
.644 .51419 Mdot
.644 .51458 Mdot
.644 .51465 Mdot
.644 .51548 Mdot
.644 .51693 Mdot
.644 .51736 Mdot
.644 .51749 Mdot
.644 .51758 Mdot
.644 .518 Mdot
.644 .51808 Mdot
.644 .51817 Mdot
.644 .51886 Mdot
.644 .51899 Mdot
.644 .51909 Mdot
.644 .51926 Mdot
.644 .51953 Mdot
.644 .51961 Mdot
.644 .52006 Mdot
.644 .52011 Mdot
.644 .52049 Mdot
.644 .52067 Mdot
.644 .52077 Mdot
.644 .52109 Mdot
.644 .52128 Mdot
.644 .52138 Mdot
.644 .52143 Mdot
.644 .52161 Mdot
.644 .52188 Mdot
.644 .52211 Mdot
.644 .52222 Mdot
.644 .52244 Mdot
.644 .52246 Mdot
.644 .5239 Mdot
.644 .5241 Mdot
.644 .52415 Mdot
.644 .52418 Mdot
.644 .52512 Mdot
.644 .52534 Mdot
.644 .52566 Mdot
.644 .52604 Mdot
.644 .52629 Mdot
.644 .5263 Mdot
.644 .52632 Mdot
.644 .52652 Mdot
.644 .52658 Mdot
.644 .52658 Mdot
.644 .52718 Mdot
.644 .5274 Mdot
.644 .52811 Mdot
.644 .52814 Mdot
.644 .52814 Mdot
.644 .52832 Mdot
.644 .52856 Mdot
.644 .52857 Mdot
.644 .52886 Mdot
.644 .52926 Mdot
.644 .52928 Mdot
.644 .5293 Mdot
.644 .52967 Mdot
.644 .52972 Mdot
.644 .53018 Mdot
.644 .53038 Mdot
.644 .5307 Mdot
.644 .53102 Mdot
.644 .53134 Mdot
.644 .53135 Mdot
.644 .53162 Mdot
.644 .53163 Mdot
.644 .53224 Mdot
.644 .53233 Mdot
.644 .53243 Mdot
.644 .53244 Mdot
.644 .53274 Mdot
.644 .53277 Mdot
.644 .53293 Mdot
.644 .533 Mdot
.644 .53301 Mdot
.644 .53318 Mdot
.644 .53345 Mdot
.644 .53354 Mdot
.644 .53381 Mdot
.644 .53392 Mdot
.644 .53399 Mdot
.644 .53409 Mdot
.644 .53423 Mdot
.644 .53423 Mdot
.644 .53431 Mdot
.644 .53456 Mdot
.644 .53467 Mdot
.644 .53481 Mdot
.644 .53493 Mdot
.644 .53532 Mdot
.644 .53534 Mdot
.644 .53548 Mdot
.644 .53549 Mdot
.644 .5355 Mdot
.644 .53577 Mdot
.644 .53586 Mdot
.644 .53593 Mdot
.644 .53652 Mdot
.644 .53652 Mdot
.644 .53661 Mdot
.644 .53663 Mdot
.644 .53672 Mdot
.644 .53685 Mdot
.644 .53705 Mdot
.644 .53739 Mdot
.644 .53742 Mdot
.644 .538 Mdot
.644 .53812 Mdot
.644 .53829 Mdot
.644 .53837 Mdot
.644 .53841 Mdot
.644 .53858 Mdot
.644 .53881 Mdot
.644 .53882 Mdot
.644 .53897 Mdot
.644 .539 Mdot
.644 .53967 Mdot
.644 .54032 Mdot
.644 .54058 Mdot
.644 .54061 Mdot
.644 .54098 Mdot
.644 .54137 Mdot
.644 .54227 Mdot
.644 .54237 Mdot
.644 .54308 Mdot
.644 .54313 Mdot
.644 .54313 Mdot
.644 .54315 Mdot
.644 .54323 Mdot
.644 .54348 Mdot
.644 .54356 Mdot
.644 .5439 Mdot
.644 .54434 Mdot
.644 .54443 Mdot
.644 .54445 Mdot
.644 .54466 Mdot
.644 .54468 Mdot
.644 .54489 Mdot
.644 .5452 Mdot
.644 .54521 Mdot
.644 .54525 Mdot
.644 .54544 Mdot
.644 .54572 Mdot
.644 .54595 Mdot
.644 .546 Mdot
.644 .54635 Mdot
.644 .54648 Mdot
.644 .54656 Mdot
.644 .54685 Mdot
.644 .54783 Mdot
.644 .54784 Mdot
.644 .54793 Mdot
.644 .54806 Mdot
.644 .54824 Mdot
.644 .54825 Mdot
.644 .54829 Mdot
.644 .54831 Mdot
.644 .5487 Mdot
.644 .54927 Mdot
.644 .54976 Mdot
.644 .55007 Mdot
.644 .55115 Mdot
.644 .5514 Mdot
.644 .55145 Mdot
.644 .55151 Mdot
.644 .55178 Mdot
.644 .55206 Mdot
.644 .55242 Mdot
.644 .55245 Mdot
.644 .55277 Mdot
.644 .55331 Mdot
.644 .55361 Mdot
.644 .55363 Mdot
.644 .55389 Mdot
.644 .55402 Mdot
.644 .55428 Mdot
.644 .55458 Mdot
.644 .55467 Mdot
.644 .55472 Mdot
.644 .55479 Mdot
.644 .55484 Mdot
.644 .55491 Mdot
.644 .55495 Mdot
.644 .55516 Mdot
.644 .55516 Mdot
.644 .55549 Mdot
.644 .5556 Mdot
.644 .5557 Mdot
.644 .55577 Mdot
.644 .55598 Mdot
.644 .55615 Mdot
.644 .5562 Mdot
.644 .55645 Mdot
.644 .55662 Mdot
.644 .55663 Mdot
.644 .5567 Mdot
.644 .55694 Mdot
.644 .55709 Mdot
.644 .55718 Mdot
.644 .5572 Mdot
.644 .55729 Mdot
.644 .55732 Mdot
.644 .55736 Mdot
.644 .55741 Mdot
.644 .55746 Mdot
.644 .55786 Mdot
.644 .55793 Mdot
.644 .55799 Mdot
.644 .55812 Mdot
.644 .55819 Mdot
.644 .55831 Mdot
.644 .55838 Mdot
.644 .5584 Mdot
.644 .55847 Mdot
.644 .55871 Mdot
.644 .55876 Mdot
.644 .55877 Mdot
.644 .55921 Mdot
.644 .55925 Mdot
.644 .55944 Mdot
.644 .55966 Mdot
.644 .56012 Mdot
.644 .5602 Mdot
.644 .56021 Mdot
.644 .56029 Mdot
.644 .56032 Mdot
.644 .56033 Mdot
.644 .56036 Mdot
.644 .56038 Mdot
.644 .56047 Mdot
.644 .56061 Mdot
.644 .56067 Mdot
.644 .56076 Mdot
.644 .56101 Mdot
.644 .56102 Mdot
.644 .56108 Mdot
.644 .5611 Mdot
.644 .5611 Mdot
.644 .56112 Mdot
.644 .56113 Mdot
.644 .5612 Mdot
.644 .56125 Mdot
.644 .56126 Mdot
.644 .56131 Mdot
.644 .56131 Mdot
.644 .56136 Mdot
.644 .56137 Mdot
.644 .56139 Mdot
.644 .56141 Mdot
.644 .56141 Mdot
.646 .15864 Mdot
.646 .15864 Mdot
.646 .15869 Mdot
.646 .15881 Mdot
.646 .15884 Mdot
.646 .15884 Mdot
.646 .1589 Mdot
.646 .15891 Mdot
.646 .15903 Mdot
.646 .1591 Mdot
.646 .15912 Mdot
.646 .15918 Mdot
.646 .15942 Mdot
.646 .15951 Mdot
.646 .15952 Mdot
.646 .16007 Mdot
.646 .16032 Mdot
.646 .16038 Mdot
.646 .1604 Mdot
.646 .16101 Mdot
.646 .16105 Mdot
.646 .16142 Mdot
.646 .16156 Mdot
.646 .1619 Mdot
.646 .16196 Mdot
.646 .16212 Mdot
.646 .16246 Mdot
.646 .16248 Mdot
.646 .16257 Mdot
.646 .16265 Mdot
.646 .16278 Mdot
.646 .16296 Mdot
.646 .1632 Mdot
.646 .16437 Mdot
.646 .16444 Mdot
.646 .16466 Mdot
.646 .16561 Mdot
.646 .16564 Mdot
.646 .16643 Mdot
.646 .16667 Mdot
.646 .16668 Mdot
.646 .16674 Mdot
.646 .16692 Mdot
.646 .16713 Mdot
.646 .16752 Mdot
.646 .16806 Mdot
.646 .16809 Mdot
.646 .16823 Mdot
.646 .16833 Mdot
.646 .16916 Mdot
.646 .16932 Mdot
.646 .16995 Mdot
.646 .17003 Mdot
.646 .17009 Mdot
.646 .17022 Mdot
.646 .17071 Mdot
.646 .17075 Mdot
.646 .17099 Mdot
.646 .17117 Mdot
.646 .17167 Mdot
.646 .17284 Mdot
.646 .17292 Mdot
.646 .17331 Mdot
.646 .17381 Mdot
.646 .17388 Mdot
.646 .1741 Mdot
.646 .175 Mdot
.646 .17513 Mdot
.646 .17557 Mdot
.646 .17589 Mdot
.646 .1766 Mdot
.646 .17727 Mdot
.646 .17849 Mdot
.646 .17884 Mdot
.646 .17891 Mdot
.646 .17902 Mdot
.646 .17942 Mdot
.646 .18035 Mdot
.646 .18105 Mdot
.646 .18267 Mdot
.646 .18277 Mdot
.646 .18353 Mdot
.646 .18401 Mdot
.646 .18433 Mdot
.646 .18463 Mdot
.646 .18511 Mdot
.646 .1853 Mdot
.646 .1856 Mdot
.646 .18678 Mdot
.646 .1874 Mdot
.646 .18748 Mdot
.646 .1883 Mdot
.646 .18883 Mdot
.646 .18936 Mdot
.646 .18972 Mdot
.646 .1901 Mdot
.646 .19028 Mdot
.646 .19108 Mdot
.646 .1927 Mdot
.646 .19293 Mdot
.646 .19297 Mdot
.646 .19297 Mdot
.646 .19356 Mdot
.646 .19664 Mdot
.646 .19685 Mdot
.646 .19726 Mdot
.646 .19729 Mdot
.646 .19807 Mdot
.646 .19827 Mdot
.646 .19886 Mdot
.646 .19899 Mdot
.646 .20053 Mdot
.646 .20106 Mdot
.646 .20282 Mdot
.646 .20382 Mdot
.646 .20437 Mdot
.646 .2048 Mdot
.646 .20498 Mdot
.646 .20562 Mdot
.646 .20766 Mdot
.646 .20786 Mdot
.646 .20963 Mdot
.646 .21097 Mdot
.646 .21107 Mdot
.646 .21143 Mdot
.646 .21337 Mdot
.646 .21651 Mdot
.646 .21666 Mdot
.646 .21776 Mdot
.646 .21884 Mdot
.646 .21939 Mdot
.646 .21942 Mdot
.646 .22001 Mdot
.646 .22065 Mdot
.646 .2215 Mdot
.646 .22153 Mdot
.646 .22182 Mdot
.646 .22192 Mdot
.646 .22253 Mdot
.646 .22261 Mdot
.646 .22274 Mdot
.646 .22299 Mdot
.646 .22364 Mdot
.646 .22379 Mdot
.646 .22427 Mdot
.646 .22512 Mdot
.646 .22535 Mdot
.646 .22536 Mdot
.646 .2261 Mdot
.646 .22616 Mdot
.646 .22639 Mdot
.646 .22674 Mdot
.646 .22731 Mdot
.646 .22751 Mdot
.646 .22923 Mdot
.646 .23038 Mdot
.646 .23051 Mdot
.646 .23207 Mdot
.646 .23231 Mdot
.646 .23276 Mdot
.646 .23411 Mdot
.646 .23519 Mdot
.646 .23531 Mdot
.646 .23544 Mdot
.646 .2367 Mdot
.646 .23781 Mdot
.646 .23984 Mdot
.646 .2413 Mdot
.646 .24133 Mdot
.646 .24211 Mdot
.646 .24237 Mdot
.646 .24315 Mdot
.646 .24377 Mdot
.646 .24567 Mdot
.646 .24572 Mdot
.646 .24684 Mdot
.646 .24929 Mdot
.646 .24971 Mdot
.646 .25091 Mdot
.646 .25129 Mdot
.646 .2515 Mdot
.646 .25432 Mdot
.646 .25439 Mdot
.646 .25694 Mdot
.646 .25712 Mdot
.646 .25787 Mdot
.646 .2589 Mdot
.646 .25998 Mdot
.646 .26033 Mdot
.646 .26043 Mdot
.646 .26066 Mdot
.646 .26096 Mdot
.646 .26375 Mdot
.646 .26409 Mdot
.646 .26467 Mdot
.646 .26469 Mdot
.646 .26493 Mdot
.646 .26505 Mdot
.646 .26691 Mdot
.646 .26728 Mdot
.646 .26731 Mdot
.646 .26745 Mdot
.646 .26847 Mdot
.646 .2691 Mdot
.646 .27131 Mdot
.646 .27233 Mdot
.646 .27246 Mdot
.646 .27324 Mdot
.646 .27359 Mdot
.646 .27422 Mdot
.646 .27543 Mdot
.646 .27669 Mdot
.646 .27743 Mdot
.646 .27843 Mdot
.646 .28025 Mdot
.646 .28037 Mdot
.646 .28137 Mdot
.646 .28191 Mdot
.646 .28227 Mdot
.646 .28235 Mdot
.646 .28348 Mdot
.646 .28398 Mdot
.646 .28444 Mdot
.646 .28509 Mdot
.646 .28515 Mdot
.646 .28524 Mdot
.646 .28701 Mdot
.646 .28713 Mdot
.646 .28729 Mdot
.646 .28733 Mdot
.646 .28796 Mdot
.646 .28869 Mdot
.646 .28899 Mdot
.646 .29033 Mdot
.646 .2917 Mdot
.646 .29202 Mdot
.646 .29211 Mdot
.646 .29395 Mdot
.646 .29466 Mdot
.646 .29503 Mdot
.646 .2952 Mdot
.646 .29523 Mdot
.646 .29586 Mdot
.646 .29627 Mdot
.646 .29697 Mdot
.646 .29725 Mdot
.646 .29807 Mdot
.646 .29817 Mdot
.646 .29966 Mdot
.646 .29987 Mdot
.646 .30059 Mdot
.646 .30241 Mdot
.646 .30244 Mdot
.646 .30279 Mdot
.646 .30383 Mdot
.646 .30414 Mdot
.646 .30423 Mdot
.646 .30459 Mdot
.646 .30582 Mdot
.646 .30743 Mdot
.646 .30865 Mdot
.646 .30895 Mdot
.646 .31196 Mdot
.646 .31215 Mdot
.646 .31262 Mdot
.646 .31269 Mdot
.646 .31832 Mdot
.646 .32187 Mdot
.646 .32315 Mdot
.646 .32368 Mdot
.646 .32766 Mdot
.646 .32873 Mdot
.646 .32903 Mdot
.646 .32912 Mdot
.646 .32961 Mdot
.646 .33194 Mdot
.646 .33212 Mdot
.646 .33308 Mdot
.646 .33363 Mdot
.646 .33388 Mdot
.646 .33686 Mdot
.646 .33816 Mdot
.646 .33844 Mdot
.646 .33905 Mdot
.646 .34089 Mdot
.646 .34094 Mdot
.646 .34103 Mdot
.646 .34207 Mdot
.646 .34389 Mdot
.646 .34502 Mdot
.646 .34523 Mdot
.646 .34591 Mdot
.646 .34715 Mdot
.646 .3472 Mdot
.646 .34775 Mdot
.646 .3481 Mdot
.646 .34845 Mdot
.646 .34869 Mdot
.646 .34905 Mdot
.646 .35075 Mdot
.646 .35382 Mdot
.646 .35435 Mdot
.646 .35524 Mdot
.646 .35554 Mdot
.646 .35652 Mdot
.646 .35924 Mdot
.646 .36086 Mdot
.646 .36208 Mdot
.646 .36425 Mdot
.646 .36477 Mdot
.646 .36504 Mdot
.646 .36505 Mdot
.646 .36534 Mdot
.646 .36564 Mdot
.646 .36605 Mdot
.646 .36606 Mdot
.646 .3662 Mdot
.646 .36625 Mdot
.646 .36657 Mdot
.646 .36663 Mdot
.646 .36705 Mdot
.646 .36735 Mdot
.646 .36774 Mdot
.646 .36785 Mdot
.646 .36785 Mdot
.646 .36819 Mdot
.646 .36822 Mdot
.646 .36849 Mdot
.646 .36884 Mdot
.646 .36962 Mdot
.646 .37013 Mdot
.646 .37019 Mdot
.646 .37089 Mdot
.646 .37099 Mdot
.646 .37179 Mdot
.646 .37226 Mdot
.646 .37291 Mdot
.646 .37339 Mdot
.646 .37489 Mdot
.646 .37522 Mdot
.646 .37533 Mdot
.646 .37719 Mdot
.646 .37837 Mdot
.646 .37885 Mdot
.646 .37901 Mdot
.646 .37909 Mdot
.646 .38025 Mdot
.646 .38126 Mdot
.646 .38163 Mdot
.646 .38204 Mdot
.646 .38246 Mdot
.646 .38263 Mdot
.646 .38405 Mdot
.646 .38427 Mdot
.646 .38428 Mdot
.646 .38437 Mdot
.646 .38442 Mdot
.646 .38513 Mdot
.646 .38528 Mdot
.646 .38534 Mdot
.646 .3868 Mdot
.646 .38718 Mdot
.646 .38723 Mdot
.646 .38789 Mdot
.646 .38834 Mdot
.646 .38908 Mdot
.646 .38945 Mdot
.646 .39012 Mdot
.646 .39016 Mdot
.646 .39085 Mdot
.646 .39088 Mdot
.646 .39147 Mdot
.646 .3919 Mdot
.646 .39257 Mdot
.646 .39261 Mdot
.646 .39317 Mdot
.646 .39328 Mdot
.646 .39436 Mdot
.646 .39549 Mdot
.646 .39572 Mdot
.646 .39586 Mdot
.646 .39705 Mdot
.646 .39712 Mdot
.646 .39801 Mdot
.646 .39814 Mdot
.646 .3985 Mdot
.646 .39877 Mdot
.646 .39975 Mdot
.646 .40017 Mdot
.646 .4013 Mdot
.646 .40155 Mdot
.646 .40346 Mdot
.646 .40509 Mdot
.646 .40527 Mdot
.646 .40709 Mdot
.646 .40725 Mdot
.646 .40803 Mdot
.646 .40809 Mdot
.646 .40859 Mdot
.646 .40867 Mdot
.646 .40965 Mdot
.646 .41009 Mdot
.646 .41098 Mdot
.646 .411 Mdot
.646 .41103 Mdot
.646 .41137 Mdot
.646 .41197 Mdot
.646 .41234 Mdot
.646 .41263 Mdot
.646 .41303 Mdot
.646 .41335 Mdot
.646 .41346 Mdot
.646 .41354 Mdot
.646 .41539 Mdot
.646 .41567 Mdot
.646 .41577 Mdot
.646 .41609 Mdot
.646 .41789 Mdot
.646 .4186 Mdot
.646 .41877 Mdot
.646 .41885 Mdot
.646 .41886 Mdot
.646 .41895 Mdot
.646 .41918 Mdot
.646 .41923 Mdot
.646 .41924 Mdot
.646 .41935 Mdot
.646 .41937 Mdot
.646 .4195 Mdot
.646 .4196 Mdot
.646 .41973 Mdot
.646 .41976 Mdot
.646 .41987 Mdot
.646 .41988 Mdot
.646 .42008 Mdot
.646 .42033 Mdot
.646 .4205 Mdot
.646 .42052 Mdot
.646 .42103 Mdot
.646 .42155 Mdot
.646 .42203 Mdot
.646 .42214 Mdot
.646 .42218 Mdot
.646 .42278 Mdot
.646 .42315 Mdot
.646 .42331 Mdot
.646 .42336 Mdot
.646 .42339 Mdot
.646 .42376 Mdot
.646 .42409 Mdot
.646 .42421 Mdot
.646 .42434 Mdot
.646 .42453 Mdot
.646 .42499 Mdot
.646 .42509 Mdot
.646 .42538 Mdot
.646 .4254 Mdot
.646 .42587 Mdot
.646 .426 Mdot
.646 .42601 Mdot
.646 .42605 Mdot
.646 .42622 Mdot
.646 .42637 Mdot
.646 .42661 Mdot
.646 .42673 Mdot
.646 .42694 Mdot
.646 .42718 Mdot
.646 .42719 Mdot
.646 .42738 Mdot
.646 .42752 Mdot
.646 .42773 Mdot
.646 .42796 Mdot
.646 .42875 Mdot
.646 .4288 Mdot
.646 .42918 Mdot
.646 .42949 Mdot
.646 .42953 Mdot
.646 .42965 Mdot
.646 .43005 Mdot
.646 .43019 Mdot
.646 .43178 Mdot
.646 .43184 Mdot
.646 .43249 Mdot
.646 .43276 Mdot
.646 .43295 Mdot
.646 .43327 Mdot
.646 .4337 Mdot
.646 .43371 Mdot
.646 .43383 Mdot
.646 .43414 Mdot
.646 .43424 Mdot
.646 .43437 Mdot
.646 .43447 Mdot
.646 .43453 Mdot
.646 .43513 Mdot
.646 .43523 Mdot
.646 .43595 Mdot
.646 .43618 Mdot
.646 .43624 Mdot
.646 .43648 Mdot
.646 .4366 Mdot
.646 .43667 Mdot
.646 .43756 Mdot
.646 .43775 Mdot
.646 .43788 Mdot
.646 .43803 Mdot
.646 .43813 Mdot
.646 .43842 Mdot
.646 .43858 Mdot
.646 .43886 Mdot
.646 .43901 Mdot
.646 .43927 Mdot
.646 .43953 Mdot
.646 .43967 Mdot
.646 .43977 Mdot
.646 .44 Mdot
.646 .44086 Mdot
.646 .44092 Mdot
.646 .44135 Mdot
.646 .44139 Mdot
.646 .44165 Mdot
.646 .44192 Mdot
.646 .44253 Mdot
.646 .44257 Mdot
.646 .44262 Mdot
.646 .4428 Mdot
.646 .44295 Mdot
.646 .44375 Mdot
.646 .44416 Mdot
.646 .44428 Mdot
.646 .44455 Mdot
.646 .44469 Mdot
.646 .44535 Mdot
.646 .44542 Mdot
.646 .44566 Mdot
.646 .44612 Mdot
.646 .4462 Mdot
.646 .44631 Mdot
.646 .44634 Mdot
.646 .44671 Mdot
.646 .44701 Mdot
.646 .44823 Mdot
.646 .44838 Mdot
.646 .44846 Mdot
.646 .44862 Mdot
.646 .44893 Mdot
.646 .44902 Mdot
.646 .44909 Mdot
.646 .4492 Mdot
.646 .44974 Mdot
.646 .4501 Mdot
.646 .45056 Mdot
.646 .45093 Mdot
.646 .45099 Mdot
.646 .45106 Mdot
.646 .45178 Mdot
.646 .45188 Mdot
.646 .45204 Mdot
.646 .4533 Mdot
.646 .45368 Mdot
.646 .45385 Mdot
.646 .45406 Mdot
.646 .45409 Mdot
.646 .45452 Mdot
.646 .45464 Mdot
.646 .45476 Mdot
.646 .45494 Mdot
.646 .45494 Mdot
.646 .45519 Mdot
.646 .45558 Mdot
.646 .45565 Mdot
.646 .4559 Mdot
.646 .45637 Mdot
.646 .45655 Mdot
.646 .45679 Mdot
.646 .457 Mdot
.646 .45711 Mdot
.646 .45731 Mdot
.646 .45824 Mdot
.646 .45875 Mdot
.646 .45886 Mdot
.646 .45905 Mdot
.646 .45944 Mdot
.646 .45953 Mdot
.646 .4599 Mdot
.646 .46084 Mdot
.646 .46101 Mdot
.646 .46106 Mdot
.646 .46121 Mdot
.646 .46217 Mdot
.646 .46221 Mdot
.646 .46226 Mdot
.646 .46243 Mdot
.646 .46263 Mdot
.646 .46279 Mdot
.646 .46298 Mdot
.646 .46328 Mdot
.646 .46346 Mdot
.646 .46347 Mdot
.646 .46348 Mdot
.646 .46394 Mdot
.646 .46416 Mdot
.646 .46466 Mdot
.646 .46471 Mdot
.646 .46496 Mdot
.646 .46499 Mdot
.646 .46538 Mdot
.646 .46546 Mdot
.646 .46638 Mdot
.646 .46647 Mdot
.646 .46729 Mdot
.646 .46824 Mdot
.646 .46837 Mdot
.646 .46893 Mdot
.646 .46914 Mdot
.646 .46962 Mdot
.646 .46975 Mdot
.646 .46993 Mdot
.646 .46999 Mdot
.646 .47043 Mdot
.646 .47046 Mdot
.646 .47105 Mdot
.646 .47112 Mdot
.646 .47123 Mdot
.646 .47178 Mdot
.646 .47231 Mdot
.646 .47236 Mdot
.646 .47263 Mdot
.646 .47265 Mdot
.646 .47297 Mdot
.646 .47318 Mdot
.646 .47346 Mdot
.646 .47348 Mdot
.646 .47381 Mdot
.646 .47383 Mdot
.646 .47415 Mdot
.646 .47433 Mdot
.646 .47468 Mdot
.646 .4749 Mdot
.646 .47521 Mdot
.646 .47524 Mdot
.646 .47542 Mdot
.646 .47611 Mdot
.646 .47614 Mdot
.646 .47621 Mdot
.646 .47654 Mdot
.646 .47657 Mdot
.646 .47661 Mdot
.646 .47661 Mdot
.646 .47672 Mdot
.646 .47739 Mdot
.646 .47747 Mdot
.646 .47767 Mdot
.646 .47786 Mdot
.646 .47803 Mdot
.646 .4785 Mdot
.646 .47905 Mdot
.646 .47909 Mdot
.646 .47916 Mdot
.646 .47938 Mdot
.646 .47993 Mdot
.646 .48079 Mdot
.646 .48084 Mdot
.646 .48099 Mdot
.646 .48168 Mdot
.646 .4819 Mdot
.646 .4822 Mdot
.646 .48241 Mdot
.646 .48278 Mdot
.646 .48282 Mdot
.646 .48314 Mdot
.646 .48317 Mdot
.646 .4834 Mdot
.646 .48376 Mdot
.646 .48392 Mdot
.646 .48404 Mdot
.646 .48405 Mdot
.646 .4842 Mdot
.646 .4842 Mdot
.646 .48425 Mdot
.646 .48443 Mdot
.646 .48456 Mdot
.646 .48475 Mdot
.646 .48478 Mdot
.646 .48493 Mdot
.646 .48495 Mdot
.646 .48501 Mdot
.646 .48502 Mdot
.646 .4852 Mdot
.646 .48534 Mdot
.646 .48546 Mdot
.646 .48547 Mdot
.646 .48559 Mdot
.646 .48582 Mdot
.646 .48679 Mdot
.646 .48733 Mdot
.646 .48805 Mdot
.646 .48925 Mdot
.646 .48968 Mdot
.646 .48981 Mdot
.646 .4902 Mdot
.646 .49043 Mdot
.646 .49177 Mdot
.646 .4925 Mdot
.646 .49266 Mdot
.646 .49276 Mdot
.646 .49291 Mdot
.646 .49306 Mdot
.646 .4933 Mdot
.646 .49332 Mdot
.646 .49385 Mdot
.646 .49414 Mdot
.646 .49424 Mdot
.646 .49472 Mdot
.646 .49549 Mdot
.646 .49593 Mdot
.646 .49597 Mdot
.646 .49599 Mdot
.646 .49677 Mdot
.646 .49703 Mdot
.646 .49714 Mdot
.646 .49769 Mdot
.646 .49894 Mdot
.646 .49904 Mdot
.646 .49927 Mdot
.646 .49967 Mdot
.646 .49974 Mdot
.646 .50071 Mdot
.646 .50091 Mdot
.646 .50095 Mdot
.646 .50107 Mdot
.646 .50151 Mdot
.646 .50314 Mdot
.646 .50336 Mdot
.646 .50388 Mdot
.646 .50532 Mdot
.646 .50758 Mdot
.646 .5076 Mdot
.646 .50779 Mdot
.646 .50787 Mdot
.646 .50906 Mdot
.646 .50918 Mdot
.646 .50966 Mdot
.646 .5103 Mdot
.646 .51078 Mdot
.646 .51092 Mdot
.646 .51096 Mdot
.646 .51108 Mdot
.646 .51149 Mdot
.646 .51162 Mdot
.646 .51163 Mdot
.646 .51234 Mdot
.646 .51263 Mdot
.646 .5127 Mdot
.646 .51328 Mdot
.646 .51332 Mdot
.646 .51364 Mdot
.646 .51375 Mdot
.646 .51402 Mdot
.646 .51418 Mdot
.646 .51442 Mdot
.646 .51443 Mdot
.646 .5145 Mdot
.646 .51464 Mdot
.646 .51491 Mdot
.646 .51562 Mdot
.646 .51565 Mdot
.646 .51578 Mdot
.646 .5163 Mdot
.646 .51681 Mdot
.646 .51692 Mdot
.646 .5172 Mdot
.646 .51744 Mdot
.646 .51746 Mdot
.646 .51752 Mdot
.646 .51756 Mdot
.646 .51824 Mdot
.646 .51827 Mdot
.646 .51829 Mdot
.646 .51854 Mdot
.646 .51871 Mdot
.646 .5189 Mdot
.646 .51933 Mdot
.646 .51936 Mdot
.646 .51949 Mdot
.646 .51969 Mdot
.646 .52007 Mdot
.646 .52011 Mdot
.646 .5208 Mdot
.646 .52117 Mdot
.646 .52145 Mdot
.646 .52192 Mdot
.646 .52237 Mdot
.646 .5226 Mdot
.646 .52273 Mdot
.646 .52302 Mdot
.646 .52307 Mdot
.646 .52344 Mdot
.646 .52426 Mdot
.646 .52449 Mdot
.646 .52486 Mdot
.646 .52492 Mdot
.646 .52493 Mdot
.646 .52506 Mdot
.646 .52574 Mdot
.646 .52579 Mdot
.646 .52587 Mdot
.646 .52588 Mdot
.646 .52609 Mdot
.646 .52621 Mdot
.646 .52723 Mdot
.646 .52734 Mdot
.646 .52742 Mdot
.646 .52746 Mdot
.646 .52759 Mdot
.646 .52798 Mdot
.646 .52835 Mdot
.646 .52862 Mdot
.646 .52869 Mdot
.646 .5296 Mdot
.646 .52963 Mdot
.646 .53064 Mdot
.646 .53071 Mdot
.646 .53085 Mdot
.646 .53128 Mdot
.646 .53143 Mdot
.646 .5323 Mdot
.646 .53269 Mdot
.646 .53271 Mdot
.646 .53338 Mdot
.646 .5336 Mdot
.646 .53387 Mdot
.646 .53397 Mdot
.646 .53424 Mdot
.646 .53425 Mdot
.646 .53477 Mdot
.646 .53548 Mdot
.646 .53586 Mdot
.646 .5363 Mdot
.646 .53635 Mdot
.646 .53639 Mdot
.646 .53677 Mdot
.646 .53723 Mdot
.646 .53739 Mdot
.646 .53747 Mdot
.646 .53801 Mdot
.646 .53806 Mdot
.646 .53846 Mdot
.646 .53905 Mdot
.646 .53912 Mdot
.646 .53931 Mdot
.646 .53943 Mdot
.646 .53951 Mdot
.646 .53953 Mdot
.646 .53979 Mdot
.646 .53979 Mdot
.646 .53987 Mdot
.646 .54016 Mdot
.646 .54033 Mdot
.646 .54038 Mdot
.646 .5406 Mdot
.646 .54069 Mdot
.646 .54073 Mdot
.646 .54076 Mdot
.646 .54096 Mdot
.646 .541 Mdot
.646 .5411 Mdot
.646 .54111 Mdot
.646 .5414 Mdot
.646 .54162 Mdot
.646 .54182 Mdot
.646 .54183 Mdot
.646 .54201 Mdot
.646 .54238 Mdot
.646 .54275 Mdot
.646 .54281 Mdot
.646 .54387 Mdot
.646 .54452 Mdot
.646 .54464 Mdot
.646 .54467 Mdot
.646 .54512 Mdot
.646 .54572 Mdot
.646 .54578 Mdot
.646 .54646 Mdot
.646 .54668 Mdot
.646 .54674 Mdot
.646 .54688 Mdot
.646 .54706 Mdot
.646 .5474 Mdot
.646 .54798 Mdot
.646 .54815 Mdot
.646 .54867 Mdot
.646 .54871 Mdot
.646 .5489 Mdot
.646 .54897 Mdot
.646 .54923 Mdot
.646 .54924 Mdot
.646 .54937 Mdot
.646 .54944 Mdot
.646 .55045 Mdot
.646 .55064 Mdot
.646 .55065 Mdot
.646 .55066 Mdot
.646 .55074 Mdot
.646 .55127 Mdot
.646 .55152 Mdot
.646 .55158 Mdot
.646 .55171 Mdot
.646 .55183 Mdot
.646 .552 Mdot
.646 .55217 Mdot
.646 .55244 Mdot
.646 .55247 Mdot
.646 .55267 Mdot
.646 .55305 Mdot
.646 .55315 Mdot
.646 .55321 Mdot
.646 .55336 Mdot
.646 .55346 Mdot
.646 .55356 Mdot
.646 .55372 Mdot
.646 .55396 Mdot
.646 .554 Mdot
.646 .55452 Mdot
.646 .55475 Mdot
.646 .55505 Mdot
.646 .55517 Mdot
.646 .55521 Mdot
.646 .55523 Mdot
.646 .55535 Mdot
.646 .55574 Mdot
.646 .55595 Mdot
.646 .55618 Mdot
.646 .55628 Mdot
.646 .55642 Mdot
.646 .55647 Mdot
.646 .55675 Mdot
.646 .55682 Mdot
.646 .55701 Mdot
.646 .55713 Mdot
.646 .55716 Mdot
.646 .55753 Mdot
.646 .55769 Mdot
.646 .55774 Mdot
.646 .55782 Mdot
.646 .55783 Mdot
.646 .55799 Mdot
.646 .55803 Mdot
.646 .55805 Mdot
.646 .55807 Mdot
.646 .55827 Mdot
.646 .55833 Mdot
.646 .55859 Mdot
.646 .55862 Mdot
.646 .55867 Mdot
.646 .55868 Mdot
.646 .55885 Mdot
.646 .55897 Mdot
.646 .55904 Mdot
.646 .55909 Mdot
.646 .55911 Mdot
.646 .55912 Mdot
.646 .55919 Mdot
.646 .55944 Mdot
.646 .55945 Mdot
.646 .55975 Mdot
.646 .55982 Mdot
.646 .55984 Mdot
.646 .56021 Mdot
.646 .56029 Mdot
.646 .56034 Mdot
.646 .56039 Mdot
.646 .56041 Mdot
.646 .56044 Mdot
.646 .56045 Mdot
.646 .56055 Mdot
.646 .5606 Mdot
.646 .56062 Mdot
.646 .56073 Mdot
.646 .56077 Mdot
.646 .56089 Mdot
.646 .5609 Mdot
.646 .56109 Mdot
.646 .5611 Mdot
.646 .56112 Mdot
.646 .5612 Mdot
.646 .56137 Mdot
.646 .56137 Mdot
.646 .5614 Mdot
.646 .56148 Mdot
.646 .5615 Mdot
.646 .5615 Mdot
.646 .56152 Mdot
.646 .56156 Mdot
.646 .56156 Mdot
.646 .56158 Mdot
.646 .56158 Mdot
.646 .56159 Mdot
.646 .56163 Mdot
.646 .56165 Mdot
.646 .56165 Mdot
.648 .15795 Mdot
.648 .15795 Mdot
.648 .15796 Mdot
.648 .15796 Mdot
.648 .15796 Mdot
.648 .15797 Mdot
.648 .15802 Mdot
.648 .15803 Mdot
.648 .15805 Mdot
.648 .15805 Mdot
.648 .15813 Mdot
.648 .15817 Mdot
.648 .15851 Mdot
.648 .15853 Mdot
.648 .15855 Mdot
.648 .15871 Mdot
.648 .15877 Mdot
.648 .15879 Mdot
.648 .15895 Mdot
.648 .15898 Mdot
.648 .15903 Mdot
.648 .15911 Mdot
.648 .15914 Mdot
.648 .15952 Mdot
.648 .15977 Mdot
.648 .15996 Mdot
.648 .16006 Mdot
.648 .1601 Mdot
.648 .16012 Mdot
.648 .1607 Mdot
.648 .16072 Mdot
.648 .16078 Mdot
.648 .16097 Mdot
.648 .16112 Mdot
.648 .1614 Mdot
.648 .16209 Mdot
.648 .16223 Mdot
.648 .16247 Mdot
.648 .16286 Mdot
.648 .16294 Mdot
.648 .16302 Mdot
.648 .16307 Mdot
.648 .1632 Mdot
.648 .1634 Mdot
.648 .16374 Mdot
.648 .16383 Mdot
.648 .16401 Mdot
.648 .16411 Mdot
.648 .16418 Mdot
.648 .16429 Mdot
.648 .16429 Mdot
.648 .16459 Mdot
.648 .16467 Mdot
.648 .16477 Mdot
.648 .16486 Mdot
.648 .16492 Mdot
.648 .16504 Mdot
.648 .16509 Mdot
.648 .16516 Mdot
.648 .16518 Mdot
.648 .16546 Mdot
.648 .16548 Mdot
.648 .16579 Mdot
.648 .16581 Mdot
.648 .16667 Mdot
.648 .16714 Mdot
.648 .16733 Mdot
.648 .16749 Mdot
.648 .16769 Mdot
.648 .16796 Mdot
.648 .16838 Mdot
.648 .16839 Mdot
.648 .17018 Mdot
.648 .17217 Mdot
.648 .17224 Mdot
.648 .17264 Mdot
.648 .1731 Mdot
.648 .17328 Mdot
.648 .17445 Mdot
.648 .17501 Mdot
.648 .17535 Mdot
.648 .17557 Mdot
.648 .17575 Mdot
.648 .17581 Mdot
.648 .17606 Mdot
.648 .17803 Mdot
.648 .1787 Mdot
.648 .17904 Mdot
.648 .1802 Mdot
.648 .18153 Mdot
.648 .182 Mdot
.648 .18213 Mdot
.648 .18235 Mdot
.648 .1831 Mdot
.648 .18383 Mdot
.648 .18396 Mdot
.648 .18448 Mdot
.648 .18478 Mdot
.648 .18604 Mdot
.648 .18929 Mdot
.648 .18974 Mdot
.648 .19026 Mdot
.648 .19168 Mdot
.648 .19191 Mdot
.648 .19246 Mdot
.648 .1927 Mdot
.648 .19358 Mdot
.648 .19358 Mdot
.648 .1949 Mdot
.648 .19558 Mdot
.648 .19772 Mdot
.648 .20028 Mdot
.648 .20598 Mdot
.648 .20642 Mdot
.648 .20751 Mdot
.648 .20759 Mdot
.648 .21008 Mdot
.648 .21018 Mdot
.648 .21092 Mdot
.648 .21093 Mdot
.648 .21107 Mdot
.648 .21108 Mdot
.648 .2112 Mdot
.648 .2112 Mdot
.648 .21123 Mdot
.648 .21131 Mdot
.648 .21134 Mdot
.648 .21186 Mdot
.648 .21203 Mdot
.648 .21223 Mdot
.648 .21227 Mdot
.648 .21231 Mdot
.648 .21252 Mdot
.648 .21316 Mdot
.648 .21362 Mdot
.648 .2154 Mdot
.648 .21573 Mdot
.648 .2169 Mdot
.648 .21733 Mdot
.648 .21769 Mdot
.648 .21795 Mdot
.648 .21823 Mdot
.648 .21944 Mdot
.648 .21979 Mdot
.648 .22025 Mdot
.648 .22088 Mdot
.648 .22114 Mdot
.648 .22119 Mdot
.648 .2217 Mdot
.648 .22322 Mdot
.648 .22355 Mdot
.648 .22364 Mdot
.648 .22402 Mdot
.648 .22415 Mdot
.648 .22516 Mdot
.648 .22523 Mdot
.648 .22559 Mdot
.648 .22792 Mdot
.648 .22884 Mdot
.648 .22903 Mdot
.648 .23006 Mdot
.648 .23049 Mdot
.648 .23063 Mdot
.648 .23103 Mdot
.648 .23195 Mdot
.648 .23247 Mdot
.648 .23266 Mdot
.648 .23286 Mdot
.648 .2338 Mdot
.648 .23644 Mdot
.648 .23776 Mdot
.648 .23832 Mdot
.648 .23858 Mdot
.648 .24067 Mdot
.648 .24074 Mdot
.648 .24319 Mdot
.648 .24655 Mdot
.648 .24664 Mdot
.648 .24672 Mdot
.648 .24695 Mdot
.648 .24779 Mdot
.648 .24834 Mdot
.648 .25054 Mdot
.648 .25071 Mdot
.648 .25189 Mdot
.648 .25252 Mdot
.648 .25269 Mdot
.648 .25371 Mdot
.648 .25392 Mdot
.648 .25449 Mdot
.648 .25619 Mdot
.648 .25689 Mdot
.648 .25727 Mdot
.648 .25861 Mdot
.648 .25866 Mdot
.648 .26406 Mdot
.648 .26572 Mdot
.648 .26652 Mdot
.648 .26706 Mdot
.648 .26721 Mdot
.648 .26755 Mdot
.648 .26769 Mdot
.648 .26892 Mdot
.648 .26921 Mdot
.648 .27137 Mdot
.648 .27224 Mdot
.648 .27245 Mdot
.648 .27282 Mdot
.648 .27291 Mdot
.648 .27397 Mdot
.648 .27414 Mdot
.648 .27674 Mdot
.648 .27727 Mdot
.648 .2791 Mdot
.648 .2793 Mdot
.648 .27978 Mdot
.648 .28027 Mdot
.648 .28132 Mdot
.648 .28149 Mdot
.648 .28235 Mdot
.648 .28431 Mdot
.648 .28619 Mdot
.648 .28621 Mdot
.648 .28721 Mdot
.648 .28739 Mdot
.648 .28762 Mdot
.648 .28817 Mdot
.648 .29023 Mdot
.648 .29059 Mdot
.648 .29072 Mdot
.648 .29141 Mdot
.648 .29166 Mdot
.648 .29192 Mdot
.648 .29287 Mdot
.648 .29306 Mdot
.648 .29444 Mdot
.648 .29467 Mdot
.648 .29717 Mdot
.648 .29734 Mdot
.648 .29864 Mdot
.648 .29878 Mdot
.648 .29902 Mdot
.648 .29952 Mdot
.648 .3002 Mdot
.648 .30133 Mdot
.648 .30187 Mdot
.648 .30196 Mdot
.648 .30265 Mdot
.648 .30366 Mdot
.648 .30603 Mdot
.648 .30678 Mdot
.648 .30716 Mdot
.648 .30797 Mdot
.648 .30824 Mdot
.648 .30874 Mdot
.648 .30881 Mdot
.648 .30981 Mdot
.648 .30989 Mdot
.648 .31105 Mdot
.648 .31129 Mdot
.648 .31231 Mdot
.648 .31428 Mdot
.648 .31448 Mdot
.648 .31518 Mdot
.648 .31548 Mdot
.648 .31633 Mdot
.648 .31659 Mdot
.648 .32074 Mdot
.648 .32126 Mdot
.648 .32156 Mdot
.648 .32212 Mdot
.648 .324 Mdot
.648 .32401 Mdot
.648 .32465 Mdot
.648 .32477 Mdot
.648 .32489 Mdot
.648 .32548 Mdot
.648 .32599 Mdot
.648 .32652 Mdot
.648 .32677 Mdot
.648 .32678 Mdot
.648 .32719 Mdot
.648 .32756 Mdot
.648 .32764 Mdot
.648 .32787 Mdot
.648 .32797 Mdot
.648 .32799 Mdot
.648 .32835 Mdot
.648 .32838 Mdot
.648 .32878 Mdot
.648 .32881 Mdot
.648 .33105 Mdot
.648 .33136 Mdot
.648 .33574 Mdot
.648 .33612 Mdot
.648 .33854 Mdot
.648 .33889 Mdot
.648 .33914 Mdot
.648 .34156 Mdot
.648 .34245 Mdot
.648 .34345 Mdot
.648 .3438 Mdot
.648 .3446 Mdot
.648 .34944 Mdot
.648 .35152 Mdot
.648 .35272 Mdot
.648 .35544 Mdot
.648 .35857 Mdot
.648 .3588 Mdot
.648 .36071 Mdot
.648 .36114 Mdot
.648 .36121 Mdot
.648 .36122 Mdot
.648 .36128 Mdot
.648 .36128 Mdot
.648 .3613 Mdot
.648 .36134 Mdot
.648 .36135 Mdot
.648 .36162 Mdot
.648 .3617 Mdot
.648 .3618 Mdot
.648 .36182 Mdot
.648 .36195 Mdot
.648 .36227 Mdot
.648 .3625 Mdot
.648 .36338 Mdot
.648 .3645 Mdot
.648 .36463 Mdot
.648 .36476 Mdot
.648 .36573 Mdot
.648 .36602 Mdot
.648 .36617 Mdot
.648 .36641 Mdot
.648 .36712 Mdot
.648 .36728 Mdot
.648 .36756 Mdot
.648 .36802 Mdot
.648 .36805 Mdot
.648 .36822 Mdot
.648 .36928 Mdot
.648 .36978 Mdot
.648 .37043 Mdot
.648 .37049 Mdot
.648 .37067 Mdot
.648 .37189 Mdot
.648 .37304 Mdot
.648 .37361 Mdot
.648 .37385 Mdot
.648 .37395 Mdot
.648 .37487 Mdot
.648 .3759 Mdot
.648 .37733 Mdot
.648 .37746 Mdot
.648 .3778 Mdot
.648 .37802 Mdot
.648 .37891 Mdot
.648 .37898 Mdot
.648 .37978 Mdot
.648 .38019 Mdot
.648 .3805 Mdot
.648 .38117 Mdot
.648 .38144 Mdot
.648 .38212 Mdot
.648 .38214 Mdot
.648 .38487 Mdot
.648 .38543 Mdot
.648 .38562 Mdot
.648 .38619 Mdot
.648 .38733 Mdot
.648 .38758 Mdot
.648 .38803 Mdot
.648 .38986 Mdot
.648 .38994 Mdot
.648 .39029 Mdot
.648 .39068 Mdot
.648 .39074 Mdot
.648 .39105 Mdot
.648 .39176 Mdot
.648 .39244 Mdot
.648 .39295 Mdot
.648 .39315 Mdot
.648 .39406 Mdot
.648 .3943 Mdot
.648 .39489 Mdot
.648 .39537 Mdot
.648 .39545 Mdot
.648 .39639 Mdot
.648 .39698 Mdot
.648 .39739 Mdot
.648 .39797 Mdot
.648 .398 Mdot
.648 .39941 Mdot
.648 .39967 Mdot
.648 .40017 Mdot
.648 .40036 Mdot
.648 .40073 Mdot
.648 .40121 Mdot
.648 .40156 Mdot
.648 .40223 Mdot
.648 .40254 Mdot
.648 .40292 Mdot
.648 .40301 Mdot
.648 .40459 Mdot
.648 .40469 Mdot
.648 .4055 Mdot
.648 .40635 Mdot
.648 .40643 Mdot
.648 .40643 Mdot
.648 .40657 Mdot
.648 .40941 Mdot
.648 .40953 Mdot
.648 .41033 Mdot
.648 .41132 Mdot
.648 .41194 Mdot
.648 .41231 Mdot
.648 .41389 Mdot
.648 .41457 Mdot
.648 .41496 Mdot
.648 .41584 Mdot
.648 .41686 Mdot
.648 .41693 Mdot
.648 .41755 Mdot
.648 .41769 Mdot
.648 .41771 Mdot
.648 .41771 Mdot
.648 .41773 Mdot
.648 .41774 Mdot
.648 .41774 Mdot
.648 .41775 Mdot
.648 .41784 Mdot
.648 .41787 Mdot
.648 .4179 Mdot
.648 .41791 Mdot
.648 .41795 Mdot
.648 .41805 Mdot
.648 .41813 Mdot
.648 .41841 Mdot
.648 .41877 Mdot
.648 .41882 Mdot
.648 .41886 Mdot
.648 .41917 Mdot
.648 .41927 Mdot
.648 .41931 Mdot
.648 .41939 Mdot
.648 .41962 Mdot
.648 .41967 Mdot
.648 .41976 Mdot
.648 .41991 Mdot
.648 .41992 Mdot
.648 .41997 Mdot
.648 .42048 Mdot
.648 .42069 Mdot
.648 .42071 Mdot
.648 .42077 Mdot
.648 .42116 Mdot
.648 .42153 Mdot
.648 .42171 Mdot
.648 .42179 Mdot
.648 .42182 Mdot
.648 .42212 Mdot
.648 .42291 Mdot
.648 .42295 Mdot
.648 .42306 Mdot
.648 .42342 Mdot
.648 .42344 Mdot
.648 .4237 Mdot
.648 .42383 Mdot
.648 .42393 Mdot
.648 .42414 Mdot
.648 .42423 Mdot
.648 .42552 Mdot
.648 .42576 Mdot
.648 .42621 Mdot
.648 .42694 Mdot
.648 .42697 Mdot
.648 .42708 Mdot
.648 .4272 Mdot
.648 .42722 Mdot
.648 .42732 Mdot
.648 .42755 Mdot
.648 .42794 Mdot
.648 .428 Mdot
.648 .42837 Mdot
.648 .42856 Mdot
.648 .42872 Mdot
.648 .42904 Mdot
.648 .42923 Mdot
.648 .42937 Mdot
.648 .42955 Mdot
.648 .42956 Mdot
.648 .43002 Mdot
.648 .4301 Mdot
.648 .43026 Mdot
.648 .43033 Mdot
.648 .43045 Mdot
.648 .4306 Mdot
.648 .43071 Mdot
.648 .43093 Mdot
.648 .43103 Mdot
.648 .43115 Mdot
.648 .43118 Mdot
.648 .43169 Mdot
.648 .43172 Mdot
.648 .43226 Mdot
.648 .43229 Mdot
.648 .43229 Mdot
.648 .43233 Mdot
.648 .43329 Mdot
.648 .43387 Mdot
.648 .43471 Mdot
.648 .43506 Mdot
.648 .43535 Mdot
.648 .4357 Mdot
.648 .43595 Mdot
.648 .43619 Mdot
.648 .43668 Mdot
.648 .43686 Mdot
.648 .43694 Mdot
.648 .43696 Mdot
.648 .4374 Mdot
.648 .43796 Mdot
.648 .43799 Mdot
.648 .43807 Mdot
.648 .43907 Mdot
.648 .43946 Mdot
.648 .44011 Mdot
.648 .44075 Mdot
.648 .44076 Mdot
.648 .44109 Mdot
.648 .44265 Mdot
.648 .44266 Mdot
.648 .44315 Mdot
.648 .44358 Mdot
.648 .4437 Mdot
.648 .44422 Mdot
.648 .44422 Mdot
.648 .44439 Mdot
.648 .44475 Mdot
.648 .44518 Mdot
.648 .44549 Mdot
.648 .44549 Mdot
.648 .44611 Mdot
.648 .44639 Mdot
.648 .4464 Mdot
.648 .44729 Mdot
.648 .44749 Mdot
.648 .44749 Mdot
.648 .44823 Mdot
.648 .44844 Mdot
.648 .44901 Mdot
.648 .44905 Mdot
.648 .44907 Mdot
.648 .44939 Mdot
.648 .44969 Mdot
.648 .4498 Mdot
.648 .45021 Mdot
.648 .45169 Mdot
.648 .45224 Mdot
.648 .45226 Mdot
.648 .45332 Mdot
.648 .45349 Mdot
.648 .45439 Mdot
.648 .45459 Mdot
.648 .45503 Mdot
.648 .45516 Mdot
.648 .45668 Mdot
.648 .45679 Mdot
.648 .45684 Mdot
.648 .45705 Mdot
.648 .45776 Mdot
.648 .45848 Mdot
.648 .45851 Mdot
.648 .45863 Mdot
.648 .45892 Mdot
.648 .4592 Mdot
.648 .45972 Mdot
.648 .45996 Mdot
.648 .4601 Mdot
.648 .46017 Mdot
.648 .46049 Mdot
.648 .46053 Mdot
.648 .46106 Mdot
.648 .46152 Mdot
.648 .46172 Mdot
.648 .46207 Mdot
.648 .46289 Mdot
.648 .46308 Mdot
.648 .4634 Mdot
.648 .4639 Mdot
.648 .46431 Mdot
.648 .46437 Mdot
.648 .46581 Mdot
.648 .46588 Mdot
.648 .46588 Mdot
.648 .46592 Mdot
.648 .46635 Mdot
.648 .46676 Mdot
.648 .46681 Mdot
.648 .4676 Mdot
.648 .46764 Mdot
.648 .46784 Mdot
.648 .46799 Mdot
.648 .46832 Mdot
.648 .46849 Mdot
.648 .46873 Mdot
.648 .46891 Mdot
.648 .46901 Mdot
.648 .46926 Mdot
.648 .46939 Mdot
.648 .47008 Mdot
.648 .47009 Mdot
.648 .47038 Mdot
.648 .47058 Mdot
.648 .47087 Mdot
.648 .47133 Mdot
.648 .47137 Mdot
.648 .4716 Mdot
.648 .47189 Mdot
.648 .47201 Mdot
.648 .47245 Mdot
.648 .47254 Mdot
.648 .47279 Mdot
.648 .47312 Mdot
.648 .47346 Mdot
.648 .47361 Mdot
.648 .47364 Mdot
.648 .47382 Mdot
.648 .47399 Mdot
.648 .47403 Mdot
.648 .47491 Mdot
.648 .47512 Mdot
.648 .47524 Mdot
.648 .47578 Mdot
.648 .47606 Mdot
.648 .47614 Mdot
.648 .47641 Mdot
.648 .47769 Mdot
.648 .4777 Mdot
.648 .47802 Mdot
.648 .47815 Mdot
.648 .47846 Mdot
.648 .47861 Mdot
.648 .4788 Mdot
.648 .47917 Mdot
.648 .4792 Mdot
.648 .47962 Mdot
.648 .47972 Mdot
.648 .47988 Mdot
.648 .47994 Mdot
.648 .4806 Mdot
.648 .48107 Mdot
.648 .48149 Mdot
.648 .48154 Mdot
.648 .48165 Mdot
.648 .48191 Mdot
.648 .48244 Mdot
.648 .48299 Mdot
.648 .48307 Mdot
.648 .4831 Mdot
.648 .4834 Mdot
.648 .48362 Mdot
.648 .4841 Mdot
.648 .48418 Mdot
.648 .48419 Mdot
.648 .4844 Mdot
.648 .48453 Mdot
.648 .4846 Mdot
.648 .48492 Mdot
.648 .48503 Mdot
.648 .48509 Mdot
.648 .48523 Mdot
.648 .48566 Mdot
.648 .48572 Mdot
.648 .48578 Mdot
.648 .48628 Mdot
.648 .48667 Mdot
.648 .48677 Mdot
.648 .48692 Mdot
.648 .48697 Mdot
.648 .48698 Mdot
.648 .48703 Mdot
.648 .48706 Mdot
.648 .48718 Mdot
.648 .48719 Mdot
.648 .48721 Mdot
.648 .48721 Mdot
.648 .48721 Mdot
.648 .48724 Mdot
.648 .48724 Mdot
.648 .48728 Mdot
.648 .48747 Mdot
.648 .48831 Mdot
.648 .48841 Mdot
.648 .48979 Mdot
.648 .49097 Mdot
.648 .4915 Mdot
.648 .4924 Mdot
.648 .49447 Mdot
.648 .49482 Mdot
.648 .49496 Mdot
.648 .49539 Mdot
.648 .49577 Mdot
.648 .49679 Mdot
.648 .4969 Mdot
.648 .49704 Mdot
.648 .49806 Mdot
.648 .49822 Mdot
.648 .50004 Mdot
.648 .50017 Mdot
.648 .5011 Mdot
.648 .50111 Mdot
.648 .50127 Mdot
.648 .50128 Mdot
.648 .50143 Mdot
.648 .50144 Mdot
.648 .50148 Mdot
.648 .50157 Mdot
.648 .50161 Mdot
.648 .50176 Mdot
.648 .50193 Mdot
.648 .50193 Mdot
.648 .50203 Mdot
.648 .50225 Mdot
.648 .50246 Mdot
.648 .5027 Mdot
.648 .50275 Mdot
.648 .5028 Mdot
.648 .50306 Mdot
.648 .50307 Mdot
.648 .50383 Mdot
.648 .50406 Mdot
.648 .50418 Mdot
.648 .50439 Mdot
.648 .50607 Mdot
.648 .50617 Mdot
.648 .50651 Mdot
.648 .50663 Mdot
.648 .50691 Mdot
.648 .50699 Mdot
.648 .50778 Mdot
.648 .50818 Mdot
.648 .50828 Mdot
.648 .50874 Mdot
.648 .50877 Mdot
.648 .50917 Mdot
.648 .50919 Mdot
.648 .50939 Mdot
.648 .5095 Mdot
.648 .50982 Mdot
.648 .50997 Mdot
.648 .51026 Mdot
.648 .51119 Mdot
.648 .51159 Mdot
.648 .51186 Mdot
.648 .51189 Mdot
.648 .5121 Mdot
.648 .51254 Mdot
.648 .51281 Mdot
.648 .513 Mdot
.648 .51309 Mdot
.648 .51315 Mdot
.648 .51365 Mdot
.648 .51372 Mdot
.648 .51468 Mdot
.648 .51477 Mdot
.648 .5153 Mdot
.648 .51537 Mdot
.648 .51574 Mdot
.648 .51584 Mdot
.648 .51593 Mdot
.648 .5162 Mdot
.648 .51625 Mdot
.648 .51638 Mdot
.648 .51717 Mdot
.648 .51738 Mdot
.648 .51746 Mdot
.648 .51753 Mdot
.648 .51791 Mdot
.648 .51792 Mdot
.648 .51863 Mdot
.648 .51937 Mdot
.648 .51969 Mdot
.648 .51976 Mdot
.648 .52015 Mdot
.648 .52033 Mdot
.648 .52051 Mdot
.648 .52059 Mdot
.648 .52127 Mdot
.648 .52147 Mdot
.648 .52244 Mdot
.648 .5225 Mdot
.648 .52289 Mdot
.648 .52293 Mdot
.648 .52306 Mdot
.648 .52314 Mdot
.648 .52346 Mdot
.648 .52426 Mdot
.648 .52436 Mdot
.648 .52481 Mdot
.648 .52487 Mdot
.648 .52499 Mdot
.648 .52505 Mdot
.648 .52524 Mdot
.648 .52554 Mdot
.648 .52614 Mdot
.648 .5281 Mdot
.648 .52812 Mdot
.648 .5286 Mdot
.648 .52874 Mdot
.648 .52899 Mdot
.648 .5296 Mdot
.648 .52981 Mdot
.648 .52988 Mdot
.648 .53025 Mdot
.648 .53031 Mdot
.648 .53054 Mdot
.648 .53095 Mdot
.648 .53102 Mdot
.648 .5318 Mdot
.648 .53199 Mdot
.648 .53229 Mdot
.648 .53237 Mdot
.648 .5324 Mdot
.648 .53243 Mdot
.648 .53362 Mdot
.648 .53448 Mdot
.648 .53451 Mdot
.648 .53524 Mdot
.648 .53533 Mdot
.648 .53553 Mdot
.648 .53599 Mdot
.648 .53691 Mdot
.648 .53723 Mdot
.648 .5373 Mdot
.648 .53737 Mdot
.648 .53755 Mdot
.648 .53787 Mdot
.648 .53801 Mdot
.648 .53805 Mdot
.648 .5382 Mdot
.648 .53856 Mdot
.648 .53862 Mdot
.648 .53894 Mdot
.648 .53974 Mdot
.648 .53986 Mdot
.648 .53989 Mdot
.648 .54023 Mdot
.648 .54028 Mdot
.648 .54041 Mdot
.648 .54044 Mdot
.648 .54055 Mdot
.648 .54107 Mdot
.648 .54125 Mdot
.648 .54126 Mdot
.648 .54135 Mdot
.648 .54157 Mdot
.648 .54172 Mdot
.648 .54184 Mdot
.648 .54225 Mdot
.648 .54234 Mdot
.648 .54243 Mdot
.648 .54256 Mdot
.648 .5427 Mdot
.648 .5431 Mdot
.648 .54321 Mdot
.648 .54381 Mdot
.648 .54397 Mdot
.648 .54418 Mdot
.648 .54425 Mdot
.648 .54426 Mdot
.648 .54428 Mdot
.648 .54435 Mdot
.648 .5444 Mdot
.648 .54458 Mdot
.648 .54459 Mdot
.648 .54461 Mdot
.648 .54462 Mdot
.648 .54463 Mdot
.648 .54467 Mdot
.648 .54467 Mdot
.648 .54471 Mdot
.648 .54472 Mdot
.648 .54497 Mdot
.648 .545 Mdot
.648 .54583 Mdot
.648 .54586 Mdot
.648 .54622 Mdot
.648 .54637 Mdot
.648 .54827 Mdot
.648 .54911 Mdot
.648 .54981 Mdot
.648 .55004 Mdot
.648 .55047 Mdot
.648 .55047 Mdot
.648 .55076 Mdot
.648 .55084 Mdot
.648 .55102 Mdot
.648 .55109 Mdot
.648 .55156 Mdot
.648 .55173 Mdot
.648 .55187 Mdot
.648 .55293 Mdot
.648 .55334 Mdot
.648 .55344 Mdot
.648 .55361 Mdot
.648 .55364 Mdot
.648 .55388 Mdot
.648 .55412 Mdot
.648 .5542 Mdot
.648 .55424 Mdot
.648 .55439 Mdot
.648 .55482 Mdot
.648 .55519 Mdot
.648 .5553 Mdot
.648 .55552 Mdot
.648 .55615 Mdot
.648 .55623 Mdot
.648 .55625 Mdot
.648 .5563 Mdot
.648 .55637 Mdot
.648 .55648 Mdot
.648 .55666 Mdot
.648 .55704 Mdot
.648 .55709 Mdot
.648 .55724 Mdot
.648 .55737 Mdot
.648 .55739 Mdot
.648 .55802 Mdot
.648 .55859 Mdot
.648 .55859 Mdot
.648 .55873 Mdot
.648 .55881 Mdot
.648 .55888 Mdot
.648 .55893 Mdot
.648 .55899 Mdot
.648 .55914 Mdot
.648 .55941 Mdot
.648 .55942 Mdot
.648 .55951 Mdot
.648 .55952 Mdot
.648 .55961 Mdot
.648 .55961 Mdot
.648 .55963 Mdot
.648 .55965 Mdot
.648 .55969 Mdot
.648 .55971 Mdot
.648 .55974 Mdot
.648 .55977 Mdot
.648 .5598 Mdot
.648 .55989 Mdot
.648 .55989 Mdot
.648 .55992 Mdot
.648 .55994 Mdot
.648 .55998 Mdot
.648 .56003 Mdot
.648 .56006 Mdot
.648 .56017 Mdot
.648 .56023 Mdot
.648 .56027 Mdot
.648 .56029 Mdot
.648 .56031 Mdot
.648 .56034 Mdot
.648 .56046 Mdot
.648 .56046 Mdot
.648 .56054 Mdot
.648 .56058 Mdot
.648 .5608 Mdot
.648 .56089 Mdot
.648 .56093 Mdot
.648 .56099 Mdot
.648 .56101 Mdot
.648 .56102 Mdot
.648 .5612 Mdot
.648 .56121 Mdot
.648 .56122 Mdot
.648 .56125 Mdot
.648 .56131 Mdot
.648 .56139 Mdot
.648 .56151 Mdot
.648 .56152 Mdot
.648 .56154 Mdot
.648 .56156 Mdot
.648 .56157 Mdot
.648 .56162 Mdot
.648 .56163 Mdot
.648 .56164 Mdot
.648 .56169 Mdot
.648 .5617 Mdot
.648 .56171 Mdot
.648 .56181 Mdot
.648 .56183 Mdot
.648 .56185 Mdot
.648 .56185 Mdot
.648 .56186 Mdot
.648 .56186 Mdot
.648 .56187 Mdot
.648 .56188 Mdot
.648 .56188 Mdot
.648 .56188 Mdot
.648 .56188 Mdot
.648 .56188 Mdot
.65 .15729 Mdot
.65 .1573 Mdot
.65 .15732 Mdot
.65 .15734 Mdot
.65 .1574 Mdot
.65 .15754 Mdot
.65 .15764 Mdot
.65 .15768 Mdot
.65 .15787 Mdot
.65 .15788 Mdot
.65 .15806 Mdot
.65 .15808 Mdot
.65 .15812 Mdot
.65 .15837 Mdot
.65 .15862 Mdot
.65 .15884 Mdot
.65 .15905 Mdot
.65 .15919 Mdot
.65 .16 Mdot
.65 .16023 Mdot
.65 .16034 Mdot
.65 .1604 Mdot
.65 .16042 Mdot
.65 .16049 Mdot
.65 .16086 Mdot
.65 .16092 Mdot
.65 .16122 Mdot
.65 .1615 Mdot
.65 .1616 Mdot
.65 .16164 Mdot
.65 .16187 Mdot
.65 .16195 Mdot
.65 .16208 Mdot
.65 .16238 Mdot
.65 .16254 Mdot
.65 .16255 Mdot
.65 .16298 Mdot
.65 .16353 Mdot
.65 .16395 Mdot
.65 .1641 Mdot
.65 .16453 Mdot
.65 .16526 Mdot
.65 .16539 Mdot
.65 .16553 Mdot
.65 .16557 Mdot
.65 .1656 Mdot
.65 .16566 Mdot
.65 .16574 Mdot
.65 .16592 Mdot
.65 .16604 Mdot
.65 .16688 Mdot
.65 .16757 Mdot
.65 .16781 Mdot
.65 .16802 Mdot
.65 .16848 Mdot
.65 .16854 Mdot
.65 .16881 Mdot
.65 .16978 Mdot
.65 .17016 Mdot
.65 .17039 Mdot
.65 .1706 Mdot
.65 .17077 Mdot
.65 .17132 Mdot
.65 .172 Mdot
.65 .17225 Mdot
.65 .17265 Mdot
.65 .17265 Mdot
.65 .17286 Mdot
.65 .17341 Mdot
.65 .17361 Mdot
.65 .17371 Mdot
.65 .17376 Mdot
.65 .17387 Mdot
.65 .17484 Mdot
.65 .1757 Mdot
.65 .17638 Mdot
.65 .1768 Mdot
.65 .17725 Mdot
.65 .17886 Mdot
.65 .17994 Mdot
.65 .18087 Mdot
.65 .1812 Mdot
.65 .18151 Mdot
.65 .18174 Mdot
.65 .18402 Mdot
.65 .18436 Mdot
.65 .18445 Mdot
.65 .18449 Mdot
.65 .18455 Mdot
.65 .18463 Mdot
.65 .185 Mdot
.65 .1858 Mdot
.65 .1866 Mdot
.65 .18667 Mdot
.65 .18734 Mdot
.65 .1898 Mdot
.65 .18985 Mdot
.65 .19023 Mdot
.65 .19066 Mdot
.65 .19176 Mdot
.65 .1918 Mdot
.65 .19184 Mdot
.65 .19225 Mdot
.65 .19278 Mdot
.65 .19452 Mdot
.65 .19488 Mdot
.65 .19707 Mdot
.65 .19744 Mdot
.65 .19844 Mdot
.65 .20339 Mdot
.65 .2035 Mdot
.65 .20359 Mdot
.65 .2036 Mdot
.65 .20382 Mdot
.65 .204 Mdot
.65 .20451 Mdot
.65 .20467 Mdot
.65 .20577 Mdot
.65 .20621 Mdot
.65 .20713 Mdot
.65 .20731 Mdot
.65 .20786 Mdot
.65 .20787 Mdot
.65 .21011 Mdot
.65 .21125 Mdot
.65 .21224 Mdot
.65 .21248 Mdot
.65 .21294 Mdot
.65 .21323 Mdot
.65 .21494 Mdot
.65 .21529 Mdot
.65 .21558 Mdot
.65 .21589 Mdot
.65 .21684 Mdot
.65 .21873 Mdot
.65 .21894 Mdot
.65 .21962 Mdot
.65 .2197 Mdot
.65 .22173 Mdot
.65 .22183 Mdot
.65 .22248 Mdot
.65 .2238 Mdot
.65 .22446 Mdot
.65 .22452 Mdot
.65 .22454 Mdot
.65 .22458 Mdot
.65 .22547 Mdot
.65 .22585 Mdot
.65 .22621 Mdot
.65 .22635 Mdot
.65 .22643 Mdot
.65 .2265 Mdot
.65 .22656 Mdot
.65 .22863 Mdot
.65 .23061 Mdot
.65 .23062 Mdot
.65 .23117 Mdot
.65 .23304 Mdot
.65 .23391 Mdot
.65 .23589 Mdot
.65 .23696 Mdot
.65 .23766 Mdot
.65 .23821 Mdot
.65 .23873 Mdot
.65 .23911 Mdot
.65 .24022 Mdot
.65 .24081 Mdot
.65 .24148 Mdot
.65 .24173 Mdot
.65 .24262 Mdot
.65 .2429 Mdot
.65 .24362 Mdot
.65 .24378 Mdot
.65 .24424 Mdot
.65 .24585 Mdot
.65 .2473 Mdot
.65 .2473 Mdot
.65 .24911 Mdot
.65 .24921 Mdot
.65 .24961 Mdot
.65 .25002 Mdot
.65 .25004 Mdot
.65 .25004 Mdot
.65 .25099 Mdot
.65 .25229 Mdot
.65 .25366 Mdot
.65 .25427 Mdot
.65 .25442 Mdot
.65 .25543 Mdot
.65 .25816 Mdot
.65 .25854 Mdot
.65 .25926 Mdot
.65 .25993 Mdot
.65 .26053 Mdot
.65 .26328 Mdot
.65 .26386 Mdot
.65 .26407 Mdot
.65 .26536 Mdot
.65 .26557 Mdot
.65 .2672 Mdot
.65 .26821 Mdot
.65 .27052 Mdot
.65 .27165 Mdot
.65 .2719 Mdot
.65 .27196 Mdot
.65 .272 Mdot
.65 .27203 Mdot
.65 .27233 Mdot
.65 .27434 Mdot
.65 .27459 Mdot
.65 .27737 Mdot
.65 .28129 Mdot
.65 .28129 Mdot
.65 .28166 Mdot
.65 .28253 Mdot
.65 .28306 Mdot
.65 .28322 Mdot
.65 .28343 Mdot
.65 .28365 Mdot
.65 .28404 Mdot
.65 .28503 Mdot
.65 .28537 Mdot
.65 .2861 Mdot
.65 .28811 Mdot
.65 .28858 Mdot
.65 .28865 Mdot
.65 .28869 Mdot
.65 .28874 Mdot
.65 .28891 Mdot
.65 .28908 Mdot
.65 .29001 Mdot
.65 .29078 Mdot
.65 .29216 Mdot
.65 .29451 Mdot
.65 .29637 Mdot
.65 .29666 Mdot
.65 .29688 Mdot
.65 .29924 Mdot
.65 .30248 Mdot
.65 .30271 Mdot
.65 .30469 Mdot
.65 .30529 Mdot
.65 .30635 Mdot
.65 .31036 Mdot
.65 .3105 Mdot
.65 .31082 Mdot
.65 .31103 Mdot
.65 .31361 Mdot
.65 .31453 Mdot
.65 .31456 Mdot
.65 .31541 Mdot
.65 .31643 Mdot
.65 .31722 Mdot
.65 .31786 Mdot
.65 .31845 Mdot
.65 .32066 Mdot
.65 .3215 Mdot
.65 .32154 Mdot
.65 .32238 Mdot
.65 .32249 Mdot
.65 .32304 Mdot
.65 .32368 Mdot
.65 .32375 Mdot
.65 .32414 Mdot
.65 .32428 Mdot
.65 .32448 Mdot
.65 .32496 Mdot
.65 .3252 Mdot
.65 .32523 Mdot
.65 .32666 Mdot
.65 .32745 Mdot
.65 .32956 Mdot
.65 .32977 Mdot
.65 .3309 Mdot
.65 .33167 Mdot
.65 .33217 Mdot
.65 .33272 Mdot
.65 .33614 Mdot
.65 .33693 Mdot
.65 .33743 Mdot
.65 .3376 Mdot
.65 .33769 Mdot
.65 .33773 Mdot
.65 .33783 Mdot
.65 .33867 Mdot
.65 .3394 Mdot
.65 .33996 Mdot
.65 .3403 Mdot
.65 .34193 Mdot
.65 .34275 Mdot
.65 .34391 Mdot
.65 .34409 Mdot
.65 .34595 Mdot
.65 .34693 Mdot
.65 .34747 Mdot
.65 .34796 Mdot
.65 .34955 Mdot
.65 .34958 Mdot
.65 .35009 Mdot
.65 .35078 Mdot
.65 .35081 Mdot
.65 .35109 Mdot
.65 .35141 Mdot
.65 .35756 Mdot
.65 .35761 Mdot
.65 .35761 Mdot
.65 .35773 Mdot
.65 .35783 Mdot
.65 .35819 Mdot
.65 .35901 Mdot
.65 .35958 Mdot
.65 .35987 Mdot
.65 .36103 Mdot
.65 .36161 Mdot
.65 .36211 Mdot
.65 .36223 Mdot
.65 .36246 Mdot
.65 .36345 Mdot
.65 .36391 Mdot
.65 .36528 Mdot
.65 .36538 Mdot
.65 .3657 Mdot
.65 .36669 Mdot
.65 .36674 Mdot
.65 .36766 Mdot
.65 .36796 Mdot
.65 .3686 Mdot
.65 .36876 Mdot
.65 .36886 Mdot
.65 .36889 Mdot
.65 .36985 Mdot
.65 .37098 Mdot
.65 .3718 Mdot
.65 .37304 Mdot
.65 .3735 Mdot
.65 .37403 Mdot
.65 .37488 Mdot
.65 .37552 Mdot
.65 .37589 Mdot
.65 .376 Mdot
.65 .37637 Mdot
.65 .37781 Mdot
.65 .37855 Mdot
.65 .37859 Mdot
.65 .37875 Mdot
.65 .37891 Mdot
.65 .37892 Mdot
.65 .38061 Mdot
.65 .38067 Mdot
.65 .38229 Mdot
.65 .38257 Mdot
.65 .38283 Mdot
.65 .38306 Mdot
.65 .38434 Mdot
.65 .38442 Mdot
.65 .38492 Mdot
.65 .38562 Mdot
.65 .386 Mdot
.65 .38729 Mdot
.65 .38738 Mdot
.65 .3874 Mdot
.65 .38754 Mdot
.65 .38829 Mdot
.65 .38838 Mdot
.65 .39083 Mdot
.65 .39083 Mdot
.65 .39097 Mdot
.65 .39128 Mdot
.65 .39231 Mdot
.65 .39329 Mdot
.65 .39348 Mdot
.65 .39363 Mdot
.65 .39396 Mdot
.65 .39472 Mdot
.65 .39638 Mdot
.65 .3972 Mdot
.65 .39966 Mdot
.65 .40103 Mdot
.65 .40108 Mdot
.65 .40126 Mdot
.65 .40336 Mdot
.65 .40358 Mdot
.65 .40377 Mdot
.65 .40452 Mdot
.65 .40481 Mdot
.65 .40513 Mdot
.65 .40531 Mdot
.65 .40553 Mdot
.65 .40568 Mdot
.65 .40573 Mdot
.65 .40595 Mdot
.65 .40603 Mdot
.65 .40604 Mdot
.65 .40652 Mdot
.65 .40748 Mdot
.65 .40755 Mdot
.65 .40818 Mdot
.65 .40835 Mdot
.65 .40853 Mdot
.65 .40965 Mdot
.65 .40991 Mdot
.65 .41008 Mdot
.65 .41013 Mdot
.65 .41021 Mdot
.65 .41049 Mdot
.65 .41102 Mdot
.65 .41155 Mdot
.65 .4122 Mdot
.65 .41286 Mdot
.65 .41318 Mdot
.65 .41405 Mdot
.65 .41663 Mdot
.65 .41665 Mdot
.65 .41665 Mdot
.65 .41669 Mdot
.65 .41672 Mdot
.65 .41684 Mdot
.65 .4171 Mdot
.65 .41729 Mdot
.65 .41738 Mdot
.65 .41774 Mdot
.65 .41775 Mdot
.65 .41794 Mdot
.65 .4181 Mdot
.65 .41814 Mdot
.65 .41821 Mdot
.65 .41853 Mdot
.65 .41868 Mdot
.65 .41912 Mdot
.65 .41916 Mdot
.65 .41926 Mdot
.65 .41958 Mdot
.65 .41989 Mdot
.65 .41999 Mdot
.65 .42019 Mdot
.65 .42024 Mdot
.65 .42028 Mdot
.65 .42029 Mdot
.65 .42122 Mdot
.65 .42162 Mdot
.65 .42177 Mdot
.65 .42194 Mdot
.65 .42221 Mdot
.65 .42241 Mdot
.65 .42253 Mdot
.65 .42257 Mdot
.65 .42269 Mdot
.65 .42339 Mdot
.65 .4234 Mdot
.65 .42345 Mdot
.65 .42351 Mdot
.65 .42405 Mdot
.65 .42407 Mdot
.65 .42459 Mdot
.65 .42468 Mdot
.65 .42476 Mdot
.65 .42484 Mdot
.65 .42528 Mdot
.65 .42543 Mdot
.65 .42566 Mdot
.65 .42622 Mdot
.65 .42652 Mdot
.65 .42655 Mdot
.65 .42733 Mdot
.65 .42733 Mdot
.65 .42748 Mdot
.65 .42812 Mdot
.65 .42834 Mdot
.65 .42858 Mdot
.65 .42912 Mdot
.65 .42938 Mdot
.65 .43018 Mdot
.65 .43062 Mdot
.65 .43063 Mdot
.65 .4315 Mdot
.65 .43174 Mdot
.65 .43184 Mdot
.65 .43194 Mdot
.65 .432 Mdot
.65 .43207 Mdot
.65 .43212 Mdot
.65 .43213 Mdot
.65 .4322 Mdot
.65 .43223 Mdot
.65 .43239 Mdot
.65 .4327 Mdot
.65 .43272 Mdot
.65 .43293 Mdot
.65 .43298 Mdot
.65 .43356 Mdot
.65 .43384 Mdot
.65 .43423 Mdot
.65 .43444 Mdot
.65 .43455 Mdot
.65 .43483 Mdot
.65 .43567 Mdot
.65 .43609 Mdot
.65 .43648 Mdot
.65 .43673 Mdot
.65 .43686 Mdot
.65 .43686 Mdot
.65 .4373 Mdot
.65 .4374 Mdot
.65 .43788 Mdot
.65 .4379 Mdot
.65 .4383 Mdot
.65 .43922 Mdot
.65 .43943 Mdot
.65 .43958 Mdot
.65 .44026 Mdot
.65 .44026 Mdot
.65 .44066 Mdot
.65 .44069 Mdot
.65 .44075 Mdot
.65 .44095 Mdot
.65 .44104 Mdot
.65 .44133 Mdot
.65 .44145 Mdot
.65 .44156 Mdot
.65 .44229 Mdot
.65 .44233 Mdot
.65 .44267 Mdot
.65 .44281 Mdot
.65 .44312 Mdot
.65 .44346 Mdot
.65 .44361 Mdot
.65 .44363 Mdot
.65 .4437 Mdot
.65 .44387 Mdot
.65 .4439 Mdot
.65 .44459 Mdot
.65 .4446 Mdot
.65 .44468 Mdot
.65 .44495 Mdot
.65 .44533 Mdot
.65 .4458 Mdot
.65 .4459 Mdot
.65 .44594 Mdot
.65 .44595 Mdot
.65 .44624 Mdot
.65 .44641 Mdot
.65 .44649 Mdot
.65 .44669 Mdot
.65 .44713 Mdot
.65 .44719 Mdot
.65 .44748 Mdot
.65 .44759 Mdot
.65 .44763 Mdot
.65 .44788 Mdot
.65 .44834 Mdot
.65 .44846 Mdot
.65 .44898 Mdot
.65 .44921 Mdot
.65 .4498 Mdot
.65 .4498 Mdot
.65 .44987 Mdot
.65 .45093 Mdot
.65 .45109 Mdot
.65 .45127 Mdot
.65 .45148 Mdot
.65 .45164 Mdot
.65 .45196 Mdot
.65 .4521 Mdot
.65 .45239 Mdot
.65 .45244 Mdot
.65 .45254 Mdot
.65 .45259 Mdot
.65 .45325 Mdot
.65 .45326 Mdot
.65 .45437 Mdot
.65 .45462 Mdot
.65 .45497 Mdot
.65 .45505 Mdot
.65 .45648 Mdot
.65 .45682 Mdot
.65 .45714 Mdot
.65 .45717 Mdot
.65 .45795 Mdot
.65 .45812 Mdot
.65 .45833 Mdot
.65 .45882 Mdot
.65 .45883 Mdot
.65 .45887 Mdot
.65 .45903 Mdot
.65 .45936 Mdot
.65 .45943 Mdot
.65 .45974 Mdot
.65 .46006 Mdot
.65 .46073 Mdot
.65 .46208 Mdot
.65 .46253 Mdot
.65 .46269 Mdot
.65 .46303 Mdot
.65 .46337 Mdot
.65 .46364 Mdot
.65 .46391 Mdot
.65 .46405 Mdot
.65 .46409 Mdot
.65 .46412 Mdot
.65 .4642 Mdot
.65 .46433 Mdot
.65 .46491 Mdot
.65 .465 Mdot
.65 .46508 Mdot
.65 .4654 Mdot
.65 .46544 Mdot
.65 .46592 Mdot
.65 .46616 Mdot
.65 .46617 Mdot
.65 .46621 Mdot
.65 .46632 Mdot
.65 .46635 Mdot
.65 .46642 Mdot
.65 .46653 Mdot
.65 .46662 Mdot
.65 .46678 Mdot
.65 .46693 Mdot
.65 .4673 Mdot
.65 .4674 Mdot
.65 .46751 Mdot
.65 .46855 Mdot
.65 .46864 Mdot
.65 .46866 Mdot
.65 .46934 Mdot
.65 .47055 Mdot
.65 .47095 Mdot
.65 .47176 Mdot
.65 .47213 Mdot
.65 .47229 Mdot
.65 .47237 Mdot
.65 .47246 Mdot
.65 .47293 Mdot
.65 .47343 Mdot
.65 .47358 Mdot
.65 .47364 Mdot
.65 .47364 Mdot
.65 .47482 Mdot
.65 .47486 Mdot
.65 .47522 Mdot
.65 .47528 Mdot
.65 .47529 Mdot
.65 .47534 Mdot
.65 .47595 Mdot
.65 .47613 Mdot
.65 .47646 Mdot
.65 .47669 Mdot
.65 .47673 Mdot
.65 .47733 Mdot
.65 .47744 Mdot
.65 .47757 Mdot
.65 .4777 Mdot
.65 .47846 Mdot
.65 .47848 Mdot
.65 .47927 Mdot
.65 .47927 Mdot
.65 .47935 Mdot
.65 .47942 Mdot
.65 .47944 Mdot
.65 .47978 Mdot
.65 .48045 Mdot
.65 .48062 Mdot
.65 .48067 Mdot
.65 .48085 Mdot
.65 .48114 Mdot
.65 .48153 Mdot
.65 .48177 Mdot
.65 .48198 Mdot
.65 .48255 Mdot
.65 .48292 Mdot
.65 .48343 Mdot
.65 .48387 Mdot
.65 .48388 Mdot
.65 .48393 Mdot
.65 .484 Mdot
.65 .48429 Mdot
.65 .48443 Mdot
.65 .48484 Mdot
.65 .48486 Mdot
.65 .48531 Mdot
.65 .48545 Mdot
.65 .4855 Mdot
.65 .48611 Mdot
.65 .48632 Mdot
.65 .48676 Mdot
.65 .48686 Mdot
.65 .48691 Mdot
.65 .48713 Mdot
.65 .48739 Mdot
.65 .48741 Mdot
.65 .4879 Mdot
.65 .48803 Mdot
.65 .48829 Mdot
.65 .48865 Mdot
.65 .48881 Mdot
.65 .48885 Mdot
.65 .4889 Mdot
.65 .4889 Mdot
.65 .48892 Mdot
.65 .49161 Mdot
.65 .49175 Mdot
.65 .49187 Mdot
.65 .49188 Mdot
.65 .49218 Mdot
.65 .4924 Mdot
.65 .49241 Mdot
.65 .4931 Mdot
.65 .49331 Mdot
.65 .49354 Mdot
.65 .49396 Mdot
.65 .49475 Mdot
.65 .49483 Mdot
.65 .49532 Mdot
.65 .49567 Mdot
.65 .49636 Mdot
.65 .4965 Mdot
.65 .49674 Mdot
.65 .49705 Mdot
.65 .4974 Mdot
.65 .49744 Mdot
.65 .49746 Mdot
.65 .4975 Mdot
.65 .49757 Mdot
.65 .49778 Mdot
.65 .49811 Mdot
.65 .49953 Mdot
.65 .49976 Mdot
.65 .49997 Mdot
.65 .50029 Mdot
.65 .50076 Mdot
.65 .50084 Mdot
.65 .50171 Mdot
.65 .50203 Mdot
.65 .50262 Mdot
.65 .50263 Mdot
.65 .50273 Mdot
.65 .50293 Mdot
.65 .50301 Mdot
.65 .50306 Mdot
.65 .50322 Mdot
.65 .50325 Mdot
.65 .50351 Mdot
.65 .50373 Mdot
.65 .50378 Mdot
.65 .50412 Mdot
.65 .50414 Mdot
.65 .50448 Mdot
.65 .50537 Mdot
.65 .50561 Mdot
.65 .50587 Mdot
.65 .50618 Mdot
.65 .50659 Mdot
.65 .50693 Mdot
.65 .50694 Mdot
.65 .50731 Mdot
.65 .50834 Mdot
.65 .50842 Mdot
.65 .50855 Mdot
.65 .5086 Mdot
.65 .51018 Mdot
.65 .5106 Mdot
.65 .51084 Mdot
.65 .51161 Mdot
.65 .5117 Mdot
.65 .51296 Mdot
.65 .51388 Mdot
.65 .51396 Mdot
.65 .51407 Mdot
.65 .51479 Mdot
.65 .51569 Mdot
.65 .51622 Mdot
.65 .51651 Mdot
.65 .51687 Mdot
.65 .51693 Mdot
.65 .517 Mdot
.65 .51702 Mdot
.65 .51703 Mdot
.65 .51706 Mdot
.65 .51723 Mdot
.65 .518 Mdot
.65 .51827 Mdot
.65 .5184 Mdot
.65 .51878 Mdot
.65 .51892 Mdot
.65 .51901 Mdot
.65 .51909 Mdot
.65 .51915 Mdot
.65 .51935 Mdot
.65 .51967 Mdot
.65 .51981 Mdot
.65 .51981 Mdot
.65 .52128 Mdot
.65 .52231 Mdot
.65 .5224 Mdot
.65 .52315 Mdot
.65 .52326 Mdot
.65 .52327 Mdot
.65 .52328 Mdot
.65 .52331 Mdot
.65 .5234 Mdot
.65 .52382 Mdot
.65 .52466 Mdot
.65 .52503 Mdot
.65 .52563 Mdot
.65 .52571 Mdot
.65 .52618 Mdot
.65 .52625 Mdot
.65 .52646 Mdot
.65 .52746 Mdot
.65 .52768 Mdot
.65 .52793 Mdot
.65 .52818 Mdot
.65 .52832 Mdot
.65 .5293 Mdot
.65 .52967 Mdot
.65 .52972 Mdot
.65 .52994 Mdot
.65 .53043 Mdot
.65 .53089 Mdot
.65 .53123 Mdot
.65 .53123 Mdot
.65 .53124 Mdot
.65 .53138 Mdot
.65 .53153 Mdot
.65 .53156 Mdot
.65 .5322 Mdot
.65 .53221 Mdot
.65 .53272 Mdot
.65 .53329 Mdot
.65 .53345 Mdot
.65 .5335 Mdot
.65 .53376 Mdot
.65 .53386 Mdot
.65 .53417 Mdot
.65 .53426 Mdot
.65 .53449 Mdot
.65 .5347 Mdot
.65 .53509 Mdot
.65 .53522 Mdot
.65 .5354 Mdot
.65 .5356 Mdot
.65 .53584 Mdot
.65 .53621 Mdot
.65 .5369 Mdot
.65 .5372 Mdot
.65 .53785 Mdot
.65 .53804 Mdot
.65 .53805 Mdot
.65 .53873 Mdot
.65 .53944 Mdot
.65 .53946 Mdot
.65 .53948 Mdot
.65 .53951 Mdot
.65 .53956 Mdot
.65 .53968 Mdot
.65 .53981 Mdot
.65 .54012 Mdot
.65 .54013 Mdot
.65 .54014 Mdot
.65 .54016 Mdot
.65 .54039 Mdot
.65 .54083 Mdot
.65 .54106 Mdot
.65 .54109 Mdot
.65 .54178 Mdot
.65 .54181 Mdot
.65 .54204 Mdot
.65 .54211 Mdot
.65 .54275 Mdot
.65 .54307 Mdot
.65 .54318 Mdot
.65 .54328 Mdot
.65 .54339 Mdot
.65 .54397 Mdot
.65 .54407 Mdot
.65 .54422 Mdot
.65 .5443 Mdot
.65 .54464 Mdot
.65 .54502 Mdot
.65 .54577 Mdot
.65 .54577 Mdot
.65 .54596 Mdot
.65 .54602 Mdot
.65 .54632 Mdot
.65 .54647 Mdot
.65 .54683 Mdot
.65 .54689 Mdot
.65 .54706 Mdot
.65 .54712 Mdot
.65 .54719 Mdot
.65 .5472 Mdot
.65 .54723 Mdot
.65 .54726 Mdot
.65 .5489 Mdot
.65 .54923 Mdot
.65 .54935 Mdot
.65 .55007 Mdot
.65 .55019 Mdot
.65 .55076 Mdot
.65 .55093 Mdot
.65 .55107 Mdot
.65 .55108 Mdot
.65 .55109 Mdot
.65 .55145 Mdot
.65 .55159 Mdot
.65 .55172 Mdot
.65 .55173 Mdot
.65 .55253 Mdot
.65 .55275 Mdot
.65 .55277 Mdot
.65 .55303 Mdot
.65 .55329 Mdot
.65 .55341 Mdot
.65 .55344 Mdot
.65 .55346 Mdot
.65 .55347 Mdot
.65 .5535 Mdot
.65 .55361 Mdot
.65 .55434 Mdot
.65 .55442 Mdot
.65 .55452 Mdot
.65 .55463 Mdot
.65 .55493 Mdot
.65 .55527 Mdot
.65 .55579 Mdot
.65 .55593 Mdot
.65 .55607 Mdot
.65 .55628 Mdot
.65 .55656 Mdot
.65 .55687 Mdot
.65 .55691 Mdot
.65 .55692 Mdot
.65 .55695 Mdot
.65 .55702 Mdot
.65 .55719 Mdot
.65 .55726 Mdot
.65 .55726 Mdot
.65 .55739 Mdot
.65 .55747 Mdot
.65 .55768 Mdot
.65 .55786 Mdot
.65 .55791 Mdot
.65 .55798 Mdot
.65 .55805 Mdot
.65 .55817 Mdot
.65 .55848 Mdot
.65 .55857 Mdot
.65 .55858 Mdot
.65 .55873 Mdot
.65 .5588 Mdot
.65 .55887 Mdot
.65 .55909 Mdot
.65 .55936 Mdot
.65 .5594 Mdot
.65 .55945 Mdot
.65 .55948 Mdot
.65 .55949 Mdot
.65 .55951 Mdot
.65 .55952 Mdot
.65 .55956 Mdot
.65 .5596 Mdot
.65 .55983 Mdot
.65 .55997 Mdot
.65 .56002 Mdot
.65 .56015 Mdot
.65 .56032 Mdot
.65 .56046 Mdot
.65 .56046 Mdot
.65 .56051 Mdot
.65 .56061 Mdot
.65 .56064 Mdot
.65 .56067 Mdot
.65 .56074 Mdot
.65 .56076 Mdot
.65 .56079 Mdot
.65 .56087 Mdot
.65 .56097 Mdot
.65 .56099 Mdot
.65 .56111 Mdot
.65 .56113 Mdot
.65 .56113 Mdot
.65 .56115 Mdot
.65 .56119 Mdot
.65 .56126 Mdot
.65 .56151 Mdot
.65 .56155 Mdot
.65 .56162 Mdot
.65 .56169 Mdot
.65 .56177 Mdot
.65 .56185 Mdot
.65 .56186 Mdot
.65 .56187 Mdot
.65 .56192 Mdot
.65 .56192 Mdot
.65 .56198 Mdot
.65 .562 Mdot
.65 .56203 Mdot
.65 .56207 Mdot
.65 .56209 Mdot
.65 .5621 Mdot
.65 .5621 Mdot
.65 .56211 Mdot
.652 .15657 Mdot
.652 .15658 Mdot
.652 .15659 Mdot
.652 .1566 Mdot
.652 .15667 Mdot
.652 .15667 Mdot
.652 .15671 Mdot
.652 .15673 Mdot
.652 .15676 Mdot
.652 .15676 Mdot
.652 .15679 Mdot
.652 .1569 Mdot
.652 .15691 Mdot
.652 .15692 Mdot
.652 .15704 Mdot
.652 .15706 Mdot
.652 .15714 Mdot
.652 .15714 Mdot
.652 .15718 Mdot
.652 .15721 Mdot
.652 .15723 Mdot
.652 .15739 Mdot
.652 .15751 Mdot
.652 .15806 Mdot
.652 .1581 Mdot
.652 .15834 Mdot
.652 .1586 Mdot
.652 .15875 Mdot
.652 .15895 Mdot
.652 .15915 Mdot
.652 .15931 Mdot
.652 .15962 Mdot
.652 .15978 Mdot
.652 .16039 Mdot
.652 .16063 Mdot
.652 .16139 Mdot
.652 .16144 Mdot
.652 .16216 Mdot
.652 .16219 Mdot
.652 .16252 Mdot
.652 .16302 Mdot
.652 .16357 Mdot
.652 .16432 Mdot
.652 .16464 Mdot
.652 .16471 Mdot
.652 .16528 Mdot
.652 .16568 Mdot
.652 .16731 Mdot
.652 .16734 Mdot
.652 .16771 Mdot
.652 .16798 Mdot
.652 .16817 Mdot
.652 .16879 Mdot
.652 .1709 Mdot
.652 .17134 Mdot
.652 .17135 Mdot
.652 .17135 Mdot
.652 .17231 Mdot
.652 .17418 Mdot
.652 .17444 Mdot
.652 .17461 Mdot
.652 .17465 Mdot
.652 .17761 Mdot
.652 .17782 Mdot
.652 .17842 Mdot
.652 .17912 Mdot
.652 .1792 Mdot
.652 .17967 Mdot
.652 .18057 Mdot
.652 .18066 Mdot
.652 .1827 Mdot
.652 .18379 Mdot
.652 .1867 Mdot
.652 .18713 Mdot
.652 .1879 Mdot
.652 .18799 Mdot
.652 .18855 Mdot
.652 .18869 Mdot
.652 .1893 Mdot
.652 .18963 Mdot
.652 .18969 Mdot
.652 .18982 Mdot
.652 .19003 Mdot
.652 .19084 Mdot
.652 .19112 Mdot
.652 .19388 Mdot
.652 .19415 Mdot
.652 .1948 Mdot
.652 .1949 Mdot
.652 .19517 Mdot
.652 .19544 Mdot
.652 .19553 Mdot
.652 .19557 Mdot
.652 .19571 Mdot
.652 .1958 Mdot
.652 .1959 Mdot
.652 .19602 Mdot
.652 .1965 Mdot
.652 .19664 Mdot
.652 .19666 Mdot
.652 .19682 Mdot
.652 .19705 Mdot
.652 .19721 Mdot
.652 .19724 Mdot
.652 .19752 Mdot
.652 .19752 Mdot
.652 .19785 Mdot
.652 .19828 Mdot
.652 .19887 Mdot
.652 .19908 Mdot
.652 .1991 Mdot
.652 .19922 Mdot
.652 .19928 Mdot
.652 .19967 Mdot
.652 .20052 Mdot
.652 .20074 Mdot
.652 .20118 Mdot
.652 .20129 Mdot
.652 .20158 Mdot
.652 .2016 Mdot
.652 .20201 Mdot
.652 .20239 Mdot
.652 .20254 Mdot
.652 .20295 Mdot
.652 .20355 Mdot
.652 .20375 Mdot
.652 .20401 Mdot
.652 .20441 Mdot
.652 .20577 Mdot
.652 .20612 Mdot
.652 .20731 Mdot
.652 .20743 Mdot
.652 .20797 Mdot
.652 .20907 Mdot
.652 .20928 Mdot
.652 .21209 Mdot
.652 .21211 Mdot
.652 .21254 Mdot
.652 .21268 Mdot
.652 .21365 Mdot
.652 .21515 Mdot
.652 .21545 Mdot
.652 .21551 Mdot
.652 .21592 Mdot
.652 .21627 Mdot
.652 .2164 Mdot
.652 .21654 Mdot
.652 .21694 Mdot
.652 .21776 Mdot
.652 .21837 Mdot
.652 .21872 Mdot
.652 .21914 Mdot
.652 .22027 Mdot
.652 .22053 Mdot
.652 .22155 Mdot
.652 .22167 Mdot
.652 .2231 Mdot
.652 .22427 Mdot
.652 .22455 Mdot
.652 .22538 Mdot
.652 .22553 Mdot
.652 .22563 Mdot
.652 .22682 Mdot
.652 .22682 Mdot
.652 .22781 Mdot
.652 .22881 Mdot
.652 .22898 Mdot
.652 .22918 Mdot
.652 .23014 Mdot
.652 .23147 Mdot
.652 .23178 Mdot
.652 .23187 Mdot
.652 .23196 Mdot
.652 .23221 Mdot
.652 .2329 Mdot
.652 .23305 Mdot
.652 .23307 Mdot
.652 .23313 Mdot
.652 .23319 Mdot
.652 .23382 Mdot
.652 .23403 Mdot
.652 .23412 Mdot
.652 .23497 Mdot
.652 .23503 Mdot
.652 .23611 Mdot
.652 .23666 Mdot
.652 .23695 Mdot
.652 .23751 Mdot
.652 .238 Mdot
.652 .23845 Mdot
.652 .23919 Mdot
.652 .23985 Mdot
.652 .24039 Mdot
.652 .24088 Mdot
.652 .24108 Mdot
.652 .24118 Mdot
.652 .24183 Mdot
.652 .24256 Mdot
.652 .24285 Mdot
.652 .24386 Mdot
.652 .24443 Mdot
.652 .24466 Mdot
.652 .24515 Mdot
.652 .24592 Mdot
.652 .24595 Mdot
.652 .24635 Mdot
.652 .24667 Mdot
.652 .24769 Mdot
.652 .24933 Mdot
.652 .2499 Mdot
.652 .25115 Mdot
.652 .25175 Mdot
.652 .25228 Mdot
.652 .25353 Mdot
.652 .25382 Mdot
.652 .25493 Mdot
.652 .25569 Mdot
.652 .25708 Mdot
.652 .25712 Mdot
.652 .25779 Mdot
.652 .25813 Mdot
.652 .25987 Mdot
.652 .26001 Mdot
.652 .26224 Mdot
.652 .26246 Mdot
.652 .26302 Mdot
.652 .26466 Mdot
.652 .26482 Mdot
.652 .26497 Mdot
.652 .26503 Mdot
.652 .26542 Mdot
.652 .26726 Mdot
.652 .26793 Mdot
.652 .26815 Mdot
.652 .2684 Mdot
.652 .26878 Mdot
.652 .26923 Mdot
.652 .26929 Mdot
.652 .26979 Mdot
.652 .27203 Mdot
.652 .2728 Mdot
.652 .27433 Mdot
.652 .27541 Mdot
.652 .27594 Mdot
.652 .27641 Mdot
.652 .27657 Mdot
.652 .27897 Mdot
.652 .27915 Mdot
.652 .28187 Mdot
.652 .28188 Mdot
.652 .28229 Mdot
.652 .28519 Mdot
.652 .28548 Mdot
.652 .28588 Mdot
.652 .2859 Mdot
.652 .28774 Mdot
.652 .28822 Mdot
.652 .28891 Mdot
.652 .289 Mdot
.652 .28941 Mdot
.652 .29038 Mdot
.652 .29113 Mdot
.652 .29232 Mdot
.652 .29237 Mdot
.652 .2964 Mdot
.652 .29673 Mdot
.652 .29736 Mdot
.652 .29772 Mdot
.652 .29898 Mdot
.652 .29965 Mdot
.652 .30031 Mdot
.652 .30042 Mdot
.652 .30336 Mdot
.652 .3037 Mdot
.652 .30407 Mdot
.652 .30484 Mdot
.652 .30492 Mdot
.652 .30594 Mdot
.652 .3067 Mdot
.652 .30771 Mdot
.652 .30867 Mdot
.652 .30991 Mdot
.652 .31012 Mdot
.652 .31131 Mdot
.652 .3117 Mdot
.652 .31187 Mdot
.652 .31209 Mdot
.652 .31234 Mdot
.652 .31313 Mdot
.652 .31434 Mdot
.652 .31452 Mdot
.652 .31473 Mdot
.652 .31542 Mdot
.652 .31587 Mdot
.652 .31941 Mdot
.652 .31988 Mdot
.652 .32278 Mdot
.652 .3232 Mdot
.652 .32448 Mdot
.652 .32455 Mdot
.652 .32619 Mdot
.652 .33304 Mdot
.652 .33367 Mdot
.652 .33615 Mdot
.652 .33703 Mdot
.652 .33867 Mdot
.652 .33903 Mdot
.652 .34269 Mdot
.652 .34304 Mdot
.652 .34377 Mdot
.652 .34796 Mdot
.652 .34916 Mdot
.652 .34985 Mdot
.652 .34997 Mdot
.652 .3506 Mdot
.652 .35246 Mdot
.652 .35343 Mdot
.652 .35345 Mdot
.652 .35353 Mdot
.652 .35358 Mdot
.652 .35364 Mdot
.652 .35371 Mdot
.652 .35399 Mdot
.652 .35407 Mdot
.652 .35408 Mdot
.652 .35417 Mdot
.652 .35431 Mdot
.652 .3544 Mdot
.652 .35441 Mdot
.652 .35458 Mdot
.652 .35458 Mdot
.652 .35477 Mdot
.652 .35534 Mdot
.652 .35546 Mdot
.652 .35547 Mdot
.652 .35554 Mdot
.652 .35627 Mdot
.652 .35639 Mdot
.652 .35663 Mdot
.652 .35669 Mdot
.652 .35685 Mdot
.652 .35686 Mdot
.652 .35708 Mdot
.652 .35729 Mdot
.652 .35737 Mdot
.652 .35759 Mdot
.652 .35791 Mdot
.652 .35837 Mdot
.652 .35909 Mdot
.652 .35928 Mdot
.652 .35996 Mdot
.652 .3608 Mdot
.652 .36233 Mdot
.652 .36255 Mdot
.652 .36262 Mdot
.652 .36383 Mdot
.652 .36398 Mdot
.652 .36401 Mdot
.652 .36438 Mdot
.652 .36444 Mdot
.652 .3647 Mdot
.652 .36509 Mdot
.652 .36538 Mdot
.652 .36555 Mdot
.652 .36641 Mdot
.652 .36693 Mdot
.652 .3676 Mdot
.652 .36826 Mdot
.652 .36864 Mdot
.652 .36875 Mdot
.652 .36929 Mdot
.652 .36929 Mdot
.652 .36974 Mdot
.652 .37018 Mdot
.652 .37026 Mdot
.652 .37077 Mdot
.652 .3715 Mdot
.652 .37154 Mdot
.652 .37157 Mdot
.652 .37199 Mdot
.652 .37205 Mdot
.652 .37206 Mdot
.652 .37238 Mdot
.652 .37247 Mdot
.652 .37251 Mdot
.652 .3729 Mdot
.652 .37373 Mdot
.652 .37396 Mdot
.652 .37436 Mdot
.652 .37467 Mdot
.652 .37495 Mdot
.652 .37538 Mdot
.652 .37551 Mdot
.652 .37578 Mdot
.652 .37609 Mdot
.652 .37662 Mdot
.652 .37747 Mdot
.652 .37748 Mdot
.652 .37777 Mdot
.652 .37908 Mdot
.652 .37982 Mdot
.652 .38064 Mdot
.652 .38194 Mdot
.652 .3822 Mdot
.652 .38233 Mdot
.652 .38639 Mdot
.652 .38659 Mdot
.652 .38677 Mdot
.652 .38761 Mdot
.652 .38846 Mdot
.652 .38928 Mdot
.652 .39016 Mdot
.652 .39136 Mdot
.652 .39266 Mdot
.652 .39332 Mdot
.652 .39373 Mdot
.652 .39391 Mdot
.652 .39425 Mdot
.652 .39452 Mdot
.652 .39495 Mdot
.652 .3967 Mdot
.652 .39683 Mdot
.652 .39726 Mdot
.652 .39773 Mdot
.652 .39878 Mdot
.652 .39902 Mdot
.652 .39929 Mdot
.652 .39993 Mdot
.652 .4006 Mdot
.652 .40102 Mdot
.652 .40169 Mdot
.652 .40185 Mdot
.652 .40265 Mdot
.652 .40304 Mdot
.652 .40423 Mdot
.652 .40649 Mdot
.652 .40977 Mdot
.652 .41203 Mdot
.652 .41424 Mdot
.652 .4154 Mdot
.652 .41541 Mdot
.652 .41543 Mdot
.652 .41545 Mdot
.652 .41547 Mdot
.652 .41558 Mdot
.652 .41561 Mdot
.652 .41561 Mdot
.652 .41568 Mdot
.652 .41571 Mdot
.652 .41572 Mdot
.652 .41577 Mdot
.652 .41577 Mdot
.652 .41583 Mdot
.652 .41606 Mdot
.652 .41606 Mdot
.652 .41608 Mdot
.652 .41632 Mdot
.652 .41636 Mdot
.652 .4165 Mdot
.652 .41651 Mdot
.652 .41658 Mdot
.652 .41665 Mdot
.652 .41667 Mdot
.652 .417 Mdot
.652 .41723 Mdot
.652 .41778 Mdot
.652 .41827 Mdot
.652 .41834 Mdot
.652 .4188 Mdot
.652 .41903 Mdot
.652 .41925 Mdot
.652 .41931 Mdot
.652 .41958 Mdot
.652 .41996 Mdot
.652 .4203 Mdot
.652 .42034 Mdot
.652 .42065 Mdot
.652 .42123 Mdot
.652 .42124 Mdot
.652 .42139 Mdot
.652 .4215 Mdot
.652 .42154 Mdot
.652 .42167 Mdot
.652 .42193 Mdot
.652 .42269 Mdot
.652 .42313 Mdot
.652 .42365 Mdot
.652 .42456 Mdot
.652 .42465 Mdot
.652 .42469 Mdot
.652 .42599 Mdot
.652 .42605 Mdot
.652 .42611 Mdot
.652 .42638 Mdot
.652 .42665 Mdot
.652 .42758 Mdot
.652 .42851 Mdot
.652 .4286 Mdot
.652 .4293 Mdot
.652 .42963 Mdot
.652 .42997 Mdot
.652 .43033 Mdot
.652 .43055 Mdot
.652 .43069 Mdot
.652 .43095 Mdot
.652 .43121 Mdot
.652 .43172 Mdot
.652 .43245 Mdot
.652 .43351 Mdot
.652 .43496 Mdot
.652 .43539 Mdot
.652 .43543 Mdot
.652 .43611 Mdot
.652 .43651 Mdot
.652 .43659 Mdot
.652 .43693 Mdot
.652 .43723 Mdot
.652 .43728 Mdot
.652 .43732 Mdot
.652 .43802 Mdot
.652 .43988 Mdot
.652 .43998 Mdot
.652 .44051 Mdot
.652 .44127 Mdot
.652 .44175 Mdot
.652 .44226 Mdot
.652 .4425 Mdot
.652 .44252 Mdot
.652 .44253 Mdot
.652 .44419 Mdot
.652 .44683 Mdot
.652 .4474 Mdot
.652 .44784 Mdot
.652 .44813 Mdot
.652 .4482 Mdot
.652 .44964 Mdot
.652 .44966 Mdot
.652 .44969 Mdot
.652 .45009 Mdot
.652 .45096 Mdot
.652 .45177 Mdot
.652 .45303 Mdot
.652 .45318 Mdot
.652 .45352 Mdot
.652 .4539 Mdot
.652 .45408 Mdot
.652 .45451 Mdot
.652 .45566 Mdot
.652 .45581 Mdot
.652 .45657 Mdot
.652 .45713 Mdot
.652 .45804 Mdot
.652 .45818 Mdot
.652 .45827 Mdot
.652 .45833 Mdot
.652 .45841 Mdot
.652 .45891 Mdot
.652 .45946 Mdot
.652 .45957 Mdot
.652 .46023 Mdot
.652 .46131 Mdot
.652 .46137 Mdot
.652 .46147 Mdot
.652 .46207 Mdot
.652 .46321 Mdot
.652 .46436 Mdot
.652 .46602 Mdot
.652 .46716 Mdot
.652 .46775 Mdot
.652 .46794 Mdot
.652 .46835 Mdot
.652 .46842 Mdot
.652 .46875 Mdot
.652 .46896 Mdot
.652 .4693 Mdot
.652 .46961 Mdot
.652 .46974 Mdot
.652 .46986 Mdot
.652 .47038 Mdot
.652 .4706 Mdot
.652 .47082 Mdot
.652 .47088 Mdot
.652 .47173 Mdot
.652 .47194 Mdot
.652 .47207 Mdot
.652 .47224 Mdot
.652 .47232 Mdot
.652 .47252 Mdot
.652 .47284 Mdot
.652 .47347 Mdot
.652 .47404 Mdot
.652 .47446 Mdot
.652 .47486 Mdot
.652 .47526 Mdot
.652 .47566 Mdot
.652 .47575 Mdot
.652 .47584 Mdot
.652 .47775 Mdot
.652 .47782 Mdot
.652 .47794 Mdot
.652 .47854 Mdot
.652 .47893 Mdot
.652 .47927 Mdot
.652 .47988 Mdot
.652 .48001 Mdot
.652 .48002 Mdot
.652 .48041 Mdot
.652 .48065 Mdot
.652 .4808 Mdot
.652 .48092 Mdot
.652 .48098 Mdot
.652 .48118 Mdot
.652 .4813 Mdot
.652 .48145 Mdot
.652 .48163 Mdot
.652 .48174 Mdot
.652 .48211 Mdot
.652 .48229 Mdot
.652 .48231 Mdot
.652 .48235 Mdot
.652 .4825 Mdot
.652 .4825 Mdot
.652 .48253 Mdot
.652 .48272 Mdot
.652 .48274 Mdot
.652 .48276 Mdot
.652 .48309 Mdot
.652 .48332 Mdot
.652 .48335 Mdot
.652 .48356 Mdot
.652 .48376 Mdot
.652 .48376 Mdot
.652 .484 Mdot
.652 .48405 Mdot
.652 .48422 Mdot
.652 .48452 Mdot
.652 .48482 Mdot
.652 .48506 Mdot
.652 .48544 Mdot
.652 .48552 Mdot
.652 .48565 Mdot
.652 .48582 Mdot
.652 .48594 Mdot
.652 .48597 Mdot
.652 .48613 Mdot
.652 .48614 Mdot
.652 .48621 Mdot
.652 .48675 Mdot
.652 .48678 Mdot
.652 .48688 Mdot
.652 .48756 Mdot
.652 .48793 Mdot
.652 .48823 Mdot
.652 .48831 Mdot
.652 .48863 Mdot
.652 .48883 Mdot
.652 .48898 Mdot
.652 .48907 Mdot
.652 .48911 Mdot
.652 .4892 Mdot
.652 .4893 Mdot
.652 .4893 Mdot
.652 .48937 Mdot
.652 .4894 Mdot
.652 .4895 Mdot
.652 .48956 Mdot
.652 .48987 Mdot
.652 .4899 Mdot
.652 .48991 Mdot
.652 .48996 Mdot
.652 .49021 Mdot
.652 .49029 Mdot
.652 .49029 Mdot
.652 .49036 Mdot
.652 .49037 Mdot
.652 .49041 Mdot
.652 .49047 Mdot
.652 .49051 Mdot
.652 .49052 Mdot
.652 .49055 Mdot
.652 .49067 Mdot
.652 .4907 Mdot
.652 .49073 Mdot
.652 .49075 Mdot
.652 .49079 Mdot
.652 .4908 Mdot
.652 .49122 Mdot
.652 .49202 Mdot
.652 .49229 Mdot
.652 .49235 Mdot
.652 .49264 Mdot
.652 .49316 Mdot
.652 .49495 Mdot
.652 .49526 Mdot
.652 .49541 Mdot
.652 .49695 Mdot
.652 .4971 Mdot
.652 .49779 Mdot
.652 .49816 Mdot
.652 .49919 Mdot
.652 .49946 Mdot
.652 .50228 Mdot
.652 .50295 Mdot
.652 .50298 Mdot
.652 .5035 Mdot
.652 .50367 Mdot
.652 .50485 Mdot
.652 .50504 Mdot
.652 .50646 Mdot
.652 .50664 Mdot
.652 .50692 Mdot
.652 .507 Mdot
.652 .50707 Mdot
.652 .50755 Mdot
.652 .50787 Mdot
.652 .50797 Mdot
.652 .50806 Mdot
.652 .50812 Mdot
.652 .50828 Mdot
.652 .50875 Mdot
.652 .50883 Mdot
.652 .50932 Mdot
.652 .5097 Mdot
.652 .5101 Mdot
.652 .5104 Mdot
.652 .5108 Mdot
.652 .51083 Mdot
.652 .51113 Mdot
.652 .51128 Mdot
.652 .51141 Mdot
.652 .51255 Mdot
.652 .51259 Mdot
.652 .51285 Mdot
.652 .51311 Mdot
.652 .5136 Mdot
.652 .51374 Mdot
.652 .51398 Mdot
.652 .51411 Mdot
.652 .51566 Mdot
.652 .51568 Mdot
.652 .51613 Mdot
.652 .51642 Mdot
.652 .51679 Mdot
.652 .51694 Mdot
.652 .51698 Mdot
.652 .51724 Mdot
.652 .51742 Mdot
.652 .51812 Mdot
.652 .51813 Mdot
.652 .51828 Mdot
.652 .51839 Mdot
.652 .51948 Mdot
.652 .51963 Mdot
.652 .51964 Mdot
.652 .52066 Mdot
.652 .52072 Mdot
.652 .52162 Mdot
.652 .52168 Mdot
.652 .52185 Mdot
.652 .52205 Mdot
.652 .52245 Mdot
.652 .52302 Mdot
.652 .5233 Mdot
.652 .52412 Mdot
.652 .52431 Mdot
.652 .52433 Mdot
.652 .5245 Mdot
.652 .52464 Mdot
.652 .52473 Mdot
.652 .52481 Mdot
.652 .52505 Mdot
.652 .52572 Mdot
.652 .52587 Mdot
.652 .52589 Mdot
.652 .52595 Mdot
.652 .526 Mdot
.652 .5266 Mdot
.652 .5268 Mdot
.652 .52688 Mdot
.652 .52769 Mdot
.652 .52774 Mdot
.652 .52837 Mdot
.652 .52849 Mdot
.652 .52873 Mdot
.652 .52875 Mdot
.652 .52925 Mdot
.652 .52952 Mdot
.652 .52992 Mdot
.652 .53002 Mdot
.652 .53047 Mdot
.652 .53066 Mdot
.652 .53087 Mdot
.652 .53132 Mdot
.652 .53152 Mdot
.652 .5321 Mdot
.652 .53246 Mdot
.652 .53258 Mdot
.652 .53272 Mdot
.652 .53273 Mdot
.652 .533 Mdot
.652 .53317 Mdot
.652 .53325 Mdot
.652 .53345 Mdot
.652 .53381 Mdot
.652 .53391 Mdot
.652 .53417 Mdot
.652 .5344 Mdot
.652 .53443 Mdot
.652 .5345 Mdot
.652 .53467 Mdot
.652 .53486 Mdot
.652 .5351 Mdot
.652 .53535 Mdot
.652 .53551 Mdot
.652 .53568 Mdot
.652 .53587 Mdot
.652 .53598 Mdot
.652 .53617 Mdot
.652 .53654 Mdot
.652 .53656 Mdot
.652 .53686 Mdot
.652 .53689 Mdot
.652 .53697 Mdot
.652 .53718 Mdot
.652 .5372 Mdot
.652 .53722 Mdot
.652 .53723 Mdot
.652 .53728 Mdot
.652 .53752 Mdot
.652 .53761 Mdot
.652 .53764 Mdot
.652 .53767 Mdot
.652 .53778 Mdot
.652 .53824 Mdot
.652 .53857 Mdot
.652 .53864 Mdot
.652 .5387 Mdot
.652 .53904 Mdot
.652 .53938 Mdot
.652 .53938 Mdot
.652 .53979 Mdot
.652 .53982 Mdot
.652 .53987 Mdot
.652 .54016 Mdot
.652 .54025 Mdot
.652 .54066 Mdot
.652 .54114 Mdot
.652 .54118 Mdot
.652 .54153 Mdot
.652 .54162 Mdot
.652 .542 Mdot
.652 .54215 Mdot
.652 .54226 Mdot
.652 .54247 Mdot
.652 .54275 Mdot
.652 .54288 Mdot
.652 .54293 Mdot
.652 .54297 Mdot
.652 .54309 Mdot
.652 .54323 Mdot
.652 .54325 Mdot
.652 .54335 Mdot
.652 .54386 Mdot
.652 .54418 Mdot
.652 .54423 Mdot
.652 .54437 Mdot
.652 .54438 Mdot
.652 .54533 Mdot
.652 .54539 Mdot
.652 .54576 Mdot
.652 .54594 Mdot
.652 .54598 Mdot
.652 .54638 Mdot
.652 .5465 Mdot
.652 .54695 Mdot
.652 .54708 Mdot
.652 .54717 Mdot
.652 .54724 Mdot
.652 .54743 Mdot
.652 .54757 Mdot
.652 .54762 Mdot
.652 .54774 Mdot
.652 .54788 Mdot
.652 .54789 Mdot
.652 .54798 Mdot
.652 .54802 Mdot
.652 .54816 Mdot
.652 .54824 Mdot
.652 .54852 Mdot
.652 .54865 Mdot
.652 .54867 Mdot
.652 .54871 Mdot
.652 .54871 Mdot
.652 .54878 Mdot
.652 .54898 Mdot
.652 .54912 Mdot
.652 .54923 Mdot
.652 .54923 Mdot
.652 .54932 Mdot
.652 .54933 Mdot
.652 .54938 Mdot
.652 .54946 Mdot
.652 .54951 Mdot
.652 .54952 Mdot
.652 .54956 Mdot
.652 .54972 Mdot
.652 .54976 Mdot
.652 .54979 Mdot
.652 .54982 Mdot
.652 .54987 Mdot
.652 .54988 Mdot
.652 .54991 Mdot
.652 .55 Mdot
.652 .55009 Mdot
.652 .55012 Mdot
.652 .55034 Mdot
.652 .55042 Mdot
.652 .55133 Mdot
.652 .55142 Mdot
.652 .55168 Mdot
.652 .55175 Mdot
.652 .55179 Mdot
.652 .55181 Mdot
.652 .55192 Mdot
.652 .55212 Mdot
.652 .55216 Mdot
.652 .55235 Mdot
.652 .55237 Mdot
.652 .55262 Mdot
.652 .55276 Mdot
.652 .5537 Mdot
.652 .55406 Mdot
.652 .55472 Mdot
.652 .55474 Mdot
.652 .55503 Mdot
.652 .55518 Mdot
.652 .55521 Mdot
.652 .55544 Mdot
.652 .55563 Mdot
.652 .55569 Mdot
.652 .55664 Mdot
.652 .55665 Mdot
.652 .55671 Mdot
.652 .55679 Mdot
.652 .55739 Mdot
.652 .55769 Mdot
.652 .55769 Mdot
.652 .5577 Mdot
.652 .55784 Mdot
.652 .55851 Mdot
.652 .5587 Mdot
.652 .55876 Mdot
.652 .55885 Mdot
.652 .55897 Mdot
.652 .55898 Mdot
.652 .55949 Mdot
.652 .55962 Mdot
.652 .5598 Mdot
.652 .55982 Mdot
.652 .55992 Mdot
.652 .56016 Mdot
.652 .56033 Mdot
.652 .56049 Mdot
.652 .56059 Mdot
.652 .5606 Mdot
.652 .56083 Mdot
.652 .56084 Mdot
.652 .56108 Mdot
.652 .56115 Mdot
.652 .56135 Mdot
.652 .5614 Mdot
.652 .56149 Mdot
.652 .56155 Mdot
.652 .56161 Mdot
.652 .56167 Mdot
.652 .56172 Mdot
.652 .5618 Mdot
.652 .56187 Mdot
.652 .56189 Mdot
.652 .56206 Mdot
.652 .56209 Mdot
.652 .56215 Mdot
.652 .56215 Mdot
.652 .56216 Mdot
.652 .56217 Mdot
.652 .56217 Mdot
.652 .5622 Mdot
.652 .56224 Mdot
.652 .56225 Mdot
.652 .56225 Mdot
.652 .56228 Mdot
.652 .56229 Mdot
.652 .56229 Mdot
.652 .5623 Mdot
.652 .56231 Mdot
.652 .56232 Mdot
.652 .56232 Mdot
.652 .56234 Mdot
.652 .56234 Mdot
.652 .56235 Mdot
.652 .56235 Mdot
.654 .15587 Mdot
.654 .1559 Mdot
.654 .15592 Mdot
.654 .15592 Mdot
.654 .15617 Mdot
.654 .1562 Mdot
.654 .1562 Mdot
.654 .15624 Mdot
.654 .15633 Mdot
.654 .15633 Mdot
.654 .15638 Mdot
.654 .15651 Mdot
.654 .15652 Mdot
.654 .15658 Mdot
.654 .15676 Mdot
.654 .15677 Mdot
.654 .1568 Mdot
.654 .15683 Mdot
.654 .15712 Mdot
.654 .15752 Mdot
.654 .15792 Mdot
.654 .15792 Mdot
.654 .1589 Mdot
.654 .15898 Mdot
.654 .15934 Mdot
.654 .15947 Mdot
.654 .15953 Mdot
.654 .15965 Mdot
.654 .15997 Mdot
.654 .16 Mdot
.654 .16012 Mdot
.654 .16017 Mdot
.654 .16029 Mdot
.654 .16054 Mdot
.654 .16134 Mdot
.654 .16156 Mdot
.654 .16175 Mdot
.654 .16176 Mdot
.654 .16179 Mdot
.654 .16187 Mdot
.654 .16302 Mdot
.654 .16359 Mdot
.654 .16359 Mdot
.654 .16361 Mdot
.654 .16428 Mdot
.654 .16429 Mdot
.654 .16434 Mdot
.654 .16437 Mdot
.654 .16438 Mdot
.654 .16453 Mdot
.654 .16543 Mdot
.654 .16583 Mdot
.654 .16591 Mdot
.654 .16622 Mdot
.654 .16758 Mdot
.654 .16788 Mdot
.654 .16854 Mdot
.654 .16925 Mdot
.654 .16945 Mdot
.654 .16977 Mdot
.654 .17059 Mdot
.654 .17133 Mdot
.654 .17166 Mdot
.654 .17174 Mdot
.654 .17236 Mdot
.654 .17268 Mdot
.654 .17292 Mdot
.654 .17409 Mdot
.654 .17463 Mdot
.654 .17473 Mdot
.654 .17535 Mdot
.654 .17545 Mdot
.654 .1757 Mdot
.654 .17998 Mdot
.654 .18041 Mdot
.654 .18116 Mdot
.654 .18183 Mdot
.654 .18188 Mdot
.654 .18302 Mdot
.654 .18404 Mdot
.654 .1841 Mdot
.654 .18522 Mdot
.654 .18555 Mdot
.654 .18681 Mdot
.654 .18832 Mdot
.654 .18843 Mdot
.654 .18867 Mdot
.654 .1889 Mdot
.654 .18894 Mdot
.654 .1896 Mdot
.654 .18981 Mdot
.654 .19135 Mdot
.654 .19159 Mdot
.654 .19159 Mdot
.654 .19171 Mdot
.654 .19202 Mdot
.654 .19288 Mdot
.654 .19294 Mdot
.654 .19334 Mdot
.654 .19344 Mdot
.654 .19385 Mdot
.654 .19431 Mdot
.654 .19475 Mdot
.654 .19481 Mdot
.654 .19482 Mdot
.654 .1954 Mdot
.654 .19716 Mdot
.654 .19727 Mdot
.654 .19744 Mdot
.654 .1977 Mdot
.654 .19776 Mdot
.654 .19801 Mdot
.654 .19809 Mdot
.654 .19843 Mdot
.654 .19847 Mdot
.654 .1993 Mdot
.654 .20113 Mdot
.654 .20187 Mdot
.654 .20264 Mdot
.654 .20283 Mdot
.654 .20352 Mdot
.654 .20522 Mdot
.654 .20556 Mdot
.654 .20566 Mdot
.654 .20755 Mdot
.654 .20852 Mdot
.654 .20903 Mdot
.654 .20913 Mdot
.654 .20975 Mdot
.654 .21031 Mdot
.654 .21033 Mdot
.654 .21062 Mdot
.654 .21231 Mdot
.654 .2124 Mdot
.654 .21278 Mdot
.654 .21379 Mdot
.654 .21494 Mdot
.654 .21582 Mdot
.654 .21587 Mdot
.654 .21665 Mdot
.654 .2168 Mdot
.654 .21718 Mdot
.654 .21889 Mdot
.654 .21919 Mdot
.654 .21949 Mdot
.654 .21952 Mdot
.654 .21986 Mdot
.654 .22176 Mdot
.654 .2218 Mdot
.654 .22227 Mdot
.654 .22241 Mdot
.654 .22349 Mdot
.654 .22395 Mdot
.654 .22429 Mdot
.654 .22436 Mdot
.654 .22505 Mdot
.654 .22617 Mdot
.654 .22737 Mdot
.654 .2279 Mdot
.654 .22811 Mdot
.654 .22814 Mdot
.654 .22821 Mdot
.654 .2299 Mdot
.654 .23077 Mdot
.654 .23115 Mdot
.654 .23231 Mdot
.654 .23279 Mdot
.654 .23379 Mdot
.654 .23398 Mdot
.654 .2352 Mdot
.654 .23599 Mdot
.654 .2367 Mdot
.654 .23711 Mdot
.654 .23744 Mdot
.654 .23746 Mdot
.654 .23786 Mdot
.654 .23798 Mdot
.654 .23804 Mdot
.654 .23885 Mdot
.654 .23956 Mdot
.654 .24094 Mdot
.654 .24119 Mdot
.654 .24129 Mdot
.654 .24361 Mdot
.654 .24386 Mdot
.654 .24448 Mdot
.654 .24482 Mdot
.654 .24534 Mdot
.654 .24542 Mdot
.654 .24586 Mdot
.654 .24786 Mdot
.654 .248 Mdot
.654 .24928 Mdot
.654 .24963 Mdot
.654 .25167 Mdot
.654 .25183 Mdot
.654 .25213 Mdot
.654 .25294 Mdot
.654 .25312 Mdot
.654 .25319 Mdot
.654 .25401 Mdot
.654 .25507 Mdot
.654 .2553 Mdot
.654 .25614 Mdot
.654 .25658 Mdot
.654 .25689 Mdot
.654 .25694 Mdot
.654 .25891 Mdot
.654 .25981 Mdot
.654 .26018 Mdot
.654 .26069 Mdot
.654 .2621 Mdot
.654 .26259 Mdot
.654 .26278 Mdot
.654 .26297 Mdot
.654 .26331 Mdot
.654 .26466 Mdot
.654 .26523 Mdot
.654 .26651 Mdot
.654 .26781 Mdot
.654 .26958 Mdot
.654 .27041 Mdot
.654 .27063 Mdot
.654 .27138 Mdot
.654 .27142 Mdot
.654 .27212 Mdot
.654 .27296 Mdot
.654 .27343 Mdot
.654 .27756 Mdot
.654 .27776 Mdot
.654 .27784 Mdot
.654 .27843 Mdot
.654 .27988 Mdot
.654 .28037 Mdot
.654 .28128 Mdot
.654 .28273 Mdot
.654 .28323 Mdot
.654 .28393 Mdot
.654 .28636 Mdot
.654 .2867 Mdot
.654 .28831 Mdot
.654 .28848 Mdot
.654 .2886 Mdot
.654 .28947 Mdot
.654 .2902 Mdot
.654 .29075 Mdot
.654 .29178 Mdot
.654 .29191 Mdot
.654 .29194 Mdot
.654 .29196 Mdot
.654 .29225 Mdot
.654 .29382 Mdot
.654 .29424 Mdot
.654 .29444 Mdot
.654 .29474 Mdot
.654 .29557 Mdot
.654 .29568 Mdot
.654 .29662 Mdot
.654 .29679 Mdot
.654 .29895 Mdot
.654 .29999 Mdot
.654 .30118 Mdot
.654 .30215 Mdot
.654 .30226 Mdot
.654 .30312 Mdot
.654 .30336 Mdot
.654 .30339 Mdot
.654 .30398 Mdot
.654 .30423 Mdot
.654 .30474 Mdot
.654 .305 Mdot
.654 .3074 Mdot
.654 .309 Mdot
.654 .31014 Mdot
.654 .31058 Mdot
.654 .31288 Mdot
.654 .31303 Mdot
.654 .31377 Mdot
.654 .31562 Mdot
.654 .31908 Mdot
.654 .3221 Mdot
.654 .32267 Mdot
.654 .32324 Mdot
.654 .32351 Mdot
.654 .32546 Mdot
.654 .32857 Mdot
.654 .32859 Mdot
.654 .32943 Mdot
.654 .3295 Mdot
.654 .32953 Mdot
.654 .33079 Mdot
.654 .33124 Mdot
.654 .33312 Mdot
.654 .33343 Mdot
.654 .33499 Mdot
.654 .33608 Mdot
.654 .33705 Mdot
.654 .33712 Mdot
.654 .33795 Mdot
.654 .33916 Mdot
.654 .33969 Mdot
.654 .34375 Mdot
.654 .34406 Mdot
.654 .34511 Mdot
.654 .34942 Mdot
.654 .34949 Mdot
.654 .34964 Mdot
.654 .34979 Mdot
.654 .34981 Mdot
.654 .35036 Mdot
.654 .3513 Mdot
.654 .35145 Mdot
.654 .35145 Mdot
.654 .35171 Mdot
.654 .35223 Mdot
.654 .35227 Mdot
.654 .35251 Mdot
.654 .35257 Mdot
.654 .35308 Mdot
.654 .35334 Mdot
.654 .35338 Mdot
.654 .35371 Mdot
.654 .35479 Mdot
.654 .35488 Mdot
.654 .35503 Mdot
.654 .35521 Mdot
.654 .35546 Mdot
.654 .35694 Mdot
.654 .35775 Mdot
.654 .3593 Mdot
.654 .35935 Mdot
.654 .36033 Mdot
.654 .36083 Mdot
.654 .36174 Mdot
.654 .36174 Mdot
.654 .36277 Mdot
.654 .36346 Mdot
.654 .36444 Mdot
.654 .36447 Mdot
.654 .36605 Mdot
.654 .36619 Mdot
.654 .36725 Mdot
.654 .36726 Mdot
.654 .36748 Mdot
.654 .36755 Mdot
.654 .36804 Mdot
.654 .36825 Mdot
.654 .36843 Mdot
.654 .36925 Mdot
.654 .36979 Mdot
.654 .37012 Mdot
.654 .37014 Mdot
.654 .37092 Mdot
.654 .37129 Mdot
.654 .37146 Mdot
.654 .37197 Mdot
.654 .37385 Mdot
.654 .37403 Mdot
.654 .37417 Mdot
.654 .37434 Mdot
.654 .37439 Mdot
.654 .37476 Mdot
.654 .37506 Mdot
.654 .37563 Mdot
.654 .37574 Mdot
.654 .37578 Mdot
.654 .37723 Mdot
.654 .37745 Mdot
.654 .37748 Mdot
.654 .37766 Mdot
.654 .37853 Mdot
.654 .37904 Mdot
.654 .38049 Mdot
.654 .38143 Mdot
.654 .38175 Mdot
.654 .38192 Mdot
.654 .38207 Mdot
.654 .38317 Mdot
.654 .38332 Mdot
.654 .38352 Mdot
.654 .38431 Mdot
.654 .38438 Mdot
.654 .38451 Mdot
.654 .38503 Mdot
.654 .38621 Mdot
.654 .38719 Mdot
.654 .38755 Mdot
.654 .38756 Mdot
.654 .38782 Mdot
.654 .3883 Mdot
.654 .39083 Mdot
.654 .39117 Mdot
.654 .39169 Mdot
.654 .39212 Mdot
.654 .39311 Mdot
.654 .39378 Mdot
.654 .39435 Mdot
.654 .3949 Mdot
.654 .39495 Mdot
.654 .39496 Mdot
.654 .39497 Mdot
.654 .39507 Mdot
.654 .39583 Mdot
.654 .39594 Mdot
.654 .3966 Mdot
.654 .39665 Mdot
.654 .39741 Mdot
.654 .39777 Mdot
.654 .39892 Mdot
.654 .39893 Mdot
.654 .39922 Mdot
.654 .3994 Mdot
.654 .39949 Mdot
.654 .40031 Mdot
.654 .40246 Mdot
.654 .40545 Mdot
.654 .40637 Mdot
.654 .4074 Mdot
.654 .40769 Mdot
.654 .40813 Mdot
.654 .40987 Mdot
.654 .41019 Mdot
.654 .41021 Mdot
.654 .41088 Mdot
.654 .41105 Mdot
.654 .41421 Mdot
.654 .41423 Mdot
.654 .41428 Mdot
.654 .41433 Mdot
.654 .41434 Mdot
.654 .41482 Mdot
.654 .41487 Mdot
.654 .41487 Mdot
.654 .41495 Mdot
.654 .41512 Mdot
.654 .41513 Mdot
.654 .41523 Mdot
.654 .41548 Mdot
.654 .41549 Mdot
.654 .4156 Mdot
.654 .41594 Mdot
.654 .41598 Mdot
.654 .41602 Mdot
.654 .41608 Mdot
.654 .41664 Mdot
.654 .4174 Mdot
.654 .41741 Mdot
.654 .41773 Mdot
.654 .41789 Mdot
.654 .41818 Mdot
.654 .41818 Mdot
.654 .41851 Mdot
.654 .41905 Mdot
.654 .41906 Mdot
.654 .41995 Mdot
.654 .42004 Mdot
.654 .4202 Mdot
.654 .42087 Mdot
.654 .42112 Mdot
.654 .42124 Mdot
.654 .4213 Mdot
.654 .42146 Mdot
.654 .42206 Mdot
.654 .42212 Mdot
.654 .42216 Mdot
.654 .42222 Mdot
.654 .42224 Mdot
.654 .42235 Mdot
.654 .42245 Mdot
.654 .42267 Mdot
.654 .42268 Mdot
.654 .42314 Mdot
.654 .42356 Mdot
.654 .42448 Mdot
.654 .42464 Mdot
.654 .42504 Mdot
.654 .42541 Mdot
.654 .42543 Mdot
.654 .42547 Mdot
.654 .42564 Mdot
.654 .42653 Mdot
.654 .42749 Mdot
.654 .4276 Mdot
.654 .42777 Mdot
.654 .42791 Mdot
.654 .42862 Mdot
.654 .4288 Mdot
.654 .42881 Mdot
.654 .42882 Mdot
.654 .42882 Mdot
.654 .42885 Mdot
.654 .42934 Mdot
.654 .43009 Mdot
.654 .43009 Mdot
.654 .43018 Mdot
.654 .43024 Mdot
.654 .43027 Mdot
.654 .43053 Mdot
.654 .43218 Mdot
.654 .4329 Mdot
.654 .43305 Mdot
.654 .43361 Mdot
.654 .43371 Mdot
.654 .43372 Mdot
.654 .43604 Mdot
.654 .43641 Mdot
.654 .43658 Mdot
.654 .43658 Mdot
.654 .43731 Mdot
.654 .43759 Mdot
.654 .43761 Mdot
.654 .43776 Mdot
.654 .43835 Mdot
.654 .43902 Mdot
.654 .43934 Mdot
.654 .43937 Mdot
.654 .43947 Mdot
.654 .43971 Mdot
.654 .43977 Mdot
.654 .43977 Mdot
.654 .43994 Mdot
.654 .44139 Mdot
.654 .44139 Mdot
.654 .44228 Mdot
.654 .44267 Mdot
.654 .44293 Mdot
.654 .44325 Mdot
.654 .44338 Mdot
.654 .4434 Mdot
.654 .44424 Mdot
.654 .44445 Mdot
.654 .44461 Mdot
.654 .44489 Mdot
.654 .44502 Mdot
.654 .44542 Mdot
.654 .44558 Mdot
.654 .4458 Mdot
.654 .44629 Mdot
.654 .44656 Mdot
.654 .44693 Mdot
.654 .44744 Mdot
.654 .44836 Mdot
.654 .44836 Mdot
.654 .44839 Mdot
.654 .44853 Mdot
.654 .4486 Mdot
.654 .44916 Mdot
.654 .44958 Mdot
.654 .44959 Mdot
.654 .44975 Mdot
.654 .45016 Mdot
.654 .45025 Mdot
.654 .45175 Mdot
.654 .45176 Mdot
.654 .45416 Mdot
.654 .45444 Mdot
.654 .45445 Mdot
.654 .45455 Mdot
.654 .45493 Mdot
.654 .4551 Mdot
.654 .45516 Mdot
.654 .45568 Mdot
.654 .45678 Mdot
.654 .45727 Mdot
.654 .45774 Mdot
.654 .45797 Mdot
.654 .45798 Mdot
.654 .45801 Mdot
.654 .45847 Mdot
.654 .45918 Mdot
.654 .45965 Mdot
.654 .45966 Mdot
.654 .45994 Mdot
.654 .46026 Mdot
.654 .46035 Mdot
.654 .46052 Mdot
.654 .46217 Mdot
.654 .4638 Mdot
.654 .46389 Mdot
.654 .46423 Mdot
.654 .46424 Mdot
.654 .4644 Mdot
.654 .46528 Mdot
.654 .46551 Mdot
.654 .46565 Mdot
.654 .46617 Mdot
.654 .46663 Mdot
.654 .46812 Mdot
.654 .46919 Mdot
.654 .46959 Mdot
.654 .46964 Mdot
.654 .46972 Mdot
.654 .46986 Mdot
.654 .46987 Mdot
.654 .47044 Mdot
.654 .47061 Mdot
.654 .47098 Mdot
.654 .47101 Mdot
.654 .47133 Mdot
.654 .47138 Mdot
.654 .47175 Mdot
.654 .4718 Mdot
.654 .47181 Mdot
.654 .47181 Mdot
.654 .47183 Mdot
.654 .4721 Mdot
.654 .47238 Mdot
.654 .4727 Mdot
.654 .47318 Mdot
.654 .47339 Mdot
.654 .47364 Mdot
.654 .4738 Mdot
.654 .47501 Mdot
.654 .47524 Mdot
.654 .47536 Mdot
.654 .47537 Mdot
.654 .47554 Mdot
.654 .476 Mdot
.654 .47656 Mdot
.654 .4768 Mdot
.654 .47686 Mdot
.654 .4769 Mdot
.654 .47727 Mdot
.654 .47736 Mdot
.654 .47743 Mdot
.654 .47795 Mdot
.654 .47802 Mdot
.654 .4781 Mdot
.654 .47825 Mdot
.654 .47868 Mdot
.654 .47936 Mdot
.654 .4796 Mdot
.654 .48 Mdot
.654 .48008 Mdot
.654 .4801 Mdot
.654 .4802 Mdot
.654 .48087 Mdot
.654 .48089 Mdot
.654 .48093 Mdot
.654 .4812 Mdot
.654 .48133 Mdot
.654 .4815 Mdot
.654 .48153 Mdot
.654 .48161 Mdot
.654 .48167 Mdot
.654 .48175 Mdot
.654 .48261 Mdot
.654 .48284 Mdot
.654 .48292 Mdot
.654 .48309 Mdot
.654 .48344 Mdot
.654 .48345 Mdot
.654 .4836 Mdot
.654 .48384 Mdot
.654 .48421 Mdot
.654 .4843 Mdot
.654 .48439 Mdot
.654 .48461 Mdot
.654 .48464 Mdot
.654 .48474 Mdot
.654 .48475 Mdot
.654 .48522 Mdot
.654 .48529 Mdot
.654 .48599 Mdot
.654 .48601 Mdot
.654 .48645 Mdot
.654 .48675 Mdot
.654 .48721 Mdot
.654 .48721 Mdot
.654 .48761 Mdot
.654 .48783 Mdot
.654 .48826 Mdot
.654 .48829 Mdot
.654 .48897 Mdot
.654 .48933 Mdot
.654 .48997 Mdot
.654 .49008 Mdot
.654 .49016 Mdot
.654 .49022 Mdot
.654 .49027 Mdot
.654 .49073 Mdot
.654 .49088 Mdot
.654 .4909 Mdot
.654 .49101 Mdot
.654 .49123 Mdot
.654 .49126 Mdot
.654 .49136 Mdot
.654 .49138 Mdot
.654 .4916 Mdot
.654 .49171 Mdot
.654 .49172 Mdot
.654 .49178 Mdot
.654 .49219 Mdot
.654 .49242 Mdot
.654 .49243 Mdot
.654 .4925 Mdot
.654 .49256 Mdot
.654 .49259 Mdot
.654 .49444 Mdot
.654 .49488 Mdot
.654 .49502 Mdot
.654 .49674 Mdot
.654 .49696 Mdot
.654 .49746 Mdot
.654 .49782 Mdot
.654 .49784 Mdot
.654 .49825 Mdot
.654 .4987 Mdot
.654 .49935 Mdot
.654 .49948 Mdot
.654 .50026 Mdot
.654 .50045 Mdot
.654 .50096 Mdot
.654 .50098 Mdot
.654 .50101 Mdot
.654 .50135 Mdot
.654 .50136 Mdot
.654 .50263 Mdot
.654 .50343 Mdot
.654 .50354 Mdot
.654 .50377 Mdot
.654 .504 Mdot
.654 .50522 Mdot
.654 .50661 Mdot
.654 .50735 Mdot
.654 .50764 Mdot
.654 .5077 Mdot
.654 .50862 Mdot
.654 .50879 Mdot
.654 .50924 Mdot
.654 .50987 Mdot
.654 .51081 Mdot
.654 .51092 Mdot
.654 .51111 Mdot
.654 .51121 Mdot
.654 .51145 Mdot
.654 .51146 Mdot
.654 .51155 Mdot
.654 .51189 Mdot
.654 .51193 Mdot
.654 .51231 Mdot
.654 .51277 Mdot
.654 .51317 Mdot
.654 .51401 Mdot
.654 .51407 Mdot
.654 .51443 Mdot
.654 .51448 Mdot
.654 .51479 Mdot
.654 .51491 Mdot
.654 .51498 Mdot
.654 .51515 Mdot
.654 .51575 Mdot
.654 .51586 Mdot
.654 .51587 Mdot
.654 .51588 Mdot
.654 .51593 Mdot
.654 .51632 Mdot
.654 .51653 Mdot
.654 .51681 Mdot
.654 .51714 Mdot
.654 .51718 Mdot
.654 .51725 Mdot
.654 .51786 Mdot
.654 .51799 Mdot
.654 .51891 Mdot
.654 .51917 Mdot
.654 .51936 Mdot
.654 .5199 Mdot
.654 .52024 Mdot
.654 .52043 Mdot
.654 .52097 Mdot
.654 .52119 Mdot
.654 .52122 Mdot
.654 .52129 Mdot
.654 .52282 Mdot
.654 .523 Mdot
.654 .52331 Mdot
.654 .52356 Mdot
.654 .52358 Mdot
.654 .52386 Mdot
.654 .52394 Mdot
.654 .52424 Mdot
.654 .52489 Mdot
.654 .52537 Mdot
.654 .52583 Mdot
.654 .52604 Mdot
.654 .52653 Mdot
.654 .52666 Mdot
.654 .52672 Mdot
.654 .52679 Mdot
.654 .52697 Mdot
.654 .52748 Mdot
.654 .52767 Mdot
.654 .5278 Mdot
.654 .52813 Mdot
.654 .52883 Mdot
.654 .52885 Mdot
.654 .52896 Mdot
.654 .52912 Mdot
.654 .52942 Mdot
.654 .52951 Mdot
.654 .52989 Mdot
.654 .53018 Mdot
.654 .5302 Mdot
.654 .53027 Mdot
.654 .53056 Mdot
.654 .53067 Mdot
.654 .53072 Mdot
.654 .53145 Mdot
.654 .53157 Mdot
.654 .53203 Mdot
.654 .53208 Mdot
.654 .53279 Mdot
.654 .53294 Mdot
.654 .53297 Mdot
.654 .53315 Mdot
.654 .53327 Mdot
.654 .53349 Mdot
.654 .53358 Mdot
.654 .53439 Mdot
.654 .53443 Mdot
.654 .53452 Mdot
.654 .535 Mdot
.654 .53525 Mdot
.654 .53553 Mdot
.654 .53555 Mdot
.654 .53559 Mdot
.654 .53573 Mdot
.654 .53574 Mdot
.654 .53585 Mdot
.654 .536 Mdot
.654 .53624 Mdot
.654 .53652 Mdot
.654 .53694 Mdot
.654 .53701 Mdot
.654 .53735 Mdot
.654 .53752 Mdot
.654 .53792 Mdot
.654 .53805 Mdot
.654 .53835 Mdot
.654 .53893 Mdot
.654 .53896 Mdot
.654 .53897 Mdot
.654 .53904 Mdot
.654 .53922 Mdot
.654 .53964 Mdot
.654 .54002 Mdot
.654 .54026 Mdot
.654 .54028 Mdot
.654 .5404 Mdot
.654 .54055 Mdot
.654 .54092 Mdot
.654 .54097 Mdot
.654 .54113 Mdot
.654 .54114 Mdot
.654 .54179 Mdot
.654 .5419 Mdot
.654 .54191 Mdot
.654 .54201 Mdot
.654 .54212 Mdot
.654 .54269 Mdot
.654 .54283 Mdot
.654 .54288 Mdot
.654 .54314 Mdot
.654 .54316 Mdot
.654 .54345 Mdot
.654 .54384 Mdot
.654 .54418 Mdot
.654 .54431 Mdot
.654 .54434 Mdot
.654 .5449 Mdot
.654 .545 Mdot
.654 .54501 Mdot
.654 .5452 Mdot
.654 .5454 Mdot
.654 .54544 Mdot
.654 .54561 Mdot
.654 .54593 Mdot
.654 .54656 Mdot
.654 .54659 Mdot
.654 .54671 Mdot
.654 .54727 Mdot
.654 .5475 Mdot
.654 .54756 Mdot
.654 .54782 Mdot
.654 .54806 Mdot
.654 .54867 Mdot
.654 .54894 Mdot
.654 .54896 Mdot
.654 .54907 Mdot
.654 .54909 Mdot
.654 .54917 Mdot
.654 .54919 Mdot
.654 .54928 Mdot
.654 .54934 Mdot
.654 .54937 Mdot
.654 .54995 Mdot
.654 .55014 Mdot
.654 .55014 Mdot
.654 .55016 Mdot
.654 .55031 Mdot
.654 .55046 Mdot
.654 .55059 Mdot
.654 .55062 Mdot
.654 .55076 Mdot
.654 .55078 Mdot
.654 .55106 Mdot
.654 .55116 Mdot
.654 .5512 Mdot
.654 .5512 Mdot
.654 .55128 Mdot
.654 .55178 Mdot
.654 .55185 Mdot
.654 .55206 Mdot
.654 .55207 Mdot
.654 .55215 Mdot
.654 .55223 Mdot
.654 .55226 Mdot
.654 .55275 Mdot
.654 .55316 Mdot
.654 .55327 Mdot
.654 .55363 Mdot
.654 .55365 Mdot
.654 .55398 Mdot
.654 .55435 Mdot
.654 .55436 Mdot
.654 .55458 Mdot
.654 .55482 Mdot
.654 .55496 Mdot
.654 .55633 Mdot
.654 .55641 Mdot
.654 .55644 Mdot
.654 .55664 Mdot
.654 .55667 Mdot
.654 .55684 Mdot
.654 .55722 Mdot
.654 .55729 Mdot
.654 .5574 Mdot
.654 .55759 Mdot
.654 .55762 Mdot
.654 .55772 Mdot
.654 .55796 Mdot
.654 .55822 Mdot
.654 .55832 Mdot
.654 .55838 Mdot
.654 .55861 Mdot
.654 .55882 Mdot
.654 .55891 Mdot
.654 .55934 Mdot
.654 .55944 Mdot
.654 .55946 Mdot
.654 .55959 Mdot
.654 .55987 Mdot
.654 .55992 Mdot
.654 .55993 Mdot
.654 .55993 Mdot
.654 .55995 Mdot
.654 .55995 Mdot
.654 .56016 Mdot
.654 .56017 Mdot
.654 .56017 Mdot
.654 .56035 Mdot
.654 .56071 Mdot
.654 .56074 Mdot
.654 .56074 Mdot
.654 .56075 Mdot
.654 .56081 Mdot
.654 .56088 Mdot
.654 .56113 Mdot
.654 .56121 Mdot
.654 .56124 Mdot
.654 .56126 Mdot
.654 .5613 Mdot
.654 .56131 Mdot
.654 .56141 Mdot
.654 .56144 Mdot
.654 .56146 Mdot
.654 .56151 Mdot
.654 .56162 Mdot
.654 .56164 Mdot
.654 .56195 Mdot
.654 .56195 Mdot
.654 .56207 Mdot
.654 .5622 Mdot
.654 .56229 Mdot
.654 .5623 Mdot
.654 .56231 Mdot
.654 .56237 Mdot
.654 .56239 Mdot
.654 .56239 Mdot
.654 .56243 Mdot
.654 .56244 Mdot
.654 .56245 Mdot
.654 .56247 Mdot
.654 .56249 Mdot
.654 .56249 Mdot
.654 .56249 Mdot
.654 .56257 Mdot
.654 .56257 Mdot
.654 .56258 Mdot
.654 .56259 Mdot
.656 .15518 Mdot
.656 .15518 Mdot
.656 .15519 Mdot
.656 .15521 Mdot
.656 .15525 Mdot
.656 .15526 Mdot
.656 .15528 Mdot
.656 .15537 Mdot
.656 .15542 Mdot
.656 .15545 Mdot
.656 .1555 Mdot
.656 .15567 Mdot
.656 .1558 Mdot
.656 .15588 Mdot
.656 .15625 Mdot
.656 .15628 Mdot
.656 .15641 Mdot
.656 .1565 Mdot
.656 .15656 Mdot
.656 .15656 Mdot
.656 .1568 Mdot
.656 .1568 Mdot
.656 .15693 Mdot
.656 .15715 Mdot
.656 .15733 Mdot
.656 .15744 Mdot
.656 .15796 Mdot
.656 .15812 Mdot
.656 .15875 Mdot
.656 .15904 Mdot
.656 .15916 Mdot
.656 .16089 Mdot
.656 .16098 Mdot
.656 .16112 Mdot
.656 .16185 Mdot
.656 .1619 Mdot
.656 .16249 Mdot
.656 .16273 Mdot
.656 .16396 Mdot
.656 .16397 Mdot
.656 .16435 Mdot
.656 .16441 Mdot
.656 .16445 Mdot
.656 .16462 Mdot
.656 .1647 Mdot
.656 .16585 Mdot
.656 .16585 Mdot
.656 .16633 Mdot
.656 .1674 Mdot
.656 .16767 Mdot
.656 .16791 Mdot
.656 .16805 Mdot
.656 .16939 Mdot
.656 .16979 Mdot
.656 .17112 Mdot
.656 .17132 Mdot
.656 .17157 Mdot
.656 .17279 Mdot
.656 .1728 Mdot
.656 .17291 Mdot
.656 .17378 Mdot
.656 .17403 Mdot
.656 .17484 Mdot
.656 .17537 Mdot
.656 .17549 Mdot
.656 .17632 Mdot
.656 .17641 Mdot
.656 .1769 Mdot
.656 .17695 Mdot
.656 .17901 Mdot
.656 .17922 Mdot
.656 .17937 Mdot
.656 .17949 Mdot
.656 .17976 Mdot
.656 .17984 Mdot
.656 .18078 Mdot
.656 .1818 Mdot
.656 .18186 Mdot
.656 .18189 Mdot
.656 .18206 Mdot
.656 .18213 Mdot
.656 .18242 Mdot
.656 .18258 Mdot
.656 .18271 Mdot
.656 .18289 Mdot
.656 .18348 Mdot
.656 .18374 Mdot
.656 .18397 Mdot
.656 .18419 Mdot
.656 .18458 Mdot
.656 .18469 Mdot
.656 .1862 Mdot
.656 .18637 Mdot
.656 .18642 Mdot
.656 .18713 Mdot
.656 .18736 Mdot
.656 .18744 Mdot
.656 .18811 Mdot
.656 .18819 Mdot
.656 .18875 Mdot
.656 .18934 Mdot
.656 .18976 Mdot
.656 .1909 Mdot
.656 .19168 Mdot
.656 .19186 Mdot
.656 .19207 Mdot
.656 .19299 Mdot
.656 .19307 Mdot
.656 .19344 Mdot
.656 .19432 Mdot
.656 .19437 Mdot
.656 .19492 Mdot
.656 .19496 Mdot
.656 .19535 Mdot
.656 .19576 Mdot
.656 .1967 Mdot
.656 .19683 Mdot
.656 .19743 Mdot
.656 .1975 Mdot
.656 .19754 Mdot
.656 .19891 Mdot
.656 .20044 Mdot
.656 .20069 Mdot
.656 .20073 Mdot
.656 .20131 Mdot
.656 .20184 Mdot
.656 .20195 Mdot
.656 .20198 Mdot
.656 .2033 Mdot
.656 .20378 Mdot
.656 .20402 Mdot
.656 .20455 Mdot
.656 .20492 Mdot
.656 .20521 Mdot
.656 .20554 Mdot
.656 .20557 Mdot
.656 .20653 Mdot
.656 .20667 Mdot
.656 .20756 Mdot
.656 .20983 Mdot
.656 .21069 Mdot
.656 .21241 Mdot
.656 .21259 Mdot
.656 .21505 Mdot
.656 .21517 Mdot
.656 .21537 Mdot
.656 .21822 Mdot
.656 .21979 Mdot
.656 .21985 Mdot
.656 .22041 Mdot
.656 .22105 Mdot
.656 .22116 Mdot
.656 .22287 Mdot
.656 .22294 Mdot
.656 .2233 Mdot
.656 .22424 Mdot
.656 .22425 Mdot
.656 .22441 Mdot
.656 .22455 Mdot
.656 .225 Mdot
.656 .22568 Mdot
.656 .22577 Mdot
.656 .22581 Mdot
.656 .22737 Mdot
.656 .22741 Mdot
.656 .22817 Mdot
.656 .22928 Mdot
.656 .23017 Mdot
.656 .23059 Mdot
.656 .23172 Mdot
.656 .23706 Mdot
.656 .23816 Mdot
.656 .23877 Mdot
.656 .239 Mdot
.656 .24007 Mdot
.656 .24298 Mdot
.656 .24308 Mdot
.656 .24333 Mdot
.656 .24608 Mdot
.656 .24763 Mdot
.656 .24797 Mdot
.656 .24868 Mdot
.656 .24874 Mdot
.656 .24932 Mdot
.656 .25002 Mdot
.656 .2508 Mdot
.656 .25085 Mdot
.656 .25143 Mdot
.656 .25353 Mdot
.656 .25362 Mdot
.656 .25496 Mdot
.656 .25739 Mdot
.656 .25792 Mdot
.656 .2586 Mdot
.656 .26038 Mdot
.656 .26399 Mdot
.656 .26458 Mdot
.656 .26536 Mdot
.656 .26614 Mdot
.656 .26757 Mdot
.656 .26794 Mdot
.656 .26897 Mdot
.656 .26942 Mdot
.656 .26946 Mdot
.656 .27063 Mdot
.656 .27177 Mdot
.656 .27417 Mdot
.656 .27452 Mdot
.656 .27606 Mdot
.656 .2761 Mdot
.656 .2772 Mdot
.656 .27838 Mdot
.656 .27931 Mdot
.656 .27941 Mdot
.656 .28087 Mdot
.656 .28375 Mdot
.656 .28389 Mdot
.656 .28413 Mdot
.656 .28602 Mdot
.656 .28603 Mdot
.656 .2873 Mdot
.656 .28771 Mdot
.656 .28815 Mdot
.656 .28817 Mdot
.656 .2897 Mdot
.656 .29086 Mdot
.656 .29188 Mdot
.656 .29208 Mdot
.656 .295 Mdot
.656 .29697 Mdot
.656 .29729 Mdot
.656 .29846 Mdot
.656 .29872 Mdot
.656 .29915 Mdot
.656 .30006 Mdot
.656 .30007 Mdot
.656 .30076 Mdot
.656 .30077 Mdot
.656 .30094 Mdot
.656 .305 Mdot
.656 .30553 Mdot
.656 .30595 Mdot
.656 .30674 Mdot
.656 .30692 Mdot
.656 .30765 Mdot
.656 .30908 Mdot
.656 .3096 Mdot
.656 .30975 Mdot
.656 .31088 Mdot
.656 .31267 Mdot
.656 .31396 Mdot
.656 .31456 Mdot
.656 .3149 Mdot
.656 .31631 Mdot
.656 .31638 Mdot
.656 .31682 Mdot
.656 .31832 Mdot
.656 .32229 Mdot
.656 .32283 Mdot
.656 .32581 Mdot
.656 .32724 Mdot
.656 .32802 Mdot
.656 .33039 Mdot
.656 .33044 Mdot
.656 .33064 Mdot
.656 .33252 Mdot
.656 .33363 Mdot
.656 .33558 Mdot
.656 .33596 Mdot
.656 .33734 Mdot
.656 .33756 Mdot
.656 .33862 Mdot
.656 .33944 Mdot
.656 .34031 Mdot
.656 .34074 Mdot
.656 .34148 Mdot
.656 .34155 Mdot
.656 .34367 Mdot
.656 .34378 Mdot
.656 .34406 Mdot
.656 .34412 Mdot
.656 .34479 Mdot
.656 .34551 Mdot
.656 .34555 Mdot
.656 .34558 Mdot
.656 .34569 Mdot
.656 .34574 Mdot
.656 .34594 Mdot
.656 .34605 Mdot
.656 .34614 Mdot
.656 .34666 Mdot
.656 .34684 Mdot
.656 .34699 Mdot
.656 .34714 Mdot
.656 .34748 Mdot
.656 .34847 Mdot
.656 .34921 Mdot
.656 .34926 Mdot
.656 .34969 Mdot
.656 .34974 Mdot
.656 .35072 Mdot
.656 .35141 Mdot
.656 .35199 Mdot
.656 .35212 Mdot
.656 .35272 Mdot
.656 .35293 Mdot
.656 .35348 Mdot
.656 .3538 Mdot
.656 .35382 Mdot
.656 .35428 Mdot
.656 .35482 Mdot
.656 .35489 Mdot
.656 .35523 Mdot
.656 .35527 Mdot
.656 .35529 Mdot
.656 .35606 Mdot
.656 .35689 Mdot
.656 .35703 Mdot
.656 .35705 Mdot
.656 .35736 Mdot
.656 .35771 Mdot
.656 .35772 Mdot
.656 .35843 Mdot
.656 .35869 Mdot
.656 .35881 Mdot
.656 .35909 Mdot
.656 .35928 Mdot
.656 .35961 Mdot
.656 .35962 Mdot
.656 .36019 Mdot
.656 .36179 Mdot
.656 .36222 Mdot
.656 .36316 Mdot
.656 .36436 Mdot
.656 .36586 Mdot
.656 .36663 Mdot
.656 .36689 Mdot
.656 .36805 Mdot
.656 .36821 Mdot
.656 .36864 Mdot
.656 .36865 Mdot
.656 .36878 Mdot
.656 .36899 Mdot
.656 .36933 Mdot
.656 .37005 Mdot
.656 .37089 Mdot
.656 .37128 Mdot
.656 .37146 Mdot
.656 .37424 Mdot
.656 .3755 Mdot
.656 .3767 Mdot
.656 .37674 Mdot
.656 .37684 Mdot
.656 .37859 Mdot
.656 .37873 Mdot
.656 .37901 Mdot
.656 .37954 Mdot
.656 .37985 Mdot
.656 .38011 Mdot
.656 .38093 Mdot
.656 .38149 Mdot
.656 .38244 Mdot
.656 .38264 Mdot
.656 .3829 Mdot
.656 .38359 Mdot
.656 .38496 Mdot
.656 .38519 Mdot
.656 .38548 Mdot
.656 .38577 Mdot
.656 .38645 Mdot
.656 .38683 Mdot
.656 .387 Mdot
.656 .38701 Mdot
.656 .38888 Mdot
.656 .38944 Mdot
.656 .38946 Mdot
.656 .39028 Mdot
.656 .39118 Mdot
.656 .39303 Mdot
.656 .39433 Mdot
.656 .39618 Mdot
.656 .39738 Mdot
.656 .39747 Mdot
.656 .39794 Mdot
.656 .39794 Mdot
.656 .39818 Mdot
.656 .39963 Mdot
.656 .39995 Mdot
.656 .40022 Mdot
.656 .40028 Mdot
.656 .40053 Mdot
.656 .40102 Mdot
.656 .40119 Mdot
.656 .40125 Mdot
.656 .40163 Mdot
.656 .40223 Mdot
.656 .40345 Mdot
.656 .40348 Mdot
.656 .40362 Mdot
.656 .40413 Mdot
.656 .40661 Mdot
.656 .40709 Mdot
.656 .40812 Mdot
.656 .40814 Mdot
.656 .40882 Mdot
.656 .40919 Mdot
.656 .40982 Mdot
.656 .40995 Mdot
.656 .4104 Mdot
.656 .41082 Mdot
.656 .41108 Mdot
.656 .41175 Mdot
.656 .41177 Mdot
.656 .41258 Mdot
.656 .4126 Mdot
.656 .41305 Mdot
.656 .41307 Mdot
.656 .41308 Mdot
.656 .41313 Mdot
.656 .41319 Mdot
.656 .41323 Mdot
.656 .41326 Mdot
.656 .41343 Mdot
.656 .41353 Mdot
.656 .41358 Mdot
.656 .41369 Mdot
.656 .41402 Mdot
.656 .41427 Mdot
.656 .4144 Mdot
.656 .41442 Mdot
.656 .41496 Mdot
.656 .41515 Mdot
.656 .41519 Mdot
.656 .41538 Mdot
.656 .41545 Mdot
.656 .41563 Mdot
.656 .41573 Mdot
.656 .41574 Mdot
.656 .41588 Mdot
.656 .4162 Mdot
.656 .41621 Mdot
.656 .41646 Mdot
.656 .41677 Mdot
.656 .41678 Mdot
.656 .41688 Mdot
.656 .41699 Mdot
.656 .41699 Mdot
.656 .41722 Mdot
.656 .41743 Mdot
.656 .41749 Mdot
.656 .4176 Mdot
.656 .41778 Mdot
.656 .4183 Mdot
.656 .41843 Mdot
.656 .41873 Mdot
.656 .4196 Mdot
.656 .41985 Mdot
.656 .41993 Mdot
.656 .4203 Mdot
.656 .42035 Mdot
.656 .42049 Mdot
.656 .42071 Mdot
.656 .42094 Mdot
.656 .42139 Mdot
.656 .42306 Mdot
.656 .4238 Mdot
.656 .42397 Mdot
.656 .42407 Mdot
.656 .42415 Mdot
.656 .42441 Mdot
.656 .42489 Mdot
.656 .42526 Mdot
.656 .4257 Mdot
.656 .42577 Mdot
.656 .42586 Mdot
.656 .4263 Mdot
.656 .42635 Mdot
.656 .42695 Mdot
.656 .42713 Mdot
.656 .4274 Mdot
.656 .42769 Mdot
.656 .42967 Mdot
.656 .4297 Mdot
.656 .42985 Mdot
.656 .43039 Mdot
.656 .43049 Mdot
.656 .43058 Mdot
.656 .43083 Mdot
.656 .43089 Mdot
.656 .43103 Mdot
.656 .43122 Mdot
.656 .43162 Mdot
.656 .43263 Mdot
.656 .43278 Mdot
.656 .43311 Mdot
.656 .43312 Mdot
.656 .43366 Mdot
.656 .43398 Mdot
.656 .43428 Mdot
.656 .43455 Mdot
.656 .43591 Mdot
.656 .43597 Mdot
.656 .4364 Mdot
.656 .43682 Mdot
.656 .4369 Mdot
.656 .43705 Mdot
.656 .43707 Mdot
.656 .4374 Mdot
.656 .43795 Mdot
.656 .439 Mdot
.656 .43928 Mdot
.656 .43946 Mdot
.656 .44017 Mdot
.656 .44049 Mdot
.656 .44062 Mdot
.656 .44075 Mdot
.656 .44142 Mdot
.656 .44219 Mdot
.656 .44249 Mdot
.656 .44284 Mdot
.656 .44328 Mdot
.656 .44369 Mdot
.656 .44373 Mdot
.656 .44377 Mdot
.656 .44476 Mdot
.656 .44477 Mdot
.656 .44478 Mdot
.656 .44511 Mdot
.656 .44512 Mdot
.656 .4454 Mdot
.656 .4454 Mdot
.656 .44559 Mdot
.656 .4456 Mdot
.656 .44561 Mdot
.656 .44618 Mdot
.656 .4462 Mdot
.656 .44623 Mdot
.656 .44709 Mdot
.656 .44752 Mdot
.656 .44791 Mdot
.656 .44798 Mdot
.656 .44805 Mdot
.656 .44874 Mdot
.656 .4489 Mdot
.656 .44949 Mdot
.656 .4498 Mdot
.656 .45 Mdot
.656 .45008 Mdot
.656 .4506 Mdot
.656 .45139 Mdot
.656 .45154 Mdot
.656 .45188 Mdot
.656 .45237 Mdot
.656 .45245 Mdot
.656 .45301 Mdot
.656 .45323 Mdot
.656 .45344 Mdot
.656 .45398 Mdot
.656 .45515 Mdot
.656 .45545 Mdot
.656 .45587 Mdot
.656 .4559 Mdot
.656 .45622 Mdot
.656 .45645 Mdot
.656 .45665 Mdot
.656 .45709 Mdot
.656 .45724 Mdot
.656 .45763 Mdot
.656 .45851 Mdot
.656 .45875 Mdot
.656 .45906 Mdot
.656 .45909 Mdot
.656 .45933 Mdot
.656 .45946 Mdot
.656 .46014 Mdot
.656 .46041 Mdot
.656 .4605 Mdot
.656 .46056 Mdot
.656 .46082 Mdot
.656 .46082 Mdot
.656 .46093 Mdot
.656 .46094 Mdot
.656 .4614 Mdot
.656 .46166 Mdot
.656 .46187 Mdot
.656 .46216 Mdot
.656 .46309 Mdot
.656 .4631 Mdot
.656 .46352 Mdot
.656 .46353 Mdot
.656 .46387 Mdot
.656 .464 Mdot
.656 .46421 Mdot
.656 .46451 Mdot
.656 .46483 Mdot
.656 .46502 Mdot
.656 .46536 Mdot
.656 .46537 Mdot
.656 .46589 Mdot
.656 .46613 Mdot
.656 .46738 Mdot
.656 .46763 Mdot
.656 .4677 Mdot
.656 .46771 Mdot
.656 .46832 Mdot
.656 .46862 Mdot
.656 .46881 Mdot
.656 .46883 Mdot
.656 .46892 Mdot
.656 .46916 Mdot
.656 .46928 Mdot
.656 .46931 Mdot
.656 .46944 Mdot
.656 .4696 Mdot
.656 .47031 Mdot
.656 .47043 Mdot
.656 .47044 Mdot
.656 .47066 Mdot
.656 .47071 Mdot
.656 .47129 Mdot
.656 .47219 Mdot
.656 .47282 Mdot
.656 .47371 Mdot
.656 .47414 Mdot
.656 .47453 Mdot
.656 .47454 Mdot
.656 .47481 Mdot
.656 .4757 Mdot
.656 .4757 Mdot
.656 .47578 Mdot
.656 .47596 Mdot
.656 .47628 Mdot
.656 .47642 Mdot
.656 .47656 Mdot
.656 .47667 Mdot
.656 .47731 Mdot
.656 .47763 Mdot
.656 .47776 Mdot
.656 .47785 Mdot
.656 .47829 Mdot
.656 .47855 Mdot
.656 .47894 Mdot
.656 .47906 Mdot
.656 .4792 Mdot
.656 .47945 Mdot
.656 .47958 Mdot
.656 .47964 Mdot
.656 .48045 Mdot
.656 .4805 Mdot
.656 .48051 Mdot
.656 .48107 Mdot
.656 .48165 Mdot
.656 .48291 Mdot
.656 .483 Mdot
.656 .48317 Mdot
.656 .48355 Mdot
.656 .48388 Mdot
.656 .48403 Mdot
.656 .48413 Mdot
.656 .48419 Mdot
.656 .48419 Mdot
.656 .48438 Mdot
.656 .48446 Mdot
.656 .48498 Mdot
.656 .48509 Mdot
.656 .48544 Mdot
.656 .48611 Mdot
.656 .48664 Mdot
.656 .48706 Mdot
.656 .48725 Mdot
.656 .48796 Mdot
.656 .48821 Mdot
.656 .48822 Mdot
.656 .48836 Mdot
.656 .48845 Mdot
.656 .48857 Mdot
.656 .48862 Mdot
.656 .48874 Mdot
.656 .48905 Mdot
.656 .48905 Mdot
.656 .4892 Mdot
.656 .48934 Mdot
.656 .48935 Mdot
.656 .48941 Mdot
.656 .48978 Mdot
.656 .49011 Mdot
.656 .49012 Mdot
.656 .49014 Mdot
.656 .49029 Mdot
.656 .49032 Mdot
.656 .49055 Mdot
.656 .49075 Mdot
.656 .49076 Mdot
.656 .4909 Mdot
.656 .49114 Mdot
.656 .49123 Mdot
.656 .49149 Mdot
.656 .49154 Mdot
.656 .49179 Mdot
.656 .4921 Mdot
.656 .49252 Mdot
.656 .49254 Mdot
.656 .49272 Mdot
.656 .49274 Mdot
.656 .49305 Mdot
.656 .49306 Mdot
.656 .49349 Mdot
.656 .49363 Mdot
.656 .4937 Mdot
.656 .49376 Mdot
.656 .49384 Mdot
.656 .49406 Mdot
.656 .4941 Mdot
.656 .49415 Mdot
.656 .49423 Mdot
.656 .49425 Mdot
.656 .4943 Mdot
.656 .49431 Mdot
.656 .49433 Mdot
.656 .49463 Mdot
.656 .49492 Mdot
.656 .49495 Mdot
.656 .49507 Mdot
.656 .49511 Mdot
.656 .49601 Mdot
.656 .49604 Mdot
.656 .49635 Mdot
.656 .49653 Mdot
.656 .4969 Mdot
.656 .49724 Mdot
.656 .49769 Mdot
.656 .49778 Mdot
.656 .49836 Mdot
.656 .49852 Mdot
.656 .49933 Mdot
.656 .49979 Mdot
.656 .50056 Mdot
.656 .50064 Mdot
.656 .50067 Mdot
.656 .50164 Mdot
.656 .50196 Mdot
.656 .50255 Mdot
.656 .50376 Mdot
.656 .50398 Mdot
.656 .50558 Mdot
.656 .50618 Mdot
.656 .50636 Mdot
.656 .50639 Mdot
.656 .50695 Mdot
.656 .50709 Mdot
.656 .50732 Mdot
.656 .50784 Mdot
.656 .50855 Mdot
.656 .50899 Mdot
.656 .50906 Mdot
.656 .50926 Mdot
.656 .50982 Mdot
.656 .51011 Mdot
.656 .51018 Mdot
.656 .51049 Mdot
.656 .51065 Mdot
.656 .51086 Mdot
.656 .51245 Mdot
.656 .51251 Mdot
.656 .51251 Mdot
.656 .51278 Mdot
.656 .51279 Mdot
.656 .51314 Mdot
.656 .51331 Mdot
.656 .51341 Mdot
.656 .51386 Mdot
.656 .51398 Mdot
.656 .51474 Mdot
.656 .51586 Mdot
.656 .51594 Mdot
.656 .51633 Mdot
.656 .51677 Mdot
.656 .51735 Mdot
.656 .51735 Mdot
.656 .51752 Mdot
.656 .51767 Mdot
.656 .51816 Mdot
.656 .51816 Mdot
.656 .51888 Mdot
.656 .51896 Mdot
.656 .51902 Mdot
.656 .5201 Mdot
.656 .52064 Mdot
.656 .52068 Mdot
.656 .52103 Mdot
.656 .52147 Mdot
.656 .52188 Mdot
.656 .52189 Mdot
.656 .52246 Mdot
.656 .52259 Mdot
.656 .52348 Mdot
.656 .5239 Mdot
.656 .52433 Mdot
.656 .52434 Mdot
.656 .52451 Mdot
.656 .52488 Mdot
.656 .52502 Mdot
.656 .52554 Mdot
.656 .52582 Mdot
.656 .52611 Mdot
.656 .52633 Mdot
.656 .52763 Mdot
.656 .52828 Mdot
.656 .52852 Mdot
.656 .52871 Mdot
.656 .52958 Mdot
.656 .53006 Mdot
.656 .5301 Mdot
.656 .53084 Mdot
.656 .53105 Mdot
.656 .53107 Mdot
.656 .53135 Mdot
.656 .5316 Mdot
.656 .5318 Mdot
.656 .53182 Mdot
.656 .53207 Mdot
.656 .53219 Mdot
.656 .53274 Mdot
.656 .53371 Mdot
.656 .5338 Mdot
.656 .53383 Mdot
.656 .53485 Mdot
.656 .53523 Mdot
.656 .53531 Mdot
.656 .53552 Mdot
.656 .5359 Mdot
.656 .53776 Mdot
.656 .53815 Mdot
.656 .53829 Mdot
.656 .5386 Mdot
.656 .53898 Mdot
.656 .53924 Mdot
.656 .53925 Mdot
.656 .53979 Mdot
.656 .5398 Mdot
.656 .53983 Mdot
.656 .54006 Mdot
.656 .54022 Mdot
.656 .54027 Mdot
.656 .54032 Mdot
.656 .54032 Mdot
.656 .54065 Mdot
.656 .54077 Mdot
.656 .54079 Mdot
.656 .54137 Mdot
.656 .54141 Mdot
.656 .54163 Mdot
.656 .54182 Mdot
.656 .54184 Mdot
.656 .54237 Mdot
.656 .54334 Mdot
.656 .5434 Mdot
.656 .54344 Mdot
.656 .54427 Mdot
.656 .54433 Mdot
.656 .54491 Mdot
.656 .5452 Mdot
.656 .54595 Mdot
.656 .54625 Mdot
.656 .5463 Mdot
.656 .54662 Mdot
.656 .54663 Mdot
.656 .54674 Mdot
.656 .54683 Mdot
.656 .54696 Mdot
.656 .54713 Mdot
.656 .54721 Mdot
.656 .54737 Mdot
.656 .54781 Mdot
.656 .54782 Mdot
.656 .54785 Mdot
.656 .54803 Mdot
.656 .54822 Mdot
.656 .54823 Mdot
.656 .54832 Mdot
.656 .54882 Mdot
.656 .54927 Mdot
.656 .54929 Mdot
.656 .54931 Mdot
.656 .54951 Mdot
.656 .54955 Mdot
.656 .54986 Mdot
.656 .54999 Mdot
.656 .55012 Mdot
.656 .55013 Mdot
.656 .55031 Mdot
.656 .55033 Mdot
.656 .55062 Mdot
.656 .55074 Mdot
.656 .55076 Mdot
.656 .55106 Mdot
.656 .55113 Mdot
.656 .55119 Mdot
.656 .55145 Mdot
.656 .55182 Mdot
.656 .55195 Mdot
.656 .55215 Mdot
.656 .55233 Mdot
.656 .55235 Mdot
.656 .55257 Mdot
.656 .5526 Mdot
.656 .55267 Mdot
.656 .5529 Mdot
.656 .55292 Mdot
.656 .55297 Mdot
.656 .55346 Mdot
.656 .5535 Mdot
.656 .55363 Mdot
.656 .5537 Mdot
.656 .55377 Mdot
.656 .55385 Mdot
.656 .55404 Mdot
.656 .5541 Mdot
.656 .55414 Mdot
.656 .5542 Mdot
.656 .55429 Mdot
.656 .55431 Mdot
.656 .55436 Mdot
.656 .55438 Mdot
.656 .55439 Mdot
.656 .55472 Mdot
.656 .55502 Mdot
.656 .55505 Mdot
.656 .55514 Mdot
.656 .55518 Mdot
.656 .55522 Mdot
.656 .55529 Mdot
.656 .55595 Mdot
.656 .55597 Mdot
.656 .55613 Mdot
.656 .55615 Mdot
.656 .55642 Mdot
.656 .55646 Mdot
.656 .55663 Mdot
.656 .55688 Mdot
.656 .55696 Mdot
.656 .55724 Mdot
.656 .55728 Mdot
.656 .55728 Mdot
.656 .55767 Mdot
.656 .55775 Mdot
.656 .55781 Mdot
.656 .55823 Mdot
.656 .55836 Mdot
.656 .55878 Mdot
.656 .55883 Mdot
.656 .5589 Mdot
.656 .55899 Mdot
.656 .55933 Mdot
.656 .55948 Mdot
.656 .55948 Mdot
.656 .55984 Mdot
.656 .55986 Mdot
.656 .55992 Mdot
.656 .55993 Mdot
.656 .55995 Mdot
.656 .56007 Mdot
.656 .56007 Mdot
.656 .56046 Mdot
.656 .56054 Mdot
.656 .56072 Mdot
.656 .56074 Mdot
.656 .56096 Mdot
.656 .56101 Mdot
.656 .56104 Mdot
.656 .56158 Mdot
.656 .56162 Mdot
.656 .56171 Mdot
.656 .5619 Mdot
.656 .56195 Mdot
.656 .56212 Mdot
.656 .56215 Mdot
.656 .56221 Mdot
.656 .56228 Mdot
.656 .56232 Mdot
.656 .56232 Mdot
.656 .56239 Mdot
.656 .56239 Mdot
.656 .56241 Mdot
.656 .56244 Mdot
.656 .56248 Mdot
.656 .56249 Mdot
.656 .5626 Mdot
.656 .56263 Mdot
.656 .56267 Mdot
.656 .56272 Mdot
.656 .56274 Mdot
.656 .56275 Mdot
.656 .56276 Mdot
.656 .56279 Mdot
.656 .5628 Mdot
.656 .5628 Mdot
.656 .56281 Mdot
.656 .56282 Mdot
.656 .56282 Mdot
.656 .56282 Mdot
.658 .15448 Mdot
.658 .15452 Mdot
.658 .15455 Mdot
.658 .15457 Mdot
.658 .15462 Mdot
.658 .15469 Mdot
.658 .15472 Mdot
.658 .15473 Mdot
.658 .15473 Mdot
.658 .15477 Mdot
.658 .15485 Mdot
.658 .15485 Mdot
.658 .15488 Mdot
.658 .15504 Mdot
.658 .15507 Mdot
.658 .15522 Mdot
.658 .15523 Mdot
.658 .15548 Mdot
.658 .15551 Mdot
.658 .15556 Mdot
.658 .15575 Mdot
.658 .15582 Mdot
.658 .15636 Mdot
.658 .15679 Mdot
.658 .1573 Mdot
.658 .15736 Mdot
.658 .15736 Mdot
.658 .15782 Mdot
.658 .158 Mdot
.658 .15805 Mdot
.658 .15909 Mdot
.658 .1592 Mdot
.658 .15922 Mdot
.658 .15963 Mdot
.658 .15984 Mdot
.658 .16013 Mdot
.658 .16048 Mdot
.658 .16057 Mdot
.658 .16079 Mdot
.658 .16134 Mdot
.658 .16185 Mdot
.658 .16356 Mdot
.658 .16359 Mdot
.658 .16465 Mdot
.658 .16533 Mdot
.658 .16607 Mdot
.658 .1664 Mdot
.658 .16691 Mdot
.658 .16692 Mdot
.658 .16735 Mdot
.658 .16777 Mdot
.658 .16786 Mdot
.658 .16798 Mdot
.658 .16808 Mdot
.658 .16949 Mdot
.658 .16967 Mdot
.658 .16977 Mdot
.658 .17012 Mdot
.658 .17166 Mdot
.658 .17179 Mdot
.658 .17222 Mdot
.658 .17238 Mdot
.658 .17287 Mdot
.658 .17333 Mdot
.658 .17458 Mdot
.658 .17464 Mdot
.658 .1748 Mdot
.658 .17487 Mdot
.658 .17528 Mdot
.658 .17568 Mdot
.658 .17604 Mdot
.658 .1762 Mdot
.658 .17643 Mdot
.658 .17681 Mdot
.658 .17684 Mdot
.658 .17726 Mdot
.658 .17736 Mdot
.658 .17757 Mdot
.658 .17757 Mdot
.658 .17764 Mdot
.658 .17771 Mdot
.658 .178 Mdot
.658 .17867 Mdot
.658 .17868 Mdot
.658 .1789 Mdot
.658 .18023 Mdot
.658 .18037 Mdot
.658 .18037 Mdot
.658 .18055 Mdot
.658 .18063 Mdot
.658 .18123 Mdot
.658 .18147 Mdot
.658 .1818 Mdot
.658 .18192 Mdot
.658 .18368 Mdot
.658 .18374 Mdot
.658 .18417 Mdot
.658 .18441 Mdot
.658 .18445 Mdot
.658 .18483 Mdot
.658 .18525 Mdot
.658 .18668 Mdot
.658 .18711 Mdot
.658 .18729 Mdot
.658 .18747 Mdot
.658 .18747 Mdot
.658 .18757 Mdot
.658 .18797 Mdot
.658 .19114 Mdot
.658 .19119 Mdot
.658 .19213 Mdot
.658 .19261 Mdot
.658 .193 Mdot
.658 .19383 Mdot
.658 .19404 Mdot
.658 .19437 Mdot
.658 .19719 Mdot
.658 .19867 Mdot
.658 .19899 Mdot
.658 .19905 Mdot
.658 .19998 Mdot
.658 .20079 Mdot
.658 .20093 Mdot
.658 .20141 Mdot
.658 .20219 Mdot
.658 .20225 Mdot
.658 .20279 Mdot
.658 .20342 Mdot
.658 .2035 Mdot
.658 .20431 Mdot
.658 .20504 Mdot
.658 .2057 Mdot
.658 .20703 Mdot
.658 .20708 Mdot
.658 .2072 Mdot
.658 .20781 Mdot
.658 .20883 Mdot
.658 .21054 Mdot
.658 .21102 Mdot
.658 .21158 Mdot
.658 .21295 Mdot
.658 .21332 Mdot
.658 .21454 Mdot
.658 .21487 Mdot
.658 .21545 Mdot
.658 .21546 Mdot
.658 .21763 Mdot
.658 .22096 Mdot
.658 .22097 Mdot
.658 .22206 Mdot
.658 .22464 Mdot
.658 .2249 Mdot
.658 .22518 Mdot
.658 .22549 Mdot
.658 .22579 Mdot
.658 .22582 Mdot
.658 .22637 Mdot
.658 .22657 Mdot
.658 .22743 Mdot
.658 .22799 Mdot
.658 .22979 Mdot
.658 .23036 Mdot
.658 .23052 Mdot
.658 .23209 Mdot
.658 .23251 Mdot
.658 .23379 Mdot
.658 .2338 Mdot
.658 .23502 Mdot
.658 .23545 Mdot
.658 .23692 Mdot
.658 .23891 Mdot
.658 .2392 Mdot
.658 .24424 Mdot
.658 .2455 Mdot
.658 .24643 Mdot
.658 .24771 Mdot
.658 .24843 Mdot
.658 .24871 Mdot
.658 .24895 Mdot
.658 .25062 Mdot
.658 .25062 Mdot
.658 .25348 Mdot
.658 .25696 Mdot
.658 .25727 Mdot
.658 .25735 Mdot
.658 .25837 Mdot
.658 .26054 Mdot
.658 .26062 Mdot
.658 .26156 Mdot
.658 .26159 Mdot
.658 .2645 Mdot
.658 .26499 Mdot
.658 .2655 Mdot
.658 .26609 Mdot
.658 .26976 Mdot
.658 .27032 Mdot
.658 .27076 Mdot
.658 .2723 Mdot
.658 .27247 Mdot
.658 .27288 Mdot
.658 .27533 Mdot
.658 .27564 Mdot
.658 .27717 Mdot
.658 .27722 Mdot
.658 .27841 Mdot
.658 .27879 Mdot
.658 .28117 Mdot
.658 .28174 Mdot
.658 .28316 Mdot
.658 .28328 Mdot
.658 .28336 Mdot
.658 .2842 Mdot
.658 .28507 Mdot
.658 .28585 Mdot
.658 .2866 Mdot
.658 .28781 Mdot
.658 .29233 Mdot
.658 .29277 Mdot
.658 .29374 Mdot
.658 .29376 Mdot
.658 .29394 Mdot
.658 .29576 Mdot
.658 .29619 Mdot
.658 .2971 Mdot
.658 .29712 Mdot
.658 .3009 Mdot
.658 .3011 Mdot
.658 .30174 Mdot
.658 .30378 Mdot
.658 .30458 Mdot
.658 .30547 Mdot
.658 .30554 Mdot
.658 .3056 Mdot
.658 .30579 Mdot
.658 .30685 Mdot
.658 .30721 Mdot
.658 .30884 Mdot
.658 .31052 Mdot
.658 .31167 Mdot
.658 .3128 Mdot
.658 .3133 Mdot
.658 .3133 Mdot
.658 .31443 Mdot
.658 .31505 Mdot
.658 .3151 Mdot
.658 .31604 Mdot
.658 .31615 Mdot
.658 .31862 Mdot
.658 .31969 Mdot
.658 .3208 Mdot
.658 .32218 Mdot
.658 .32494 Mdot
.658 .32622 Mdot
.658 .32634 Mdot
.658 .32665 Mdot
.658 .32741 Mdot
.658 .32809 Mdot
.658 .33019 Mdot
.658 .33331 Mdot
.658 .33382 Mdot
.658 .33425 Mdot
.658 .33497 Mdot
.658 .33645 Mdot
.658 .33655 Mdot
.658 .33821 Mdot
.658 .33833 Mdot
.658 .33869 Mdot
.658 .33883 Mdot
.658 .34063 Mdot
.658 .34068 Mdot
.658 .34119 Mdot
.658 .3415 Mdot
.658 .34177 Mdot
.658 .3419 Mdot
.658 .34208 Mdot
.658 .34236 Mdot
.658 .34278 Mdot
.658 .34293 Mdot
.658 .34294 Mdot
.658 .34298 Mdot
.658 .34304 Mdot
.658 .34325 Mdot
.658 .34375 Mdot
.658 .34375 Mdot
.658 .34391 Mdot
.658 .34487 Mdot
.658 .34496 Mdot
.658 .34496 Mdot
.658 .34509 Mdot
.658 .34596 Mdot
.658 .34604 Mdot
.658 .34723 Mdot
.658 .34756 Mdot
.658 .34774 Mdot
.658 .34799 Mdot
.658 .34919 Mdot
.658 .34946 Mdot
.658 .34957 Mdot
.658 .34969 Mdot
.658 .34969 Mdot
.658 .34975 Mdot
.658 .35 Mdot
.658 .35197 Mdot
.658 .35281 Mdot
.658 .35365 Mdot
.658 .35384 Mdot
.658 .35544 Mdot
.658 .35626 Mdot
.658 .35698 Mdot
.658 .35775 Mdot
.658 .35816 Mdot
.658 .35819 Mdot
.658 .35848 Mdot
.658 .35881 Mdot
.658 .35886 Mdot
.658 .35928 Mdot
.658 .36 Mdot
.658 .36071 Mdot
.658 .36159 Mdot
.658 .36245 Mdot
.658 .36268 Mdot
.658 .36296 Mdot
.658 .36363 Mdot
.658 .3638 Mdot
.658 .36439 Mdot
.658 .36483 Mdot
.658 .36483 Mdot
.658 .36586 Mdot
.658 .36791 Mdot
.658 .3692 Mdot
.658 .36946 Mdot
.658 .36959 Mdot
.658 .36985 Mdot
.658 .36994 Mdot
.658 .37057 Mdot
.658 .37136 Mdot
.658 .37168 Mdot
.658 .37236 Mdot
.658 .37308 Mdot
.658 .37309 Mdot
.658 .37361 Mdot
.658 .37441 Mdot
.658 .37524 Mdot
.658 .37536 Mdot
.658 .37743 Mdot
.658 .37794 Mdot
.658 .37832 Mdot
.658 .37923 Mdot
.658 .37933 Mdot
.658 .37999 Mdot
.658 .37999 Mdot
.658 .38247 Mdot
.658 .38262 Mdot
.658 .38384 Mdot
.658 .38387 Mdot
.658 .38534 Mdot
.658 .38572 Mdot
.658 .38731 Mdot
.658 .3883 Mdot
.658 .38846 Mdot
.658 .38935 Mdot
.658 .38946 Mdot
.658 .39002 Mdot
.658 .39047 Mdot
.658 .39217 Mdot
.658 .39382 Mdot
.658 .39541 Mdot
.658 .39556 Mdot
.658 .3959 Mdot
.658 .39591 Mdot
.658 .3966 Mdot
.658 .39675 Mdot
.658 .39837 Mdot
.658 .39844 Mdot
.658 .39866 Mdot
.658 .39936 Mdot
.658 .39963 Mdot
.658 .39993 Mdot
.658 .39996 Mdot
.658 .39998 Mdot
.658 .40004 Mdot
.658 .40052 Mdot
.658 .40108 Mdot
.658 .40164 Mdot
.658 .40203 Mdot
.658 .40241 Mdot
.658 .40296 Mdot
.658 .40318 Mdot
.658 .40353 Mdot
.658 .40436 Mdot
.658 .40554 Mdot
.658 .40687 Mdot
.658 .40691 Mdot
.658 .40727 Mdot
.658 .40818 Mdot
.658 .40937 Mdot
.658 .40951 Mdot
.658 .40974 Mdot
.658 .41026 Mdot
.658 .4108 Mdot
.658 .41158 Mdot
.658 .4116 Mdot
.658 .41177 Mdot
.658 .41187 Mdot
.658 .41195 Mdot
.658 .412 Mdot
.658 .41205 Mdot
.658 .41215 Mdot
.658 .41228 Mdot
.658 .41233 Mdot
.658 .41235 Mdot
.658 .41236 Mdot
.658 .41243 Mdot
.658 .41259 Mdot
.658 .4126 Mdot
.658 .41265 Mdot
.658 .41296 Mdot
.658 .41299 Mdot
.658 .41303 Mdot
.658 .41331 Mdot
.658 .41334 Mdot
.658 .41382 Mdot
.658 .41389 Mdot
.658 .41397 Mdot
.658 .41435 Mdot
.658 .41444 Mdot
.658 .41447 Mdot
.658 .41451 Mdot
.658 .41451 Mdot
.658 .41552 Mdot
.658 .41636 Mdot
.658 .41685 Mdot
.658 .41723 Mdot
.658 .41734 Mdot
.658 .41744 Mdot
.658 .41746 Mdot
.658 .41759 Mdot
.658 .41782 Mdot
.658 .41833 Mdot
.658 .4186 Mdot
.658 .41868 Mdot
.658 .41877 Mdot
.658 .41923 Mdot
.658 .41937 Mdot
.658 .4197 Mdot
.658 .42035 Mdot
.658 .42076 Mdot
.658 .42089 Mdot
.658 .42097 Mdot
.658 .421 Mdot
.658 .4212 Mdot
.658 .42145 Mdot
.658 .42155 Mdot
.658 .42177 Mdot
.658 .422 Mdot
.658 .422 Mdot
.658 .42217 Mdot
.658 .42242 Mdot
.658 .42269 Mdot
.658 .42273 Mdot
.658 .42339 Mdot
.658 .42355 Mdot
.658 .42396 Mdot
.658 .4242 Mdot
.658 .42499 Mdot
.658 .42544 Mdot
.658 .42595 Mdot
.658 .42602 Mdot
.658 .42653 Mdot
.658 .42718 Mdot
.658 .42722 Mdot
.658 .42739 Mdot
.658 .42754 Mdot
.658 .42808 Mdot
.658 .42861 Mdot
.658 .42911 Mdot
.658 .42916 Mdot
.658 .42927 Mdot
.658 .42927 Mdot
.658 .42949 Mdot
.658 .42954 Mdot
.658 .43008 Mdot
.658 .43015 Mdot
.658 .43037 Mdot
.658 .43057 Mdot
.658 .43059 Mdot
.658 .4311 Mdot
.658 .43123 Mdot
.658 .43153 Mdot
.658 .4316 Mdot
.658 .43171 Mdot
.658 .43197 Mdot
.658 .43235 Mdot
.658 .43279 Mdot
.658 .43291 Mdot
.658 .4337 Mdot
.658 .43404 Mdot
.658 .4343 Mdot
.658 .43475 Mdot
.658 .43521 Mdot
.658 .43524 Mdot
.658 .43524 Mdot
.658 .43599 Mdot
.658 .43631 Mdot
.658 .43676 Mdot
.658 .43691 Mdot
.658 .43713 Mdot
.658 .4373 Mdot
.658 .43752 Mdot
.658 .43838 Mdot
.658 .43878 Mdot
.658 .43897 Mdot
.658 .43942 Mdot
.658 .43947 Mdot
.658 .43964 Mdot
.658 .43982 Mdot
.658 .44003 Mdot
.658 .44011 Mdot
.658 .44012 Mdot
.658 .4403 Mdot
.658 .4408 Mdot
.658 .44083 Mdot
.658 .44092 Mdot
.658 .44303 Mdot
.658 .44338 Mdot
.658 .44358 Mdot
.658 .44361 Mdot
.658 .44384 Mdot
.658 .44385 Mdot
.658 .44458 Mdot
.658 .44477 Mdot
.658 .44486 Mdot
.658 .44571 Mdot
.658 .44624 Mdot
.658 .44639 Mdot
.658 .44651 Mdot
.658 .44671 Mdot
.658 .44796 Mdot
.658 .44798 Mdot
.658 .44838 Mdot
.658 .44842 Mdot
.658 .44864 Mdot
.658 .44874 Mdot
.658 .44876 Mdot
.658 .44902 Mdot
.658 .44913 Mdot
.658 .44935 Mdot
.658 .44984 Mdot
.658 .45051 Mdot
.658 .45111 Mdot
.658 .45138 Mdot
.658 .45177 Mdot
.658 .4524 Mdot
.658 .45246 Mdot
.658 .45291 Mdot
.658 .45306 Mdot
.658 .45312 Mdot
.658 .45316 Mdot
.658 .45332 Mdot
.658 .45367 Mdot
.658 .45368 Mdot
.658 .45379 Mdot
.658 .45391 Mdot
.658 .45395 Mdot
.658 .45424 Mdot
.658 .45427 Mdot
.658 .45439 Mdot
.658 .45439 Mdot
.658 .45475 Mdot
.658 .45503 Mdot
.658 .45533 Mdot
.658 .4554 Mdot
.658 .4555 Mdot
.658 .45552 Mdot
.658 .45587 Mdot
.658 .45614 Mdot
.658 .45646 Mdot
.658 .45712 Mdot
.658 .45806 Mdot
.658 .45828 Mdot
.658 .45828 Mdot
.658 .45852 Mdot
.658 .45858 Mdot
.658 .45871 Mdot
.658 .45887 Mdot
.658 .45915 Mdot
.658 .4595 Mdot
.658 .45967 Mdot
.658 .45975 Mdot
.658 .46007 Mdot
.658 .46048 Mdot
.658 .4606 Mdot
.658 .46079 Mdot
.658 .46098 Mdot
.658 .4622 Mdot
.658 .4622 Mdot
.658 .46223 Mdot
.658 .46298 Mdot
.658 .4636 Mdot
.658 .46369 Mdot
.658 .4637 Mdot
.658 .4641 Mdot
.658 .46437 Mdot
.658 .46464 Mdot
.658 .46475 Mdot
.658 .46483 Mdot
.658 .46543 Mdot
.658 .46589 Mdot
.658 .46606 Mdot
.658 .46608 Mdot
.658 .46675 Mdot
.658 .46734 Mdot
.658 .46775 Mdot
.658 .46793 Mdot
.658 .46804 Mdot
.658 .46831 Mdot
.658 .4685 Mdot
.658 .46869 Mdot
.658 .46897 Mdot
.658 .46925 Mdot
.658 .46948 Mdot
.658 .46951 Mdot
.658 .46952 Mdot
.658 .46954 Mdot
.658 .46968 Mdot
.658 .46982 Mdot
.658 .47016 Mdot
.658 .47027 Mdot
.658 .4703 Mdot
.658 .47109 Mdot
.658 .47117 Mdot
.658 .47151 Mdot
.658 .47151 Mdot
.658 .47167 Mdot
.658 .47175 Mdot
.658 .47252 Mdot
.658 .47331 Mdot
.658 .47413 Mdot
.658 .47434 Mdot
.658 .47461 Mdot
.658 .47466 Mdot
.658 .47509 Mdot
.658 .47516 Mdot
.658 .47563 Mdot
.658 .47638 Mdot
.658 .47656 Mdot
.658 .47725 Mdot
.658 .47727 Mdot
.658 .47784 Mdot
.658 .47791 Mdot
.658 .47906 Mdot
.658 .47907 Mdot
.658 .47937 Mdot
.658 .47942 Mdot
.658 .47984 Mdot
.658 .48001 Mdot
.658 .48025 Mdot
.658 .4812 Mdot
.658 .48126 Mdot
.658 .48164 Mdot
.658 .482 Mdot
.658 .48224 Mdot
.658 .48224 Mdot
.658 .48258 Mdot
.658 .48288 Mdot
.658 .48303 Mdot
.658 .48339 Mdot
.658 .48367 Mdot
.658 .48371 Mdot
.658 .48383 Mdot
.658 .48389 Mdot
.658 .48401 Mdot
.658 .48459 Mdot
.658 .48551 Mdot
.658 .48597 Mdot
.658 .48597 Mdot
.658 .48616 Mdot
.658 .48642 Mdot
.658 .4865 Mdot
.658 .4868 Mdot
.658 .48692 Mdot
.658 .48703 Mdot
.658 .48741 Mdot
.658 .4878 Mdot
.658 .48811 Mdot
.658 .48843 Mdot
.658 .48861 Mdot
.658 .48863 Mdot
.658 .48878 Mdot
.658 .4889 Mdot
.658 .48892 Mdot
.658 .4891 Mdot
.658 .48944 Mdot
.658 .48975 Mdot
.658 .49011 Mdot
.658 .49081 Mdot
.658 .49089 Mdot
.658 .49125 Mdot
.658 .49162 Mdot
.658 .49246 Mdot
.658 .49257 Mdot
.658 .4926 Mdot
.658 .4926 Mdot
.658 .49265 Mdot
.658 .4927 Mdot
.658 .49281 Mdot
.658 .49333 Mdot
.658 .49343 Mdot
.658 .49352 Mdot
.658 .49365 Mdot
.658 .49416 Mdot
.658 .4942 Mdot
.658 .49457 Mdot
.658 .49462 Mdot
.658 .49462 Mdot
.658 .49466 Mdot
.658 .49507 Mdot
.658 .49514 Mdot
.658 .49514 Mdot
.658 .49535 Mdot
.658 .49544 Mdot
.658 .49546 Mdot
.658 .49548 Mdot
.658 .49548 Mdot
.658 .49555 Mdot
.658 .49573 Mdot
.658 .49585 Mdot
.658 .49592 Mdot
.658 .49597 Mdot
.658 .49609 Mdot
.658 .49622 Mdot
.658 .49644 Mdot
.658 .49646 Mdot
.658 .49721 Mdot
.658 .49727 Mdot
.658 .49742 Mdot
.658 .49747 Mdot
.658 .49817 Mdot
.658 .49821 Mdot
.658 .49883 Mdot
.658 .49912 Mdot
.658 .4993 Mdot
.658 .49952 Mdot
.658 .5008 Mdot
.658 .50167 Mdot
.658 .50195 Mdot
.658 .50226 Mdot
.658 .50238 Mdot
.658 .50243 Mdot
.658 .50296 Mdot
.658 .50407 Mdot
.658 .50463 Mdot
.658 .50508 Mdot
.658 .50551 Mdot
.658 .5065 Mdot
.658 .50655 Mdot
.658 .50692 Mdot
.658 .50694 Mdot
.658 .50719 Mdot
.658 .50764 Mdot
.658 .50764 Mdot
.658 .50784 Mdot
.658 .50829 Mdot
.658 .50874 Mdot
.658 .5094 Mdot
.658 .51005 Mdot
.658 .51019 Mdot
.658 .5106 Mdot
.658 .51068 Mdot
.658 .5107 Mdot
.658 .51073 Mdot
.658 .51107 Mdot
.658 .51139 Mdot
.658 .51218 Mdot
.658 .51243 Mdot
.658 .51251 Mdot
.658 .51397 Mdot
.658 .51398 Mdot
.658 .51433 Mdot
.658 .51449 Mdot
.658 .51519 Mdot
.658 .51526 Mdot
.658 .51527 Mdot
.658 .51564 Mdot
.658 .51581 Mdot
.658 .51753 Mdot
.658 .51799 Mdot
.658 .51827 Mdot
.658 .51856 Mdot
.658 .51889 Mdot
.658 .51921 Mdot
.658 .51924 Mdot
.658 .51928 Mdot
.658 .51982 Mdot
.658 .52003 Mdot
.658 .52092 Mdot
.658 .52106 Mdot
.658 .5215 Mdot
.658 .52152 Mdot
.658 .52209 Mdot
.658 .5222 Mdot
.658 .52311 Mdot
.658 .52326 Mdot
.658 .52332 Mdot
.658 .52389 Mdot
.658 .52405 Mdot
.658 .52425 Mdot
.658 .5256 Mdot
.658 .52581 Mdot
.658 .526 Mdot
.658 .52618 Mdot
.658 .52723 Mdot
.658 .52724 Mdot
.658 .52759 Mdot
.658 .52761 Mdot
.658 .5284 Mdot
.658 .52876 Mdot
.658 .52879 Mdot
.658 .5289 Mdot
.658 .53015 Mdot
.658 .53117 Mdot
.658 .53117 Mdot
.658 .53176 Mdot
.658 .53185 Mdot
.658 .53195 Mdot
.658 .5322 Mdot
.658 .53265 Mdot
.658 .53298 Mdot
.658 .53342 Mdot
.658 .53519 Mdot
.658 .53529 Mdot
.658 .53599 Mdot
.658 .5365 Mdot
.658 .53665 Mdot
.658 .53707 Mdot
.658 .53707 Mdot
.658 .53752 Mdot
.658 .53766 Mdot
.658 .5382 Mdot
.658 .53826 Mdot
.658 .53845 Mdot
.658 .53907 Mdot
.658 .53927 Mdot
.658 .53956 Mdot
.658 .53963 Mdot
.658 .53982 Mdot
.658 .53983 Mdot
.658 .53993 Mdot
.658 .54003 Mdot
.658 .54013 Mdot
.658 .54022 Mdot
.658 .5411 Mdot
.658 .54147 Mdot
.658 .54147 Mdot
.658 .5426 Mdot
.658 .54334 Mdot
.658 .54334 Mdot
.658 .54353 Mdot
.658 .54365 Mdot
.658 .54405 Mdot
.658 .54418 Mdot
.658 .54464 Mdot
.658 .54483 Mdot
.658 .54499 Mdot
.658 .54556 Mdot
.658 .5459 Mdot
.658 .5461 Mdot
.658 .54614 Mdot
.658 .54616 Mdot
.658 .5466 Mdot
.658 .54682 Mdot
.658 .54706 Mdot
.658 .54733 Mdot
.658 .54736 Mdot
.658 .54757 Mdot
.658 .54775 Mdot
.658 .54777 Mdot
.658 .54802 Mdot
.658 .54818 Mdot
.658 .54823 Mdot
.658 .54849 Mdot
.658 .5488 Mdot
.658 .54882 Mdot
.658 .54893 Mdot
.658 .54941 Mdot
.658 .55034 Mdot
.658 .55045 Mdot
.658 .55051 Mdot
.658 .55079 Mdot
.658 .55092 Mdot
.658 .55107 Mdot
.658 .55138 Mdot
.658 .55139 Mdot
.658 .55242 Mdot
.658 .55255 Mdot
.658 .55259 Mdot
.658 .55259 Mdot
.658 .55265 Mdot
.658 .5527 Mdot
.658 .55284 Mdot
.658 .5533 Mdot
.658 .55344 Mdot
.658 .55356 Mdot
.658 .55358 Mdot
.658 .55366 Mdot
.658 .55379 Mdot
.658 .55381 Mdot
.658 .55438 Mdot
.658 .55442 Mdot
.658 .55452 Mdot
.658 .5546 Mdot
.658 .55479 Mdot
.658 .55482 Mdot
.658 .55488 Mdot
.658 .55488 Mdot
.658 .55492 Mdot
.658 .55535 Mdot
.658 .55542 Mdot
.658 .55542 Mdot
.658 .55564 Mdot
.658 .55573 Mdot
.658 .55575 Mdot
.658 .55577 Mdot
.658 .55578 Mdot
.658 .55584 Mdot
.658 .55587 Mdot
.658 .55601 Mdot
.658 .55602 Mdot
.658 .55614 Mdot
.658 .55621 Mdot
.658 .55627 Mdot
.658 .55638 Mdot
.658 .55651 Mdot
.658 .55664 Mdot
.658 .55666 Mdot
.658 .55671 Mdot
.658 .55673 Mdot
.658 .55713 Mdot
.658 .55728 Mdot
.658 .55743 Mdot
.658 .55748 Mdot
.658 .55762 Mdot
.658 .55766 Mdot
.658 .55815 Mdot
.658 .55826 Mdot
.658 .55829 Mdot
.658 .55835 Mdot
.658 .5588 Mdot
.658 .55883 Mdot
.658 .55886 Mdot
.658 .55889 Mdot
.658 .55903 Mdot
.658 .55916 Mdot
.658 .55916 Mdot
.658 .55932 Mdot
.658 .55943 Mdot
.658 .55966 Mdot
.658 .55988 Mdot
.658 .56021 Mdot
.658 .56022 Mdot
.658 .56076 Mdot
.658 .56092 Mdot
.658 .56109 Mdot
.658 .56116 Mdot
.658 .56119 Mdot
.658 .56129 Mdot
.658 .56139 Mdot
.658 .56145 Mdot
.658 .56158 Mdot
.658 .56159 Mdot
.658 .56162 Mdot
.658 .56195 Mdot
.658 .56196 Mdot
.658 .56202 Mdot
.658 .56216 Mdot
.658 .56216 Mdot
.658 .56218 Mdot
.658 .56234 Mdot
.658 .56247 Mdot
.658 .56264 Mdot
.658 .56266 Mdot
.658 .56272 Mdot
.658 .56274 Mdot
.658 .56275 Mdot
.658 .56282 Mdot
.658 .56283 Mdot
.658 .56287 Mdot
.658 .56288 Mdot
.658 .56293 Mdot
.658 .56294 Mdot
.658 .56294 Mdot
.658 .56297 Mdot
.658 .56298 Mdot
.658 .56298 Mdot
.658 .56298 Mdot
.658 .56299 Mdot
.658 .56301 Mdot
.658 .56303 Mdot
.658 .56304 Mdot
.658 .56304 Mdot
.658 .56306 Mdot
.66 .15378 Mdot
.66 .15379 Mdot
.66 .15396 Mdot
.66 .154 Mdot
.66 .15403 Mdot
.66 .15406 Mdot
.66 .15419 Mdot
.66 .15445 Mdot
.66 .15446 Mdot
.66 .15449 Mdot
.66 .15458 Mdot
.66 .1546 Mdot
.66 .1547 Mdot
.66 .15491 Mdot
.66 .15492 Mdot
.66 .15505 Mdot
.66 .1553 Mdot
.66 .15579 Mdot
.66 .15617 Mdot
.66 .15626 Mdot
.66 .1563 Mdot
.66 .15634 Mdot
.66 .15638 Mdot
.66 .15655 Mdot
.66 .15681 Mdot
.66 .15688 Mdot
.66 .15735 Mdot
.66 .15755 Mdot
.66 .15778 Mdot
.66 .15812 Mdot
.66 .15835 Mdot
.66 .15912 Mdot
.66 .15918 Mdot
.66 .15931 Mdot
.66 .15998 Mdot
.66 .16022 Mdot
.66 .16065 Mdot
.66 .1612 Mdot
.66 .16256 Mdot
.66 .1626 Mdot
.66 .16328 Mdot
.66 .16356 Mdot
.66 .16518 Mdot
.66 .16596 Mdot
.66 .16606 Mdot
.66 .16712 Mdot
.66 .1674 Mdot
.66 .16751 Mdot
.66 .16785 Mdot
.66 .16835 Mdot
.66 .16917 Mdot
.66 .17011 Mdot
.66 .17015 Mdot
.66 .17017 Mdot
.66 .17133 Mdot
.66 .17164 Mdot
.66 .17171 Mdot
.66 .17189 Mdot
.66 .17205 Mdot
.66 .17228 Mdot
.66 .17308 Mdot
.66 .1732 Mdot
.66 .17356 Mdot
.66 .17412 Mdot
.66 .17445 Mdot
.66 .17445 Mdot
.66 .17459 Mdot
.66 .17482 Mdot
.66 .17503 Mdot
.66 .17507 Mdot
.66 .17515 Mdot
.66 .17532 Mdot
.66 .17558 Mdot
.66 .17605 Mdot
.66 .17618 Mdot
.66 .17645 Mdot
.66 .17701 Mdot
.66 .17716 Mdot
.66 .17723 Mdot
.66 .17758 Mdot
.66 .17758 Mdot
.66 .17762 Mdot
.66 .17774 Mdot
.66 .17775 Mdot
.66 .17877 Mdot
.66 .17888 Mdot
.66 .17913 Mdot
.66 .17999 Mdot
.66 .18052 Mdot
.66 .18062 Mdot
.66 .18217 Mdot
.66 .18249 Mdot
.66 .18333 Mdot
.66 .18359 Mdot
.66 .18377 Mdot
.66 .18396 Mdot
.66 .18548 Mdot
.66 .18666 Mdot
.66 .18791 Mdot
.66 .1883 Mdot
.66 .19002 Mdot
.66 .19044 Mdot
.66 .19063 Mdot
.66 .19104 Mdot
.66 .1913 Mdot
.66 .19143 Mdot
.66 .19181 Mdot
.66 .19217 Mdot
.66 .19254 Mdot
.66 .19311 Mdot
.66 .19369 Mdot
.66 .19434 Mdot
.66 .19544 Mdot
.66 .19584 Mdot
.66 .19679 Mdot
.66 .19709 Mdot
.66 .19795 Mdot
.66 .19832 Mdot
.66 .19926 Mdot
.66 .20011 Mdot
.66 .20153 Mdot
.66 .20259 Mdot
.66 .2032 Mdot
.66 .20401 Mdot
.66 .20473 Mdot
.66 .20507 Mdot
.66 .20539 Mdot
.66 .20553 Mdot
.66 .20611 Mdot
.66 .2062 Mdot
.66 .20817 Mdot
.66 .2104 Mdot
.66 .21064 Mdot
.66 .21084 Mdot
.66 .21095 Mdot
.66 .21234 Mdot
.66 .21264 Mdot
.66 .21301 Mdot
.66 .21524 Mdot
.66 .21566 Mdot
.66 .21652 Mdot
.66 .21672 Mdot
.66 .21871 Mdot
.66 .21903 Mdot
.66 .22055 Mdot
.66 .22233 Mdot
.66 .22391 Mdot
.66 .22494 Mdot
.66 .22522 Mdot
.66 .22563 Mdot
.66 .22605 Mdot
.66 .22711 Mdot
.66 .22782 Mdot
.66 .22795 Mdot
.66 .22877 Mdot
.66 .22877 Mdot
.66 .23024 Mdot
.66 .23211 Mdot
.66 .23248 Mdot
.66 .23359 Mdot
.66 .23396 Mdot
.66 .23609 Mdot
.66 .23697 Mdot
.66 .23717 Mdot
.66 .23847 Mdot
.66 .23932 Mdot
.66 .23958 Mdot
.66 .23997 Mdot
.66 .24058 Mdot
.66 .24239 Mdot
.66 .24374 Mdot
.66 .24527 Mdot
.66 .24543 Mdot
.66 .24624 Mdot
.66 .24687 Mdot
.66 .24687 Mdot
.66 .24903 Mdot
.66 .25055 Mdot
.66 .25233 Mdot
.66 .25283 Mdot
.66 .2551 Mdot
.66 .25515 Mdot
.66 .25524 Mdot
.66 .25788 Mdot
.66 .25822 Mdot
.66 .25859 Mdot
.66 .25989 Mdot
.66 .26065 Mdot
.66 .26111 Mdot
.66 .26162 Mdot
.66 .263 Mdot
.66 .26456 Mdot
.66 .26554 Mdot
.66 .26602 Mdot
.66 .26743 Mdot
.66 .2692 Mdot
.66 .27031 Mdot
.66 .27043 Mdot
.66 .2706 Mdot
.66 .27251 Mdot
.66 .27457 Mdot
.66 .2746 Mdot
.66 .27461 Mdot
.66 .27544 Mdot
.66 .2761 Mdot
.66 .27643 Mdot
.66 .27687 Mdot
.66 .27708 Mdot
.66 .27724 Mdot
.66 .27769 Mdot
.66 .2792 Mdot
.66 .28142 Mdot
.66 .28217 Mdot
.66 .28334 Mdot
.66 .28449 Mdot
.66 .28529 Mdot
.66 .28705 Mdot
.66 .28737 Mdot
.66 .28817 Mdot
.66 .28821 Mdot
.66 .29252 Mdot
.66 .29272 Mdot
.66 .29282 Mdot
.66 .29683 Mdot
.66 .29788 Mdot
.66 .29799 Mdot
.66 .29818 Mdot
.66 .30038 Mdot
.66 .30111 Mdot
.66 .30153 Mdot
.66 .30157 Mdot
.66 .30231 Mdot
.66 .30269 Mdot
.66 .30276 Mdot
.66 .30326 Mdot
.66 .30913 Mdot
.66 .30971 Mdot
.66 .31194 Mdot
.66 .31228 Mdot
.66 .31254 Mdot
.66 .31269 Mdot
.66 .31352 Mdot
.66 .31475 Mdot
.66 .3149 Mdot
.66 .31894 Mdot
.66 .32023 Mdot
.66 .32031 Mdot
.66 .32067 Mdot
.66 .32136 Mdot
.66 .32226 Mdot
.66 .32263 Mdot
.66 .32303 Mdot
.66 .32362 Mdot
.66 .324 Mdot
.66 .32649 Mdot
.66 .32682 Mdot
.66 .32741 Mdot
.66 .32814 Mdot
.66 .33364 Mdot
.66 .33496 Mdot
.66 .33506 Mdot
.66 .3354 Mdot
.66 .33745 Mdot
.66 .33748 Mdot
.66 .33751 Mdot
.66 .33851 Mdot
.66 .33876 Mdot
.66 .33898 Mdot
.66 .33911 Mdot
.66 .3393 Mdot
.66 .33995 Mdot
.66 .34005 Mdot
.66 .34105 Mdot
.66 .34105 Mdot
.66 .34134 Mdot
.66 .3415 Mdot
.66 .34153 Mdot
.66 .34173 Mdot
.66 .34229 Mdot
.66 .34238 Mdot
.66 .34301 Mdot
.66 .34311 Mdot
.66 .34317 Mdot
.66 .34355 Mdot
.66 .34355 Mdot
.66 .34429 Mdot
.66 .34437 Mdot
.66 .34455 Mdot
.66 .34515 Mdot
.66 .3456 Mdot
.66 .34665 Mdot
.66 .34687 Mdot
.66 .34785 Mdot
.66 .34958 Mdot
.66 .35036 Mdot
.66 .35165 Mdot
.66 .3519 Mdot
.66 .35226 Mdot
.66 .35241 Mdot
.66 .35271 Mdot
.66 .35292 Mdot
.66 .35314 Mdot
.66 .35381 Mdot
.66 .35418 Mdot
.66 .35481 Mdot
.66 .35556 Mdot
.66 .35573 Mdot
.66 .3562 Mdot
.66 .3587 Mdot
.66 .35902 Mdot
.66 .35999 Mdot
.66 .36023 Mdot
.66 .36052 Mdot
.66 .36057 Mdot
.66 .36156 Mdot
.66 .36267 Mdot
.66 .36362 Mdot
.66 .36376 Mdot
.66 .36394 Mdot
.66 .36501 Mdot
.66 .36561 Mdot
.66 .36663 Mdot
.66 .36679 Mdot
.66 .3683 Mdot
.66 .36947 Mdot
.66 .36959 Mdot
.66 .36978 Mdot
.66 .36996 Mdot
.66 .37043 Mdot
.66 .37074 Mdot
.66 .3708 Mdot
.66 .37323 Mdot
.66 .37339 Mdot
.66 .37466 Mdot
.66 .37474 Mdot
.66 .37528 Mdot
.66 .37574 Mdot
.66 .3759 Mdot
.66 .37616 Mdot
.66 .3769 Mdot
.66 .37813 Mdot
.66 .37871 Mdot
.66 .38017 Mdot
.66 .38197 Mdot
.66 .382 Mdot
.66 .38302 Mdot
.66 .38315 Mdot
.66 .38329 Mdot
.66 .38379 Mdot
.66 .38425 Mdot
.66 .38496 Mdot
.66 .3861 Mdot
.66 .38662 Mdot
.66 .38728 Mdot
.66 .38769 Mdot
.66 .38773 Mdot
.66 .3885 Mdot
.66 .38925 Mdot
.66 .38956 Mdot
.66 .3898 Mdot
.66 .38992 Mdot
.66 .39016 Mdot
.66 .39038 Mdot
.66 .39172 Mdot
.66 .39371 Mdot
.66 .39383 Mdot
.66 .39411 Mdot
.66 .39563 Mdot
.66 .39573 Mdot
.66 .39712 Mdot
.66 .39752 Mdot
.66 .39759 Mdot
.66 .39834 Mdot
.66 .39859 Mdot
.66 .39873 Mdot
.66 .39875 Mdot
.66 .39913 Mdot
.66 .39915 Mdot
.66 .40226 Mdot
.66 .40246 Mdot
.66 .40251 Mdot
.66 .4032 Mdot
.66 .40325 Mdot
.66 .40459 Mdot
.66 .40505 Mdot
.66 .40517 Mdot
.66 .40582 Mdot
.66 .40595 Mdot
.66 .40614 Mdot
.66 .40627 Mdot
.66 .40943 Mdot
.66 .40989 Mdot
.66 .41 Mdot
.66 .41067 Mdot
.66 .41068 Mdot
.66 .41069 Mdot
.66 .41101 Mdot
.66 .41109 Mdot
.66 .41116 Mdot
.66 .41121 Mdot
.66 .41127 Mdot
.66 .41148 Mdot
.66 .41151 Mdot
.66 .41183 Mdot
.66 .41198 Mdot
.66 .41199 Mdot
.66 .41205 Mdot
.66 .41223 Mdot
.66 .41226 Mdot
.66 .41247 Mdot
.66 .41252 Mdot
.66 .41264 Mdot
.66 .41288 Mdot
.66 .41291 Mdot
.66 .41316 Mdot
.66 .41364 Mdot
.66 .41371 Mdot
.66 .41458 Mdot
.66 .41525 Mdot
.66 .41533 Mdot
.66 .41549 Mdot
.66 .41559 Mdot
.66 .41566 Mdot
.66 .41573 Mdot
.66 .41594 Mdot
.66 .41606 Mdot
.66 .41626 Mdot
.66 .41656 Mdot
.66 .41671 Mdot
.66 .41751 Mdot
.66 .41761 Mdot
.66 .41799 Mdot
.66 .41809 Mdot
.66 .4181 Mdot
.66 .41842 Mdot
.66 .41908 Mdot
.66 .41912 Mdot
.66 .41918 Mdot
.66 .41952 Mdot
.66 .42004 Mdot
.66 .42057 Mdot
.66 .42098 Mdot
.66 .42104 Mdot
.66 .4211 Mdot
.66 .42135 Mdot
.66 .42136 Mdot
.66 .42214 Mdot
.66 .42262 Mdot
.66 .42279 Mdot
.66 .42294 Mdot
.66 .42299 Mdot
.66 .42307 Mdot
.66 .4233 Mdot
.66 .42388 Mdot
.66 .42491 Mdot
.66 .42525 Mdot
.66 .42534 Mdot
.66 .42564 Mdot
.66 .42639 Mdot
.66 .42675 Mdot
.66 .42723 Mdot
.66 .42733 Mdot
.66 .42744 Mdot
.66 .42752 Mdot
.66 .42865 Mdot
.66 .42869 Mdot
.66 .42877 Mdot
.66 .42926 Mdot
.66 .42929 Mdot
.66 .42986 Mdot
.66 .42988 Mdot
.66 .4302 Mdot
.66 .43025 Mdot
.66 .43025 Mdot
.66 .43038 Mdot
.66 .43038 Mdot
.66 .43144 Mdot
.66 .43145 Mdot
.66 .43167 Mdot
.66 .43169 Mdot
.66 .43212 Mdot
.66 .43227 Mdot
.66 .43231 Mdot
.66 .43251 Mdot
.66 .43262 Mdot
.66 .43266 Mdot
.66 .43367 Mdot
.66 .43382 Mdot
.66 .43385 Mdot
.66 .43434 Mdot
.66 .43466 Mdot
.66 .43505 Mdot
.66 .43576 Mdot
.66 .43627 Mdot
.66 .43646 Mdot
.66 .43646 Mdot
.66 .43679 Mdot
.66 .43681 Mdot
.66 .43709 Mdot
.66 .43726 Mdot
.66 .43777 Mdot
.66 .43798 Mdot
.66 .43803 Mdot
.66 .43814 Mdot
.66 .43878 Mdot
.66 .43881 Mdot
.66 .43942 Mdot
.66 .43945 Mdot
.66 .43989 Mdot
.66 .4399 Mdot
.66 .44009 Mdot
.66 .44039 Mdot
.66 .44041 Mdot
.66 .4408 Mdot
.66 .44088 Mdot
.66 .44108 Mdot
.66 .44115 Mdot
.66 .44118 Mdot
.66 .4412 Mdot
.66 .44175 Mdot
.66 .44256 Mdot
.66 .44256 Mdot
.66 .44322 Mdot
.66 .44365 Mdot
.66 .44375 Mdot
.66 .44376 Mdot
.66 .44389 Mdot
.66 .44401 Mdot
.66 .4442 Mdot
.66 .44447 Mdot
.66 .44487 Mdot
.66 .44625 Mdot
.66 .4464 Mdot
.66 .44646 Mdot
.66 .44708 Mdot
.66 .44708 Mdot
.66 .44755 Mdot
.66 .44787 Mdot
.66 .44804 Mdot
.66 .44808 Mdot
.66 .44831 Mdot
.66 .44832 Mdot
.66 .44849 Mdot
.66 .4486 Mdot
.66 .4486 Mdot
.66 .44885 Mdot
.66 .44921 Mdot
.66 .44923 Mdot
.66 .44958 Mdot
.66 .44965 Mdot
.66 .4498 Mdot
.66 .45008 Mdot
.66 .45033 Mdot
.66 .45034 Mdot
.66 .45053 Mdot
.66 .45131 Mdot
.66 .45153 Mdot
.66 .45171 Mdot
.66 .45199 Mdot
.66 .45263 Mdot
.66 .45266 Mdot
.66 .45271 Mdot
.66 .45283 Mdot
.66 .45293 Mdot
.66 .45316 Mdot
.66 .45317 Mdot
.66 .45329 Mdot
.66 .4533 Mdot
.66 .45388 Mdot
.66 .45388 Mdot
.66 .45395 Mdot
.66 .45395 Mdot
.66 .45398 Mdot
.66 .45415 Mdot
.66 .45416 Mdot
.66 .45449 Mdot
.66 .4548 Mdot
.66 .45482 Mdot
.66 .45553 Mdot
.66 .45559 Mdot
.66 .45585 Mdot
.66 .45604 Mdot
.66 .45644 Mdot
.66 .4566 Mdot
.66 .45665 Mdot
.66 .45769 Mdot
.66 .45785 Mdot
.66 .45788 Mdot
.66 .45796 Mdot
.66 .4583 Mdot
.66 .45871 Mdot
.66 .45888 Mdot
.66 .45913 Mdot
.66 .45941 Mdot
.66 .45986 Mdot
.66 .45989 Mdot
.66 .46042 Mdot
.66 .46043 Mdot
.66 .46073 Mdot
.66 .46138 Mdot
.66 .46155 Mdot
.66 .4619 Mdot
.66 .46269 Mdot
.66 .46324 Mdot
.66 .46331 Mdot
.66 .46366 Mdot
.66 .46382 Mdot
.66 .46395 Mdot
.66 .46425 Mdot
.66 .46459 Mdot
.66 .46465 Mdot
.66 .46488 Mdot
.66 .46647 Mdot
.66 .46654 Mdot
.66 .46663 Mdot
.66 .4667 Mdot
.66 .46702 Mdot
.66 .46708 Mdot
.66 .46731 Mdot
.66 .46798 Mdot
.66 .468 Mdot
.66 .46835 Mdot
.66 .46837 Mdot
.66 .46847 Mdot
.66 .47 Mdot
.66 .47001 Mdot
.66 .4702 Mdot
.66 .47021 Mdot
.66 .47028 Mdot
.66 .4704 Mdot
.66 .47077 Mdot
.66 .4708 Mdot
.66 .47099 Mdot
.66 .47167 Mdot
.66 .47172 Mdot
.66 .47246 Mdot
.66 .47259 Mdot
.66 .47265 Mdot
.66 .47361 Mdot
.66 .47425 Mdot
.66 .47435 Mdot
.66 .47446 Mdot
.66 .47452 Mdot
.66 .47464 Mdot
.66 .47479 Mdot
.66 .47514 Mdot
.66 .47551 Mdot
.66 .47553 Mdot
.66 .47572 Mdot
.66 .47603 Mdot
.66 .47628 Mdot
.66 .47681 Mdot
.66 .47715 Mdot
.66 .47737 Mdot
.66 .4776 Mdot
.66 .47773 Mdot
.66 .4782 Mdot
.66 .47822 Mdot
.66 .47906 Mdot
.66 .47973 Mdot
.66 .48 Mdot
.66 .48057 Mdot
.66 .48091 Mdot
.66 .48102 Mdot
.66 .4811 Mdot
.66 .48131 Mdot
.66 .48156 Mdot
.66 .48159 Mdot
.66 .48217 Mdot
.66 .48225 Mdot
.66 .48335 Mdot
.66 .48338 Mdot
.66 .48352 Mdot
.66 .48373 Mdot
.66 .48381 Mdot
.66 .4839 Mdot
.66 .48395 Mdot
.66 .48448 Mdot
.66 .48516 Mdot
.66 .48523 Mdot
.66 .48568 Mdot
.66 .48595 Mdot
.66 .48643 Mdot
.66 .48651 Mdot
.66 .48657 Mdot
.66 .48699 Mdot
.66 .48748 Mdot
.66 .48792 Mdot
.66 .48795 Mdot
.66 .48808 Mdot
.66 .48818 Mdot
.66 .48861 Mdot
.66 .48875 Mdot
.66 .48984 Mdot
.66 .49005 Mdot
.66 .49012 Mdot
.66 .49045 Mdot
.66 .49072 Mdot
.66 .49088 Mdot
.66 .49117 Mdot
.66 .49127 Mdot
.66 .49136 Mdot
.66 .49149 Mdot
.66 .49155 Mdot
.66 .49171 Mdot
.66 .49182 Mdot
.66 .49237 Mdot
.66 .49271 Mdot
.66 .49345 Mdot
.66 .49387 Mdot
.66 .49396 Mdot
.66 .49441 Mdot
.66 .4946 Mdot
.66 .49486 Mdot
.66 .49493 Mdot
.66 .49497 Mdot
.66 .49528 Mdot
.66 .49528 Mdot
.66 .49544 Mdot
.66 .49547 Mdot
.66 .49551 Mdot
.66 .49578 Mdot
.66 .49582 Mdot
.66 .49605 Mdot
.66 .49614 Mdot
.66 .49615 Mdot
.66 .49622 Mdot
.66 .49634 Mdot
.66 .49634 Mdot
.66 .49676 Mdot
.66 .4968 Mdot
.66 .49707 Mdot
.66 .49715 Mdot
.66 .49721 Mdot
.66 .4973 Mdot
.66 .49741 Mdot
.66 .49783 Mdot
.66 .49784 Mdot
.66 .49785 Mdot
.66 .49871 Mdot
.66 .49884 Mdot
.66 .49889 Mdot
.66 .49944 Mdot
.66 .5017 Mdot
.66 .502 Mdot
.66 .50224 Mdot
.66 .50238 Mdot
.66 .50339 Mdot
.66 .50355 Mdot
.66 .50379 Mdot
.66 .50395 Mdot
.66 .5041 Mdot
.66 .50446 Mdot
.66 .50474 Mdot
.66 .50489 Mdot
.66 .50492 Mdot
.66 .50544 Mdot
.66 .50705 Mdot
.66 .50711 Mdot
.66 .5076 Mdot
.66 .50793 Mdot
.66 .50799 Mdot
.66 .50809 Mdot
.66 .50823 Mdot
.66 .50911 Mdot
.66 .50934 Mdot
.66 .51164 Mdot
.66 .51184 Mdot
.66 .51186 Mdot
.66 .51201 Mdot
.66 .5123 Mdot
.66 .51231 Mdot
.66 .51247 Mdot
.66 .51276 Mdot
.66 .51361 Mdot
.66 .51368 Mdot
.66 .51372 Mdot
.66 .51413 Mdot
.66 .51567 Mdot
.66 .5157 Mdot
.66 .51578 Mdot
.66 .51742 Mdot
.66 .51744 Mdot
.66 .51774 Mdot
.66 .51786 Mdot
.66 .51852 Mdot
.66 .51882 Mdot
.66 .51926 Mdot
.66 .5197 Mdot
.66 .51998 Mdot
.66 .5208 Mdot
.66 .52137 Mdot
.66 .52154 Mdot
.66 .52159 Mdot
.66 .52167 Mdot
.66 .52183 Mdot
.66 .52196 Mdot
.66 .5222 Mdot
.66 .52251 Mdot
.66 .52251 Mdot
.66 .52252 Mdot
.66 .52329 Mdot
.66 .52399 Mdot
.66 .52405 Mdot
.66 .52409 Mdot
.66 .5245 Mdot
.66 .52515 Mdot
.66 .52566 Mdot
.66 .52584 Mdot
.66 .52619 Mdot
.66 .52676 Mdot
.66 .52726 Mdot
.66 .52744 Mdot
.66 .52761 Mdot
.66 .52788 Mdot
.66 .52835 Mdot
.66 .52849 Mdot
.66 .52861 Mdot
.66 .52956 Mdot
.66 .52959 Mdot
.66 .52961 Mdot
.66 .53042 Mdot
.66 .5306 Mdot
.66 .53123 Mdot
.66 .53177 Mdot
.66 .53253 Mdot
.66 .53253 Mdot
.66 .53276 Mdot
.66 .53304 Mdot
.66 .5331 Mdot
.66 .53363 Mdot
.66 .53411 Mdot
.66 .53474 Mdot
.66 .53496 Mdot
.66 .53509 Mdot
.66 .53518 Mdot
.66 .53548 Mdot
.66 .53593 Mdot
.66 .536 Mdot
.66 .53631 Mdot
.66 .53705 Mdot
.66 .53718 Mdot
.66 .53756 Mdot
.66 .53768 Mdot
.66 .53833 Mdot
.66 .53884 Mdot
.66 .53884 Mdot
.66 .53912 Mdot
.66 .53916 Mdot
.66 .53941 Mdot
.66 .53977 Mdot
.66 .53991 Mdot
.66 .54005 Mdot
.66 .54015 Mdot
.66 .5405 Mdot
.66 .54104 Mdot
.66 .54164 Mdot
.66 .54216 Mdot
.66 .54227 Mdot
.66 .54294 Mdot
.66 .54301 Mdot
.66 .5433 Mdot
.66 .54344 Mdot
.66 .54419 Mdot
.66 .54431 Mdot
.66 .54441 Mdot
.66 .54488 Mdot
.66 .54492 Mdot
.66 .54498 Mdot
.66 .54506 Mdot
.66 .54581 Mdot
.66 .54646 Mdot
.66 .54649 Mdot
.66 .54669 Mdot
.66 .54673 Mdot
.66 .54684 Mdot
.66 .54695 Mdot
.66 .54719 Mdot
.66 .54746 Mdot
.66 .54766 Mdot
.66 .54801 Mdot
.66 .54848 Mdot
.66 .54876 Mdot
.66 .54907 Mdot
.66 .54919 Mdot
.66 .54947 Mdot
.66 .54957 Mdot
.66 .54988 Mdot
.66 .55001 Mdot
.66 .55037 Mdot
.66 .55059 Mdot
.66 .55078 Mdot
.66 .55096 Mdot
.66 .55108 Mdot
.66 .5512 Mdot
.66 .55132 Mdot
.66 .55137 Mdot
.66 .55145 Mdot
.66 .55159 Mdot
.66 .55164 Mdot
.66 .55178 Mdot
.66 .55234 Mdot
.66 .55247 Mdot
.66 .55287 Mdot
.66 .55325 Mdot
.66 .55374 Mdot
.66 .55381 Mdot
.66 .55386 Mdot
.66 .55395 Mdot
.66 .55422 Mdot
.66 .55432 Mdot
.66 .55482 Mdot
.66 .55485 Mdot
.66 .55502 Mdot
.66 .5553 Mdot
.66 .55538 Mdot
.66 .55541 Mdot
.66 .55574 Mdot
.66 .55574 Mdot
.66 .55578 Mdot
.66 .55579 Mdot
.66 .55579 Mdot
.66 .55591 Mdot
.66 .55593 Mdot
.66 .55598 Mdot
.66 .55615 Mdot
.66 .55624 Mdot
.66 .55628 Mdot
.66 .55643 Mdot
.66 .55652 Mdot
.66 .55657 Mdot
.66 .5566 Mdot
.66 .55661 Mdot
.66 .55668 Mdot
.66 .55675 Mdot
.66 .55679 Mdot
.66 .5568 Mdot
.66 .5569 Mdot
.66 .55708 Mdot
.66 .55719 Mdot
.66 .55723 Mdot
.66 .55749 Mdot
.66 .55756 Mdot
.66 .55761 Mdot
.66 .55767 Mdot
.66 .55769 Mdot
.66 .55779 Mdot
.66 .55815 Mdot
.66 .55816 Mdot
.66 .55817 Mdot
.66 .55847 Mdot
.66 .55873 Mdot
.66 .55889 Mdot
.66 .559 Mdot
.66 .55903 Mdot
.66 .55912 Mdot
.66 .55945 Mdot
.66 .55949 Mdot
.66 .55973 Mdot
.66 .56024 Mdot
.66 .56033 Mdot
.66 .56054 Mdot
.66 .56055 Mdot
.66 .56098 Mdot
.66 .56115 Mdot
.66 .56129 Mdot
.66 .56136 Mdot
.66 .56157 Mdot
.66 .56161 Mdot
.66 .56163 Mdot
.66 .56187 Mdot
.66 .56194 Mdot
.66 .56205 Mdot
.66 .56212 Mdot
.66 .56218 Mdot
.66 .56233 Mdot
.66 .56235 Mdot
.66 .56243 Mdot
.66 .56249 Mdot
.66 .5625 Mdot
.66 .56251 Mdot
.66 .56252 Mdot
.66 .56255 Mdot
.66 .56267 Mdot
.66 .56282 Mdot
.66 .5629 Mdot
.66 .56294 Mdot
.66 .56294 Mdot
.66 .56301 Mdot
.66 .56304 Mdot
.66 .56305 Mdot
.66 .56307 Mdot
.66 .56308 Mdot
.66 .56309 Mdot
.66 .56317 Mdot
.66 .56321 Mdot
.66 .56322 Mdot
.66 .56323 Mdot
.66 .56324 Mdot
.66 .56329 Mdot
.66 .56329 Mdot
.662 .15308 Mdot
.662 .1531 Mdot
.662 .1531 Mdot
.662 .15311 Mdot
.662 .15314 Mdot
.662 .15318 Mdot
.662 .15373 Mdot
.662 .15429 Mdot
.662 .15435 Mdot
.662 .15437 Mdot
.662 .15455 Mdot
.662 .15491 Mdot
.662 .15497 Mdot
.662 .15512 Mdot
.662 .15541 Mdot
.662 .15607 Mdot
.662 .15624 Mdot
.662 .15629 Mdot
.662 .15633 Mdot
.662 .1565 Mdot
.662 .15654 Mdot
.662 .15671 Mdot
.662 .15676 Mdot
.662 .15678 Mdot
.662 .15723 Mdot
.662 .1578 Mdot
.662 .15878 Mdot
.662 .15939 Mdot
.662 .1594 Mdot
.662 .15967 Mdot
.662 .16 Mdot
.662 .16007 Mdot
.662 .16115 Mdot
.662 .16122 Mdot
.662 .16161 Mdot
.662 .1621 Mdot
.662 .16216 Mdot
.662 .16263 Mdot
.662 .1632 Mdot
.662 .16372 Mdot
.662 .16376 Mdot
.662 .16416 Mdot
.662 .16455 Mdot
.662 .16495 Mdot
.662 .16511 Mdot
.662 .16522 Mdot
.662 .16522 Mdot
.662 .16527 Mdot
.662 .16546 Mdot
.662 .16571 Mdot
.662 .16587 Mdot
.662 .16609 Mdot
.662 .16637 Mdot
.662 .16642 Mdot
.662 .16743 Mdot
.662 .16812 Mdot
.662 .16818 Mdot
.662 .16863 Mdot
.662 .16931 Mdot
.662 .17082 Mdot
.662 .1723 Mdot
.662 .17236 Mdot
.662 .17257 Mdot
.662 .17258 Mdot
.662 .17269 Mdot
.662 .17336 Mdot
.662 .1738 Mdot
.662 .174 Mdot
.662 .17413 Mdot
.662 .17435 Mdot
.662 .17537 Mdot
.662 .17544 Mdot
.662 .17553 Mdot
.662 .17573 Mdot
.662 .17575 Mdot
.662 .17663 Mdot
.662 .17754 Mdot
.662 .17833 Mdot
.662 .17847 Mdot
.662 .17872 Mdot
.662 .17886 Mdot
.662 .17892 Mdot
.662 .17964 Mdot
.662 .17968 Mdot
.662 .18002 Mdot
.662 .18019 Mdot
.662 .18223 Mdot
.662 .18277 Mdot
.662 .18301 Mdot
.662 .18326 Mdot
.662 .18361 Mdot
.662 .18444 Mdot
.662 .18475 Mdot
.662 .18499 Mdot
.662 .18499 Mdot
.662 .18667 Mdot
.662 .18673 Mdot
.662 .18675 Mdot
.662 .18916 Mdot
.662 .19089 Mdot
.662 .19117 Mdot
.662 .1913 Mdot
.662 .19143 Mdot
.662 .19176 Mdot
.662 .19193 Mdot
.662 .1921 Mdot
.662 .19295 Mdot
.662 .19361 Mdot
.662 .19379 Mdot
.662 .19388 Mdot
.662 .19395 Mdot
.662 .19398 Mdot
.662 .19506 Mdot
.662 .19519 Mdot
.662 .19567 Mdot
.662 .19579 Mdot
.662 .19634 Mdot
.662 .19645 Mdot
.662 .19657 Mdot
.662 .19658 Mdot
.662 .19748 Mdot
.662 .1977 Mdot
.662 .20022 Mdot
.662 .20072 Mdot
.662 .20162 Mdot
.662 .20319 Mdot
.662 .20413 Mdot
.662 .20469 Mdot
.662 .20517 Mdot
.662 .20815 Mdot
.662 .20833 Mdot
.662 .2089 Mdot
.662 .20923 Mdot
.662 .20999 Mdot
.662 .21156 Mdot
.662 .21215 Mdot
.662 .21346 Mdot
.662 .21405 Mdot
.662 .21657 Mdot
.662 .21903 Mdot
.662 .21949 Mdot
.662 .22001 Mdot
.662 .22073 Mdot
.662 .22103 Mdot
.662 .2212 Mdot
.662 .2245 Mdot
.662 .22494 Mdot
.662 .22535 Mdot
.662 .22603 Mdot
.662 .22605 Mdot
.662 .22733 Mdot
.662 .22739 Mdot
.662 .22743 Mdot
.662 .22784 Mdot
.662 .22828 Mdot
.662 .229 Mdot
.662 .22907 Mdot
.662 .22912 Mdot
.662 .23055 Mdot
.662 .23102 Mdot
.662 .23262 Mdot
.662 .23287 Mdot
.662 .23298 Mdot
.662 .23316 Mdot
.662 .23335 Mdot
.662 .23401 Mdot
.662 .23623 Mdot
.662 .23658 Mdot
.662 .23749 Mdot
.662 .23767 Mdot
.662 .23854 Mdot
.662 .23861 Mdot
.662 .24466 Mdot
.662 .24566 Mdot
.662 .24704 Mdot
.662 .24723 Mdot
.662 .24783 Mdot
.662 .24813 Mdot
.662 .24831 Mdot
.662 .24851 Mdot
.662 .24999 Mdot
.662 .25053 Mdot
.662 .25098 Mdot
.662 .25212 Mdot
.662 .25331 Mdot
.662 .25422 Mdot
.662 .25451 Mdot
.662 .25527 Mdot
.662 .25564 Mdot
.662 .26 Mdot
.662 .26162 Mdot
.662 .26175 Mdot
.662 .26225 Mdot
.662 .26231 Mdot
.662 .26274 Mdot
.662 .26302 Mdot
.662 .2637 Mdot
.662 .26376 Mdot
.662 .2638 Mdot
.662 .26525 Mdot
.662 .26532 Mdot
.662 .26801 Mdot
.662 .26804 Mdot
.662 .26911 Mdot
.662 .26911 Mdot
.662 .26926 Mdot
.662 .26946 Mdot
.662 .27022 Mdot
.662 .27038 Mdot
.662 .27264 Mdot
.662 .27317 Mdot
.662 .27332 Mdot
.662 .27349 Mdot
.662 .27547 Mdot
.662 .27571 Mdot
.662 .27671 Mdot
.662 .27786 Mdot
.662 .27794 Mdot
.662 .27795 Mdot
.662 .27812 Mdot
.662 .27939 Mdot
.662 .28171 Mdot
.662 .28176 Mdot
.662 .28342 Mdot
.662 .28368 Mdot
.662 .28483 Mdot
.662 .28609 Mdot
.662 .28734 Mdot
.662 .28788 Mdot
.662 .28854 Mdot
.662 .29555 Mdot
.662 .296 Mdot
.662 .29606 Mdot
.662 .29657 Mdot
.662 .29691 Mdot
.662 .29902 Mdot
.662 .30054 Mdot
.662 .30114 Mdot
.662 .30336 Mdot
.662 .30681 Mdot
.662 .30916 Mdot
.662 .30997 Mdot
.662 .30999 Mdot
.662 .31015 Mdot
.662 .31071 Mdot
.662 .31672 Mdot
.662 .31697 Mdot
.662 .31847 Mdot
.662 .31863 Mdot
.662 .31969 Mdot
.662 .32157 Mdot
.662 .32163 Mdot
.662 .32235 Mdot
.662 .32244 Mdot
.662 .32423 Mdot
.662 .32575 Mdot
.662 .32663 Mdot
.662 .32664 Mdot
.662 .32701 Mdot
.662 .32745 Mdot
.662 .32755 Mdot
.662 .32893 Mdot
.662 .32902 Mdot
.662 .33009 Mdot
.662 .33134 Mdot
.662 .33191 Mdot
.662 .33238 Mdot
.662 .33279 Mdot
.662 .33337 Mdot
.662 .33348 Mdot
.662 .33348 Mdot
.662 .33352 Mdot
.662 .33372 Mdot
.662 .33397 Mdot
.662 .33413 Mdot
.662 .33467 Mdot
.662 .33563 Mdot
.662 .33673 Mdot
.662 .33733 Mdot
.662 .33987 Mdot
.662 .34072 Mdot
.662 .34106 Mdot
.662 .34122 Mdot
.662 .34149 Mdot
.662 .34227 Mdot
.662 .34239 Mdot
.662 .34254 Mdot
.662 .34321 Mdot
.662 .34388 Mdot
.662 .34444 Mdot
.662 .34482 Mdot
.662 .34537 Mdot
.662 .34563 Mdot
.662 .34575 Mdot
.662 .34713 Mdot
.662 .34748 Mdot
.662 .34804 Mdot
.662 .35004 Mdot
.662 .35151 Mdot
.662 .35255 Mdot
.662 .35286 Mdot
.662 .35305 Mdot
.662 .35316 Mdot
.662 .35326 Mdot
.662 .35375 Mdot
.662 .35412 Mdot
.662 .35432 Mdot
.662 .35495 Mdot
.662 .35535 Mdot
.662 .35566 Mdot
.662 .35579 Mdot
.662 .35777 Mdot
.662 .35851 Mdot
.662 .35933 Mdot
.662 .35982 Mdot
.662 .36011 Mdot
.662 .36035 Mdot
.662 .36185 Mdot
.662 .36194 Mdot
.662 .36222 Mdot
.662 .36444 Mdot
.662 .36726 Mdot
.662 .36783 Mdot
.662 .36796 Mdot
.662 .37021 Mdot
.662 .37078 Mdot
.662 .37082 Mdot
.662 .37119 Mdot
.662 .3715 Mdot
.662 .37153 Mdot
.662 .37155 Mdot
.662 .37217 Mdot
.662 .37306 Mdot
.662 .37317 Mdot
.662 .37321 Mdot
.662 .37329 Mdot
.662 .37365 Mdot
.662 .37458 Mdot
.662 .37473 Mdot
.662 .3751 Mdot
.662 .37518 Mdot
.662 .37554 Mdot
.662 .37557 Mdot
.662 .37804 Mdot
.662 .37844 Mdot
.662 .37898 Mdot
.662 .37906 Mdot
.662 .3793 Mdot
.662 .37957 Mdot
.662 .38015 Mdot
.662 .38099 Mdot
.662 .38192 Mdot
.662 .38221 Mdot
.662 .38236 Mdot
.662 .38463 Mdot
.662 .38489 Mdot
.662 .38544 Mdot
.662 .38545 Mdot
.662 .38599 Mdot
.662 .38602 Mdot
.662 .38703 Mdot
.662 .38742 Mdot
.662 .38742 Mdot
.662 .38755 Mdot
.662 .38783 Mdot
.662 .38789 Mdot
.662 .38872 Mdot
.662 .38983 Mdot
.662 .39064 Mdot
.662 .39116 Mdot
.662 .39259 Mdot
.662 .39397 Mdot
.662 .39416 Mdot
.662 .39439 Mdot
.662 .39699 Mdot
.662 .39718 Mdot
.662 .39875 Mdot
.662 .3995 Mdot
.662 .40067 Mdot
.662 .40173 Mdot
.662 .40174 Mdot
.662 .40179 Mdot
.662 .40198 Mdot
.662 .40407 Mdot
.662 .40462 Mdot
.662 .40497 Mdot
.662 .40559 Mdot
.662 .40561 Mdot
.662 .40585 Mdot
.662 .40697 Mdot
.662 .40726 Mdot
.662 .40726 Mdot
.662 .40738 Mdot
.662 .40753 Mdot
.662 .40756 Mdot
.662 .40801 Mdot
.662 .40839 Mdot
.662 .40898 Mdot
.662 .40927 Mdot
.662 .40946 Mdot
.662 .40949 Mdot
.662 .4095 Mdot
.662 .40951 Mdot
.662 .40957 Mdot
.662 .40965 Mdot
.662 .41019 Mdot
.662 .41055 Mdot
.662 .41075 Mdot
.662 .41157 Mdot
.662 .41184 Mdot
.662 .41195 Mdot
.662 .412 Mdot
.662 .41209 Mdot
.662 .41234 Mdot
.662 .41238 Mdot
.662 .41243 Mdot
.662 .41264 Mdot
.662 .41304 Mdot
.662 .41316 Mdot
.662 .41342 Mdot
.662 .41346 Mdot
.662 .41402 Mdot
.662 .4142 Mdot
.662 .41531 Mdot
.662 .41564 Mdot
.662 .41574 Mdot
.662 .4158 Mdot
.662 .41584 Mdot
.662 .41587 Mdot
.662 .41603 Mdot
.662 .41615 Mdot
.662 .41621 Mdot
.662 .41654 Mdot
.662 .41664 Mdot
.662 .41668 Mdot
.662 .41755 Mdot
.662 .41796 Mdot
.662 .41806 Mdot
.662 .41813 Mdot
.662 .41861 Mdot
.662 .41864 Mdot
.662 .41873 Mdot
.662 .41944 Mdot
.662 .42051 Mdot
.662 .42127 Mdot
.662 .42168 Mdot
.662 .4217 Mdot
.662 .42189 Mdot
.662 .42217 Mdot
.662 .42221 Mdot
.662 .42222 Mdot
.662 .42266 Mdot
.662 .4227 Mdot
.662 .42282 Mdot
.662 .42296 Mdot
.662 .42375 Mdot
.662 .42388 Mdot
.662 .42469 Mdot
.662 .42498 Mdot
.662 .42512 Mdot
.662 .42585 Mdot
.662 .42611 Mdot
.662 .42629 Mdot
.662 .42673 Mdot
.662 .42677 Mdot
.662 .42688 Mdot
.662 .4275 Mdot
.662 .42775 Mdot
.662 .42792 Mdot
.662 .42837 Mdot
.662 .42881 Mdot
.662 .42894 Mdot
.662 .42977 Mdot
.662 .42983 Mdot
.662 .43033 Mdot
.662 .43057 Mdot
.662 .43094 Mdot
.662 .43128 Mdot
.662 .43203 Mdot
.662 .4322 Mdot
.662 .43231 Mdot
.662 .43251 Mdot
.662 .43252 Mdot
.662 .43259 Mdot
.662 .43295 Mdot
.662 .43308 Mdot
.662 .43313 Mdot
.662 .43314 Mdot
.662 .4334 Mdot
.662 .43369 Mdot
.662 .43398 Mdot
.662 .4341 Mdot
.662 .43459 Mdot
.662 .43468 Mdot
.662 .4347 Mdot
.662 .43579 Mdot
.662 .43585 Mdot
.662 .43648 Mdot
.662 .43651 Mdot
.662 .43653 Mdot
.662 .43669 Mdot
.662 .43673 Mdot
.662 .43695 Mdot
.662 .43755 Mdot
.662 .43775 Mdot
.662 .43785 Mdot
.662 .43799 Mdot
.662 .43865 Mdot
.662 .43985 Mdot
.662 .44004 Mdot
.662 .44069 Mdot
.662 .4411 Mdot
.662 .44139 Mdot
.662 .44141 Mdot
.662 .44169 Mdot
.662 .44192 Mdot
.662 .44252 Mdot
.662 .44258 Mdot
.662 .44286 Mdot
.662 .44301 Mdot
.662 .44413 Mdot
.662 .44414 Mdot
.662 .44431 Mdot
.662 .44452 Mdot
.662 .44462 Mdot
.662 .44504 Mdot
.662 .44504 Mdot
.662 .4451 Mdot
.662 .44517 Mdot
.662 .44521 Mdot
.662 .44535 Mdot
.662 .44539 Mdot
.662 .44556 Mdot
.662 .44559 Mdot
.662 .44569 Mdot
.662 .44576 Mdot
.662 .44576 Mdot
.662 .44601 Mdot
.662 .44606 Mdot
.662 .44619 Mdot
.662 .44628 Mdot
.662 .44629 Mdot
.662 .44693 Mdot
.662 .44702 Mdot
.662 .44718 Mdot
.662 .44755 Mdot
.662 .44769 Mdot
.662 .44784 Mdot
.662 .44785 Mdot
.662 .44802 Mdot
.662 .44825 Mdot
.662 .44862 Mdot
.662 .44977 Mdot
.662 .45002 Mdot
.662 .45035 Mdot
.662 .45048 Mdot
.662 .4505 Mdot
.662 .45059 Mdot
.662 .45062 Mdot
.662 .45097 Mdot
.662 .451 Mdot
.662 .45161 Mdot
.662 .452 Mdot
.662 .45247 Mdot
.662 .45247 Mdot
.662 .4525 Mdot
.662 .45298 Mdot
.662 .45367 Mdot
.662 .45401 Mdot
.662 .45476 Mdot
.662 .45507 Mdot
.662 .45531 Mdot
.662 .45554 Mdot
.662 .45595 Mdot
.662 .45619 Mdot
.662 .45629 Mdot
.662 .45704 Mdot
.662 .45747 Mdot
.662 .45754 Mdot
.662 .4581 Mdot
.662 .45812 Mdot
.662 .45835 Mdot
.662 .45838 Mdot
.662 .45853 Mdot
.662 .45885 Mdot
.662 .45982 Mdot
.662 .46019 Mdot
.662 .46025 Mdot
.662 .4605 Mdot
.662 .46054 Mdot
.662 .46059 Mdot
.662 .46159 Mdot
.662 .46167 Mdot
.662 .46169 Mdot
.662 .46253 Mdot
.662 .46293 Mdot
.662 .46333 Mdot
.662 .46344 Mdot
.662 .46347 Mdot
.662 .46361 Mdot
.662 .46388 Mdot
.662 .4644 Mdot
.662 .46458 Mdot
.662 .46505 Mdot
.662 .46519 Mdot
.662 .46549 Mdot
.662 .46568 Mdot
.662 .46591 Mdot
.662 .46592 Mdot
.662 .466 Mdot
.662 .46606 Mdot
.662 .46606 Mdot
.662 .46621 Mdot
.662 .46677 Mdot
.662 .46688 Mdot
.662 .46689 Mdot
.662 .4672 Mdot
.662 .46738 Mdot
.662 .46765 Mdot
.662 .46869 Mdot
.662 .46878 Mdot
.662 .46881 Mdot
.662 .46881 Mdot
.662 .46934 Mdot
.662 .46991 Mdot
.662 .47028 Mdot
.662 .47104 Mdot
.662 .47114 Mdot
.662 .4724 Mdot
.662 .47251 Mdot
.662 .4726 Mdot
.662 .47326 Mdot
.662 .47395 Mdot
.662 .4742 Mdot
.662 .47459 Mdot
.662 .47512 Mdot
.662 .47551 Mdot
.662 .47553 Mdot
.662 .47567 Mdot
.662 .47573 Mdot
.662 .47573 Mdot
.662 .47591 Mdot
.662 .47639 Mdot
.662 .4764 Mdot
.662 .47666 Mdot
.662 .47667 Mdot
.662 .47692 Mdot
.662 .47704 Mdot
.662 .47811 Mdot
.662 .47818 Mdot
.662 .47832 Mdot
.662 .47875 Mdot
.662 .47914 Mdot
.662 .47941 Mdot
.662 .47953 Mdot
.662 .47964 Mdot
.662 .47968 Mdot
.662 .47993 Mdot
.662 .48011 Mdot
.662 .48125 Mdot
.662 .48126 Mdot
.662 .48143 Mdot
.662 .48146 Mdot
.662 .48163 Mdot
.662 .4817 Mdot
.662 .48213 Mdot
.662 .48229 Mdot
.662 .48233 Mdot
.662 .48235 Mdot
.662 .4824 Mdot
.662 .4828 Mdot
.662 .48308 Mdot
.662 .48309 Mdot
.662 .4831 Mdot
.662 .48324 Mdot
.662 .48341 Mdot
.662 .48343 Mdot
.662 .48369 Mdot
.662 .4847 Mdot
.662 .48476 Mdot
.662 .48501 Mdot
.662 .48627 Mdot
.662 .48726 Mdot
.662 .48738 Mdot
.662 .48742 Mdot
.662 .48808 Mdot
.662 .48819 Mdot
.662 .48832 Mdot
.662 .48853 Mdot
.662 .48889 Mdot
.662 .48922 Mdot
.662 .49008 Mdot
.662 .49014 Mdot
.662 .49028 Mdot
.662 .49045 Mdot
.662 .49072 Mdot
.662 .49081 Mdot
.662 .49097 Mdot
.662 .49119 Mdot
.662 .49123 Mdot
.662 .49127 Mdot
.662 .49136 Mdot
.662 .49149 Mdot
.662 .49194 Mdot
.662 .49257 Mdot
.662 .49343 Mdot
.662 .49367 Mdot
.662 .49382 Mdot
.662 .49441 Mdot
.662 .49446 Mdot
.662 .49457 Mdot
.662 .4948 Mdot
.662 .49496 Mdot
.662 .4952 Mdot
.662 .49549 Mdot
.662 .49577 Mdot
.662 .49583 Mdot
.662 .49588 Mdot
.662 .49621 Mdot
.662 .49633 Mdot
.662 .49639 Mdot
.662 .49654 Mdot
.662 .49689 Mdot
.662 .49796 Mdot
.662 .49821 Mdot
.662 .49867 Mdot
.662 .49907 Mdot
.662 .49929 Mdot
.662 .49935 Mdot
.662 .49946 Mdot
.662 .49954 Mdot
.662 .49956 Mdot
.662 .49956 Mdot
.662 .49961 Mdot
.662 .49985 Mdot
.662 .50002 Mdot
.662 .50021 Mdot
.662 .50044 Mdot
.662 .50096 Mdot
.662 .5014 Mdot
.662 .50143 Mdot
.662 .502 Mdot
.662 .50204 Mdot
.662 .50222 Mdot
.662 .50237 Mdot
.662 .50238 Mdot
.662 .50274 Mdot
.662 .50335 Mdot
.662 .50408 Mdot
.662 .50411 Mdot
.662 .5044 Mdot
.662 .50443 Mdot
.662 .50519 Mdot
.662 .50561 Mdot
.662 .50568 Mdot
.662 .50628 Mdot
.662 .50638 Mdot
.662 .50877 Mdot
.662 .50899 Mdot
.662 .50905 Mdot
.662 .50906 Mdot
.662 .50938 Mdot
.662 .5103 Mdot
.662 .51165 Mdot
.662 .51251 Mdot
.662 .51274 Mdot
.662 .51333 Mdot
.662 .51415 Mdot
.662 .51428 Mdot
.662 .51447 Mdot
.662 .51449 Mdot
.662 .51467 Mdot
.662 .51734 Mdot
.662 .51759 Mdot
.662 .5178 Mdot
.662 .51827 Mdot
.662 .51874 Mdot
.662 .51917 Mdot
.662 .51927 Mdot
.662 .51989 Mdot
.662 .51991 Mdot
.662 .52078 Mdot
.662 .52125 Mdot
.662 .52131 Mdot
.662 .52132 Mdot
.662 .52135 Mdot
.662 .52177 Mdot
.662 .52215 Mdot
.662 .52223 Mdot
.662 .52296 Mdot
.662 .52303 Mdot
.662 .52308 Mdot
.662 .52328 Mdot
.662 .52411 Mdot
.662 .52417 Mdot
.662 .52445 Mdot
.662 .52452 Mdot
.662 .52458 Mdot
.662 .52458 Mdot
.662 .52496 Mdot
.662 .52498 Mdot
.662 .52596 Mdot
.662 .52598 Mdot
.662 .52651 Mdot
.662 .52653 Mdot
.662 .52655 Mdot
.662 .52679 Mdot
.662 .52689 Mdot
.662 .52705 Mdot
.662 .52707 Mdot
.662 .52725 Mdot
.662 .5273 Mdot
.662 .52789 Mdot
.662 .52945 Mdot
.662 .52958 Mdot
.662 .52986 Mdot
.662 .52996 Mdot
.662 .53028 Mdot
.662 .53071 Mdot
.662 .53111 Mdot
.662 .53127 Mdot
.662 .53146 Mdot
.662 .53199 Mdot
.662 .53206 Mdot
.662 .53212 Mdot
.662 .53223 Mdot
.662 .53244 Mdot
.662 .53251 Mdot
.662 .53299 Mdot
.662 .53335 Mdot
.662 .53546 Mdot
.662 .53549 Mdot
.662 .53579 Mdot
.662 .53585 Mdot
.662 .53617 Mdot
.662 .53629 Mdot
.662 .53706 Mdot
.662 .53729 Mdot
.662 .53735 Mdot
.662 .53742 Mdot
.662 .53745 Mdot
.662 .53754 Mdot
.662 .5381 Mdot
.662 .53826 Mdot
.662 .53875 Mdot
.662 .53877 Mdot
.662 .53879 Mdot
.662 .53903 Mdot
.662 .53919 Mdot
.662 .53933 Mdot
.662 .53934 Mdot
.662 .53936 Mdot
.662 .5398 Mdot
.662 .53981 Mdot
.662 .54004 Mdot
.662 .54018 Mdot
.662 .54033 Mdot
.662 .54145 Mdot
.662 .54151 Mdot
.662 .54161 Mdot
.662 .54186 Mdot
.662 .54203 Mdot
.662 .54219 Mdot
.662 .54302 Mdot
.662 .54387 Mdot
.662 .54406 Mdot
.662 .5445 Mdot
.662 .5447 Mdot
.662 .54523 Mdot
.662 .54548 Mdot
.662 .54559 Mdot
.662 .54578 Mdot
.662 .54584 Mdot
.662 .54683 Mdot
.662 .54699 Mdot
.662 .54718 Mdot
.662 .54749 Mdot
.662 .54801 Mdot
.662 .5483 Mdot
.662 .54847 Mdot
.662 .5493 Mdot
.662 .54937 Mdot
.662 .54966 Mdot
.662 .54967 Mdot
.662 .54971 Mdot
.662 .54974 Mdot
.662 .54993 Mdot
.662 .54996 Mdot
.662 .55012 Mdot
.662 .55016 Mdot
.662 .55052 Mdot
.662 .55053 Mdot
.662 .55055 Mdot
.662 .55058 Mdot
.662 .55064 Mdot
.662 .55085 Mdot
.662 .55113 Mdot
.662 .55118 Mdot
.662 .55124 Mdot
.662 .55135 Mdot
.662 .55139 Mdot
.662 .55143 Mdot
.662 .55152 Mdot
.662 .55209 Mdot
.662 .55287 Mdot
.662 .55287 Mdot
.662 .55289 Mdot
.662 .55344 Mdot
.662 .55344 Mdot
.662 .55351 Mdot
.662 .55361 Mdot
.662 .55388 Mdot
.662 .55399 Mdot
.662 .55407 Mdot
.662 .55415 Mdot
.662 .55433 Mdot
.662 .55498 Mdot
.662 .55503 Mdot
.662 .55514 Mdot
.662 .55516 Mdot
.662 .55539 Mdot
.662 .55541 Mdot
.662 .55545 Mdot
.662 .55553 Mdot
.662 .55558 Mdot
.662 .55583 Mdot
.662 .55612 Mdot
.662 .5564 Mdot
.662 .55641 Mdot
.662 .55647 Mdot
.662 .5565 Mdot
.662 .55652 Mdot
.662 .55685 Mdot
.662 .55692 Mdot
.662 .55696 Mdot
.662 .55702 Mdot
.662 .55716 Mdot
.662 .55738 Mdot
.662 .55741 Mdot
.662 .55741 Mdot
.662 .55748 Mdot
.662 .5575 Mdot
.662 .55797 Mdot
.662 .55845 Mdot
.662 .55866 Mdot
.662 .5588 Mdot
.662 .55882 Mdot
.662 .55904 Mdot
.662 .55936 Mdot
.662 .55938 Mdot
.662 .55946 Mdot
.662 .55953 Mdot
.662 .55958 Mdot
.662 .55966 Mdot
.662 .55972 Mdot
.662 .55974 Mdot
.662 .55974 Mdot
.662 .55977 Mdot
.662 .55982 Mdot
.662 .55995 Mdot
.662 .56007 Mdot
.662 .5602 Mdot
.662 .56021 Mdot
.662 .56037 Mdot
.662 .56055 Mdot
.662 .5607 Mdot
.662 .56072 Mdot
.662 .56087 Mdot
.662 .56099 Mdot
.662 .56102 Mdot
.662 .56135 Mdot
.662 .56138 Mdot
.662 .56148 Mdot
.662 .56156 Mdot
.662 .56156 Mdot
.662 .56176 Mdot
.662 .56206 Mdot
.662 .56238 Mdot
.662 .56239 Mdot
.662 .5624 Mdot
.662 .56246 Mdot
.662 .56247 Mdot
.662 .56252 Mdot
.662 .56253 Mdot
.662 .56255 Mdot
.662 .5626 Mdot
.662 .56281 Mdot
.662 .5629 Mdot
.662 .56294 Mdot
.662 .56296 Mdot
.662 .56307 Mdot
.662 .56313 Mdot
.662 .56314 Mdot
.662 .56315 Mdot
.662 .56333 Mdot
.662 .5635 Mdot
.662 .56351 Mdot
.662 .56352 Mdot
.662 .56352 Mdot
.662 .56352 Mdot
.662 .56353 Mdot
.664 .15239 Mdot
.664 .15241 Mdot
.664 .15244 Mdot
.664 .15252 Mdot
.664 .15254 Mdot
.664 .15255 Mdot
.664 .15263 Mdot
.664 .15264 Mdot
.664 .15281 Mdot
.664 .15287 Mdot
.664 .15289 Mdot
.664 .15328 Mdot
.664 .15334 Mdot
.664 .15342 Mdot
.664 .15399 Mdot
.664 .15413 Mdot
.664 .15419 Mdot
.664 .15452 Mdot
.664 .15455 Mdot
.664 .15465 Mdot
.664 .15466 Mdot
.664 .15468 Mdot
.664 .15491 Mdot
.664 .15534 Mdot
.664 .15543 Mdot
.664 .15548 Mdot
.664 .15554 Mdot
.664 .15584 Mdot
.664 .15629 Mdot
.664 .15658 Mdot
.664 .15711 Mdot
.664 .15855 Mdot
.664 .15893 Mdot
.664 .15932 Mdot
.664 .15951 Mdot
.664 .15975 Mdot
.664 .16039 Mdot
.664 .16039 Mdot
.664 .16077 Mdot
.664 .16085 Mdot
.664 .16101 Mdot
.664 .16106 Mdot
.664 .16144 Mdot
.664 .16154 Mdot
.664 .16157 Mdot
.664 .162 Mdot
.664 .16208 Mdot
.664 .16213 Mdot
.664 .16224 Mdot
.664 .16275 Mdot
.664 .16302 Mdot
.664 .16334 Mdot
.664 .16343 Mdot
.664 .16374 Mdot
.664 .16375 Mdot
.664 .16425 Mdot
.664 .16439 Mdot
.664 .16582 Mdot
.664 .1662 Mdot
.664 .16663 Mdot
.664 .16669 Mdot
.664 .16834 Mdot
.664 .16865 Mdot
.664 .16917 Mdot
.664 .1694 Mdot
.664 .16959 Mdot
.664 .17063 Mdot
.664 .17068 Mdot
.664 .17106 Mdot
.664 .17128 Mdot
.664 .17172 Mdot
.664 .17212 Mdot
.664 .17271 Mdot
.664 .17337 Mdot
.664 .1747 Mdot
.664 .17481 Mdot
.664 .175 Mdot
.664 .17577 Mdot
.664 .17585 Mdot
.664 .17607 Mdot
.664 .1762 Mdot
.664 .17694 Mdot
.664 .17707 Mdot
.664 .17801 Mdot
.664 .17852 Mdot
.664 .1799 Mdot
.664 .18006 Mdot
.664 .18037 Mdot
.664 .18128 Mdot
.664 .18157 Mdot
.664 .18177 Mdot
.664 .18234 Mdot
.664 .18265 Mdot
.664 .18276 Mdot
.664 .18287 Mdot
.664 .18308 Mdot
.664 .18315 Mdot
.664 .18342 Mdot
.664 .1837 Mdot
.664 .18396 Mdot
.664 .18457 Mdot
.664 .18513 Mdot
.664 .1858 Mdot
.664 .18601 Mdot
.664 .18621 Mdot
.664 .18644 Mdot
.664 .18656 Mdot
.664 .18784 Mdot
.664 .18806 Mdot
.664 .19009 Mdot
.664 .19058 Mdot
.664 .19109 Mdot
.664 .19118 Mdot
.664 .19417 Mdot
.664 .19448 Mdot
.664 .19452 Mdot
.664 .19498 Mdot
.664 .19561 Mdot
.664 .19618 Mdot
.664 .19688 Mdot
.664 .19732 Mdot
.664 .19761 Mdot
.664 .19772 Mdot
.664 .19847 Mdot
.664 .19909 Mdot
.664 .20005 Mdot
.664 .20131 Mdot
.664 .20142 Mdot
.664 .2015 Mdot
.664 .20302 Mdot
.664 .2069 Mdot
.664 .20903 Mdot
.664 .20993 Mdot
.664 .21172 Mdot
.664 .21189 Mdot
.664 .21235 Mdot
.664 .21295 Mdot
.664 .21297 Mdot
.664 .21305 Mdot
.664 .2134 Mdot
.664 .21494 Mdot
.664 .2156 Mdot
.664 .21625 Mdot
.664 .21768 Mdot
.664 .21812 Mdot
.664 .21888 Mdot
.664 .22004 Mdot
.664 .22025 Mdot
.664 .2209 Mdot
.664 .22259 Mdot
.664 .22268 Mdot
.664 .22286 Mdot
.664 .22325 Mdot
.664 .22397 Mdot
.664 .22615 Mdot
.664 .22804 Mdot
.664 .22901 Mdot
.664 .23061 Mdot
.664 .23077 Mdot
.664 .23173 Mdot
.664 .23184 Mdot
.664 .23317 Mdot
.664 .23326 Mdot
.664 .23362 Mdot
.664 .23406 Mdot
.664 .23606 Mdot
.664 .23609 Mdot
.664 .23617 Mdot
.664 .23677 Mdot
.664 .23689 Mdot
.664 .23802 Mdot
.664 .23814 Mdot
.664 .2396 Mdot
.664 .24035 Mdot
.664 .24047 Mdot
.664 .24107 Mdot
.664 .24148 Mdot
.664 .24153 Mdot
.664 .24183 Mdot
.664 .24295 Mdot
.664 .24325 Mdot
.664 .24328 Mdot
.664 .2433 Mdot
.664 .24432 Mdot
.664 .24512 Mdot
.664 .24553 Mdot
.664 .24881 Mdot
.664 .24898 Mdot
.664 .2491 Mdot
.664 .25025 Mdot
.664 .252 Mdot
.664 .2523 Mdot
.664 .25261 Mdot
.664 .25334 Mdot
.664 .25354 Mdot
.664 .25355 Mdot
.664 .25384 Mdot
.664 .25406 Mdot
.664 .25414 Mdot
.664 .25501 Mdot
.664 .2593 Mdot
.664 .25936 Mdot
.664 .26054 Mdot
.664 .26087 Mdot
.664 .26134 Mdot
.664 .26149 Mdot
.664 .26173 Mdot
.664 .2653 Mdot
.664 .26559 Mdot
.664 .26693 Mdot
.664 .26806 Mdot
.664 .26819 Mdot
.664 .26861 Mdot
.664 .26897 Mdot
.664 .26935 Mdot
.664 .2697 Mdot
.664 .27013 Mdot
.664 .27172 Mdot
.664 .27204 Mdot
.664 .273 Mdot
.664 .27411 Mdot
.664 .27569 Mdot
.664 .27846 Mdot
.664 .27899 Mdot
.664 .28023 Mdot
.664 .28096 Mdot
.664 .28471 Mdot
.664 .28537 Mdot
.664 .287 Mdot
.664 .28713 Mdot
.664 .28919 Mdot
.664 .29 Mdot
.664 .29032 Mdot
.664 .29056 Mdot
.664 .2911 Mdot
.664 .29162 Mdot
.664 .296 Mdot
.664 .2967 Mdot
.664 .2968 Mdot
.664 .29699 Mdot
.664 .29788 Mdot
.664 .29849 Mdot
.664 .29879 Mdot
.664 .29962 Mdot
.664 .3019 Mdot
.664 .30413 Mdot
.664 .30544 Mdot
.664 .30555 Mdot
.664 .30788 Mdot
.664 .3097 Mdot
.664 .31068 Mdot
.664 .31164 Mdot
.664 .31182 Mdot
.664 .31187 Mdot
.664 .31361 Mdot
.664 .31398 Mdot
.664 .31565 Mdot
.664 .31587 Mdot
.664 .3179 Mdot
.664 .31828 Mdot
.664 .31933 Mdot
.664 .31957 Mdot
.664 .31963 Mdot
.664 .32146 Mdot
.664 .32285 Mdot
.664 .32335 Mdot
.664 .32424 Mdot
.664 .32884 Mdot
.664 .32931 Mdot
.664 .32941 Mdot
.664 .3296 Mdot
.664 .32966 Mdot
.664 .33011 Mdot
.664 .33023 Mdot
.664 .33026 Mdot
.664 .33075 Mdot
.664 .33084 Mdot
.664 .33159 Mdot
.664 .33189 Mdot
.664 .33223 Mdot
.664 .33233 Mdot
.664 .33265 Mdot
.664 .33319 Mdot
.664 .33474 Mdot
.664 .33511 Mdot
.664 .33552 Mdot
.664 .33557 Mdot
.664 .33735 Mdot
.664 .338 Mdot
.664 .33816 Mdot
.664 .33908 Mdot
.664 .3394 Mdot
.664 .33994 Mdot
.664 .34025 Mdot
.664 .34073 Mdot
.664 .34124 Mdot
.664 .34227 Mdot
.664 .34249 Mdot
.664 .34306 Mdot
.664 .34312 Mdot
.664 .34328 Mdot
.664 .34338 Mdot
.664 .34401 Mdot
.664 .34468 Mdot
.664 .3461 Mdot
.664 .34693 Mdot
.664 .34712 Mdot
.664 .34726 Mdot
.664 .34763 Mdot
.664 .34784 Mdot
.664 .34797 Mdot
.664 .34811 Mdot
.664 .34816 Mdot
.664 .34851 Mdot
.664 .3501 Mdot
.664 .35024 Mdot
.664 .35032 Mdot
.664 .35124 Mdot
.664 .35303 Mdot
.664 .35308 Mdot
.664 .35479 Mdot
.664 .355 Mdot
.664 .35525 Mdot
.664 .3556 Mdot
.664 .35592 Mdot
.664 .35676 Mdot
.664 .35801 Mdot
.664 .35877 Mdot
.664 .35956 Mdot
.664 .36153 Mdot
.664 .36258 Mdot
.664 .36453 Mdot
.664 .3667 Mdot
.664 .3669 Mdot
.664 .36725 Mdot
.664 .36788 Mdot
.664 .36817 Mdot
.664 .36897 Mdot
.664 .36955 Mdot
.664 .37051 Mdot
.664 .37133 Mdot
.664 .37175 Mdot
.664 .37244 Mdot
.664 .37296 Mdot
.664 .37353 Mdot
.664 .37356 Mdot
.664 .3739 Mdot
.664 .37503 Mdot
.664 .37555 Mdot
.664 .3756 Mdot
.664 .3768 Mdot
.664 .37698 Mdot
.664 .37711 Mdot
.664 .3777 Mdot
.664 .3777 Mdot
.664 .37811 Mdot
.664 .3786 Mdot
.664 .37996 Mdot
.664 .38046 Mdot
.664 .38138 Mdot
.664 .38167 Mdot
.664 .38174 Mdot
.664 .38175 Mdot
.664 .38231 Mdot
.664 .38395 Mdot
.664 .38454 Mdot
.664 .38472 Mdot
.664 .3868 Mdot
.664 .38722 Mdot
.664 .38755 Mdot
.664 .38769 Mdot
.664 .38782 Mdot
.664 .38798 Mdot
.664 .38856 Mdot
.664 .38867 Mdot
.664 .38943 Mdot
.664 .39099 Mdot
.664 .39118 Mdot
.664 .39163 Mdot
.664 .39321 Mdot
.664 .39344 Mdot
.664 .39402 Mdot
.664 .39506 Mdot
.664 .39526 Mdot
.664 .39563 Mdot
.664 .39738 Mdot
.664 .39741 Mdot
.664 .39748 Mdot
.664 .39809 Mdot
.664 .39838 Mdot
.664 .40039 Mdot
.664 .40117 Mdot
.664 .40211 Mdot
.664 .40249 Mdot
.664 .40251 Mdot
.664 .40321 Mdot
.664 .40377 Mdot
.664 .40384 Mdot
.664 .40451 Mdot
.664 .4066 Mdot
.664 .40826 Mdot
.664 .40829 Mdot
.664 .40835 Mdot
.664 .40837 Mdot
.664 .40852 Mdot
.664 .40856 Mdot
.664 .40857 Mdot
.664 .40873 Mdot
.664 .40876 Mdot
.664 .4091 Mdot
.664 .40921 Mdot
.664 .40924 Mdot
.664 .40935 Mdot
.664 .40952 Mdot
.664 .41002 Mdot
.664 .41014 Mdot
.664 .41027 Mdot
.664 .41029 Mdot
.664 .41087 Mdot
.664 .41108 Mdot
.664 .41143 Mdot
.664 .41153 Mdot
.664 .4117 Mdot
.664 .4118 Mdot
.664 .41196 Mdot
.664 .41212 Mdot
.664 .41245 Mdot
.664 .41252 Mdot
.664 .41271 Mdot
.664 .41273 Mdot
.664 .41278 Mdot
.664 .41281 Mdot
.664 .41301 Mdot
.664 .41323 Mdot
.664 .41368 Mdot
.664 .41395 Mdot
.664 .41401 Mdot
.664 .41405 Mdot
.664 .41417 Mdot
.664 .41424 Mdot
.664 .41428 Mdot
.664 .41433 Mdot
.664 .41434 Mdot
.664 .41446 Mdot
.664 .41496 Mdot
.664 .41503 Mdot
.664 .41533 Mdot
.664 .4159 Mdot
.664 .41592 Mdot
.664 .41646 Mdot
.664 .41682 Mdot
.664 .41709 Mdot
.664 .41749 Mdot
.664 .41773 Mdot
.664 .41861 Mdot
.664 .42025 Mdot
.664 .42062 Mdot
.664 .42097 Mdot
.664 .42146 Mdot
.664 .42172 Mdot
.664 .42207 Mdot
.664 .42223 Mdot
.664 .42241 Mdot
.664 .42253 Mdot
.664 .42289 Mdot
.664 .42307 Mdot
.664 .42345 Mdot
.664 .42373 Mdot
.664 .42373 Mdot
.664 .42402 Mdot
.664 .42445 Mdot
.664 .42461 Mdot
.664 .4249 Mdot
.664 .42499 Mdot
.664 .42501 Mdot
.664 .42502 Mdot
.664 .42519 Mdot
.664 .42571 Mdot
.664 .4259 Mdot
.664 .42596 Mdot
.664 .42662 Mdot
.664 .42675 Mdot
.664 .4269 Mdot
.664 .42699 Mdot
.664 .42717 Mdot
.664 .42721 Mdot
.664 .428 Mdot
.664 .42814 Mdot
.664 .42865 Mdot
.664 .42872 Mdot
.664 .4289 Mdot
.664 .42923 Mdot
.664 .4293 Mdot
.664 .42941 Mdot
.664 .42998 Mdot
.664 .43 Mdot
.664 .43029 Mdot
.664 .43092 Mdot
.664 .43117 Mdot
.664 .4316 Mdot
.664 .432 Mdot
.664 .43378 Mdot
.664 .43383 Mdot
.664 .43427 Mdot
.664 .43448 Mdot
.664 .43467 Mdot
.664 .43525 Mdot
.664 .43532 Mdot
.664 .43536 Mdot
.664 .43558 Mdot
.664 .43588 Mdot
.664 .43617 Mdot
.664 .4374 Mdot
.664 .43792 Mdot
.664 .43819 Mdot
.664 .43831 Mdot
.664 .43849 Mdot
.664 .43882 Mdot
.664 .43882 Mdot
.664 .43888 Mdot
.664 .43934 Mdot
.664 .43979 Mdot
.664 .44008 Mdot
.664 .44021 Mdot
.664 .44053 Mdot
.664 .44169 Mdot
.664 .44236 Mdot
.664 .44246 Mdot
.664 .44286 Mdot
.664 .44312 Mdot
.664 .44333 Mdot
.664 .4435 Mdot
.664 .44374 Mdot
.664 .44428 Mdot
.664 .44482 Mdot
.664 .44496 Mdot
.664 .446 Mdot
.664 .44662 Mdot
.664 .44685 Mdot
.664 .44712 Mdot
.664 .44779 Mdot
.664 .4487 Mdot
.664 .44912 Mdot
.664 .44941 Mdot
.664 .44941 Mdot
.664 .44959 Mdot
.664 .44976 Mdot
.664 .44992 Mdot
.664 .45021 Mdot
.664 .45089 Mdot
.664 .45105 Mdot
.664 .45122 Mdot
.664 .45136 Mdot
.664 .45172 Mdot
.664 .45195 Mdot
.664 .45218 Mdot
.664 .45319 Mdot
.664 .45341 Mdot
.664 .45413 Mdot
.664 .45466 Mdot
.664 .45488 Mdot
.664 .45497 Mdot
.664 .45536 Mdot
.664 .45581 Mdot
.664 .45611 Mdot
.664 .45687 Mdot
.664 .45696 Mdot
.664 .45696 Mdot
.664 .45749 Mdot
.664 .4578 Mdot
.664 .458 Mdot
.664 .45809 Mdot
.664 .45834 Mdot
.664 .45844 Mdot
.664 .45885 Mdot
.664 .45929 Mdot
.664 .46034 Mdot
.664 .4608 Mdot
.664 .46113 Mdot
.664 .46127 Mdot
.664 .46174 Mdot
.664 .46204 Mdot
.664 .46223 Mdot
.664 .46255 Mdot
.664 .46258 Mdot
.664 .46263 Mdot
.664 .46272 Mdot
.664 .46275 Mdot
.664 .46289 Mdot
.664 .46323 Mdot
.664 .46333 Mdot
.664 .46368 Mdot
.664 .46377 Mdot
.664 .46399 Mdot
.664 .46422 Mdot
.664 .46432 Mdot
.664 .46462 Mdot
.664 .46501 Mdot
.664 .46509 Mdot
.664 .46559 Mdot
.664 .46648 Mdot
.664 .46752 Mdot
.664 .46785 Mdot
.664 .46789 Mdot
.664 .46816 Mdot
.664 .46851 Mdot
.664 .46852 Mdot
.664 .46871 Mdot
.664 .46917 Mdot
.664 .46956 Mdot
.664 .47054 Mdot
.664 .47068 Mdot
.664 .47098 Mdot
.664 .47101 Mdot
.664 .47103 Mdot
.664 .47188 Mdot
.664 .47206 Mdot
.664 .47215 Mdot
.664 .47266 Mdot
.664 .47293 Mdot
.664 .47305 Mdot
.664 .47381 Mdot
.664 .47402 Mdot
.664 .47411 Mdot
.664 .47485 Mdot
.664 .47521 Mdot
.664 .47527 Mdot
.664 .47554 Mdot
.664 .47562 Mdot
.664 .47568 Mdot
.664 .47574 Mdot
.664 .4759 Mdot
.664 .4761 Mdot
.664 .47708 Mdot
.664 .47716 Mdot
.664 .47744 Mdot
.664 .47821 Mdot
.664 .47847 Mdot
.664 .47847 Mdot
.664 .47851 Mdot
.664 .47864 Mdot
.664 .47906 Mdot
.664 .4793 Mdot
.664 .47993 Mdot
.664 .48015 Mdot
.664 .48034 Mdot
.664 .48034 Mdot
.664 .48061 Mdot
.664 .48067 Mdot
.664 .48076 Mdot
.664 .48131 Mdot
.664 .48133 Mdot
.664 .48156 Mdot
.664 .48208 Mdot
.664 .48224 Mdot
.664 .48225 Mdot
.664 .48251 Mdot
.664 .48275 Mdot
.664 .48306 Mdot
.664 .48325 Mdot
.664 .48362 Mdot
.664 .48406 Mdot
.664 .48431 Mdot
.664 .48468 Mdot
.664 .48481 Mdot
.664 .48509 Mdot
.664 .48524 Mdot
.664 .48533 Mdot
.664 .4863 Mdot
.664 .48716 Mdot
.664 .48763 Mdot
.664 .4885 Mdot
.664 .48884 Mdot
.664 .48918 Mdot
.664 .48973 Mdot
.664 .49009 Mdot
.664 .49023 Mdot
.664 .49038 Mdot
.664 .49049 Mdot
.664 .49058 Mdot
.664 .49132 Mdot
.664 .49134 Mdot
.664 .49212 Mdot
.664 .49252 Mdot
.664 .49255 Mdot
.664 .49261 Mdot
.664 .49329 Mdot
.664 .49344 Mdot
.664 .49346 Mdot
.664 .49352 Mdot
.664 .49358 Mdot
.664 .49367 Mdot
.664 .49383 Mdot
.664 .49389 Mdot
.664 .49397 Mdot
.664 .49432 Mdot
.664 .49492 Mdot
.664 .49521 Mdot
.664 .49547 Mdot
.664 .49551 Mdot
.664 .49558 Mdot
.664 .49561 Mdot
.664 .49585 Mdot
.664 .49594 Mdot
.664 .49638 Mdot
.664 .49659 Mdot
.664 .49679 Mdot
.664 .49692 Mdot
.664 .49715 Mdot
.664 .49728 Mdot
.664 .49767 Mdot
.664 .49773 Mdot
.664 .49801 Mdot
.664 .49875 Mdot
.664 .49877 Mdot
.664 .49894 Mdot
.664 .49909 Mdot
.664 .49974 Mdot
.664 .49996 Mdot
.664 .50009 Mdot
.664 .50013 Mdot
.664 .50027 Mdot
.664 .5004 Mdot
.664 .5007 Mdot
.664 .50074 Mdot
.664 .50094 Mdot
.664 .50096 Mdot
.664 .501 Mdot
.664 .50119 Mdot
.664 .50121 Mdot
.664 .50129 Mdot
.664 .50133 Mdot
.664 .50153 Mdot
.664 .5034 Mdot
.664 .50376 Mdot
.664 .50397 Mdot
.664 .50453 Mdot
.664 .50526 Mdot
.664 .50529 Mdot
.664 .50539 Mdot
.664 .50581 Mdot
.664 .50596 Mdot
.664 .50677 Mdot
.664 .50686 Mdot
.664 .50752 Mdot
.664 .50767 Mdot
.664 .50836 Mdot
.664 .50838 Mdot
.664 .50845 Mdot
.664 .50883 Mdot
.664 .50921 Mdot
.664 .50993 Mdot
.664 .51084 Mdot
.664 .51088 Mdot
.664 .5114 Mdot
.664 .51227 Mdot
.664 .51315 Mdot
.664 .51347 Mdot
.664 .51359 Mdot
.664 .51382 Mdot
.664 .51416 Mdot
.664 .51424 Mdot
.664 .51427 Mdot
.664 .51454 Mdot
.664 .51621 Mdot
.664 .51641 Mdot
.664 .51651 Mdot
.664 .51662 Mdot
.664 .51671 Mdot
.664 .51683 Mdot
.664 .51714 Mdot
.664 .51792 Mdot
.664 .51797 Mdot
.664 .51858 Mdot
.664 .51883 Mdot
.664 .52023 Mdot
.664 .52051 Mdot
.664 .52097 Mdot
.664 .52117 Mdot
.664 .5222 Mdot
.664 .52278 Mdot
.664 .52319 Mdot
.664 .52354 Mdot
.664 .52366 Mdot
.664 .52424 Mdot
.664 .5244 Mdot
.664 .52453 Mdot
.664 .52467 Mdot
.664 .5248 Mdot
.664 .52495 Mdot
.664 .525 Mdot
.664 .52541 Mdot
.664 .5259 Mdot
.664 .52601 Mdot
.664 .5273 Mdot
.664 .52738 Mdot
.664 .52744 Mdot
.664 .52761 Mdot
.664 .52773 Mdot
.664 .52815 Mdot
.664 .52817 Mdot
.664 .52971 Mdot
.664 .53002 Mdot
.664 .53005 Mdot
.664 .53013 Mdot
.664 .53023 Mdot
.664 .53024 Mdot
.664 .53031 Mdot
.664 .53057 Mdot
.664 .53068 Mdot
.664 .53079 Mdot
.664 .53141 Mdot
.664 .53181 Mdot
.664 .53186 Mdot
.664 .53192 Mdot
.664 .53308 Mdot
.664 .53322 Mdot
.664 .5335 Mdot
.664 .53386 Mdot
.664 .53387 Mdot
.664 .53388 Mdot
.664 .53398 Mdot
.664 .53437 Mdot
.664 .53448 Mdot
.664 .5345 Mdot
.664 .53464 Mdot
.664 .53485 Mdot
.664 .53489 Mdot
.664 .53515 Mdot
.664 .53566 Mdot
.664 .5357 Mdot
.664 .5361 Mdot
.664 .53614 Mdot
.664 .53634 Mdot
.664 .53637 Mdot
.664 .53639 Mdot
.664 .53708 Mdot
.664 .53723 Mdot
.664 .53735 Mdot
.664 .53739 Mdot
.664 .53784 Mdot
.664 .53788 Mdot
.664 .53821 Mdot
.664 .53827 Mdot
.664 .53882 Mdot
.664 .53915 Mdot
.664 .5398 Mdot
.664 .54054 Mdot
.664 .54079 Mdot
.664 .54092 Mdot
.664 .54098 Mdot
.664 .54101 Mdot
.664 .54159 Mdot
.664 .5418 Mdot
.664 .54187 Mdot
.664 .54227 Mdot
.664 .54252 Mdot
.664 .54267 Mdot
.664 .54316 Mdot
.664 .54337 Mdot
.664 .5436 Mdot
.664 .54412 Mdot
.664 .54423 Mdot
.664 .54426 Mdot
.664 .54427 Mdot
.664 .54447 Mdot
.664 .54462 Mdot
.664 .54468 Mdot
.664 .54528 Mdot
.664 .54557 Mdot
.664 .54628 Mdot
.664 .54757 Mdot
.664 .54807 Mdot
.664 .5481 Mdot
.664 .54814 Mdot
.664 .54855 Mdot
.664 .54887 Mdot
.664 .54907 Mdot
.664 .54932 Mdot
.664 .54935 Mdot
.664 .54945 Mdot
.664 .54959 Mdot
.664 .54982 Mdot
.664 .55001 Mdot
.664 .55022 Mdot
.664 .55036 Mdot
.664 .55038 Mdot
.664 .55048 Mdot
.664 .55145 Mdot
.664 .55148 Mdot
.664 .55165 Mdot
.664 .55181 Mdot
.664 .55247 Mdot
.664 .55254 Mdot
.664 .55295 Mdot
.664 .55299 Mdot
.664 .55307 Mdot
.664 .55313 Mdot
.664 .5532 Mdot
.664 .55341 Mdot
.664 .5536 Mdot
.664 .55379 Mdot
.664 .55388 Mdot
.664 .55397 Mdot
.664 .55405 Mdot
.664 .55408 Mdot
.664 .55414 Mdot
.664 .55418 Mdot
.664 .55421 Mdot
.664 .55431 Mdot
.664 .5545 Mdot
.664 .55456 Mdot
.664 .55465 Mdot
.664 .55495 Mdot
.664 .55505 Mdot
.664 .5551 Mdot
.664 .55554 Mdot
.664 .5557 Mdot
.664 .556 Mdot
.664 .55604 Mdot
.664 .55628 Mdot
.664 .55632 Mdot
.664 .55639 Mdot
.664 .55642 Mdot
.664 .55666 Mdot
.664 .55672 Mdot
.664 .55676 Mdot
.664 .55718 Mdot
.664 .55739 Mdot
.664 .55758 Mdot
.664 .5577 Mdot
.664 .55785 Mdot
.664 .55791 Mdot
.664 .55803 Mdot
.664 .55805 Mdot
.664 .55838 Mdot
.664 .55844 Mdot
.664 .55851 Mdot
.664 .55868 Mdot
.664 .55878 Mdot
.664 .55929 Mdot
.664 .55931 Mdot
.664 .55945 Mdot
.664 .55957 Mdot
.664 .56002 Mdot
.664 .56006 Mdot
.664 .56022 Mdot
.664 .56022 Mdot
.664 .56032 Mdot
.664 .56035 Mdot
.664 .56045 Mdot
.664 .56053 Mdot
.664 .56069 Mdot
.664 .56073 Mdot
.664 .56074 Mdot
.664 .56077 Mdot
.664 .5609 Mdot
.664 .56091 Mdot
.664 .56094 Mdot
.664 .56106 Mdot
.664 .56108 Mdot
.664 .56113 Mdot
.664 .56115 Mdot
.664 .56127 Mdot
.664 .56127 Mdot
.664 .56147 Mdot
.664 .56155 Mdot
.664 .56161 Mdot
.664 .56173 Mdot
.664 .56185 Mdot
.664 .5623 Mdot
.664 .56246 Mdot
.664 .56255 Mdot
.664 .56269 Mdot
.664 .56278 Mdot
.664 .5628 Mdot
.664 .56282 Mdot
.664 .56285 Mdot
.664 .56298 Mdot
.664 .56305 Mdot
.664 .56306 Mdot
.664 .56306 Mdot
.664 .56309 Mdot
.664 .5631 Mdot
.664 .56321 Mdot
.664 .56322 Mdot
.664 .56326 Mdot
.664 .56344 Mdot
.664 .56347 Mdot
.664 .56349 Mdot
.664 .56361 Mdot
.664 .56361 Mdot
.664 .56363 Mdot
.664 .56368 Mdot
.664 .56369 Mdot
.664 .56371 Mdot
.664 .56372 Mdot
.664 .56372 Mdot
.664 .56375 Mdot
.664 .56376 Mdot
.664 .56376 Mdot
.666 .15168 Mdot
.666 .15169 Mdot
.666 .15169 Mdot
.666 .1517 Mdot
.666 .1517 Mdot
.666 .15171 Mdot
.666 .15181 Mdot
.666 .15206 Mdot
.666 .15221 Mdot
.666 .15225 Mdot
.666 .15232 Mdot
.666 .1524 Mdot
.666 .15243 Mdot
.666 .15245 Mdot
.666 .15283 Mdot
.666 .15305 Mdot
.666 .1536 Mdot
.666 .15362 Mdot
.666 .15364 Mdot
.666 .15396 Mdot
.666 .15434 Mdot
.666 .15468 Mdot
.666 .15485 Mdot
.666 .15505 Mdot
.666 .15543 Mdot
.666 .15582 Mdot
.666 .15585 Mdot
.666 .15677 Mdot
.666 .15687 Mdot
.666 .15697 Mdot
.666 .15702 Mdot
.666 .15704 Mdot
.666 .15705 Mdot
.666 .15705 Mdot
.666 .1571 Mdot
.666 .15726 Mdot
.666 .15743 Mdot
.666 .15752 Mdot
.666 .15859 Mdot
.666 .15932 Mdot
.666 .15946 Mdot
.666 .1595 Mdot
.666 .15987 Mdot
.666 .16018 Mdot
.666 .16027 Mdot
.666 .16039 Mdot
.666 .16048 Mdot
.666 .16079 Mdot
.666 .16121 Mdot
.666 .16171 Mdot
.666 .16259 Mdot
.666 .16372 Mdot
.666 .16385 Mdot
.666 .16437 Mdot
.666 .16441 Mdot
.666 .16508 Mdot
.666 .16589 Mdot
.666 .1663 Mdot
.666 .16693 Mdot
.666 .16694 Mdot
.666 .16699 Mdot
.666 .16738 Mdot
.666 .16755 Mdot
.666 .16768 Mdot
.666 .16827 Mdot
.666 .16922 Mdot
.666 .17 Mdot
.666 .17031 Mdot
.666 .17043 Mdot
.666 .17103 Mdot
.666 .17177 Mdot
.666 .17288 Mdot
.666 .17345 Mdot
.666 .17466 Mdot
.666 .17535 Mdot
.666 .17559 Mdot
.666 .17561 Mdot
.666 .17567 Mdot
.666 .17587 Mdot
.666 .17636 Mdot
.666 .17711 Mdot
.666 .17728 Mdot
.666 .17729 Mdot
.666 .17734 Mdot
.666 .17755 Mdot
.666 .17786 Mdot
.666 .17875 Mdot
.666 .17878 Mdot
.666 .18032 Mdot
.666 .18184 Mdot
.666 .18225 Mdot
.666 .18235 Mdot
.666 .18238 Mdot
.666 .18252 Mdot
.666 .18304 Mdot
.666 .18489 Mdot
.666 .18527 Mdot
.666 .18559 Mdot
.666 .18608 Mdot
.666 .18617 Mdot
.666 .18635 Mdot
.666 .18654 Mdot
.666 .18726 Mdot
.666 .18832 Mdot
.666 .18896 Mdot
.666 .18949 Mdot
.666 .19037 Mdot
.666 .19042 Mdot
.666 .19046 Mdot
.666 .19054 Mdot
.666 .19077 Mdot
.666 .19214 Mdot
.666 .19214 Mdot
.666 .19252 Mdot
.666 .19273 Mdot
.666 .19421 Mdot
.666 .19444 Mdot
.666 .1957 Mdot
.666 .19604 Mdot
.666 .19606 Mdot
.666 .19719 Mdot
.666 .19832 Mdot
.666 .19881 Mdot
.666 .19881 Mdot
.666 .19904 Mdot
.666 .19916 Mdot
.666 .19922 Mdot
.666 .19976 Mdot
.666 .20018 Mdot
.666 .20026 Mdot
.666 .20055 Mdot
.666 .20102 Mdot
.666 .20161 Mdot
.666 .20203 Mdot
.666 .20358 Mdot
.666 .20361 Mdot
.666 .20372 Mdot
.666 .20465 Mdot
.666 .20508 Mdot
.666 .20641 Mdot
.666 .20697 Mdot
.666 .20734 Mdot
.666 .20735 Mdot
.666 .20754 Mdot
.666 .20814 Mdot
.666 .20961 Mdot
.666 .20991 Mdot
.666 .2108 Mdot
.666 .21107 Mdot
.666 .21284 Mdot
.666 .21593 Mdot
.666 .21601 Mdot
.666 .21811 Mdot
.666 .21837 Mdot
.666 .21909 Mdot
.666 .22055 Mdot
.666 .22116 Mdot
.666 .22466 Mdot
.666 .22646 Mdot
.666 .22721 Mdot
.666 .228 Mdot
.666 .22869 Mdot
.666 .22884 Mdot
.666 .22994 Mdot
.666 .23052 Mdot
.666 .2313 Mdot
.666 .23144 Mdot
.666 .23183 Mdot
.666 .23413 Mdot
.666 .23519 Mdot
.666 .2358 Mdot
.666 .23675 Mdot
.666 .2373 Mdot
.666 .23859 Mdot
.666 .23871 Mdot
.666 .23943 Mdot
.666 .23989 Mdot
.666 .24041 Mdot
.666 .24063 Mdot
.666 .24065 Mdot
.666 .24096 Mdot
.666 .24097 Mdot
.666 .24118 Mdot
.666 .24119 Mdot
.666 .24168 Mdot
.666 .24197 Mdot
.666 .24203 Mdot
.666 .24255 Mdot
.666 .24278 Mdot
.666 .24343 Mdot
.666 .24387 Mdot
.666 .24484 Mdot
.666 .245 Mdot
.666 .24682 Mdot
.666 .24714 Mdot
.666 .24948 Mdot
.666 .25042 Mdot
.666 .25075 Mdot
.666 .25184 Mdot
.666 .2543 Mdot
.666 .25473 Mdot
.666 .25589 Mdot
.666 .25599 Mdot
.666 .25645 Mdot
.666 .25867 Mdot
.666 .25959 Mdot
.666 .25963 Mdot
.666 .26204 Mdot
.666 .26274 Mdot
.666 .26382 Mdot
.666 .26482 Mdot
.666 .26588 Mdot
.666 .26626 Mdot
.666 .26836 Mdot
.666 .26996 Mdot
.666 .27131 Mdot
.666 .27299 Mdot
.666 .27336 Mdot
.666 .27341 Mdot
.666 .27406 Mdot
.666 .27441 Mdot
.666 .27479 Mdot
.666 .27531 Mdot
.666 .27752 Mdot
.666 .27812 Mdot
.666 .27961 Mdot
.666 .28258 Mdot
.666 .284 Mdot
.666 .2847 Mdot
.666 .28683 Mdot
.666 .28739 Mdot
.666 .29323 Mdot
.666 .29478 Mdot
.666 .29548 Mdot
.666 .29656 Mdot
.666 .29691 Mdot
.666 .29923 Mdot
.666 .30084 Mdot
.666 .30151 Mdot
.666 .3029 Mdot
.666 .30298 Mdot
.666 .30307 Mdot
.666 .30341 Mdot
.666 .30375 Mdot
.666 .30806 Mdot
.666 .30813 Mdot
.666 .30886 Mdot
.666 .30976 Mdot
.666 .31001 Mdot
.666 .31026 Mdot
.666 .31156 Mdot
.666 .3133 Mdot
.666 .31411 Mdot
.666 .31869 Mdot
.666 .31875 Mdot
.666 .31958 Mdot
.666 .32042 Mdot
.666 .32184 Mdot
.666 .3233 Mdot
.666 .32496 Mdot
.666 .32511 Mdot
.666 .32518 Mdot
.666 .32521 Mdot
.666 .32522 Mdot
.666 .32523 Mdot
.666 .3253 Mdot
.666 .32554 Mdot
.666 .32579 Mdot
.666 .32592 Mdot
.666 .32741 Mdot
.666 .32836 Mdot
.666 .32854 Mdot
.666 .32859 Mdot
.666 .32905 Mdot
.666 .32943 Mdot
.666 .32954 Mdot
.666 .32968 Mdot
.666 .32979 Mdot
.666 .33015 Mdot
.666 .33216 Mdot
.666 .33347 Mdot
.666 .33399 Mdot
.666 .33468 Mdot
.666 .33583 Mdot
.666 .33641 Mdot
.666 .33642 Mdot
.666 .33647 Mdot
.666 .33682 Mdot
.666 .33697 Mdot
.666 .33708 Mdot
.666 .3376 Mdot
.666 .33907 Mdot
.666 .33933 Mdot
.666 .33943 Mdot
.666 .34138 Mdot
.666 .34182 Mdot
.666 .34341 Mdot
.666 .34343 Mdot
.666 .34348 Mdot
.666 .34451 Mdot
.666 .34464 Mdot
.666 .34482 Mdot
.666 .34566 Mdot
.666 .34567 Mdot
.666 .34773 Mdot
.666 .34799 Mdot
.666 .34806 Mdot
.666 .34817 Mdot
.666 .3485 Mdot
.666 .34991 Mdot
.666 .35011 Mdot
.666 .35042 Mdot
.666 .35047 Mdot
.666 .35058 Mdot
.666 .3507 Mdot
.666 .35113 Mdot
.666 .35247 Mdot
.666 .35298 Mdot
.666 .35301 Mdot
.666 .35303 Mdot
.666 .35308 Mdot
.666 .354 Mdot
.666 .354 Mdot
.666 .35433 Mdot
.666 .35517 Mdot
.666 .35618 Mdot
.666 .35619 Mdot
.666 .35681 Mdot
.666 .35741 Mdot
.666 .35767 Mdot
.666 .35768 Mdot
.666 .3578 Mdot
.666 .35786 Mdot
.666 .35789 Mdot
.666 .35818 Mdot
.666 .35859 Mdot
.666 .35884 Mdot
.666 .35915 Mdot
.666 .36016 Mdot
.666 .36018 Mdot
.666 .36023 Mdot
.666 .3607 Mdot
.666 .36092 Mdot
.666 .36186 Mdot
.666 .36205 Mdot
.666 .36244 Mdot
.666 .36316 Mdot
.666 .36387 Mdot
.666 .36471 Mdot
.666 .36616 Mdot
.666 .36717 Mdot
.666 .36827 Mdot
.666 .3701 Mdot
.666 .37156 Mdot
.666 .37185 Mdot
.666 .37192 Mdot
.666 .37239 Mdot
.666 .37264 Mdot
.666 .37297 Mdot
.666 .37486 Mdot
.666 .37654 Mdot
.666 .37675 Mdot
.666 .37698 Mdot
.666 .37698 Mdot
.666 .37727 Mdot
.666 .37771 Mdot
.666 .37797 Mdot
.666 .37853 Mdot
.666 .38037 Mdot
.666 .38086 Mdot
.666 .3824 Mdot
.666 .38288 Mdot
.666 .38306 Mdot
.666 .38425 Mdot
.666 .38426 Mdot
.666 .38517 Mdot
.666 .38543 Mdot
.666 .38583 Mdot
.666 .38859 Mdot
.666 .38933 Mdot
.666 .38958 Mdot
.666 .38971 Mdot
.666 .38985 Mdot
.666 .39104 Mdot
.666 .39262 Mdot
.666 .39312 Mdot
.666 .39412 Mdot
.666 .39431 Mdot
.666 .39634 Mdot
.666 .39711 Mdot
.666 .3976 Mdot
.666 .39839 Mdot
.666 .39916 Mdot
.666 .39964 Mdot
.666 .39969 Mdot
.666 .39981 Mdot
.666 .40137 Mdot
.666 .40139 Mdot
.666 .40164 Mdot
.666 .40194 Mdot
.666 .40254 Mdot
.666 .40312 Mdot
.666 .40339 Mdot
.666 .4049 Mdot
.666 .40492 Mdot
.666 .40547 Mdot
.666 .40594 Mdot
.666 .40642 Mdot
.666 .40701 Mdot
.666 .40703 Mdot
.666 .40704 Mdot
.666 .40705 Mdot
.666 .40705 Mdot
.666 .40707 Mdot
.666 .40715 Mdot
.666 .40727 Mdot
.666 .40776 Mdot
.666 .40807 Mdot
.666 .40814 Mdot
.666 .40829 Mdot
.666 .40845 Mdot
.666 .4085 Mdot
.666 .40853 Mdot
.666 .40865 Mdot
.666 .40931 Mdot
.666 .40973 Mdot
.666 .41012 Mdot
.666 .41068 Mdot
.666 .41081 Mdot
.666 .41086 Mdot
.666 .4109 Mdot
.666 .41154 Mdot
.666 .41165 Mdot
.666 .41228 Mdot
.666 .41242 Mdot
.666 .41293 Mdot
.666 .41294 Mdot
.666 .41328 Mdot
.666 .41332 Mdot
.666 .41365 Mdot
.666 .41366 Mdot
.666 .4144 Mdot
.666 .41456 Mdot
.666 .41501 Mdot
.666 .41508 Mdot
.666 .41517 Mdot
.666 .41519 Mdot
.666 .41522 Mdot
.666 .41526 Mdot
.666 .4154 Mdot
.666 .41583 Mdot
.666 .41599 Mdot
.666 .41601 Mdot
.666 .41602 Mdot
.666 .41631 Mdot
.666 .41632 Mdot
.666 .41669 Mdot
.666 .41701 Mdot
.666 .41721 Mdot
.666 .4174 Mdot
.666 .41748 Mdot
.666 .41752 Mdot
.666 .41754 Mdot
.666 .41755 Mdot
.666 .41764 Mdot
.666 .41795 Mdot
.666 .41827 Mdot
.666 .41829 Mdot
.666 .41844 Mdot
.666 .41851 Mdot
.666 .41945 Mdot
.666 .42017 Mdot
.666 .42049 Mdot
.666 .42142 Mdot
.666 .42188 Mdot
.666 .42215 Mdot
.666 .42222 Mdot
.666 .42292 Mdot
.666 .42346 Mdot
.666 .42352 Mdot
.666 .42359 Mdot
.666 .42369 Mdot
.666 .42391 Mdot
.666 .42409 Mdot
.666 .42467 Mdot
.666 .42482 Mdot
.666 .42546 Mdot
.666 .42618 Mdot
.666 .42626 Mdot
.666 .42639 Mdot
.666 .42804 Mdot
.666 .4287 Mdot
.666 .42901 Mdot
.666 .42996 Mdot
.666 .43011 Mdot
.666 .43036 Mdot
.666 .43061 Mdot
.666 .43076 Mdot
.666 .43081 Mdot
.666 .43131 Mdot
.666 .43132 Mdot
.666 .4314 Mdot
.666 .43243 Mdot
.666 .43261 Mdot
.666 .43291 Mdot
.666 .43363 Mdot
.666 .43409 Mdot
.666 .43458 Mdot
.666 .43483 Mdot
.666 .43512 Mdot
.666 .43522 Mdot
.666 .43571 Mdot
.666 .43574 Mdot
.666 .43592 Mdot
.666 .43597 Mdot
.666 .43598 Mdot
.666 .43598 Mdot
.666 .43607 Mdot
.666 .43608 Mdot
.666 .43671 Mdot
.666 .43678 Mdot
.666 .43708 Mdot
.666 .43731 Mdot
.666 .43837 Mdot
.666 .43842 Mdot
.666 .43881 Mdot
.666 .44007 Mdot
.666 .44128 Mdot
.666 .44144 Mdot
.666 .44199 Mdot
.666 .4422 Mdot
.666 .44237 Mdot
.666 .44248 Mdot
.666 .44325 Mdot
.666 .44419 Mdot
.666 .44455 Mdot
.666 .44646 Mdot
.666 .44745 Mdot
.666 .44751 Mdot
.666 .44812 Mdot
.666 .44952 Mdot
.666 .44974 Mdot
.666 .45069 Mdot
.666 .45104 Mdot
.666 .4511 Mdot
.666 .45113 Mdot
.666 .45123 Mdot
.666 .45124 Mdot
.666 .45152 Mdot
.666 .45157 Mdot
.666 .45187 Mdot
.666 .4524 Mdot
.666 .45279 Mdot
.666 .45305 Mdot
.666 .45366 Mdot
.666 .45394 Mdot
.666 .45396 Mdot
.666 .45405 Mdot
.666 .4544 Mdot
.666 .45491 Mdot
.666 .45508 Mdot
.666 .45639 Mdot
.666 .45643 Mdot
.666 .45716 Mdot
.666 .45781 Mdot
.666 .45788 Mdot
.666 .45896 Mdot
.666 .45961 Mdot
.666 .45999 Mdot
.666 .46048 Mdot
.666 .46059 Mdot
.666 .46143 Mdot
.666 .46162 Mdot
.666 .46162 Mdot
.666 .46177 Mdot
.666 .46178 Mdot
.666 .46179 Mdot
.666 .46187 Mdot
.666 .46209 Mdot
.666 .46216 Mdot
.666 .4622 Mdot
.666 .46226 Mdot
.666 .46229 Mdot
.666 .46252 Mdot
.666 .46299 Mdot
.666 .46316 Mdot
.666 .46336 Mdot
.666 .46362 Mdot
.666 .46401 Mdot
.666 .4645 Mdot
.666 .46479 Mdot
.666 .46553 Mdot
.666 .46628 Mdot
.666 .46665 Mdot
.666 .46689 Mdot
.666 .46712 Mdot
.666 .4674 Mdot
.666 .46741 Mdot
.666 .46816 Mdot
.666 .46829 Mdot
.666 .46858 Mdot
.666 .46887 Mdot
.666 .46902 Mdot
.666 .46914 Mdot
.666 .46915 Mdot
.666 .46992 Mdot
.666 .46998 Mdot
.666 .47001 Mdot
.666 .47024 Mdot
.666 .47061 Mdot
.666 .471 Mdot
.666 .47124 Mdot
.666 .47161 Mdot
.666 .47259 Mdot
.666 .47269 Mdot
.666 .47317 Mdot
.666 .47341 Mdot
.666 .47416 Mdot
.666 .47473 Mdot
.666 .4748 Mdot
.666 .47486 Mdot
.666 .47498 Mdot
.666 .47533 Mdot
.666 .47663 Mdot
.666 .47682 Mdot
.666 .47694 Mdot
.666 .47737 Mdot
.666 .47737 Mdot
.666 .47793 Mdot
.666 .47801 Mdot
.666 .47824 Mdot
.666 .47895 Mdot
.666 .47918 Mdot
.666 .48003 Mdot
.666 .48029 Mdot
.666 .48041 Mdot
.666 .48061 Mdot
.666 .48074 Mdot
.666 .48075 Mdot
.666 .48085 Mdot
.666 .48095 Mdot
.666 .48172 Mdot
.666 .48258 Mdot
.666 .48272 Mdot
.666 .48284 Mdot
.666 .48305 Mdot
.666 .48308 Mdot
.666 .48321 Mdot
.666 .48387 Mdot
.666 .4847 Mdot
.666 .48519 Mdot
.666 .48564 Mdot
.666 .48629 Mdot
.666 .48666 Mdot
.666 .48698 Mdot
.666 .48729 Mdot
.666 .48747 Mdot
.666 .48755 Mdot
.666 .48797 Mdot
.666 .48806 Mdot
.666 .48827 Mdot
.666 .48829 Mdot
.666 .4883 Mdot
.666 .48874 Mdot
.666 .48888 Mdot
.666 .48899 Mdot
.666 .48917 Mdot
.666 .48929 Mdot
.666 .48931 Mdot
.666 .48934 Mdot
.666 .48939 Mdot
.666 .48939 Mdot
.666 .4895 Mdot
.666 .48977 Mdot
.666 .49004 Mdot
.666 .49004 Mdot
.666 .49048 Mdot
.666 .49084 Mdot
.666 .49099 Mdot
.666 .49099 Mdot
.666 .49139 Mdot
.666 .49141 Mdot
.666 .49142 Mdot
.666 .49143 Mdot
.666 .49165 Mdot
.666 .49223 Mdot
.666 .49241 Mdot
.666 .49246 Mdot
.666 .49251 Mdot
.666 .49253 Mdot
.666 .49266 Mdot
.666 .49275 Mdot
.666 .49335 Mdot
.666 .4935 Mdot
.666 .49354 Mdot
.666 .49357 Mdot
.666 .49369 Mdot
.666 .49456 Mdot
.666 .49457 Mdot
.666 .49492 Mdot
.666 .495 Mdot
.666 .49505 Mdot
.666 .49549 Mdot
.666 .49551 Mdot
.666 .49552 Mdot
.666 .49619 Mdot
.666 .49638 Mdot
.666 .4972 Mdot
.666 .49724 Mdot
.666 .49734 Mdot
.666 .49796 Mdot
.666 .49818 Mdot
.666 .49822 Mdot
.666 .49829 Mdot
.666 .49843 Mdot
.666 .49845 Mdot
.666 .49845 Mdot
.666 .4987 Mdot
.666 .49917 Mdot
.666 .49946 Mdot
.666 .49968 Mdot
.666 .50022 Mdot
.666 .50104 Mdot
.666 .50119 Mdot
.666 .50124 Mdot
.666 .5013 Mdot
.666 .50134 Mdot
.666 .5015 Mdot
.666 .50168 Mdot
.666 .50171 Mdot
.666 .50178 Mdot
.666 .50217 Mdot
.666 .50277 Mdot
.666 .50283 Mdot
.666 .50293 Mdot
.666 .50302 Mdot
.666 .50305 Mdot
.666 .50306 Mdot
.666 .50306 Mdot
.666 .50307 Mdot
.666 .5031 Mdot
.666 .50316 Mdot
.666 .50384 Mdot
.666 .50443 Mdot
.666 .505 Mdot
.666 .50534 Mdot
.666 .50567 Mdot
.666 .50569 Mdot
.666 .50752 Mdot
.666 .50784 Mdot
.666 .50853 Mdot
.666 .50904 Mdot
.666 .50914 Mdot
.666 .50924 Mdot
.666 .50959 Mdot
.666 .50988 Mdot
.666 .50991 Mdot
.666 .5116 Mdot
.666 .51173 Mdot
.666 .51186 Mdot
.666 .51189 Mdot
.666 .51192 Mdot
.666 .51246 Mdot
.666 .51272 Mdot
.666 .51334 Mdot
.666 .51424 Mdot
.666 .51437 Mdot
.666 .51479 Mdot
.666 .51505 Mdot
.666 .51565 Mdot
.666 .51786 Mdot
.666 .51807 Mdot
.666 .51888 Mdot
.666 .51914 Mdot
.666 .51967 Mdot
.666 .52078 Mdot
.666 .52134 Mdot
.666 .52156 Mdot
.666 .52238 Mdot
.666 .52257 Mdot
.666 .52271 Mdot
.666 .52284 Mdot
.666 .52308 Mdot
.666 .52309 Mdot
.666 .52323 Mdot
.666 .52385 Mdot
.666 .52434 Mdot
.666 .52493 Mdot
.666 .52569 Mdot
.666 .52583 Mdot
.666 .52622 Mdot
.666 .52658 Mdot
.666 .52697 Mdot
.666 .52723 Mdot
.666 .52809 Mdot
.666 .52811 Mdot
.666 .52844 Mdot
.666 .52924 Mdot
.666 .5294 Mdot
.666 .52944 Mdot
.666 .52985 Mdot
.666 .53 Mdot
.666 .53088 Mdot
.666 .53127 Mdot
.666 .53138 Mdot
.666 .53171 Mdot
.666 .53254 Mdot
.666 .53266 Mdot
.666 .53329 Mdot
.666 .53335 Mdot
.666 .53369 Mdot
.666 .53385 Mdot
.666 .53408 Mdot
.666 .53415 Mdot
.666 .53434 Mdot
.666 .53436 Mdot
.666 .53446 Mdot
.666 .53463 Mdot
.666 .53463 Mdot
.666 .53471 Mdot
.666 .53471 Mdot
.666 .53482 Mdot
.666 .53483 Mdot
.666 .5349 Mdot
.666 .53509 Mdot
.666 .53524 Mdot
.666 .5355 Mdot
.666 .53554 Mdot
.666 .53599 Mdot
.666 .53618 Mdot
.666 .53651 Mdot
.666 .53672 Mdot
.666 .53708 Mdot
.666 .53788 Mdot
.666 .53801 Mdot
.666 .53806 Mdot
.666 .53833 Mdot
.666 .53853 Mdot
.666 .53891 Mdot
.666 .53896 Mdot
.666 .53919 Mdot
.666 .53947 Mdot
.666 .53972 Mdot
.666 .54033 Mdot
.666 .54152 Mdot
.666 .54173 Mdot
.666 .54223 Mdot
.666 .54247 Mdot
.666 .54256 Mdot
.666 .54327 Mdot
.666 .54329 Mdot
.666 .54433 Mdot
.666 .54492 Mdot
.666 .54501 Mdot
.666 .54531 Mdot
.666 .54541 Mdot
.666 .5459 Mdot
.666 .5461 Mdot
.666 .54616 Mdot
.666 .54617 Mdot
.666 .54629 Mdot
.666 .54647 Mdot
.666 .54692 Mdot
.666 .54706 Mdot
.666 .54737 Mdot
.666 .5474 Mdot
.666 .54741 Mdot
.666 .54792 Mdot
.666 .54806 Mdot
.666 .54826 Mdot
.666 .54841 Mdot
.666 .54851 Mdot
.666 .54853 Mdot
.666 .54867 Mdot
.666 .54885 Mdot
.666 .54887 Mdot
.666 .54891 Mdot
.666 .54898 Mdot
.666 .54899 Mdot
.666 .54915 Mdot
.666 .54952 Mdot
.666 .54989 Mdot
.666 .54989 Mdot
.666 .55 Mdot
.666 .55042 Mdot
.666 .55049 Mdot
.666 .55098 Mdot
.666 .55104 Mdot
.666 .55117 Mdot
.666 .55117 Mdot
.666 .55161 Mdot
.666 .55169 Mdot
.666 .55171 Mdot
.666 .55173 Mdot
.666 .55174 Mdot
.666 .55203 Mdot
.666 .5522 Mdot
.666 .55241 Mdot
.666 .55275 Mdot
.666 .55298 Mdot
.666 .55304 Mdot
.666 .5531 Mdot
.666 .55313 Mdot
.666 .55329 Mdot
.666 .55339 Mdot
.666 .55352 Mdot
.666 .55411 Mdot
.666 .55428 Mdot
.666 .55433 Mdot
.666 .55433 Mdot
.666 .55437 Mdot
.666 .5545 Mdot
.666 .55499 Mdot
.666 .55548 Mdot
.666 .55549 Mdot
.666 .55577 Mdot
.666 .55587 Mdot
.666 .55594 Mdot
.666 .55595 Mdot
.666 .55596 Mdot
.666 .55601 Mdot
.666 .55625 Mdot
.666 .55641 Mdot
.666 .55647 Mdot
.666 .55649 Mdot
.666 .5565 Mdot
.666 .55657 Mdot
.666 .55679 Mdot
.666 .55718 Mdot
.666 .55736 Mdot
.666 .55771 Mdot
.666 .55795 Mdot
.666 .55814 Mdot
.666 .55817 Mdot
.666 .55827 Mdot
.666 .55852 Mdot
.666 .55882 Mdot
.666 .559 Mdot
.666 .55905 Mdot
.666 .5591 Mdot
.666 .55922 Mdot
.666 .55924 Mdot
.666 .55924 Mdot
.666 .55944 Mdot
.666 .55957 Mdot
.666 .55982 Mdot
.666 .56003 Mdot
.666 .56005 Mdot
.666 .56021 Mdot
.666 .56025 Mdot
.666 .5606 Mdot
.666 .56088 Mdot
.666 .56104 Mdot
.666 .56117 Mdot
.666 .56126 Mdot
.666 .56129 Mdot
.666 .56133 Mdot
.666 .56136 Mdot
.666 .56146 Mdot
.666 .56157 Mdot
.666 .56158 Mdot
.666 .56163 Mdot
.666 .56186 Mdot
.666 .56219 Mdot
.666 .56222 Mdot
.666 .56227 Mdot
.666 .56232 Mdot
.666 .56233 Mdot
.666 .56233 Mdot
.666 .56234 Mdot
.666 .56234 Mdot
.666 .56236 Mdot
.666 .56239 Mdot
.666 .56242 Mdot
.666 .56271 Mdot
.666 .56272 Mdot
.666 .56284 Mdot
.666 .56296 Mdot
.666 .56302 Mdot
.666 .56307 Mdot
.666 .56318 Mdot
.666 .56329 Mdot
.666 .56339 Mdot
.666 .5634 Mdot
.666 .56341 Mdot
.666 .56358 Mdot
.666 .56364 Mdot
.666 .56376 Mdot
.666 .56377 Mdot
.666 .56378 Mdot
.666 .5638 Mdot
.666 .56382 Mdot
.666 .56384 Mdot
.666 .56388 Mdot
.666 .56396 Mdot
.666 .56399 Mdot
.666 .56399 Mdot
.666 .56399 Mdot
.666 .564 Mdot
.666 .564 Mdot
.666 .564 Mdot
.668 .15098 Mdot
.668 .15098 Mdot
.668 .15098 Mdot
.668 .15099 Mdot
.668 .151 Mdot
.668 .15105 Mdot
.668 .15109 Mdot
.668 .1511 Mdot
.668 .15112 Mdot
.668 .15129 Mdot
.668 .15165 Mdot
.668 .15216 Mdot
.668 .15219 Mdot
.668 .15225 Mdot
.668 .15245 Mdot
.668 .15247 Mdot
.668 .15258 Mdot
.668 .15277 Mdot
.668 .15289 Mdot
.668 .15389 Mdot
.668 .1539 Mdot
.668 .15391 Mdot
.668 .15392 Mdot
.668 .15397 Mdot
.668 .15408 Mdot
.668 .1541 Mdot
.668 .15423 Mdot
.668 .15427 Mdot
.668 .15427 Mdot
.668 .15433 Mdot
.668 .1547 Mdot
.668 .15489 Mdot
.668 .1551 Mdot
.668 .15541 Mdot
.668 .1562 Mdot
.668 .15625 Mdot
.668 .15628 Mdot
.668 .1567 Mdot
.668 .15758 Mdot
.668 .15758 Mdot
.668 .15851 Mdot
.668 .15864 Mdot
.668 .15895 Mdot
.668 .1591 Mdot
.668 .15912 Mdot
.668 .15992 Mdot
.668 .15993 Mdot
.668 .16001 Mdot
.668 .16006 Mdot
.668 .16029 Mdot
.668 .16042 Mdot
.668 .16051 Mdot
.668 .16061 Mdot
.668 .16065 Mdot
.668 .16078 Mdot
.668 .16172 Mdot
.668 .16238 Mdot
.668 .16253 Mdot
.668 .16389 Mdot
.668 .16406 Mdot
.668 .16446 Mdot
.668 .1649 Mdot
.668 .16516 Mdot
.668 .16542 Mdot
.668 .16637 Mdot
.668 .16757 Mdot
.668 .1678 Mdot
.668 .168 Mdot
.668 .16856 Mdot
.668 .16877 Mdot
.668 .16907 Mdot
.668 .16915 Mdot
.668 .16924 Mdot
.668 .16926 Mdot
.668 .16959 Mdot
.668 .16966 Mdot
.668 .17023 Mdot
.668 .17033 Mdot
.668 .17039 Mdot
.668 .1706 Mdot
.668 .17128 Mdot
.668 .17158 Mdot
.668 .17184 Mdot
.668 .17189 Mdot
.668 .17239 Mdot
.668 .17326 Mdot
.668 .17358 Mdot
.668 .17361 Mdot
.668 .1741 Mdot
.668 .17453 Mdot
.668 .17481 Mdot
.668 .17482 Mdot
.668 .17543 Mdot
.668 .1756 Mdot
.668 .17625 Mdot
.668 .17699 Mdot
.668 .17707 Mdot
.668 .17844 Mdot
.668 .1786 Mdot
.668 .17892 Mdot
.668 .17947 Mdot
.668 .18176 Mdot
.668 .18268 Mdot
.668 .18331 Mdot
.668 .18336 Mdot
.668 .18422 Mdot
.668 .18496 Mdot
.668 .18734 Mdot
.668 .1896 Mdot
.668 .18986 Mdot
.668 .19019 Mdot
.668 .19043 Mdot
.668 .19054 Mdot
.668 .19119 Mdot
.668 .19136 Mdot
.668 .19147 Mdot
.668 .19327 Mdot
.668 .19389 Mdot
.668 .1949 Mdot
.668 .19506 Mdot
.668 .19514 Mdot
.668 .19723 Mdot
.668 .19766 Mdot
.668 .19773 Mdot
.668 .19801 Mdot
.668 .20318 Mdot
.668 .2053 Mdot
.668 .20531 Mdot
.668 .20659 Mdot
.668 .2072 Mdot
.668 .20919 Mdot
.668 .21029 Mdot
.668 .21152 Mdot
.668 .21301 Mdot
.668 .2131 Mdot
.668 .21365 Mdot
.668 .21558 Mdot
.668 .21605 Mdot
.668 .21641 Mdot
.668 .21698 Mdot
.668 .21709 Mdot
.668 .21876 Mdot
.668 .21905 Mdot
.668 .22035 Mdot
.668 .22161 Mdot
.668 .22165 Mdot
.668 .22187 Mdot
.668 .22298 Mdot
.668 .22352 Mdot
.668 .22486 Mdot
.668 .225 Mdot
.668 .22531 Mdot
.668 .22607 Mdot
.668 .22636 Mdot
.668 .22763 Mdot
.668 .22805 Mdot
.668 .22842 Mdot
.668 .22998 Mdot
.668 .23014 Mdot
.668 .23264 Mdot
.668 .23269 Mdot
.668 .23311 Mdot
.668 .23321 Mdot
.668 .23428 Mdot
.668 .23493 Mdot
.668 .23613 Mdot
.668 .23672 Mdot
.668 .23683 Mdot
.668 .23764 Mdot
.668 .23797 Mdot
.668 .23841 Mdot
.668 .23874 Mdot
.668 .24188 Mdot
.668 .24219 Mdot
.668 .24402 Mdot
.668 .24406 Mdot
.668 .24538 Mdot
.668 .24621 Mdot
.668 .24639 Mdot
.668 .24694 Mdot
.668 .24707 Mdot
.668 .24759 Mdot
.668 .24818 Mdot
.668 .24901 Mdot
.668 .24903 Mdot
.668 .24959 Mdot
.668 .25112 Mdot
.668 .25138 Mdot
.668 .25292 Mdot
.668 .25367 Mdot
.668 .25479 Mdot
.668 .25576 Mdot
.668 .25606 Mdot
.668 .25777 Mdot
.668 .2606 Mdot
.668 .26087 Mdot
.668 .262 Mdot
.668 .26213 Mdot
.668 .26406 Mdot
.668 .26411 Mdot
.668 .26421 Mdot
.668 .26459 Mdot
.668 .26498 Mdot
.668 .26646 Mdot
.668 .26837 Mdot
.668 .26892 Mdot
.668 .26935 Mdot
.668 .27214 Mdot
.668 .27314 Mdot
.668 .27366 Mdot
.668 .2747 Mdot
.668 .27491 Mdot
.668 .27523 Mdot
.668 .27585 Mdot
.668 .27738 Mdot
.668 .27814 Mdot
.668 .27902 Mdot
.668 .27942 Mdot
.668 .28026 Mdot
.668 .28045 Mdot
.668 .28239 Mdot
.668 .28287 Mdot
.668 .2833 Mdot
.668 .28368 Mdot
.668 .28384 Mdot
.668 .2873 Mdot
.668 .28752 Mdot
.668 .28809 Mdot
.668 .28906 Mdot
.668 .28908 Mdot
.668 .29229 Mdot
.668 .29293 Mdot
.668 .29305 Mdot
.668 .29634 Mdot
.668 .29672 Mdot
.668 .30048 Mdot
.668 .30055 Mdot
.668 .30112 Mdot
.668 .30141 Mdot
.668 .30328 Mdot
.668 .30512 Mdot
.668 .30637 Mdot
.668 .30658 Mdot
.668 .30669 Mdot
.668 .30826 Mdot
.668 .3084 Mdot
.668 .3089 Mdot
.668 .30947 Mdot
.668 .31017 Mdot
.668 .31088 Mdot
.668 .31671 Mdot
.668 .31787 Mdot
.668 .31838 Mdot
.668 .31867 Mdot
.668 .32094 Mdot
.668 .32096 Mdot
.668 .32098 Mdot
.668 .32101 Mdot
.668 .3211 Mdot
.668 .32137 Mdot
.668 .32162 Mdot
.668 .32168 Mdot
.668 .32182 Mdot
.668 .3225 Mdot
.668 .32285 Mdot
.668 .32321 Mdot
.668 .32373 Mdot
.668 .32507 Mdot
.668 .32699 Mdot
.668 .32699 Mdot
.668 .32821 Mdot
.668 .32837 Mdot
.668 .32877 Mdot
.668 .32995 Mdot
.668 .33004 Mdot
.668 .3301 Mdot
.668 .33037 Mdot
.668 .33062 Mdot
.668 .33078 Mdot
.668 .33093 Mdot
.668 .33196 Mdot
.668 .33265 Mdot
.668 .33281 Mdot
.668 .33541 Mdot
.668 .33652 Mdot
.668 .33795 Mdot
.668 .33843 Mdot
.668 .33886 Mdot
.668 .33893 Mdot
.668 .339 Mdot
.668 .33929 Mdot
.668 .33934 Mdot
.668 .33981 Mdot
.668 .33994 Mdot
.668 .34011 Mdot
.668 .34089 Mdot
.668 .34109 Mdot
.668 .34113 Mdot
.668 .34152 Mdot
.668 .34242 Mdot
.668 .34244 Mdot
.668 .34333 Mdot
.668 .34378 Mdot
.668 .3439 Mdot
.668 .34495 Mdot
.668 .346 Mdot
.668 .34621 Mdot
.668 .34659 Mdot
.668 .3481 Mdot
.668 .34909 Mdot
.668 .35012 Mdot
.668 .3529 Mdot
.668 .35324 Mdot
.668 .35338 Mdot
.668 .355 Mdot
.668 .35534 Mdot
.668 .35599 Mdot
.668 .35758 Mdot
.668 .36133 Mdot
.668 .36134 Mdot
.668 .36377 Mdot
.668 .36507 Mdot
.668 .36537 Mdot
.668 .36627 Mdot
.668 .36649 Mdot
.668 .36696 Mdot
.668 .36772 Mdot
.668 .36786 Mdot
.668 .36912 Mdot
.668 .36961 Mdot
.668 .3705 Mdot
.668 .37064 Mdot
.668 .37198 Mdot
.668 .37272 Mdot
.668 .37377 Mdot
.668 .37379 Mdot
.668 .37446 Mdot
.668 .37473 Mdot
.668 .37522 Mdot
.668 .37547 Mdot
.668 .37551 Mdot
.668 .37598 Mdot
.668 .37629 Mdot
.668 .37756 Mdot
.668 .37769 Mdot
.668 .37842 Mdot
.668 .37844 Mdot
.668 .37896 Mdot
.668 .37936 Mdot
.668 .37958 Mdot
.668 .37983 Mdot
.668 .38039 Mdot
.668 .38061 Mdot
.668 .38219 Mdot
.668 .38262 Mdot
.668 .38299 Mdot
.668 .3861 Mdot
.668 .38613 Mdot
.668 .38616 Mdot
.668 .3863 Mdot
.668 .38645 Mdot
.668 .38699 Mdot
.668 .38769 Mdot
.668 .38906 Mdot
.668 .38942 Mdot
.668 .39006 Mdot
.668 .39017 Mdot
.668 .39095 Mdot
.668 .39122 Mdot
.668 .39153 Mdot
.668 .39204 Mdot
.668 .39289 Mdot
.668 .39323 Mdot
.668 .39444 Mdot
.668 .39471 Mdot
.668 .39505 Mdot
.668 .39755 Mdot
.668 .39896 Mdot
.668 .39918 Mdot
.668 .39991 Mdot
.668 .40052 Mdot
.668 .40101 Mdot
.668 .40158 Mdot
.668 .40179 Mdot
.668 .40222 Mdot
.668 .40476 Mdot
.668 .40577 Mdot
.668 .40578 Mdot
.668 .40579 Mdot
.668 .40579 Mdot
.668 .40583 Mdot
.668 .40591 Mdot
.668 .40599 Mdot
.668 .40602 Mdot
.668 .40606 Mdot
.668 .40628 Mdot
.668 .40639 Mdot
.668 .40668 Mdot
.668 .40712 Mdot
.668 .40775 Mdot
.668 .40814 Mdot
.668 .4082 Mdot
.668 .40832 Mdot
.668 .40871 Mdot
.668 .40874 Mdot
.668 .40876 Mdot
.668 .40892 Mdot
.668 .40898 Mdot
.668 .40903 Mdot
.668 .40936 Mdot
.668 .40958 Mdot
.668 .40963 Mdot
.668 .41047 Mdot
.668 .41129 Mdot
.668 .41158 Mdot
.668 .4116 Mdot
.668 .41163 Mdot
.668 .41172 Mdot
.668 .41174 Mdot
.668 .41189 Mdot
.668 .41193 Mdot
.668 .41198 Mdot
.668 .41223 Mdot
.668 .4123 Mdot
.668 .41231 Mdot
.668 .41244 Mdot
.668 .41302 Mdot
.668 .41316 Mdot
.668 .4132 Mdot
.668 .41353 Mdot
.668 .41387 Mdot
.668 .41394 Mdot
.668 .41406 Mdot
.668 .41454 Mdot
.668 .41518 Mdot
.668 .41607 Mdot
.668 .41618 Mdot
.668 .41622 Mdot
.668 .41673 Mdot
.668 .41684 Mdot
.668 .41705 Mdot
.668 .41755 Mdot
.668 .41874 Mdot
.668 .41874 Mdot
.668 .41952 Mdot
.668 .41992 Mdot
.668 .42052 Mdot
.668 .42076 Mdot
.668 .4212 Mdot
.668 .42136 Mdot
.668 .42164 Mdot
.668 .42168 Mdot
.668 .42211 Mdot
.668 .42234 Mdot
.668 .42267 Mdot
.668 .42268 Mdot
.668 .42321 Mdot
.668 .42322 Mdot
.668 .42337 Mdot
.668 .42347 Mdot
.668 .42387 Mdot
.668 .42391 Mdot
.668 .42414 Mdot
.668 .42431 Mdot
.668 .42443 Mdot
.668 .4245 Mdot
.668 .42458 Mdot
.668 .42483 Mdot
.668 .42533 Mdot
.668 .42546 Mdot
.668 .42558 Mdot
.668 .42656 Mdot
.668 .42658 Mdot
.668 .42662 Mdot
.668 .42706 Mdot
.668 .42781 Mdot
.668 .42809 Mdot
.668 .42827 Mdot
.668 .4287 Mdot
.668 .42881 Mdot
.668 .42919 Mdot
.668 .42928 Mdot
.668 .42938 Mdot
.668 .43017 Mdot
.668 .43062 Mdot
.668 .43092 Mdot
.668 .43112 Mdot
.668 .43127 Mdot
.668 .43145 Mdot
.668 .43152 Mdot
.668 .43165 Mdot
.668 .43246 Mdot
.668 .43294 Mdot
.668 .43341 Mdot
.668 .43372 Mdot
.668 .43378 Mdot
.668 .43401 Mdot
.668 .43427 Mdot
.668 .43453 Mdot
.668 .43508 Mdot
.668 .43514 Mdot
.668 .43542 Mdot
.668 .43578 Mdot
.668 .43631 Mdot
.668 .43654 Mdot
.668 .43716 Mdot
.668 .4373 Mdot
.668 .43771 Mdot
.668 .438 Mdot
.668 .43807 Mdot
.668 .43818 Mdot
.668 .43818 Mdot
.668 .43875 Mdot
.668 .43903 Mdot
.668 .43908 Mdot
.668 .43945 Mdot
.668 .43999 Mdot
.668 .44013 Mdot
.668 .44016 Mdot
.668 .44028 Mdot
.668 .44031 Mdot
.668 .44035 Mdot
.668 .4406 Mdot
.668 .44091 Mdot
.668 .44102 Mdot
.668 .44176 Mdot
.668 .44185 Mdot
.668 .44194 Mdot
.668 .44202 Mdot
.668 .4422 Mdot
.668 .44231 Mdot
.668 .44268 Mdot
.668 .44288 Mdot
.668 .44316 Mdot
.668 .4434 Mdot
.668 .44387 Mdot
.668 .44401 Mdot
.668 .4444 Mdot
.668 .44486 Mdot
.668 .44494 Mdot
.668 .44514 Mdot
.668 .44552 Mdot
.668 .44581 Mdot
.668 .44602 Mdot
.668 .44667 Mdot
.668 .44702 Mdot
.668 .44716 Mdot
.668 .44732 Mdot
.668 .44786 Mdot
.668 .4479 Mdot
.668 .44796 Mdot
.668 .44861 Mdot
.668 .44876 Mdot
.668 .44886 Mdot
.668 .44949 Mdot
.668 .44966 Mdot
.668 .44997 Mdot
.668 .44997 Mdot
.668 .45007 Mdot
.668 .45054 Mdot
.668 .45089 Mdot
.668 .45102 Mdot
.668 .45131 Mdot
.668 .45151 Mdot
.668 .45169 Mdot
.668 .452 Mdot
.668 .45214 Mdot
.668 .45229 Mdot
.668 .45241 Mdot
.668 .45244 Mdot
.668 .45365 Mdot
.668 .45369 Mdot
.668 .45378 Mdot
.668 .45387 Mdot
.668 .45438 Mdot
.668 .45481 Mdot
.668 .45487 Mdot
.668 .45491 Mdot
.668 .45512 Mdot
.668 .45518 Mdot
.668 .45541 Mdot
.668 .45606 Mdot
.668 .45629 Mdot
.668 .45633 Mdot
.668 .45685 Mdot
.668 .45691 Mdot
.668 .45698 Mdot
.668 .45746 Mdot
.668 .45776 Mdot
.668 .45839 Mdot
.668 .45839 Mdot
.668 .45857 Mdot
.668 .45869 Mdot
.668 .45916 Mdot
.668 .45983 Mdot
.668 .46005 Mdot
.668 .46107 Mdot
.668 .46144 Mdot
.668 .46149 Mdot
.668 .46229 Mdot
.668 .46287 Mdot
.668 .46297 Mdot
.668 .46331 Mdot
.668 .4634 Mdot
.668 .46398 Mdot
.668 .46405 Mdot
.668 .46428 Mdot
.668 .46469 Mdot
.668 .46512 Mdot
.668 .46543 Mdot
.668 .46548 Mdot
.668 .46557 Mdot
.668 .46607 Mdot
.668 .4666 Mdot
.668 .4668 Mdot
.668 .46756 Mdot
.668 .46882 Mdot
.668 .46903 Mdot
.668 .46913 Mdot
.668 .46941 Mdot
.668 .46965 Mdot
.668 .46995 Mdot
.668 .47031 Mdot
.668 .47042 Mdot
.668 .4711 Mdot
.668 .47232 Mdot
.668 .47248 Mdot
.668 .47261 Mdot
.668 .47319 Mdot
.668 .47335 Mdot
.668 .47376 Mdot
.668 .47401 Mdot
.668 .47416 Mdot
.668 .47428 Mdot
.668 .47465 Mdot
.668 .47471 Mdot
.668 .47501 Mdot
.668 .47518 Mdot
.668 .47583 Mdot
.668 .47616 Mdot
.668 .47642 Mdot
.668 .47648 Mdot
.668 .47655 Mdot
.668 .47657 Mdot
.668 .47658 Mdot
.668 .47804 Mdot
.668 .47821 Mdot
.668 .47841 Mdot
.668 .47914 Mdot
.668 .47924 Mdot
.668 .4795 Mdot
.668 .47962 Mdot
.668 .47972 Mdot
.668 .4799 Mdot
.668 .48015 Mdot
.668 .48015 Mdot
.668 .48049 Mdot
.668 .48055 Mdot
.668 .48113 Mdot
.668 .48127 Mdot
.668 .48149 Mdot
.668 .48151 Mdot
.668 .48162 Mdot
.668 .48185 Mdot
.668 .48197 Mdot
.668 .48227 Mdot
.668 .48228 Mdot
.668 .48276 Mdot
.668 .48309 Mdot
.668 .4837 Mdot
.668 .48376 Mdot
.668 .48416 Mdot
.668 .48438 Mdot
.668 .48495 Mdot
.668 .48501 Mdot
.668 .48535 Mdot
.668 .48556 Mdot
.668 .48566 Mdot
.668 .48606 Mdot
.668 .4862 Mdot
.668 .48677 Mdot
.668 .48785 Mdot
.668 .48785 Mdot
.668 .48949 Mdot
.668 .49019 Mdot
.668 .49047 Mdot
.668 .49062 Mdot
.668 .49132 Mdot
.668 .49138 Mdot
.668 .49153 Mdot
.668 .49272 Mdot
.668 .49317 Mdot
.668 .49359 Mdot
.668 .49423 Mdot
.668 .49439 Mdot
.668 .49448 Mdot
.668 .49493 Mdot
.668 .49537 Mdot
.668 .49542 Mdot
.668 .49561 Mdot
.668 .49599 Mdot
.668 .496 Mdot
.668 .49638 Mdot
.668 .49654 Mdot
.668 .49656 Mdot
.668 .49664 Mdot
.668 .49697 Mdot
.668 .49704 Mdot
.668 .4971 Mdot
.668 .49729 Mdot
.668 .49731 Mdot
.668 .49743 Mdot
.668 .49746 Mdot
.668 .49749 Mdot
.668 .49767 Mdot
.668 .49787 Mdot
.668 .49847 Mdot
.668 .49893 Mdot
.668 .5 Mdot
.668 .50007 Mdot
.668 .50036 Mdot
.668 .50078 Mdot
.668 .50084 Mdot
.668 .50091 Mdot
.668 .50101 Mdot
.668 .50112 Mdot
.668 .50114 Mdot
.668 .50118 Mdot
.668 .50167 Mdot
.668 .50183 Mdot
.668 .50189 Mdot
.668 .50239 Mdot
.668 .50239 Mdot
.668 .50317 Mdot
.668 .50372 Mdot
.668 .50393 Mdot
.668 .50407 Mdot
.668 .50421 Mdot
.668 .50449 Mdot
.668 .50454 Mdot
.668 .50457 Mdot
.668 .50467 Mdot
.668 .50478 Mdot
.668 .50481 Mdot
.668 .50482 Mdot
.668 .50483 Mdot
.668 .50484 Mdot
.668 .50575 Mdot
.668 .50587 Mdot
.668 .50607 Mdot
.668 .50654 Mdot
.668 .50885 Mdot
.668 .50913 Mdot
.668 .50941 Mdot
.668 .50963 Mdot
.668 .50982 Mdot
.668 .50988 Mdot
.668 .5105 Mdot
.668 .51054 Mdot
.668 .51062 Mdot
.668 .51111 Mdot
.668 .51182 Mdot
.668 .51255 Mdot
.668 .51266 Mdot
.668 .51288 Mdot
.668 .51291 Mdot
.668 .51436 Mdot
.668 .5145 Mdot
.668 .51576 Mdot
.668 .51581 Mdot
.668 .51605 Mdot
.668 .51727 Mdot
.668 .51728 Mdot
.668 .51764 Mdot
.668 .51786 Mdot
.668 .51794 Mdot
.668 .51924 Mdot
.668 .5193 Mdot
.668 .51945 Mdot
.668 .5196 Mdot
.668 .51979 Mdot
.668 .52051 Mdot
.668 .52058 Mdot
.668 .52089 Mdot
.668 .52104 Mdot
.668 .52137 Mdot
.668 .52165 Mdot
.668 .52222 Mdot
.668 .52245 Mdot
.668 .52257 Mdot
.668 .52264 Mdot
.668 .52302 Mdot
.668 .52322 Mdot
.668 .52358 Mdot
.668 .52461 Mdot
.668 .52477 Mdot
.668 .52496 Mdot
.668 .52566 Mdot
.668 .5262 Mdot
.668 .52634 Mdot
.668 .52648 Mdot
.668 .52651 Mdot
.668 .52653 Mdot
.668 .52723 Mdot
.668 .52728 Mdot
.668 .52768 Mdot
.668 .52778 Mdot
.668 .5288 Mdot
.668 .52941 Mdot
.668 .52952 Mdot
.668 .52987 Mdot
.668 .53026 Mdot
.668 .53053 Mdot
.668 .53108 Mdot
.668 .53117 Mdot
.668 .53171 Mdot
.668 .53191 Mdot
.668 .53192 Mdot
.668 .53221 Mdot
.668 .53242 Mdot
.668 .5326 Mdot
.668 .53265 Mdot
.668 .53284 Mdot
.668 .53291 Mdot
.668 .5332 Mdot
.668 .53366 Mdot
.668 .53367 Mdot
.668 .53432 Mdot
.668 .53443 Mdot
.668 .53552 Mdot
.668 .53564 Mdot
.668 .53579 Mdot
.668 .5359 Mdot
.668 .53618 Mdot
.668 .53622 Mdot
.668 .53643 Mdot
.668 .53684 Mdot
.668 .53707 Mdot
.668 .53743 Mdot
.668 .53747 Mdot
.668 .53761 Mdot
.668 .53763 Mdot
.668 .53849 Mdot
.668 .53855 Mdot
.668 .53908 Mdot
.668 .53921 Mdot
.668 .53935 Mdot
.668 .53979 Mdot
.668 .53989 Mdot
.668 .54014 Mdot
.668 .54025 Mdot
.668 .5403 Mdot
.668 .54075 Mdot
.668 .54094 Mdot
.668 .54132 Mdot
.668 .54139 Mdot
.668 .5414 Mdot
.668 .54183 Mdot
.668 .54227 Mdot
.668 .54237 Mdot
.668 .54293 Mdot
.668 .54297 Mdot
.668 .54316 Mdot
.668 .54328 Mdot
.668 .54344 Mdot
.668 .54409 Mdot
.668 .54427 Mdot
.668 .5443 Mdot
.668 .5448 Mdot
.668 .54521 Mdot
.668 .54558 Mdot
.668 .54624 Mdot
.668 .54644 Mdot
.668 .54687 Mdot
.668 .54687 Mdot
.668 .54757 Mdot
.668 .54927 Mdot
.668 .54937 Mdot
.668 .54939 Mdot
.668 .54953 Mdot
.668 .55021 Mdot
.668 .55024 Mdot
.668 .55029 Mdot
.668 .55062 Mdot
.668 .55082 Mdot
.668 .55141 Mdot
.668 .55144 Mdot
.668 .5515 Mdot
.668 .55171 Mdot
.668 .55175 Mdot
.668 .55183 Mdot
.668 .55193 Mdot
.668 .55202 Mdot
.668 .55275 Mdot
.668 .55352 Mdot
.668 .55376 Mdot
.668 .55403 Mdot
.668 .55405 Mdot
.668 .55425 Mdot
.668 .55455 Mdot
.668 .55528 Mdot
.668 .55546 Mdot
.668 .55556 Mdot
.668 .55561 Mdot
.668 .55605 Mdot
.668 .55607 Mdot
.668 .55631 Mdot
.668 .55651 Mdot
.668 .55657 Mdot
.668 .55676 Mdot
.668 .55677 Mdot
.668 .55685 Mdot
.668 .55699 Mdot
.668 .55715 Mdot
.668 .55716 Mdot
.668 .55726 Mdot
.668 .55753 Mdot
.668 .55769 Mdot
.668 .55771 Mdot
.668 .55779 Mdot
.668 .55789 Mdot
.668 .5581 Mdot
.668 .55817 Mdot
.668 .55819 Mdot
.668 .55822 Mdot
.668 .5584 Mdot
.668 .55842 Mdot
.668 .55853 Mdot
.668 .55853 Mdot
.668 .55856 Mdot
.668 .55858 Mdot
.668 .55868 Mdot
.668 .55875 Mdot
.668 .55892 Mdot
.668 .55899 Mdot
.668 .55906 Mdot
.668 .55944 Mdot
.668 .55974 Mdot
.668 .55982 Mdot
.668 .5599 Mdot
.668 .56004 Mdot
.668 .56016 Mdot
.668 .56021 Mdot
.668 .56064 Mdot
.668 .56069 Mdot
.668 .5609 Mdot
.668 .56119 Mdot
.668 .56123 Mdot
.668 .56124 Mdot
.668 .56128 Mdot
.668 .5613 Mdot
.668 .56134 Mdot
.668 .56141 Mdot
.668 .56143 Mdot
.668 .56146 Mdot
.668 .56146 Mdot
.668 .56171 Mdot
.668 .56172 Mdot
.668 .56176 Mdot
.668 .56186 Mdot
.668 .5619 Mdot
.668 .56219 Mdot
.668 .56219 Mdot
.668 .56246 Mdot
.668 .56259 Mdot
.668 .5626 Mdot
.668 .56262 Mdot
.668 .56286 Mdot
.668 .56296 Mdot
.668 .56302 Mdot
.668 .56308 Mdot
.668 .5632 Mdot
.668 .56322 Mdot
.668 .56322 Mdot
.668 .56323 Mdot
.668 .56327 Mdot
.668 .56328 Mdot
.668 .56331 Mdot
.668 .56332 Mdot
.668 .56333 Mdot
.668 .56333 Mdot
.668 .56333 Mdot
.668 .56364 Mdot
.668 .56368 Mdot
.668 .56374 Mdot
.668 .56377 Mdot
.668 .56378 Mdot
.668 .56384 Mdot
.668 .56386 Mdot
.668 .56387 Mdot
.668 .56403 Mdot
.668 .56414 Mdot
.668 .56419 Mdot
.668 .5642 Mdot
.668 .5642 Mdot
.668 .56421 Mdot
.668 .56423 Mdot
.668 .56423 Mdot
.668 .56423 Mdot
.668 .56423 Mdot
.668 .56424 Mdot
.67 .15027 Mdot
.67 .15028 Mdot
.67 .1503 Mdot
.67 .1503 Mdot
.67 .1503 Mdot
.67 .15034 Mdot
.67 .15044 Mdot
.67 .15061 Mdot
.67 .15072 Mdot
.67 .15082 Mdot
.67 .15085 Mdot
.67 .15092 Mdot
.67 .15094 Mdot
.67 .15149 Mdot
.67 .1515 Mdot
.67 .15152 Mdot
.67 .15156 Mdot
.67 .15156 Mdot
.67 .15156 Mdot
.67 .15161 Mdot
.67 .15164 Mdot
.67 .15169 Mdot
.67 .15176 Mdot
.67 .15184 Mdot
.67 .15187 Mdot
.67 .15224 Mdot
.67 .15244 Mdot
.67 .15253 Mdot
.67 .1527 Mdot
.67 .15279 Mdot
.67 .1528 Mdot
.67 .15289 Mdot
.67 .15295 Mdot
.67 .15307 Mdot
.67 .15313 Mdot
.67 .15314 Mdot
.67 .15328 Mdot
.67 .15356 Mdot
.67 .15381 Mdot
.67 .15391 Mdot
.67 .15502 Mdot
.67 .15506 Mdot
.67 .15512 Mdot
.67 .15523 Mdot
.67 .15528 Mdot
.67 .15529 Mdot
.67 .15529 Mdot
.67 .15547 Mdot
.67 .15561 Mdot
.67 .1558 Mdot
.67 .15583 Mdot
.67 .1561 Mdot
.67 .15646 Mdot
.67 .15651 Mdot
.67 .15657 Mdot
.67 .15672 Mdot
.67 .15709 Mdot
.67 .15725 Mdot
.67 .1583 Mdot
.67 .15929 Mdot
.67 .15936 Mdot
.67 .15946 Mdot
.67 .1595 Mdot
.67 .1598 Mdot
.67 .16053 Mdot
.67 .16076 Mdot
.67 .16092 Mdot
.67 .1612 Mdot
.67 .16124 Mdot
.67 .16133 Mdot
.67 .16138 Mdot
.67 .16184 Mdot
.67 .16187 Mdot
.67 .16219 Mdot
.67 .16297 Mdot
.67 .16334 Mdot
.67 .1634 Mdot
.67 .16359 Mdot
.67 .16367 Mdot
.67 .16385 Mdot
.67 .16428 Mdot
.67 .16446 Mdot
.67 .16619 Mdot
.67 .16708 Mdot
.67 .16761 Mdot
.67 .16795 Mdot
.67 .16834 Mdot
.67 .1687 Mdot
.67 .16886 Mdot
.67 .17006 Mdot
.67 .17101 Mdot
.67 .17155 Mdot
.67 .1724 Mdot
.67 .17354 Mdot
.67 .17527 Mdot
.67 .17589 Mdot
.67 .17662 Mdot
.67 .17687 Mdot
.67 .17718 Mdot
.67 .17763 Mdot
.67 .17782 Mdot
.67 .17796 Mdot
.67 .17815 Mdot
.67 .1785 Mdot
.67 .17873 Mdot
.67 .17972 Mdot
.67 .17983 Mdot
.67 .18019 Mdot
.67 .18027 Mdot
.67 .18032 Mdot
.67 .1813 Mdot
.67 .18195 Mdot
.67 .18217 Mdot
.67 .18298 Mdot
.67 .18337 Mdot
.67 .18342 Mdot
.67 .18406 Mdot
.67 .18449 Mdot
.67 .1852 Mdot
.67 .18558 Mdot
.67 .18583 Mdot
.67 .18585 Mdot
.67 .18625 Mdot
.67 .18626 Mdot
.67 .18669 Mdot
.67 .18754 Mdot
.67 .18773 Mdot
.67 .18828 Mdot
.67 .19102 Mdot
.67 .19218 Mdot
.67 .19245 Mdot
.67 .19264 Mdot
.67 .19269 Mdot
.67 .19332 Mdot
.67 .195 Mdot
.67 .19673 Mdot
.67 .19725 Mdot
.67 .19775 Mdot
.67 .19929 Mdot
.67 .19931 Mdot
.67 .19951 Mdot
.67 .20003 Mdot
.67 .2012 Mdot
.67 .20147 Mdot
.67 .20212 Mdot
.67 .20271 Mdot
.67 .20301 Mdot
.67 .20393 Mdot
.67 .20405 Mdot
.67 .20429 Mdot
.67 .20434 Mdot
.67 .20566 Mdot
.67 .20769 Mdot
.67 .2091 Mdot
.67 .20919 Mdot
.67 .21242 Mdot
.67 .21325 Mdot
.67 .21418 Mdot
.67 .21421 Mdot
.67 .21472 Mdot
.67 .21594 Mdot
.67 .21763 Mdot
.67 .21952 Mdot
.67 .22014 Mdot
.67 .22049 Mdot
.67 .22131 Mdot
.67 .22231 Mdot
.67 .22477 Mdot
.67 .22676 Mdot
.67 .22771 Mdot
.67 .22817 Mdot
.67 .22865 Mdot
.67 .22964 Mdot
.67 .23012 Mdot
.67 .23067 Mdot
.67 .23076 Mdot
.67 .23315 Mdot
.67 .23417 Mdot
.67 .23505 Mdot
.67 .24592 Mdot
.67 .24652 Mdot
.67 .24738 Mdot
.67 .24943 Mdot
.67 .25189 Mdot
.67 .25257 Mdot
.67 .25296 Mdot
.67 .2545 Mdot
.67 .25454 Mdot
.67 .25522 Mdot
.67 .25622 Mdot
.67 .25687 Mdot
.67 .2569 Mdot
.67 .25754 Mdot
.67 .25799 Mdot
.67 .25832 Mdot
.67 .25907 Mdot
.67 .26026 Mdot
.67 .26314 Mdot
.67 .26395 Mdot
.67 .26647 Mdot
.67 .26673 Mdot
.67 .26673 Mdot
.67 .26698 Mdot
.67 .26699 Mdot
.67 .26847 Mdot
.67 .26925 Mdot
.67 .26981 Mdot
.67 .27077 Mdot
.67 .27225 Mdot
.67 .27255 Mdot
.67 .27345 Mdot
.67 .27389 Mdot
.67 .27515 Mdot
.67 .27782 Mdot
.67 .27879 Mdot
.67 .28264 Mdot
.67 .28348 Mdot
.67 .28519 Mdot
.67 .28783 Mdot
.67 .29056 Mdot
.67 .29128 Mdot
.67 .29157 Mdot
.67 .29255 Mdot
.67 .29347 Mdot
.67 .2957 Mdot
.67 .29589 Mdot
.67 .29635 Mdot
.67 .29691 Mdot
.67 .29721 Mdot
.67 .29814 Mdot
.67 .29873 Mdot
.67 .3002 Mdot
.67 .30072 Mdot
.67 .30434 Mdot
.67 .30616 Mdot
.67 .30773 Mdot
.67 .30941 Mdot
.67 .30977 Mdot
.67 .31027 Mdot
.67 .31029 Mdot
.67 .3109 Mdot
.67 .31306 Mdot
.67 .31419 Mdot
.67 .31433 Mdot
.67 .31462 Mdot
.67 .31472 Mdot
.67 .31672 Mdot
.67 .31675 Mdot
.67 .31681 Mdot
.67 .31693 Mdot
.67 .31694 Mdot
.67 .31694 Mdot
.67 .31707 Mdot
.67 .31718 Mdot
.67 .31753 Mdot
.67 .31776 Mdot
.67 .3188 Mdot
.67 .3195 Mdot
.67 .32008 Mdot
.67 .32011 Mdot
.67 .3203 Mdot
.67 .32043 Mdot
.67 .3207 Mdot
.67 .32084 Mdot
.67 .32423 Mdot
.67 .32429 Mdot
.67 .32439 Mdot
.67 .32464 Mdot
.67 .32465 Mdot
.67 .32466 Mdot
.67 .32493 Mdot
.67 .32515 Mdot
.67 .32543 Mdot
.67 .32587 Mdot
.67 .32639 Mdot
.67 .32654 Mdot
.67 .32726 Mdot
.67 .32881 Mdot
.67 .33001 Mdot
.67 .33008 Mdot
.67 .33026 Mdot
.67 .3306 Mdot
.67 .33141 Mdot
.67 .33166 Mdot
.67 .33184 Mdot
.67 .33213 Mdot
.67 .33218 Mdot
.67 .33227 Mdot
.67 .33232 Mdot
.67 .33281 Mdot
.67 .33317 Mdot
.67 .33395 Mdot
.67 .33432 Mdot
.67 .33438 Mdot
.67 .33464 Mdot
.67 .33481 Mdot
.67 .33522 Mdot
.67 .33696 Mdot
.67 .33774 Mdot
.67 .33819 Mdot
.67 .33848 Mdot
.67 .33881 Mdot
.67 .33911 Mdot
.67 .34097 Mdot
.67 .34138 Mdot
.67 .34203 Mdot
.67 .34509 Mdot
.67 .34526 Mdot
.67 .34591 Mdot
.67 .34601 Mdot
.67 .34614 Mdot
.67 .34638 Mdot
.67 .34653 Mdot
.67 .34719 Mdot
.67 .3475 Mdot
.67 .34755 Mdot
.67 .34758 Mdot
.67 .34864 Mdot
.67 .34929 Mdot
.67 .34953 Mdot
.67 .34996 Mdot
.67 .35023 Mdot
.67 .35066 Mdot
.67 .35089 Mdot
.67 .35207 Mdot
.67 .35218 Mdot
.67 .3525 Mdot
.67 .35474 Mdot
.67 .355 Mdot
.67 .35502 Mdot
.67 .35537 Mdot
.67 .35629 Mdot
.67 .35723 Mdot
.67 .35751 Mdot
.67 .35858 Mdot
.67 .35859 Mdot
.67 .35869 Mdot
.67 .35957 Mdot
.67 .36034 Mdot
.67 .36095 Mdot
.67 .36101 Mdot
.67 .36589 Mdot
.67 .36591 Mdot
.67 .3667 Mdot
.67 .36748 Mdot
.67 .36833 Mdot
.67 .36876 Mdot
.67 .36913 Mdot
.67 .36957 Mdot
.67 .37192 Mdot
.67 .37232 Mdot
.67 .37274 Mdot
.67 .37295 Mdot
.67 .37318 Mdot
.67 .37322 Mdot
.67 .37422 Mdot
.67 .37464 Mdot
.67 .37501 Mdot
.67 .37938 Mdot
.67 .37962 Mdot
.67 .37996 Mdot
.67 .38075 Mdot
.67 .38171 Mdot
.67 .38197 Mdot
.67 .38212 Mdot
.67 .38271 Mdot
.67 .38272 Mdot
.67 .38336 Mdot
.67 .38361 Mdot
.67 .38362 Mdot
.67 .38403 Mdot
.67 .38415 Mdot
.67 .38443 Mdot
.67 .38595 Mdot
.67 .38625 Mdot
.67 .38718 Mdot
.67 .38727 Mdot
.67 .38737 Mdot
.67 .38819 Mdot
.67 .38874 Mdot
.67 .38928 Mdot
.67 .38971 Mdot
.67 .39161 Mdot
.67 .39297 Mdot
.67 .39386 Mdot
.67 .39478 Mdot
.67 .39597 Mdot
.67 .39607 Mdot
.67 .39641 Mdot
.67 .39748 Mdot
.67 .39771 Mdot
.67 .398 Mdot
.67 .39831 Mdot
.67 .39901 Mdot
.67 .39919 Mdot
.67 .40101 Mdot
.67 .40154 Mdot
.67 .40222 Mdot
.67 .40238 Mdot
.67 .40239 Mdot
.67 .40259 Mdot
.67 .40368 Mdot
.67 .40373 Mdot
.67 .40452 Mdot
.67 .40453 Mdot
.67 .40454 Mdot
.67 .40458 Mdot
.67 .40459 Mdot
.67 .40459 Mdot
.67 .40463 Mdot
.67 .40467 Mdot
.67 .40486 Mdot
.67 .4052 Mdot
.67 .40543 Mdot
.67 .40563 Mdot
.67 .40569 Mdot
.67 .40573 Mdot
.67 .40582 Mdot
.67 .40587 Mdot
.67 .40697 Mdot
.67 .40699 Mdot
.67 .40703 Mdot
.67 .40711 Mdot
.67 .40711 Mdot
.67 .40711 Mdot
.67 .4072 Mdot
.67 .40727 Mdot
.67 .40736 Mdot
.67 .40751 Mdot
.67 .40768 Mdot
.67 .40772 Mdot
.67 .40796 Mdot
.67 .40846 Mdot
.67 .40887 Mdot
.67 .40904 Mdot
.67 .4093 Mdot
.67 .40938 Mdot
.67 .40944 Mdot
.67 .40953 Mdot
.67 .40955 Mdot
.67 .40958 Mdot
.67 .4096 Mdot
.67 .40975 Mdot
.67 .40987 Mdot
.67 .41012 Mdot
.67 .41024 Mdot
.67 .41026 Mdot
.67 .4104 Mdot
.67 .41053 Mdot
.67 .41109 Mdot
.67 .41134 Mdot
.67 .41148 Mdot
.67 .41158 Mdot
.67 .41168 Mdot
.67 .41178 Mdot
.67 .4125 Mdot
.67 .41271 Mdot
.67 .41395 Mdot
.67 .41402 Mdot
.67 .41415 Mdot
.67 .41436 Mdot
.67 .41446 Mdot
.67 .41447 Mdot
.67 .41448 Mdot
.67 .41482 Mdot
.67 .4151 Mdot
.67 .41524 Mdot
.67 .41546 Mdot
.67 .41554 Mdot
.67 .41594 Mdot
.67 .41605 Mdot
.67 .41675 Mdot
.67 .41685 Mdot
.67 .41696 Mdot
.67 .41725 Mdot
.67 .41754 Mdot
.67 .41763 Mdot
.67 .41797 Mdot
.67 .41797 Mdot
.67 .41828 Mdot
.67 .42028 Mdot
.67 .42054 Mdot
.67 .42105 Mdot
.67 .42118 Mdot
.67 .42144 Mdot
.67 .42218 Mdot
.67 .42231 Mdot
.67 .42244 Mdot
.67 .4225 Mdot
.67 .42258 Mdot
.67 .42259 Mdot
.67 .4229 Mdot
.67 .42315 Mdot
.67 .42453 Mdot
.67 .4246 Mdot
.67 .42496 Mdot
.67 .42526 Mdot
.67 .42557 Mdot
.67 .42578 Mdot
.67 .42586 Mdot
.67 .42599 Mdot
.67 .42603 Mdot
.67 .42612 Mdot
.67 .42659 Mdot
.67 .42669 Mdot
.67 .42698 Mdot
.67 .42704 Mdot
.67 .42747 Mdot
.67 .42764 Mdot
.67 .42778 Mdot
.67 .42838 Mdot
.67 .4288 Mdot
.67 .42909 Mdot
.67 .42937 Mdot
.67 .42978 Mdot
.67 .42989 Mdot
.67 .43023 Mdot
.67 .43039 Mdot
.67 .43071 Mdot
.67 .43077 Mdot
.67 .43151 Mdot
.67 .43172 Mdot
.67 .43184 Mdot
.67 .43249 Mdot
.67 .43401 Mdot
.67 .43404 Mdot
.67 .43406 Mdot
.67 .43432 Mdot
.67 .43473 Mdot
.67 .43499 Mdot
.67 .4366 Mdot
.67 .43662 Mdot
.67 .43755 Mdot
.67 .43816 Mdot
.67 .43886 Mdot
.67 .43917 Mdot
.67 .4395 Mdot
.67 .43979 Mdot
.67 .44191 Mdot
.67 .44192 Mdot
.67 .44192 Mdot
.67 .442 Mdot
.67 .44359 Mdot
.67 .44449 Mdot
.67 .44452 Mdot
.67 .44535 Mdot
.67 .44601 Mdot
.67 .4465 Mdot
.67 .44792 Mdot
.67 .44797 Mdot
.67 .44798 Mdot
.67 .44952 Mdot
.67 .45094 Mdot
.67 .45199 Mdot
.67 .45222 Mdot
.67 .45235 Mdot
.67 .45237 Mdot
.67 .45238 Mdot
.67 .45322 Mdot
.67 .45363 Mdot
.67 .45416 Mdot
.67 .45491 Mdot
.67 .45522 Mdot
.67 .45545 Mdot
.67 .45577 Mdot
.67 .45593 Mdot
.67 .45635 Mdot
.67 .4564 Mdot
.67 .45672 Mdot
.67 .45695 Mdot
.67 .45746 Mdot
.67 .45836 Mdot
.67 .45853 Mdot
.67 .45861 Mdot
.67 .45913 Mdot
.67 .45927 Mdot
.67 .45934 Mdot
.67 .45961 Mdot
.67 .46094 Mdot
.67 .46112 Mdot
.67 .46116 Mdot
.67 .46199 Mdot
.67 .46235 Mdot
.67 .46364 Mdot
.67 .46375 Mdot
.67 .46417 Mdot
.67 .46427 Mdot
.67 .46434 Mdot
.67 .46482 Mdot
.67 .46522 Mdot
.67 .46525 Mdot
.67 .4653 Mdot
.67 .46537 Mdot
.67 .46605 Mdot
.67 .46716 Mdot
.67 .46771 Mdot
.67 .46776 Mdot
.67 .46815 Mdot
.67 .46818 Mdot
.67 .46872 Mdot
.67 .46882 Mdot
.67 .46882 Mdot
.67 .4689 Mdot
.67 .46923 Mdot
.67 .46949 Mdot
.67 .47039 Mdot
.67 .47047 Mdot
.67 .47081 Mdot
.67 .47097 Mdot
.67 .47111 Mdot
.67 .47122 Mdot
.67 .47174 Mdot
.67 .4719 Mdot
.67 .47195 Mdot
.67 .47253 Mdot
.67 .47297 Mdot
.67 .47339 Mdot
.67 .47404 Mdot
.67 .47495 Mdot
.67 .47516 Mdot
.67 .47541 Mdot
.67 .47567 Mdot
.67 .47606 Mdot
.67 .4761 Mdot
.67 .47615 Mdot
.67 .47658 Mdot
.67 .47672 Mdot
.67 .47744 Mdot
.67 .47757 Mdot
.67 .47762 Mdot
.67 .47782 Mdot
.67 .47782 Mdot
.67 .47794 Mdot
.67 .47823 Mdot
.67 .47824 Mdot
.67 .47851 Mdot
.67 .47858 Mdot
.67 .47871 Mdot
.67 .47915 Mdot
.67 .47952 Mdot
.67 .47967 Mdot
.67 .47978 Mdot
.67 .48179 Mdot
.67 .48195 Mdot
.67 .48215 Mdot
.67 .4826 Mdot
.67 .48262 Mdot
.67 .48272 Mdot
.67 .48282 Mdot
.67 .48301 Mdot
.67 .48319 Mdot
.67 .48425 Mdot
.67 .48445 Mdot
.67 .48461 Mdot
.67 .48481 Mdot
.67 .48519 Mdot
.67 .48553 Mdot
.67 .48589 Mdot
.67 .4859 Mdot
.67 .48805 Mdot
.67 .48808 Mdot
.67 .48835 Mdot
.67 .48869 Mdot
.67 .48907 Mdot
.67 .48912 Mdot
.67 .48912 Mdot
.67 .48959 Mdot
.67 .48971 Mdot
.67 .49012 Mdot
.67 .49052 Mdot
.67 .49067 Mdot
.67 .49068 Mdot
.67 .4908 Mdot
.67 .49106 Mdot
.67 .49176 Mdot
.67 .4919 Mdot
.67 .49195 Mdot
.67 .49245 Mdot
.67 .49255 Mdot
.67 .49274 Mdot
.67 .49285 Mdot
.67 .49304 Mdot
.67 .49314 Mdot
.67 .49342 Mdot
.67 .49387 Mdot
.67 .49388 Mdot
.67 .49391 Mdot
.67 .49404 Mdot
.67 .49432 Mdot
.67 .49438 Mdot
.67 .49448 Mdot
.67 .49454 Mdot
.67 .49458 Mdot
.67 .49486 Mdot
.67 .49493 Mdot
.67 .49622 Mdot
.67 .49649 Mdot
.67 .49667 Mdot
.67 .49745 Mdot
.67 .49757 Mdot
.67 .49771 Mdot
.67 .49783 Mdot
.67 .49802 Mdot
.67 .49834 Mdot
.67 .49907 Mdot
.67 .49924 Mdot
.67 .49931 Mdot
.67 .49941 Mdot
.67 .49944 Mdot
.67 .49959 Mdot
.67 .49991 Mdot
.67 .50006 Mdot
.67 .50026 Mdot
.67 .50028 Mdot
.67 .50032 Mdot
.67 .50034 Mdot
.67 .50046 Mdot
.67 .50053 Mdot
.67 .50064 Mdot
.67 .50097 Mdot
.67 .50111 Mdot
.67 .50118 Mdot
.67 .50121 Mdot
.67 .5017 Mdot
.67 .50234 Mdot
.67 .50263 Mdot
.67 .50269 Mdot
.67 .5029 Mdot
.67 .50308 Mdot
.67 .50319 Mdot
.67 .50328 Mdot
.67 .50339 Mdot
.67 .5034 Mdot
.67 .5034 Mdot
.67 .5035 Mdot
.67 .50354 Mdot
.67 .50357 Mdot
.67 .50493 Mdot
.67 .50499 Mdot
.67 .5051 Mdot
.67 .50515 Mdot
.67 .50523 Mdot
.67 .50524 Mdot
.67 .50547 Mdot
.67 .50575 Mdot
.67 .50617 Mdot
.67 .50626 Mdot
.67 .5064 Mdot
.67 .50644 Mdot
.67 .5065 Mdot
.67 .5065 Mdot
.67 .5065 Mdot
.67 .50655 Mdot
.67 .50657 Mdot
.67 .50658 Mdot
.67 .50738 Mdot
.67 .50742 Mdot
.67 .50753 Mdot
.67 .50759 Mdot
.67 .50804 Mdot
.67 .50889 Mdot
.67 .50913 Mdot
.67 .50914 Mdot
.67 .50934 Mdot
.67 .50948 Mdot
.67 .51014 Mdot
.67 .51075 Mdot
.67 .51146 Mdot
.67 .51287 Mdot
.67 .51306 Mdot
.67 .51363 Mdot
.67 .51386 Mdot
.67 .51422 Mdot
.67 .51433 Mdot
.67 .51454 Mdot
.67 .51472 Mdot
.67 .5148 Mdot
.67 .51565 Mdot
.67 .516 Mdot
.67 .51637 Mdot
.67 .51648 Mdot
.67 .51675 Mdot
.67 .51779 Mdot
.67 .51878 Mdot
.67 .51942 Mdot
.67 .51973 Mdot
.67 .52117 Mdot
.67 .52153 Mdot
.67 .52252 Mdot
.67 .52298 Mdot
.67 .52314 Mdot
.67 .52347 Mdot
.67 .52359 Mdot
.67 .52413 Mdot
.67 .52448 Mdot
.67 .52468 Mdot
.67 .52497 Mdot
.67 .52551 Mdot
.67 .52551 Mdot
.67 .5256 Mdot
.67 .5256 Mdot
.67 .5257 Mdot
.67 .52661 Mdot
.67 .5269 Mdot
.67 .52794 Mdot
.67 .52837 Mdot
.67 .52864 Mdot
.67 .52876 Mdot
.67 .52892 Mdot
.67 .52915 Mdot
.67 .52916 Mdot
.67 .52939 Mdot
.67 .52975 Mdot
.67 .52999 Mdot
.67 .53 Mdot
.67 .53055 Mdot
.67 .53069 Mdot
.67 .53093 Mdot
.67 .53181 Mdot
.67 .53253 Mdot
.67 .53283 Mdot
.67 .53304 Mdot
.67 .53683 Mdot
.67 .53714 Mdot
.67 .53749 Mdot
.67 .53831 Mdot
.67 .53834 Mdot
.67 .53853 Mdot
.67 .5387 Mdot
.67 .53904 Mdot
.67 .5392 Mdot
.67 .53936 Mdot
.67 .53968 Mdot
.67 .54036 Mdot
.67 .5412 Mdot
.67 .54154 Mdot
.67 .54181 Mdot
.67 .54193 Mdot
.67 .54214 Mdot
.67 .54278 Mdot
.67 .54335 Mdot
.67 .54376 Mdot
.67 .54393 Mdot
.67 .54394 Mdot
.67 .54425 Mdot
.67 .54453 Mdot
.67 .54561 Mdot
.67 .54563 Mdot
.67 .5461 Mdot
.67 .54678 Mdot
.67 .54721 Mdot
.67 .54723 Mdot
.67 .54731 Mdot
.67 .54735 Mdot
.67 .54766 Mdot
.67 .54775 Mdot
.67 .54795 Mdot
.67 .54816 Mdot
.67 .54825 Mdot
.67 .54864 Mdot
.67 .54881 Mdot
.67 .54887 Mdot
.67 .54888 Mdot
.67 .54938 Mdot
.67 .54955 Mdot
.67 .54972 Mdot
.67 .55029 Mdot
.67 .55083 Mdot
.67 .55104 Mdot
.67 .55105 Mdot
.67 .55111 Mdot
.67 .5512 Mdot
.67 .55158 Mdot
.67 .55247 Mdot
.67 .55264 Mdot
.67 .55271 Mdot
.67 .55298 Mdot
.67 .55312 Mdot
.67 .55312 Mdot
.67 .55325 Mdot
.67 .55326 Mdot
.67 .55334 Mdot
.67 .55346 Mdot
.67 .55369 Mdot
.67 .55383 Mdot
.67 .55404 Mdot
.67 .55405 Mdot
.67 .55418 Mdot
.67 .55444 Mdot
.67 .55451 Mdot
.67 .55472 Mdot
.67 .55503 Mdot
.67 .55505 Mdot
.67 .55507 Mdot
.67 .55519 Mdot
.67 .55522 Mdot
.67 .55554 Mdot
.67 .55561 Mdot
.67 .55572 Mdot
.67 .55579 Mdot
.67 .55583 Mdot
.67 .55589 Mdot
.67 .55603 Mdot
.67 .55613 Mdot
.67 .55621 Mdot
.67 .55644 Mdot
.67 .55664 Mdot
.67 .55719 Mdot
.67 .55755 Mdot
.67 .55782 Mdot
.67 .55799 Mdot
.67 .55829 Mdot
.67 .55867 Mdot
.67 .55872 Mdot
.67 .55884 Mdot
.67 .55896 Mdot
.67 .55907 Mdot
.67 .55924 Mdot
.67 .55952 Mdot
.67 .56006 Mdot
.67 .56011 Mdot
.67 .56025 Mdot
.67 .5603 Mdot
.67 .56033 Mdot
.67 .56039 Mdot
.67 .56041 Mdot
.67 .56053 Mdot
.67 .56077 Mdot
.67 .56087 Mdot
.67 .56088 Mdot
.67 .56102 Mdot
.67 .56104 Mdot
.67 .56107 Mdot
.67 .56108 Mdot
.67 .56117 Mdot
.67 .56122 Mdot
.67 .56129 Mdot
.67 .56152 Mdot
.67 .56161 Mdot
.67 .56162 Mdot
.67 .56165 Mdot
.67 .56167 Mdot
.67 .56198 Mdot
.67 .56231 Mdot
.67 .56236 Mdot
.67 .56248 Mdot
.67 .56252 Mdot
.67 .56254 Mdot
.67 .56255 Mdot
.67 .56267 Mdot
.67 .56275 Mdot
.67 .56276 Mdot
.67 .56282 Mdot
.67 .56286 Mdot
.67 .56292 Mdot
.67 .56292 Mdot
.67 .56292 Mdot
.67 .56294 Mdot
.67 .56297 Mdot
.67 .56299 Mdot
.67 .563 Mdot
.67 .56335 Mdot
.67 .56338 Mdot
.67 .56345 Mdot
.67 .56354 Mdot
.67 .56358 Mdot
.67 .56359 Mdot
.67 .56361 Mdot
.67 .56364 Mdot
.67 .56366 Mdot
.67 .56369 Mdot
.67 .56369 Mdot
.67 .56372 Mdot
.67 .56377 Mdot
.67 .5638 Mdot
.67 .56386 Mdot
.67 .56398 Mdot
.67 .56399 Mdot
.67 .56401 Mdot
.67 .56403 Mdot
.67 .56405 Mdot
.67 .56406 Mdot
.67 .56407 Mdot
.67 .56407 Mdot
.67 .56407 Mdot
.67 .56409 Mdot
.67 .56409 Mdot
.67 .56409 Mdot
.67 .56426 Mdot
.67 .56427 Mdot
.67 .56429 Mdot
.67 .5643 Mdot
.67 .56433 Mdot
.67 .56437 Mdot
.67 .56442 Mdot
.67 .56445 Mdot
.67 .56446 Mdot
.67 .56446 Mdot
.67 .56446 Mdot
.67 .56447 Mdot
.67 .56447 Mdot
.672 .14957 Mdot
.672 .14957 Mdot
.672 .14957 Mdot
.672 .14957 Mdot
.672 .14973 Mdot
.672 .14982 Mdot
.672 .14982 Mdot
.672 .14982 Mdot
.672 .14982 Mdot
.672 .14995 Mdot
.672 .14996 Mdot
.672 .14998 Mdot
.672 .15009 Mdot
.672 .15009 Mdot
.672 .15009 Mdot
.672 .15009 Mdot
.672 .15011 Mdot
.672 .15027 Mdot
.672 .15029 Mdot
.672 .15032 Mdot
.672 .15032 Mdot
.672 .15037 Mdot
.672 .15049 Mdot
.672 .15049 Mdot
.672 .15049 Mdot
.672 .15049 Mdot
.672 .15053 Mdot
.672 .15054 Mdot
.672 .15064 Mdot
.672 .1507 Mdot
.672 .15082 Mdot
.672 .15083 Mdot
.672 .15087 Mdot
.672 .15092 Mdot
.672 .15093 Mdot
.672 .15103 Mdot
.672 .15112 Mdot
.672 .1513 Mdot
.672 .1513 Mdot
.672 .15131 Mdot
.672 .15131 Mdot
.672 .15138 Mdot
.672 .15143 Mdot
.672 .15167 Mdot
.672 .15174 Mdot
.672 .15183 Mdot
.672 .1519 Mdot
.672 .15215 Mdot
.672 .15218 Mdot
.672 .15231 Mdot
.672 .15244 Mdot
.672 .15247 Mdot
.672 .15278 Mdot
.672 .15307 Mdot
.672 .15348 Mdot
.672 .15353 Mdot
.672 .15369 Mdot
.672 .1537 Mdot
.672 .15372 Mdot
.672 .15373 Mdot
.672 .15387 Mdot
.672 .15393 Mdot
.672 .15394 Mdot
.672 .15394 Mdot
.672 .15399 Mdot
.672 .15415 Mdot
.672 .15472 Mdot
.672 .15513 Mdot
.672 .15527 Mdot
.672 .15542 Mdot
.672 .15579 Mdot
.672 .15584 Mdot
.672 .15598 Mdot
.672 .15599 Mdot
.672 .15611 Mdot
.672 .15652 Mdot
.672 .15686 Mdot
.672 .15696 Mdot
.672 .15719 Mdot
.672 .15731 Mdot
.672 .15746 Mdot
.672 .15789 Mdot
.672 .15806 Mdot
.672 .15806 Mdot
.672 .15843 Mdot
.672 .1586 Mdot
.672 .15879 Mdot
.672 .15894 Mdot
.672 .15897 Mdot
.672 .15921 Mdot
.672 .16008 Mdot
.672 .16029 Mdot
.672 .16065 Mdot
.672 .16239 Mdot
.672 .16282 Mdot
.672 .16323 Mdot
.672 .16397 Mdot
.672 .16434 Mdot
.672 .16511 Mdot
.672 .1655 Mdot
.672 .16659 Mdot
.672 .16663 Mdot
.672 .16665 Mdot
.672 .16682 Mdot
.672 .16688 Mdot
.672 .16791 Mdot
.672 .16834 Mdot
.672 .16845 Mdot
.672 .16845 Mdot
.672 .16886 Mdot
.672 .16956 Mdot
.672 .17008 Mdot
.672 .17179 Mdot
.672 .17477 Mdot
.672 .17604 Mdot
.672 .17773 Mdot
.672 .17815 Mdot
.672 .17841 Mdot
.672 .17914 Mdot
.672 .17923 Mdot
.672 .17936 Mdot
.672 .17977 Mdot
.672 .18036 Mdot
.672 .18118 Mdot
.672 .18185 Mdot
.672 .18242 Mdot
.672 .18365 Mdot
.672 .18419 Mdot
.672 .18444 Mdot
.672 .18484 Mdot
.672 .18537 Mdot
.672 .1855 Mdot
.672 .18674 Mdot
.672 .18693 Mdot
.672 .1871 Mdot
.672 .18782 Mdot
.672 .18815 Mdot
.672 .18938 Mdot
.672 .1908 Mdot
.672 .19103 Mdot
.672 .19137 Mdot
.672 .19253 Mdot
.672 .19291 Mdot
.672 .19469 Mdot
.672 .19644 Mdot
.672 .19711 Mdot
.672 .19756 Mdot
.672 .19913 Mdot
.672 .20022 Mdot
.672 .20167 Mdot
.672 .2035 Mdot
.672 .20353 Mdot
.672 .20385 Mdot
.672 .20893 Mdot
.672 .20962 Mdot
.672 .21046 Mdot
.672 .21073 Mdot
.672 .21114 Mdot
.672 .21114 Mdot
.672 .21242 Mdot
.672 .21354 Mdot
.672 .21423 Mdot
.672 .215 Mdot
.672 .21586 Mdot
.672 .21599 Mdot
.672 .21737 Mdot
.672 .21823 Mdot
.672 .21937 Mdot
.672 .22079 Mdot
.672 .22182 Mdot
.672 .22214 Mdot
.672 .22229 Mdot
.672 .22281 Mdot
.672 .22303 Mdot
.672 .22327 Mdot
.672 .2236 Mdot
.672 .22664 Mdot
.672 .22939 Mdot
.672 .22974 Mdot
.672 .23055 Mdot
.672 .23169 Mdot
.672 .23248 Mdot
.672 .23532 Mdot
.672 .23602 Mdot
.672 .23628 Mdot
.672 .23912 Mdot
.672 .23925 Mdot
.672 .2423 Mdot
.672 .2424 Mdot
.672 .24386 Mdot
.672 .24419 Mdot
.672 .24467 Mdot
.672 .24789 Mdot
.672 .24821 Mdot
.672 .24842 Mdot
.672 .24951 Mdot
.672 .25149 Mdot
.672 .25216 Mdot
.672 .25268 Mdot
.672 .25348 Mdot
.672 .2536 Mdot
.672 .254 Mdot
.672 .25699 Mdot
.672 .26157 Mdot
.672 .26254 Mdot
.672 .26358 Mdot
.672 .26371 Mdot
.672 .26543 Mdot
.672 .2668 Mdot
.672 .26744 Mdot
.672 .26905 Mdot
.672 .27 Mdot
.672 .2708 Mdot
.672 .27289 Mdot
.672 .27596 Mdot
.672 .27768 Mdot
.672 .28013 Mdot
.672 .28246 Mdot
.672 .28317 Mdot
.672 .28636 Mdot
.672 .28732 Mdot
.672 .28802 Mdot
.672 .28866 Mdot
.672 .29004 Mdot
.672 .29016 Mdot
.672 .29062 Mdot
.672 .29132 Mdot
.672 .29153 Mdot
.672 .29445 Mdot
.672 .29455 Mdot
.672 .29873 Mdot
.672 .30121 Mdot
.672 .30212 Mdot
.672 .30277 Mdot
.672 .30296 Mdot
.672 .30461 Mdot
.672 .30469 Mdot
.672 .30867 Mdot
.672 .30882 Mdot
.672 .30923 Mdot
.672 .3094 Mdot
.672 .31183 Mdot
.672 .31251 Mdot
.672 .31251 Mdot
.672 .31252 Mdot
.672 .31253 Mdot
.672 .31351 Mdot
.672 .31406 Mdot
.672 .31406 Mdot
.672 .31406 Mdot
.672 .31407 Mdot
.672 .31415 Mdot
.672 .31488 Mdot
.672 .31497 Mdot
.672 .31506 Mdot
.672 .31572 Mdot
.672 .31572 Mdot
.672 .31573 Mdot
.672 .31574 Mdot
.672 .31585 Mdot
.672 .31625 Mdot
.672 .31645 Mdot
.672 .31686 Mdot
.672 .31699 Mdot
.672 .31713 Mdot
.672 .31716 Mdot
.672 .31745 Mdot
.672 .3177 Mdot
.672 .3182 Mdot
.672 .3182 Mdot
.672 .31822 Mdot
.672 .31823 Mdot
.672 .31841 Mdot
.672 .31852 Mdot
.672 .31913 Mdot
.672 .3195 Mdot
.672 .31967 Mdot
.672 .32023 Mdot
.672 .3203 Mdot
.672 .32056 Mdot
.672 .32084 Mdot
.672 .3209 Mdot
.672 .32151 Mdot
.672 .32206 Mdot
.672 .32281 Mdot
.672 .32291 Mdot
.672 .32319 Mdot
.672 .32319 Mdot
.672 .32323 Mdot
.672 .32325 Mdot
.672 .3236 Mdot
.672 .32361 Mdot
.672 .32369 Mdot
.672 .32395 Mdot
.672 .32485 Mdot
.672 .32547 Mdot
.672 .32568 Mdot
.672 .3259 Mdot
.672 .32643 Mdot
.672 .32668 Mdot
.672 .32687 Mdot
.672 .32829 Mdot
.672 .32844 Mdot
.672 .32863 Mdot
.672 .32916 Mdot
.672 .32937 Mdot
.672 .32981 Mdot
.672 .33023 Mdot
.672 .3304 Mdot
.672 .33043 Mdot
.672 .3319 Mdot
.672 .33228 Mdot
.672 .33406 Mdot
.672 .33448 Mdot
.672 .33591 Mdot
.672 .3366 Mdot
.672 .33695 Mdot
.672 .33794 Mdot
.672 .33795 Mdot
.672 .3381 Mdot
.672 .33815 Mdot
.672 .33902 Mdot
.672 .33937 Mdot
.672 .33946 Mdot
.672 .33946 Mdot
.672 .33979 Mdot
.672 .34076 Mdot
.672 .34425 Mdot
.672 .3463 Mdot
.672 .34658 Mdot
.672 .34676 Mdot
.672 .3473 Mdot
.672 .34738 Mdot
.672 .34765 Mdot
.672 .34856 Mdot
.672 .34934 Mdot
.672 .3501 Mdot
.672 .35044 Mdot
.672 .35083 Mdot
.672 .35115 Mdot
.672 .35197 Mdot
.672 .35208 Mdot
.672 .35218 Mdot
.672 .3528 Mdot
.672 .35316 Mdot
.672 .35351 Mdot
.672 .35464 Mdot
.672 .35528 Mdot
.672 .35741 Mdot
.672 .35776 Mdot
.672 .358 Mdot
.672 .35882 Mdot
.672 .35938 Mdot
.672 .36012 Mdot
.672 .36106 Mdot
.672 .36122 Mdot
.672 .3637 Mdot
.672 .36475 Mdot
.672 .36475 Mdot
.672 .36619 Mdot
.672 .36694 Mdot
.672 .367 Mdot
.672 .36762 Mdot
.672 .36801 Mdot
.672 .36916 Mdot
.672 .36975 Mdot
.672 .37004 Mdot
.672 .37025 Mdot
.672 .37039 Mdot
.672 .37171 Mdot
.672 .37288 Mdot
.672 .37302 Mdot
.672 .37534 Mdot
.672 .37689 Mdot
.672 .37694 Mdot
.672 .37816 Mdot
.672 .3782 Mdot
.672 .3791 Mdot
.672 .38036 Mdot
.672 .38049 Mdot
.672 .38057 Mdot
.672 .38099 Mdot
.672 .38221 Mdot
.672 .38251 Mdot
.672 .38256 Mdot
.672 .38384 Mdot
.672 .38591 Mdot
.672 .3863 Mdot
.672 .38698 Mdot
.672 .38771 Mdot
.672 .38893 Mdot
.672 .38968 Mdot
.672 .39078 Mdot
.672 .39225 Mdot
.672 .39307 Mdot
.672 .39332 Mdot
.672 .3957 Mdot
.672 .39614 Mdot
.672 .39721 Mdot
.672 .3995 Mdot
.672 .40002 Mdot
.672 .40008 Mdot
.672 .40064 Mdot
.672 .40199 Mdot
.672 .40223 Mdot
.672 .40326 Mdot
.672 .40326 Mdot
.672 .40327 Mdot
.672 .40327 Mdot
.672 .40359 Mdot
.672 .40377 Mdot
.672 .40377 Mdot
.672 .40377 Mdot
.672 .40377 Mdot
.672 .40404 Mdot
.672 .40407 Mdot
.672 .4041 Mdot
.672 .40432 Mdot
.672 .40432 Mdot
.672 .40432 Mdot
.672 .40432 Mdot
.672 .40436 Mdot
.672 .40456 Mdot
.672 .40469 Mdot
.672 .40473 Mdot
.672 .40478 Mdot
.672 .40479 Mdot
.672 .40489 Mdot
.672 .40497 Mdot
.672 .40513 Mdot
.672 .40513 Mdot
.672 .40514 Mdot
.672 .40514 Mdot
.672 .4052 Mdot
.672 .40524 Mdot
.672 .40544 Mdot
.672 .40556 Mdot
.672 .4058 Mdot
.672 .40582 Mdot
.672 .4059 Mdot
.672 .406 Mdot
.672 .40601 Mdot
.672 .40621 Mdot
.672 .40639 Mdot
.672 .40664 Mdot
.672 .40667 Mdot
.672 .40676 Mdot
.672 .40676 Mdot
.672 .40677 Mdot
.672 .40678 Mdot
.672 .40692 Mdot
.672 .40701 Mdot
.672 .4075 Mdot
.672 .40764 Mdot
.672 .40781 Mdot
.672 .40789 Mdot
.672 .40795 Mdot
.672 .40846 Mdot
.672 .40852 Mdot
.672 .4087 Mdot
.672 .40876 Mdot
.672 .40891 Mdot
.672 .40904 Mdot
.672 .40909 Mdot
.672 .40958 Mdot
.672 .4097 Mdot
.672 .41027 Mdot
.672 .41041 Mdot
.672 .41087 Mdot
.672 .41109 Mdot
.672 .4112 Mdot
.672 .41152 Mdot
.672 .41152 Mdot
.672 .41157 Mdot
.672 .41159 Mdot
.672 .41186 Mdot
.672 .41197 Mdot
.672 .412 Mdot
.672 .412 Mdot
.672 .41211 Mdot
.672 .41242 Mdot
.672 .41353 Mdot
.672 .41427 Mdot
.672 .41433 Mdot
.672 .41461 Mdot
.672 .4149 Mdot
.672 .41515 Mdot
.672 .41539 Mdot
.672 .4155 Mdot
.672 .41562 Mdot
.672 .41572 Mdot
.672 .41598 Mdot
.672 .41602 Mdot
.672 .41605 Mdot
.672 .41625 Mdot
.672 .41647 Mdot
.672 .41683 Mdot
.672 .41703 Mdot
.672 .4177 Mdot
.672 .41789 Mdot
.672 .41815 Mdot
.672 .41832 Mdot
.672 .41856 Mdot
.672 .41885 Mdot
.672 .41968 Mdot
.672 .42002 Mdot
.672 .42002 Mdot
.672 .4207 Mdot
.672 .42072 Mdot
.672 .42104 Mdot
.672 .4214 Mdot
.672 .42168 Mdot
.672 .42174 Mdot
.672 .42179 Mdot
.672 .4222 Mdot
.672 .42257 Mdot
.672 .42262 Mdot
.672 .42383 Mdot
.672 .42385 Mdot
.672 .42423 Mdot
.672 .42424 Mdot
.672 .42453 Mdot
.672 .42492 Mdot
.672 .42499 Mdot
.672 .4256 Mdot
.672 .42561 Mdot
.672 .42601 Mdot
.672 .42679 Mdot
.672 .42761 Mdot
.672 .42785 Mdot
.672 .42819 Mdot
.672 .42891 Mdot
.672 .42899 Mdot
.672 .42974 Mdot
.672 .43112 Mdot
.672 .43172 Mdot
.672 .4318 Mdot
.672 .4332 Mdot
.672 .43391 Mdot
.672 .43412 Mdot
.672 .43453 Mdot
.672 .43589 Mdot
.672 .43597 Mdot
.672 .43601 Mdot
.672 .43632 Mdot
.672 .43643 Mdot
.672 .43802 Mdot
.672 .43828 Mdot
.672 .43904 Mdot
.672 .43924 Mdot
.672 .43924 Mdot
.672 .43937 Mdot
.672 .43996 Mdot
.672 .44122 Mdot
.672 .44213 Mdot
.672 .44371 Mdot
.672 .44513 Mdot
.672 .44706 Mdot
.672 .44951 Mdot
.672 .45027 Mdot
.672 .45219 Mdot
.672 .45242 Mdot
.672 .45373 Mdot
.672 .45525 Mdot
.672 .45582 Mdot
.672 .45595 Mdot
.672 .45639 Mdot
.672 .45681 Mdot
.672 .45702 Mdot
.672 .45703 Mdot
.672 .45735 Mdot
.672 .4576 Mdot
.672 .45775 Mdot
.672 .45796 Mdot
.672 .4586 Mdot
.672 .45863 Mdot
.672 .45904 Mdot
.672 .45961 Mdot
.672 .46094 Mdot
.672 .46162 Mdot
.672 .46181 Mdot
.672 .46202 Mdot
.672 .46231 Mdot
.672 .46236 Mdot
.672 .46249 Mdot
.672 .46293 Mdot
.672 .46467 Mdot
.672 .4649 Mdot
.672 .46532 Mdot
.672 .46566 Mdot
.672 .46576 Mdot
.672 .46616 Mdot
.672 .46678 Mdot
.672 .46679 Mdot
.672 .46762 Mdot
.672 .46783 Mdot
.672 .46898 Mdot
.672 .46909 Mdot
.672 .46976 Mdot
.672 .47003 Mdot
.672 .47006 Mdot
.672 .47032 Mdot
.672 .47143 Mdot
.672 .47195 Mdot
.672 .47216 Mdot
.672 .47331 Mdot
.672 .47342 Mdot
.672 .47381 Mdot
.672 .47452 Mdot
.672 .47504 Mdot
.672 .4754 Mdot
.672 .47597 Mdot
.672 .47632 Mdot
.672 .47664 Mdot
.672 .47682 Mdot
.672 .47778 Mdot
.672 .47838 Mdot
.672 .4784 Mdot
.672 .47854 Mdot
.672 .47911 Mdot
.672 .47931 Mdot
.672 .4794 Mdot
.672 .47998 Mdot
.672 .4804 Mdot
.672 .48041 Mdot
.672 .48097 Mdot
.672 .481 Mdot
.672 .48171 Mdot
.672 .48276 Mdot
.672 .48283 Mdot
.672 .48336 Mdot
.672 .48395 Mdot
.672 .48401 Mdot
.672 .4841 Mdot
.672 .48424 Mdot
.672 .4845 Mdot
.672 .48502 Mdot
.672 .48519 Mdot
.672 .48547 Mdot
.672 .4855 Mdot
.672 .48583 Mdot
.672 .48647 Mdot
.672 .48647 Mdot
.672 .48694 Mdot
.672 .48803 Mdot
.672 .4881 Mdot
.672 .48851 Mdot
.672 .48884 Mdot
.672 .48908 Mdot
.672 .48944 Mdot
.672 .48954 Mdot
.672 .4897 Mdot
.672 .49062 Mdot
.672 .4909 Mdot
.672 .49139 Mdot
.672 .49154 Mdot
.672 .49169 Mdot
.672 .49196 Mdot
.672 .492 Mdot
.672 .49205 Mdot
.672 .4924 Mdot
.672 .49254 Mdot
.672 .49271 Mdot
.672 .49285 Mdot
.672 .49318 Mdot
.672 .49351 Mdot
.672 .4939 Mdot
.672 .49402 Mdot
.672 .49405 Mdot
.672 .49428 Mdot
.672 .49436 Mdot
.672 .49448 Mdot
.672 .49534 Mdot
.672 .49681 Mdot
.672 .49722 Mdot
.672 .49736 Mdot
.672 .49736 Mdot
.672 .4974 Mdot
.672 .49754 Mdot
.672 .4979 Mdot
.672 .49793 Mdot
.672 .49799 Mdot
.672 .49799 Mdot
.672 .4984 Mdot
.672 .49855 Mdot
.672 .49884 Mdot
.672 .49943 Mdot
.672 .4996 Mdot
.672 .50034 Mdot
.672 .50049 Mdot
.672 .50109 Mdot
.672 .50111 Mdot
.672 .50118 Mdot
.672 .50135 Mdot
.672 .50153 Mdot
.672 .50161 Mdot
.672 .50183 Mdot
.672 .50191 Mdot
.672 .50197 Mdot
.672 .50255 Mdot
.672 .50263 Mdot
.672 .50273 Mdot
.672 .50294 Mdot
.672 .50303 Mdot
.672 .50312 Mdot
.672 .50337 Mdot
.672 .50373 Mdot
.672 .50384 Mdot
.672 .50387 Mdot
.672 .50387 Mdot
.672 .50402 Mdot
.672 .50402 Mdot
.672 .50404 Mdot
.672 .50404 Mdot
.672 .50415 Mdot
.672 .50419 Mdot
.672 .5045 Mdot
.672 .50472 Mdot
.672 .50496 Mdot
.672 .50499 Mdot
.672 .5051 Mdot
.672 .5052 Mdot
.672 .50523 Mdot
.672 .50546 Mdot
.672 .50553 Mdot
.672 .50567 Mdot
.672 .50592 Mdot
.672 .50596 Mdot
.672 .50604 Mdot
.672 .50604 Mdot
.672 .50604 Mdot
.672 .50605 Mdot
.672 .50624 Mdot
.672 .50635 Mdot
.672 .50646 Mdot
.672 .50647 Mdot
.672 .50653 Mdot
.672 .50658 Mdot
.672 .50674 Mdot
.672 .50682 Mdot
.672 .50698 Mdot
.672 .50703 Mdot
.672 .50703 Mdot
.672 .50703 Mdot
.672 .50703 Mdot
.672 .5073 Mdot
.672 .50733 Mdot
.672 .50737 Mdot
.672 .50766 Mdot
.672 .50769 Mdot
.672 .50769 Mdot
.672 .50769 Mdot
.672 .50769 Mdot
.672 .50791 Mdot
.672 .5083 Mdot
.672 .5083 Mdot
.672 .5083 Mdot
.672 .50831 Mdot
.672 .50858 Mdot
.672 .50953 Mdot
.672 .5096 Mdot
.672 .50976 Mdot
.672 .50982 Mdot
.672 .51137 Mdot
.672 .5114 Mdot
.672 .51205 Mdot
.672 .51212 Mdot
.672 .51237 Mdot
.672 .51272 Mdot
.672 .51368 Mdot
.672 .51528 Mdot
.672 .51532 Mdot
.672 .51643 Mdot
.672 .51651 Mdot
.672 .51678 Mdot
.672 .51695 Mdot
.672 .517 Mdot
.672 .51752 Mdot
.672 .51776 Mdot
.672 .51802 Mdot
.672 .51838 Mdot
.672 .51958 Mdot
.672 .51984 Mdot
.672 .52071 Mdot
.672 .52162 Mdot
.672 .52226 Mdot
.672 .52339 Mdot
.672 .52416 Mdot
.672 .52445 Mdot
.672 .5248 Mdot
.672 .52538 Mdot
.672 .52561 Mdot
.672 .52611 Mdot
.672 .52673 Mdot
.672 .52678 Mdot
.672 .52716 Mdot
.672 .52751 Mdot
.672 .52915 Mdot
.672 .53022 Mdot
.672 .53036 Mdot
.672 .53041 Mdot
.672 .53069 Mdot
.672 .53087 Mdot
.672 .53111 Mdot
.672 .53181 Mdot
.672 .5322 Mdot
.672 .53227 Mdot
.672 .53238 Mdot
.672 .53352 Mdot
.672 .53368 Mdot
.672 .5338 Mdot
.672 .53431 Mdot
.672 .53435 Mdot
.672 .53541 Mdot
.672 .53545 Mdot
.672 .53644 Mdot
.672 .53653 Mdot
.672 .53677 Mdot
.672 .53775 Mdot
.672 .53802 Mdot
.672 .53841 Mdot
.672 .53869 Mdot
.672 .53881 Mdot
.672 .53975 Mdot
.672 .54079 Mdot
.672 .5409 Mdot
.672 .54098 Mdot
.672 .54106 Mdot
.672 .54123 Mdot
.672 .54129 Mdot
.672 .54139 Mdot
.672 .54174 Mdot
.672 .54222 Mdot
.672 .54261 Mdot
.672 .5429 Mdot
.672 .54336 Mdot
.672 .5434 Mdot
.672 .54369 Mdot
.672 .54395 Mdot
.672 .54418 Mdot
.672 .54456 Mdot
.672 .54498 Mdot
.672 .54498 Mdot
.672 .54512 Mdot
.672 .54521 Mdot
.672 .54549 Mdot
.672 .54572 Mdot
.672 .5474 Mdot
.672 .54751 Mdot
.672 .54752 Mdot
.672 .54812 Mdot
.672 .5486 Mdot
.672 .54896 Mdot
.672 .54947 Mdot
.672 .54962 Mdot
.672 .54984 Mdot
.672 .55041 Mdot
.672 .55099 Mdot
.672 .55111 Mdot
.672 .55149 Mdot
.672 .5516 Mdot
.672 .55168 Mdot
.672 .55214 Mdot
.672 .55233 Mdot
.672 .55253 Mdot
.672 .55264 Mdot
.672 .55288 Mdot
.672 .55293 Mdot
.672 .55299 Mdot
.672 .55339 Mdot
.672 .55343 Mdot
.672 .5536 Mdot
.672 .55373 Mdot
.672 .55381 Mdot
.672 .55399 Mdot
.672 .55438 Mdot
.672 .55456 Mdot
.672 .55478 Mdot
.672 .55504 Mdot
.672 .55523 Mdot
.672 .55536 Mdot
.672 .5554 Mdot
.672 .55543 Mdot
.672 .55566 Mdot
.672 .55575 Mdot
.672 .55588 Mdot
.672 .55642 Mdot
.672 .55682 Mdot
.672 .55777 Mdot
.672 .55831 Mdot
.672 .55847 Mdot
.672 .5587 Mdot
.672 .55882 Mdot
.672 .55882 Mdot
.672 .55886 Mdot
.672 .55899 Mdot
.672 .55932 Mdot
.672 .55934 Mdot
.672 .55939 Mdot
.672 .5594 Mdot
.672 .55941 Mdot
.672 .55975 Mdot
.672 .55987 Mdot
.672 .56011 Mdot
.672 .56023 Mdot
.672 .56046 Mdot
.672 .56059 Mdot
.672 .56073 Mdot
.672 .56127 Mdot
.672 .56138 Mdot
.672 .56145 Mdot
.672 .56172 Mdot
.672 .56179 Mdot
.672 .5618 Mdot
.672 .56185 Mdot
.672 .56191 Mdot
.672 .56196 Mdot
.672 .56208 Mdot
.672 .56208 Mdot
.672 .56213 Mdot
.672 .56226 Mdot
.672 .56231 Mdot
.672 .56235 Mdot
.672 .56242 Mdot
.672 .56245 Mdot
.672 .56256 Mdot
.672 .56268 Mdot
.672 .56272 Mdot
.672 .56272 Mdot
.672 .56277 Mdot
.672 .56278 Mdot
.672 .5629 Mdot
.672 .56294 Mdot
.672 .56299 Mdot
.672 .56311 Mdot
.672 .56329 Mdot
.672 .56334 Mdot
.672 .56336 Mdot
.672 .56336 Mdot
.672 .56336 Mdot
.672 .56338 Mdot
.672 .56342 Mdot
.672 .56342 Mdot
.672 .56343 Mdot
.672 .56343 Mdot
.672 .56348 Mdot
.672 .5635 Mdot
.672 .56363 Mdot
.672 .56372 Mdot
.672 .56381 Mdot
.672 .56382 Mdot
.672 .56386 Mdot
.672 .5639 Mdot
.672 .56391 Mdot
.672 .56399 Mdot
.672 .56401 Mdot
.672 .56404 Mdot
.672 .56406 Mdot
.672 .56413 Mdot
.672 .56415 Mdot
.672 .56417 Mdot
.672 .56417 Mdot
.672 .56417 Mdot
.672 .56417 Mdot
.672 .56423 Mdot
.672 .56426 Mdot
.672 .56429 Mdot
.672 .56429 Mdot
.672 .5643 Mdot
.672 .56432 Mdot
.672 .56432 Mdot
.672 .56436 Mdot
.672 .56437 Mdot
.672 .56441 Mdot
.672 .56441 Mdot
.672 .56442 Mdot
.672 .56442 Mdot
.672 .56442 Mdot
.672 .56442 Mdot
.672 .56446 Mdot
.672 .56447 Mdot
.672 .56447 Mdot
.672 .56448 Mdot
.672 .56449 Mdot
.672 .56454 Mdot
.672 .56454 Mdot
.672 .56454 Mdot
.672 .56455 Mdot
.672 .56455 Mdot
.672 .56458 Mdot
.672 .56458 Mdot
.672 .56459 Mdot
.672 .56463 Mdot
.672 .56463 Mdot
.672 .56463 Mdot
.672 .56463 Mdot
.672 .56466 Mdot
.672 .56471 Mdot
.672 .56471 Mdot
.672 .56471 Mdot
.672 .56471 Mdot
.674 .14887 Mdot
.674 .30832 Mdot
.674 .40201 Mdot
.674 .51 Mdot
.674 .56494 Mdot
.676 .1484 Mdot
.676 .30553 Mdot
.676 .40122 Mdot
.676 .51114 Mdot
.676 .5651 Mdot
.678 .14747 Mdot
.678 .14916 Mdot
.678 .2999 Mdot
.678 .3103 Mdot
.678 .39949 Mdot
.678 .40294 Mdot
.678 .50933 Mdot
.678 .51337 Mdot
.678 .56488 Mdot
.678 .5654 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14673 Mdot
.68 .14674 Mdot
.68 .14674 Mdot
.68 .14674 Mdot
.68 .14674 Mdot
.68 .14674 Mdot
.68 .14674 Mdot
.68 .14674 Mdot
.68 .14674 Mdot
.68 .14674 Mdot
.68 .14675 Mdot
.68 .14675 Mdot
.68 .14675 Mdot
.68 .14675 Mdot
.68 .14676 Mdot
.68 .14676 Mdot
.68 .14676 Mdot
.68 .14676 Mdot
.68 .14677 Mdot
.68 .14678 Mdot
.68 .14678 Mdot
.68 .14678 Mdot
.68 .1468 Mdot
.68 .1468 Mdot
.68 .14681 Mdot
.68 .14682 Mdot
.68 .14682 Mdot
.68 .14683 Mdot
.68 .14689 Mdot
.68 .1469 Mdot
.68 .1469 Mdot
.68 .1469 Mdot
.68 .14692 Mdot
.68 .14697 Mdot
.68 .14698 Mdot
.68 .14706 Mdot
.68 .14707 Mdot
.68 .1471 Mdot
.68 .14715 Mdot
.68 .14717 Mdot
.68 .1472 Mdot
.68 .14723 Mdot
.68 .14725 Mdot
.68 .14726 Mdot
.68 .14728 Mdot
.68 .14735 Mdot
.68 .14736 Mdot
.68 .14739 Mdot
.68 .14754 Mdot
.68 .14757 Mdot
.68 .14761 Mdot
.68 .14764 Mdot
.68 .14766 Mdot
.68 .14772 Mdot
.68 .14791 Mdot
.68 .14802 Mdot
.68 .14804 Mdot
.68 .14805 Mdot
.68 .14812 Mdot
.68 .14815 Mdot
.68 .14817 Mdot
.68 .14819 Mdot
.68 .14821 Mdot
.68 .14826 Mdot
.68 .14828 Mdot
.68 .14829 Mdot
.68 .14845 Mdot
.68 .14847 Mdot
.68 .14848 Mdot
.68 .14849 Mdot
.68 .14857 Mdot
.68 .1486 Mdot
.68 .1486 Mdot
.68 .14863 Mdot
.68 .14863 Mdot
.68 .14869 Mdot
.68 .14869 Mdot
.68 .14869 Mdot
.68 .14872 Mdot
.68 .14873 Mdot
.68 .14873 Mdot
.68 .14874 Mdot
.68 .14877 Mdot
.68 .14877 Mdot
.68 .14878 Mdot
.68 .14879 Mdot
.68 .14879 Mdot
.68 .1488 Mdot
.68 .14881 Mdot
.68 .14881 Mdot
.68 .14882 Mdot
.68 .14882 Mdot
.68 .14883 Mdot
.68 .14883 Mdot
.68 .14884 Mdot
.68 .14884 Mdot
.68 .14884 Mdot
.68 .14885 Mdot
.68 .14885 Mdot
.68 .14885 Mdot
.68 .14886 Mdot
.68 .14886 Mdot
.68 .14886 Mdot
.68 .14886 Mdot
.68 .14887 Mdot
.68 .14887 Mdot
.68 .14887 Mdot
.68 .14887 Mdot
.68 .14888 Mdot
.68 .14888 Mdot
.68 .14889 Mdot
.68 .14889 Mdot
.68 .1489 Mdot
.68 .14896 Mdot
.68 .14899 Mdot
.68 .14905 Mdot
.68 .14912 Mdot
.68 .14919 Mdot
.68 .14927 Mdot
.68 .14941 Mdot
.68 .1495 Mdot
.68 .1495 Mdot
.68 .14974 Mdot
.68 .14977 Mdot
.68 .14994 Mdot
.68 .14999 Mdot
.68 .15001 Mdot
.68 .15002 Mdot
.68 .15005 Mdot
.68 .15022 Mdot
.68 .15027 Mdot
.68 .15028 Mdot
.68 .15029 Mdot
.68 .15032 Mdot
.68 .15033 Mdot
.68 .1504 Mdot
.68 .15041 Mdot
.68 .15042 Mdot
.68 .15042 Mdot
.68 .15046 Mdot
.68 .15047 Mdot
.68 .15047 Mdot
.68 .15048 Mdot
.68 .15049 Mdot
.68 .1505 Mdot
.68 .15051 Mdot
.68 .15052 Mdot
.68 .15052 Mdot
.68 .15053 Mdot
.68 .15053 Mdot
.68 .15053 Mdot
.68 .15054 Mdot
.68 .15054 Mdot
.68 .15054 Mdot
.68 .15055 Mdot
.68 .15055 Mdot
.68 .15055 Mdot
.68 .15055 Mdot
.68 .15056 Mdot
.68 .15056 Mdot
.68 .15056 Mdot
.68 .15056 Mdot
.68 .15056 Mdot
.68 .15056 Mdot
.68 .15057 Mdot
.68 .15057 Mdot
.68 .15057 Mdot
.68 .15057 Mdot
.68 .15057 Mdot
.68 .15057 Mdot
.68 .15057 Mdot
.68 .15057 Mdot
.68 .15057 Mdot
.68 .15057 Mdot
.68 .15058 Mdot
.68 .15058 Mdot
.68 .15058 Mdot
.68 .15058 Mdot
.68 .15058 Mdot
.68 .29537 Mdot
.68 .29538 Mdot
.68 .29538 Mdot
.68 .29538 Mdot
.68 .29539 Mdot
.68 .29539 Mdot
.68 .29539 Mdot
.68 .29539 Mdot
.68 .29539 Mdot
.68 .29539 Mdot
.68 .2954 Mdot
.68 .2954 Mdot
.68 .2954 Mdot
.68 .2954 Mdot
.68 .2954 Mdot
.68 .29541 Mdot
.68 .29541 Mdot
.68 .29541 Mdot
.68 .29541 Mdot
.68 .29542 Mdot
.68 .29542 Mdot
.68 .29542 Mdot
.68 .29543 Mdot
.68 .29543 Mdot
.68 .29543 Mdot
.68 .29544 Mdot
.68 .29545 Mdot
.68 .29545 Mdot
.68 .29546 Mdot
.68 .29546 Mdot
.68 .29548 Mdot
.68 .29549 Mdot
.68 .29549 Mdot
.68 .29551 Mdot
.68 .29551 Mdot
.68 .29554 Mdot
.68 .29555 Mdot
.68 .29558 Mdot
.68 .29558 Mdot
.68 .2956 Mdot
.68 .29566 Mdot
.68 .29567 Mdot
.68 .29567 Mdot
.68 .2957 Mdot
.68 .29582 Mdot
.68 .29585 Mdot
.68 .2959 Mdot
.68 .29592 Mdot
.68 .29594 Mdot
.68 .29603 Mdot
.68 .29635 Mdot
.68 .29642 Mdot
.68 .29643 Mdot
.68 .29647 Mdot
.68 .29656 Mdot
.68 .2969 Mdot
.68 .29695 Mdot
.68 .29744 Mdot
.68 .29746 Mdot
.68 .29764 Mdot
.68 .29795 Mdot
.68 .29811 Mdot
.68 .29827 Mdot
.68 .29844 Mdot
.68 .29857 Mdot
.68 .29863 Mdot
.68 .29878 Mdot
.68 .29918 Mdot
.68 .29929 Mdot
.68 .29945 Mdot
.68 .30035 Mdot
.68 .30055 Mdot
.68 .30082 Mdot
.68 .30101 Mdot
.68 .30111 Mdot
.68 .30147 Mdot
.68 .30264 Mdot
.68 .30337 Mdot
.68 .30348 Mdot
.68 .30355 Mdot
.68 .30396 Mdot
.68 .30411 Mdot
.68 .30425 Mdot
.68 .30439 Mdot
.68 .30452 Mdot
.68 .3048 Mdot
.68 .30497 Mdot
.68 .30499 Mdot
.68 .30597 Mdot
.68 .30613 Mdot
.68 .30615 Mdot
.68 .30624 Mdot
.68 .30674 Mdot
.68 .3069 Mdot
.68 .30694 Mdot
.68 .30709 Mdot
.68 .30714 Mdot
.68 .30747 Mdot
.68 .30748 Mdot
.68 .30751 Mdot
.68 .30767 Mdot
.68 .30773 Mdot
.68 .30775 Mdot
.68 .30782 Mdot
.68 .30796 Mdot
.68 .30797 Mdot
.68 .30804 Mdot
.68 .30807 Mdot
.68 .30811 Mdot
.68 .30818 Mdot
.68 .30823 Mdot
.68 .30825 Mdot
.68 .30827 Mdot
.68 .30831 Mdot
.68 .30835 Mdot
.68 .30837 Mdot
.68 .3084 Mdot
.68 .30843 Mdot
.68 .30844 Mdot
.68 .30846 Mdot
.68 .30848 Mdot
.68 .30849 Mdot
.68 .30851 Mdot
.68 .30853 Mdot
.68 .30854 Mdot
.68 .30856 Mdot
.68 .30858 Mdot
.68 .30859 Mdot
.68 .30861 Mdot
.68 .30863 Mdot
.68 .30864 Mdot
.68 .30866 Mdot
.68 .3087 Mdot
.68 .30873 Mdot
.68 .30879 Mdot
.68 .30918 Mdot
.68 .30935 Mdot
.68 .30969 Mdot
.68 .31016 Mdot
.68 .31061 Mdot
.68 .31106 Mdot
.68 .31195 Mdot
.68 .31248 Mdot
.68 .31254 Mdot
.68 .31402 Mdot
.68 .31418 Mdot
.68 .31526 Mdot
.68 .31555 Mdot
.68 .31566 Mdot
.68 .31572 Mdot
.68 .31593 Mdot
.68 .31698 Mdot
.68 .31729 Mdot
.68 .31735 Mdot
.68 .31741 Mdot
.68 .31761 Mdot
.68 .31769 Mdot
.68 .31812 Mdot
.68 .31819 Mdot
.68 .3182 Mdot
.68 .31824 Mdot
.68 .31844 Mdot
.68 .31851 Mdot
.68 .31853 Mdot
.68 .31861 Mdot
.68 .31866 Mdot
.68 .31874 Mdot
.68 .31876 Mdot
.68 .31882 Mdot
.68 .31885 Mdot
.68 .31888 Mdot
.68 .31893 Mdot
.68 .31894 Mdot
.68 .31897 Mdot
.68 .31898 Mdot
.68 .319 Mdot
.68 .31902 Mdot
.68 .31904 Mdot
.68 .31905 Mdot
.68 .31906 Mdot
.68 .31907 Mdot
.68 .31909 Mdot
.68 .3191 Mdot
.68 .31911 Mdot
.68 .31912 Mdot
.68 .31912 Mdot
.68 .31913 Mdot
.68 .31914 Mdot
.68 .31914 Mdot
.68 .31915 Mdot
.68 .31916 Mdot
.68 .31916 Mdot
.68 .31917 Mdot
.68 .31918 Mdot
.68 .31918 Mdot
.68 .31919 Mdot
.68 .31919 Mdot
.68 .3192 Mdot
.68 .31921 Mdot
.68 .31922 Mdot
.68 .31923 Mdot
.68 .39812 Mdot
.68 .39812 Mdot
.68 .39812 Mdot
.68 .39812 Mdot
.68 .39812 Mdot
.68 .39812 Mdot
.68 .39812 Mdot
.68 .39812 Mdot
.68 .39812 Mdot
.68 .39813 Mdot
.68 .39813 Mdot
.68 .39813 Mdot
.68 .39813 Mdot
.68 .39813 Mdot
.68 .39813 Mdot
.68 .39813 Mdot
.68 .39813 Mdot
.68 .39813 Mdot
.68 .39813 Mdot
.68 .39813 Mdot
.68 .39813 Mdot
.68 .39814 Mdot
.68 .39814 Mdot
.68 .39814 Mdot
.68 .39814 Mdot
.68 .39814 Mdot
.68 .39814 Mdot
.68 .39814 Mdot
.68 .39815 Mdot
.68 .39815 Mdot
.68 .39816 Mdot
.68 .39816 Mdot
.68 .39816 Mdot
.68 .39817 Mdot
.68 .39817 Mdot
.68 .39818 Mdot
.68 .39819 Mdot
.68 .39819 Mdot
.68 .39819 Mdot
.68 .39821 Mdot
.68 .39822 Mdot
.68 .39822 Mdot
.68 .39823 Mdot
.68 .39827 Mdot
.68 .39828 Mdot
.68 .3983 Mdot
.68 .3983 Mdot
.68 .39831 Mdot
.68 .39834 Mdot
.68 .39845 Mdot
.68 .39847 Mdot
.68 .39847 Mdot
.68 .39849 Mdot
.68 .39852 Mdot
.68 .39863 Mdot
.68 .39865 Mdot
.68 .39881 Mdot
.68 .39882 Mdot
.68 .39888 Mdot
.68 .39898 Mdot
.68 .39903 Mdot
.68 .39909 Mdot
.68 .39915 Mdot
.68 .39919 Mdot
.68 .39921 Mdot
.68 .39926 Mdot
.68 .39939 Mdot
.68 .39943 Mdot
.68 .39948 Mdot
.68 .39978 Mdot
.68 .39985 Mdot
.68 .39994 Mdot
.68 .40001 Mdot
.68 .40004 Mdot
.68 .40016 Mdot
.68 .40055 Mdot
.68 .40079 Mdot
.68 .40082 Mdot
.68 .40085 Mdot
.68 .40099 Mdot
.68 .40103 Mdot
.68 .40108 Mdot
.68 .40113 Mdot
.68 .40117 Mdot
.68 .40126 Mdot
.68 .40132 Mdot
.68 .40132 Mdot
.68 .40165 Mdot
.68 .4017 Mdot
.68 .40171 Mdot
.68 .40174 Mdot
.68 .4019 Mdot
.68 .40196 Mdot
.68 .40197 Mdot
.68 .40202 Mdot
.68 .40203 Mdot
.68 .40214 Mdot
.68 .40215 Mdot
.68 .40216 Mdot
.68 .40221 Mdot
.68 .40223 Mdot
.68 .40223 Mdot
.68 .40226 Mdot
.68 .4023 Mdot
.68 .40231 Mdot
.68 .40233 Mdot
.68 .40234 Mdot
.68 .40236 Mdot
.68 .40238 Mdot
.68 .40239 Mdot
.68 .4024 Mdot
.68 .40241 Mdot
.68 .40242 Mdot
.68 .40243 Mdot
.68 .40244 Mdot
.68 .40245 Mdot
.68 .40246 Mdot
.68 .40246 Mdot
.68 .40247 Mdot
.68 .40248 Mdot
.68 .40248 Mdot
.68 .40249 Mdot
.68 .40249 Mdot
.68 .4025 Mdot
.68 .4025 Mdot
.68 .40251 Mdot
.68 .40251 Mdot
.68 .40252 Mdot
.68 .40252 Mdot
.68 .40253 Mdot
.68 .40253 Mdot
.68 .40255 Mdot
.68 .40256 Mdot
.68 .40258 Mdot
.68 .40271 Mdot
.68 .40276 Mdot
.68 .40287 Mdot
.68 .40303 Mdot
.68 .40318 Mdot
.68 .40332 Mdot
.68 .40361 Mdot
.68 .40379 Mdot
.68 .40381 Mdot
.68 .40429 Mdot
.68 .40434 Mdot
.68 .40469 Mdot
.68 .40479 Mdot
.68 .40483 Mdot
.68 .40484 Mdot
.68 .40491 Mdot
.68 .40525 Mdot
.68 .40535 Mdot
.68 .40537 Mdot
.68 .40539 Mdot
.68 .40546 Mdot
.68 .40548 Mdot
.68 .40562 Mdot
.68 .40565 Mdot
.68 .40565 Mdot
.68 .40566 Mdot
.68 .40573 Mdot
.68 .40575 Mdot
.68 .40575 Mdot
.68 .40578 Mdot
.68 .4058 Mdot
.68 .40582 Mdot
.68 .40583 Mdot
.68 .40585 Mdot
.68 .40586 Mdot
.68 .40587 Mdot
.68 .40589 Mdot
.68 .40589 Mdot
.68 .4059 Mdot
.68 .4059 Mdot
.68 .40591 Mdot
.68 .40592 Mdot
.68 .40592 Mdot
.68 .40592 Mdot
.68 .40593 Mdot
.68 .40593 Mdot
.68 .40594 Mdot
.68 .40594 Mdot
.68 .40594 Mdot
.68 .40595 Mdot
.68 .40595 Mdot
.68 .40595 Mdot
.68 .40595 Mdot
.68 .40595 Mdot
.68 .40596 Mdot
.68 .40596 Mdot
.68 .40596 Mdot
.68 .40596 Mdot
.68 .40597 Mdot
.68 .40597 Mdot
.68 .40597 Mdot
.68 .40597 Mdot
.68 .40597 Mdot
.68 .40597 Mdot
.68 .40598 Mdot
.68 .40598 Mdot
.68 .50584 Mdot
.68 .50585 Mdot
.68 .50585 Mdot
.68 .50585 Mdot
.68 .50586 Mdot
.68 .50586 Mdot
.68 .50586 Mdot
.68 .50586 Mdot
.68 .50587 Mdot
.68 .50587 Mdot
.68 .50587 Mdot
.68 .50587 Mdot
.68 .50588 Mdot
.68 .50588 Mdot
.68 .50588 Mdot
.68 .50588 Mdot
.68 .50589 Mdot
.68 .50589 Mdot
.68 .5059 Mdot
.68 .5059 Mdot
.68 .5059 Mdot
.68 .50591 Mdot
.68 .50591 Mdot
.68 .50592 Mdot
.68 .50592 Mdot
.68 .50594 Mdot
.68 .50594 Mdot
.68 .50595 Mdot
.68 .50596 Mdot
.68 .50596 Mdot
.68 .50598 Mdot
.68 .50599 Mdot
.68 .506 Mdot
.68 .50603 Mdot
.68 .50604 Mdot
.68 .50607 Mdot
.68 .50609 Mdot
.68 .50612 Mdot
.68 .50613 Mdot
.68 .50616 Mdot
.68 .50624 Mdot
.68 .50625 Mdot
.68 .50626 Mdot
.68 .50628 Mdot
.68 .50646 Mdot
.68 .50649 Mdot
.68 .50657 Mdot
.68 .50659 Mdot
.68 .50662 Mdot
.68 .50674 Mdot
.68 .50716 Mdot
.68 .50724 Mdot
.68 .50726 Mdot
.68 .50731 Mdot
.68 .50742 Mdot
.68 .50785 Mdot
.68 .50791 Mdot
.68 .5085 Mdot
.68 .50852 Mdot
.68 .50873 Mdot
.68 .50908 Mdot
.68 .50925 Mdot
.68 .50943 Mdot
.68 .50962 Mdot
.68 .50975 Mdot
.68 .50982 Mdot
.68 .50997 Mdot
.68 .50999 Mdot
.68 .51 Mdot
.68 .51002 Mdot
.68 .51003 Mdot
.68 .51003 Mdot
.68 .51004 Mdot
.68 .51005 Mdot
.68 .51005 Mdot
.68 .51006 Mdot
.68 .51006 Mdot
.68 .51007 Mdot
.68 .51008 Mdot
.68 .51008 Mdot
.68 .51009 Mdot
.68 .5101 Mdot
.68 .5101 Mdot
.68 .51011 Mdot
.68 .51012 Mdot
.68 .51013 Mdot
.68 .51014 Mdot
.68 .51015 Mdot
.68 .51017 Mdot
.68 .51018 Mdot
.68 .51019 Mdot
.68 .51021 Mdot
.68 .51023 Mdot
.68 .51025 Mdot
.68 .51026 Mdot
.68 .51029 Mdot
.68 .51029 Mdot
.68 .51035 Mdot
.68 .51038 Mdot
.68 .51038 Mdot
.68 .5104 Mdot
.68 .51047 Mdot
.68 .51048 Mdot
.68 .51048 Mdot
.68 .51061 Mdot
.68 .51063 Mdot
.68 .51069 Mdot
.68 .5107 Mdot
.68 .51077 Mdot
.68 .51096 Mdot
.68 .511 Mdot
.68 .51101 Mdot
.68 .51107 Mdot
.68 .51145 Mdot
.68 .51146 Mdot
.68 .51152 Mdot
.68 .51163 Mdot
.68 .51168 Mdot
.68 .51174 Mdot
.68 .51179 Mdot
.68 .51185 Mdot
.68 .51201 Mdot
.68 .51204 Mdot
.68 .51208 Mdot
.68 .51236 Mdot
.68 .51281 Mdot
.68 .51295 Mdot
.68 .51299 Mdot
.68 .51306 Mdot
.68 .51316 Mdot
.68 .51324 Mdot
.68 .51359 Mdot
.68 .51365 Mdot
.68 .51369 Mdot
.68 .51385 Mdot
.68 .5139 Mdot
.68 .51393 Mdot
.68 .51398 Mdot
.68 .51404 Mdot
.68 .5141 Mdot
.68 .51417 Mdot
.68 .51428 Mdot
.68 .51435 Mdot
.68 .51436 Mdot
.68 .51455 Mdot
.68 .51457 Mdot
.68 .5147 Mdot
.68 .51473 Mdot
.68 .51475 Mdot
.68 .51475 Mdot
.68 .51478 Mdot
.68 .5149 Mdot
.68 .51493 Mdot
.68 .51494 Mdot
.68 .51495 Mdot
.68 .51497 Mdot
.68 .51498 Mdot
.68 .51503 Mdot
.68 .51503 Mdot
.68 .51504 Mdot
.68 .51504 Mdot
.68 .51506 Mdot
.68 .51507 Mdot
.68 .51507 Mdot
.68 .51508 Mdot
.68 .51509 Mdot
.68 .5151 Mdot
.68 .5151 Mdot
.68 .5151 Mdot
.68 .51511 Mdot
.68 .51511 Mdot
.68 .51512 Mdot
.68 .51512 Mdot
.68 .51512 Mdot
.68 .51512 Mdot
.68 .51513 Mdot
.68 .51513 Mdot
.68 .51513 Mdot
.68 .51513 Mdot
.68 .51513 Mdot
.68 .51513 Mdot
.68 .51513 Mdot
.68 .51514 Mdot
.68 .51514 Mdot
.68 .51514 Mdot
.68 .51514 Mdot
.68 .51514 Mdot
.68 .51514 Mdot
.68 .51514 Mdot
.68 .51514 Mdot
.68 .51514 Mdot
.68 .51514 Mdot
.68 .51514 Mdot
.68 .51514 Mdot
.68 .51514 Mdot
.68 .51514 Mdot
.68 .51515 Mdot
.68 .51515 Mdot
.68 .51515 Mdot
.68 .51515 Mdot
.68 .56446 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56447 Mdot
.68 .56448 Mdot
.68 .56448 Mdot
.68 .56448 Mdot
.68 .56448 Mdot
.68 .56448 Mdot
.68 .56448 Mdot
.68 .56448 Mdot
.68 .56448 Mdot
.68 .56449 Mdot
.68 .56449 Mdot
.68 .56449 Mdot
.68 .56449 Mdot
.68 .5645 Mdot
.68 .5645 Mdot
.68 .5645 Mdot
.68 .5645 Mdot
.68 .56451 Mdot
.68 .56452 Mdot
.68 .56452 Mdot
.68 .56452 Mdot
.68 .56454 Mdot
.68 .56455 Mdot
.68 .56455 Mdot
.68 .56456 Mdot
.68 .56456 Mdot
.68 .56458 Mdot
.68 .56463 Mdot
.68 .56464 Mdot
.68 .56464 Mdot
.68 .56465 Mdot
.68 .56466 Mdot
.68 .56471 Mdot
.68 .56472 Mdot
.68 .5648 Mdot
.68 .5648 Mdot
.68 .56483 Mdot
.68 .56487 Mdot
.68 .56489 Mdot
.68 .56491 Mdot
.68 .56494 Mdot
.68 .56495 Mdot
.68 .56496 Mdot
.68 .56498 Mdot
.68 .56498 Mdot
.68 .56499 Mdot
.68 .56499 Mdot
.68 .56499 Mdot
.68 .56499 Mdot
.68 .56499 Mdot
.68 .56499 Mdot
.68 .56499 Mdot
.68 .56499 Mdot
.68 .56499 Mdot
.68 .56499 Mdot
.68 .565 Mdot
.68 .565 Mdot
.68 .565 Mdot
.68 .565 Mdot
.68 .565 Mdot
.68 .565 Mdot
.68 .565 Mdot
.68 .565 Mdot
.68 .565 Mdot
.68 .56501 Mdot
.68 .56501 Mdot
.68 .56501 Mdot
.68 .56501 Mdot
.68 .56501 Mdot
.68 .56502 Mdot
.68 .56502 Mdot
.68 .56502 Mdot
.68 .56502 Mdot
.68 .56502 Mdot
.68 .56503 Mdot
.68 .56503 Mdot
.68 .56503 Mdot
.68 .56504 Mdot
.68 .56505 Mdot
.68 .56505 Mdot
.68 .56505 Mdot
.68 .56506 Mdot
.68 .56507 Mdot
.68 .56507 Mdot
.68 .56508 Mdot
.68 .56508 Mdot
.68 .56511 Mdot
.68 .56511 Mdot
.68 .56511 Mdot
.68 .56512 Mdot
.68 .56517 Mdot
.68 .56517 Mdot
.68 .56518 Mdot
.68 .56519 Mdot
.68 .5652 Mdot
.68 .56521 Mdot
.68 .56521 Mdot
.68 .56522 Mdot
.68 .56524 Mdot
.68 .56525 Mdot
.68 .56525 Mdot
.68 .56529 Mdot
.68 .56534 Mdot
.68 .56536 Mdot
.68 .56537 Mdot
.68 .56538 Mdot
.68 .56539 Mdot
.68 .5654 Mdot
.68 .56545 Mdot
.68 .56545 Mdot
.68 .56546 Mdot
.68 .56548 Mdot
.68 .56549 Mdot
.68 .56549 Mdot
.68 .5655 Mdot
.68 .5655 Mdot
.68 .56551 Mdot
.68 .56552 Mdot
.68 .56554 Mdot
.68 .56554 Mdot
.68 .56555 Mdot
.68 .56557 Mdot
.68 .56557 Mdot
.68 .56559 Mdot
.68 .56559 Mdot
.68 .5656 Mdot
.68 .5656 Mdot
.68 .5656 Mdot
.68 .56562 Mdot
.68 .56562 Mdot
.68 .56562 Mdot
.68 .56562 Mdot
.68 .56562 Mdot
.68 .56563 Mdot
.68 .56563 Mdot
.68 .56563 Mdot
.68 .56563 Mdot
.68 .56563 Mdot
.68 .56564 Mdot
.68 .56564 Mdot
.68 .56564 Mdot
.68 .56564 Mdot
.68 .56564 Mdot
.68 .56564 Mdot
.68 .56564 Mdot
.68 .56564 Mdot
.68 .56564 Mdot
.68 .56564 Mdot
.68 .56564 Mdot
.68 .56564 Mdot
.68 .56564 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.68 .56565 Mdot
.682 .14601 Mdot
.682 .14602 Mdot
.682 .14603 Mdot
.682 .14604 Mdot
.682 .14609 Mdot
.682 .1461 Mdot
.682 .14612 Mdot
.682 .14612 Mdot
.682 .14616 Mdot
.682 .1462 Mdot
.682 .1462 Mdot
.682 .14621 Mdot
.682 .14636 Mdot
.682 .14637 Mdot
.682 .14643 Mdot
.682 .14652 Mdot
.682 .14656 Mdot
.682 .14659 Mdot
.682 .14661 Mdot
.682 .14671 Mdot
.682 .14672 Mdot
.682 .14676 Mdot
.682 .14677 Mdot
.682 .14679 Mdot
.682 .14686 Mdot
.682 .14689 Mdot
.682 .14696 Mdot
.682 .14698 Mdot
.682 .14702 Mdot
.682 .14712 Mdot
.682 .14718 Mdot
.682 .14739 Mdot
.682 .14742 Mdot
.682 .14743 Mdot
.682 .14746 Mdot
.682 .14751 Mdot
.682 .14755 Mdot
.682 .14758 Mdot
.682 .1476 Mdot
.682 .14761 Mdot
.682 .14771 Mdot
.682 .1478 Mdot
.682 .14782 Mdot
.682 .14787 Mdot
.682 .14789 Mdot
.682 .14796 Mdot
.682 .14806 Mdot
.682 .14827 Mdot
.682 .14843 Mdot
.682 .1485 Mdot
.682 .1486 Mdot
.682 .14861 Mdot
.682 .1489 Mdot
.682 .14902 Mdot
.682 .14907 Mdot
.682 .14928 Mdot
.682 .14929 Mdot
.682 .1494 Mdot
.682 .14959 Mdot
.682 .14964 Mdot
.682 .14972 Mdot
.682 .14975 Mdot
.682 .14977 Mdot
.682 .14986 Mdot
.682 .14989 Mdot
.682 .1499 Mdot
.682 .1501 Mdot
.682 .15025 Mdot
.682 .15031 Mdot
.682 .15033 Mdot
.682 .15044 Mdot
.682 .15048 Mdot
.682 .15051 Mdot
.682 .15059 Mdot
.682 .15094 Mdot
.682 .15103 Mdot
.682 .15117 Mdot
.682 .15123 Mdot
.682 .15128 Mdot
.682 .15185 Mdot
.682 .15187 Mdot
.682 .15191 Mdot
.682 .15206 Mdot
.682 .15222 Mdot
.682 .15225 Mdot
.682 .15233 Mdot
.682 .15236 Mdot
.682 .15258 Mdot
.682 .15263 Mdot
.682 .15267 Mdot
.682 .15271 Mdot
.682 .15295 Mdot
.682 .15296 Mdot
.682 .153 Mdot
.682 .1532 Mdot
.682 .15397 Mdot
.682 .15397 Mdot
.682 .15413 Mdot
.682 .15417 Mdot
.682 .15476 Mdot
.682 .15491 Mdot
.682 .15503 Mdot
.682 .15537 Mdot
.682 .15554 Mdot
.682 .15595 Mdot
.682 .15619 Mdot
.682 .1566 Mdot
.682 .15677 Mdot
.682 .15708 Mdot
.682 .15735 Mdot
.682 .15756 Mdot
.682 .15877 Mdot
.682 .15904 Mdot
.682 .15912 Mdot
.682 .15938 Mdot
.682 .1607 Mdot
.682 .16118 Mdot
.682 .16142 Mdot
.682 .16179 Mdot
.682 .16333 Mdot
.682 .16463 Mdot
.682 .16536 Mdot
.682 .16639 Mdot
.682 .16641 Mdot
.682 .16772 Mdot
.682 .16808 Mdot
.682 .16818 Mdot
.682 .17056 Mdot
.682 .1729 Mdot
.682 .17302 Mdot
.682 .17318 Mdot
.682 .17463 Mdot
.682 .17489 Mdot
.682 .17575 Mdot
.682 .17784 Mdot
.682 .17905 Mdot
.682 .17919 Mdot
.682 .18014 Mdot
.682 .18049 Mdot
.682 .18064 Mdot
.682 .1812 Mdot
.682 .18153 Mdot
.682 .18239 Mdot
.682 .18296 Mdot
.682 .18345 Mdot
.682 .18358 Mdot
.682 .18456 Mdot
.682 .18511 Mdot
.682 .18601 Mdot
.682 .18683 Mdot
.682 .18711 Mdot
.682 .18731 Mdot
.682 .18776 Mdot
.682 .18886 Mdot
.682 .19086 Mdot
.682 .19148 Mdot
.682 .19168 Mdot
.682 .19245 Mdot
.682 .1928 Mdot
.682 .19436 Mdot
.682 .19743 Mdot
.682 .19821 Mdot
.682 .19862 Mdot
.682 .19897 Mdot
.682 .20024 Mdot
.682 .20058 Mdot
.682 .20088 Mdot
.682 .20152 Mdot
.682 .20321 Mdot
.682 .20361 Mdot
.682 .20363 Mdot
.682 .20415 Mdot
.682 .20723 Mdot
.682 .20794 Mdot
.682 .20891 Mdot
.682 .21304 Mdot
.682 .21564 Mdot
.682 .22054 Mdot
.682 .22184 Mdot
.682 .22443 Mdot
.682 .22454 Mdot
.682 .22558 Mdot
.682 .22869 Mdot
.682 .2295 Mdot
.682 .22969 Mdot
.682 .22981 Mdot
.682 .22991 Mdot
.682 .23158 Mdot
.682 .2332 Mdot
.682 .23824 Mdot
.682 .24377 Mdot
.682 .24427 Mdot
.682 .24601 Mdot
.682 .24716 Mdot
.682 .24987 Mdot
.682 .25103 Mdot
.682 .25371 Mdot
.682 .25544 Mdot
.682 .25709 Mdot
.682 .25772 Mdot
.682 .2609 Mdot
.682 .26149 Mdot
.682 .2616 Mdot
.682 .26462 Mdot
.682 .26546 Mdot
.682 .2661 Mdot
.682 .26639 Mdot
.682 .26673 Mdot
.682 .26725 Mdot
.682 .26778 Mdot
.682 .26952 Mdot
.682 .27834 Mdot
.682 .27894 Mdot
.682 .28135 Mdot
.682 .28168 Mdot
.682 .28916 Mdot
.682 .28922 Mdot
.682 .29104 Mdot
.682 .29109 Mdot
.682 .29115 Mdot
.682 .29122 Mdot
.682 .29151 Mdot
.682 .29156 Mdot
.682 .29168 Mdot
.682 .29172 Mdot
.682 .29193 Mdot
.682 .29215 Mdot
.682 .29221 Mdot
.682 .29223 Mdot
.682 .29307 Mdot
.682 .29315 Mdot
.682 .29324 Mdot
.682 .29347 Mdot
.682 .29361 Mdot
.682 .29416 Mdot
.682 .29435 Mdot
.682 .29441 Mdot
.682 .29459 Mdot
.682 .29473 Mdot
.682 .29533 Mdot
.682 .29535 Mdot
.682 .29541 Mdot
.682 .2956 Mdot
.682 .29566 Mdot
.682 .29579 Mdot
.682 .29625 Mdot
.682 .29645 Mdot
.682 .29688 Mdot
.682 .29698 Mdot
.682 .29722 Mdot
.682 .29786 Mdot
.682 .29808 Mdot
.682 .29823 Mdot
.682 .2995 Mdot
.682 .29968 Mdot
.682 .29974 Mdot
.682 .29997 Mdot
.682 .30028 Mdot
.682 .30052 Mdot
.682 .30066 Mdot
.682 .3008 Mdot
.682 .30088 Mdot
.682 .30152 Mdot
.682 .30206 Mdot
.682 .3022 Mdot
.682 .30251 Mdot
.682 .30263 Mdot
.682 .30304 Mdot
.682 .30364 Mdot
.682 .30495 Mdot
.682 .30596 Mdot
.682 .30598 Mdot
.682 .30637 Mdot
.682 .307 Mdot
.682 .30708 Mdot
.682 .30782 Mdot
.682 .3089 Mdot
.682 .30963 Mdot
.682 .30994 Mdot
.682 .31125 Mdot
.682 .31132 Mdot
.682 .31197 Mdot
.682 .31317 Mdot
.682 .31351 Mdot
.682 .31396 Mdot
.682 .31415 Mdot
.682 .31429 Mdot
.682 .31481 Mdot
.682 .31483 Mdot
.682 .31503 Mdot
.682 .31511 Mdot
.682 .31578 Mdot
.682 .31632 Mdot
.682 .31726 Mdot
.682 .31762 Mdot
.682 .31769 Mdot
.682 .31779 Mdot
.682 .31848 Mdot
.682 .3187 Mdot
.682 .31893 Mdot
.682 .31943 Mdot
.682 .3202 Mdot
.682 .32156 Mdot
.682 .32214 Mdot
.682 .32247 Mdot
.682 .32304 Mdot
.682 .32341 Mdot
.682 .32375 Mdot
.682 .32731 Mdot
.682 .32733 Mdot
.682 .32738 Mdot
.682 .32764 Mdot
.682 .32861 Mdot
.682 .32862 Mdot
.682 .32957 Mdot
.682 .32976 Mdot
.682 .32989 Mdot
.682 .33028 Mdot
.682 .33048 Mdot
.682 .33094 Mdot
.682 .3312 Mdot
.682 .33165 Mdot
.682 .33182 Mdot
.682 .33216 Mdot
.682 .33244 Mdot
.682 .33265 Mdot
.682 .33387 Mdot
.682 .33414 Mdot
.682 .33421 Mdot
.682 .33447 Mdot
.682 .3357 Mdot
.682 .33615 Mdot
.682 .33802 Mdot
.682 .34051 Mdot
.682 .34052 Mdot
.682 .34153 Mdot
.682 .3418 Mdot
.682 .34188 Mdot
.682 .34362 Mdot
.682 .34526 Mdot
.682 .34535 Mdot
.682 .34546 Mdot
.682 .34643 Mdot
.682 .34661 Mdot
.682 .34717 Mdot
.682 .34928 Mdot
.682 .34936 Mdot
.682 .34994 Mdot
.682 .35016 Mdot
.682 .35059 Mdot
.682 .35201 Mdot
.682 .35289 Mdot
.682 .35387 Mdot
.682 .35403 Mdot
.682 .35414 Mdot
.682 .3544 Mdot
.682 .355 Mdot
.682 .35609 Mdot
.682 .35695 Mdot
.682 .35796 Mdot
.682 .35953 Mdot
.682 .35993 Mdot
.682 .36014 Mdot
.682 .36111 Mdot
.682 .36126 Mdot
.682 .36158 Mdot
.682 .3624 Mdot
.682 .36261 Mdot
.682 .36286 Mdot
.682 .36465 Mdot
.682 .3651 Mdot
.682 .37031 Mdot
.682 .37198 Mdot
.682 .37246 Mdot
.682 .3741 Mdot
.682 .37417 Mdot
.682 .37422 Mdot
.682 .37495 Mdot
.682 .37561 Mdot
.682 .37763 Mdot
.682 .37999 Mdot
.682 .38066 Mdot
.682 .3811 Mdot
.682 .38214 Mdot
.682 .38258 Mdot
.682 .38358 Mdot
.682 .38422 Mdot
.682 .38507 Mdot
.682 .38624 Mdot
.682 .38649 Mdot
.682 .38789 Mdot
.682 .38872 Mdot
.682 .39266 Mdot
.682 .39617 Mdot
.682 .39681 Mdot
.682 .39682 Mdot
.682 .39684 Mdot
.682 .39687 Mdot
.682 .39697 Mdot
.682 .39698 Mdot
.682 .39702 Mdot
.682 .39703 Mdot
.682 .39711 Mdot
.682 .39718 Mdot
.682 .3972 Mdot
.682 .39721 Mdot
.682 .39752 Mdot
.682 .39755 Mdot
.682 .39763 Mdot
.682 .39767 Mdot
.682 .39786 Mdot
.682 .39792 Mdot
.682 .39794 Mdot
.682 .398 Mdot
.682 .39805 Mdot
.682 .39825 Mdot
.682 .39826 Mdot
.682 .39828 Mdot
.682 .39834 Mdot
.682 .39836 Mdot
.682 .39841 Mdot
.682 .39856 Mdot
.682 .39863 Mdot
.682 .39877 Mdot
.682 .3988 Mdot
.682 .39888 Mdot
.682 .3991 Mdot
.682 .39917 Mdot
.682 .39922 Mdot
.682 .39965 Mdot
.682 .39971 Mdot
.682 .39972 Mdot
.682 .3998 Mdot
.682 .39991 Mdot
.682 .39998 Mdot
.682 .40003 Mdot
.682 .40008 Mdot
.682 .40011 Mdot
.682 .40032 Mdot
.682 .4005 Mdot
.682 .40054 Mdot
.682 .40065 Mdot
.682 .40069 Mdot
.682 .40082 Mdot
.682 .40102 Mdot
.682 .40145 Mdot
.682 .40178 Mdot
.682 .40179 Mdot
.682 .40192 Mdot
.682 .40213 Mdot
.682 .40215 Mdot
.682 .40275 Mdot
.682 .40299 Mdot
.682 .40309 Mdot
.682 .40352 Mdot
.682 .40354 Mdot
.682 .40376 Mdot
.682 .40415 Mdot
.682 .40425 Mdot
.682 .4044 Mdot
.682 .40446 Mdot
.682 .40451 Mdot
.682 .40468 Mdot
.682 .40468 Mdot
.682 .40475 Mdot
.682 .40478 Mdot
.682 .40517 Mdot
.682 .40547 Mdot
.682 .40559 Mdot
.682 .40561 Mdot
.682 .40564 Mdot
.682 .40587 Mdot
.682 .40594 Mdot
.682 .40601 Mdot
.682 .40618 Mdot
.682 .40642 Mdot
.682 .40686 Mdot
.682 .40705 Mdot
.682 .40715 Mdot
.682 .40734 Mdot
.682 .40746 Mdot
.682 .40756 Mdot
.682 .40871 Mdot
.682 .40871 Mdot
.682 .40873 Mdot
.682 .40881 Mdot
.682 .40912 Mdot
.682 .40943 Mdot
.682 .40949 Mdot
.682 .40953 Mdot
.682 .40966 Mdot
.682 .40972 Mdot
.682 .40986 Mdot
.682 .40995 Mdot
.682 .41015 Mdot
.682 .41025 Mdot
.682 .41034 Mdot
.682 .41041 Mdot
.682 .41088 Mdot
.682 .41091 Mdot
.682 .41099 Mdot
.682 .41138 Mdot
.682 .41152 Mdot
.682 .41211 Mdot
.682 .4129 Mdot
.682 .4129 Mdot
.682 .41322 Mdot
.682 .41331 Mdot
.682 .41333 Mdot
.682 .41446 Mdot
.682 .41477 Mdot
.682 .415 Mdot
.682 .41566 Mdot
.682 .41569 Mdot
.682 .41587 Mdot
.682 .41594 Mdot
.682 .41607 Mdot
.682 .41679 Mdot
.682 .4171 Mdot
.682 .41718 Mdot
.682 .41726 Mdot
.682 .41806 Mdot
.682 .41838 Mdot
.682 .41887 Mdot
.682 .41899 Mdot
.682 .41936 Mdot
.682 .41951 Mdot
.682 .41976 Mdot
.682 .41991 Mdot
.682 .42047 Mdot
.682 .42223 Mdot
.682 .42274 Mdot
.682 .4229 Mdot
.682 .4234 Mdot
.682 .42343 Mdot
.682 .42344 Mdot
.682 .42387 Mdot
.682 .4245 Mdot
.682 .42544 Mdot
.682 .4259 Mdot
.682 .42604 Mdot
.682 .42681 Mdot
.682 .42726 Mdot
.682 .42769 Mdot
.682 .42795 Mdot
.682 .43082 Mdot
.682 .43321 Mdot
.682 .4337 Mdot
.682 .43419 Mdot
.682 .43455 Mdot
.682 .43526 Mdot
.682 .43639 Mdot
.682 .43644 Mdot
.682 .43646 Mdot
.682 .43686 Mdot
.682 .43767 Mdot
.682 .43884 Mdot
.682 .43918 Mdot
.682 .43948 Mdot
.682 .43967 Mdot
.682 .44212 Mdot
.682 .44262 Mdot
.682 .44299 Mdot
.682 .44389 Mdot
.682 .44799 Mdot
.682 .44819 Mdot
.682 .44847 Mdot
.682 .45012 Mdot
.682 .45096 Mdot
.682 .45141 Mdot
.682 .45167 Mdot
.682 .45229 Mdot
.682 .45287 Mdot
.682 .45314 Mdot
.682 .45638 Mdot
.682 .45726 Mdot
.682 .45757 Mdot
.682 .45807 Mdot
.682 .4584 Mdot
.682 .45863 Mdot
.682 .45864 Mdot
.682 .46019 Mdot
.682 .46055 Mdot
.682 .46076 Mdot
.682 .46101 Mdot
.682 .46188 Mdot
.682 .46192 Mdot
.682 .46245 Mdot
.682 .46252 Mdot
.682 .46256 Mdot
.682 .46265 Mdot
.682 .46385 Mdot
.682 .46447 Mdot
.682 .46477 Mdot
.682 .46556 Mdot
.682 .4656 Mdot
.682 .46576 Mdot
.682 .46618 Mdot
.682 .46695 Mdot
.682 .46732 Mdot
.682 .46773 Mdot
.682 .46818 Mdot
.682 .4696 Mdot
.682 .47087 Mdot
.682 .47131 Mdot
.682 .47148 Mdot
.682 .47162 Mdot
.682 .47233 Mdot
.682 .47401 Mdot
.682 .47587 Mdot
.682 .47626 Mdot
.682 .47692 Mdot
.682 .47704 Mdot
.682 .47758 Mdot
.682 .47798 Mdot
.682 .47827 Mdot
.682 .47874 Mdot
.682 .47894 Mdot
.682 .47942 Mdot
.682 .47962 Mdot
.682 .47993 Mdot
.682 .48102 Mdot
.682 .48194 Mdot
.682 .48223 Mdot
.682 .48256 Mdot
.682 .48259 Mdot
.682 .48262 Mdot
.682 .48336 Mdot
.682 .48358 Mdot
.682 .48433 Mdot
.682 .48664 Mdot
.682 .48684 Mdot
.682 .48764 Mdot
.682 .48775 Mdot
.682 .48784 Mdot
.682 .4882 Mdot
.682 .48833 Mdot
.682 .4884 Mdot
.682 .48883 Mdot
.682 .48892 Mdot
.682 .48909 Mdot
.682 .48978 Mdot
.682 .49022 Mdot
.682 .49059 Mdot
.682 .49106 Mdot
.682 .49132 Mdot
.682 .49143 Mdot
.682 .49148 Mdot
.682 .49155 Mdot
.682 .49197 Mdot
.682 .49235 Mdot
.682 .49295 Mdot
.682 .49314 Mdot
.682 .49323 Mdot
.682 .49348 Mdot
.682 .49351 Mdot
.682 .49441 Mdot
.682 .49465 Mdot
.682 .49472 Mdot
.682 .49513 Mdot
.682 .49518 Mdot
.682 .49521 Mdot
.682 .49591 Mdot
.682 .49664 Mdot
.682 .49667 Mdot
.682 .49678 Mdot
.682 .49721 Mdot
.682 .49721 Mdot
.682 .49825 Mdot
.682 .49902 Mdot
.682 .4992 Mdot
.682 .49971 Mdot
.682 .49982 Mdot
.682 .49985 Mdot
.682 .49996 Mdot
.682 .50046 Mdot
.682 .50055 Mdot
.682 .50066 Mdot
.682 .5008 Mdot
.682 .50087 Mdot
.682 .50106 Mdot
.682 .50116 Mdot
.682 .50135 Mdot
.682 .50143 Mdot
.682 .50159 Mdot
.682 .50165 Mdot
.682 .50172 Mdot
.682 .50211 Mdot
.682 .50211 Mdot
.682 .50251 Mdot
.682 .50261 Mdot
.682 .50264 Mdot
.682 .50264 Mdot
.682 .50408 Mdot
.682 .50422 Mdot
.682 .50437 Mdot
.682 .5046 Mdot
.682 .50473 Mdot
.682 .50496 Mdot
.682 .50551 Mdot
.682 .50581 Mdot
.682 .50601 Mdot
.682 .50611 Mdot
.682 .50619 Mdot
.682 .50647 Mdot
.682 .50651 Mdot
.682 .50653 Mdot
.682 .50668 Mdot
.682 .50705 Mdot
.682 .50727 Mdot
.682 .50753 Mdot
.682 .50756 Mdot
.682 .50764 Mdot
.682 .50765 Mdot
.682 .50785 Mdot
.682 .50791 Mdot
.682 .50799 Mdot
.682 .50816 Mdot
.682 .5083 Mdot
.682 .50877 Mdot
.682 .50902 Mdot
.682 .50905 Mdot
.682 .50957 Mdot
.682 .50969 Mdot
.682 .50997 Mdot
.682 .51039 Mdot
.682 .51068 Mdot
.682 .51072 Mdot
.682 .51096 Mdot
.682 .51111 Mdot
.682 .51112 Mdot
.682 .51151 Mdot
.682 .51202 Mdot
.682 .51225 Mdot
.682 .51241 Mdot
.682 .51246 Mdot
.682 .51258 Mdot
.682 .51263 Mdot
.682 .51284 Mdot
.682 .51308 Mdot
.682 .51312 Mdot
.682 .51317 Mdot
.682 .51323 Mdot
.682 .51331 Mdot
.682 .51344 Mdot
.682 .51353 Mdot
.682 .51355 Mdot
.682 .51362 Mdot
.682 .5141 Mdot
.682 .51416 Mdot
.682 .51424 Mdot
.682 .51449 Mdot
.682 .51458 Mdot
.682 .51462 Mdot
.682 .51479 Mdot
.682 .51486 Mdot
.682 .51504 Mdot
.682 .51509 Mdot
.682 .51511 Mdot
.682 .51518 Mdot
.682 .5152 Mdot
.682 .51521 Mdot
.682 .51544 Mdot
.682 .51549 Mdot
.682 .51556 Mdot
.682 .51558 Mdot
.682 .51566 Mdot
.682 .51587 Mdot
.682 .51592 Mdot
.682 .516 Mdot
.682 .51604 Mdot
.682 .51607 Mdot
.682 .51639 Mdot
.682 .5164 Mdot
.682 .51642 Mdot
.682 .5165 Mdot
.682 .51658 Mdot
.682 .5166 Mdot
.682 .51664 Mdot
.682 .51666 Mdot
.682 .51677 Mdot
.682 .5168 Mdot
.682 .51682 Mdot
.682 .51684 Mdot
.682 .51753 Mdot
.682 .51755 Mdot
.682 .52035 Mdot
.682 .52047 Mdot
.682 .52137 Mdot
.682 .52159 Mdot
.682 .52482 Mdot
.682 .52545 Mdot
.682 .52565 Mdot
.682 .52584 Mdot
.682 .52596 Mdot
.682 .52606 Mdot
.682 .5263 Mdot
.682 .5266 Mdot
.682 .52769 Mdot
.682 .52773 Mdot
.682 .52794 Mdot
.682 .52908 Mdot
.682 .5293 Mdot
.682 .52989 Mdot
.682 .5305 Mdot
.682 .53145 Mdot
.682 .53186 Mdot
.682 .53282 Mdot
.682 .53322 Mdot
.682 .53383 Mdot
.682 .534 Mdot
.682 .53593 Mdot
.682 .53767 Mdot
.682 .53822 Mdot
.682 .53879 Mdot
.682 .53883 Mdot
.682 .53887 Mdot
.682 .53893 Mdot
.682 .53921 Mdot
.682 .54027 Mdot
.682 .54062 Mdot
.682 .54066 Mdot
.682 .54153 Mdot
.682 .54197 Mdot
.682 .54362 Mdot
.682 .54449 Mdot
.682 .54587 Mdot
.682 .54619 Mdot
.682 .54642 Mdot
.682 .54744 Mdot
.682 .54761 Mdot
.682 .54762 Mdot
.682 .54775 Mdot
.682 .5483 Mdot
.682 .54851 Mdot
.682 .54861 Mdot
.682 .54872 Mdot
.682 .54914 Mdot
.682 .54925 Mdot
.682 .54939 Mdot
.682 .54964 Mdot
.682 .55064 Mdot
.682 .55115 Mdot
.682 .55126 Mdot
.682 .55151 Mdot
.682 .55158 Mdot
.682 .55178 Mdot
.682 .55243 Mdot
.682 .55278 Mdot
.682 .55293 Mdot
.682 .55299 Mdot
.682 .55308 Mdot
.682 .55334 Mdot
.682 .55363 Mdot
.682 .55381 Mdot
.682 .55412 Mdot
.682 .55416 Mdot
.682 .55432 Mdot
.682 .55451 Mdot
.682 .55478 Mdot
.682 .55489 Mdot
.682 .55506 Mdot
.682 .55511 Mdot
.682 .55523 Mdot
.682 .55553 Mdot
.682 .55557 Mdot
.682 .55596 Mdot
.682 .55662 Mdot
.682 .55689 Mdot
.682 .55698 Mdot
.682 .55743 Mdot
.682 .55749 Mdot
.682 .55752 Mdot
.682 .55826 Mdot
.682 .55901 Mdot
.682 .55904 Mdot
.682 .55916 Mdot
.682 .55957 Mdot
.682 .55957 Mdot
.682 .5599 Mdot
.682 .56013 Mdot
.682 .56053 Mdot
.682 .56101 Mdot
.682 .56113 Mdot
.682 .5612 Mdot
.682 .56135 Mdot
.682 .56176 Mdot
.682 .56184 Mdot
.682 .56187 Mdot
.682 .56195 Mdot
.682 .56233 Mdot
.682 .56239 Mdot
.682 .56248 Mdot
.682 .56257 Mdot
.682 .56262 Mdot
.682 .56275 Mdot
.682 .56283 Mdot
.682 .56295 Mdot
.682 .56301 Mdot
.682 .56311 Mdot
.682 .56315 Mdot
.682 .5632 Mdot
.682 .56338 Mdot
.682 .56339 Mdot
.682 .56344 Mdot
.682 .56344 Mdot
.682 .56368 Mdot
.682 .56374 Mdot
.682 .56375 Mdot
.682 .56375 Mdot
.682 .56383 Mdot
.682 .56384 Mdot
.682 .56385 Mdot
.682 .56387 Mdot
.682 .56393 Mdot
.682 .56394 Mdot
.682 .56397 Mdot
.682 .56398 Mdot
.682 .56403 Mdot
.682 .56407 Mdot
.682 .56409 Mdot
.682 .56409 Mdot
.682 .56427 Mdot
.682 .56428 Mdot
.682 .5643 Mdot
.682 .56435 Mdot
.682 .56437 Mdot
.682 .56448 Mdot
.682 .5645 Mdot
.682 .56452 Mdot
.682 .56453 Mdot
.682 .56456 Mdot
.682 .56456 Mdot
.682 .56459 Mdot
.682 .56463 Mdot
.682 .56469 Mdot
.682 .5647 Mdot
.682 .56471 Mdot
.682 .56473 Mdot
.682 .56474 Mdot
.682 .56475 Mdot
.682 .56477 Mdot
.682 .56479 Mdot
.682 .56485 Mdot
.682 .56488 Mdot
.682 .56488 Mdot
.682 .56495 Mdot
.682 .56496 Mdot
.682 .565 Mdot
.682 .56509 Mdot
.682 .56509 Mdot
.682 .56512 Mdot
.682 .56514 Mdot
.682 .56519 Mdot
.682 .56526 Mdot
.682 .56529 Mdot
.682 .56531 Mdot
.682 .56531 Mdot
.682 .56533 Mdot
.682 .56534 Mdot
.682 .56536 Mdot
.682 .56539 Mdot
.682 .5654 Mdot
.682 .56541 Mdot
.682 .56541 Mdot
.682 .56542 Mdot
.682 .56544 Mdot
.682 .56545 Mdot
.682 .56545 Mdot
.682 .56546 Mdot
.682 .56553 Mdot
.682 .56554 Mdot
.682 .56558 Mdot
.682 .56559 Mdot
.682 .56559 Mdot
.682 .56561 Mdot
.682 .56562 Mdot
.682 .56565 Mdot
.682 .56565 Mdot
.682 .56566 Mdot
.682 .56567 Mdot
.682 .56567 Mdot
.682 .5657 Mdot
.682 .56571 Mdot
.682 .56572 Mdot
.682 .56573 Mdot
.682 .56576 Mdot
.682 .56577 Mdot
.682 .56578 Mdot
.682 .56582 Mdot
.682 .56583 Mdot
.682 .56583 Mdot
.682 .56584 Mdot
.682 .56585 Mdot
.682 .56585 Mdot
.682 .56586 Mdot
.682 .56586 Mdot
.682 .56587 Mdot
.682 .56588 Mdot
.682 .56588 Mdot
.682 .56588 Mdot
.684 .1453 Mdot
.684 .1453 Mdot
.684 .14531 Mdot
.684 .14531 Mdot
.684 .14531 Mdot
.684 .14543 Mdot
.684 .14543 Mdot
.684 .14546 Mdot
.684 .14549 Mdot
.684 .1455 Mdot
.684 .14551 Mdot
.684 .14553 Mdot
.684 .14554 Mdot
.684 .14554 Mdot
.684 .14559 Mdot
.684 .14564 Mdot
.684 .14565 Mdot
.684 .14569 Mdot
.684 .14575 Mdot
.684 .14577 Mdot
.684 .1458 Mdot
.684 .1458 Mdot
.684 .14581 Mdot
.684 .14614 Mdot
.684 .14618 Mdot
.684 .1462 Mdot
.684 .14637 Mdot
.684 .14642 Mdot
.684 .14663 Mdot
.684 .14676 Mdot
.684 .1468 Mdot
.684 .14697 Mdot
.684 .14699 Mdot
.684 .14703 Mdot
.684 .14713 Mdot
.684 .14716 Mdot
.684 .14727 Mdot
.684 .1473 Mdot
.684 .14739 Mdot
.684 .14747 Mdot
.684 .14776 Mdot
.684 .14785 Mdot
.684 .14812 Mdot
.684 .14812 Mdot
.684 .14825 Mdot
.684 .14831 Mdot
.684 .14838 Mdot
.684 .14843 Mdot
.684 .1485 Mdot
.684 .14881 Mdot
.684 .14888 Mdot
.684 .149 Mdot
.684 .14903 Mdot
.684 .14936 Mdot
.684 .14941 Mdot
.684 .14945 Mdot
.684 .14967 Mdot
.684 .14995 Mdot
.684 .15025 Mdot
.684 .15041 Mdot
.684 .15046 Mdot
.684 .15089 Mdot
.684 .15105 Mdot
.684 .15116 Mdot
.684 .15123 Mdot
.684 .15141 Mdot
.684 .15153 Mdot
.684 .15157 Mdot
.684 .1529 Mdot
.684 .15294 Mdot
.684 .153 Mdot
.684 .153 Mdot
.684 .15315 Mdot
.684 .15321 Mdot
.684 .15325 Mdot
.684 .15354 Mdot
.684 .15376 Mdot
.684 .1538 Mdot
.684 .15404 Mdot
.684 .15423 Mdot
.684 .15433 Mdot
.684 .15434 Mdot
.684 .15437 Mdot
.684 .15449 Mdot
.684 .15453 Mdot
.684 .15459 Mdot
.684 .15469 Mdot
.684 .1547 Mdot
.684 .15471 Mdot
.684 .15488 Mdot
.684 .15489 Mdot
.684 .15515 Mdot
.684 .15549 Mdot
.684 .15556 Mdot
.684 .15558 Mdot
.684 .15559 Mdot
.684 .15562 Mdot
.684 .15562 Mdot
.684 .15821 Mdot
.684 .15847 Mdot
.684 .15888 Mdot
.684 .15889 Mdot
.684 .1593 Mdot
.684 .15966 Mdot
.684 .15981 Mdot
.684 .15985 Mdot
.684 .16026 Mdot
.684 .16032 Mdot
.684 .16038 Mdot
.684 .16057 Mdot
.684 .16262 Mdot
.684 .16384 Mdot
.684 .16429 Mdot
.684 .16461 Mdot
.684 .16559 Mdot
.684 .16653 Mdot
.684 .16809 Mdot
.684 .1681 Mdot
.684 .169 Mdot
.684 .16904 Mdot
.684 .16934 Mdot
.684 .17019 Mdot
.684 .17035 Mdot
.684 .17072 Mdot
.684 .17074 Mdot
.684 .17132 Mdot
.684 .17222 Mdot
.684 .17224 Mdot
.684 .17238 Mdot
.684 .17307 Mdot
.684 .17348 Mdot
.684 .17392 Mdot
.684 .17401 Mdot
.684 .17424 Mdot
.684 .17626 Mdot
.684 .17658 Mdot
.684 .17666 Mdot
.684 .17713 Mdot
.684 .17997 Mdot
.684 .18065 Mdot
.684 .18087 Mdot
.684 .18097 Mdot
.684 .18132 Mdot
.684 .18135 Mdot
.684 .18187 Mdot
.684 .18243 Mdot
.684 .18511 Mdot
.684 .18773 Mdot
.684 .18789 Mdot
.684 .18833 Mdot
.684 .19046 Mdot
.684 .19468 Mdot
.684 .19848 Mdot
.684 .20056 Mdot
.684 .20335 Mdot
.684 .20385 Mdot
.684 .20893 Mdot
.684 .21272 Mdot
.684 .21594 Mdot
.684 .21621 Mdot
.684 .21643 Mdot
.684 .2172 Mdot
.684 .21774 Mdot
.684 .2179 Mdot
.684 .21916 Mdot
.684 .2194 Mdot
.684 .22085 Mdot
.684 .2222 Mdot
.684 .22237 Mdot
.684 .22416 Mdot
.684 .22633 Mdot
.684 .22784 Mdot
.684 .2284 Mdot
.684 .2285 Mdot
.684 .23086 Mdot
.684 .23368 Mdot
.684 .23377 Mdot
.684 .23606 Mdot
.684 .23666 Mdot
.684 .242 Mdot
.684 .24315 Mdot
.684 .24412 Mdot
.684 .24502 Mdot
.684 .24733 Mdot
.684 .24807 Mdot
.684 .24861 Mdot
.684 .24892 Mdot
.684 .24935 Mdot
.684 .24948 Mdot
.684 .25503 Mdot
.684 .25527 Mdot
.684 .26297 Mdot
.684 .26321 Mdot
.684 .26955 Mdot
.684 .26985 Mdot
.684 .27011 Mdot
.684 .27142 Mdot
.684 .2742 Mdot
.684 .27572 Mdot
.684 .27902 Mdot
.684 .28199 Mdot
.684 .28251 Mdot
.684 .28265 Mdot
.684 .28299 Mdot
.684 .28669 Mdot
.684 .28669 Mdot
.684 .28673 Mdot
.684 .28674 Mdot
.684 .28676 Mdot
.684 .28683 Mdot
.684 .28721 Mdot
.684 .28751 Mdot
.684 .28752 Mdot
.684 .28771 Mdot
.684 .28772 Mdot
.684 .28773 Mdot
.684 .28784 Mdot
.684 .28792 Mdot
.684 .28796 Mdot
.684 .2881 Mdot
.684 .28814 Mdot
.684 .28814 Mdot
.684 .28826 Mdot
.684 .28849 Mdot
.684 .28877 Mdot
.684 .28882 Mdot
.684 .28909 Mdot
.684 .28944 Mdot
.684 .28957 Mdot
.684 .28975 Mdot
.684 .28975 Mdot
.684 .28983 Mdot
.684 .29169 Mdot
.684 .29185 Mdot
.684 .29212 Mdot
.684 .29222 Mdot
.684 .29325 Mdot
.684 .29358 Mdot
.684 .29489 Mdot
.684 .29504 Mdot
.684 .29568 Mdot
.684 .29589 Mdot
.684 .29603 Mdot
.684 .29675 Mdot
.684 .29686 Mdot
.684 .29699 Mdot
.684 .2971 Mdot
.684 .29737 Mdot
.684 .29737 Mdot
.684 .29794 Mdot
.684 .29815 Mdot
.684 .29881 Mdot
.684 .299 Mdot
.684 .29922 Mdot
.684 .29956 Mdot
.684 .30005 Mdot
.684 .30054 Mdot
.684 .30101 Mdot
.684 .30186 Mdot
.684 .30244 Mdot
.684 .30266 Mdot
.684 .30406 Mdot
.684 .30412 Mdot
.684 .30412 Mdot
.684 .30493 Mdot
.684 .30498 Mdot
.684 .30526 Mdot
.684 .30564 Mdot
.684 .30569 Mdot
.684 .30602 Mdot
.684 .30647 Mdot
.684 .30648 Mdot
.684 .30839 Mdot
.684 .30884 Mdot
.684 .30909 Mdot
.684 .30958 Mdot
.684 .30978 Mdot
.684 .31184 Mdot
.684 .31212 Mdot
.684 .31218 Mdot
.684 .31238 Mdot
.684 .31335 Mdot
.684 .31365 Mdot
.684 .31376 Mdot
.684 .31553 Mdot
.684 .31636 Mdot
.684 .31739 Mdot
.684 .31803 Mdot
.684 .31814 Mdot
.684 .31839 Mdot
.684 .31874 Mdot
.684 .32142 Mdot
.684 .32241 Mdot
.684 .32307 Mdot
.684 .32352 Mdot
.684 .32398 Mdot
.684 .3247 Mdot
.684 .32543 Mdot
.684 .32566 Mdot
.684 .32639 Mdot
.684 .32815 Mdot
.684 .334 Mdot
.684 .33426 Mdot
.684 .33465 Mdot
.684 .33466 Mdot
.684 .33555 Mdot
.684 .33593 Mdot
.684 .33599 Mdot
.684 .33621 Mdot
.684 .338 Mdot
.684 .33938 Mdot
.684 .33964 Mdot
.684 .34041 Mdot
.684 .34114 Mdot
.684 .34233 Mdot
.684 .34298 Mdot
.684 .34301 Mdot
.684 .34323 Mdot
.684 .34395 Mdot
.684 .34421 Mdot
.684 .34423 Mdot
.684 .34463 Mdot
.684 .34525 Mdot
.684 .34527 Mdot
.684 .34536 Mdot
.684 .34583 Mdot
.684 .34611 Mdot
.684 .3464 Mdot
.684 .34646 Mdot
.684 .34813 Mdot
.684 .35024 Mdot
.684 .35065 Mdot
.684 .35079 Mdot
.684 .35084 Mdot
.684 .35105 Mdot
.684 .35107 Mdot
.684 .35138 Mdot
.684 .35171 Mdot
.684 .35326 Mdot
.684 .35474 Mdot
.684 .35528 Mdot
.684 .35622 Mdot
.684 .35845 Mdot
.684 .36038 Mdot
.684 .36141 Mdot
.684 .3654 Mdot
.684 .36712 Mdot
.684 .36878 Mdot
.684 .36935 Mdot
.684 .37007 Mdot
.684 .37127 Mdot
.684 .37135 Mdot
.684 .3721 Mdot
.684 .37364 Mdot
.684 .37387 Mdot
.684 .37606 Mdot
.684 .37698 Mdot
.684 .37722 Mdot
.684 .37932 Mdot
.684 .37976 Mdot
.684 .38014 Mdot
.684 .38049 Mdot
.684 .38165 Mdot
.684 .38186 Mdot
.684 .38214 Mdot
.684 .38219 Mdot
.684 .38726 Mdot
.684 .38973 Mdot
.684 .39117 Mdot
.684 .39285 Mdot
.684 .39406 Mdot
.684 .3941 Mdot
.684 .39422 Mdot
.684 .39548 Mdot
.684 .39548 Mdot
.684 .3955 Mdot
.684 .3955 Mdot
.684 .39551 Mdot
.684 .39553 Mdot
.684 .39576 Mdot
.684 .39577 Mdot
.684 .39583 Mdot
.684 .39583 Mdot
.684 .39587 Mdot
.684 .3959 Mdot
.684 .39592 Mdot
.684 .39596 Mdot
.684 .39598 Mdot
.684 .39598 Mdot
.684 .39602 Mdot
.684 .39609 Mdot
.684 .39619 Mdot
.684 .39621 Mdot
.684 .3963 Mdot
.684 .39642 Mdot
.684 .39646 Mdot
.684 .39652 Mdot
.684 .39652 Mdot
.684 .39655 Mdot
.684 .39723 Mdot
.684 .39732 Mdot
.684 .39736 Mdot
.684 .3977 Mdot
.684 .39781 Mdot
.684 .39825 Mdot
.684 .3983 Mdot
.684 .39852 Mdot
.684 .39859 Mdot
.684 .39891 Mdot
.684 .39896 Mdot
.684 .39899 Mdot
.684 .39908 Mdot
.684 .39908 Mdot
.684 .39927 Mdot
.684 .39934 Mdot
.684 .39956 Mdot
.684 .39962 Mdot
.684 .3997 Mdot
.684 .39981 Mdot
.684 .39997 Mdot
.684 .40057 Mdot
.684 .40076 Mdot
.684 .4013 Mdot
.684 .40132 Mdot
.684 .40132 Mdot
.684 .40158 Mdot
.684 .40169 Mdot
.684 .40184 Mdot
.684 .40194 Mdot
.684 .40209 Mdot
.684 .40272 Mdot
.684 .40287 Mdot
.684 .40295 Mdot
.684 .40311 Mdot
.684 .40317 Mdot
.684 .40384 Mdot
.684 .40394 Mdot
.684 .40395 Mdot
.684 .40402 Mdot
.684 .40434 Mdot
.684 .40443 Mdot
.684 .40447 Mdot
.684 .40504 Mdot
.684 .40565 Mdot
.684 .40585 Mdot
.684 .40589 Mdot
.684 .40597 Mdot
.684 .40608 Mdot
.684 .40694 Mdot
.684 .40726 Mdot
.684 .40747 Mdot
.684 .40761 Mdot
.684 .40776 Mdot
.684 .40799 Mdot
.684 .40823 Mdot
.684 .4083 Mdot
.684 .40854 Mdot
.684 .41096 Mdot
.684 .41104 Mdot
.684 .41116 Mdot
.684 .41116 Mdot
.684 .41145 Mdot
.684 .41157 Mdot
.684 .41159 Mdot
.684 .41166 Mdot
.684 .41222 Mdot
.684 .41266 Mdot
.684 .41274 Mdot
.684 .41298 Mdot
.684 .41321 Mdot
.684 .41358 Mdot
.684 .41379 Mdot
.684 .4138 Mdot
.684 .41387 Mdot
.684 .4141 Mdot
.684 .41418 Mdot
.684 .41431 Mdot
.684 .4145 Mdot
.684 .41451 Mdot
.684 .41454 Mdot
.684 .41477 Mdot
.684 .41486 Mdot
.684 .41488 Mdot
.684 .41541 Mdot
.684 .41607 Mdot
.684 .4162 Mdot
.684 .41624 Mdot
.684 .41626 Mdot
.684 .41632 Mdot
.684 .41633 Mdot
.684 .41642 Mdot
.684 .41653 Mdot
.684 .41701 Mdot
.684 .41764 Mdot
.684 .41794 Mdot
.684 .41863 Mdot
.684 .41923 Mdot
.684 .42079 Mdot
.684 .42133 Mdot
.684 .42184 Mdot
.684 .42202 Mdot
.684 .42224 Mdot
.684 .42262 Mdot
.684 .42264 Mdot
.684 .42287 Mdot
.684 .42342 Mdot
.684 .4241 Mdot
.684 .42439 Mdot
.684 .42446 Mdot
.684 .42511 Mdot
.684 .42525 Mdot
.684 .42537 Mdot
.684 .42547 Mdot
.684 .42584 Mdot
.684 .4259 Mdot
.684 .42599 Mdot
.684 .426 Mdot
.684 .42834 Mdot
.684 .42879 Mdot
.684 .42931 Mdot
.684 .42969 Mdot
.684 .42974 Mdot
.684 .43024 Mdot
.684 .43101 Mdot
.684 .4312 Mdot
.684 .43125 Mdot
.684 .43144 Mdot
.684 .43194 Mdot
.684 .43246 Mdot
.684 .43277 Mdot
.684 .43289 Mdot
.684 .43336 Mdot
.684 .43338 Mdot
.684 .43396 Mdot
.684 .4342 Mdot
.684 .43516 Mdot
.684 .43687 Mdot
.684 .43757 Mdot
.684 .43845 Mdot
.684 .43852 Mdot
.684 .43872 Mdot
.684 .43943 Mdot
.684 .43968 Mdot
.684 .43971 Mdot
.684 .43971 Mdot
.684 .44046 Mdot
.684 .4406 Mdot
.684 .44077 Mdot
.684 .44107 Mdot
.684 .44131 Mdot
.684 .44139 Mdot
.684 .44191 Mdot
.684 .44207 Mdot
.684 .44226 Mdot
.684 .44234 Mdot
.684 .44342 Mdot
.684 .44371 Mdot
.684 .44373 Mdot
.684 .44436 Mdot
.684 .4444 Mdot
.684 .44446 Mdot
.684 .44488 Mdot
.684 .44494 Mdot
.684 .44542 Mdot
.684 .44698 Mdot
.684 .44702 Mdot
.684 .44726 Mdot
.684 .44767 Mdot
.684 .44846 Mdot
.684 .4485 Mdot
.684 .44861 Mdot
.684 .44917 Mdot
.684 .44934 Mdot
.684 .44943 Mdot
.684 .44951 Mdot
.684 .44993 Mdot
.684 .45008 Mdot
.684 .45048 Mdot
.684 .45059 Mdot
.684 .45063 Mdot
.684 .45112 Mdot
.684 .45296 Mdot
.684 .4531 Mdot
.684 .45342 Mdot
.684 .45368 Mdot
.684 .45391 Mdot
.684 .45446 Mdot
.684 .45457 Mdot
.684 .4546 Mdot
.684 .4547 Mdot
.684 .45511 Mdot
.684 .45538 Mdot
.684 .45561 Mdot
.684 .45589 Mdot
.684 .45613 Mdot
.684 .45737 Mdot
.684 .45738 Mdot
.684 .45743 Mdot
.684 .45784 Mdot
.684 .45902 Mdot
.684 .45935 Mdot
.684 .45947 Mdot
.684 .46011 Mdot
.684 .46091 Mdot
.684 .46123 Mdot
.684 .46158 Mdot
.684 .46173 Mdot
.684 .46206 Mdot
.684 .46231 Mdot
.684 .46236 Mdot
.684 .4632 Mdot
.684 .46411 Mdot
.684 .46482 Mdot
.684 .46635 Mdot
.684 .46673 Mdot
.684 .46766 Mdot
.684 .46768 Mdot
.684 .46838 Mdot
.684 .46843 Mdot
.684 .46862 Mdot
.684 .46911 Mdot
.684 .46992 Mdot
.684 .4707 Mdot
.684 .471 Mdot
.684 .47108 Mdot
.684 .47138 Mdot
.684 .47248 Mdot
.684 .47256 Mdot
.684 .47271 Mdot
.684 .47334 Mdot
.684 .47339 Mdot
.684 .47342 Mdot
.684 .47399 Mdot
.684 .47479 Mdot
.684 .47547 Mdot
.684 .47663 Mdot
.684 .47899 Mdot
.684 .47901 Mdot
.684 .47914 Mdot
.684 .47924 Mdot
.684 .47978 Mdot
.684 .47994 Mdot
.684 .48011 Mdot
.684 .48031 Mdot
.684 .48127 Mdot
.684 .48138 Mdot
.684 .4818 Mdot
.684 .48279 Mdot
.684 .4829 Mdot
.684 .48359 Mdot
.684 .48393 Mdot
.684 .48396 Mdot
.684 .4845 Mdot
.684 .48482 Mdot
.684 .48508 Mdot
.684 .48582 Mdot
.684 .48658 Mdot
.684 .48834 Mdot
.684 .48879 Mdot
.684 .48963 Mdot
.684 .49059 Mdot
.684 .491 Mdot
.684 .49124 Mdot
.684 .49187 Mdot
.684 .49253 Mdot
.684 .49268 Mdot
.684 .49281 Mdot
.684 .49282 Mdot
.684 .49291 Mdot
.684 .49293 Mdot
.684 .49299 Mdot
.684 .49316 Mdot
.684 .49406 Mdot
.684 .49477 Mdot
.684 .49479 Mdot
.684 .49492 Mdot
.684 .49504 Mdot
.684 .49523 Mdot
.684 .49527 Mdot
.684 .49528 Mdot
.684 .49554 Mdot
.684 .49571 Mdot
.684 .49572 Mdot
.684 .49583 Mdot
.684 .49613 Mdot
.684 .49622 Mdot
.684 .49623 Mdot
.684 .49651 Mdot
.684 .497 Mdot
.684 .49731 Mdot
.684 .49763 Mdot
.684 .49774 Mdot
.684 .49831 Mdot
.684 .49905 Mdot
.684 .49914 Mdot
.684 .49917 Mdot
.684 .49932 Mdot
.684 .49969 Mdot
.684 .4997 Mdot
.684 .49986 Mdot
.684 .49996 Mdot
.684 .50235 Mdot
.684 .50307 Mdot
.684 .50337 Mdot
.684 .50346 Mdot
.684 .50375 Mdot
.684 .50404 Mdot
.684 .50423 Mdot
.684 .50441 Mdot
.684 .50467 Mdot
.684 .50507 Mdot
.684 .50614 Mdot
.684 .50628 Mdot
.684 .50638 Mdot
.684 .50642 Mdot
.684 .50668 Mdot
.684 .50709 Mdot
.684 .50741 Mdot
.684 .50811 Mdot
.684 .50816 Mdot
.684 .50828 Mdot
.684 .50866 Mdot
.684 .50874 Mdot
.684 .50876 Mdot
.684 .50887 Mdot
.684 .50968 Mdot
.684 .50976 Mdot
.684 .50995 Mdot
.684 .51005 Mdot
.684 .51022 Mdot
.684 .51096 Mdot
.684 .51097 Mdot
.684 .51115 Mdot
.684 .51127 Mdot
.684 .51129 Mdot
.684 .51144 Mdot
.684 .51155 Mdot
.684 .51157 Mdot
.684 .51188 Mdot
.684 .51188 Mdot
.684 .51191 Mdot
.684 .51245 Mdot
.684 .51253 Mdot
.684 .51276 Mdot
.684 .51308 Mdot
.684 .51326 Mdot
.684 .51345 Mdot
.684 .51364 Mdot
.684 .51377 Mdot
.684 .51386 Mdot
.684 .51393 Mdot
.684 .51418 Mdot
.684 .51426 Mdot
.684 .51448 Mdot
.684 .51448 Mdot
.684 .51458 Mdot
.684 .51462 Mdot
.684 .51468 Mdot
.684 .51471 Mdot
.684 .51499 Mdot
.684 .51504 Mdot
.684 .51513 Mdot
.684 .51537 Mdot
.684 .51543 Mdot
.684 .51592 Mdot
.684 .51605 Mdot
.684 .51644 Mdot
.684 .51648 Mdot
.684 .51658 Mdot
.684 .51664 Mdot
.684 .51734 Mdot
.684 .51737 Mdot
.684 .51737 Mdot
.684 .51744 Mdot
.684 .51749 Mdot
.684 .51762 Mdot
.684 .51772 Mdot
.684 .51774 Mdot
.684 .51785 Mdot
.684 .51793 Mdot
.684 .51798 Mdot
.684 .51798 Mdot
.684 .51799 Mdot
.684 .51804 Mdot
.684 .51806 Mdot
.684 .51809 Mdot
.684 .51813 Mdot
.684 .51813 Mdot
.684 .51814 Mdot
.684 .51821 Mdot
.684 .51822 Mdot
.684 .51833 Mdot
.684 .51847 Mdot
.684 .51849 Mdot
.684 .5185 Mdot
.684 .51851 Mdot
.684 .51852 Mdot
.684 .51852 Mdot
.684 .51991 Mdot
.684 .52003 Mdot
.684 .52008 Mdot
.684 .52028 Mdot
.684 .52138 Mdot
.684 .5226 Mdot
.684 .52315 Mdot
.684 .52417 Mdot
.684 .52465 Mdot
.684 .52474 Mdot
.684 .52485 Mdot
.684 .52715 Mdot
.684 .52723 Mdot
.684 .52999 Mdot
.684 .53007 Mdot
.684 .53204 Mdot
.684 .53208 Mdot
.684 .53223 Mdot
.684 .53234 Mdot
.684 .53253 Mdot
.684 .53279 Mdot
.684 .5336 Mdot
.684 .53392 Mdot
.684 .53425 Mdot
.684 .53465 Mdot
.684 .53651 Mdot
.684 .53671 Mdot
.684 .5375 Mdot
.684 .53753 Mdot
.684 .5385 Mdot
.684 .5393 Mdot
.684 .53934 Mdot
.684 .53953 Mdot
.684 .54004 Mdot
.684 .54078 Mdot
.684 .54139 Mdot
.684 .54144 Mdot
.684 .5419 Mdot
.684 .54239 Mdot
.684 .54247 Mdot
.684 .54289 Mdot
.684 .54295 Mdot
.684 .54313 Mdot
.684 .54338 Mdot
.684 .54346 Mdot
.684 .54355 Mdot
.684 .54462 Mdot
.684 .54588 Mdot
.684 .54756 Mdot
.684 .54773 Mdot
.684 .54864 Mdot
.684 .54932 Mdot
.684 .55056 Mdot
.684 .55193 Mdot
.684 .55262 Mdot
.684 .55276 Mdot
.684 .55281 Mdot
.684 .55366 Mdot
.684 .55451 Mdot
.684 .55469 Mdot
.684 .55486 Mdot
.684 .55487 Mdot
.684 .55498 Mdot
.684 .55501 Mdot
.684 .55508 Mdot
.684 .5553 Mdot
.684 .55621 Mdot
.684 .55635 Mdot
.684 .55638 Mdot
.684 .55648 Mdot
.684 .55712 Mdot
.684 .55719 Mdot
.684 .55722 Mdot
.684 .55736 Mdot
.684 .55749 Mdot
.684 .55771 Mdot
.684 .55775 Mdot
.684 .55776 Mdot
.684 .55804 Mdot
.684 .55823 Mdot
.684 .55823 Mdot
.684 .55835 Mdot
.684 .5584 Mdot
.684 .55867 Mdot
.684 .55876 Mdot
.684 .55877 Mdot
.684 .55906 Mdot
.684 .55906 Mdot
.684 .55955 Mdot
.684 .55984 Mdot
.684 .56015 Mdot
.684 .56025 Mdot
.684 .56039 Mdot
.684 .56077 Mdot
.684 .56141 Mdot
.684 .56147 Mdot
.684 .56149 Mdot
.684 .56151 Mdot
.684 .56164 Mdot
.684 .56165 Mdot
.684 .56169 Mdot
.684 .56181 Mdot
.684 .56193 Mdot
.684 .56194 Mdot
.684 .56206 Mdot
.684 .56215 Mdot
.684 .56295 Mdot
.684 .56295 Mdot
.684 .56296 Mdot
.684 .56296 Mdot
.684 .56297 Mdot
.684 .56299 Mdot
.684 .56309 Mdot
.684 .56317 Mdot
.684 .56318 Mdot
.684 .56323 Mdot
.684 .56323 Mdot
.684 .56323 Mdot
.684 .56326 Mdot
.684 .56328 Mdot
.684 .5633 Mdot
.684 .56333 Mdot
.684 .56334 Mdot
.684 .56335 Mdot
.684 .56338 Mdot
.684 .56344 Mdot
.684 .56351 Mdot
.684 .56352 Mdot
.684 .56359 Mdot
.684 .56368 Mdot
.684 .56371 Mdot
.684 .56376 Mdot
.684 .56376 Mdot
.684 .56377 Mdot
.684 .56379 Mdot
.684 .5642 Mdot
.684 .56421 Mdot
.684 .56424 Mdot
.684 .5643 Mdot
.684 .56432 Mdot
.684 .56436 Mdot
.684 .56441 Mdot
.684 .56454 Mdot
.684 .56455 Mdot
.684 .5646 Mdot
.684 .56469 Mdot
.684 .56478 Mdot
.684 .56485 Mdot
.684 .56486 Mdot
.684 .56488 Mdot
.684 .56498 Mdot
.684 .56499 Mdot
.684 .56502 Mdot
.684 .56505 Mdot
.684 .56514 Mdot
.684 .56516 Mdot
.684 .56518 Mdot
.684 .5652 Mdot
.684 .56522 Mdot
.684 .56526 Mdot
.684 .56526 Mdot
.684 .56534 Mdot
.684 .56537 Mdot
.684 .56546 Mdot
.684 .56548 Mdot
.684 .56551 Mdot
.684 .56552 Mdot
.684 .56555 Mdot
.684 .56556 Mdot
.684 .56559 Mdot
.684 .5656 Mdot
.684 .56561 Mdot
.684 .56566 Mdot
.684 .56567 Mdot
.684 .56571 Mdot
.684 .56578 Mdot
.684 .56579 Mdot
.684 .56584 Mdot
.684 .56585 Mdot
.684 .56586 Mdot
.684 .56596 Mdot
.684 .56597 Mdot
.684 .56597 Mdot
.684 .56598 Mdot
.684 .56598 Mdot
.684 .566 Mdot
.684 .56601 Mdot
.684 .56602 Mdot
.684 .56603 Mdot
.684 .56605 Mdot
.684 .56605 Mdot
.684 .56605 Mdot
.684 .56606 Mdot
.684 .56606 Mdot
.684 .56606 Mdot
.684 .56607 Mdot
.684 .56608 Mdot
.684 .56608 Mdot
.684 .56612 Mdot
.684 .56612 Mdot
.684 .56612 Mdot
.684 .56612 Mdot
.684 .56612 Mdot
.686 .14461 Mdot
.686 .14461 Mdot
.686 .14462 Mdot
.686 .14463 Mdot
.686 .14465 Mdot
.686 .14467 Mdot
.686 .14468 Mdot
.686 .1448 Mdot
.686 .14485 Mdot
.686 .1449 Mdot
.686 .14497 Mdot
.686 .145 Mdot
.686 .14528 Mdot
.686 .14569 Mdot
.686 .14579 Mdot
.686 .14581 Mdot
.686 .14583 Mdot
.686 .14591 Mdot
.686 .14595 Mdot
.686 .14595 Mdot
.686 .14596 Mdot
.686 .14611 Mdot
.686 .14615 Mdot
.686 .14616 Mdot
.686 .14653 Mdot
.686 .14664 Mdot
.686 .14668 Mdot
.686 .14694 Mdot
.686 .14696 Mdot
.686 .14697 Mdot
.686 .14697 Mdot
.686 .1471 Mdot
.686 .14719 Mdot
.686 .14729 Mdot
.686 .14751 Mdot
.686 .14756 Mdot
.686 .14759 Mdot
.686 .1476 Mdot
.686 .14761 Mdot
.686 .14765 Mdot
.686 .14767 Mdot
.686 .1482 Mdot
.686 .14855 Mdot
.686 .14861 Mdot
.686 .14867 Mdot
.686 .14871 Mdot
.686 .14908 Mdot
.686 .14913 Mdot
.686 .14923 Mdot
.686 .14941 Mdot
.686 .14952 Mdot
.686 .15012 Mdot
.686 .15028 Mdot
.686 .15044 Mdot
.686 .1506 Mdot
.686 .1506 Mdot
.686 .15065 Mdot
.686 .15071 Mdot
.686 .15083 Mdot
.686 .15114 Mdot
.686 .15149 Mdot
.686 .15153 Mdot
.686 .15157 Mdot
.686 .15172 Mdot
.686 .15191 Mdot
.686 .15204 Mdot
.686 .15211 Mdot
.686 .15223 Mdot
.686 .15231 Mdot
.686 .15247 Mdot
.686 .1525 Mdot
.686 .1527 Mdot
.686 .1528 Mdot
.686 .15284 Mdot
.686 .15286 Mdot
.686 .15307 Mdot
.686 .15333 Mdot
.686 .15372 Mdot
.686 .15412 Mdot
.686 .1549 Mdot
.686 .15502 Mdot
.686 .15505 Mdot
.686 .15523 Mdot
.686 .15641 Mdot
.686 .15665 Mdot
.686 .15683 Mdot
.686 .15685 Mdot
.686 .15707 Mdot
.686 .15726 Mdot
.686 .15728 Mdot
.686 .15743 Mdot
.686 .15758 Mdot
.686 .15789 Mdot
.686 .15869 Mdot
.686 .15872 Mdot
.686 .15883 Mdot
.686 .15889 Mdot
.686 .15903 Mdot
.686 .15906 Mdot
.686 .15915 Mdot
.686 .15915 Mdot
.686 .15966 Mdot
.686 .16062 Mdot
.686 .16062 Mdot
.686 .16144 Mdot
.686 .16219 Mdot
.686 .163 Mdot
.686 .16325 Mdot
.686 .16353 Mdot
.686 .16363 Mdot
.686 .16473 Mdot
.686 .16653 Mdot
.686 .16678 Mdot
.686 .16721 Mdot
.686 .16723 Mdot
.686 .16742 Mdot
.686 .16759 Mdot
.686 .16761 Mdot
.686 .16763 Mdot
.686 .16776 Mdot
.686 .16785 Mdot
.686 .16984 Mdot
.686 .17022 Mdot
.686 .17267 Mdot
.686 .17277 Mdot
.686 .17301 Mdot
.686 .17378 Mdot
.686 .17489 Mdot
.686 .17505 Mdot
.686 .17521 Mdot
.686 .17652 Mdot
.686 .17697 Mdot
.686 .17714 Mdot
.686 .17726 Mdot
.686 .17729 Mdot
.686 .17935 Mdot
.686 .1794 Mdot
.686 .18154 Mdot
.686 .18351 Mdot
.686 .18606 Mdot
.686 .18723 Mdot
.686 .18827 Mdot
.686 .18873 Mdot
.686 .18981 Mdot
.686 .19218 Mdot
.686 .19257 Mdot
.686 .19456 Mdot
.686 .19474 Mdot
.686 .19498 Mdot
.686 .19772 Mdot
.686 .20018 Mdot
.686 .20043 Mdot
.686 .20226 Mdot
.686 .20429 Mdot
.686 .2043 Mdot
.686 .20438 Mdot
.686 .20526 Mdot
.686 .20838 Mdot
.686 .20855 Mdot
.686 .21108 Mdot
.686 .2122 Mdot
.686 .21261 Mdot
.686 .21615 Mdot
.686 .21644 Mdot
.686 .21932 Mdot
.686 .21956 Mdot
.686 .21985 Mdot
.686 .22 Mdot
.686 .2206 Mdot
.686 .22119 Mdot
.686 .22158 Mdot
.686 .22238 Mdot
.686 .22428 Mdot
.686 .22452 Mdot
.686 .22497 Mdot
.686 .22611 Mdot
.686 .22617 Mdot
.686 .22621 Mdot
.686 .22746 Mdot
.686 .22748 Mdot
.686 .22848 Mdot
.686 .22897 Mdot
.686 .22943 Mdot
.686 .22984 Mdot
.686 .23393 Mdot
.686 .23519 Mdot
.686 .23799 Mdot
.686 .23925 Mdot
.686 .24007 Mdot
.686 .24334 Mdot
.686 .24369 Mdot
.686 .24694 Mdot
.686 .249 Mdot
.686 .24912 Mdot
.686 .25069 Mdot
.686 .25407 Mdot
.686 .25453 Mdot
.686 .26265 Mdot
.686 .26532 Mdot
.686 .26647 Mdot
.686 .26774 Mdot
.686 .26777 Mdot
.686 .26913 Mdot
.686 .27195 Mdot
.686 .27202 Mdot
.686 .2754 Mdot
.686 .27546 Mdot
.686 .27559 Mdot
.686 .27572 Mdot
.686 .27587 Mdot
.686 .27638 Mdot
.686 .27776 Mdot
.686 .27915 Mdot
.686 .27982 Mdot
.686 .28045 Mdot
.686 .28117 Mdot
.686 .28202 Mdot
.686 .28249 Mdot
.686 .28249 Mdot
.686 .28256 Mdot
.686 .28259 Mdot
.686 .28273 Mdot
.686 .28288 Mdot
.686 .28291 Mdot
.686 .28367 Mdot
.686 .28397 Mdot
.686 .28428 Mdot
.686 .28469 Mdot
.686 .28471 Mdot
.686 .28489 Mdot
.686 .28659 Mdot
.686 .28672 Mdot
.686 .28909 Mdot
.686 .28913 Mdot
.686 .28953 Mdot
.686 .28974 Mdot
.686 .28983 Mdot
.686 .28998 Mdot
.686 .29024 Mdot
.686 .29049 Mdot
.686 .29069 Mdot
.686 .29074 Mdot
.686 .29079 Mdot
.686 .29169 Mdot
.686 .29185 Mdot
.686 .29194 Mdot
.686 .29201 Mdot
.686 .29201 Mdot
.686 .29379 Mdot
.686 .29408 Mdot
.686 .29425 Mdot
.686 .29433 Mdot
.686 .295 Mdot
.686 .29511 Mdot
.686 .29521 Mdot
.686 .29584 Mdot
.686 .29684 Mdot
.686 .29696 Mdot
.686 .297 Mdot
.686 .29706 Mdot
.686 .29784 Mdot
.686 .29834 Mdot
.686 .29839 Mdot
.686 .29899 Mdot
.686 .29908 Mdot
.686 .30035 Mdot
.686 .30072 Mdot
.686 .30089 Mdot
.686 .30091 Mdot
.686 .30093 Mdot
.686 .30103 Mdot
.686 .30128 Mdot
.686 .30141 Mdot
.686 .30324 Mdot
.686 .30453 Mdot
.686 .30469 Mdot
.686 .30543 Mdot
.686 .30688 Mdot
.686 .30724 Mdot
.686 .30764 Mdot
.686 .30789 Mdot
.686 .31016 Mdot
.686 .31047 Mdot
.686 .3111 Mdot
.686 .31226 Mdot
.686 .31293 Mdot
.686 .31631 Mdot
.686 .31667 Mdot
.686 .31756 Mdot
.686 .31771 Mdot
.686 .31869 Mdot
.686 .31971 Mdot
.686 .31973 Mdot
.686 .32 Mdot
.686 .32041 Mdot
.686 .32086 Mdot
.686 .32105 Mdot
.686 .32116 Mdot
.686 .3231 Mdot
.686 .32441 Mdot
.686 .32532 Mdot
.686 .32556 Mdot
.686 .32579 Mdot
.686 .32677 Mdot
.686 .32796 Mdot
.686 .32854 Mdot
.686 .32878 Mdot
.686 .32897 Mdot
.686 .32923 Mdot
.686 .32954 Mdot
.686 .32999 Mdot
.686 .33045 Mdot
.686 .33147 Mdot
.686 .33167 Mdot
.686 .3329 Mdot
.686 .33356 Mdot
.686 .33377 Mdot
.686 .33391 Mdot
.686 .33525 Mdot
.686 .33687 Mdot
.686 .33909 Mdot
.686 .33931 Mdot
.686 .3394 Mdot
.686 .34184 Mdot
.686 .34218 Mdot
.686 .34246 Mdot
.686 .34248 Mdot
.686 .34407 Mdot
.686 .34433 Mdot
.686 .34624 Mdot
.686 .34674 Mdot
.686 .34747 Mdot
.686 .34757 Mdot
.686 .34767 Mdot
.686 .34851 Mdot
.686 .3488 Mdot
.686 .34897 Mdot
.686 .34899 Mdot
.686 .35416 Mdot
.686 .35481 Mdot
.686 .35563 Mdot
.686 .35622 Mdot
.686 .35747 Mdot
.686 .35768 Mdot
.686 .35871 Mdot
.686 .3588 Mdot
.686 .35892 Mdot
.686 .36031 Mdot
.686 .36152 Mdot
.686 .36165 Mdot
.686 .36253 Mdot
.686 .36351 Mdot
.686 .36355 Mdot
.686 .36541 Mdot
.686 .3655 Mdot
.686 .36665 Mdot
.686 .36716 Mdot
.686 .37029 Mdot
.686 .37039 Mdot
.686 .37052 Mdot
.686 .37058 Mdot
.686 .37084 Mdot
.686 .37126 Mdot
.686 .3716 Mdot
.686 .3724 Mdot
.686 .3725 Mdot
.686 .37269 Mdot
.686 .37316 Mdot
.686 .37318 Mdot
.686 .3732 Mdot
.686 .37372 Mdot
.686 .37373 Mdot
.686 .37414 Mdot
.686 .37453 Mdot
.686 .37635 Mdot
.686 .37686 Mdot
.686 .37846 Mdot
.686 .38018 Mdot
.686 .38143 Mdot
.686 .3822 Mdot
.686 .38225 Mdot
.686 .38427 Mdot
.686 .38724 Mdot
.686 .38907 Mdot
.686 .39176 Mdot
.686 .39178 Mdot
.686 .3921 Mdot
.686 .39258 Mdot
.686 .39329 Mdot
.686 .39405 Mdot
.686 .39421 Mdot
.686 .39421 Mdot
.686 .39423 Mdot
.686 .39424 Mdot
.686 .39429 Mdot
.686 .39434 Mdot
.686 .39435 Mdot
.686 .39461 Mdot
.686 .39471 Mdot
.686 .39482 Mdot
.686 .39496 Mdot
.686 .39497 Mdot
.686 .39503 Mdot
.686 .39561 Mdot
.686 .39646 Mdot
.686 .3966 Mdot
.686 .39667 Mdot
.686 .3967 Mdot
.686 .39675 Mdot
.686 .39692 Mdot
.686 .39699 Mdot
.686 .39701 Mdot
.686 .39702 Mdot
.686 .39733 Mdot
.686 .39738 Mdot
.686 .39741 Mdot
.686 .39743 Mdot
.686 .39813 Mdot
.686 .39821 Mdot
.686 .39844 Mdot
.686 .39851 Mdot
.686 .39905 Mdot
.686 .39909 Mdot
.686 .3991 Mdot
.686 .39912 Mdot
.686 .39938 Mdot
.686 .39955 Mdot
.686 .39956 Mdot
.686 .39977 Mdot
.686 .39979 Mdot
.686 .40022 Mdot
.686 .40034 Mdot
.686 .40039 Mdot
.686 .4004 Mdot
.686 .40041 Mdot
.686 .40044 Mdot
.686 .40052 Mdot
.686 .40056 Mdot
.686 .40117 Mdot
.686 .40165 Mdot
.686 .40236 Mdot
.686 .40248 Mdot
.686 .40261 Mdot
.686 .40269 Mdot
.686 .40343 Mdot
.686 .40353 Mdot
.686 .40374 Mdot
.686 .40412 Mdot
.686 .40433 Mdot
.686 .40554 Mdot
.686 .40588 Mdot
.686 .40619 Mdot
.686 .40652 Mdot
.686 .40653 Mdot
.686 .40661 Mdot
.686 .40674 Mdot
.686 .40689 Mdot
.686 .40698 Mdot
.686 .40761 Mdot
.686 .40803 Mdot
.686 .40832 Mdot
.686 .40839 Mdot
.686 .40847 Mdot
.686 .40878 Mdot
.686 .40916 Mdot
.686 .40934 Mdot
.686 .40942 Mdot
.686 .40956 Mdot
.686 .4098 Mdot
.686 .40995 Mdot
.686 .41027 Mdot
.686 .41033 Mdot
.686 .41073 Mdot
.686 .41093 Mdot
.686 .411 Mdot
.686 .41104 Mdot
.686 .41147 Mdot
.686 .41198 Mdot
.686 .41268 Mdot
.686 .41275 Mdot
.686 .41354 Mdot
.686 .41424 Mdot
.686 .41432 Mdot
.686 .41508 Mdot
.686 .41531 Mdot
.686 .41534 Mdot
.686 .41537 Mdot
.686 .41563 Mdot
.686 .41572 Mdot
.686 .41578 Mdot
.686 .41739 Mdot
.686 .41804 Mdot
.686 .41843 Mdot
.686 .41849 Mdot
.686 .41881 Mdot
.686 .41884 Mdot
.686 .41888 Mdot
.686 .41931 Mdot
.686 .41969 Mdot
.686 .41972 Mdot
.686 .42 Mdot
.686 .4203 Mdot
.686 .42089 Mdot
.686 .42092 Mdot
.686 .42128 Mdot
.686 .42143 Mdot
.686 .4224 Mdot
.686 .42243 Mdot
.686 .42247 Mdot
.686 .42249 Mdot
.686 .42257 Mdot
.686 .4227 Mdot
.686 .42281 Mdot
.686 .42309 Mdot
.686 .42315 Mdot
.686 .4233 Mdot
.686 .42331 Mdot
.686 .42347 Mdot
.686 .4236 Mdot
.686 .42372 Mdot
.686 .42428 Mdot
.686 .42444 Mdot
.686 .42493 Mdot
.686 .42609 Mdot
.686 .42611 Mdot
.686 .42673 Mdot
.686 .42765 Mdot
.686 .42905 Mdot
.686 .42906 Mdot
.686 .42916 Mdot
.686 .42953 Mdot
.686 .43005 Mdot
.686 .43056 Mdot
.686 .43103 Mdot
.686 .43147 Mdot
.686 .43155 Mdot
.686 .43174 Mdot
.686 .43376 Mdot
.686 .43411 Mdot
.686 .43557 Mdot
.686 .43606 Mdot
.686 .43609 Mdot
.686 .4364 Mdot
.686 .43654 Mdot
.686 .43705 Mdot
.686 .43738 Mdot
.686 .4375 Mdot
.686 .43816 Mdot
.686 .43828 Mdot
.686 .43832 Mdot
.686 .43865 Mdot
.686 .43897 Mdot
.686 .43901 Mdot
.686 .43905 Mdot
.686 .43928 Mdot
.686 .43943 Mdot
.686 .44 Mdot
.686 .44236 Mdot
.686 .44299 Mdot
.686 .4431 Mdot
.686 .44341 Mdot
.686 .44366 Mdot
.686 .44796 Mdot
.686 .44813 Mdot
.686 .44855 Mdot
.686 .44987 Mdot
.686 .45089 Mdot
.686 .45132 Mdot
.686 .45178 Mdot
.686 .45186 Mdot
.686 .45203 Mdot
.686 .45205 Mdot
.686 .45232 Mdot
.686 .45311 Mdot
.686 .45454 Mdot
.686 .45531 Mdot
.686 .45559 Mdot
.686 .45579 Mdot
.686 .45584 Mdot
.686 .45708 Mdot
.686 .45803 Mdot
.686 .45829 Mdot
.686 .45867 Mdot
.686 .45873 Mdot
.686 .4588 Mdot
.686 .45927 Mdot
.686 .45932 Mdot
.686 .45936 Mdot
.686 .45986 Mdot
.686 .45994 Mdot
.686 .46013 Mdot
.686 .46122 Mdot
.686 .46142 Mdot
.686 .46195 Mdot
.686 .46277 Mdot
.686 .46285 Mdot
.686 .463 Mdot
.686 .46352 Mdot
.686 .46356 Mdot
.686 .46435 Mdot
.686 .46603 Mdot
.686 .46669 Mdot
.686 .46725 Mdot
.686 .47006 Mdot
.686 .47044 Mdot
.686 .47073 Mdot
.686 .47085 Mdot
.686 .47154 Mdot
.686 .4719 Mdot
.686 .47227 Mdot
.686 .47306 Mdot
.686 .4735 Mdot
.686 .47386 Mdot
.686 .4742 Mdot
.686 .47443 Mdot
.686 .47458 Mdot
.686 .47459 Mdot
.686 .47586 Mdot
.686 .47672 Mdot
.686 .4781 Mdot
.686 .47903 Mdot
.686 .47906 Mdot
.686 .47942 Mdot
.686 .47999 Mdot
.686 .48078 Mdot
.686 .48151 Mdot
.686 .48174 Mdot
.686 .48256 Mdot
.686 .48274 Mdot
.686 .48293 Mdot
.686 .48293 Mdot
.686 .48316 Mdot
.686 .48317 Mdot
.686 .48318 Mdot
.686 .4834 Mdot
.686 .48348 Mdot
.686 .48353 Mdot
.686 .48389 Mdot
.686 .48404 Mdot
.686 .48423 Mdot
.686 .48434 Mdot
.686 .48437 Mdot
.686 .48443 Mdot
.686 .48447 Mdot
.686 .48587 Mdot
.686 .48609 Mdot
.686 .4866 Mdot
.686 .48664 Mdot
.686 .48746 Mdot
.686 .48748 Mdot
.686 .48791 Mdot
.686 .4883 Mdot
.686 .48835 Mdot
.686 .48888 Mdot
.686 .48949 Mdot
.686 .48954 Mdot
.686 .48958 Mdot
.686 .49003 Mdot
.686 .49012 Mdot
.686 .49066 Mdot
.686 .49091 Mdot
.686 .49126 Mdot
.686 .49155 Mdot
.686 .49375 Mdot
.686 .49376 Mdot
.686 .49384 Mdot
.686 .49396 Mdot
.686 .49431 Mdot
.686 .49436 Mdot
.686 .4944 Mdot
.686 .49471 Mdot
.686 .49492 Mdot
.686 .49572 Mdot
.686 .49584 Mdot
.686 .4965 Mdot
.686 .49651 Mdot
.686 .49663 Mdot
.686 .49677 Mdot
.686 .49779 Mdot
.686 .49782 Mdot
.686 .49792 Mdot
.686 .49884 Mdot
.686 .4995 Mdot
.686 .50006 Mdot
.686 .50011 Mdot
.686 .5002 Mdot
.686 .50047 Mdot
.686 .50098 Mdot
.686 .50106 Mdot
.686 .50147 Mdot
.686 .50166 Mdot
.686 .50185 Mdot
.686 .50197 Mdot
.686 .50208 Mdot
.686 .50215 Mdot
.686 .50225 Mdot
.686 .50249 Mdot
.686 .50297 Mdot
.686 .50337 Mdot
.686 .50346 Mdot
.686 .50355 Mdot
.686 .50392 Mdot
.686 .50445 Mdot
.686 .50523 Mdot
.686 .50527 Mdot
.686 .50535 Mdot
.686 .50553 Mdot
.686 .50569 Mdot
.686 .5058 Mdot
.686 .50581 Mdot
.686 .50621 Mdot
.686 .5066 Mdot
.686 .50666 Mdot
.686 .50701 Mdot
.686 .50716 Mdot
.686 .50849 Mdot
.686 .50875 Mdot
.686 .50921 Mdot
.686 .50946 Mdot
.686 .50958 Mdot
.686 .51047 Mdot
.686 .51056 Mdot
.686 .51072 Mdot
.686 .51086 Mdot
.686 .51142 Mdot
.686 .51171 Mdot
.686 .51177 Mdot
.686 .51227 Mdot
.686 .51298 Mdot
.686 .51302 Mdot
.686 .51312 Mdot
.686 .51316 Mdot
.686 .51317 Mdot
.686 .51318 Mdot
.686 .51324 Mdot
.686 .51338 Mdot
.686 .51387 Mdot
.686 .5139 Mdot
.686 .51414 Mdot
.686 .51415 Mdot
.686 .51435 Mdot
.686 .51464 Mdot
.686 .51467 Mdot
.686 .51468 Mdot
.686 .51473 Mdot
.686 .51511 Mdot
.686 .51535 Mdot
.686 .51539 Mdot
.686 .51543 Mdot
.686 .51568 Mdot
.686 .51571 Mdot
.686 .51578 Mdot
.686 .51589 Mdot
.686 .51656 Mdot
.686 .51656 Mdot
.686 .51659 Mdot
.686 .51662 Mdot
.686 .51668 Mdot
.686 .51702 Mdot
.686 .51704 Mdot
.686 .51706 Mdot
.686 .51714 Mdot
.686 .51723 Mdot
.686 .51733 Mdot
.686 .51739 Mdot
.686 .51742 Mdot
.686 .5175 Mdot
.686 .51765 Mdot
.686 .51767 Mdot
.686 .51855 Mdot
.686 .5186 Mdot
.686 .51924 Mdot
.686 .51931 Mdot
.686 .51931 Mdot
.686 .51947 Mdot
.686 .51958 Mdot
.686 .51969 Mdot
.686 .51998 Mdot
.686 .51999 Mdot
.686 .52004 Mdot
.686 .52009 Mdot
.686 .52011 Mdot
.686 .52013 Mdot
.686 .52013 Mdot
.686 .52031 Mdot
.686 .52062 Mdot
.686 .52089 Mdot
.686 .52112 Mdot
.686 .52137 Mdot
.686 .52188 Mdot
.686 .52239 Mdot
.686 .52258 Mdot
.686 .52264 Mdot
.686 .52268 Mdot
.686 .52273 Mdot
.686 .52275 Mdot
.686 .52399 Mdot
.686 .52401 Mdot
.686 .52504 Mdot
.686 .52554 Mdot
.686 .52555 Mdot
.686 .52601 Mdot
.686 .52642 Mdot
.686 .52739 Mdot
.686 .53029 Mdot
.686 .53045 Mdot
.686 .53164 Mdot
.686 .5322 Mdot
.686 .53224 Mdot
.686 .53296 Mdot
.686 .5341 Mdot
.686 .53422 Mdot
.686 .53536 Mdot
.686 .53564 Mdot
.686 .53608 Mdot
.686 .53704 Mdot
.686 .53748 Mdot
.686 .53888 Mdot
.686 .53902 Mdot
.686 .53918 Mdot
.686 .53934 Mdot
.686 .53968 Mdot
.686 .53969 Mdot
.686 .54012 Mdot
.686 .54013 Mdot
.686 .54015 Mdot
.686 .54054 Mdot
.686 .54069 Mdot
.686 .54077 Mdot
.686 .54141 Mdot
.686 .54168 Mdot
.686 .54181 Mdot
.686 .54201 Mdot
.686 .54221 Mdot
.686 .54227 Mdot
.686 .54236 Mdot
.686 .54245 Mdot
.686 .54341 Mdot
.686 .54351 Mdot
.686 .54469 Mdot
.686 .54483 Mdot
.686 .5452 Mdot
.686 .54604 Mdot
.686 .5461 Mdot
.686 .54713 Mdot
.686 .54741 Mdot
.686 .54744 Mdot
.686 .54745 Mdot
.686 .54811 Mdot
.686 .54871 Mdot
.686 .54879 Mdot
.686 .5496 Mdot
.686 .55049 Mdot
.686 .55057 Mdot
.686 .55063 Mdot
.686 .55127 Mdot
.686 .5514 Mdot
.686 .55217 Mdot
.686 .55252 Mdot
.686 .55266 Mdot
.686 .553 Mdot
.686 .55337 Mdot
.686 .55419 Mdot
.686 .55482 Mdot
.686 .5555 Mdot
.686 .55552 Mdot
.686 .55618 Mdot
.686 .55619 Mdot
.686 .55622 Mdot
.686 .55628 Mdot
.686 .55642 Mdot
.686 .55684 Mdot
.686 .55689 Mdot
.686 .55694 Mdot
.686 .55729 Mdot
.686 .55753 Mdot
.686 .55761 Mdot
.686 .55764 Mdot
.686 .55841 Mdot
.686 .55853 Mdot
.686 .55916 Mdot
.686 .55918 Mdot
.686 .55922 Mdot
.686 .55923 Mdot
.686 .55924 Mdot
.686 .55929 Mdot
.686 .55935 Mdot
.686 .55936 Mdot
.686 .55949 Mdot
.686 .55957 Mdot
.686 .56013 Mdot
.686 .56048 Mdot
.686 .56051 Mdot
.686 .5606 Mdot
.686 .56068 Mdot
.686 .56093 Mdot
.686 .56116 Mdot
.686 .56141 Mdot
.686 .56142 Mdot
.686 .56171 Mdot
.686 .56187 Mdot
.686 .56187 Mdot
.686 .5619 Mdot
.686 .56191 Mdot
.686 .56195 Mdot
.686 .56197 Mdot
.686 .562 Mdot
.686 .56201 Mdot
.686 .56226 Mdot
.686 .56236 Mdot
.686 .56241 Mdot
.686 .56245 Mdot
.686 .56246 Mdot
.686 .56252 Mdot
.686 .56259 Mdot
.686 .56259 Mdot
.686 .56265 Mdot
.686 .56272 Mdot
.686 .56309 Mdot
.686 .56314 Mdot
.686 .56315 Mdot
.686 .56319 Mdot
.686 .56343 Mdot
.686 .56355 Mdot
.686 .56367 Mdot
.686 .56375 Mdot
.686 .56382 Mdot
.686 .56382 Mdot
.686 .56384 Mdot
.686 .56387 Mdot
.686 .56393 Mdot
.686 .56394 Mdot
.686 .56399 Mdot
.686 .56401 Mdot
.686 .56405 Mdot
.686 .56407 Mdot
.686 .56411 Mdot
.686 .56417 Mdot
.686 .56422 Mdot
.686 .56423 Mdot
.686 .56424 Mdot
.686 .56435 Mdot
.686 .56444 Mdot
.686 .56448 Mdot
.686 .5645 Mdot
.686 .56451 Mdot
.686 .56451 Mdot
.686 .56456 Mdot
.686 .56461 Mdot
.686 .56466 Mdot
.686 .56484 Mdot
.686 .56488 Mdot
.686 .56493 Mdot
.686 .56497 Mdot
.686 .56498 Mdot
.686 .56509 Mdot
.686 .5651 Mdot
.686 .56512 Mdot
.686 .56514 Mdot
.686 .56525 Mdot
.686 .56541 Mdot
.686 .56542 Mdot
.686 .56543 Mdot
.686 .56543 Mdot
.686 .56544 Mdot
.686 .56544 Mdot
.686 .56546 Mdot
.686 .56553 Mdot
.686 .56556 Mdot
.686 .56559 Mdot
.686 .56562 Mdot
.686 .56563 Mdot
.686 .56563 Mdot
.686 .56564 Mdot
.686 .56572 Mdot
.686 .56573 Mdot
.686 .56576 Mdot
.686 .56587 Mdot
.686 .56588 Mdot
.686 .56589 Mdot
.686 .56593 Mdot
.686 .56594 Mdot
.686 .56594 Mdot
.686 .56595 Mdot
.686 .56597 Mdot
.686 .56598 Mdot
.686 .56599 Mdot
.686 .56602 Mdot
.686 .56614 Mdot
.686 .56623 Mdot
.686 .56624 Mdot
.686 .56626 Mdot
.686 .56627 Mdot
.686 .56629 Mdot
.686 .56633 Mdot
.686 .56633 Mdot
.686 .56633 Mdot
.686 .56634 Mdot
.686 .56634 Mdot
.686 .56635 Mdot
.686 .56635 Mdot
.688 .14387 Mdot
.688 .14387 Mdot
.688 .14387 Mdot
.688 .14387 Mdot
.688 .14387 Mdot
.688 .14388 Mdot
.688 .14389 Mdot
.688 .14392 Mdot
.688 .14394 Mdot
.688 .14405 Mdot
.688 .14422 Mdot
.688 .14425 Mdot
.688 .14425 Mdot
.688 .14425 Mdot
.688 .14432 Mdot
.688 .14439 Mdot
.688 .14449 Mdot
.688 .14462 Mdot
.688 .14462 Mdot
.688 .14469 Mdot
.688 .14472 Mdot
.688 .14476 Mdot
.688 .14504 Mdot
.688 .14516 Mdot
.688 .14522 Mdot
.688 .1454 Mdot
.688 .14547 Mdot
.688 .14569 Mdot
.688 .14576 Mdot
.688 .14579 Mdot
.688 .14581 Mdot
.688 .14604 Mdot
.688 .14605 Mdot
.688 .14633 Mdot
.688 .14644 Mdot
.688 .14652 Mdot
.688 .14666 Mdot
.688 .14674 Mdot
.688 .14689 Mdot
.688 .147 Mdot
.688 .1471 Mdot
.688 .14751 Mdot
.688 .14759 Mdot
.688 .14762 Mdot
.688 .14788 Mdot
.688 .14792 Mdot
.688 .14841 Mdot
.688 .14871 Mdot
.688 .14898 Mdot
.688 .14914 Mdot
.688 .14917 Mdot
.688 .14953 Mdot
.688 .14962 Mdot
.688 .14984 Mdot
.688 .1499 Mdot
.688 .15036 Mdot
.688 .15041 Mdot
.688 .15041 Mdot
.688 .1505 Mdot
.688 .15067 Mdot
.688 .15072 Mdot
.688 .1515 Mdot
.688 .15152 Mdot
.688 .15158 Mdot
.688 .15175 Mdot
.688 .15192 Mdot
.688 .15209 Mdot
.688 .15238 Mdot
.688 .15279 Mdot
.688 .15304 Mdot
.688 .15314 Mdot
.688 .15325 Mdot
.688 .15361 Mdot
.688 .15399 Mdot
.688 .15464 Mdot
.688 .15488 Mdot
.688 .15493 Mdot
.688 .15496 Mdot
.688 .15509 Mdot
.688 .15571 Mdot
.688 .15582 Mdot
.688 .15616 Mdot
.688 .15647 Mdot
.688 .15662 Mdot
.688 .15745 Mdot
.688 .1577 Mdot
.688 .15795 Mdot
.688 .15811 Mdot
.688 .15836 Mdot
.688 .15838 Mdot
.688 .15856 Mdot
.688 .15878 Mdot
.688 .15927 Mdot
.688 .15957 Mdot
.688 .15995 Mdot
.688 .16028 Mdot
.688 .16035 Mdot
.688 .16047 Mdot
.688 .16092 Mdot
.688 .16095 Mdot
.688 .16098 Mdot
.688 .16116 Mdot
.688 .16122 Mdot
.688 .16226 Mdot
.688 .16243 Mdot
.688 .16287 Mdot
.688 .16328 Mdot
.688 .16337 Mdot
.688 .16363 Mdot
.688 .16368 Mdot
.688 .16374 Mdot
.688 .16377 Mdot
.688 .16381 Mdot
.688 .16381 Mdot
.688 .16381 Mdot
.688 .1647 Mdot
.688 .16477 Mdot
.688 .16496 Mdot
.688 .1653 Mdot
.688 .16671 Mdot
.688 .16879 Mdot
.688 .16994 Mdot
.688 .17102 Mdot
.688 .17105 Mdot
.688 .17115 Mdot
.688 .17165 Mdot
.688 .17321 Mdot
.688 .17375 Mdot
.688 .17405 Mdot
.688 .17463 Mdot
.688 .17531 Mdot
.688 .17534 Mdot
.688 .17575 Mdot
.688 .17701 Mdot
.688 .17729 Mdot
.688 .18174 Mdot
.688 .18288 Mdot
.688 .18293 Mdot
.688 .18537 Mdot
.688 .18632 Mdot
.688 .1867 Mdot
.688 .18748 Mdot
.688 .18775 Mdot
.688 .19025 Mdot
.688 .19209 Mdot
.688 .19323 Mdot
.688 .19401 Mdot
.688 .19606 Mdot
.688 .19762 Mdot
.688 .19855 Mdot
.688 .20202 Mdot
.688 .20207 Mdot
.688 .20254 Mdot
.688 .20315 Mdot
.688 .20377 Mdot
.688 .20424 Mdot
.688 .20583 Mdot
.688 .20914 Mdot
.688 .20971 Mdot
.688 .21133 Mdot
.688 .21479 Mdot
.688 .21487 Mdot
.688 .21501 Mdot
.688 .21513 Mdot
.688 .21771 Mdot
.688 .22 Mdot
.688 .22073 Mdot
.688 .22083 Mdot
.688 .22179 Mdot
.688 .2237 Mdot
.688 .22547 Mdot
.688 .22549 Mdot
.688 .22805 Mdot
.688 .22814 Mdot
.688 .23058 Mdot
.688 .23266 Mdot
.688 .23461 Mdot
.688 .23631 Mdot
.688 .2369 Mdot
.688 .23861 Mdot
.688 .24119 Mdot
.688 .24384 Mdot
.688 .24489 Mdot
.688 .24564 Mdot
.688 .24644 Mdot
.688 .24689 Mdot
.688 .2472 Mdot
.688 .24937 Mdot
.688 .25173 Mdot
.688 .25426 Mdot
.688 .25478 Mdot
.688 .25529 Mdot
.688 .25701 Mdot
.688 .25825 Mdot
.688 .25928 Mdot
.688 .26259 Mdot
.688 .26273 Mdot
.688 .2639 Mdot
.688 .26959 Mdot
.688 .26985 Mdot
.688 .27267 Mdot
.688 .27705 Mdot
.688 .2772 Mdot
.688 .27726 Mdot
.688 .27795 Mdot
.688 .27795 Mdot
.688 .27795 Mdot
.688 .27798 Mdot
.688 .278 Mdot
.688 .27805 Mdot
.688 .27809 Mdot
.688 .2783 Mdot
.688 .27837 Mdot
.688 .27906 Mdot
.688 .28006 Mdot
.688 .28011 Mdot
.688 .28026 Mdot
.688 .28029 Mdot
.688 .28031 Mdot
.688 .2807 Mdot
.688 .28086 Mdot
.688 .28115 Mdot
.688 .28175 Mdot
.688 .28239 Mdot
.688 .28256 Mdot
.688 .28258 Mdot
.688 .28296 Mdot
.688 .28319 Mdot
.688 .28342 Mdot
.688 .28513 Mdot
.688 .28577 Mdot
.688 .2859 Mdot
.688 .28624 Mdot
.688 .28737 Mdot
.688 .28778 Mdot
.688 .28791 Mdot
.688 .28802 Mdot
.688 .2883 Mdot
.688 .28914 Mdot
.688 .28934 Mdot
.688 .28956 Mdot
.688 .28977 Mdot
.688 .28987 Mdot
.688 .29088 Mdot
.688 .29117 Mdot
.688 .2913 Mdot
.688 .29136 Mdot
.688 .29311 Mdot
.688 .29335 Mdot
.688 .29378 Mdot
.688 .29426 Mdot
.688 .29508 Mdot
.688 .29515 Mdot
.688 .29565 Mdot
.688 .2958 Mdot
.688 .29656 Mdot
.688 .29676 Mdot
.688 .29728 Mdot
.688 .29792 Mdot
.688 .2995 Mdot
.688 .30026 Mdot
.688 .30044 Mdot
.688 .30097 Mdot
.688 .30113 Mdot
.688 .30152 Mdot
.688 .30247 Mdot
.688 .30276 Mdot
.688 .30301 Mdot
.688 .30356 Mdot
.688 .30401 Mdot
.688 .30471 Mdot
.688 .30474 Mdot
.688 .30476 Mdot
.688 .30607 Mdot
.688 .30796 Mdot
.688 .30813 Mdot
.688 .3085 Mdot
.688 .30885 Mdot
.688 .30891 Mdot
.688 .30915 Mdot
.688 .30966 Mdot
.688 .31068 Mdot
.688 .31084 Mdot
.688 .31313 Mdot
.688 .31366 Mdot
.688 .31504 Mdot
.688 .31542 Mdot
.688 .31836 Mdot
.688 .31861 Mdot
.688 .31866 Mdot
.688 .31921 Mdot
.688 .31924 Mdot
.688 .31988 Mdot
.688 .32028 Mdot
.688 .32058 Mdot
.688 .32104 Mdot
.688 .32243 Mdot
.688 .32497 Mdot
.688 .32551 Mdot
.688 .32563 Mdot
.688 .32594 Mdot
.688 .32603 Mdot
.688 .32674 Mdot
.688 .32709 Mdot
.688 .32819 Mdot
.688 .32925 Mdot
.688 .33109 Mdot
.688 .33204 Mdot
.688 .3321 Mdot
.688 .33301 Mdot
.688 .33335 Mdot
.688 .33366 Mdot
.688 .33381 Mdot
.688 .33522 Mdot
.688 .33584 Mdot
.688 .33655 Mdot
.688 .33723 Mdot
.688 .33884 Mdot
.688 .33934 Mdot
.688 .34123 Mdot
.688 .34229 Mdot
.688 .3438 Mdot
.688 .3446 Mdot
.688 .34534 Mdot
.688 .34544 Mdot
.688 .34577 Mdot
.688 .34681 Mdot
.688 .34716 Mdot
.688 .34736 Mdot
.688 .34773 Mdot
.688 .34817 Mdot
.688 .34923 Mdot
.688 .3494 Mdot
.688 .35207 Mdot
.688 .35273 Mdot
.688 .35275 Mdot
.688 .35466 Mdot
.688 .35487 Mdot
.688 .35679 Mdot
.688 .35776 Mdot
.688 .35835 Mdot
.688 .36057 Mdot
.688 .36271 Mdot
.688 .36296 Mdot
.688 .36355 Mdot
.688 .36451 Mdot
.688 .36604 Mdot
.688 .36703 Mdot
.688 .36857 Mdot
.688 .36861 Mdot
.688 .36872 Mdot
.688 .36984 Mdot
.688 .37118 Mdot
.688 .37313 Mdot
.688 .37423 Mdot
.688 .37523 Mdot
.688 .37607 Mdot
.688 .37752 Mdot
.688 .37775 Mdot
.688 .37842 Mdot
.688 .38044 Mdot
.688 .38085 Mdot
.688 .38144 Mdot
.688 .38161 Mdot
.688 .38254 Mdot
.688 .38436 Mdot
.688 .38455 Mdot
.688 .38474 Mdot
.688 .38582 Mdot
.688 .3862 Mdot
.688 .3874 Mdot
.688 .38787 Mdot
.688 .39097 Mdot
.688 .3925 Mdot
.688 .39281 Mdot
.688 .39281 Mdot
.688 .39281 Mdot
.688 .39282 Mdot
.688 .39282 Mdot
.688 .39284 Mdot
.688 .39286 Mdot
.688 .39293 Mdot
.688 .39295 Mdot
.688 .39319 Mdot
.688 .39353 Mdot
.688 .39355 Mdot
.688 .3936 Mdot
.688 .39361 Mdot
.688 .39362 Mdot
.688 .39375 Mdot
.688 .39381 Mdot
.688 .39391 Mdot
.688 .39411 Mdot
.688 .39439 Mdot
.688 .3944 Mdot
.688 .39453 Mdot
.688 .3946 Mdot
.688 .39468 Mdot
.688 .39527 Mdot
.688 .39548 Mdot
.688 .39553 Mdot
.688 .39564 Mdot
.688 .39602 Mdot
.688 .39616 Mdot
.688 .39621 Mdot
.688 .39634 Mdot
.688 .39662 Mdot
.688 .39669 Mdot
.688 .39676 Mdot
.688 .39683 Mdot
.688 .39687 Mdot
.688 .39735 Mdot
.688 .39737 Mdot
.688 .39795 Mdot
.688 .39818 Mdot
.688 .39834 Mdot
.688 .39861 Mdot
.688 .39863 Mdot
.688 .3988 Mdot
.688 .39885 Mdot
.688 .3991 Mdot
.688 .39917 Mdot
.688 .39934 Mdot
.688 .39955 Mdot
.688 .39961 Mdot
.688 .40008 Mdot
.688 .40039 Mdot
.688 .40056 Mdot
.688 .40062 Mdot
.688 .40074 Mdot
.688 .40106 Mdot
.688 .40115 Mdot
.688 .40123 Mdot
.688 .40141 Mdot
.688 .40156 Mdot
.688 .40179 Mdot
.688 .4018 Mdot
.688 .40181 Mdot
.688 .40223 Mdot
.688 .40285 Mdot
.688 .40314 Mdot
.688 .40341 Mdot
.688 .40373 Mdot
.688 .40379 Mdot
.688 .40453 Mdot
.688 .4047 Mdot
.688 .40514 Mdot
.688 .40527 Mdot
.688 .40621 Mdot
.688 .4063 Mdot
.688 .40631 Mdot
.688 .40649 Mdot
.688 .40649 Mdot
.688 .40683 Mdot
.688 .40693 Mdot
.688 .40707 Mdot
.688 .40752 Mdot
.688 .4085 Mdot
.688 .40854 Mdot
.688 .40864 Mdot
.688 .40866 Mdot
.688 .409 Mdot
.688 .40935 Mdot
.688 .40969 Mdot
.688 .41027 Mdot
.688 .41057 Mdot
.688 .41059 Mdot
.688 .41088 Mdot
.688 .41098 Mdot
.688 .41108 Mdot
.688 .41113 Mdot
.688 .41157 Mdot
.688 .41177 Mdot
.688 .41199 Mdot
.688 .41271 Mdot
.688 .41287 Mdot
.688 .41346 Mdot
.688 .41452 Mdot
.688 .41475 Mdot
.688 .41478 Mdot
.688 .41521 Mdot
.688 .41532 Mdot
.688 .41538 Mdot
.688 .41563 Mdot
.688 .41685 Mdot
.688 .41705 Mdot
.688 .41706 Mdot
.688 .41765 Mdot
.688 .41772 Mdot
.688 .41831 Mdot
.688 .41861 Mdot
.688 .4188 Mdot
.688 .42015 Mdot
.688 .42023 Mdot
.688 .42071 Mdot
.688 .42118 Mdot
.688 .42149 Mdot
.688 .42196 Mdot
.688 .42201 Mdot
.688 .42236 Mdot
.688 .42277 Mdot
.688 .42337 Mdot
.688 .42371 Mdot
.688 .42428 Mdot
.688 .42473 Mdot
.688 .42501 Mdot
.688 .42563 Mdot
.688 .42576 Mdot
.688 .42599 Mdot
.688 .42628 Mdot
.688 .42684 Mdot
.688 .4269 Mdot
.688 .42696 Mdot
.688 .4273 Mdot
.688 .42741 Mdot
.688 .42793 Mdot
.688 .42889 Mdot
.688 .42936 Mdot
.688 .42968 Mdot
.688 .42977 Mdot
.688 .43051 Mdot
.688 .43066 Mdot
.688 .43125 Mdot
.688 .43143 Mdot
.688 .43156 Mdot
.688 .43192 Mdot
.688 .43201 Mdot
.688 .43212 Mdot
.688 .43217 Mdot
.688 .43224 Mdot
.688 .43224 Mdot
.688 .43225 Mdot
.688 .4337 Mdot
.688 .43389 Mdot
.688 .43402 Mdot
.688 .43437 Mdot
.688 .43498 Mdot
.688 .43498 Mdot
.688 .43507 Mdot
.688 .43569 Mdot
.688 .43621 Mdot
.688 .43701 Mdot
.688 .4372 Mdot
.688 .43756 Mdot
.688 .43798 Mdot
.688 .439 Mdot
.688 .43943 Mdot
.688 .43992 Mdot
.688 .44044 Mdot
.688 .44131 Mdot
.688 .4416 Mdot
.688 .44292 Mdot
.688 .44309 Mdot
.688 .44334 Mdot
.688 .44365 Mdot
.688 .44445 Mdot
.688 .44525 Mdot
.688 .4453 Mdot
.688 .44549 Mdot
.688 .44575 Mdot
.688 .44617 Mdot
.688 .44631 Mdot
.688 .44635 Mdot
.688 .44641 Mdot
.688 .44649 Mdot
.688 .44673 Mdot
.688 .44747 Mdot
.688 .44792 Mdot
.688 .44824 Mdot
.688 .44833 Mdot
.688 .44908 Mdot
.688 .44972 Mdot
.688 .45001 Mdot
.688 .45029 Mdot
.688 .45053 Mdot
.688 .45109 Mdot
.688 .45152 Mdot
.688 .45162 Mdot
.688 .45206 Mdot
.688 .45235 Mdot
.688 .45269 Mdot
.688 .45274 Mdot
.688 .45343 Mdot
.688 .45459 Mdot
.688 .45508 Mdot
.688 .45556 Mdot
.688 .45603 Mdot
.688 .45654 Mdot
.688 .45741 Mdot
.688 .45823 Mdot
.688 .45894 Mdot
.688 .46062 Mdot
.688 .46132 Mdot
.688 .4619 Mdot
.688 .46221 Mdot
.688 .46337 Mdot
.688 .46351 Mdot
.688 .46434 Mdot
.688 .46522 Mdot
.688 .46529 Mdot
.688 .46535 Mdot
.688 .46549 Mdot
.688 .4655 Mdot
.688 .46647 Mdot
.688 .46702 Mdot
.688 .46724 Mdot
.688 .46753 Mdot
.688 .46918 Mdot
.688 .46983 Mdot
.688 .46984 Mdot
.688 .46984 Mdot
.688 .46995 Mdot
.688 .47002 Mdot
.688 .4702 Mdot
.688 .47035 Mdot
.688 .47067 Mdot
.688 .4709 Mdot
.688 .47111 Mdot
.688 .47127 Mdot
.688 .47139 Mdot
.688 .47231 Mdot
.688 .47248 Mdot
.688 .47254 Mdot
.688 .47289 Mdot
.688 .47369 Mdot
.688 .47382 Mdot
.688 .47431 Mdot
.688 .47504 Mdot
.688 .4765 Mdot
.688 .47672 Mdot
.688 .47727 Mdot
.688 .47745 Mdot
.688 .47795 Mdot
.688 .47804 Mdot
.688 .47813 Mdot
.688 .47897 Mdot
.688 .4794 Mdot
.688 .47948 Mdot
.688 .47975 Mdot
.688 .47994 Mdot
.688 .48087 Mdot
.688 .48117 Mdot
.688 .48128 Mdot
.688 .48194 Mdot
.688 .48232 Mdot
.688 .48277 Mdot
.688 .48326 Mdot
.688 .48414 Mdot
.688 .48474 Mdot
.688 .48524 Mdot
.688 .48529 Mdot
.688 .48531 Mdot
.688 .48599 Mdot
.688 .48643 Mdot
.688 .4871 Mdot
.688 .48753 Mdot
.688 .48779 Mdot
.688 .48789 Mdot
.688 .48883 Mdot
.688 .4898 Mdot
.688 .49006 Mdot
.688 .49047 Mdot
.688 .4913 Mdot
.688 .49139 Mdot
.688 .49221 Mdot
.688 .49222 Mdot
.688 .49251 Mdot
.688 .49364 Mdot
.688 .49372 Mdot
.688 .49417 Mdot
.688 .49435 Mdot
.688 .49451 Mdot
.688 .49459 Mdot
.688 .49474 Mdot
.688 .49518 Mdot
.688 .49532 Mdot
.688 .49536 Mdot
.688 .49567 Mdot
.688 .49601 Mdot
.688 .49664 Mdot
.688 .49708 Mdot
.688 .49787 Mdot
.688 .49808 Mdot
.688 .49875 Mdot
.688 .49903 Mdot
.688 .49932 Mdot
.688 .49957 Mdot
.688 .50016 Mdot
.688 .50022 Mdot
.688 .50034 Mdot
.688 .50048 Mdot
.688 .50086 Mdot
.688 .50088 Mdot
.688 .50127 Mdot
.688 .50202 Mdot
.688 .50245 Mdot
.688 .50289 Mdot
.688 .50303 Mdot
.688 .50332 Mdot
.688 .50336 Mdot
.688 .50348 Mdot
.688 .50353 Mdot
.688 .50375 Mdot
.688 .50477 Mdot
.688 .50533 Mdot
.688 .50551 Mdot
.688 .50563 Mdot
.688 .50579 Mdot
.688 .50605 Mdot
.688 .50606 Mdot
.688 .50628 Mdot
.688 .50629 Mdot
.688 .5064 Mdot
.688 .50756 Mdot
.688 .50771 Mdot
.688 .50826 Mdot
.688 .50846 Mdot
.688 .50936 Mdot
.688 .50943 Mdot
.688 .50982 Mdot
.688 .51002 Mdot
.688 .51012 Mdot
.688 .51014 Mdot
.688 .51028 Mdot
.688 .51042 Mdot
.688 .51049 Mdot
.688 .51122 Mdot
.688 .51173 Mdot
.688 .51174 Mdot
.688 .51175 Mdot
.688 .51202 Mdot
.688 .51219 Mdot
.688 .51241 Mdot
.688 .5125 Mdot
.688 .51261 Mdot
.688 .51298 Mdot
.688 .51313 Mdot
.688 .51319 Mdot
.688 .51339 Mdot
.688 .51347 Mdot
.688 .51376 Mdot
.688 .5143 Mdot
.688 .51436 Mdot
.688 .5146 Mdot
.688 .5148 Mdot
.688 .51488 Mdot
.688 .51517 Mdot
.688 .51523 Mdot
.688 .51542 Mdot
.688 .51544 Mdot
.688 .51576 Mdot
.688 .51594 Mdot
.688 .5161 Mdot
.688 .51619 Mdot
.688 .51685 Mdot
.688 .51688 Mdot
.688 .51693 Mdot
.688 .51703 Mdot
.688 .51741 Mdot
.688 .51745 Mdot
.688 .51753 Mdot
.688 .51761 Mdot
.688 .51769 Mdot
.688 .518 Mdot
.688 .51811 Mdot
.688 .51815 Mdot
.688 .5182 Mdot
.688 .51835 Mdot
.688 .51878 Mdot
.688 .5189 Mdot
.688 .51895 Mdot
.688 .51919 Mdot
.688 .51983 Mdot
.688 .51992 Mdot
.688 .52 Mdot
.688 .52014 Mdot
.688 .52015 Mdot
.688 .52021 Mdot
.688 .52045 Mdot
.688 .52067 Mdot
.688 .52078 Mdot
.688 .52084 Mdot
.688 .52098 Mdot
.688 .52099 Mdot
.688 .521 Mdot
.688 .52106 Mdot
.688 .52108 Mdot
.688 .52145 Mdot
.688 .5217 Mdot
.688 .52173 Mdot
.688 .5218 Mdot
.688 .52182 Mdot
.688 .52184 Mdot
.688 .52184 Mdot
.688 .52186 Mdot
.688 .52186 Mdot
.688 .52186 Mdot
.688 .52211 Mdot
.688 .52213 Mdot
.688 .52219 Mdot
.688 .52379 Mdot
.688 .52482 Mdot
.688 .52492 Mdot
.688 .52698 Mdot
.688 .52739 Mdot
.688 .52745 Mdot
.688 .52863 Mdot
.688 .529 Mdot
.688 .52944 Mdot
.688 .53005 Mdot
.688 .53023 Mdot
.688 .53042 Mdot
.688 .53131 Mdot
.688 .53215 Mdot
.688 .5329 Mdot
.688 .53301 Mdot
.688 .53317 Mdot
.688 .53345 Mdot
.688 .53371 Mdot
.688 .53408 Mdot
.688 .535 Mdot
.688 .5359 Mdot
.688 .53649 Mdot
.688 .53669 Mdot
.688 .53728 Mdot
.688 .53795 Mdot
.688 .53866 Mdot
.688 .53949 Mdot
.688 .53952 Mdot
.688 .54039 Mdot
.688 .5404 Mdot
.688 .541 Mdot
.688 .54164 Mdot
.688 .54197 Mdot
.688 .542 Mdot
.688 .54225 Mdot
.688 .54302 Mdot
.688 .54388 Mdot
.688 .54392 Mdot
.688 .54396 Mdot
.688 .54399 Mdot
.688 .54514 Mdot
.688 .54568 Mdot
.688 .54587 Mdot
.688 .54697 Mdot
.688 .54749 Mdot
.688 .54764 Mdot
.688 .54785 Mdot
.688 .54805 Mdot
.688 .5482 Mdot
.688 .54822 Mdot
.688 .54936 Mdot
.688 .54966 Mdot
.688 .55017 Mdot
.688 .55083 Mdot
.688 .55108 Mdot
.688 .55145 Mdot
.688 .55205 Mdot
.688 .55285 Mdot
.688 .55294 Mdot
.688 .55319 Mdot
.688 .55331 Mdot
.688 .55362 Mdot
.688 .5544 Mdot
.688 .55442 Mdot
.688 .55478 Mdot
.688 .5562 Mdot
.688 .55629 Mdot
.688 .55669 Mdot
.688 .55681 Mdot
.688 .55682 Mdot
.688 .55704 Mdot
.688 .55722 Mdot
.688 .55732 Mdot
.688 .55749 Mdot
.688 .55798 Mdot
.688 .55814 Mdot
.688 .55817 Mdot
.688 .55818 Mdot
.688 .55852 Mdot
.688 .55888 Mdot
.688 .55953 Mdot
.688 .55998 Mdot
.688 .56008 Mdot
.688 .56014 Mdot
.688 .56016 Mdot
.688 .56044 Mdot
.688 .56044 Mdot
.688 .56044 Mdot
.688 .56045 Mdot
.688 .56046 Mdot
.688 .56048 Mdot
.688 .5605 Mdot
.688 .56058 Mdot
.688 .56061 Mdot
.688 .56073 Mdot
.688 .56087 Mdot
.688 .56092 Mdot
.688 .56125 Mdot
.688 .56127 Mdot
.688 .56132 Mdot
.688 .56133 Mdot
.688 .56134 Mdot
.688 .56148 Mdot
.688 .56152 Mdot
.688 .56154 Mdot
.688 .56164 Mdot
.688 .56176 Mdot
.688 .56185 Mdot
.688 .56201 Mdot
.688 .56207 Mdot
.688 .56213 Mdot
.688 .56214 Mdot
.688 .56221 Mdot
.688 .56226 Mdot
.688 .56234 Mdot
.688 .56242 Mdot
.688 .56267 Mdot
.688 .56272 Mdot
.688 .56282 Mdot
.688 .56292 Mdot
.688 .56296 Mdot
.688 .56315 Mdot
.688 .56319 Mdot
.688 .5632 Mdot
.688 .56321 Mdot
.688 .56329 Mdot
.688 .56349 Mdot
.688 .5636 Mdot
.688 .56372 Mdot
.688 .56375 Mdot
.688 .56378 Mdot
.688 .56386 Mdot
.688 .56398 Mdot
.688 .56407 Mdot
.688 .56412 Mdot
.688 .56418 Mdot
.688 .56423 Mdot
.688 .56425 Mdot
.688 .56425 Mdot
.688 .56449 Mdot
.688 .56451 Mdot
.688 .56456 Mdot
.688 .56459 Mdot
.688 .56459 Mdot
.688 .5646 Mdot
.688 .56475 Mdot
.688 .56476 Mdot
.688 .56483 Mdot
.688 .56486 Mdot
.688 .56497 Mdot
.688 .56498 Mdot
.688 .56503 Mdot
.688 .56511 Mdot
.688 .5652 Mdot
.688 .56535 Mdot
.688 .56536 Mdot
.688 .56544 Mdot
.688 .56545 Mdot
.688 .56548 Mdot
.688 .5656 Mdot
.688 .56563 Mdot
.688 .56567 Mdot
.688 .56571 Mdot
.688 .56574 Mdot
.688 .56578 Mdot
.688 .56581 Mdot
.688 .56584 Mdot
.688 .56592 Mdot
.688 .56593 Mdot
.688 .566 Mdot
.688 .566 Mdot
.688 .56601 Mdot
.688 .56603 Mdot
.688 .5661 Mdot
.688 .56612 Mdot
.688 .56618 Mdot
.688 .56619 Mdot
.688 .56623 Mdot
.688 .56632 Mdot
.688 .56633 Mdot
.688 .56634 Mdot
.688 .56636 Mdot
.688 .56636 Mdot
.688 .5664 Mdot
.688 .56643 Mdot
.688 .56645 Mdot
.688 .56647 Mdot
.688 .56647 Mdot
.688 .56647 Mdot
.688 .56648 Mdot
.688 .56653 Mdot
.688 .56657 Mdot
.688 .56657 Mdot
.688 .56658 Mdot
.688 .56659 Mdot
.688 .56659 Mdot
.688 .56659 Mdot
.688 .56659 Mdot
.688 .56659 Mdot
.688 .56659 Mdot
.69 .14315 Mdot
.69 .14315 Mdot
.69 .14316 Mdot
.69 .14316 Mdot
.69 .14317 Mdot
.69 .14317 Mdot
.69 .14317 Mdot
.69 .14318 Mdot
.69 .14319 Mdot
.69 .1432 Mdot
.69 .14321 Mdot
.69 .14323 Mdot
.69 .14332 Mdot
.69 .14346 Mdot
.69 .14347 Mdot
.69 .14352 Mdot
.69 .14356 Mdot
.69 .14357 Mdot
.69 .14375 Mdot
.69 .14399 Mdot
.69 .14411 Mdot
.69 .14425 Mdot
.69 .14436 Mdot
.69 .14453 Mdot
.69 .14458 Mdot
.69 .14481 Mdot
.69 .14503 Mdot
.69 .14507 Mdot
.69 .14527 Mdot
.69 .14576 Mdot
.69 .1458 Mdot
.69 .14581 Mdot
.69 .14587 Mdot
.69 .14594 Mdot
.69 .14608 Mdot
.69 .14618 Mdot
.69 .14626 Mdot
.69 .1466 Mdot
.69 .14675 Mdot
.69 .14677 Mdot
.69 .14681 Mdot
.69 .14702 Mdot
.69 .14705 Mdot
.69 .14735 Mdot
.69 .14755 Mdot
.69 .14819 Mdot
.69 .14854 Mdot
.69 .14869 Mdot
.69 .14871 Mdot
.69 .14873 Mdot
.69 .14898 Mdot
.69 .14902 Mdot
.69 .14947 Mdot
.69 .15007 Mdot
.69 .15015 Mdot
.69 .15046 Mdot
.69 .15074 Mdot
.69 .1508 Mdot
.69 .15102 Mdot
.69 .15141 Mdot
.69 .15151 Mdot
.69 .15203 Mdot
.69 .15272 Mdot
.69 .15361 Mdot
.69 .1537 Mdot
.69 .15396 Mdot
.69 .1548 Mdot
.69 .15508 Mdot
.69 .15508 Mdot
.69 .15541 Mdot
.69 .15551 Mdot
.69 .15644 Mdot
.69 .15694 Mdot
.69 .15773 Mdot
.69 .15798 Mdot
.69 .15805 Mdot
.69 .15826 Mdot
.69 .15831 Mdot
.69 .15895 Mdot
.69 .15908 Mdot
.69 .1595 Mdot
.69 .16022 Mdot
.69 .16095 Mdot
.69 .16131 Mdot
.69 .16141 Mdot
.69 .16146 Mdot
.69 .16171 Mdot
.69 .16177 Mdot
.69 .16218 Mdot
.69 .16221 Mdot
.69 .16247 Mdot
.69 .16404 Mdot
.69 .16409 Mdot
.69 .16461 Mdot
.69 .16485 Mdot
.69 .16546 Mdot
.69 .16561 Mdot
.69 .16562 Mdot
.69 .16592 Mdot
.69 .16594 Mdot
.69 .16634 Mdot
.69 .16643 Mdot
.69 .16762 Mdot
.69 .16834 Mdot
.69 .16849 Mdot
.69 .16855 Mdot
.69 .16856 Mdot
.69 .1686 Mdot
.69 .16863 Mdot
.69 .16869 Mdot
.69 .16881 Mdot
.69 .16886 Mdot
.69 .1689 Mdot
.69 .1689 Mdot
.69 .16894 Mdot
.69 .16898 Mdot
.69 .16902 Mdot
.69 .16902 Mdot
.69 .16915 Mdot
.69 .16962 Mdot
.69 .17212 Mdot
.69 .17213 Mdot
.69 .17488 Mdot
.69 .17488 Mdot
.69 .17533 Mdot
.69 .17568 Mdot
.69 .17595 Mdot
.69 .17772 Mdot
.69 .17817 Mdot
.69 .17828 Mdot
.69 .1793 Mdot
.69 .18008 Mdot
.69 .18042 Mdot
.69 .18153 Mdot
.69 .18178 Mdot
.69 .18451 Mdot
.69 .1846 Mdot
.69 .18519 Mdot
.69 .18672 Mdot
.69 .18968 Mdot
.69 .18979 Mdot
.69 .19182 Mdot
.69 .19202 Mdot
.69 .19356 Mdot
.69 .19375 Mdot
.69 .19417 Mdot
.69 .19583 Mdot
.69 .19679 Mdot
.69 .19698 Mdot
.69 .19889 Mdot
.69 .20048 Mdot
.69 .20209 Mdot
.69 .20616 Mdot
.69 .20695 Mdot
.69 .20833 Mdot
.69 .20946 Mdot
.69 .21047 Mdot
.69 .21344 Mdot
.69 .2142 Mdot
.69 .21526 Mdot
.69 .21644 Mdot
.69 .21865 Mdot
.69 .22178 Mdot
.69 .22263 Mdot
.69 .2235 Mdot
.69 .22531 Mdot
.69 .22802 Mdot
.69 .22911 Mdot
.69 .23139 Mdot
.69 .23168 Mdot
.69 .23171 Mdot
.69 .23227 Mdot
.69 .23293 Mdot
.69 .24214 Mdot
.69 .24317 Mdot
.69 .24498 Mdot
.69 .24584 Mdot
.69 .2462 Mdot
.69 .24753 Mdot
.69 .25499 Mdot
.69 .25576 Mdot
.69 .25747 Mdot
.69 .25757 Mdot
.69 .25909 Mdot
.69 .25919 Mdot
.69 .25999 Mdot
.69 .26115 Mdot
.69 .2628 Mdot
.69 .26364 Mdot
.69 .26557 Mdot
.69 .26635 Mdot
.69 .26656 Mdot
.69 .26763 Mdot
.69 .26796 Mdot
.69 .26905 Mdot
.69 .26944 Mdot
.69 .2736 Mdot
.69 .2736 Mdot
.69 .27363 Mdot
.69 .27365 Mdot
.69 .27368 Mdot
.69 .27368 Mdot
.69 .27371 Mdot
.69 .27375 Mdot
.69 .27383 Mdot
.69 .27387 Mdot
.69 .27393 Mdot
.69 .27408 Mdot
.69 .27459 Mdot
.69 .27544 Mdot
.69 .27551 Mdot
.69 .27581 Mdot
.69 .27582 Mdot
.69 .27604 Mdot
.69 .27605 Mdot
.69 .27616 Mdot
.69 .27662 Mdot
.69 .2772 Mdot
.69 .27724 Mdot
.69 .27868 Mdot
.69 .27871 Mdot
.69 .27933 Mdot
.69 .27941 Mdot
.69 .28032 Mdot
.69 .28094 Mdot
.69 .28131 Mdot
.69 .28142 Mdot
.69 .28199 Mdot
.69 .2823 Mdot
.69 .28252 Mdot
.69 .28325 Mdot
.69 .28373 Mdot
.69 .28506 Mdot
.69 .28506 Mdot
.69 .28535 Mdot
.69 .28622 Mdot
.69 .28651 Mdot
.69 .2866 Mdot
.69 .28758 Mdot
.69 .28959 Mdot
.69 .28986 Mdot
.69 .28994 Mdot
.69 .29029 Mdot
.69 .2907 Mdot
.69 .2908 Mdot
.69 .29161 Mdot
.69 .29225 Mdot
.69 .2927 Mdot
.69 .29273 Mdot
.69 .2945 Mdot
.69 .29483 Mdot
.69 .29536 Mdot
.69 .29577 Mdot
.69 .29589 Mdot
.69 .29617 Mdot
.69 .29697 Mdot
.69 .29747 Mdot
.69 .29761 Mdot
.69 .29773 Mdot
.69 .29775 Mdot
.69 .29954 Mdot
.69 .30011 Mdot
.69 .30076 Mdot
.69 .30225 Mdot
.69 .30368 Mdot
.69 .3045 Mdot
.69 .30461 Mdot
.69 .30481 Mdot
.69 .307 Mdot
.69 .30731 Mdot
.69 .30792 Mdot
.69 .30803 Mdot
.69 .30816 Mdot
.69 .30955 Mdot
.69 .30956 Mdot
.69 .30973 Mdot
.69 .31 Mdot
.69 .31023 Mdot
.69 .31046 Mdot
.69 .31057 Mdot
.69 .31186 Mdot
.69 .31286 Mdot
.69 .31293 Mdot
.69 .31536 Mdot
.69 .31629 Mdot
.69 .31661 Mdot
.69 .31713 Mdot
.69 .3186 Mdot
.69 .3191 Mdot
.69 .32018 Mdot
.69 .32086 Mdot
.69 .32122 Mdot
.69 .32218 Mdot
.69 .32263 Mdot
.69 .32456 Mdot
.69 .32509 Mdot
.69 .32536 Mdot
.69 .32573 Mdot
.69 .32892 Mdot
.69 .32904 Mdot
.69 .32967 Mdot
.69 .33329 Mdot
.69 .3334 Mdot
.69 .3358 Mdot
.69 .336 Mdot
.69 .33832 Mdot
.69 .33874 Mdot
.69 .33895 Mdot
.69 .339 Mdot
.69 .33957 Mdot
.69 .34123 Mdot
.69 .34406 Mdot
.69 .34411 Mdot
.69 .34414 Mdot
.69 .34453 Mdot
.69 .34485 Mdot
.69 .34653 Mdot
.69 .34654 Mdot
.69 .34831 Mdot
.69 .34831 Mdot
.69 .34881 Mdot
.69 .35034 Mdot
.69 .35101 Mdot
.69 .35233 Mdot
.69 .35402 Mdot
.69 .35407 Mdot
.69 .35682 Mdot
.69 .35794 Mdot
.69 .35915 Mdot
.69 .35999 Mdot
.69 .3615 Mdot
.69 .36495 Mdot
.69 .36532 Mdot
.69 .36595 Mdot
.69 .36646 Mdot
.69 .36692 Mdot
.69 .36824 Mdot
.69 .36857 Mdot
.69 .36903 Mdot
.69 .36955 Mdot
.69 .37255 Mdot
.69 .3733 Mdot
.69 .37442 Mdot
.69 .37578 Mdot
.69 .37591 Mdot
.69 .37613 Mdot
.69 .3764 Mdot
.69 .38 Mdot
.69 .3804 Mdot
.69 .38109 Mdot
.69 .38141 Mdot
.69 .38205 Mdot
.69 .38482 Mdot
.69 .38573 Mdot
.69 .38706 Mdot
.69 .38765 Mdot
.69 .38795 Mdot
.69 .38864 Mdot
.69 .38899 Mdot
.69 .38937 Mdot
.69 .38949 Mdot
.69 .38987 Mdot
.69 .39146 Mdot
.69 .39146 Mdot
.69 .39147 Mdot
.69 .39148 Mdot
.69 .39149 Mdot
.69 .39149 Mdot
.69 .3915 Mdot
.69 .39152 Mdot
.69 .39154 Mdot
.69 .39156 Mdot
.69 .39158 Mdot
.69 .39163 Mdot
.69 .39181 Mdot
.69 .39211 Mdot
.69 .39213 Mdot
.69 .39223 Mdot
.69 .39224 Mdot
.69 .39231 Mdot
.69 .39231 Mdot
.69 .39235 Mdot
.69 .39251 Mdot
.69 .39271 Mdot
.69 .39322 Mdot
.69 .39323 Mdot
.69 .39345 Mdot
.69 .39347 Mdot
.69 .39378 Mdot
.69 .394 Mdot
.69 .39412 Mdot
.69 .39416 Mdot
.69 .39435 Mdot
.69 .39446 Mdot
.69 .39478 Mdot
.69 .39495 Mdot
.69 .3954 Mdot
.69 .3955 Mdot
.69 .39579 Mdot
.69 .39589 Mdot
.69 .39592 Mdot
.69 .39692 Mdot
.69 .39702 Mdot
.69 .39704 Mdot
.69 .39716 Mdot
.69 .3973 Mdot
.69 .39733 Mdot
.69 .3976 Mdot
.69 .39781 Mdot
.69 .39797 Mdot
.69 .39797 Mdot
.69 .39857 Mdot
.69 .39867 Mdot
.69 .39885 Mdot
.69 .39899 Mdot
.69 .39903 Mdot
.69 .39912 Mdot
.69 .39955 Mdot
.69 .3996 Mdot
.69 .39964 Mdot
.69 .39964 Mdot
.69 .40023 Mdot
.69 .40042 Mdot
.69 .40063 Mdot
.69 .40112 Mdot
.69 .40186 Mdot
.69 .40189 Mdot
.69 .40196 Mdot
.69 .40268 Mdot
.69 .40297 Mdot
.69 .40301 Mdot
.69 .40305 Mdot
.69 .4035 Mdot
.69 .40351 Mdot
.69 .40356 Mdot
.69 .40365 Mdot
.69 .40372 Mdot
.69 .4038 Mdot
.69 .40425 Mdot
.69 .40457 Mdot
.69 .40538 Mdot
.69 .40568 Mdot
.69 .40578 Mdot
.69 .40595 Mdot
.69 .40642 Mdot
.69 .40658 Mdot
.69 .40692 Mdot
.69 .40714 Mdot
.69 .40726 Mdot
.69 .40771 Mdot
.69 .40832 Mdot
.69 .40849 Mdot
.69 .40869 Mdot
.69 .40974 Mdot
.69 .40994 Mdot
.69 .41111 Mdot
.69 .41193 Mdot
.69 .41266 Mdot
.69 .41279 Mdot
.69 .41286 Mdot
.69 .41287 Mdot
.69 .41305 Mdot
.69 .41357 Mdot
.69 .41446 Mdot
.69 .41447 Mdot
.69 .41448 Mdot
.69 .4146 Mdot
.69 .4147 Mdot
.69 .41523 Mdot
.69 .41523 Mdot
.69 .41578 Mdot
.69 .41578 Mdot
.69 .41641 Mdot
.69 .41662 Mdot
.69 .41703 Mdot
.69 .41757 Mdot
.69 .41842 Mdot
.69 .41877 Mdot
.69 .4194 Mdot
.69 .41987 Mdot
.69 .42094 Mdot
.69 .4214 Mdot
.69 .42155 Mdot
.69 .42195 Mdot
.69 .42206 Mdot
.69 .42236 Mdot
.69 .42328 Mdot
.69 .42352 Mdot
.69 .42432 Mdot
.69 .42439 Mdot
.69 .42558 Mdot
.69 .4257 Mdot
.69 .42592 Mdot
.69 .42707 Mdot
.69 .42735 Mdot
.69 .42776 Mdot
.69 .42794 Mdot
.69 .42803 Mdot
.69 .42847 Mdot
.69 .42851 Mdot
.69 .42863 Mdot
.69 .42936 Mdot
.69 .42938 Mdot
.69 .42944 Mdot
.69 .42966 Mdot
.69 .42973 Mdot
.69 .42994 Mdot
.69 .42995 Mdot
.69 .43014 Mdot
.69 .43046 Mdot
.69 .43049 Mdot
.69 .43093 Mdot
.69 .43113 Mdot
.69 .4314 Mdot
.69 .43165 Mdot
.69 .43165 Mdot
.69 .43189 Mdot
.69 .43211 Mdot
.69 .43234 Mdot
.69 .43235 Mdot
.69 .43285 Mdot
.69 .43291 Mdot
.69 .43294 Mdot
.69 .43308 Mdot
.69 .43375 Mdot
.69 .43391 Mdot
.69 .43434 Mdot
.69 .43485 Mdot
.69 .43547 Mdot
.69 .4357 Mdot
.69 .43574 Mdot
.69 .43576 Mdot
.69 .43626 Mdot
.69 .43626 Mdot
.69 .4363 Mdot
.69 .43633 Mdot
.69 .43706 Mdot
.69 .43723 Mdot
.69 .43938 Mdot
.69 .44067 Mdot
.69 .44095 Mdot
.69 .44105 Mdot
.69 .44107 Mdot
.69 .44114 Mdot
.69 .4412 Mdot
.69 .4413 Mdot
.69 .44131 Mdot
.69 .44145 Mdot
.69 .44151 Mdot
.69 .4416 Mdot
.69 .44168 Mdot
.69 .44168 Mdot
.69 .44176 Mdot
.69 .44183 Mdot
.69 .4419 Mdot
.69 .4419 Mdot
.69 .44213 Mdot
.69 .44297 Mdot
.69 .44477 Mdot
.69 .44482 Mdot
.69 .44736 Mdot
.69 .44739 Mdot
.69 .44926 Mdot
.69 .44935 Mdot
.69 .45213 Mdot
.69 .45213 Mdot
.69 .45244 Mdot
.69 .45291 Mdot
.69 .4535 Mdot
.69 .45387 Mdot
.69 .45396 Mdot
.69 .45426 Mdot
.69 .45427 Mdot
.69 .45439 Mdot
.69 .45451 Mdot
.69 .45464 Mdot
.69 .45464 Mdot
.69 .45477 Mdot
.69 .45492 Mdot
.69 .45503 Mdot
.69 .45527 Mdot
.69 .45528 Mdot
.69 .45545 Mdot
.69 .45555 Mdot
.69 .45567 Mdot
.69 .45571 Mdot
.69 .45587 Mdot
.69 .45634 Mdot
.69 .45694 Mdot
.69 .4577 Mdot
.69 .45787 Mdot
.69 .4585 Mdot
.69 .45956 Mdot
.69 .46085 Mdot
.69 .46142 Mdot
.69 .46204 Mdot
.69 .46231 Mdot
.69 .46323 Mdot
.69 .4635 Mdot
.69 .46355 Mdot
.69 .46361 Mdot
.69 .46362 Mdot
.69 .46362 Mdot
.69 .46443 Mdot
.69 .46446 Mdot
.69 .46453 Mdot
.69 .4649 Mdot
.69 .4659 Mdot
.69 .46671 Mdot
.69 .4674 Mdot
.69 .46765 Mdot
.69 .46802 Mdot
.69 .46816 Mdot
.69 .46872 Mdot
.69 .46894 Mdot
.69 .46898 Mdot
.69 .46908 Mdot
.69 .46908 Mdot
.69 .46987 Mdot
.69 .46989 Mdot
.69 .47025 Mdot
.69 .47059 Mdot
.69 .47096 Mdot
.69 .47097 Mdot
.69 .47135 Mdot
.69 .47148 Mdot
.69 .47177 Mdot
.69 .47208 Mdot
.69 .47277 Mdot
.69 .47282 Mdot
.69 .4733 Mdot
.69 .4736 Mdot
.69 .47362 Mdot
.69 .47394 Mdot
.69 .47405 Mdot
.69 .47438 Mdot
.69 .47448 Mdot
.69 .47452 Mdot
.69 .47563 Mdot
.69 .47581 Mdot
.69 .47587 Mdot
.69 .47604 Mdot
.69 .47621 Mdot
.69 .47653 Mdot
.69 .47667 Mdot
.69 .47695 Mdot
.69 .47757 Mdot
.69 .47799 Mdot
.69 .47927 Mdot
.69 .47957 Mdot
.69 .47972 Mdot
.69 .48003 Mdot
.69 .48021 Mdot
.69 .48186 Mdot
.69 .48198 Mdot
.69 .48208 Mdot
.69 .48214 Mdot
.69 .48275 Mdot
.69 .48326 Mdot
.69 .48359 Mdot
.69 .48494 Mdot
.69 .48517 Mdot
.69 .48537 Mdot
.69 .48552 Mdot
.69 .48611 Mdot
.69 .48631 Mdot
.69 .48654 Mdot
.69 .48682 Mdot
.69 .48698 Mdot
.69 .48849 Mdot
.69 .48915 Mdot
.69 .48951 Mdot
.69 .49004 Mdot
.69 .49052 Mdot
.69 .49171 Mdot
.69 .49173 Mdot
.69 .49246 Mdot
.69 .49302 Mdot
.69 .4933 Mdot
.69 .49395 Mdot
.69 .49417 Mdot
.69 .49417 Mdot
.69 .49491 Mdot
.69 .49492 Mdot
.69 .49563 Mdot
.69 .49576 Mdot
.69 .49592 Mdot
.69 .49594 Mdot
.69 .49596 Mdot
.69 .49714 Mdot
.69 .49783 Mdot
.69 .49807 Mdot
.69 .49809 Mdot
.69 .49818 Mdot
.69 .49835 Mdot
.69 .49931 Mdot
.69 .49939 Mdot
.69 .50038 Mdot
.69 .50042 Mdot
.69 .5019 Mdot
.69 .50216 Mdot
.69 .5022 Mdot
.69 .5035 Mdot
.69 .50364 Mdot
.69 .50375 Mdot
.69 .50397 Mdot
.69 .50474 Mdot
.69 .50492 Mdot
.69 .50531 Mdot
.69 .50545 Mdot
.69 .50572 Mdot
.69 .50615 Mdot
.69 .50635 Mdot
.69 .50693 Mdot
.69 .50714 Mdot
.69 .50727 Mdot
.69 .50763 Mdot
.69 .50859 Mdot
.69 .50862 Mdot
.69 .50901 Mdot
.69 .50952 Mdot
.69 .50956 Mdot
.69 .50965 Mdot
.69 .50974 Mdot
.69 .50985 Mdot
.69 .50991 Mdot
.69 .50992 Mdot
.69 .51046 Mdot
.69 .51051 Mdot
.69 .51055 Mdot
.69 .51079 Mdot
.69 .51091 Mdot
.69 .51176 Mdot
.69 .51184 Mdot
.69 .51188 Mdot
.69 .5122 Mdot
.69 .51275 Mdot
.69 .51332 Mdot
.69 .51357 Mdot
.69 .51379 Mdot
.69 .51447 Mdot
.69 .51448 Mdot
.69 .51453 Mdot
.69 .51458 Mdot
.69 .51477 Mdot
.69 .51508 Mdot
.69 .51518 Mdot
.69 .51523 Mdot
.69 .51538 Mdot
.69 .51558 Mdot
.69 .51571 Mdot
.69 .51638 Mdot
.69 .51639 Mdot
.69 .51656 Mdot
.69 .5168 Mdot
.69 .51711 Mdot
.69 .51715 Mdot
.69 .5173 Mdot
.69 .51743 Mdot
.69 .51746 Mdot
.69 .51757 Mdot
.69 .51832 Mdot
.69 .51868 Mdot
.69 .51872 Mdot
.69 .51883 Mdot
.69 .51915 Mdot
.69 .51926 Mdot
.69 .51926 Mdot
.69 .51976 Mdot
.69 .51993 Mdot
.69 .52021 Mdot
.69 .52029 Mdot
.69 .5204 Mdot
.69 .52062 Mdot
.69 .52065 Mdot
.69 .52079 Mdot
.69 .52102 Mdot
.69 .52136 Mdot
.69 .52139 Mdot
.69 .52162 Mdot
.69 .52163 Mdot
.69 .52216 Mdot
.69 .52217 Mdot
.69 .52239 Mdot
.69 .52256 Mdot
.69 .5226 Mdot
.69 .5226 Mdot
.69 .52268 Mdot
.69 .52269 Mdot
.69 .52279 Mdot
.69 .52282 Mdot
.69 .52313 Mdot
.69 .52332 Mdot
.69 .52337 Mdot
.69 .52339 Mdot
.69 .52341 Mdot
.69 .52344 Mdot
.69 .52345 Mdot
.69 .52346 Mdot
.69 .52346 Mdot
.69 .52347 Mdot
.69 .52348 Mdot
.69 .52349 Mdot
.69 .5235 Mdot
.69 .52501 Mdot
.69 .52515 Mdot
.69 .52555 Mdot
.69 .52567 Mdot
.69 .52605 Mdot
.69 .52613 Mdot
.69 .52641 Mdot
.69 .52711 Mdot
.69 .52741 Mdot
.69 .528 Mdot
.69 .52842 Mdot
.69 .5287 Mdot
.69 .52873 Mdot
.69 .52928 Mdot
.69 .52931 Mdot
.69 .52992 Mdot
.69 .5302 Mdot
.69 .53282 Mdot
.69 .53329 Mdot
.69 .53342 Mdot
.69 .53372 Mdot
.69 .53435 Mdot
.69 .53471 Mdot
.69 .53789 Mdot
.69 .53811 Mdot
.69 .5383 Mdot
.69 .53831 Mdot
.69 .53841 Mdot
.69 .53919 Mdot
.69 .53956 Mdot
.69 .54048 Mdot
.69 .54069 Mdot
.69 .54109 Mdot
.69 .54139 Mdot
.69 .54167 Mdot
.69 .54273 Mdot
.69 .54347 Mdot
.69 .54386 Mdot
.69 .54422 Mdot
.69 .54447 Mdot
.69 .54546 Mdot
.69 .54579 Mdot
.69 .54617 Mdot
.69 .54662 Mdot
.69 .54688 Mdot
.69 .54822 Mdot
.69 .54875 Mdot
.69 .54927 Mdot
.69 .54989 Mdot
.69 .54995 Mdot
.69 .55026 Mdot
.69 .5508 Mdot
.69 .55094 Mdot
.69 .551 Mdot
.69 .5515 Mdot
.69 .55157 Mdot
.69 .55222 Mdot
.69 .55226 Mdot
.69 .55321 Mdot
.69 .5537 Mdot
.69 .55389 Mdot
.69 .55392 Mdot
.69 .55479 Mdot
.69 .55487 Mdot
.69 .55522 Mdot
.69 .55533 Mdot
.69 .55558 Mdot
.69 .55591 Mdot
.69 .55594 Mdot
.69 .55608 Mdot
.69 .55664 Mdot
.69 .55673 Mdot
.69 .55684 Mdot
.69 .55698 Mdot
.69 .55698 Mdot
.69 .55785 Mdot
.69 .55786 Mdot
.69 .55864 Mdot
.69 .55879 Mdot
.69 .55883 Mdot
.69 .55883 Mdot
.69 .55884 Mdot
.69 .55885 Mdot
.69 .55887 Mdot
.69 .55887 Mdot
.69 .55888 Mdot
.69 .5589 Mdot
.69 .55893 Mdot
.69 .55895 Mdot
.69 .55896 Mdot
.69 .55898 Mdot
.69 .55898 Mdot
.69 .559 Mdot
.69 .55905 Mdot
.69 .55927 Mdot
.69 .55964 Mdot
.69 .55967 Mdot
.69 .5598 Mdot
.69 .5598 Mdot
.69 .55989 Mdot
.69 .5599 Mdot
.69 .55994 Mdot
.69 .56014 Mdot
.69 .56021 Mdot
.69 .56037 Mdot
.69 .56039 Mdot
.69 .56088 Mdot
.69 .56096 Mdot
.69 .56097 Mdot
.69 .5611 Mdot
.69 .56111 Mdot
.69 .56119 Mdot
.69 .56121 Mdot
.69 .56124 Mdot
.69 .56135 Mdot
.69 .56158 Mdot
.69 .5618 Mdot
.69 .56193 Mdot
.69 .56197 Mdot
.69 .56217 Mdot
.69 .56219 Mdot
.69 .56225 Mdot
.69 .56227 Mdot
.69 .56235 Mdot
.69 .56259 Mdot
.69 .56275 Mdot
.69 .56304 Mdot
.69 .56307 Mdot
.69 .56317 Mdot
.69 .56317 Mdot
.69 .56326 Mdot
.69 .56351 Mdot
.69 .5636 Mdot
.69 .56362 Mdot
.69 .5639 Mdot
.69 .56411 Mdot
.69 .56427 Mdot
.69 .5643 Mdot
.69 .56442 Mdot
.69 .56449 Mdot
.69 .56451 Mdot
.69 .56459 Mdot
.69 .56469 Mdot
.69 .56471 Mdot
.69 .56489 Mdot
.69 .56503 Mdot
.69 .56505 Mdot
.69 .56512 Mdot
.69 .56513 Mdot
.69 .56513 Mdot
.69 .56518 Mdot
.69 .56529 Mdot
.69 .56548 Mdot
.69 .56554 Mdot
.69 .56564 Mdot
.69 .56564 Mdot
.69 .56571 Mdot
.69 .56572 Mdot
.69 .56573 Mdot
.69 .56577 Mdot
.69 .56588 Mdot
.69 .5659 Mdot
.69 .56593 Mdot
.69 .56598 Mdot
.69 .566 Mdot
.69 .56601 Mdot
.69 .56602 Mdot
.69 .56603 Mdot
.69 .56618 Mdot
.69 .56624 Mdot
.69 .56625 Mdot
.69 .56632 Mdot
.69 .56639 Mdot
.69 .56641 Mdot
.69 .56646 Mdot
.69 .56649 Mdot
.69 .56653 Mdot
.69 .56657 Mdot
.69 .56664 Mdot
.69 .5667 Mdot
.69 .5667 Mdot
.69 .56671 Mdot
.69 .56673 Mdot
.69 .56673 Mdot
.69 .56677 Mdot
.69 .5668 Mdot
.69 .56681 Mdot
.69 .56681 Mdot
.69 .56681 Mdot
.69 .56682 Mdot
.69 .56682 Mdot
.69 .56682 Mdot
.69 .56682 Mdot
.69 .56682 Mdot
.69 .56682 Mdot
.69 .56682 Mdot
.69 .56682 Mdot
.692 .14244 Mdot
.692 .1425 Mdot
.692 .14252 Mdot
.692 .14276 Mdot
.692 .14284 Mdot
.692 .14286 Mdot
.692 .14307 Mdot
.692 .14315 Mdot
.692 .14321 Mdot
.692 .14326 Mdot
.692 .14339 Mdot
.692 .14384 Mdot
.692 .14402 Mdot
.692 .14403 Mdot
.692 .14425 Mdot
.692 .14465 Mdot
.692 .14474 Mdot
.692 .14485 Mdot
.692 .14486 Mdot
.692 .14493 Mdot
.692 .14506 Mdot
.692 .14516 Mdot
.692 .14527 Mdot
.692 .1454 Mdot
.692 .14553 Mdot
.692 .14558 Mdot
.692 .1456 Mdot
.692 .14568 Mdot
.692 .14603 Mdot
.692 .1463 Mdot
.692 .14653 Mdot
.692 .14656 Mdot
.692 .14668 Mdot
.692 .14676 Mdot
.692 .14687 Mdot
.692 .14707 Mdot
.692 .14718 Mdot
.692 .14721 Mdot
.692 .14777 Mdot
.692 .14785 Mdot
.692 .14813 Mdot
.692 .14897 Mdot
.692 .14955 Mdot
.692 .15055 Mdot
.692 .15069 Mdot
.692 .1511 Mdot
.692 .1512 Mdot
.692 .15146 Mdot
.692 .15176 Mdot
.692 .15196 Mdot
.692 .15219 Mdot
.692 .15291 Mdot
.692 .15353 Mdot
.692 .15387 Mdot
.692 .1539 Mdot
.692 .15413 Mdot
.692 .15497 Mdot
.692 .15537 Mdot
.692 .15549 Mdot
.692 .15573 Mdot
.692 .1562 Mdot
.692 .1562 Mdot
.692 .15677 Mdot
.692 .1572 Mdot
.692 .1574 Mdot
.692 .15745 Mdot
.692 .15855 Mdot
.692 .15887 Mdot
.692 .15957 Mdot
.692 .16067 Mdot
.692 .1612 Mdot
.692 .16128 Mdot
.692 .16188 Mdot
.692 .16269 Mdot
.692 .16339 Mdot
.692 .16367 Mdot
.692 .16464 Mdot
.692 .16533 Mdot
.692 .16562 Mdot
.692 .16587 Mdot
.692 .16627 Mdot
.692 .16632 Mdot
.692 .16641 Mdot
.692 .16691 Mdot
.692 .16746 Mdot
.692 .16751 Mdot
.692 .16784 Mdot
.692 .1682 Mdot
.692 .16843 Mdot
.692 .16857 Mdot
.692 .16912 Mdot
.692 .16964 Mdot
.692 .17019 Mdot
.692 .17105 Mdot
.692 .17125 Mdot
.692 .17179 Mdot
.692 .17182 Mdot
.692 .17198 Mdot
.692 .17224 Mdot
.692 .17309 Mdot
.692 .17324 Mdot
.692 .17335 Mdot
.692 .17338 Mdot
.692 .17346 Mdot
.692 .17368 Mdot
.692 .17426 Mdot
.692 .17438 Mdot
.692 .17629 Mdot
.692 .17714 Mdot
.692 .17724 Mdot
.692 .17755 Mdot
.692 .17796 Mdot
.692 .1788 Mdot
.692 .18029 Mdot
.692 .1806 Mdot
.692 .18132 Mdot
.692 .18174 Mdot
.692 .18177 Mdot
.692 .18301 Mdot
.692 .18373 Mdot
.692 .18492 Mdot
.692 .18572 Mdot
.692 .18601 Mdot
.692 .18666 Mdot
.692 .18666 Mdot
.692 .18914 Mdot
.692 .18945 Mdot
.692 .18981 Mdot
.692 .19024 Mdot
.692 .19087 Mdot
.692 .19131 Mdot
.692 .19194 Mdot
.692 .19194 Mdot
.692 .19209 Mdot
.692 .19264 Mdot
.692 .19362 Mdot
.692 .19367 Mdot
.692 .19623 Mdot
.692 .19773 Mdot
.692 .19815 Mdot
.692 .19904 Mdot
.692 .20052 Mdot
.692 .20095 Mdot
.692 .20158 Mdot
.692 .20225 Mdot
.692 .20229 Mdot
.692 .20353 Mdot
.692 .20942 Mdot
.692 .21063 Mdot
.692 .21075 Mdot
.692 .2109 Mdot
.692 .21106 Mdot
.692 .21656 Mdot
.692 .21724 Mdot
.692 .21761 Mdot
.692 .22231 Mdot
.692 .22345 Mdot
.692 .22347 Mdot
.692 .2238 Mdot
.692 .22548 Mdot
.692 .22579 Mdot
.692 .22645 Mdot
.692 .22671 Mdot
.692 .22684 Mdot
.692 .22935 Mdot
.692 .23079 Mdot
.692 .2312 Mdot
.692 .23163 Mdot
.692 .23293 Mdot
.692 .23437 Mdot
.692 .23711 Mdot
.692 .23832 Mdot
.692 .2393 Mdot
.692 .24084 Mdot
.692 .24193 Mdot
.692 .24392 Mdot
.692 .24402 Mdot
.692 .24512 Mdot
.692 .24526 Mdot
.692 .24526 Mdot
.692 .24789 Mdot
.692 .25066 Mdot
.692 .25073 Mdot
.692 .25132 Mdot
.692 .2546 Mdot
.692 .25524 Mdot
.692 .25882 Mdot
.692 .25934 Mdot
.692 .25962 Mdot
.692 .26002 Mdot
.692 .26025 Mdot
.692 .2608 Mdot
.692 .26099 Mdot
.692 .26116 Mdot
.692 .26299 Mdot
.692 .26409 Mdot
.692 .2652 Mdot
.692 .26742 Mdot
.692 .26786 Mdot
.692 .26843 Mdot
.692 .26962 Mdot
.692 .2697 Mdot
.692 .27027 Mdot
.692 .27044 Mdot
.692 .27116 Mdot
.692 .27126 Mdot
.692 .27128 Mdot
.692 .27164 Mdot
.692 .27177 Mdot
.692 .27234 Mdot
.692 .27271 Mdot
.692 .27306 Mdot
.692 .27345 Mdot
.692 .27354 Mdot
.692 .27395 Mdot
.692 .27422 Mdot
.692 .27503 Mdot
.692 .27507 Mdot
.692 .27536 Mdot
.692 .27627 Mdot
.692 .27776 Mdot
.692 .27887 Mdot
.692 .27894 Mdot
.692 .28029 Mdot
.692 .28089 Mdot
.692 .28117 Mdot
.692 .28215 Mdot
.692 .28219 Mdot
.692 .28237 Mdot
.692 .28276 Mdot
.692 .2833 Mdot
.692 .28397 Mdot
.692 .28408 Mdot
.692 .28448 Mdot
.692 .28532 Mdot
.692 .28556 Mdot
.692 .28559 Mdot
.692 .28595 Mdot
.692 .2866 Mdot
.692 .28739 Mdot
.692 .28822 Mdot
.692 .28852 Mdot
.692 .28864 Mdot
.692 .28913 Mdot
.692 .29133 Mdot
.692 .29303 Mdot
.692 .2939 Mdot
.692 .29395 Mdot
.692 .29445 Mdot
.692 .29463 Mdot
.692 .29502 Mdot
.692 .29541 Mdot
.692 .2959 Mdot
.692 .29656 Mdot
.692 .29685 Mdot
.692 .2978 Mdot
.692 .29823 Mdot
.692 .29852 Mdot
.692 .29872 Mdot
.692 .29969 Mdot
.692 .30028 Mdot
.692 .30031 Mdot
.692 .30082 Mdot
.692 .30224 Mdot
.692 .30272 Mdot
.692 .30289 Mdot
.692 .30316 Mdot
.692 .30349 Mdot
.692 .3045 Mdot
.692 .30978 Mdot
.692 .3109 Mdot
.692 .31106 Mdot
.692 .31297 Mdot
.692 .31342 Mdot
.692 .31976 Mdot
.692 .31994 Mdot
.692 .32044 Mdot
.692 .32066 Mdot
.692 .32092 Mdot
.692 .32128 Mdot
.692 .32132 Mdot
.692 .32306 Mdot
.692 .32328 Mdot
.692 .3239 Mdot
.692 .32511 Mdot
.692 .32553 Mdot
.692 .32747 Mdot
.692 .32873 Mdot
.692 .33016 Mdot
.692 .33039 Mdot
.692 .33429 Mdot
.692 .33473 Mdot
.692 .33866 Mdot
.692 .33964 Mdot
.692 .34082 Mdot
.692 .34104 Mdot
.692 .34228 Mdot
.692 .34249 Mdot
.692 .34307 Mdot
.692 .34343 Mdot
.692 .34385 Mdot
.692 .34433 Mdot
.692 .34705 Mdot
.692 .34769 Mdot
.692 .34778 Mdot
.692 .34783 Mdot
.692 .34797 Mdot
.692 .35012 Mdot
.692 .35036 Mdot
.692 .35111 Mdot
.692 .35198 Mdot
.692 .35216 Mdot
.692 .35258 Mdot
.692 .35282 Mdot
.692 .35354 Mdot
.692 .3546 Mdot
.692 .3552 Mdot
.692 .35555 Mdot
.692 .35555 Mdot
.692 .35745 Mdot
.692 .35833 Mdot
.692 .35833 Mdot
.692 .35919 Mdot
.692 .3605 Mdot
.692 .36123 Mdot
.692 .36144 Mdot
.692 .36187 Mdot
.692 .36259 Mdot
.692 .36309 Mdot
.692 .36341 Mdot
.692 .36401 Mdot
.692 .36726 Mdot
.692 .36745 Mdot
.692 .36985 Mdot
.692 .3703 Mdot
.692 .3723 Mdot
.692 .37361 Mdot
.692 .37374 Mdot
.692 .37416 Mdot
.692 .37518 Mdot
.692 .37576 Mdot
.692 .37593 Mdot
.692 .37662 Mdot
.692 .37826 Mdot
.692 .37911 Mdot
.692 .38013 Mdot
.692 .38089 Mdot
.692 .38134 Mdot
.692 .38139 Mdot
.692 .3814 Mdot
.692 .38238 Mdot
.692 .38342 Mdot
.692 .38344 Mdot
.692 .38487 Mdot
.692 .38659 Mdot
.692 .38669 Mdot
.692 .38692 Mdot
.692 .38712 Mdot
.692 .38719 Mdot
.692 .3879 Mdot
.692 .38829 Mdot
.692 .38947 Mdot
.692 .38963 Mdot
.692 .38983 Mdot
.692 .39011 Mdot
.692 .39024 Mdot
.692 .39027 Mdot
.692 .39047 Mdot
.692 .39053 Mdot
.692 .39078 Mdot
.692 .39082 Mdot
.692 .39083 Mdot
.692 .39095 Mdot
.692 .39099 Mdot
.692 .39145 Mdot
.692 .39161 Mdot
.692 .39175 Mdot
.692 .39185 Mdot
.692 .39213 Mdot
.692 .39214 Mdot
.692 .39307 Mdot
.692 .39345 Mdot
.692 .39347 Mdot
.692 .39394 Mdot
.692 .39414 Mdot
.692 .39464 Mdot
.692 .39478 Mdot
.692 .39496 Mdot
.692 .39519 Mdot
.692 .39522 Mdot
.692 .39536 Mdot
.692 .39564 Mdot
.692 .39573 Mdot
.692 .39585 Mdot
.692 .39607 Mdot
.692 .39634 Mdot
.692 .39662 Mdot
.692 .39672 Mdot
.692 .39676 Mdot
.692 .39692 Mdot
.692 .39766 Mdot
.692 .39823 Mdot
.692 .39851 Mdot
.692 .39853 Mdot
.692 .3987 Mdot
.692 .39875 Mdot
.692 .39888 Mdot
.692 .39901 Mdot
.692 .39918 Mdot
.692 .3994 Mdot
.692 .39949 Mdot
.692 .3998 Mdot
.692 .39995 Mdot
.692 .40004 Mdot
.692 .40011 Mdot
.692 .40062 Mdot
.692 .40063 Mdot
.692 .40126 Mdot
.692 .40142 Mdot
.692 .40156 Mdot
.692 .40167 Mdot
.692 .402 Mdot
.692 .40371 Mdot
.692 .40407 Mdot
.692 .40412 Mdot
.692 .40474 Mdot
.692 .40489 Mdot
.692 .40691 Mdot
.692 .4072 Mdot
.692 .40741 Mdot
.692 .40797 Mdot
.692 .40803 Mdot
.692 .40823 Mdot
.692 .40875 Mdot
.692 .40936 Mdot
.692 .40976 Mdot
.692 .41021 Mdot
.692 .41028 Mdot
.692 .41151 Mdot
.692 .41165 Mdot
.692 .41288 Mdot
.692 .41319 Mdot
.692 .41355 Mdot
.692 .41362 Mdot
.692 .41401 Mdot
.692 .41408 Mdot
.692 .41426 Mdot
.692 .41437 Mdot
.692 .41465 Mdot
.692 .41549 Mdot
.692 .41569 Mdot
.692 .41572 Mdot
.692 .41652 Mdot
.692 .41676 Mdot
.692 .41703 Mdot
.692 .41721 Mdot
.692 .41728 Mdot
.692 .41784 Mdot
.692 .41802 Mdot
.692 .41813 Mdot
.692 .41813 Mdot
.692 .41872 Mdot
.692 .41899 Mdot
.692 .41926 Mdot
.692 .41966 Mdot
.692 .41995 Mdot
.692 .42008 Mdot
.692 .42046 Mdot
.692 .42056 Mdot
.692 .42074 Mdot
.692 .42174 Mdot
.692 .42254 Mdot
.692 .42268 Mdot
.692 .4233 Mdot
.692 .4237 Mdot
.692 .42374 Mdot
.692 .42387 Mdot
.692 .42418 Mdot
.692 .42463 Mdot
.692 .42513 Mdot
.692 .42571 Mdot
.692 .42608 Mdot
.692 .4264 Mdot
.692 .42673 Mdot
.692 .4277 Mdot
.692 .42773 Mdot
.692 .42786 Mdot
.692 .42788 Mdot
.692 .4281 Mdot
.692 .42863 Mdot
.692 .42869 Mdot
.692 .42891 Mdot
.692 .429 Mdot
.692 .429 Mdot
.692 .42941 Mdot
.692 .43002 Mdot
.692 .43018 Mdot
.692 .43051 Mdot
.692 .43149 Mdot
.692 .43167 Mdot
.692 .43182 Mdot
.692 .43202 Mdot
.692 .43235 Mdot
.692 .43309 Mdot
.692 .4333 Mdot
.692 .43413 Mdot
.692 .4354 Mdot
.692 .43592 Mdot
.692 .43618 Mdot
.692 .43638 Mdot
.692 .43712 Mdot
.692 .43721 Mdot
.692 .43738 Mdot
.692 .43765 Mdot
.692 .43795 Mdot
.692 .43804 Mdot
.692 .43829 Mdot
.692 .4386 Mdot
.692 .43886 Mdot
.692 .43922 Mdot
.692 .43927 Mdot
.692 .43937 Mdot
.692 .43967 Mdot
.692 .43985 Mdot
.692 .43997 Mdot
.692 .44053 Mdot
.692 .44061 Mdot
.692 .44078 Mdot
.692 .44086 Mdot
.692 .44102 Mdot
.692 .44122 Mdot
.692 .44127 Mdot
.692 .44168 Mdot
.692 .44185 Mdot
.692 .44219 Mdot
.692 .44226 Mdot
.692 .44318 Mdot
.692 .44374 Mdot
.692 .44395 Mdot
.692 .44404 Mdot
.692 .44415 Mdot
.692 .4443 Mdot
.692 .445 Mdot
.692 .44511 Mdot
.692 .44561 Mdot
.692 .44568 Mdot
.692 .44571 Mdot
.692 .44602 Mdot
.692 .44697 Mdot
.692 .44702 Mdot
.692 .4473 Mdot
.692 .44737 Mdot
.692 .44776 Mdot
.692 .44791 Mdot
.692 .44796 Mdot
.692 .44808 Mdot
.692 .44895 Mdot
.692 .44914 Mdot
.692 .44923 Mdot
.692 .44949 Mdot
.692 .44969 Mdot
.692 .44974 Mdot
.692 .44988 Mdot
.692 .45025 Mdot
.692 .45035 Mdot
.692 .4506 Mdot
.692 .45081 Mdot
.692 .45094 Mdot
.692 .45126 Mdot
.692 .45131 Mdot
.692 .45147 Mdot
.692 .45228 Mdot
.692 .45384 Mdot
.692 .45396 Mdot
.692 .45453 Mdot
.692 .45472 Mdot
.692 .45482 Mdot
.692 .45553 Mdot
.692 .45561 Mdot
.692 .45594 Mdot
.692 .45616 Mdot
.692 .4562 Mdot
.692 .45632 Mdot
.692 .45635 Mdot
.692 .45663 Mdot
.692 .45676 Mdot
.692 .45685 Mdot
.692 .45753 Mdot
.692 .4577 Mdot
.692 .4579 Mdot
.692 .4582 Mdot
.692 .4587 Mdot
.692 .45886 Mdot
.692 .45893 Mdot
.692 .45895 Mdot
.692 .45955 Mdot
.692 .45997 Mdot
.692 .46049 Mdot
.692 .4609 Mdot
.692 .46105 Mdot
.692 .46139 Mdot
.692 .46153 Mdot
.692 .46189 Mdot
.692 .46199 Mdot
.692 .46227 Mdot
.692 .4624 Mdot
.692 .46308 Mdot
.692 .46361 Mdot
.692 .46375 Mdot
.692 .46381 Mdot
.692 .46394 Mdot
.692 .46435 Mdot
.692 .4652 Mdot
.692 .46581 Mdot
.692 .46697 Mdot
.692 .46724 Mdot
.692 .46856 Mdot
.692 .46886 Mdot
.692 .46889 Mdot
.692 .47006 Mdot
.692 .47011 Mdot
.692 .47057 Mdot
.692 .47057 Mdot
.692 .4709 Mdot
.692 .47112 Mdot
.692 .47141 Mdot
.692 .47158 Mdot
.692 .47159 Mdot
.692 .47292 Mdot
.692 .47345 Mdot
.692 .47369 Mdot
.692 .47463 Mdot
.692 .47526 Mdot
.692 .47526 Mdot
.692 .47539 Mdot
.692 .47542 Mdot
.692 .47573 Mdot
.692 .47582 Mdot
.692 .47589 Mdot
.692 .47645 Mdot
.692 .47663 Mdot
.692 .47696 Mdot
.692 .477 Mdot
.692 .47709 Mdot
.692 .47719 Mdot
.692 .47724 Mdot
.692 .47804 Mdot
.692 .4787 Mdot
.692 .47871 Mdot
.692 .47919 Mdot
.692 .47965 Mdot
.692 .47965 Mdot
.692 .47967 Mdot
.692 .47988 Mdot
.692 .48023 Mdot
.692 .48069 Mdot
.692 .48108 Mdot
.692 .48183 Mdot
.692 .48214 Mdot
.692 .48221 Mdot
.692 .48248 Mdot
.692 .48294 Mdot
.692 .48313 Mdot
.692 .48319 Mdot
.692 .48378 Mdot
.692 .48467 Mdot
.692 .48487 Mdot
.692 .48594 Mdot
.692 .48602 Mdot
.692 .48746 Mdot
.692 .48772 Mdot
.692 .48786 Mdot
.692 .48808 Mdot
.692 .48839 Mdot
.692 .48858 Mdot
.692 .48867 Mdot
.692 .48899 Mdot
.692 .48956 Mdot
.692 .48993 Mdot
.692 .48993 Mdot
.692 .49032 Mdot
.692 .49113 Mdot
.692 .49114 Mdot
.692 .49129 Mdot
.692 .49154 Mdot
.692 .492 Mdot
.692 .49231 Mdot
.692 .49241 Mdot
.692 .49259 Mdot
.692 .49266 Mdot
.692 .49304 Mdot
.692 .49335 Mdot
.692 .49346 Mdot
.692 .49437 Mdot
.692 .49443 Mdot
.692 .49445 Mdot
.692 .49449 Mdot
.692 .49476 Mdot
.692 .4959 Mdot
.692 .4961 Mdot
.692 .49628 Mdot
.692 .49643 Mdot
.692 .49667 Mdot
.692 .49676 Mdot
.692 .49728 Mdot
.692 .49737 Mdot
.692 .49786 Mdot
.692 .49827 Mdot
.692 .49989 Mdot
.692 .50007 Mdot
.692 .50166 Mdot
.692 .50175 Mdot
.692 .50234 Mdot
.692 .50285 Mdot
.692 .50363 Mdot
.692 .5038 Mdot
.692 .50429 Mdot
.692 .50454 Mdot
.692 .50462 Mdot
.692 .50532 Mdot
.692 .50533 Mdot
.692 .50548 Mdot
.692 .50558 Mdot
.692 .50567 Mdot
.692 .50587 Mdot
.692 .50594 Mdot
.692 .50845 Mdot
.692 .50863 Mdot
.692 .50938 Mdot
.692 .50944 Mdot
.692 .50988 Mdot
.692 .51193 Mdot
.692 .51232 Mdot
.692 .51244 Mdot
.692 .51255 Mdot
.692 .51261 Mdot
.692 .5128 Mdot
.692 .51334 Mdot
.692 .51354 Mdot
.692 .51355 Mdot
.692 .51377 Mdot
.692 .51415 Mdot
.692 .51422 Mdot
.692 .51433 Mdot
.692 .5145 Mdot
.692 .51486 Mdot
.692 .51497 Mdot
.692 .51522 Mdot
.692 .51541 Mdot
.692 .51556 Mdot
.692 .51571 Mdot
.692 .51577 Mdot
.692 .51596 Mdot
.692 .51598 Mdot
.692 .51631 Mdot
.692 .51695 Mdot
.692 .51778 Mdot
.692 .51797 Mdot
.692 .51801 Mdot
.692 .51812 Mdot
.692 .51843 Mdot
.692 .51873 Mdot
.692 .51897 Mdot
.692 .51911 Mdot
.692 .51912 Mdot
.692 .51921 Mdot
.692 .51952 Mdot
.692 .51967 Mdot
.692 .51971 Mdot
.692 .51996 Mdot
.692 .52016 Mdot
.692 .52031 Mdot
.692 .52037 Mdot
.692 .52039 Mdot
.692 .52075 Mdot
.692 .52085 Mdot
.692 .52107 Mdot
.692 .52157 Mdot
.692 .5216 Mdot
.692 .52201 Mdot
.692 .52256 Mdot
.692 .52289 Mdot
.692 .523 Mdot
.692 .52301 Mdot
.692 .52331 Mdot
.692 .52341 Mdot
.692 .52356 Mdot
.692 .52359 Mdot
.692 .52373 Mdot
.692 .52386 Mdot
.692 .52399 Mdot
.692 .5242 Mdot
.692 .52425 Mdot
.692 .52438 Mdot
.692 .52439 Mdot
.692 .52443 Mdot
.692 .52469 Mdot
.692 .52475 Mdot
.692 .52496 Mdot
.692 .52498 Mdot
.692 .52512 Mdot
.692 .52541 Mdot
.692 .52562 Mdot
.692 .52578 Mdot
.692 .52658 Mdot
.692 .52698 Mdot
.692 .52738 Mdot
.692 .52804 Mdot
.692 .52809 Mdot
.692 .52816 Mdot
.692 .52836 Mdot
.692 .52844 Mdot
.692 .52858 Mdot
.692 .52868 Mdot
.692 .52887 Mdot
.692 .53014 Mdot
.692 .53037 Mdot
.692 .53153 Mdot
.692 .53174 Mdot
.692 .53176 Mdot
.692 .53274 Mdot
.692 .53365 Mdot
.692 .53366 Mdot
.692 .5337 Mdot
.692 .53408 Mdot
.692 .53412 Mdot
.692 .53481 Mdot
.692 .53519 Mdot
.692 .53573 Mdot
.692 .53606 Mdot
.692 .53648 Mdot
.692 .53742 Mdot
.692 .53792 Mdot
.692 .53836 Mdot
.692 .53851 Mdot
.692 .53865 Mdot
.692 .53914 Mdot
.692 .53999 Mdot
.692 .54004 Mdot
.692 .54012 Mdot
.692 .54035 Mdot
.692 .54046 Mdot
.692 .54102 Mdot
.692 .54114 Mdot
.692 .54114 Mdot
.692 .54153 Mdot
.692 .54311 Mdot
.692 .54323 Mdot
.692 .54346 Mdot
.692 .54529 Mdot
.692 .54534 Mdot
.692 .54539 Mdot
.692 .54543 Mdot
.692 .54583 Mdot
.692 .54777 Mdot
.692 .54818 Mdot
.692 .54819 Mdot
.692 .54841 Mdot
.692 .54862 Mdot
.692 .54876 Mdot
.692 .54924 Mdot
.692 .54954 Mdot
.692 .54967 Mdot
.692 .55016 Mdot
.692 .55099 Mdot
.692 .55101 Mdot
.692 .55133 Mdot
.692 .5515 Mdot
.692 .55155 Mdot
.692 .55155 Mdot
.692 .55175 Mdot
.692 .5519 Mdot
.692 .5521 Mdot
.692 .55224 Mdot
.692 .55235 Mdot
.692 .55245 Mdot
.692 .55325 Mdot
.692 .55325 Mdot
.692 .55346 Mdot
.692 .55355 Mdot
.692 .55381 Mdot
.692 .55419 Mdot
.692 .55442 Mdot
.692 .55482 Mdot
.692 .55483 Mdot
.692 .55496 Mdot
.692 .55519 Mdot
.692 .55529 Mdot
.692 .55576 Mdot
.692 .55603 Mdot
.692 .55616 Mdot
.692 .55626 Mdot
.692 .55629 Mdot
.692 .55656 Mdot
.692 .55716 Mdot
.692 .5572 Mdot
.692 .55739 Mdot
.692 .55745 Mdot
.692 .55748 Mdot
.692 .55749 Mdot
.692 .55752 Mdot
.692 .55757 Mdot
.692 .55784 Mdot
.692 .55792 Mdot
.692 .55797 Mdot
.692 .55798 Mdot
.692 .55815 Mdot
.692 .55821 Mdot
.692 .55848 Mdot
.692 .55866 Mdot
.692 .55882 Mdot
.692 .55899 Mdot
.692 .55904 Mdot
.692 .55911 Mdot
.692 .55922 Mdot
.692 .55932 Mdot
.692 .55934 Mdot
.692 .55951 Mdot
.692 .55967 Mdot
.692 .5597 Mdot
.692 .55971 Mdot
.692 .55984 Mdot
.692 .55992 Mdot
.692 .56001 Mdot
.692 .56022 Mdot
.692 .56052 Mdot
.692 .56061 Mdot
.692 .56083 Mdot
.692 .56108 Mdot
.692 .56127 Mdot
.692 .56129 Mdot
.692 .56146 Mdot
.692 .5618 Mdot
.692 .56202 Mdot
.692 .56212 Mdot
.692 .56246 Mdot
.692 .56247 Mdot
.692 .56253 Mdot
.692 .56266 Mdot
.692 .56284 Mdot
.692 .56284 Mdot
.692 .56299 Mdot
.692 .56306 Mdot
.692 .5631 Mdot
.692 .56322 Mdot
.692 .56348 Mdot
.692 .56355 Mdot
.692 .56356 Mdot
.692 .56367 Mdot
.692 .56386 Mdot
.692 .56408 Mdot
.692 .56415 Mdot
.692 .56421 Mdot
.692 .5643 Mdot
.692 .56438 Mdot
.692 .56441 Mdot
.692 .56454 Mdot
.692 .56458 Mdot
.692 .56489 Mdot
.692 .56507 Mdot
.692 .56532 Mdot
.692 .56541 Mdot
.692 .56543 Mdot
.692 .5656 Mdot
.692 .56561 Mdot
.692 .56565 Mdot
.692 .56571 Mdot
.692 .56574 Mdot
.692 .56576 Mdot
.692 .5658 Mdot
.692 .56581 Mdot
.692 .56588 Mdot
.692 .56596 Mdot
.692 .56607 Mdot
.692 .5661 Mdot
.692 .5661 Mdot
.692 .56612 Mdot
.692 .56616 Mdot
.692 .5662 Mdot
.692 .56623 Mdot
.692 .56626 Mdot
.692 .5663 Mdot
.692 .56632 Mdot
.692 .56633 Mdot
.692 .56636 Mdot
.692 .56639 Mdot
.692 .56651 Mdot
.692 .56657 Mdot
.692 .56658 Mdot
.692 .56663 Mdot
.692 .56677 Mdot
.692 .56681 Mdot
.692 .56682 Mdot
.692 .56684 Mdot
.692 .56687 Mdot
.692 .56693 Mdot
.692 .56694 Mdot
.692 .56696 Mdot
.692 .56703 Mdot
.692 .56704 Mdot
.692 .56706 Mdot
.694 .14171 Mdot
.694 .14173 Mdot
.694 .14174 Mdot
.694 .14175 Mdot
.694 .14176 Mdot
.694 .14181 Mdot
.694 .14206 Mdot
.694 .1421 Mdot
.694 .14212 Mdot
.694 .14212 Mdot
.694 .14222 Mdot
.694 .1423 Mdot
.694 .14231 Mdot
.694 .14235 Mdot
.694 .1424 Mdot
.694 .14253 Mdot
.694 .14299 Mdot
.694 .14306 Mdot
.694 .1431 Mdot
.694 .14314 Mdot
.694 .14337 Mdot
.694 .1434 Mdot
.694 .14381 Mdot
.694 .14399 Mdot
.694 .14463 Mdot
.694 .14492 Mdot
.694 .1452 Mdot
.694 .14522 Mdot
.694 .14526 Mdot
.694 .1454 Mdot
.694 .14543 Mdot
.694 .14609 Mdot
.694 .14687 Mdot
.694 .14718 Mdot
.694 .14754 Mdot
.694 .14757 Mdot
.694 .14796 Mdot
.694 .14815 Mdot
.694 .14874 Mdot
.694 .149 Mdot
.694 .14904 Mdot
.694 .14982 Mdot
.694 .15006 Mdot
.694 .15041 Mdot
.694 .15131 Mdot
.694 .15146 Mdot
.694 .15147 Mdot
.694 .15159 Mdot
.694 .15223 Mdot
.694 .15241 Mdot
.694 .15244 Mdot
.694 .15247 Mdot
.694 .1525 Mdot
.694 .15251 Mdot
.694 .15262 Mdot
.694 .15267 Mdot
.694 .15287 Mdot
.694 .15303 Mdot
.694 .1531 Mdot
.694 .15381 Mdot
.694 .15395 Mdot
.694 .1541 Mdot
.694 .15414 Mdot
.694 .15433 Mdot
.694 .15544 Mdot
.694 .1555 Mdot
.694 .15554 Mdot
.694 .15619 Mdot
.694 .1562 Mdot
.694 .15644 Mdot
.694 .15654 Mdot
.694 .15701 Mdot
.694 .15803 Mdot
.694 .15842 Mdot
.694 .15892 Mdot
.694 .16035 Mdot
.694 .16085 Mdot
.694 .16092 Mdot
.694 .16186 Mdot
.694 .1619 Mdot
.694 .16223 Mdot
.694 .16227 Mdot
.694 .16253 Mdot
.694 .16345 Mdot
.694 .16367 Mdot
.694 .16386 Mdot
.694 .16423 Mdot
.694 .16492 Mdot
.694 .16499 Mdot
.694 .16531 Mdot
.694 .16562 Mdot
.694 .16567 Mdot
.694 .16589 Mdot
.694 .16608 Mdot
.694 .16642 Mdot
.694 .16642 Mdot
.694 .16702 Mdot
.694 .16786 Mdot
.694 .16818 Mdot
.694 .1684 Mdot
.694 .16843 Mdot
.694 .16849 Mdot
.694 .16861 Mdot
.694 .16884 Mdot
.694 .16923 Mdot
.694 .16949 Mdot
.694 .16998 Mdot
.694 .1703 Mdot
.694 .17067 Mdot
.694 .17095 Mdot
.694 .17348 Mdot
.694 .17473 Mdot
.694 .17491 Mdot
.694 .17522 Mdot
.694 .17567 Mdot
.694 .17576 Mdot
.694 .17654 Mdot
.694 .1766 Mdot
.694 .1769 Mdot
.694 .17693 Mdot
.694 .17757 Mdot
.694 .17757 Mdot
.694 .17773 Mdot
.694 .17795 Mdot
.694 .17814 Mdot
.694 .17859 Mdot
.694 .17904 Mdot
.694 .18074 Mdot
.694 .18099 Mdot
.694 .18135 Mdot
.694 .18137 Mdot
.694 .18149 Mdot
.694 .18149 Mdot
.694 .18163 Mdot
.694 .18181 Mdot
.694 .1824 Mdot
.694 .1862 Mdot
.694 .18632 Mdot
.694 .18636 Mdot
.694 .18647 Mdot
.694 .18871 Mdot
.694 .18929 Mdot
.694 .18958 Mdot
.694 .1906 Mdot
.694 .19083 Mdot
.694 .19174 Mdot
.694 .19535 Mdot
.694 .19648 Mdot
.694 .19887 Mdot
.694 .19902 Mdot
.694 .19936 Mdot
.694 .20299 Mdot
.694 .20368 Mdot
.694 .20495 Mdot
.694 .20794 Mdot
.694 .20807 Mdot
.694 .20847 Mdot
.694 .20927 Mdot
.694 .21019 Mdot
.694 .21027 Mdot
.694 .21577 Mdot
.694 .21587 Mdot
.694 .21615 Mdot
.694 .2163 Mdot
.694 .21711 Mdot
.694 .22188 Mdot
.694 .22189 Mdot
.694 .22241 Mdot
.694 .22314 Mdot
.694 .22831 Mdot
.694 .23533 Mdot
.694 .24025 Mdot
.694 .24545 Mdot
.694 .24567 Mdot
.694 .24568 Mdot
.694 .2481 Mdot
.694 .24822 Mdot
.694 .25067 Mdot
.694 .25148 Mdot
.694 .25166 Mdot
.694 .25367 Mdot
.694 .25399 Mdot
.694 .25525 Mdot
.694 .25571 Mdot
.694 .25587 Mdot
.694 .25594 Mdot
.694 .26447 Mdot
.694 .26481 Mdot
.694 .26491 Mdot
.694 .26498 Mdot
.694 .26499 Mdot
.694 .26506 Mdot
.694 .26507 Mdot
.694 .26542 Mdot
.694 .26693 Mdot
.694 .26717 Mdot
.694 .26726 Mdot
.694 .26726 Mdot
.694 .26765 Mdot
.694 .26766 Mdot
.694 .26788 Mdot
.694 .26835 Mdot
.694 .26841 Mdot
.694 .26868 Mdot
.694 .26899 Mdot
.694 .26977 Mdot
.694 .27139 Mdot
.694 .27203 Mdot
.694 .27254 Mdot
.694 .27296 Mdot
.694 .27307 Mdot
.694 .27325 Mdot
.694 .27347 Mdot
.694 .27472 Mdot
.694 .27485 Mdot
.694 .27505 Mdot
.694 .2755 Mdot
.694 .27607 Mdot
.694 .27758 Mdot
.694 .27784 Mdot
.694 .27787 Mdot
.694 .27861 Mdot
.694 .27867 Mdot
.694 .28068 Mdot
.694 .28265 Mdot
.694 .28266 Mdot
.694 .28326 Mdot
.694 .28442 Mdot
.694 .28465 Mdot
.694 .2848 Mdot
.694 .28616 Mdot
.694 .28628 Mdot
.694 .28629 Mdot
.694 .28635 Mdot
.694 .28639 Mdot
.694 .28657 Mdot
.694 .28727 Mdot
.694 .28742 Mdot
.694 .28759 Mdot
.694 .29174 Mdot
.694 .29456 Mdot
.694 .2957 Mdot
.694 .29608 Mdot
.694 .29665 Mdot
.694 .29721 Mdot
.694 .2986 Mdot
.694 .30004 Mdot
.694 .30013 Mdot
.694 .30076 Mdot
.694 .30086 Mdot
.694 .301 Mdot
.694 .30326 Mdot
.694 .30347 Mdot
.694 .3037 Mdot
.694 .30407 Mdot
.694 .30458 Mdot
.694 .30467 Mdot
.694 .30489 Mdot
.694 .30751 Mdot
.694 .30845 Mdot
.694 .31008 Mdot
.694 .31033 Mdot
.694 .31056 Mdot
.694 .31128 Mdot
.694 .31345 Mdot
.694 .31437 Mdot
.694 .31528 Mdot
.694 .31682 Mdot
.694 .31902 Mdot
.694 .32191 Mdot
.694 .32203 Mdot
.694 .32228 Mdot
.694 .32472 Mdot
.694 .32518 Mdot
.694 .32571 Mdot
.694 .32574 Mdot
.694 .32655 Mdot
.694 .32735 Mdot
.694 .32768 Mdot
.694 .32773 Mdot
.694 .32871 Mdot
.694 .329 Mdot
.694 .32941 Mdot
.694 .33062 Mdot
.694 .33172 Mdot
.694 .33193 Mdot
.694 .33214 Mdot
.694 .3323 Mdot
.694 .33237 Mdot
.694 .3331 Mdot
.694 .33343 Mdot
.694 .33468 Mdot
.694 .33473 Mdot
.694 .3356 Mdot
.694 .3357 Mdot
.694 .33612 Mdot
.694 .33702 Mdot
.694 .33778 Mdot
.694 .33896 Mdot
.694 .34048 Mdot
.694 .34068 Mdot
.694 .34139 Mdot
.694 .34155 Mdot
.694 .34169 Mdot
.694 .34248 Mdot
.694 .34276 Mdot
.694 .34302 Mdot
.694 .34356 Mdot
.694 .34356 Mdot
.694 .34398 Mdot
.694 .34494 Mdot
.694 .34499 Mdot
.694 .34524 Mdot
.694 .34567 Mdot
.694 .34622 Mdot
.694 .34646 Mdot
.694 .34916 Mdot
.694 .35019 Mdot
.694 .35099 Mdot
.694 .35137 Mdot
.694 .35164 Mdot
.694 .35276 Mdot
.694 .35565 Mdot
.694 .35571 Mdot
.694 .35573 Mdot
.694 .3558 Mdot
.694 .35698 Mdot
.694 .35729 Mdot
.694 .35744 Mdot
.694 .35797 Mdot
.694 .35809 Mdot
.694 .35856 Mdot
.694 .36037 Mdot
.694 .36093 Mdot
.694 .36495 Mdot
.694 .36632 Mdot
.694 .36692 Mdot
.694 .36733 Mdot
.694 .36977 Mdot
.694 .37 Mdot
.694 .37035 Mdot
.694 .37288 Mdot
.694 .37499 Mdot
.694 .37969 Mdot
.694 .38167 Mdot
.694 .38175 Mdot
.694 .38175 Mdot
.694 .38266 Mdot
.694 .38362 Mdot
.694 .38391 Mdot
.694 .38398 Mdot
.694 .38472 Mdot
.694 .38483 Mdot
.694 .38529 Mdot
.694 .38546 Mdot
.694 .38552 Mdot
.694 .38555 Mdot
.694 .38861 Mdot
.694 .38872 Mdot
.694 .38876 Mdot
.694 .38879 Mdot
.694 .38879 Mdot
.694 .38881 Mdot
.694 .38882 Mdot
.694 .38894 Mdot
.694 .38947 Mdot
.694 .38956 Mdot
.694 .38959 Mdot
.694 .38959 Mdot
.694 .38973 Mdot
.694 .38981 Mdot
.694 .38997 Mdot
.694 .38999 Mdot
.694 .39009 Mdot
.694 .3902 Mdot
.694 .39047 Mdot
.694 .39103 Mdot
.694 .39126 Mdot
.694 .39143 Mdot
.694 .39158 Mdot
.694 .39162 Mdot
.694 .39168 Mdot
.694 .39175 Mdot
.694 .39219 Mdot
.694 .39223 Mdot
.694 .3923 Mdot
.694 .39246 Mdot
.694 .39265 Mdot
.694 .39317 Mdot
.694 .39326 Mdot
.694 .39327 Mdot
.694 .39352 Mdot
.694 .39354 Mdot
.694 .39423 Mdot
.694 .3949 Mdot
.694 .3951 Mdot
.694 .39549 Mdot
.694 .39557 Mdot
.694 .39608 Mdot
.694 .39612 Mdot
.694 .39612 Mdot
.694 .39622 Mdot
.694 .39645 Mdot
.694 .3965 Mdot
.694 .39656 Mdot
.694 .39795 Mdot
.694 .39888 Mdot
.694 .39926 Mdot
.694 .39938 Mdot
.694 .39957 Mdot
.694 .39975 Mdot
.694 .40021 Mdot
.694 .40068 Mdot
.694 .40071 Mdot
.694 .40095 Mdot
.694 .401 Mdot
.694 .4018 Mdot
.694 .402 Mdot
.694 .40219 Mdot
.694 .40311 Mdot
.694 .40342 Mdot
.694 .40394 Mdot
.694 .40402 Mdot
.694 .4041 Mdot
.694 .40433 Mdot
.694 .40503 Mdot
.694 .40532 Mdot
.694 .40561 Mdot
.694 .4061 Mdot
.694 .40681 Mdot
.694 .40772 Mdot
.694 .40861 Mdot
.694 .40893 Mdot
.694 .40894 Mdot
.694 .40919 Mdot
.694 .40944 Mdot
.694 .40955 Mdot
.694 .40987 Mdot
.694 .41048 Mdot
.694 .41082 Mdot
.694 .41089 Mdot
.694 .41095 Mdot
.694 .411 Mdot
.694 .41102 Mdot
.694 .41125 Mdot
.694 .41136 Mdot
.694 .41175 Mdot
.694 .41177 Mdot
.694 .41204 Mdot
.694 .41207 Mdot
.694 .4122 Mdot
.694 .41248 Mdot
.694 .41272 Mdot
.694 .41356 Mdot
.694 .41362 Mdot
.694 .41384 Mdot
.694 .41389 Mdot
.694 .41394 Mdot
.694 .41418 Mdot
.694 .41427 Mdot
.694 .41452 Mdot
.694 .41452 Mdot
.694 .41465 Mdot
.694 .41495 Mdot
.694 .41496 Mdot
.694 .41518 Mdot
.694 .41534 Mdot
.694 .41542 Mdot
.694 .41626 Mdot
.694 .41657 Mdot
.694 .41682 Mdot
.694 .41694 Mdot
.694 .41702 Mdot
.694 .41737 Mdot
.694 .41826 Mdot
.694 .41828 Mdot
.694 .41829 Mdot
.694 .41831 Mdot
.694 .41877 Mdot
.694 .41898 Mdot
.694 .41972 Mdot
.694 .41989 Mdot
.694 .42113 Mdot
.694 .42173 Mdot
.694 .42186 Mdot
.694 .42261 Mdot
.694 .42279 Mdot
.694 .42357 Mdot
.694 .42421 Mdot
.694 .42566 Mdot
.694 .42627 Mdot
.694 .42629 Mdot
.694 .42657 Mdot
.694 .42686 Mdot
.694 .42695 Mdot
.694 .42697 Mdot
.694 .42724 Mdot
.694 .42738 Mdot
.694 .42745 Mdot
.694 .42746 Mdot
.694 .4284 Mdot
.694 .42914 Mdot
.694 .42921 Mdot
.694 .4295 Mdot
.694 .42958 Mdot
.694 .42964 Mdot
.694 .42983 Mdot
.694 .42983 Mdot
.694 .42991 Mdot
.694 .43013 Mdot
.694 .4304 Mdot
.694 .43054 Mdot
.694 .43071 Mdot
.694 .43081 Mdot
.694 .43212 Mdot
.694 .43212 Mdot
.694 .43252 Mdot
.694 .43287 Mdot
.694 .43317 Mdot
.694 .43324 Mdot
.694 .43346 Mdot
.694 .43355 Mdot
.694 .43429 Mdot
.694 .43483 Mdot
.694 .43486 Mdot
.694 .43496 Mdot
.694 .43555 Mdot
.694 .43577 Mdot
.694 .43584 Mdot
.694 .43611 Mdot
.694 .43619 Mdot
.694 .43641 Mdot
.694 .43661 Mdot
.694 .43695 Mdot
.694 .43757 Mdot
.694 .43758 Mdot
.694 .43803 Mdot
.694 .43847 Mdot
.694 .43866 Mdot
.694 .44018 Mdot
.694 .44027 Mdot
.694 .44031 Mdot
.694 .44076 Mdot
.694 .44115 Mdot
.694 .44121 Mdot
.694 .44131 Mdot
.694 .44152 Mdot
.694 .44194 Mdot
.694 .44229 Mdot
.694 .44263 Mdot
.694 .4431 Mdot
.694 .44382 Mdot
.694 .44396 Mdot
.694 .44454 Mdot
.694 .44519 Mdot
.694 .44568 Mdot
.694 .44814 Mdot
.694 .44899 Mdot
.694 .4501 Mdot
.694 .45012 Mdot
.694 .45112 Mdot
.694 .45136 Mdot
.694 .45225 Mdot
.694 .45256 Mdot
.694 .4526 Mdot
.694 .45309 Mdot
.694 .4534 Mdot
.694 .45386 Mdot
.694 .45397 Mdot
.694 .45401 Mdot
.694 .45458 Mdot
.694 .45528 Mdot
.694 .45534 Mdot
.694 .45543 Mdot
.694 .45565 Mdot
.694 .45581 Mdot
.694 .45591 Mdot
.694 .45594 Mdot
.694 .45598 Mdot
.694 .45657 Mdot
.694 .45707 Mdot
.694 .45707 Mdot
.694 .45732 Mdot
.694 .45733 Mdot
.694 .45738 Mdot
.694 .45754 Mdot
.694 .4577 Mdot
.694 .45802 Mdot
.694 .45877 Mdot
.694 .45952 Mdot
.694 .46007 Mdot
.694 .46038 Mdot
.694 .46111 Mdot
.694 .46185 Mdot
.694 .46186 Mdot
.694 .46231 Mdot
.694 .46272 Mdot
.694 .46288 Mdot
.694 .46331 Mdot
.694 .46335 Mdot
.694 .46343 Mdot
.694 .46354 Mdot
.694 .46355 Mdot
.694 .46376 Mdot
.694 .46377 Mdot
.694 .46406 Mdot
.694 .46411 Mdot
.694 .46425 Mdot
.694 .46467 Mdot
.694 .46479 Mdot
.694 .46502 Mdot
.694 .46515 Mdot
.694 .4661 Mdot
.694 .46626 Mdot
.694 .46631 Mdot
.694 .46717 Mdot
.694 .46835 Mdot
.694 .4685 Mdot
.694 .46884 Mdot
.694 .46896 Mdot
.694 .46944 Mdot
.694 .46998 Mdot
.694 .47061 Mdot
.694 .47062 Mdot
.694 .47107 Mdot
.694 .47125 Mdot
.694 .47131 Mdot
.694 .47149 Mdot
.694 .47266 Mdot
.694 .47282 Mdot
.694 .47308 Mdot
.694 .4733 Mdot
.694 .47372 Mdot
.694 .47406 Mdot
.694 .47418 Mdot
.694 .47418 Mdot
.694 .47447 Mdot
.694 .47456 Mdot
.694 .47469 Mdot
.694 .47496 Mdot
.694 .47513 Mdot
.694 .47523 Mdot
.694 .47585 Mdot
.694 .47629 Mdot
.694 .47637 Mdot
.694 .4778 Mdot
.694 .47781 Mdot
.694 .47784 Mdot
.694 .47792 Mdot
.694 .47813 Mdot
.694 .47819 Mdot
.694 .47853 Mdot
.694 .47856 Mdot
.694 .4787 Mdot
.694 .47914 Mdot
.694 .47955 Mdot
.694 .47955 Mdot
.694 .47959 Mdot
.694 .4805 Mdot
.694 .48263 Mdot
.694 .48358 Mdot
.694 .48472 Mdot
.694 .48487 Mdot
.694 .48498 Mdot
.694 .48606 Mdot
.694 .48624 Mdot
.694 .48651 Mdot
.694 .48711 Mdot
.694 .48887 Mdot
.694 .48911 Mdot
.694 .4899 Mdot
.694 .4901 Mdot
.694 .49015 Mdot
.694 .49045 Mdot
.694 .49058 Mdot
.694 .49109 Mdot
.694 .49112 Mdot
.694 .49113 Mdot
.694 .49115 Mdot
.694 .49239 Mdot
.694 .49287 Mdot
.694 .49299 Mdot
.694 .49315 Mdot
.694 .49349 Mdot
.694 .49393 Mdot
.694 .49507 Mdot
.694 .49517 Mdot
.694 .4954 Mdot
.694 .49558 Mdot
.694 .49568 Mdot
.694 .49571 Mdot
.694 .49611 Mdot
.694 .49628 Mdot
.694 .49629 Mdot
.694 .49651 Mdot
.694 .49662 Mdot
.694 .49674 Mdot
.694 .49707 Mdot
.694 .49712 Mdot
.694 .49719 Mdot
.694 .49748 Mdot
.694 .49757 Mdot
.694 .4982 Mdot
.694 .49869 Mdot
.694 .499 Mdot
.694 .49937 Mdot
.694 .49955 Mdot
.694 .49959 Mdot
.694 .49994 Mdot
.694 .49997 Mdot
.694 .50048 Mdot
.694 .50061 Mdot
.694 .50091 Mdot
.694 .50094 Mdot
.694 .50101 Mdot
.694 .50109 Mdot
.694 .50118 Mdot
.694 .50162 Mdot
.694 .50211 Mdot
.694 .50228 Mdot
.694 .5024 Mdot
.694 .50279 Mdot
.694 .50282 Mdot
.694 .50295 Mdot
.694 .50327 Mdot
.694 .5036 Mdot
.694 .50361 Mdot
.694 .50382 Mdot
.694 .50401 Mdot
.694 .50499 Mdot
.694 .50509 Mdot
.694 .50514 Mdot
.694 .50629 Mdot
.694 .50716 Mdot
.694 .50777 Mdot
.694 .50813 Mdot
.694 .50849 Mdot
.694 .50934 Mdot
.694 .50962 Mdot
.694 .50971 Mdot
.694 .50981 Mdot
.694 .51044 Mdot
.694 .51081 Mdot
.694 .51182 Mdot
.694 .51191 Mdot
.694 .51194 Mdot
.694 .51214 Mdot
.694 .51228 Mdot
.694 .51237 Mdot
.694 .51245 Mdot
.694 .51332 Mdot
.694 .51337 Mdot
.694 .51341 Mdot
.694 .51365 Mdot
.694 .51369 Mdot
.694 .51424 Mdot
.694 .51477 Mdot
.694 .51498 Mdot
.694 .5152 Mdot
.694 .51534 Mdot
.694 .51578 Mdot
.694 .51684 Mdot
.694 .5184 Mdot
.694 .51847 Mdot
.694 .51852 Mdot
.694 .51878 Mdot
.694 .51885 Mdot
.694 .51887 Mdot
.694 .51889 Mdot
.694 .51889 Mdot
.694 .51894 Mdot
.694 .51945 Mdot
.694 .5195 Mdot
.694 .51959 Mdot
.694 .52002 Mdot
.694 .52024 Mdot
.694 .52024 Mdot
.694 .52097 Mdot
.694 .52171 Mdot
.694 .52174 Mdot
.694 .52201 Mdot
.694 .52202 Mdot
.694 .52211 Mdot
.694 .52267 Mdot
.694 .52288 Mdot
.694 .52304 Mdot
.694 .52312 Mdot
.694 .52316 Mdot
.694 .52362 Mdot
.694 .5237 Mdot
.694 .52377 Mdot
.694 .52381 Mdot
.694 .52396 Mdot
.694 .52415 Mdot
.694 .52438 Mdot
.694 .52497 Mdot
.694 .52525 Mdot
.694 .52536 Mdot
.694 .52546 Mdot
.694 .52548 Mdot
.694 .52565 Mdot
.694 .52573 Mdot
.694 .52574 Mdot
.694 .52588 Mdot
.694 .52588 Mdot
.694 .52591 Mdot
.694 .526 Mdot
.694 .52654 Mdot
.694 .52667 Mdot
.694 .52667 Mdot
.694 .5267 Mdot
.694 .5267 Mdot
.694 .52673 Mdot
.694 .52676 Mdot
.694 .52688 Mdot
.694 .52993 Mdot
.694 .52996 Mdot
.694 .53001 Mdot
.694 .53018 Mdot
.694 .53062 Mdot
.694 .53074 Mdot
.694 .53144 Mdot
.694 .53151 Mdot
.694 .53179 Mdot
.694 .53265 Mdot
.694 .5327 Mdot
.694 .53354 Mdot
.694 .53354 Mdot
.694 .53362 Mdot
.694 .53543 Mdot
.694 .53713 Mdot
.694 .53953 Mdot
.694 .54128 Mdot
.694 .54152 Mdot
.694 .5417 Mdot
.694 .5417 Mdot
.694 .5433 Mdot
.694 .54357 Mdot
.694 .54362 Mdot
.694 .54372 Mdot
.694 .54375 Mdot
.694 .54558 Mdot
.694 .54561 Mdot
.694 .54591 Mdot
.694 .54618 Mdot
.694 .54631 Mdot
.694 .54635 Mdot
.694 .54734 Mdot
.694 .54775 Mdot
.694 .54798 Mdot
.694 .54917 Mdot
.694 .54928 Mdot
.694 .54932 Mdot
.694 .5501 Mdot
.694 .55047 Mdot
.694 .55164 Mdot
.694 .55193 Mdot
.694 .55201 Mdot
.694 .55234 Mdot
.694 .55243 Mdot
.694 .55262 Mdot
.694 .55334 Mdot
.694 .55337 Mdot
.694 .55339 Mdot
.694 .55342 Mdot
.694 .55464 Mdot
.694 .55483 Mdot
.694 .55489 Mdot
.694 .55493 Mdot
.694 .55493 Mdot
.694 .55497 Mdot
.694 .55497 Mdot
.694 .55509 Mdot
.694 .55517 Mdot
.694 .55571 Mdot
.694 .55585 Mdot
.694 .55599 Mdot
.694 .55606 Mdot
.694 .55612 Mdot
.694 .55617 Mdot
.694 .55617 Mdot
.694 .55638 Mdot
.694 .55639 Mdot
.694 .55648 Mdot
.694 .5565 Mdot
.694 .55675 Mdot
.694 .55678 Mdot
.694 .55692 Mdot
.694 .55702 Mdot
.694 .55707 Mdot
.694 .55747 Mdot
.694 .55827 Mdot
.694 .55835 Mdot
.694 .55847 Mdot
.694 .55857 Mdot
.694 .55872 Mdot
.694 .55881 Mdot
.694 .55893 Mdot
.694 .559 Mdot
.694 .55904 Mdot
.694 .55905 Mdot
.694 .55907 Mdot
.694 .55913 Mdot
.694 .55923 Mdot
.694 .5595 Mdot
.694 .55968 Mdot
.694 .55969 Mdot
.694 .55979 Mdot
.694 .55985 Mdot
.694 .55992 Mdot
.694 .55994 Mdot
.694 .56003 Mdot
.694 .56013 Mdot
.694 .56015 Mdot
.694 .56037 Mdot
.694 .56049 Mdot
.694 .56054 Mdot
.694 .56061 Mdot
.694 .5609 Mdot
.694 .56098 Mdot
.694 .56099 Mdot
.694 .5611 Mdot
.694 .56111 Mdot
.694 .5614 Mdot
.694 .56142 Mdot
.694 .56158 Mdot
.694 .56202 Mdot
.694 .56217 Mdot
.694 .56229 Mdot
.694 .56261 Mdot
.694 .56275 Mdot
.694 .56279 Mdot
.694 .56286 Mdot
.694 .56286 Mdot
.694 .56306 Mdot
.694 .56308 Mdot
.694 .5631 Mdot
.694 .56344 Mdot
.694 .5635 Mdot
.694 .56351 Mdot
.694 .56355 Mdot
.694 .5636 Mdot
.694 .56382 Mdot
.694 .56384 Mdot
.694 .56389 Mdot
.694 .56395 Mdot
.694 .56396 Mdot
.694 .564 Mdot
.694 .564 Mdot
.694 .56401 Mdot
.694 .56402 Mdot
.694 .56403 Mdot
.694 .56408 Mdot
.694 .56428 Mdot
.694 .56432 Mdot
.694 .56432 Mdot
.694 .56437 Mdot
.694 .56464 Mdot
.694 .56475 Mdot
.694 .56482 Mdot
.694 .56506 Mdot
.694 .56507 Mdot
.694 .56515 Mdot
.694 .56534 Mdot
.694 .56539 Mdot
.694 .56551 Mdot
.694 .56552 Mdot
.694 .56563 Mdot
.694 .56572 Mdot
.694 .56596 Mdot
.694 .56617 Mdot
.694 .56617 Mdot
.694 .56622 Mdot
.694 .56623 Mdot
.694 .56624 Mdot
.694 .56632 Mdot
.694 .56641 Mdot
.694 .5666 Mdot
.694 .56666 Mdot
.694 .56678 Mdot
.694 .56679 Mdot
.694 .56686 Mdot
.694 .56687 Mdot
.694 .56689 Mdot
.694 .56691 Mdot
.694 .56705 Mdot
.694 .56709 Mdot
.694 .5671 Mdot
.694 .56711 Mdot
.694 .56712 Mdot
.694 .56714 Mdot
.694 .56717 Mdot
.694 .56717 Mdot
.694 .56718 Mdot
.694 .56719 Mdot
.694 .56726 Mdot
.694 .56728 Mdot
.694 .56728 Mdot
.694 .56729 Mdot
.694 .56729 Mdot
.694 .56729 Mdot
.696 .14098 Mdot
.696 .14099 Mdot
.696 .141 Mdot
.696 .141 Mdot
.696 .14101 Mdot
.696 .14101 Mdot
.696 .14106 Mdot
.696 .14107 Mdot
.696 .14109 Mdot
.696 .14115 Mdot
.696 .14125 Mdot
.696 .14138 Mdot
.696 .1414 Mdot
.696 .14174 Mdot
.696 .14176 Mdot
.696 .14178 Mdot
.696 .14189 Mdot
.696 .14202 Mdot
.696 .14251 Mdot
.696 .14253 Mdot
.696 .14254 Mdot
.696 .14282 Mdot
.696 .14316 Mdot
.696 .14368 Mdot
.696 .14382 Mdot
.696 .1443 Mdot
.696 .14486 Mdot
.696 .14506 Mdot
.696 .14517 Mdot
.696 .14562 Mdot
.696 .14575 Mdot
.696 .14582 Mdot
.696 .14603 Mdot
.696 .14621 Mdot
.696 .14667 Mdot
.696 .14703 Mdot
.696 .14748 Mdot
.696 .14825 Mdot
.696 .14847 Mdot
.696 .14863 Mdot
.696 .14887 Mdot
.696 .14893 Mdot
.696 .1495 Mdot
.696 .14978 Mdot
.696 .14979 Mdot
.696 .14985 Mdot
.696 .15103 Mdot
.696 .15187 Mdot
.696 .15203 Mdot
.696 .15205 Mdot
.696 .1527 Mdot
.696 .15289 Mdot
.696 .1532 Mdot
.696 .15322 Mdot
.696 .15334 Mdot
.696 .15378 Mdot
.696 .15395 Mdot
.696 .15485 Mdot
.696 .15504 Mdot
.696 .15576 Mdot
.696 .15582 Mdot
.696 .15729 Mdot
.696 .15744 Mdot
.696 .15746 Mdot
.696 .15781 Mdot
.696 .15834 Mdot
.696 .15853 Mdot
.696 .15929 Mdot
.696 .15939 Mdot
.696 .15958 Mdot
.696 .16003 Mdot
.696 .16049 Mdot
.696 .16068 Mdot
.696 .16074 Mdot
.696 .16145 Mdot
.696 .1615 Mdot
.696 .1618 Mdot
.696 .16223 Mdot
.696 .16259 Mdot
.696 .16309 Mdot
.696 .16323 Mdot
.696 .16517 Mdot
.696 .16548 Mdot
.696 .16655 Mdot
.696 .16706 Mdot
.696 .16727 Mdot
.696 .16867 Mdot
.696 .16958 Mdot
.696 .17012 Mdot
.696 .17086 Mdot
.696 .17128 Mdot
.696 .17135 Mdot
.696 .17136 Mdot
.696 .1716 Mdot
.696 .17252 Mdot
.696 .17283 Mdot
.696 .17288 Mdot
.696 .17311 Mdot
.696 .17344 Mdot
.696 .17393 Mdot
.696 .17454 Mdot
.696 .17609 Mdot
.696 .17642 Mdot
.696 .17777 Mdot
.696 .17801 Mdot
.696 .17934 Mdot
.696 .17937 Mdot
.696 .17945 Mdot
.696 .17991 Mdot
.696 .18006 Mdot
.696 .18039 Mdot
.696 .1805 Mdot
.696 .1807 Mdot
.696 .18101 Mdot
.696 .18116 Mdot
.696 .18143 Mdot
.696 .18183 Mdot
.696 .18215 Mdot
.696 .18303 Mdot
.696 .18344 Mdot
.696 .1839 Mdot
.696 .18471 Mdot
.696 .1849 Mdot
.696 .185 Mdot
.696 .1863 Mdot
.696 .18661 Mdot
.696 .18751 Mdot
.696 .18804 Mdot
.696 .18823 Mdot
.696 .18841 Mdot
.696 .18849 Mdot
.696 .18905 Mdot
.696 .18915 Mdot
.696 .18917 Mdot
.696 .18926 Mdot
.696 .18936 Mdot
.696 .18939 Mdot
.696 .19164 Mdot
.696 .1918 Mdot
.696 .19281 Mdot
.696 .19479 Mdot
.696 .20002 Mdot
.696 .202 Mdot
.696 .20225 Mdot
.696 .20259 Mdot
.696 .20474 Mdot
.696 .20485 Mdot
.696 .2049 Mdot
.696 .20513 Mdot
.696 .20588 Mdot
.696 .20663 Mdot
.696 .20706 Mdot
.696 .20734 Mdot
.696 .20779 Mdot
.696 .20838 Mdot
.696 .21238 Mdot
.696 .2146 Mdot
.696 .21494 Mdot
.696 .2152 Mdot
.696 .21657 Mdot
.696 .21708 Mdot
.696 .21733 Mdot
.696 .21935 Mdot
.696 .22184 Mdot
.696 .22229 Mdot
.696 .22562 Mdot
.696 .22898 Mdot
.696 .23046 Mdot
.696 .23133 Mdot
.696 .23304 Mdot
.696 .23343 Mdot
.696 .23347 Mdot
.696 .23533 Mdot
.696 .24078 Mdot
.696 .24093 Mdot
.696 .2439 Mdot
.696 .24527 Mdot
.696 .24745 Mdot
.696 .24767 Mdot
.696 .24826 Mdot
.696 .24837 Mdot
.696 .25151 Mdot
.696 .25238 Mdot
.696 .25272 Mdot
.696 .25282 Mdot
.696 .25284 Mdot
.696 .25389 Mdot
.696 .25862 Mdot
.696 .26036 Mdot
.696 .26038 Mdot
.696 .26043 Mdot
.696 .26047 Mdot
.696 .26049 Mdot
.696 .26054 Mdot
.696 .26083 Mdot
.696 .26087 Mdot
.696 .26097 Mdot
.696 .26106 Mdot
.696 .26134 Mdot
.696 .26182 Mdot
.696 .26198 Mdot
.696 .26274 Mdot
.696 .26284 Mdot
.696 .26425 Mdot
.696 .26466 Mdot
.696 .26489 Mdot
.696 .26507 Mdot
.696 .26518 Mdot
.696 .26524 Mdot
.696 .26543 Mdot
.696 .26552 Mdot
.696 .26578 Mdot
.696 .26584 Mdot
.696 .26662 Mdot
.696 .26676 Mdot
.696 .26756 Mdot
.696 .26775 Mdot
.696 .26869 Mdot
.696 .26958 Mdot
.696 .26973 Mdot
.696 .26975 Mdot
.696 .27069 Mdot
.696 .2715 Mdot
.696 .27356 Mdot
.696 .27391 Mdot
.696 .27466 Mdot
.696 .27488 Mdot
.696 .27641 Mdot
.696 .27678 Mdot
.696 .27765 Mdot
.696 .27821 Mdot
.696 .27825 Mdot
.696 .27841 Mdot
.696 .28061 Mdot
.696 .28325 Mdot
.696 .28411 Mdot
.696 .2847 Mdot
.696 .28484 Mdot
.696 .28535 Mdot
.696 .28602 Mdot
.696 .28604 Mdot
.696 .28716 Mdot
.696 .28886 Mdot
.696 .28962 Mdot
.696 .29012 Mdot
.696 .29143 Mdot
.696 .29204 Mdot
.696 .29256 Mdot
.696 .29324 Mdot
.696 .29351 Mdot
.696 .29384 Mdot
.696 .29396 Mdot
.696 .29509 Mdot
.696 .29543 Mdot
.696 .29646 Mdot
.696 .2974 Mdot
.696 .29769 Mdot
.696 .29967 Mdot
.696 .30043 Mdot
.696 .30044 Mdot
.696 .30051 Mdot
.696 .302 Mdot
.696 .30459 Mdot
.696 .30544 Mdot
.696 .30623 Mdot
.696 .30683 Mdot
.696 .30701 Mdot
.696 .30783 Mdot
.696 .30802 Mdot
.696 .30807 Mdot
.696 .309 Mdot
.696 .30936 Mdot
.696 .30976 Mdot
.696 .31094 Mdot
.696 .31335 Mdot
.696 .31499 Mdot
.696 .3151 Mdot
.696 .31518 Mdot
.696 .31559 Mdot
.696 .31918 Mdot
.696 .32313 Mdot
.696 .32388 Mdot
.696 .32763 Mdot
.696 .32811 Mdot
.696 .32849 Mdot
.696 .3295 Mdot
.696 .32951 Mdot
.696 .32959 Mdot
.696 .33093 Mdot
.696 .33183 Mdot
.696 .33287 Mdot
.696 .33321 Mdot
.696 .33376 Mdot
.696 .33495 Mdot
.696 .33562 Mdot
.696 .33567 Mdot
.696 .33698 Mdot
.696 .33711 Mdot
.696 .33712 Mdot
.696 .33787 Mdot
.696 .33803 Mdot
.696 .33866 Mdot
.696 .33874 Mdot
.696 .33889 Mdot
.696 .33926 Mdot
.696 .34041 Mdot
.696 .34065 Mdot
.696 .34173 Mdot
.696 .34462 Mdot
.696 .34557 Mdot
.696 .34618 Mdot
.696 .34702 Mdot
.696 .34729 Mdot
.696 .34734 Mdot
.696 .3475 Mdot
.696 .34808 Mdot
.696 .34866 Mdot
.696 .34896 Mdot
.696 .35221 Mdot
.696 .35323 Mdot
.696 .35361 Mdot
.696 .35427 Mdot
.696 .3545 Mdot
.696 .35475 Mdot
.696 .35535 Mdot
.696 .35883 Mdot
.696 .35891 Mdot
.696 .3604 Mdot
.696 .36294 Mdot
.696 .36387 Mdot
.696 .36398 Mdot
.696 .36514 Mdot
.696 .366 Mdot
.696 .36619 Mdot
.696 .36632 Mdot
.696 .36678 Mdot
.696 .36856 Mdot
.696 .36952 Mdot
.696 .37069 Mdot
.696 .37154 Mdot
.696 .37258 Mdot
.696 .37549 Mdot
.696 .37608 Mdot
.696 .37643 Mdot
.696 .37727 Mdot
.696 .378 Mdot
.696 .3801 Mdot
.696 .38016 Mdot
.696 .38129 Mdot
.696 .3818 Mdot
.696 .38262 Mdot
.696 .38292 Mdot
.696 .38296 Mdot
.696 .38412 Mdot
.696 .38444 Mdot
.696 .3846 Mdot
.696 .38732 Mdot
.696 .38733 Mdot
.696 .38735 Mdot
.696 .38736 Mdot
.696 .38737 Mdot
.696 .38739 Mdot
.696 .38749 Mdot
.696 .3875 Mdot
.696 .38754 Mdot
.696 .38767 Mdot
.696 .38784 Mdot
.696 .3879 Mdot
.696 .38817 Mdot
.696 .38821 Mdot
.696 .3887 Mdot
.696 .38885 Mdot
.696 .38893 Mdot
.696 .38899 Mdot
.696 .38903 Mdot
.696 .38912 Mdot
.696 .38915 Mdot
.696 .38924 Mdot
.696 .38927 Mdot
.696 .38954 Mdot
.696 .38959 Mdot
.696 .38987 Mdot
.696 .38994 Mdot
.696 .39027 Mdot
.696 .39058 Mdot
.696 .39063 Mdot
.696 .39064 Mdot
.696 .39096 Mdot
.696 .39124 Mdot
.696 .39195 Mdot
.696 .39207 Mdot
.696 .39233 Mdot
.696 .39293 Mdot
.696 .39306 Mdot
.696 .39336 Mdot
.696 .39355 Mdot
.696 .39356 Mdot
.696 .39362 Mdot
.696 .39436 Mdot
.696 .39526 Mdot
.696 .39555 Mdot
.696 .39579 Mdot
.696 .39596 Mdot
.696 .39619 Mdot
.696 .39657 Mdot
.696 .39714 Mdot
.696 .39739 Mdot
.696 .39756 Mdot
.696 .39799 Mdot
.696 .3982 Mdot
.696 .39837 Mdot
.696 .39859 Mdot
.696 .39879 Mdot
.696 .39883 Mdot
.696 .3992 Mdot
.696 .39931 Mdot
.696 .39965 Mdot
.696 .39996 Mdot
.696 .40006 Mdot
.696 .40095 Mdot
.696 .40098 Mdot
.696 .40231 Mdot
.696 .40258 Mdot
.696 .40303 Mdot
.696 .40335 Mdot
.696 .40341 Mdot
.696 .40373 Mdot
.696 .40384 Mdot
.696 .40397 Mdot
.696 .40435 Mdot
.696 .40512 Mdot
.696 .40569 Mdot
.696 .40571 Mdot
.696 .40584 Mdot
.696 .40698 Mdot
.696 .40824 Mdot
.696 .40847 Mdot
.696 .40981 Mdot
.696 .40992 Mdot
.696 .41025 Mdot
.696 .41027 Mdot
.696 .4113 Mdot
.696 .41157 Mdot
.696 .41195 Mdot
.696 .41217 Mdot
.696 .41258 Mdot
.696 .41262 Mdot
.696 .41263 Mdot
.696 .41286 Mdot
.696 .4131 Mdot
.696 .41365 Mdot
.696 .41372 Mdot
.696 .41406 Mdot
.696 .41496 Mdot
.696 .41525 Mdot
.696 .4157 Mdot
.696 .4158 Mdot
.696 .41585 Mdot
.696 .41621 Mdot
.696 .4163 Mdot
.696 .4173 Mdot
.696 .41762 Mdot
.696 .41773 Mdot
.696 .41794 Mdot
.696 .41809 Mdot
.696 .41827 Mdot
.696 .41934 Mdot
.696 .41937 Mdot
.696 .41983 Mdot
.696 .4206 Mdot
.696 .42089 Mdot
.696 .42093 Mdot
.696 .42128 Mdot
.696 .42154 Mdot
.696 .4216 Mdot
.696 .42164 Mdot
.696 .42179 Mdot
.696 .42233 Mdot
.696 .42263 Mdot
.696 .42298 Mdot
.696 .42356 Mdot
.696 .42446 Mdot
.696 .42464 Mdot
.696 .42474 Mdot
.696 .425 Mdot
.696 .42587 Mdot
.696 .42589 Mdot
.696 .42664 Mdot
.696 .42673 Mdot
.696 .42674 Mdot
.696 .4271 Mdot
.696 .4272 Mdot
.696 .42725 Mdot
.696 .42824 Mdot
.696 .42851 Mdot
.696 .42855 Mdot
.696 .42863 Mdot
.696 .4292 Mdot
.696 .43 Mdot
.696 .43001 Mdot
.696 .43068 Mdot
.696 .43092 Mdot
.696 .43154 Mdot
.696 .4316 Mdot
.696 .43162 Mdot
.696 .43187 Mdot
.696 .43197 Mdot
.696 .43227 Mdot
.696 .43269 Mdot
.696 .43547 Mdot
.696 .43574 Mdot
.696 .43603 Mdot
.696 .4367 Mdot
.696 .43684 Mdot
.696 .43758 Mdot
.696 .43798 Mdot
.696 .43874 Mdot
.696 .43891 Mdot
.696 .43929 Mdot
.696 .43966 Mdot
.696 .44029 Mdot
.696 .44045 Mdot
.696 .44077 Mdot
.696 .44085 Mdot
.696 .44132 Mdot
.696 .44181 Mdot
.696 .44183 Mdot
.696 .44204 Mdot
.696 .44217 Mdot
.696 .44314 Mdot
.696 .44345 Mdot
.696 .44373 Mdot
.696 .44439 Mdot
.696 .44465 Mdot
.696 .44475 Mdot
.696 .44477 Mdot
.696 .44509 Mdot
.696 .4457 Mdot
.696 .446 Mdot
.696 .44603 Mdot
.696 .44604 Mdot
.696 .44614 Mdot
.696 .44644 Mdot
.696 .44645 Mdot
.696 .44648 Mdot
.696 .44658 Mdot
.696 .44659 Mdot
.696 .44673 Mdot
.696 .44675 Mdot
.696 .44693 Mdot
.696 .44699 Mdot
.696 .44699 Mdot
.696 .44701 Mdot
.696 .44752 Mdot
.696 .4477 Mdot
.696 .44772 Mdot
.696 .44777 Mdot
.696 .44829 Mdot
.696 .44862 Mdot
.696 .44916 Mdot
.696 .44924 Mdot
.696 .44936 Mdot
.696 .44964 Mdot
.696 .4499 Mdot
.696 .44995 Mdot
.696 .45012 Mdot
.696 .45021 Mdot
.696 .45056 Mdot
.696 .45107 Mdot
.696 .45171 Mdot
.696 .45211 Mdot
.696 .45219 Mdot
.696 .45271 Mdot
.696 .45437 Mdot
.696 .45459 Mdot
.696 .45476 Mdot
.696 .45495 Mdot
.696 .45498 Mdot
.696 .45532 Mdot
.696 .45581 Mdot
.696 .4566 Mdot
.696 .45674 Mdot
.696 .45727 Mdot
.696 .45754 Mdot
.696 .45759 Mdot
.696 .45799 Mdot
.696 .45859 Mdot
.696 .4592 Mdot
.696 .45985 Mdot
.696 .46013 Mdot
.696 .4602 Mdot
.696 .46025 Mdot
.696 .46039 Mdot
.696 .46114 Mdot
.696 .46138 Mdot
.696 .46139 Mdot
.696 .46194 Mdot
.696 .46204 Mdot
.696 .46211 Mdot
.696 .46244 Mdot
.696 .46295 Mdot
.696 .4632 Mdot
.696 .46325 Mdot
.696 .46348 Mdot
.696 .46363 Mdot
.696 .46429 Mdot
.696 .46456 Mdot
.696 .46481 Mdot
.696 .46503 Mdot
.696 .46547 Mdot
.696 .46622 Mdot
.696 .46688 Mdot
.696 .46762 Mdot
.696 .46891 Mdot
.696 .46922 Mdot
.696 .46937 Mdot
.696 .46991 Mdot
.696 .47057 Mdot
.696 .47105 Mdot
.696 .4712 Mdot
.696 .47142 Mdot
.696 .4716 Mdot
.696 .47162 Mdot
.696 .47171 Mdot
.696 .4719 Mdot
.696 .47268 Mdot
.696 .47305 Mdot
.696 .47331 Mdot
.696 .47409 Mdot
.696 .47411 Mdot
.696 .47412 Mdot
.696 .47441 Mdot
.696 .4747 Mdot
.696 .47482 Mdot
.696 .47534 Mdot
.696 .47567 Mdot
.696 .47583 Mdot
.696 .47586 Mdot
.696 .47599 Mdot
.696 .47615 Mdot
.696 .47619 Mdot
.696 .47621 Mdot
.696 .47634 Mdot
.696 .4764 Mdot
.696 .47681 Mdot
.696 .47831 Mdot
.696 .47839 Mdot
.696 .47854 Mdot
.696 .47907 Mdot
.696 .47909 Mdot
.696 .47923 Mdot
.696 .4796 Mdot
.696 .47984 Mdot
.696 .48036 Mdot
.696 .48038 Mdot
.696 .48134 Mdot
.696 .48167 Mdot
.696 .48205 Mdot
.696 .48221 Mdot
.696 .48248 Mdot
.696 .48379 Mdot
.696 .48425 Mdot
.696 .48463 Mdot
.696 .48515 Mdot
.696 .48558 Mdot
.696 .48637 Mdot
.696 .48657 Mdot
.696 .48663 Mdot
.696 .48671 Mdot
.696 .48709 Mdot
.696 .4876 Mdot
.696 .48765 Mdot
.696 .48806 Mdot
.696 .48916 Mdot
.696 .48981 Mdot
.696 .48985 Mdot
.696 .49135 Mdot
.696 .4916 Mdot
.696 .49171 Mdot
.696 .49181 Mdot
.696 .49209 Mdot
.696 .49225 Mdot
.696 .49269 Mdot
.696 .49407 Mdot
.696 .4942 Mdot
.696 .49444 Mdot
.696 .49469 Mdot
.696 .49475 Mdot
.696 .49478 Mdot
.696 .49489 Mdot
.696 .49524 Mdot
.696 .4955 Mdot
.696 .4959 Mdot
.696 .49711 Mdot
.696 .49756 Mdot
.696 .49765 Mdot
.696 .49813 Mdot
.696 .49828 Mdot
.696 .49835 Mdot
.696 .49838 Mdot
.696 .49864 Mdot
.696 .49871 Mdot
.696 .49902 Mdot
.696 .49902 Mdot
.696 .49908 Mdot
.696 .49961 Mdot
.696 .49964 Mdot
.696 .49991 Mdot
.696 .5004 Mdot
.696 .50062 Mdot
.696 .50076 Mdot
.696 .50119 Mdot
.696 .50155 Mdot
.696 .5021 Mdot
.696 .50213 Mdot
.696 .50213 Mdot
.696 .50254 Mdot
.696 .5027 Mdot
.696 .50289 Mdot
.696 .5044 Mdot
.696 .5047 Mdot
.696 .50628 Mdot
.696 .5077 Mdot
.696 .50786 Mdot
.696 .50789 Mdot
.696 .50793 Mdot
.696 .50858 Mdot
.696 .50952 Mdot
.696 .50998 Mdot
.696 .51014 Mdot
.696 .51028 Mdot
.696 .51064 Mdot
.696 .51066 Mdot
.696 .51073 Mdot
.696 .51105 Mdot
.696 .51112 Mdot
.696 .51135 Mdot
.696 .51166 Mdot
.696 .51199 Mdot
.696 .51298 Mdot
.696 .51356 Mdot
.696 .51358 Mdot
.696 .51359 Mdot
.696 .51388 Mdot
.696 .51463 Mdot
.696 .51474 Mdot
.696 .5151 Mdot
.696 .51549 Mdot
.696 .51562 Mdot
.696 .51605 Mdot
.696 .5161 Mdot
.696 .51622 Mdot
.696 .51632 Mdot
.696 .51658 Mdot
.696 .51677 Mdot
.696 .51701 Mdot
.696 .5175 Mdot
.696 .51768 Mdot
.696 .51797 Mdot
.696 .51861 Mdot
.696 .51903 Mdot
.696 .51903 Mdot
.696 .51928 Mdot
.696 .51947 Mdot
.696 .51952 Mdot
.696 .51974 Mdot
.696 .52006 Mdot
.696 .52104 Mdot
.696 .52185 Mdot
.696 .52191 Mdot
.696 .52192 Mdot
.696 .52213 Mdot
.696 .52245 Mdot
.696 .52259 Mdot
.696 .52315 Mdot
.696 .52323 Mdot
.696 .5235 Mdot
.696 .52363 Mdot
.696 .52438 Mdot
.696 .52467 Mdot
.696 .52501 Mdot
.696 .52502 Mdot
.696 .52508 Mdot
.696 .5254 Mdot
.696 .52574 Mdot
.696 .52581 Mdot
.696 .5261 Mdot
.696 .52615 Mdot
.696 .52643 Mdot
.696 .52645 Mdot
.696 .52655 Mdot
.696 .52658 Mdot
.696 .52665 Mdot
.696 .52667 Mdot
.696 .52671 Mdot
.696 .52677 Mdot
.696 .52686 Mdot
.696 .527 Mdot
.696 .52751 Mdot
.696 .52754 Mdot
.696 .52781 Mdot
.696 .52787 Mdot
.696 .52804 Mdot
.696 .52814 Mdot
.696 .52818 Mdot
.696 .52821 Mdot
.696 .52823 Mdot
.696 .52833 Mdot
.696 .52835 Mdot
.696 .52835 Mdot
.696 .52837 Mdot
.696 .52839 Mdot
.696 .52839 Mdot
.696 .52902 Mdot
.696 .53069 Mdot
.696 .53106 Mdot
.696 .53107 Mdot
.696 .53111 Mdot
.696 .53123 Mdot
.696 .53153 Mdot
.696 .53264 Mdot
.696 .53268 Mdot
.696 .53288 Mdot
.696 .53296 Mdot
.696 .53372 Mdot
.696 .5342 Mdot
.696 .53523 Mdot
.696 .53528 Mdot
.696 .53716 Mdot
.696 .5378 Mdot
.696 .53781 Mdot
.696 .53794 Mdot
.696 .53853 Mdot
.696 .53882 Mdot
.696 .53933 Mdot
.696 .54047 Mdot
.696 .54159 Mdot
.696 .54174 Mdot
.696 .54258 Mdot
.696 .54326 Mdot
.696 .54334 Mdot
.696 .54351 Mdot
.696 .54397 Mdot
.696 .54405 Mdot
.696 .54417 Mdot
.696 .54491 Mdot
.696 .54623 Mdot
.696 .54643 Mdot
.696 .54657 Mdot
.696 .54667 Mdot
.696 .54681 Mdot
.696 .54706 Mdot
.696 .5473 Mdot
.696 .54738 Mdot
.696 .54739 Mdot
.696 .54743 Mdot
.696 .54814 Mdot
.696 .54825 Mdot
.696 .54833 Mdot
.696 .54898 Mdot
.696 .55068 Mdot
.696 .55132 Mdot
.696 .55164 Mdot
.696 .5517 Mdot
.696 .55242 Mdot
.696 .55243 Mdot
.696 .55247 Mdot
.696 .55249 Mdot
.696 .5525 Mdot
.696 .55253 Mdot
.696 .55271 Mdot
.696 .55274 Mdot
.696 .5528 Mdot
.696 .55286 Mdot
.696 .55303 Mdot
.696 .55332 Mdot
.696 .55341 Mdot
.696 .55383 Mdot
.696 .55386 Mdot
.696 .55392 Mdot
.696 .55418 Mdot
.696 .55433 Mdot
.696 .55446 Mdot
.696 .55474 Mdot
.696 .55484 Mdot
.696 .55497 Mdot
.696 .55506 Mdot
.696 .55511 Mdot
.696 .5552 Mdot
.696 .55527 Mdot
.696 .5553 Mdot
.696 .55541 Mdot
.696 .55545 Mdot
.696 .5556 Mdot
.696 .55563 Mdot
.696 .55564 Mdot
.696 .55606 Mdot
.696 .55613 Mdot
.696 .55656 Mdot
.696 .55667 Mdot
.696 .55715 Mdot
.696 .55735 Mdot
.696 .5575 Mdot
.696 .55761 Mdot
.696 .55768 Mdot
.696 .55769 Mdot
.696 .55779 Mdot
.696 .55808 Mdot
.696 .55816 Mdot
.696 .55816 Mdot
.696 .55818 Mdot
.696 .55832 Mdot
.696 .55855 Mdot
.696 .55872 Mdot
.696 .559 Mdot
.696 .55944 Mdot
.696 .55951 Mdot
.696 .55967 Mdot
.696 .56 Mdot
.696 .5601 Mdot
.696 .5607 Mdot
.696 .56074 Mdot
.696 .5609 Mdot
.696 .56115 Mdot
.696 .56124 Mdot
.696 .56125 Mdot
.696 .56148 Mdot
.696 .56149 Mdot
.696 .56155 Mdot
.696 .56169 Mdot
.696 .56183 Mdot
.696 .56189 Mdot
.696 .56192 Mdot
.696 .56216 Mdot
.696 .56222 Mdot
.696 .56238 Mdot
.696 .56249 Mdot
.696 .5625 Mdot
.696 .56254 Mdot
.696 .563 Mdot
.696 .56302 Mdot
.696 .56324 Mdot
.696 .56329 Mdot
.696 .56357 Mdot
.696 .56363 Mdot
.696 .56376 Mdot
.696 .5638 Mdot
.696 .5638 Mdot
.696 .5639 Mdot
.696 .56396 Mdot
.696 .56416 Mdot
.696 .56416 Mdot
.696 .56421 Mdot
.696 .56447 Mdot
.696 .56448 Mdot
.696 .56483 Mdot
.696 .56485 Mdot
.696 .56485 Mdot
.696 .56494 Mdot
.696 .56511 Mdot
.696 .56513 Mdot
.696 .5652 Mdot
.696 .56525 Mdot
.696 .56532 Mdot
.696 .56556 Mdot
.696 .56569 Mdot
.696 .5658 Mdot
.696 .56594 Mdot
.696 .566 Mdot
.696 .56606 Mdot
.696 .56609 Mdot
.696 .56612 Mdot
.696 .56626 Mdot
.696 .56629 Mdot
.696 .56635 Mdot
.696 .56653 Mdot
.696 .56667 Mdot
.696 .56671 Mdot
.696 .56687 Mdot
.696 .56698 Mdot
.696 .56706 Mdot
.696 .56706 Mdot
.696 .56707 Mdot
.696 .56722 Mdot
.696 .56726 Mdot
.696 .56729 Mdot
.696 .5673 Mdot
.696 .5673 Mdot
.696 .56741 Mdot
.696 .56741 Mdot
.696 .56745 Mdot
.696 .56748 Mdot
.696 .5675 Mdot
.696 .56751 Mdot
.696 .56751 Mdot
.696 .56752 Mdot
.696 .56753 Mdot
.696 .56753 Mdot
.696 .56753 Mdot
.696 .56753 Mdot
.696 .56753 Mdot
.698 .14028 Mdot
.698 .14029 Mdot
.698 .14032 Mdot
.698 .14034 Mdot
.698 .14039 Mdot
.698 .14039 Mdot
.698 .14051 Mdot
.698 .14053 Mdot
.698 .14057 Mdot
.698 .14063 Mdot
.698 .14066 Mdot
.698 .14082 Mdot
.698 .14099 Mdot
.698 .14099 Mdot
.698 .14105 Mdot
.698 .1411 Mdot
.698 .14126 Mdot
.698 .14149 Mdot
.698 .1415 Mdot
.698 .14184 Mdot
.698 .14186 Mdot
.698 .14208 Mdot
.698 .14212 Mdot
.698 .14262 Mdot
.698 .14275 Mdot
.698 .14304 Mdot
.698 .14311 Mdot
.698 .1432 Mdot
.698 .1434 Mdot
.698 .1438 Mdot
.698 .14416 Mdot
.698 .14422 Mdot
.698 .14454 Mdot
.698 .14473 Mdot
.698 .14502 Mdot
.698 .14505 Mdot
.698 .1452 Mdot
.698 .14549 Mdot
.698 .14639 Mdot
.698 .14666 Mdot
.698 .14688 Mdot
.698 .14694 Mdot
.698 .14714 Mdot
.698 .14744 Mdot
.698 .14824 Mdot
.698 .14842 Mdot
.698 .14854 Mdot
.698 .14863 Mdot
.698 .1492 Mdot
.698 .14946 Mdot
.698 .14949 Mdot
.698 .14972 Mdot
.698 .1505 Mdot
.698 .15083 Mdot
.698 .15108 Mdot
.698 .15116 Mdot
.698 .15189 Mdot
.698 .15203 Mdot
.698 .15208 Mdot
.698 .15226 Mdot
.698 .153 Mdot
.698 .15327 Mdot
.698 .15408 Mdot
.698 .15529 Mdot
.698 .1554 Mdot
.698 .15545 Mdot
.698 .15558 Mdot
.698 .15627 Mdot
.698 .15646 Mdot
.698 .15665 Mdot
.698 .15685 Mdot
.698 .15734 Mdot
.698 .15769 Mdot
.698 .15817 Mdot
.698 .15856 Mdot
.698 .15905 Mdot
.698 .16041 Mdot
.698 .16095 Mdot
.698 .16236 Mdot
.698 .16259 Mdot
.698 .16287 Mdot
.698 .16293 Mdot
.698 .16397 Mdot
.698 .16418 Mdot
.698 .16423 Mdot
.698 .16427 Mdot
.698 .16597 Mdot
.698 .16674 Mdot
.698 .16678 Mdot
.698 .16713 Mdot
.698 .16744 Mdot
.698 .16768 Mdot
.698 .16768 Mdot
.698 .16819 Mdot
.698 .16929 Mdot
.698 .17018 Mdot
.698 .17142 Mdot
.698 .17181 Mdot
.698 .17186 Mdot
.698 .17296 Mdot
.698 .17323 Mdot
.698 .17391 Mdot
.698 .17486 Mdot
.698 .17575 Mdot
.698 .17635 Mdot
.698 .17678 Mdot
.698 .17694 Mdot
.698 .17747 Mdot
.698 .1787 Mdot
.698 .17889 Mdot
.698 .17892 Mdot
.698 .17913 Mdot
.698 .17914 Mdot
.698 .1792 Mdot
.698 .17933 Mdot
.698 .17934 Mdot
.698 .18302 Mdot
.698 .18312 Mdot
.698 .18344 Mdot
.698 .18566 Mdot
.698 .18692 Mdot
.698 .18752 Mdot
.698 .18764 Mdot
.698 .18812 Mdot
.698 .18878 Mdot
.698 .18886 Mdot
.698 .18924 Mdot
.698 .19046 Mdot
.698 .19083 Mdot
.698 .19165 Mdot
.698 .19268 Mdot
.698 .19312 Mdot
.698 .19386 Mdot
.698 .19398 Mdot
.698 .19416 Mdot
.698 .19429 Mdot
.698 .19447 Mdot
.698 .19503 Mdot
.698 .19596 Mdot
.698 .19605 Mdot
.698 .19659 Mdot
.698 .19685 Mdot
.698 .19687 Mdot
.698 .19727 Mdot
.698 .19737 Mdot
.698 .19912 Mdot
.698 .19981 Mdot
.698 .20052 Mdot
.698 .20055 Mdot
.698 .20063 Mdot
.698 .20241 Mdot
.698 .20263 Mdot
.698 .20274 Mdot
.698 .20377 Mdot
.698 .20379 Mdot
.698 .2047 Mdot
.698 .20483 Mdot
.698 .20532 Mdot
.698 .20784 Mdot
.698 .20787 Mdot
.698 .20851 Mdot
.698 .20915 Mdot
.698 .20937 Mdot
.698 .20963 Mdot
.698 .21172 Mdot
.698 .21221 Mdot
.698 .21447 Mdot
.698 .21528 Mdot
.698 .21582 Mdot
.698 .2162 Mdot
.698 .21717 Mdot
.698 .21721 Mdot
.698 .21794 Mdot
.698 .21995 Mdot
.698 .22052 Mdot
.698 .22194 Mdot
.698 .22302 Mdot
.698 .22442 Mdot
.698 .22493 Mdot
.698 .22538 Mdot
.698 .2254 Mdot
.698 .22609 Mdot
.698 .22622 Mdot
.698 .23147 Mdot
.698 .23166 Mdot
.698 .23511 Mdot
.698 .24342 Mdot
.698 .24348 Mdot
.698 .24395 Mdot
.698 .24716 Mdot
.698 .24774 Mdot
.698 .24951 Mdot
.698 .2512 Mdot
.698 .25305 Mdot
.698 .25452 Mdot
.698 .25607 Mdot
.698 .25611 Mdot
.698 .25631 Mdot
.698 .25632 Mdot
.698 .25644 Mdot
.698 .2567 Mdot
.698 .25675 Mdot
.698 .2572 Mdot
.698 .25748 Mdot
.698 .25756 Mdot
.698 .25772 Mdot
.698 .25778 Mdot
.698 .25815 Mdot
.698 .25836 Mdot
.698 .2593 Mdot
.698 .25949 Mdot
.698 .26031 Mdot
.698 .26035 Mdot
.698 .26069 Mdot
.698 .261 Mdot
.698 .26199 Mdot
.698 .26336 Mdot
.698 .26341 Mdot
.698 .26547 Mdot
.698 .26559 Mdot
.698 .2657 Mdot
.698 .26695 Mdot
.698 .26721 Mdot
.698 .26867 Mdot
.698 .26926 Mdot
.698 .26994 Mdot
.698 .26998 Mdot
.698 .27022 Mdot
.698 .27102 Mdot
.698 .27267 Mdot
.698 .27283 Mdot
.698 .27304 Mdot
.698 .27328 Mdot
.698 .27331 Mdot
.698 .27384 Mdot
.698 .27504 Mdot
.698 .27507 Mdot
.698 .2751 Mdot
.698 .27626 Mdot
.698 .27644 Mdot
.698 .27751 Mdot
.698 .27793 Mdot
.698 .27972 Mdot
.698 .28013 Mdot
.698 .28084 Mdot
.698 .28117 Mdot
.698 .28134 Mdot
.698 .28195 Mdot
.698 .28207 Mdot
.698 .28211 Mdot
.698 .28332 Mdot
.698 .28436 Mdot
.698 .28508 Mdot
.698 .28527 Mdot
.698 .28532 Mdot
.698 .28546 Mdot
.698 .28622 Mdot
.698 .28656 Mdot
.698 .28778 Mdot
.698 .28805 Mdot
.698 .28952 Mdot
.698 .29053 Mdot
.698 .29127 Mdot
.698 .29157 Mdot
.698 .2937 Mdot
.698 .29541 Mdot
.698 .29681 Mdot
.698 .29719 Mdot
.698 .29738 Mdot
.698 .29753 Mdot
.698 .29844 Mdot
.698 .29961 Mdot
.698 .29972 Mdot
.698 .30031 Mdot
.698 .30036 Mdot
.698 .3027 Mdot
.698 .30387 Mdot
.698 .30522 Mdot
.698 .30545 Mdot
.698 .30554 Mdot
.698 .30658 Mdot
.698 .30733 Mdot
.698 .30789 Mdot
.698 .30808 Mdot
.698 .31099 Mdot
.698 .31152 Mdot
.698 .31318 Mdot
.698 .31338 Mdot
.698 .31488 Mdot
.698 .31491 Mdot
.698 .31513 Mdot
.698 .31591 Mdot
.698 .31665 Mdot
.698 .31668 Mdot
.698 .31988 Mdot
.698 .32198 Mdot
.698 .32273 Mdot
.698 .32327 Mdot
.698 .32359 Mdot
.698 .32405 Mdot
.698 .32411 Mdot
.698 .32478 Mdot
.698 .32609 Mdot
.698 .32684 Mdot
.698 .32711 Mdot
.698 .32873 Mdot
.698 .32887 Mdot
.698 .32898 Mdot
.698 .32965 Mdot
.698 .32995 Mdot
.698 .33112 Mdot
.698 .33174 Mdot
.698 .33395 Mdot
.698 .33582 Mdot
.698 .33703 Mdot
.698 .33761 Mdot
.698 .33863 Mdot
.698 .33903 Mdot
.698 .34197 Mdot
.698 .34202 Mdot
.698 .34278 Mdot
.698 .34536 Mdot
.698 .34571 Mdot
.698 .34643 Mdot
.698 .34894 Mdot
.698 .35047 Mdot
.698 .35117 Mdot
.698 .35149 Mdot
.698 .3522 Mdot
.698 .35231 Mdot
.698 .35245 Mdot
.698 .35249 Mdot
.698 .35256 Mdot
.698 .35485 Mdot
.698 .35672 Mdot
.698 .35709 Mdot
.698 .35792 Mdot
.698 .35915 Mdot
.698 .3604 Mdot
.698 .3628 Mdot
.698 .36313 Mdot
.698 .36346 Mdot
.698 .36348 Mdot
.698 .36434 Mdot
.698 .36445 Mdot
.698 .3645 Mdot
.698 .36497 Mdot
.698 .36537 Mdot
.698 .3654 Mdot
.698 .36545 Mdot
.698 .36568 Mdot
.698 .36681 Mdot
.698 .36711 Mdot
.698 .3674 Mdot
.698 .36749 Mdot
.698 .36761 Mdot
.698 .36874 Mdot
.698 .36972 Mdot
.698 .37007 Mdot
.698 .37046 Mdot
.698 .37088 Mdot
.698 .37119 Mdot
.698 .37203 Mdot
.698 .37228 Mdot
.698 .37286 Mdot
.698 .3733 Mdot
.698 .37388 Mdot
.698 .37427 Mdot
.698 .37428 Mdot
.698 .37671 Mdot
.698 .37678 Mdot
.698 .37813 Mdot
.698 .38131 Mdot
.698 .38133 Mdot
.698 .38151 Mdot
.698 .38271 Mdot
.698 .38358 Mdot
.698 .3842 Mdot
.698 .38487 Mdot
.698 .38541 Mdot
.698 .38597 Mdot
.698 .38598 Mdot
.698 .38605 Mdot
.698 .38606 Mdot
.698 .3861 Mdot
.698 .38619 Mdot
.698 .38621 Mdot
.698 .38647 Mdot
.698 .3865 Mdot
.698 .38658 Mdot
.698 .38671 Mdot
.698 .38679 Mdot
.698 .38713 Mdot
.698 .38719 Mdot
.698 .38749 Mdot
.698 .3875 Mdot
.698 .38762 Mdot
.698 .38773 Mdot
.698 .38808 Mdot
.698 .38857 Mdot
.698 .38859 Mdot
.698 .38931 Mdot
.698 .38935 Mdot
.698 .38939 Mdot
.698 .38983 Mdot
.698 .38992 Mdot
.698 .39043 Mdot
.698 .39063 Mdot
.698 .39087 Mdot
.698 .39088 Mdot
.698 .39097 Mdot
.698 .39124 Mdot
.698 .39187 Mdot
.698 .39202 Mdot
.698 .39203 Mdot
.698 .39221 Mdot
.698 .39263 Mdot
.698 .39305 Mdot
.698 .39347 Mdot
.698 .39422 Mdot
.698 .39436 Mdot
.698 .3946 Mdot
.698 .39471 Mdot
.698 .39477 Mdot
.698 .39498 Mdot
.698 .39503 Mdot
.698 .39544 Mdot
.698 .39578 Mdot
.698 .39603 Mdot
.698 .39611 Mdot
.698 .39616 Mdot
.698 .39641 Mdot
.698 .39652 Mdot
.698 .39693 Mdot
.698 .39702 Mdot
.698 .39784 Mdot
.698 .39819 Mdot
.698 .39889 Mdot
.698 .39945 Mdot
.698 .39991 Mdot
.698 .40004 Mdot
.698 .40015 Mdot
.698 .40044 Mdot
.698 .40105 Mdot
.698 .40107 Mdot
.698 .40264 Mdot
.698 .40272 Mdot
.698 .40308 Mdot
.698 .40332 Mdot
.698 .40351 Mdot
.698 .4045 Mdot
.698 .40467 Mdot
.698 .4052 Mdot
.698 .40527 Mdot
.698 .40574 Mdot
.698 .40575 Mdot
.698 .40607 Mdot
.698 .40631 Mdot
.698 .40733 Mdot
.698 .408 Mdot
.698 .40823 Mdot
.698 .4085 Mdot
.698 .40865 Mdot
.698 .40929 Mdot
.698 .40961 Mdot
.698 .41012 Mdot
.698 .41041 Mdot
.698 .4105 Mdot
.698 .41087 Mdot
.698 .41106 Mdot
.698 .41175 Mdot
.698 .41233 Mdot
.698 .41289 Mdot
.698 .41449 Mdot
.698 .4164 Mdot
.698 .41687 Mdot
.698 .41709 Mdot
.698 .41718 Mdot
.698 .41744 Mdot
.698 .41749 Mdot
.698 .41879 Mdot
.698 .41916 Mdot
.698 .41954 Mdot
.698 .41992 Mdot
.698 .42086 Mdot
.698 .42087 Mdot
.698 .42113 Mdot
.698 .42132 Mdot
.698 .42145 Mdot
.698 .42147 Mdot
.698 .42154 Mdot
.698 .42189 Mdot
.698 .4221 Mdot
.698 .42213 Mdot
.698 .42248 Mdot
.698 .42278 Mdot
.698 .42288 Mdot
.698 .42313 Mdot
.698 .42323 Mdot
.698 .42349 Mdot
.698 .42417 Mdot
.698 .42494 Mdot
.698 .42632 Mdot
.698 .42633 Mdot
.698 .42675 Mdot
.698 .42702 Mdot
.698 .42741 Mdot
.698 .42777 Mdot
.698 .42812 Mdot
.698 .42911 Mdot
.698 .42925 Mdot
.698 .42961 Mdot
.698 .43043 Mdot
.698 .43045 Mdot
.698 .43076 Mdot
.698 .43087 Mdot
.698 .43098 Mdot
.698 .43139 Mdot
.698 .43149 Mdot
.698 .4321 Mdot
.698 .43287 Mdot
.698 .43344 Mdot
.698 .43382 Mdot
.698 .43392 Mdot
.698 .43399 Mdot
.698 .43546 Mdot
.698 .43568 Mdot
.698 .43712 Mdot
.698 .43746 Mdot
.698 .43851 Mdot
.698 .43859 Mdot
.698 .43865 Mdot
.698 .43922 Mdot
.698 .43978 Mdot
.698 .44022 Mdot
.698 .44022 Mdot
.698 .44044 Mdot
.698 .44078 Mdot
.698 .44114 Mdot
.698 .44152 Mdot
.698 .44161 Mdot
.698 .44204 Mdot
.698 .44311 Mdot
.698 .44374 Mdot
.698 .44469 Mdot
.698 .44504 Mdot
.698 .4452 Mdot
.698 .44575 Mdot
.698 .4464 Mdot
.698 .44688 Mdot
.698 .44725 Mdot
.698 .44756 Mdot
.698 .44766 Mdot
.698 .44839 Mdot
.698 .44934 Mdot
.698 .44958 Mdot
.698 .44963 Mdot
.698 .45004 Mdot
.698 .45023 Mdot
.698 .45122 Mdot
.698 .45187 Mdot
.698 .45285 Mdot
.698 .45296 Mdot
.698 .45437 Mdot
.698 .45478 Mdot
.698 .45538 Mdot
.698 .4555 Mdot
.698 .45567 Mdot
.698 .45611 Mdot
.698 .4563 Mdot
.698 .45637 Mdot
.698 .4569 Mdot
.698 .45728 Mdot
.698 .45749 Mdot
.698 .45785 Mdot
.698 .45785 Mdot
.698 .45858 Mdot
.698 .45934 Mdot
.698 .45952 Mdot
.698 .45965 Mdot
.698 .45971 Mdot
.698 .46004 Mdot
.698 .46006 Mdot
.698 .46017 Mdot
.698 .46038 Mdot
.698 .46039 Mdot
.698 .46046 Mdot
.698 .46056 Mdot
.698 .46069 Mdot
.698 .46243 Mdot
.698 .46298 Mdot
.698 .46533 Mdot
.698 .46568 Mdot
.698 .4664 Mdot
.698 .46656 Mdot
.698 .46708 Mdot
.698 .46803 Mdot
.698 .46815 Mdot
.698 .46831 Mdot
.698 .46892 Mdot
.698 .46983 Mdot
.698 .4706 Mdot
.698 .47104 Mdot
.698 .47198 Mdot
.698 .47215 Mdot
.698 .47259 Mdot
.698 .47278 Mdot
.698 .47296 Mdot
.698 .47313 Mdot
.698 .47352 Mdot
.698 .47362 Mdot
.698 .47364 Mdot
.698 .4737 Mdot
.698 .47443 Mdot
.698 .47491 Mdot
.698 .47546 Mdot
.698 .47546 Mdot
.698 .47557 Mdot
.698 .47567 Mdot
.698 .47616 Mdot
.698 .47718 Mdot
.698 .47771 Mdot
.698 .47801 Mdot
.698 .47826 Mdot
.698 .47857 Mdot
.698 .47886 Mdot
.698 .47926 Mdot
.698 .47981 Mdot
.698 .47989 Mdot
.698 .4799 Mdot
.698 .48135 Mdot
.698 .48196 Mdot
.698 .482 Mdot
.698 .48309 Mdot
.698 .4831 Mdot
.698 .48327 Mdot
.698 .48353 Mdot
.698 .48373 Mdot
.698 .48399 Mdot
.698 .4841 Mdot
.698 .48448 Mdot
.698 .48461 Mdot
.698 .4848 Mdot
.698 .48498 Mdot
.698 .48513 Mdot
.698 .48557 Mdot
.698 .48607 Mdot
.698 .48612 Mdot
.698 .48616 Mdot
.698 .48629 Mdot
.698 .48642 Mdot
.698 .48692 Mdot
.698 .48702 Mdot
.698 .48704 Mdot
.698 .48705 Mdot
.698 .48723 Mdot
.698 .48744 Mdot
.698 .48746 Mdot
.698 .48751 Mdot
.698 .48788 Mdot
.698 .48789 Mdot
.698 .48804 Mdot
.698 .48818 Mdot
.698 .48923 Mdot
.698 .48977 Mdot
.698 .4903 Mdot
.698 .49066 Mdot
.698 .49082 Mdot
.698 .49162 Mdot
.698 .4926 Mdot
.698 .49263 Mdot
.698 .49265 Mdot
.698 .49271 Mdot
.698 .49276 Mdot
.698 .49306 Mdot
.698 .49319 Mdot
.698 .49349 Mdot
.698 .49414 Mdot
.698 .4952 Mdot
.698 .4955 Mdot
.698 .49565 Mdot
.698 .49673 Mdot
.698 .49705 Mdot
.698 .49706 Mdot
.698 .49829 Mdot
.698 .49845 Mdot
.698 .49887 Mdot
.698 .49911 Mdot
.698 .49961 Mdot
.698 .50038 Mdot
.698 .50128 Mdot
.698 .50153 Mdot
.698 .50201 Mdot
.698 .50213 Mdot
.698 .5024 Mdot
.698 .50244 Mdot
.698 .5025 Mdot
.698 .50316 Mdot
.698 .50326 Mdot
.698 .50357 Mdot
.698 .50409 Mdot
.698 .50436 Mdot
.698 .50438 Mdot
.698 .50457 Mdot
.698 .5047 Mdot
.698 .50491 Mdot
.698 .50521 Mdot
.698 .50605 Mdot
.698 .50732 Mdot
.698 .50733 Mdot
.698 .50762 Mdot
.698 .50793 Mdot
.698 .50802 Mdot
.698 .50803 Mdot
.698 .50861 Mdot
.698 .50869 Mdot
.698 .50934 Mdot
.698 .50955 Mdot
.698 .51068 Mdot
.698 .51076 Mdot
.698 .51098 Mdot
.698 .51127 Mdot
.698 .51167 Mdot
.698 .5117 Mdot
.698 .51179 Mdot
.698 .51231 Mdot
.698 .51276 Mdot
.698 .51366 Mdot
.698 .51368 Mdot
.698 .5139 Mdot
.698 .51395 Mdot
.698 .51439 Mdot
.698 .51474 Mdot
.698 .5148 Mdot
.698 .51487 Mdot
.698 .51501 Mdot
.698 .51554 Mdot
.698 .51619 Mdot
.698 .517 Mdot
.698 .51711 Mdot
.698 .51739 Mdot
.698 .51777 Mdot
.698 .51832 Mdot
.698 .51842 Mdot
.698 .51887 Mdot
.698 .519 Mdot
.698 .51928 Mdot
.698 .51934 Mdot
.698 .51936 Mdot
.698 .51942 Mdot
.698 .51969 Mdot
.698 .52008 Mdot
.698 .52053 Mdot
.698 .52054 Mdot
.698 .52059 Mdot
.698 .52081 Mdot
.698 .52087 Mdot
.698 .521 Mdot
.698 .52126 Mdot
.698 .52141 Mdot
.698 .52207 Mdot
.698 .52222 Mdot
.698 .52262 Mdot
.698 .52268 Mdot
.698 .52311 Mdot
.698 .52312 Mdot
.698 .52313 Mdot
.698 .52357 Mdot
.698 .52376 Mdot
.698 .52377 Mdot
.698 .52386 Mdot
.698 .52394 Mdot
.698 .52399 Mdot
.698 .52459 Mdot
.698 .52488 Mdot
.698 .52497 Mdot
.698 .52498 Mdot
.698 .52523 Mdot
.698 .52545 Mdot
.698 .52597 Mdot
.698 .52607 Mdot
.698 .52652 Mdot
.698 .52656 Mdot
.698 .5266 Mdot
.698 .52734 Mdot
.698 .52736 Mdot
.698 .52785 Mdot
.698 .5282 Mdot
.698 .52831 Mdot
.698 .52844 Mdot
.698 .52845 Mdot
.698 .52874 Mdot
.698 .52881 Mdot
.698 .52914 Mdot
.698 .52922 Mdot
.698 .52935 Mdot
.698 .52937 Mdot
.698 .52943 Mdot
.698 .52946 Mdot
.698 .52956 Mdot
.698 .52972 Mdot
.698 .52973 Mdot
.698 .52983 Mdot
.698 .52987 Mdot
.698 .52987 Mdot
.698 .52994 Mdot
.698 .52996 Mdot
.698 .53051 Mdot
.698 .53102 Mdot
.698 .53168 Mdot
.698 .53227 Mdot
.698 .53289 Mdot
.698 .53309 Mdot
.698 .53421 Mdot
.698 .53438 Mdot
.698 .5344 Mdot
.698 .53727 Mdot
.698 .53845 Mdot
.698 .53851 Mdot
.698 .5403 Mdot
.698 .54034 Mdot
.698 .54057 Mdot
.698 .54058 Mdot
.698 .54073 Mdot
.698 .5409 Mdot
.698 .54138 Mdot
.698 .54174 Mdot
.698 .54222 Mdot
.698 .54241 Mdot
.698 .54308 Mdot
.698 .54333 Mdot
.698 .54334 Mdot
.698 .54366 Mdot
.698 .54379 Mdot
.698 .54397 Mdot
.698 .54424 Mdot
.698 .54499 Mdot
.698 .54516 Mdot
.698 .54585 Mdot
.698 .54593 Mdot
.698 .546 Mdot
.698 .54622 Mdot
.698 .54643 Mdot
.698 .54644 Mdot
.698 .54727 Mdot
.698 .54743 Mdot
.698 .54747 Mdot
.698 .54777 Mdot
.698 .54777 Mdot
.698 .54811 Mdot
.698 .54815 Mdot
.698 .54822 Mdot
.698 .5488 Mdot
.698 .54883 Mdot
.698 .54884 Mdot
.698 .54907 Mdot
.698 .54929 Mdot
.698 .54986 Mdot
.698 .5499 Mdot
.698 .55003 Mdot
.698 .55003 Mdot
.698 .55012 Mdot
.698 .55029 Mdot
.698 .55032 Mdot
.698 .55063 Mdot
.698 .55081 Mdot
.698 .55086 Mdot
.698 .55091 Mdot
.698 .55096 Mdot
.698 .551 Mdot
.698 .55124 Mdot
.698 .55139 Mdot
.698 .55172 Mdot
.698 .55198 Mdot
.698 .5521 Mdot
.698 .5525 Mdot
.698 .55262 Mdot
.698 .55264 Mdot
.698 .55286 Mdot
.698 .55301 Mdot
.698 .55305 Mdot
.698 .55324 Mdot
.698 .55364 Mdot
.698 .55435 Mdot
.698 .55446 Mdot
.698 .55449 Mdot
.698 .55566 Mdot
.698 .55566 Mdot
.698 .5557 Mdot
.698 .55572 Mdot
.698 .55573 Mdot
.698 .55579 Mdot
.698 .5558 Mdot
.698 .55586 Mdot
.698 .55625 Mdot
.698 .55642 Mdot
.698 .55647 Mdot
.698 .55661 Mdot
.698 .55679 Mdot
.698 .55738 Mdot
.698 .55759 Mdot
.698 .55767 Mdot
.698 .55802 Mdot
.698 .55804 Mdot
.698 .55816 Mdot
.698 .55855 Mdot
.698 .55883 Mdot
.698 .55917 Mdot
.698 .55933 Mdot
.698 .55933 Mdot
.698 .55941 Mdot
.698 .5595 Mdot
.698 .55961 Mdot
.698 .55963 Mdot
.698 .55987 Mdot
.698 .5604 Mdot
.698 .56041 Mdot
.698 .56042 Mdot
.698 .56049 Mdot
.698 .56081 Mdot
.698 .56083 Mdot
.698 .56092 Mdot
.698 .56099 Mdot
.698 .56143 Mdot
.698 .5616 Mdot
.698 .56202 Mdot
.698 .56217 Mdot
.698 .56229 Mdot
.698 .56244 Mdot
.698 .56255 Mdot
.698 .5627 Mdot
.698 .56276 Mdot
.698 .56282 Mdot
.698 .56288 Mdot
.698 .56309 Mdot
.698 .56313 Mdot
.698 .56314 Mdot
.698 .56318 Mdot
.698 .56355 Mdot
.698 .5638 Mdot
.698 .56388 Mdot
.698 .56411 Mdot
.698 .56417 Mdot
.698 .56418 Mdot
.698 .56422 Mdot
.698 .56445 Mdot
.698 .56447 Mdot
.698 .56455 Mdot
.698 .56465 Mdot
.698 .56489 Mdot
.698 .56496 Mdot
.698 .56497 Mdot
.698 .56505 Mdot
.698 .56522 Mdot
.698 .56525 Mdot
.698 .56529 Mdot
.698 .56534 Mdot
.698 .56559 Mdot
.698 .56568 Mdot
.698 .56574 Mdot
.698 .56576 Mdot
.698 .56582 Mdot
.698 .56591 Mdot
.698 .56618 Mdot
.698 .56627 Mdot
.698 .56631 Mdot
.698 .56632 Mdot
.698 .56641 Mdot
.698 .56647 Mdot
.698 .56657 Mdot
.698 .56659 Mdot
.698 .56669 Mdot
.698 .56682 Mdot
.698 .56688 Mdot
.698 .5669 Mdot
.698 .56692 Mdot
.698 .56701 Mdot
.698 .56705 Mdot
.698 .5672 Mdot
.698 .56722 Mdot
.698 .56728 Mdot
.698 .56729 Mdot
.698 .56739 Mdot
.698 .5674 Mdot
.698 .56746 Mdot
.698 .56751 Mdot
.698 .56753 Mdot
.698 .56755 Mdot
.698 .56755 Mdot
.698 .5676 Mdot
.698 .56765 Mdot
.698 .56766 Mdot
.698 .56768 Mdot
.698 .56769 Mdot
.698 .56769 Mdot
.698 .56773 Mdot
.698 .56773 Mdot
.698 .56774 Mdot
.698 .56775 Mdot
.698 .56776 Mdot
.698 .56776 Mdot
.7 .13954 Mdot
.7 .13954 Mdot
.7 .13958 Mdot
.7 .13967 Mdot
.7 .13979 Mdot
.7 .1399 Mdot
.7 .13999 Mdot
.7 .14001 Mdot
.7 .14002 Mdot
.7 .14013 Mdot
.7 .14018 Mdot
.7 .14029 Mdot
.7 .14045 Mdot
.7 .14051 Mdot
.7 .14086 Mdot
.7 .14088 Mdot
.7 .14103 Mdot
.7 .14114 Mdot
.7 .14145 Mdot
.7 .14161 Mdot
.7 .14162 Mdot
.7 .142 Mdot
.7 .14227 Mdot
.7 .14324 Mdot
.7 .14328 Mdot
.7 .14334 Mdot
.7 .14357 Mdot
.7 .14371 Mdot
.7 .14411 Mdot
.7 .1444 Mdot
.7 .14451 Mdot
.7 .14479 Mdot
.7 .14491 Mdot
.7 .14527 Mdot
.7 .14533 Mdot
.7 .14535 Mdot
.7 .14538 Mdot
.7 .14593 Mdot
.7 .14599 Mdot
.7 .14603 Mdot
.7 .14617 Mdot
.7 .14619 Mdot
.7 .14628 Mdot
.7 .14647 Mdot
.7 .14661 Mdot
.7 .14669 Mdot
.7 .147 Mdot
.7 .14742 Mdot
.7 .14875 Mdot
.7 .14878 Mdot
.7 .14918 Mdot
.7 .14933 Mdot
.7 .14954 Mdot
.7 .14962 Mdot
.7 .14965 Mdot
.7 .14982 Mdot
.7 .15002 Mdot
.7 .15034 Mdot
.7 .15048 Mdot
.7 .15088 Mdot
.7 .15098 Mdot
.7 .15151 Mdot
.7 .15156 Mdot
.7 .15206 Mdot
.7 .15221 Mdot
.7 .15288 Mdot
.7 .15299 Mdot
.7 .15359 Mdot
.7 .15364 Mdot
.7 .15382 Mdot
.7 .154 Mdot
.7 .15474 Mdot
.7 .1549 Mdot
.7 .15546 Mdot
.7 .15569 Mdot
.7 .15618 Mdot
.7 .15753 Mdot
.7 .15774 Mdot
.7 .15778 Mdot
.7 .15781 Mdot
.7 .15928 Mdot
.7 .15938 Mdot
.7 .15957 Mdot
.7 .15973 Mdot
.7 .15986 Mdot
.7 .16059 Mdot
.7 .16096 Mdot
.7 .16124 Mdot
.7 .16201 Mdot
.7 .16211 Mdot
.7 .16282 Mdot
.7 .16301 Mdot
.7 .16415 Mdot
.7 .16463 Mdot
.7 .16467 Mdot
.7 .1648 Mdot
.7 .16496 Mdot
.7 .1663 Mdot
.7 .16641 Mdot
.7 .16767 Mdot
.7 .16795 Mdot
.7 .16843 Mdot
.7 .16982 Mdot
.7 .17137 Mdot
.7 .17146 Mdot
.7 .17428 Mdot
.7 .17458 Mdot
.7 .17479 Mdot
.7 .17569 Mdot
.7 .17701 Mdot
.7 .17706 Mdot
.7 .17733 Mdot
.7 .17767 Mdot
.7 .17907 Mdot
.7 .17987 Mdot
.7 .18022 Mdot
.7 .18112 Mdot
.7 .1812 Mdot
.7 .18121 Mdot
.7 .18167 Mdot
.7 .18194 Mdot
.7 .18306 Mdot
.7 .18338 Mdot
.7 .18483 Mdot
.7 .18509 Mdot
.7 .18547 Mdot
.7 .18551 Mdot
.7 .18562 Mdot
.7 .18652 Mdot
.7 .18661 Mdot
.7 .18778 Mdot
.7 .18889 Mdot
.7 .18903 Mdot
.7 .18953 Mdot
.7 .18959 Mdot
.7 .18988 Mdot
.7 .19005 Mdot
.7 .19051 Mdot
.7 .19172 Mdot
.7 .19293 Mdot
.7 .19406 Mdot
.7 .19473 Mdot
.7 .19486 Mdot
.7 .19495 Mdot
.7 .19588 Mdot
.7 .19672 Mdot
.7 .1981 Mdot
.7 .19873 Mdot
.7 .20015 Mdot
.7 .20035 Mdot
.7 .20059 Mdot
.7 .20095 Mdot
.7 .20174 Mdot
.7 .20234 Mdot
.7 .20244 Mdot
.7 .2031 Mdot
.7 .20313 Mdot
.7 .20372 Mdot
.7 .20475 Mdot
.7 .20534 Mdot
.7 .2058 Mdot
.7 .20586 Mdot
.7 .20607 Mdot
.7 .20648 Mdot
.7 .20649 Mdot
.7 .20666 Mdot
.7 .20687 Mdot
.7 .20704 Mdot
.7 .20741 Mdot
.7 .20837 Mdot
.7 .20847 Mdot
.7 .20877 Mdot
.7 .21552 Mdot
.7 .21622 Mdot
.7 .21723 Mdot
.7 .22148 Mdot
.7 .22251 Mdot
.7 .22286 Mdot
.7 .22366 Mdot
.7 .22904 Mdot
.7 .22914 Mdot
.7 .23061 Mdot
.7 .23173 Mdot
.7 .23283 Mdot
.7 .23367 Mdot
.7 .23622 Mdot
.7 .23759 Mdot
.7 .2383 Mdot
.7 .23873 Mdot
.7 .24057 Mdot
.7 .24203 Mdot
.7 .24423 Mdot
.7 .24455 Mdot
.7 .24512 Mdot
.7 .25054 Mdot
.7 .25114 Mdot
.7 .25138 Mdot
.7 .25155 Mdot
.7 .25156 Mdot
.7 .25184 Mdot
.7 .25234 Mdot
.7 .25281 Mdot
.7 .25309 Mdot
.7 .25344 Mdot
.7 .25371 Mdot
.7 .25408 Mdot
.7 .25425 Mdot
.7 .25436 Mdot
.7 .25445 Mdot
.7 .25512 Mdot
.7 .25542 Mdot
.7 .25608 Mdot
.7 .25648 Mdot
.7 .25693 Mdot
.7 .25698 Mdot
.7 .25704 Mdot
.7 .25737 Mdot
.7 .25853 Mdot
.7 .25937 Mdot
.7 .25946 Mdot
.7 .2596 Mdot
.7 .25963 Mdot
.7 .26053 Mdot
.7 .26114 Mdot
.7 .26119 Mdot
.7 .26172 Mdot
.7 .26174 Mdot
.7 .26208 Mdot
.7 .26304 Mdot
.7 .26365 Mdot
.7 .26379 Mdot
.7 .26405 Mdot
.7 .26405 Mdot
.7 .2641 Mdot
.7 .2664 Mdot
.7 .26643 Mdot
.7 .26774 Mdot
.7 .26804 Mdot
.7 .27407 Mdot
.7 .2743 Mdot
.7 .27464 Mdot
.7 .27546 Mdot
.7 .27611 Mdot
.7 .27697 Mdot
.7 .27726 Mdot
.7 .27827 Mdot
.7 .27947 Mdot
.7 .27968 Mdot
.7 .28124 Mdot
.7 .28193 Mdot
.7 .28312 Mdot
.7 .28369 Mdot
.7 .28444 Mdot
.7 .28577 Mdot
.7 .28619 Mdot
.7 .28667 Mdot
.7 .28711 Mdot
.7 .2872 Mdot
.7 .28742 Mdot
.7 .28966 Mdot
.7 .29018 Mdot
.7 .29057 Mdot
.7 .29087 Mdot
.7 .29123 Mdot
.7 .29151 Mdot
.7 .29235 Mdot
.7 .29252 Mdot
.7 .29305 Mdot
.7 .29365 Mdot
.7 .29428 Mdot
.7 .29518 Mdot
.7 .29569 Mdot
.7 .29764 Mdot
.7 .2991 Mdot
.7 .2995 Mdot
.7 .30029 Mdot
.7 .30059 Mdot
.7 .30104 Mdot
.7 .30223 Mdot
.7 .30429 Mdot
.7 .30439 Mdot
.7 .30487 Mdot
.7 .3075 Mdot
.7 .30877 Mdot
.7 .30895 Mdot
.7 .31152 Mdot
.7 .31252 Mdot
.7 .31382 Mdot
.7 .31434 Mdot
.7 .31456 Mdot
.7 .31501 Mdot
.7 .31561 Mdot
.7 .31692 Mdot
.7 .31896 Mdot
.7 .31983 Mdot
.7 .32228 Mdot
.7 .32244 Mdot
.7 .32309 Mdot
.7 .32421 Mdot
.7 .32481 Mdot
.7 .32561 Mdot
.7 .32563 Mdot
.7 .32644 Mdot
.7 .32658 Mdot
.7 .32676 Mdot
.7 .32691 Mdot
.7 .32735 Mdot
.7 .32995 Mdot
.7 .32998 Mdot
.7 .33044 Mdot
.7 .33096 Mdot
.7 .33114 Mdot
.7 .3317 Mdot
.7 .33237 Mdot
.7 .3329 Mdot
.7 .33295 Mdot
.7 .33345 Mdot
.7 .33425 Mdot
.7 .33495 Mdot
.7 .33512 Mdot
.7 .33529 Mdot
.7 .33596 Mdot
.7 .3366 Mdot
.7 .33722 Mdot
.7 .33853 Mdot
.7 .33858 Mdot
.7 .33984 Mdot
.7 .33999 Mdot
.7 .34011 Mdot
.7 .34021 Mdot
.7 .34127 Mdot
.7 .34185 Mdot
.7 .34244 Mdot
.7 .34376 Mdot
.7 .34385 Mdot
.7 .34489 Mdot
.7 .34496 Mdot
.7 .34581 Mdot
.7 .34599 Mdot
.7 .34631 Mdot
.7 .34721 Mdot
.7 .3482 Mdot
.7 .34826 Mdot
.7 .35017 Mdot
.7 .35083 Mdot
.7 .35179 Mdot
.7 .35198 Mdot
.7 .35278 Mdot
.7 .35324 Mdot
.7 .35343 Mdot
.7 .35517 Mdot
.7 .35609 Mdot
.7 .35637 Mdot
.7 .35807 Mdot
.7 .35814 Mdot
.7 .35889 Mdot
.7 .36011 Mdot
.7 .36464 Mdot
.7 .36496 Mdot
.7 .36597 Mdot
.7 .36629 Mdot
.7 .36656 Mdot
.7 .36673 Mdot
.7 .36732 Mdot
.7 .36736 Mdot
.7 .37042 Mdot
.7 .37071 Mdot
.7 .37114 Mdot
.7 .37333 Mdot
.7 .37597 Mdot
.7 .37659 Mdot
.7 .37703 Mdot
.7 .37779 Mdot
.7 .37877 Mdot
.7 .37957 Mdot
.7 .38099 Mdot
.7 .38194 Mdot
.7 .38215 Mdot
.7 .38415 Mdot
.7 .38446 Mdot
.7 .38452 Mdot
.7 .38452 Mdot
.7 .38462 Mdot
.7 .3848 Mdot
.7 .38497 Mdot
.7 .38508 Mdot
.7 .3853 Mdot
.7 .38544 Mdot
.7 .3855 Mdot
.7 .38554 Mdot
.7 .38557 Mdot
.7 .38581 Mdot
.7 .38592 Mdot
.7 .38616 Mdot
.7 .38646 Mdot
.7 .38648 Mdot
.7 .3865 Mdot
.7 .38662 Mdot
.7 .38703 Mdot
.7 .38733 Mdot
.7 .38736 Mdot
.7 .38742 Mdot
.7 .38775 Mdot
.7 .38796 Mdot
.7 .38798 Mdot
.7 .38817 Mdot
.7 .38817 Mdot
.7 .38829 Mdot
.7 .38863 Mdot
.7 .38885 Mdot
.7 .38899 Mdot
.7 .389 Mdot
.7 .38981 Mdot
.7 .38982 Mdot
.7 .39028 Mdot
.7 .39038 Mdot
.7 .39246 Mdot
.7 .39254 Mdot
.7 .39266 Mdot
.7 .39293 Mdot
.7 .39316 Mdot
.7 .39345 Mdot
.7 .39355 Mdot
.7 .39389 Mdot
.7 .3943 Mdot
.7 .39489 Mdot
.7 .39513 Mdot
.7 .39572 Mdot
.7 .39597 Mdot
.7 .39641 Mdot
.7 .39671 Mdot
.7 .39686 Mdot
.7 .39689 Mdot
.7 .39696 Mdot
.7 .3977 Mdot
.7 .39788 Mdot
.7 .39801 Mdot
.7 .3981 Mdot
.7 .39822 Mdot
.7 .39832 Mdot
.7 .39859 Mdot
.7 .39865 Mdot
.7 .39882 Mdot
.7 .39902 Mdot
.7 .39923 Mdot
.7 .39952 Mdot
.7 .39969 Mdot
.7 .40033 Mdot
.7 .40093 Mdot
.7 .40119 Mdot
.7 .40129 Mdot
.7 .40143 Mdot
.7 .40248 Mdot
.7 .40267 Mdot
.7 .40352 Mdot
.7 .40392 Mdot
.7 .40398 Mdot
.7 .4048 Mdot
.7 .40512 Mdot
.7 .40554 Mdot
.7 .4057 Mdot
.7 .40577 Mdot
.7 .40591 Mdot
.7 .40611 Mdot
.7 .40652 Mdot
.7 .40716 Mdot
.7 .40744 Mdot
.7 .40821 Mdot
.7 .40826 Mdot
.7 .40847 Mdot
.7 .40882 Mdot
.7 .40901 Mdot
.7 .40927 Mdot
.7 .40952 Mdot
.7 .40962 Mdot
.7 .40981 Mdot
.7 .41063 Mdot
.7 .41077 Mdot
.7 .41093 Mdot
.7 .41171 Mdot
.7 .41228 Mdot
.7 .41249 Mdot
.7 .41288 Mdot
.7 .4133 Mdot
.7 .41369 Mdot
.7 .41374 Mdot
.7 .41378 Mdot
.7 .41381 Mdot
.7 .41414 Mdot
.7 .4145 Mdot
.7 .41525 Mdot
.7 .41528 Mdot
.7 .41554 Mdot
.7 .41597 Mdot
.7 .41627 Mdot
.7 .41688 Mdot
.7 .41738 Mdot
.7 .41782 Mdot
.7 .41842 Mdot
.7 .4187 Mdot
.7 .41879 Mdot
.7 .41933 Mdot
.7 .41956 Mdot
.7 .42141 Mdot
.7 .42172 Mdot
.7 .42182 Mdot
.7 .4219 Mdot
.7 .42196 Mdot
.7 .42214 Mdot
.7 .42478 Mdot
.7 .42497 Mdot
.7 .42533 Mdot
.7 .42563 Mdot
.7 .42588 Mdot
.7 .4266 Mdot
.7 .42666 Mdot
.7 .42727 Mdot
.7 .42737 Mdot
.7 .42767 Mdot
.7 .42798 Mdot
.7 .42825 Mdot
.7 .4285 Mdot
.7 .42854 Mdot
.7 .42871 Mdot
.7 .42996 Mdot
.7 .43015 Mdot
.7 .43102 Mdot
.7 .43147 Mdot
.7 .43182 Mdot
.7 .43289 Mdot
.7 .43394 Mdot
.7 .43484 Mdot
.7 .4349 Mdot
.7 .43514 Mdot
.7 .43544 Mdot
.7 .43573 Mdot
.7 .43622 Mdot
.7 .43638 Mdot
.7 .43733 Mdot
.7 .4379 Mdot
.7 .43809 Mdot
.7 .43884 Mdot
.7 .44038 Mdot
.7 .4406 Mdot
.7 .44088 Mdot
.7 .44175 Mdot
.7 .4434 Mdot
.7 .44423 Mdot
.7 .44479 Mdot
.7 .44569 Mdot
.7 .44614 Mdot
.7 .44642 Mdot
.7 .44697 Mdot
.7 .44714 Mdot
.7 .44739 Mdot
.7 .4479 Mdot
.7 .44868 Mdot
.7 .45024 Mdot
.7 .45121 Mdot
.7 .45204 Mdot
.7 .45256 Mdot
.7 .45265 Mdot
.7 .45291 Mdot
.7 .45445 Mdot
.7 .45545 Mdot
.7 .45668 Mdot
.7 .45677 Mdot
.7 .45693 Mdot
.7 .45723 Mdot
.7 .45739 Mdot
.7 .45776 Mdot
.7 .4578 Mdot
.7 .46013 Mdot
.7 .46034 Mdot
.7 .46146 Mdot
.7 .46157 Mdot
.7 .4619 Mdot
.7 .46204 Mdot
.7 .46283 Mdot
.7 .46351 Mdot
.7 .46364 Mdot
.7 .46365 Mdot
.7 .46438 Mdot
.7 .46442 Mdot
.7 .46464 Mdot
.7 .46485 Mdot
.7 .46544 Mdot
.7 .4659 Mdot
.7 .46638 Mdot
.7 .46665 Mdot
.7 .46678 Mdot
.7 .46687 Mdot
.7 .46718 Mdot
.7 .46831 Mdot
.7 .46948 Mdot
.7 .4699 Mdot
.7 .46999 Mdot
.7 .4705 Mdot
.7 .47057 Mdot
.7 .47074 Mdot
.7 .47166 Mdot
.7 .47215 Mdot
.7 .47221 Mdot
.7 .47229 Mdot
.7 .47291 Mdot
.7 .47411 Mdot
.7 .47427 Mdot
.7 .47456 Mdot
.7 .47582 Mdot
.7 .47603 Mdot
.7 .47649 Mdot
.7 .47674 Mdot
.7 .4768 Mdot
.7 .4768 Mdot
.7 .4769 Mdot
.7 .47719 Mdot
.7 .47733 Mdot
.7 .47759 Mdot
.7 .4776 Mdot
.7 .47807 Mdot
.7 .47829 Mdot
.7 .47853 Mdot
.7 .47867 Mdot
.7 .47959 Mdot
.7 .47968 Mdot
.7 .48012 Mdot
.7 .48077 Mdot
.7 .48113 Mdot
.7 .48158 Mdot
.7 .48192 Mdot
.7 .48212 Mdot
.7 .4824 Mdot
.7 .48359 Mdot
.7 .48456 Mdot
.7 .48476 Mdot
.7 .48489 Mdot
.7 .48624 Mdot
.7 .48626 Mdot
.7 .48652 Mdot
.7 .4866 Mdot
.7 .48671 Mdot
.7 .48686 Mdot
.7 .4873 Mdot
.7 .48744 Mdot
.7 .48942 Mdot
.7 .48994 Mdot
.7 .49027 Mdot
.7 .4903 Mdot
.7 .49103 Mdot
.7 .49115 Mdot
.7 .49155 Mdot
.7 .49229 Mdot
.7 .49238 Mdot
.7 .49257 Mdot
.7 .49291 Mdot
.7 .49299 Mdot
.7 .4934 Mdot
.7 .49368 Mdot
.7 .49449 Mdot
.7 .49451 Mdot
.7 .49493 Mdot
.7 .49531 Mdot
.7 .49544 Mdot
.7 .49552 Mdot
.7 .49587 Mdot
.7 .4959 Mdot
.7 .49634 Mdot
.7 .49638 Mdot
.7 .49693 Mdot
.7 .49717 Mdot
.7 .49741 Mdot
.7 .49785 Mdot
.7 .4979 Mdot
.7 .49795 Mdot
.7 .49801 Mdot
.7 .49853 Mdot
.7 .49855 Mdot
.7 .49909 Mdot
.7 .49935 Mdot
.7 .49961 Mdot
.7 .49988 Mdot
.7 .49995 Mdot
.7 .50002 Mdot
.7 .50031 Mdot
.7 .50064 Mdot
.7 .50084 Mdot
.7 .50086 Mdot
.7 .50108 Mdot
.7 .50135 Mdot
.7 .50158 Mdot
.7 .50165 Mdot
.7 .50186 Mdot
.7 .50205 Mdot
.7 .50206 Mdot
.7 .50311 Mdot
.7 .50329 Mdot
.7 .50335 Mdot
.7 .50342 Mdot
.7 .50348 Mdot
.7 .5038 Mdot
.7 .50381 Mdot
.7 .50413 Mdot
.7 .50438 Mdot
.7 .50482 Mdot
.7 .50508 Mdot
.7 .50515 Mdot
.7 .50612 Mdot
.7 .50647 Mdot
.7 .50727 Mdot
.7 .50779 Mdot
.7 .50802 Mdot
.7 .5082 Mdot
.7 .50829 Mdot
.7 .50849 Mdot
.7 .509 Mdot
.7 .50939 Mdot
.7 .5104 Mdot
.7 .51046 Mdot
.7 .51096 Mdot
.7 .51198 Mdot
.7 .51216 Mdot
.7 .5122 Mdot
.7 .51299 Mdot
.7 .51345 Mdot
.7 .51362 Mdot
.7 .51373 Mdot
.7 .51403 Mdot
.7 .51419 Mdot
.7 .51474 Mdot
.7 .51548 Mdot
.7 .51568 Mdot
.7 .51602 Mdot
.7 .51625 Mdot
.7 .51648 Mdot
.7 .51668 Mdot
.7 .51675 Mdot
.7 .51706 Mdot
.7 .51717 Mdot
.7 .51731 Mdot
.7 .51741 Mdot
.7 .51756 Mdot
.7 .51776 Mdot
.7 .51859 Mdot
.7 .51868 Mdot
.7 .51871 Mdot
.7 .51887 Mdot
.7 .51905 Mdot
.7 .51921 Mdot
.7 .51971 Mdot
.7 .51999 Mdot
.7 .5202 Mdot
.7 .52059 Mdot
.7 .52064 Mdot
.7 .52089 Mdot
.7 .52147 Mdot
.7 .52154 Mdot
.7 .52198 Mdot
.7 .52236 Mdot
.7 .52246 Mdot
.7 .52278 Mdot
.7 .52302 Mdot
.7 .52332 Mdot
.7 .52344 Mdot
.7 .52352 Mdot
.7 .52571 Mdot
.7 .52582 Mdot
.7 .52629 Mdot
.7 .5263 Mdot
.7 .52713 Mdot
.7 .52715 Mdot
.7 .52715 Mdot
.7 .52724 Mdot
.7 .52729 Mdot
.7 .52751 Mdot
.7 .52785 Mdot
.7 .52798 Mdot
.7 .52798 Mdot
.7 .52817 Mdot
.7 .52819 Mdot
.7 .52841 Mdot
.7 .52873 Mdot
.7 .52874 Mdot
.7 .52879 Mdot
.7 .52882 Mdot
.7 .52912 Mdot
.7 .52953 Mdot
.7 .52965 Mdot
.7 .52967 Mdot
.7 .52969 Mdot
.7 .52985 Mdot
.7 .52999 Mdot
.7 .53022 Mdot
.7 .53033 Mdot
.7 .53057 Mdot
.7 .5306 Mdot
.7 .53064 Mdot
.7 .5307 Mdot
.7 .53083 Mdot
.7 .53092 Mdot
.7 .53105 Mdot
.7 .53115 Mdot
.7 .53131 Mdot
.7 .53149 Mdot
.7 .53159 Mdot
.7 .53159 Mdot
.7 .53165 Mdot
.7 .53173 Mdot
.7 .53195 Mdot
.7 .53384 Mdot
.7 .53404 Mdot
.7 .53415 Mdot
.7 .53491 Mdot
.7 .53542 Mdot
.7 .53605 Mdot
.7 .5362 Mdot
.7 .53644 Mdot
.7 .53692 Mdot
.7 .53779 Mdot
.7 .53808 Mdot
.7 .53845 Mdot
.7 .53884 Mdot
.7 .53934 Mdot
.7 .53937 Mdot
.7 .54119 Mdot
.7 .54146 Mdot
.7 .54158 Mdot
.7 .54192 Mdot
.7 .54335 Mdot
.7 .54369 Mdot
.7 .54392 Mdot
.7 .54616 Mdot
.7 .54626 Mdot
.7 .54629 Mdot
.7 .5466 Mdot
.7 .54673 Mdot
.7 .54678 Mdot
.7 .54685 Mdot
.7 .54691 Mdot
.7 .54691 Mdot
.7 .54705 Mdot
.7 .54712 Mdot
.7 .54729 Mdot
.7 .54748 Mdot
.7 .54782 Mdot
.7 .54801 Mdot
.7 .54802 Mdot
.7 .54824 Mdot
.7 .54827 Mdot
.7 .54847 Mdot
.7 .54872 Mdot
.7 .54884 Mdot
.7 .54892 Mdot
.7 .54899 Mdot
.7 .54945 Mdot
.7 .54965 Mdot
.7 .5501 Mdot
.7 .55037 Mdot
.7 .55068 Mdot
.7 .55071 Mdot
.7 .55075 Mdot
.7 .55096 Mdot
.7 .55133 Mdot
.7 .55172 Mdot
.7 .55211 Mdot
.7 .55226 Mdot
.7 .55231 Mdot
.7 .5524 Mdot
.7 .55242 Mdot
.7 .55259 Mdot
.7 .55263 Mdot
.7 .55299 Mdot
.7 .55336 Mdot
.7 .55339 Mdot
.7 .55368 Mdot
.7 .55371 Mdot
.7 .55373 Mdot
.7 .55385 Mdot
.7 .55393 Mdot
.7 .55439 Mdot
.7 .5545 Mdot
.7 .55485 Mdot
.7 .55494 Mdot
.7 .55509 Mdot
.7 .55509 Mdot
.7 .55512 Mdot
.7 .5554 Mdot
.7 .55551 Mdot
.7 .55577 Mdot
.7 .55621 Mdot
.7 .55632 Mdot
.7 .5564 Mdot
.7 .55642 Mdot
.7 .55684 Mdot
.7 .55712 Mdot
.7 .55718 Mdot
.7 .55728 Mdot
.7 .55817 Mdot
.7 .5582 Mdot
.7 .55868 Mdot
.7 .55912 Mdot
.7 .55927 Mdot
.7 .55935 Mdot
.7 .55975 Mdot
.7 .55978 Mdot
.7 .5602 Mdot
.7 .56025 Mdot
.7 .56029 Mdot
.7 .5603 Mdot
.7 .56045 Mdot
.7 .56081 Mdot
.7 .56087 Mdot
.7 .56109 Mdot
.7 .56112 Mdot
.7 .56136 Mdot
.7 .56144 Mdot
.7 .56156 Mdot
.7 .56179 Mdot
.7 .56183 Mdot
.7 .56188 Mdot
.7 .56193 Mdot
.7 .56197 Mdot
.7 .56242 Mdot
.7 .56243 Mdot
.7 .56244 Mdot
.7 .56251 Mdot
.7 .56292 Mdot
.7 .56307 Mdot
.7 .56314 Mdot
.7 .56332 Mdot
.7 .56336 Mdot
.7 .56359 Mdot
.7 .56365 Mdot
.7 .56371 Mdot
.7 .56372 Mdot
.7 .5639 Mdot
.7 .56394 Mdot
.7 .56414 Mdot
.7 .56419 Mdot
.7 .56434 Mdot
.7 .56436 Mdot
.7 .56452 Mdot
.7 .56455 Mdot
.7 .56468 Mdot
.7 .56472 Mdot
.7 .56481 Mdot
.7 .56488 Mdot
.7 .56493 Mdot
.7 .56494 Mdot
.7 .56496 Mdot
.7 .56502 Mdot
.7 .56507 Mdot
.7 .56519 Mdot
.7 .5652 Mdot
.7 .56561 Mdot
.7 .56574 Mdot
.7 .56583 Mdot
.7 .56586 Mdot
.7 .5659 Mdot
.7 .56596 Mdot
.7 .56598 Mdot
.7 .56599 Mdot
.7 .56603 Mdot
.7 .56605 Mdot
.7 .56606 Mdot
.7 .56623 Mdot
.7 .56624 Mdot
.7 .56624 Mdot
.7 .56627 Mdot
.7 .56637 Mdot
.7 .56641 Mdot
.7 .5665 Mdot
.7 .56653 Mdot
.7 .56662 Mdot
.7 .56674 Mdot
.7 .56678 Mdot
.7 .56685 Mdot
.7 .56687 Mdot
.7 .56688 Mdot
.7 .56718 Mdot
.7 .56726 Mdot
.7 .56737 Mdot
.7 .56737 Mdot
.7 .56742 Mdot
.7 .56752 Mdot
.7 .56755 Mdot
.7 .5676 Mdot
.7 .5676 Mdot
.7 .56771 Mdot
.7 .56772 Mdot
.7 .56777 Mdot
.7 .56781 Mdot
.7 .56782 Mdot
.7 .56786 Mdot
.7 .56786 Mdot
.7 .56787 Mdot
.7 .56789 Mdot
.7 .56792 Mdot
.7 .56796 Mdot
.7 .56799 Mdot
.7 .568 Mdot
.7 .568 Mdot
.702 .13882 Mdot
.702 .13885 Mdot
.702 .13886 Mdot
.702 .13887 Mdot
.702 .13887 Mdot
.702 .13888 Mdot
.702 .13888 Mdot
.702 .13889 Mdot
.702 .1389 Mdot
.702 .13891 Mdot
.702 .13892 Mdot
.702 .13892 Mdot
.702 .13893 Mdot
.702 .13894 Mdot
.702 .139 Mdot
.702 .139 Mdot
.702 .13902 Mdot
.702 .13907 Mdot
.702 .13907 Mdot
.702 .13913 Mdot
.702 .13916 Mdot
.702 .13917 Mdot
.702 .13927 Mdot
.702 .13928 Mdot
.702 .1393 Mdot
.702 .1393 Mdot
.702 .13945 Mdot
.702 .13954 Mdot
.702 .13955 Mdot
.702 .13957 Mdot
.702 .13962 Mdot
.702 .13988 Mdot
.702 .14001 Mdot
.702 .14035 Mdot
.702 .14037 Mdot
.702 .14051 Mdot
.702 .14052 Mdot
.702 .14054 Mdot
.702 .1406 Mdot
.702 .1411 Mdot
.702 .14116 Mdot
.702 .14197 Mdot
.702 .142 Mdot
.702 .14238 Mdot
.702 .14249 Mdot
.702 .1426 Mdot
.702 .14272 Mdot
.702 .14309 Mdot
.702 .14321 Mdot
.702 .14341 Mdot
.702 .14364 Mdot
.702 .14426 Mdot
.702 .14456 Mdot
.702 .14481 Mdot
.702 .1449 Mdot
.702 .14557 Mdot
.702 .14559 Mdot
.702 .14585 Mdot
.702 .14613 Mdot
.702 .14674 Mdot
.702 .14686 Mdot
.702 .14733 Mdot
.702 .14744 Mdot
.702 .14759 Mdot
.702 .1478 Mdot
.702 .14817 Mdot
.702 .1483 Mdot
.702 .14844 Mdot
.702 .14906 Mdot
.702 .14969 Mdot
.702 .15018 Mdot
.702 .15099 Mdot
.702 .15156 Mdot
.702 .15207 Mdot
.702 .1521 Mdot
.702 .1522 Mdot
.702 .15231 Mdot
.702 .15321 Mdot
.702 .15335 Mdot
.702 .1538 Mdot
.702 .15383 Mdot
.702 .15567 Mdot
.702 .15589 Mdot
.702 .15597 Mdot
.702 .15635 Mdot
.702 .15673 Mdot
.702 .15694 Mdot
.702 .1574 Mdot
.702 .15907 Mdot
.702 .15984 Mdot
.702 .16067 Mdot
.702 .16085 Mdot
.702 .16093 Mdot
.702 .16224 Mdot
.702 .16282 Mdot
.702 .16368 Mdot
.702 .16459 Mdot
.702 .16481 Mdot
.702 .16571 Mdot
.702 .16624 Mdot
.702 .16685 Mdot
.702 .1682 Mdot
.702 .16832 Mdot
.702 .16915 Mdot
.702 .17036 Mdot
.702 .17066 Mdot
.702 .17098 Mdot
.702 .17143 Mdot
.702 .17251 Mdot
.702 .17279 Mdot
.702 .17281 Mdot
.702 .17449 Mdot
.702 .17644 Mdot
.702 .17675 Mdot
.702 .17828 Mdot
.702 .17886 Mdot
.702 .17946 Mdot
.702 .18094 Mdot
.702 .18202 Mdot
.702 .18296 Mdot
.702 .18399 Mdot
.702 .18578 Mdot
.702 .18651 Mdot
.702 .1875 Mdot
.702 .19232 Mdot
.702 .19245 Mdot
.702 .19267 Mdot
.702 .19317 Mdot
.702 .19343 Mdot
.702 .19353 Mdot
.702 .19509 Mdot
.702 .19512 Mdot
.702 .19537 Mdot
.702 .19555 Mdot
.702 .19674 Mdot
.702 .19758 Mdot
.702 .19795 Mdot
.702 .19981 Mdot
.702 .20094 Mdot
.702 .20126 Mdot
.702 .2016 Mdot
.702 .20166 Mdot
.702 .20455 Mdot
.702 .20499 Mdot
.702 .20566 Mdot
.702 .20595 Mdot
.702 .20599 Mdot
.702 .20725 Mdot
.702 .20824 Mdot
.702 .20922 Mdot
.702 .20933 Mdot
.702 .20959 Mdot
.702 .20966 Mdot
.702 .20972 Mdot
.702 .21055 Mdot
.702 .21104 Mdot
.702 .21105 Mdot
.702 .21117 Mdot
.702 .21164 Mdot
.702 .21237 Mdot
.702 .2124 Mdot
.702 .2129 Mdot
.702 .21313 Mdot
.702 .21318 Mdot
.702 .21336 Mdot
.702 .21337 Mdot
.702 .21343 Mdot
.702 .21417 Mdot
.702 .21435 Mdot
.702 .21449 Mdot
.702 .21454 Mdot
.702 .21463 Mdot
.702 .2147 Mdot
.702 .21485 Mdot
.702 .21502 Mdot
.702 .21503 Mdot
.702 .2152 Mdot
.702 .21522 Mdot
.702 .21539 Mdot
.702 .21545 Mdot
.702 .21582 Mdot
.702 .2191 Mdot
.702 .22043 Mdot
.702 .22526 Mdot
.702 .22553 Mdot
.702 .22587 Mdot
.702 .22631 Mdot
.702 .22842 Mdot
.702 .23201 Mdot
.702 .23263 Mdot
.702 .23452 Mdot
.702 .23561 Mdot
.702 .23735 Mdot
.702 .23813 Mdot
.702 .23831 Mdot
.702 .23861 Mdot
.702 .24068 Mdot
.702 .24532 Mdot
.702 .24724 Mdot
.702 .24739 Mdot
.702 .24742 Mdot
.702 .24749 Mdot
.702 .2475 Mdot
.702 .24757 Mdot
.702 .24757 Mdot
.702 .24765 Mdot
.702 .24771 Mdot
.702 .24774 Mdot
.702 .24778 Mdot
.702 .2478 Mdot
.702 .24786 Mdot
.702 .24794 Mdot
.702 .24825 Mdot
.702 .24828 Mdot
.702 .24828 Mdot
.702 .24838 Mdot
.702 .24869 Mdot
.702 .24871 Mdot
.702 .24902 Mdot
.702 .24922 Mdot
.702 .24928 Mdot
.702 .24986 Mdot
.702 .24991 Mdot
.702 .25003 Mdot
.702 .25007 Mdot
.702 .25094 Mdot
.702 .2515 Mdot
.702 .25152 Mdot
.702 .25165 Mdot
.702 .25195 Mdot
.702 .25215 Mdot
.702 .25347 Mdot
.702 .2535 Mdot
.702 .25432 Mdot
.702 .2552 Mdot
.702 .25537 Mdot
.702 .25634 Mdot
.702 .25643 Mdot
.702 .25678 Mdot
.702 .25732 Mdot
.702 .25737 Mdot
.702 .2575 Mdot
.702 .25785 Mdot
.702 .26086 Mdot
.702 .26124 Mdot
.702 .26533 Mdot
.702 .2662 Mdot
.702 .26638 Mdot
.702 .26853 Mdot
.702 .26872 Mdot
.702 .26938 Mdot
.702 .27005 Mdot
.702 .27082 Mdot
.702 .27143 Mdot
.702 .27273 Mdot
.702 .27308 Mdot
.702 .2737 Mdot
.702 .27385 Mdot
.702 .27449 Mdot
.702 .2751 Mdot
.702 .27552 Mdot
.702 .27654 Mdot
.702 .2779 Mdot
.702 .27977 Mdot
.702 .28009 Mdot
.702 .2804 Mdot
.702 .28226 Mdot
.702 .28229 Mdot
.702 .28367 Mdot
.702 .28387 Mdot
.702 .28438 Mdot
.702 .28576 Mdot
.702 .2886 Mdot
.702 .28878 Mdot
.702 .2889 Mdot
.702 .28947 Mdot
.702 .29039 Mdot
.702 .29074 Mdot
.702 .29203 Mdot
.702 .29214 Mdot
.702 .29294 Mdot
.702 .29601 Mdot
.702 .29673 Mdot
.702 .29678 Mdot
.702 .29861 Mdot
.702 .29981 Mdot
.702 .30048 Mdot
.702 .30147 Mdot
.702 .30283 Mdot
.702 .30303 Mdot
.702 .30419 Mdot
.702 .30437 Mdot
.702 .30489 Mdot
.702 .30494 Mdot
.702 .30515 Mdot
.702 .30549 Mdot
.702 .3055 Mdot
.702 .30601 Mdot
.702 .30604 Mdot
.702 .3065 Mdot
.702 .30673 Mdot
.702 .30684 Mdot
.702 .30689 Mdot
.702 .30701 Mdot
.702 .30717 Mdot
.702 .30761 Mdot
.702 .30816 Mdot
.702 .31049 Mdot
.702 .31067 Mdot
.702 .31069 Mdot
.702 .31086 Mdot
.702 .31127 Mdot
.702 .31141 Mdot
.702 .31215 Mdot
.702 .31371 Mdot
.702 .31381 Mdot
.702 .31452 Mdot
.702 .31491 Mdot
.702 .31492 Mdot
.702 .31612 Mdot
.702 .31759 Mdot
.702 .31799 Mdot
.702 .31801 Mdot
.702 .31807 Mdot
.702 .31956 Mdot
.702 .32221 Mdot
.702 .32241 Mdot
.702 .32263 Mdot
.702 .32325 Mdot
.702 .32346 Mdot
.702 .32378 Mdot
.702 .32415 Mdot
.702 .32552 Mdot
.702 .32692 Mdot
.702 .32695 Mdot
.702 .32841 Mdot
.702 .32968 Mdot
.702 .3301 Mdot
.702 .33025 Mdot
.702 .3304 Mdot
.702 .33108 Mdot
.702 .33176 Mdot
.702 .33308 Mdot
.702 .33414 Mdot
.702 .33427 Mdot
.702 .33521 Mdot
.702 .33533 Mdot
.702 .33738 Mdot
.702 .33757 Mdot
.702 .33844 Mdot
.702 .33881 Mdot
.702 .34073 Mdot
.702 .34135 Mdot
.702 .34156 Mdot
.702 .34571 Mdot
.702 .34668 Mdot
.702 .34817 Mdot
.702 .34838 Mdot
.702 .34949 Mdot
.702 .35051 Mdot
.702 .35304 Mdot
.702 .35337 Mdot
.702 .35419 Mdot
.702 .35479 Mdot
.702 .3553 Mdot
.702 .35585 Mdot
.702 .35769 Mdot
.702 .36012 Mdot
.702 .36029 Mdot
.702 .36147 Mdot
.702 .36149 Mdot
.702 .36226 Mdot
.702 .36424 Mdot
.702 .36438 Mdot
.702 .36753 Mdot
.702 .36815 Mdot
.702 .36854 Mdot
.702 .36875 Mdot
.702 .36955 Mdot
.702 .36967 Mdot
.702 .37217 Mdot
.702 .37468 Mdot
.702 .37479 Mdot
.702 .37493 Mdot
.702 .3751 Mdot
.702 .37595 Mdot
.702 .3776 Mdot
.702 .37833 Mdot
.702 .37875 Mdot
.702 .37979 Mdot
.702 .38313 Mdot
.702 .38319 Mdot
.702 .3832 Mdot
.702 .38322 Mdot
.702 .38323 Mdot
.702 .38325 Mdot
.702 .38325 Mdot
.702 .38328 Mdot
.702 .3833 Mdot
.702 .38332 Mdot
.702 .38333 Mdot
.702 .38334 Mdot
.702 .38336 Mdot
.702 .38339 Mdot
.702 .3835 Mdot
.702 .38351 Mdot
.702 .38355 Mdot
.702 .38367 Mdot
.702 .38367 Mdot
.702 .38379 Mdot
.702 .38386 Mdot
.702 .38388 Mdot
.702 .38409 Mdot
.702 .38411 Mdot
.702 .38415 Mdot
.702 .38417 Mdot
.702 .38449 Mdot
.702 .38469 Mdot
.702 .3847 Mdot
.702 .38474 Mdot
.702 .38485 Mdot
.702 .38493 Mdot
.702 .38541 Mdot
.702 .38571 Mdot
.702 .38609 Mdot
.702 .38644 Mdot
.702 .38647 Mdot
.702 .38659 Mdot
.702 .38679 Mdot
.702 .3868 Mdot
.702 .38685 Mdot
.702 .38697 Mdot
.702 .38804 Mdot
.702 .38818 Mdot
.702 .38991 Mdot
.702 .38998 Mdot
.702 .39072 Mdot
.702 .39079 Mdot
.702 .39102 Mdot
.702 .39125 Mdot
.702 .39151 Mdot
.702 .39229 Mdot
.702 .39255 Mdot
.702 .39298 Mdot
.702 .39312 Mdot
.702 .39347 Mdot
.702 .39393 Mdot
.702 .39456 Mdot
.702 .39466 Mdot
.702 .39477 Mdot
.702 .3954 Mdot
.702 .3954 Mdot
.702 .39586 Mdot
.702 .39593 Mdot
.702 .3961 Mdot
.702 .39656 Mdot
.702 .3975 Mdot
.702 .39756 Mdot
.702 .39779 Mdot
.702 .39809 Mdot
.702 .39821 Mdot
.702 .39863 Mdot
.702 .39867 Mdot
.702 .39994 Mdot
.702 .40017 Mdot
.702 .40019 Mdot
.702 .40079 Mdot
.702 .40117 Mdot
.702 .40139 Mdot
.702 .40171 Mdot
.702 .40215 Mdot
.702 .4029 Mdot
.702 .40317 Mdot
.702 .40344 Mdot
.702 .40346 Mdot
.702 .40472 Mdot
.702 .40589 Mdot
.702 .40601 Mdot
.702 .40601 Mdot
.702 .40701 Mdot
.702 .40864 Mdot
.702 .40892 Mdot
.702 .40935 Mdot
.702 .4098 Mdot
.702 .41026 Mdot
.702 .41065 Mdot
.702 .41083 Mdot
.702 .41088 Mdot
.702 .41109 Mdot
.702 .4113 Mdot
.702 .41171 Mdot
.702 .41241 Mdot
.702 .4131 Mdot
.702 .41337 Mdot
.702 .41408 Mdot
.702 .41427 Mdot
.702 .41433 Mdot
.702 .41562 Mdot
.702 .41591 Mdot
.702 .41786 Mdot
.702 .41797 Mdot
.702 .4184 Mdot
.702 .41856 Mdot
.702 .41873 Mdot
.702 .41929 Mdot
.702 .42003 Mdot
.702 .42044 Mdot
.702 .42069 Mdot
.702 .42133 Mdot
.702 .42229 Mdot
.702 .4226 Mdot
.702 .42371 Mdot
.702 .42447 Mdot
.702 .42455 Mdot
.702 .42603 Mdot
.702 .42759 Mdot
.702 .42795 Mdot
.702 .4281 Mdot
.702 .42936 Mdot
.702 .43009 Mdot
.702 .43034 Mdot
.702 .43057 Mdot
.702 .43079 Mdot
.702 .43093 Mdot
.702 .43115 Mdot
.702 .43165 Mdot
.702 .43244 Mdot
.702 .43325 Mdot
.702 .434 Mdot
.702 .43494 Mdot
.702 .43535 Mdot
.702 .43547 Mdot
.702 .4358 Mdot
.702 .43653 Mdot
.702 .437 Mdot
.702 .4377 Mdot
.702 .43797 Mdot
.702 .43908 Mdot
.702 .43952 Mdot
.702 .44152 Mdot
.702 .44174 Mdot
.702 .44178 Mdot
.702 .44185 Mdot
.702 .44225 Mdot
.702 .44275 Mdot
.702 .44321 Mdot
.702 .44332 Mdot
.702 .44392 Mdot
.702 .4445 Mdot
.702 .44537 Mdot
.702 .44571 Mdot
.702 .4459 Mdot
.702 .44609 Mdot
.702 .44648 Mdot
.702 .44727 Mdot
.702 .44748 Mdot
.702 .44817 Mdot
.702 .44849 Mdot
.702 .44883 Mdot
.702 .44915 Mdot
.702 .44942 Mdot
.702 .44965 Mdot
.702 .44969 Mdot
.702 .45094 Mdot
.702 .45194 Mdot
.702 .45258 Mdot
.702 .45297 Mdot
.702 .45315 Mdot
.702 .45395 Mdot
.702 .45479 Mdot
.702 .45548 Mdot
.702 .45559 Mdot
.702 .45567 Mdot
.702 .45591 Mdot
.702 .45604 Mdot
.702 .45643 Mdot
.702 .459 Mdot
.702 .4594 Mdot
.702 .45998 Mdot
.702 .46014 Mdot
.702 .46097 Mdot
.702 .46197 Mdot
.702 .46241 Mdot
.702 .4634 Mdot
.702 .46355 Mdot
.702 .46433 Mdot
.702 .46517 Mdot
.702 .46552 Mdot
.702 .46605 Mdot
.702 .46624 Mdot
.702 .46669 Mdot
.702 .46691 Mdot
.702 .46834 Mdot
.702 .4684 Mdot
.702 .4696 Mdot
.702 .47089 Mdot
.702 .47119 Mdot
.702 .47213 Mdot
.702 .47233 Mdot
.702 .47292 Mdot
.702 .47325 Mdot
.702 .47347 Mdot
.702 .47382 Mdot
.702 .47387 Mdot
.702 .47417 Mdot
.702 .47455 Mdot
.702 .47568 Mdot
.702 .47761 Mdot
.702 .47784 Mdot
.702 .47838 Mdot
.702 .48074 Mdot
.702 .48121 Mdot
.702 .4814 Mdot
.702 .48173 Mdot
.702 .48248 Mdot
.702 .48286 Mdot
.702 .48294 Mdot
.702 .483 Mdot
.702 .48305 Mdot
.702 .48418 Mdot
.702 .48529 Mdot
.702 .48534 Mdot
.702 .48569 Mdot
.702 .48579 Mdot
.702 .48596 Mdot
.702 .48624 Mdot
.702 .48762 Mdot
.702 .48768 Mdot
.702 .48854 Mdot
.702 .48888 Mdot
.702 .48889 Mdot
.702 .4894 Mdot
.702 .48948 Mdot
.702 .49053 Mdot
.702 .49132 Mdot
.702 .49156 Mdot
.702 .49177 Mdot
.702 .49203 Mdot
.702 .49238 Mdot
.702 .49252 Mdot
.702 .4936 Mdot
.702 .49403 Mdot
.702 .4945 Mdot
.702 .49458 Mdot
.702 .49521 Mdot
.702 .49562 Mdot
.702 .49735 Mdot
.702 .49744 Mdot
.702 .49769 Mdot
.702 .49849 Mdot
.702 .49864 Mdot
.702 .499 Mdot
.702 .49908 Mdot
.702 .49992 Mdot
.702 .49997 Mdot
.702 .50036 Mdot
.702 .50041 Mdot
.702 .50084 Mdot
.702 .50138 Mdot
.702 .50165 Mdot
.702 .50193 Mdot
.702 .50199 Mdot
.702 .50205 Mdot
.702 .50222 Mdot
.702 .50274 Mdot
.702 .50332 Mdot
.702 .50334 Mdot
.702 .5039 Mdot
.702 .50445 Mdot
.702 .5046 Mdot
.702 .50473 Mdot
.702 .50481 Mdot
.702 .50506 Mdot
.702 .50515 Mdot
.702 .50522 Mdot
.702 .50628 Mdot
.702 .50687 Mdot
.702 .50689 Mdot
.702 .5069 Mdot
.702 .50706 Mdot
.702 .50764 Mdot
.702 .50811 Mdot
.702 .50812 Mdot
.702 .50827 Mdot
.702 .50855 Mdot
.702 .50858 Mdot
.702 .50919 Mdot
.702 .50949 Mdot
.702 .50954 Mdot
.702 .5097 Mdot
.702 .50977 Mdot
.702 .50977 Mdot
.702 .50984 Mdot
.702 .51075 Mdot
.702 .51096 Mdot
.702 .51113 Mdot
.702 .51119 Mdot
.702 .51124 Mdot
.702 .51126 Mdot
.702 .5113 Mdot
.702 .51139 Mdot
.702 .51157 Mdot
.702 .51158 Mdot
.702 .51178 Mdot
.702 .51178 Mdot
.702 .51192 Mdot
.702 .51199 Mdot
.702 .51201 Mdot
.702 .51222 Mdot
.702 .51229 Mdot
.702 .51273 Mdot
.702 .51281 Mdot
.702 .51333 Mdot
.702 .51371 Mdot
.702 .51396 Mdot
.702 .51442 Mdot
.702 .51512 Mdot
.702 .51514 Mdot
.702 .51541 Mdot
.702 .51657 Mdot
.702 .51687 Mdot
.702 .51691 Mdot
.702 .51739 Mdot
.702 .51753 Mdot
.702 .51787 Mdot
.702 .51809 Mdot
.702 .51813 Mdot
.702 .5182 Mdot
.702 .51926 Mdot
.702 .51977 Mdot
.702 .51996 Mdot
.702 .52004 Mdot
.702 .52055 Mdot
.702 .52056 Mdot
.702 .52124 Mdot
.702 .52136 Mdot
.702 .52148 Mdot
.702 .52216 Mdot
.702 .52266 Mdot
.702 .52304 Mdot
.702 .52319 Mdot
.702 .52341 Mdot
.702 .52364 Mdot
.702 .5237 Mdot
.702 .52392 Mdot
.702 .52405 Mdot
.702 .52452 Mdot
.702 .52475 Mdot
.702 .52503 Mdot
.702 .52527 Mdot
.702 .52551 Mdot
.702 .52558 Mdot
.702 .52635 Mdot
.702 .52641 Mdot
.702 .52673 Mdot
.702 .52819 Mdot
.702 .52833 Mdot
.702 .5294 Mdot
.702 .52953 Mdot
.702 .52957 Mdot
.702 .52959 Mdot
.702 .52978 Mdot
.702 .5299 Mdot
.702 .52993 Mdot
.702 .53028 Mdot
.702 .53034 Mdot
.702 .53065 Mdot
.702 .53094 Mdot
.702 .53095 Mdot
.702 .53141 Mdot
.702 .53148 Mdot
.702 .53159 Mdot
.702 .53164 Mdot
.702 .53164 Mdot
.702 .53184 Mdot
.702 .53214 Mdot
.702 .53216 Mdot
.702 .5322 Mdot
.702 .53222 Mdot
.702 .53242 Mdot
.702 .53244 Mdot
.702 .53251 Mdot
.702 .53262 Mdot
.702 .53263 Mdot
.702 .53274 Mdot
.702 .53277 Mdot
.702 .53277 Mdot
.702 .53278 Mdot
.702 .53289 Mdot
.702 .53292 Mdot
.702 .53294 Mdot
.702 .53295 Mdot
.702 .53296 Mdot
.702 .53297 Mdot
.702 .53299 Mdot
.702 .53302 Mdot
.702 .53302 Mdot
.702 .53304 Mdot
.702 .53305 Mdot
.702 .53307 Mdot
.702 .53308 Mdot
.702 .53314 Mdot
.702 .53381 Mdot
.702 .53541 Mdot
.702 .53613 Mdot
.702 .53623 Mdot
.702 .53629 Mdot
.702 .53656 Mdot
.702 .53716 Mdot
.702 .53753 Mdot
.702 .53818 Mdot
.702 .53839 Mdot
.702 .53961 Mdot
.702 .54033 Mdot
.702 .54048 Mdot
.702 .54059 Mdot
.702 .54068 Mdot
.702 .54231 Mdot
.702 .54275 Mdot
.702 .54385 Mdot
.702 .54397 Mdot
.702 .54399 Mdot
.702 .54405 Mdot
.702 .54405 Mdot
.702 .54411 Mdot
.702 .54411 Mdot
.702 .54417 Mdot
.702 .54422 Mdot
.702 .54424 Mdot
.702 .54427 Mdot
.702 .54429 Mdot
.702 .54434 Mdot
.702 .5444 Mdot
.702 .54464 Mdot
.702 .54466 Mdot
.702 .54466 Mdot
.702 .54473 Mdot
.702 .54474 Mdot
.702 .54482 Mdot
.702 .54498 Mdot
.702 .54499 Mdot
.702 .54524 Mdot
.702 .54539 Mdot
.702 .54543 Mdot
.702 .54543 Mdot
.702 .5456 Mdot
.702 .54587 Mdot
.702 .54589 Mdot
.702 .54591 Mdot
.702 .546 Mdot
.702 .54603 Mdot
.702 .54636 Mdot
.702 .54669 Mdot
.702 .5471 Mdot
.702 .54711 Mdot
.702 .54721 Mdot
.702 .54743 Mdot
.702 .54757 Mdot
.702 .54852 Mdot
.702 .54854 Mdot
.702 .54865 Mdot
.702 .54875 Mdot
.702 .54912 Mdot
.702 .54973 Mdot
.702 .54985 Mdot
.702 .55012 Mdot
.702 .55051 Mdot
.702 .55057 Mdot
.702 .55064 Mdot
.702 .55066 Mdot
.702 .5508 Mdot
.702 .55116 Mdot
.702 .55119 Mdot
.702 .55127 Mdot
.702 .55144 Mdot
.702 .55151 Mdot
.702 .55155 Mdot
.702 .5531 Mdot
.702 .55342 Mdot
.702 .55365 Mdot
.702 .55422 Mdot
.702 .55455 Mdot
.702 .55485 Mdot
.702 .5552 Mdot
.702 .55567 Mdot
.702 .55585 Mdot
.702 .55604 Mdot
.702 .55652 Mdot
.702 .55662 Mdot
.702 .55724 Mdot
.702 .55776 Mdot
.702 .55777 Mdot
.702 .55786 Mdot
.702 .5582 Mdot
.702 .55834 Mdot
.702 .55844 Mdot
.702 .55853 Mdot
.702 .55891 Mdot
.702 .55917 Mdot
.702 .55921 Mdot
.702 .55963 Mdot
.702 .55982 Mdot
.702 .55999 Mdot
.702 .56027 Mdot
.702 .56034 Mdot
.702 .56062 Mdot
.702 .56089 Mdot
.702 .56107 Mdot
.702 .56147 Mdot
.702 .5615 Mdot
.702 .56156 Mdot
.702 .56181 Mdot
.702 .56205 Mdot
.702 .56257 Mdot
.702 .56271 Mdot
.702 .56277 Mdot
.702 .56289 Mdot
.702 .563 Mdot
.702 .56303 Mdot
.702 .5631 Mdot
.702 .56366 Mdot
.702 .56367 Mdot
.702 .56381 Mdot
.702 .56385 Mdot
.702 .56413 Mdot
.702 .56416 Mdot
.702 .5642 Mdot
.702 .5642 Mdot
.702 .56436 Mdot
.702 .56454 Mdot
.702 .56478 Mdot
.702 .56493 Mdot
.702 .56513 Mdot
.702 .56532 Mdot
.702 .56536 Mdot
.702 .5654 Mdot
.702 .56551 Mdot
.702 .56557 Mdot
.702 .56562 Mdot
.702 .56565 Mdot
.702 .5658 Mdot
.702 .56583 Mdot
.702 .56602 Mdot
.702 .5661 Mdot
.702 .56618 Mdot
.702 .56619 Mdot
.702 .56639 Mdot
.702 .56642 Mdot
.702 .5665 Mdot
.702 .56659 Mdot
.702 .56677 Mdot
.702 .56685 Mdot
.702 .56691 Mdot
.702 .56694 Mdot
.702 .56705 Mdot
.702 .56709 Mdot
.702 .56713 Mdot
.702 .56716 Mdot
.702 .56727 Mdot
.702 .56728 Mdot
.702 .56753 Mdot
.702 .56755 Mdot
.702 .5677 Mdot
.702 .56771 Mdot
.702 .56772 Mdot
.702 .56772 Mdot
.702 .56777 Mdot
.702 .56777 Mdot
.702 .56787 Mdot
.702 .56792 Mdot
.702 .56799 Mdot
.702 .56801 Mdot
.702 .56802 Mdot
.702 .56802 Mdot
.702 .56805 Mdot
.702 .56809 Mdot
.702 .56809 Mdot
.702 .5681 Mdot
.702 .5681 Mdot
.702 .56813 Mdot
.702 .56813 Mdot
.702 .56814 Mdot
.702 .56816 Mdot
.702 .56816 Mdot
.702 .56818 Mdot
.702 .56818 Mdot
.702 .56818 Mdot
.702 .5682 Mdot
.702 .5682 Mdot
.702 .56821 Mdot
.702 .56821 Mdot
.702 .56821 Mdot
.702 .56821 Mdot
.702 .56821 Mdot
.702 .56822 Mdot
.702 .56822 Mdot
.702 .56822 Mdot
.702 .56822 Mdot
.702 .56822 Mdot
.702 .56823 Mdot
.702 .56823 Mdot
.704 .13809 Mdot
.704 .13809 Mdot
.704 .1381 Mdot
.704 .1381 Mdot
.704 .13813 Mdot
.704 .13815 Mdot
.704 .13825 Mdot
.704 .13834 Mdot
.704 .13842 Mdot
.704 .13851 Mdot
.704 .13853 Mdot
.704 .13859 Mdot
.704 .13866 Mdot
.704 .13886 Mdot
.704 .13907 Mdot
.704 .13911 Mdot
.704 .13918 Mdot
.704 .1392 Mdot
.704 .13929 Mdot
.704 .13934 Mdot
.704 .13966 Mdot
.704 .13969 Mdot
.704 .13975 Mdot
.704 .13976 Mdot
.704 .14026 Mdot
.704 .14031 Mdot
.704 .14073 Mdot
.704 .141 Mdot
.704 .14123 Mdot
.704 .14128 Mdot
.704 .14149 Mdot
.704 .14179 Mdot
.704 .14203 Mdot
.704 .14275 Mdot
.704 .14288 Mdot
.704 .14293 Mdot
.704 .14324 Mdot
.704 .14346 Mdot
.704 .1437 Mdot
.704 .14375 Mdot
.704 .14436 Mdot
.704 .14444 Mdot
.704 .14448 Mdot
.704 .14477 Mdot
.704 .14504 Mdot
.704 .14514 Mdot
.704 .14536 Mdot
.704 .14543 Mdot
.704 .14567 Mdot
.704 .14571 Mdot
.704 .14584 Mdot
.704 .14585 Mdot
.704 .14606 Mdot
.704 .14626 Mdot
.704 .14662 Mdot
.704 .14685 Mdot
.704 .14715 Mdot
.704 .14762 Mdot
.704 .14767 Mdot
.704 .14799 Mdot
.704 .14887 Mdot
.704 .14919 Mdot
.704 .1493 Mdot
.704 .14993 Mdot
.704 .15013 Mdot
.704 .15151 Mdot
.704 .1517 Mdot
.704 .15173 Mdot
.704 .15206 Mdot
.704 .15267 Mdot
.704 .1527 Mdot
.704 .15284 Mdot
.704 .15364 Mdot
.704 .15375 Mdot
.704 .15396 Mdot
.704 .15454 Mdot
.704 .15467 Mdot
.704 .15538 Mdot
.704 .15749 Mdot
.704 .15779 Mdot
.704 .1583 Mdot
.704 .15862 Mdot
.704 .15889 Mdot
.704 .15916 Mdot
.704 .15931 Mdot
.704 .15938 Mdot
.704 .15948 Mdot
.704 .15969 Mdot
.704 .15983 Mdot
.704 .16011 Mdot
.704 .16125 Mdot
.704 .16165 Mdot
.704 .16175 Mdot
.704 .16335 Mdot
.704 .16367 Mdot
.704 .16371 Mdot
.704 .16371 Mdot
.704 .1644 Mdot
.704 .16482 Mdot
.704 .16542 Mdot
.704 .16549 Mdot
.704 .16558 Mdot
.704 .16619 Mdot
.704 .16655 Mdot
.704 .16657 Mdot
.704 .16657 Mdot
.704 .16697 Mdot
.704 .167 Mdot
.704 .16704 Mdot
.704 .16715 Mdot
.704 .16716 Mdot
.704 .16825 Mdot
.704 .16842 Mdot
.704 .17012 Mdot
.704 .1731 Mdot
.704 .17335 Mdot
.704 .17458 Mdot
.704 .17473 Mdot
.704 .1755 Mdot
.704 .17587 Mdot
.704 .17808 Mdot
.704 .18146 Mdot
.704 .18251 Mdot
.704 .18302 Mdot
.704 .18379 Mdot
.704 .18439 Mdot
.704 .18634 Mdot
.704 .18708 Mdot
.704 .19036 Mdot
.704 .19057 Mdot
.704 .19216 Mdot
.704 .19235 Mdot
.704 .19556 Mdot
.704 .19617 Mdot
.704 .19635 Mdot
.704 .19722 Mdot
.704 .1978 Mdot
.704 .19807 Mdot
.704 .20223 Mdot
.704 .20243 Mdot
.704 .20245 Mdot
.704 .20268 Mdot
.704 .20282 Mdot
.704 .20362 Mdot
.704 .20379 Mdot
.704 .20397 Mdot
.704 .2052 Mdot
.704 .20665 Mdot
.704 .20828 Mdot
.704 .2083 Mdot
.704 .20899 Mdot
.704 .20958 Mdot
.704 .21005 Mdot
.704 .21022 Mdot
.704 .21055 Mdot
.704 .21094 Mdot
.704 .21102 Mdot
.704 .21148 Mdot
.704 .21211 Mdot
.704 .21423 Mdot
.704 .21505 Mdot
.704 .21523 Mdot
.704 .21656 Mdot
.704 .21785 Mdot
.704 .21862 Mdot
.704 .2188 Mdot
.704 .21905 Mdot
.704 .21967 Mdot
.704 .21997 Mdot
.704 .22122 Mdot
.704 .22154 Mdot
.704 .22239 Mdot
.704 .22313 Mdot
.704 .22371 Mdot
.704 .22379 Mdot
.704 .22393 Mdot
.704 .22415 Mdot
.704 .22518 Mdot
.704 .22553 Mdot
.704 .22567 Mdot
.704 .22584 Mdot
.704 .22593 Mdot
.704 .22603 Mdot
.704 .22606 Mdot
.704 .22739 Mdot
.704 .22764 Mdot
.704 .22767 Mdot
.704 .2299 Mdot
.704 .23094 Mdot
.704 .23264 Mdot
.704 .23404 Mdot
.704 .23405 Mdot
.704 .23567 Mdot
.704 .23603 Mdot
.704 .23752 Mdot
.704 .23834 Mdot
.704 .23967 Mdot
.704 .2428 Mdot
.704 .24281 Mdot
.704 .24285 Mdot
.704 .24289 Mdot
.704 .24296 Mdot
.704 .24301 Mdot
.704 .24315 Mdot
.704 .24366 Mdot
.704 .24374 Mdot
.704 .24428 Mdot
.704 .24462 Mdot
.704 .24475 Mdot
.704 .24527 Mdot
.704 .24539 Mdot
.704 .24575 Mdot
.704 .24614 Mdot
.704 .24731 Mdot
.704 .24856 Mdot
.704 .24883 Mdot
.704 .24903 Mdot
.704 .24906 Mdot
.704 .24923 Mdot
.704 .24937 Mdot
.704 .24945 Mdot
.704 .24965 Mdot
.704 .24991 Mdot
.704 .25021 Mdot
.704 .25158 Mdot
.704 .25214 Mdot
.704 .25229 Mdot
.704 .25265 Mdot
.704 .25272 Mdot
.704 .25292 Mdot
.704 .25575 Mdot
.704 .25604 Mdot
.704 .25768 Mdot
.704 .25857 Mdot
.704 .26023 Mdot
.704 .26062 Mdot
.704 .26163 Mdot
.704 .26195 Mdot
.704 .26263 Mdot
.704 .2632 Mdot
.704 .26507 Mdot
.704 .26654 Mdot
.704 .26699 Mdot
.704 .26708 Mdot
.704 .26781 Mdot
.704 .26796 Mdot
.704 .26978 Mdot
.704 .27096 Mdot
.704 .27167 Mdot
.704 .27167 Mdot
.704 .27177 Mdot
.704 .27179 Mdot
.704 .27205 Mdot
.704 .27206 Mdot
.704 .27231 Mdot
.704 .27282 Mdot
.704 .27322 Mdot
.704 .27399 Mdot
.704 .27424 Mdot
.704 .27537 Mdot
.704 .27689 Mdot
.704 .27718 Mdot
.704 .2773 Mdot
.704 .27795 Mdot
.704 .27836 Mdot
.704 .27859 Mdot
.704 .28031 Mdot
.704 .28091 Mdot
.704 .28103 Mdot
.704 .28153 Mdot
.704 .28181 Mdot
.704 .28252 Mdot
.704 .28265 Mdot
.704 .28358 Mdot
.704 .28509 Mdot
.704 .2853 Mdot
.704 .28594 Mdot
.704 .28605 Mdot
.704 .28734 Mdot
.704 .28775 Mdot
.704 .28933 Mdot
.704 .28957 Mdot
.704 .28985 Mdot
.704 .29 Mdot
.704 .29037 Mdot
.704 .29045 Mdot
.704 .29074 Mdot
.704 .29087 Mdot
.704 .29178 Mdot
.704 .29265 Mdot
.704 .29271 Mdot
.704 .29307 Mdot
.704 .2934 Mdot
.704 .29395 Mdot
.704 .29535 Mdot
.704 .29633 Mdot
.704 .29681 Mdot
.704 .29875 Mdot
.704 .3003 Mdot
.704 .3013 Mdot
.704 .30174 Mdot
.704 .30205 Mdot
.704 .30411 Mdot
.704 .30442 Mdot
.704 .30452 Mdot
.704 .30501 Mdot
.704 .30722 Mdot
.704 .30757 Mdot
.704 .30797 Mdot
.704 .30811 Mdot
.704 .30964 Mdot
.704 .30973 Mdot
.704 .31184 Mdot
.704 .31252 Mdot
.704 .31423 Mdot
.704 .31583 Mdot
.704 .31621 Mdot
.704 .31658 Mdot
.704 .31766 Mdot
.704 .31789 Mdot
.704 .31792 Mdot
.704 .31917 Mdot
.704 .3202 Mdot
.704 .32077 Mdot
.704 .32132 Mdot
.704 .32226 Mdot
.704 .32387 Mdot
.704 .32415 Mdot
.704 .32636 Mdot
.704 .32642 Mdot
.704 .3268 Mdot
.704 .32798 Mdot
.704 .3282 Mdot
.704 .32913 Mdot
.704 .3294 Mdot
.704 .32975 Mdot
.704 .33034 Mdot
.704 .33164 Mdot
.704 .33428 Mdot
.704 .33449 Mdot
.704 .3348 Mdot
.704 .33536 Mdot
.704 .33632 Mdot
.704 .34019 Mdot
.704 .34033 Mdot
.704 .34053 Mdot
.704 .3409 Mdot
.704 .34098 Mdot
.704 .34125 Mdot
.704 .34145 Mdot
.704 .34229 Mdot
.704 .34258 Mdot
.704 .34401 Mdot
.704 .34404 Mdot
.704 .34452 Mdot
.704 .34526 Mdot
.704 .34532 Mdot
.704 .34597 Mdot
.704 .34629 Mdot
.704 .34718 Mdot
.704 .35171 Mdot
.704 .35567 Mdot
.704 .35957 Mdot
.704 .36044 Mdot
.704 .36237 Mdot
.704 .36278 Mdot
.704 .36306 Mdot
.704 .36319 Mdot
.704 .3652 Mdot
.704 .36521 Mdot
.704 .36581 Mdot
.704 .36709 Mdot
.704 .36781 Mdot
.704 .37037 Mdot
.704 .3708 Mdot
.704 .37135 Mdot
.704 .37221 Mdot
.704 .37239 Mdot
.704 .37406 Mdot
.704 .37432 Mdot
.704 .37447 Mdot
.704 .37576 Mdot
.704 .37586 Mdot
.704 .37587 Mdot
.704 .37675 Mdot
.704 .37716 Mdot
.704 .37782 Mdot
.704 .37837 Mdot
.704 .37899 Mdot
.704 .37913 Mdot
.704 .38001 Mdot
.704 .38168 Mdot
.704 .38169 Mdot
.704 .3817 Mdot
.704 .38172 Mdot
.704 .38174 Mdot
.704 .38176 Mdot
.704 .38181 Mdot
.704 .38203 Mdot
.704 .38223 Mdot
.704 .38241 Mdot
.704 .3826 Mdot
.704 .38264 Mdot
.704 .38278 Mdot
.704 .38292 Mdot
.704 .38335 Mdot
.704 .38381 Mdot
.704 .38391 Mdot
.704 .38406 Mdot
.704 .38411 Mdot
.704 .38414 Mdot
.704 .38421 Mdot
.704 .3843 Mdot
.704 .38441 Mdot
.704 .38491 Mdot
.704 .38511 Mdot
.704 .38517 Mdot
.704 .3853 Mdot
.704 .38532 Mdot
.704 .38641 Mdot
.704 .38651 Mdot
.704 .38741 Mdot
.704 .388 Mdot
.704 .38849 Mdot
.704 .3886 Mdot
.704 .38884 Mdot
.704 .38904 Mdot
.704 .38969 Mdot
.704 .3902 Mdot
.704 .39069 Mdot
.704 .39132 Mdot
.704 .39173 Mdot
.704 .39197 Mdot
.704 .39201 Mdot
.704 .3921 Mdot
.704 .39276 Mdot
.704 .39323 Mdot
.704 .39375 Mdot
.704 .39384 Mdot
.704 .3951 Mdot
.704 .39514 Mdot
.704 .39531 Mdot
.704 .3954 Mdot
.704 .39568 Mdot
.704 .39599 Mdot
.704 .39656 Mdot
.704 .39678 Mdot
.704 .39724 Mdot
.704 .39737 Mdot
.704 .39789 Mdot
.704 .39798 Mdot
.704 .39812 Mdot
.704 .39824 Mdot
.704 .39826 Mdot
.704 .3984 Mdot
.704 .3987 Mdot
.704 .39901 Mdot
.704 .39912 Mdot
.704 .39987 Mdot
.704 .40034 Mdot
.704 .40097 Mdot
.704 .4018 Mdot
.704 .40194 Mdot
.704 .40204 Mdot
.704 .4027 Mdot
.704 .40283 Mdot
.704 .4037 Mdot
.704 .40393 Mdot
.704 .40398 Mdot
.704 .40447 Mdot
.704 .4045 Mdot
.704 .40517 Mdot
.704 .40538 Mdot
.704 .40643 Mdot
.704 .40667 Mdot
.704 .40708 Mdot
.704 .40816 Mdot
.704 .40896 Mdot
.704 .40987 Mdot
.704 .41024 Mdot
.704 .41031 Mdot
.704 .4106 Mdot
.704 .41068 Mdot
.704 .41079 Mdot
.704 .41097 Mdot
.704 .4122 Mdot
.704 .41226 Mdot
.704 .41236 Mdot
.704 .41253 Mdot
.704 .41402 Mdot
.704 .41413 Mdot
.704 .41427 Mdot
.704 .41435 Mdot
.704 .41467 Mdot
.704 .41476 Mdot
.704 .4152 Mdot
.704 .4159 Mdot
.704 .41617 Mdot
.704 .41756 Mdot
.704 .41877 Mdot
.704 .42094 Mdot
.704 .42103 Mdot
.704 .42106 Mdot
.704 .42168 Mdot
.704 .42225 Mdot
.704 .42325 Mdot
.704 .42338 Mdot
.704 .42355 Mdot
.704 .42381 Mdot
.704 .42386 Mdot
.704 .42437 Mdot
.704 .42445 Mdot
.704 .4245 Mdot
.704 .42489 Mdot
.704 .42492 Mdot
.704 .42492 Mdot
.704 .42519 Mdot
.704 .42531 Mdot
.704 .42552 Mdot
.704 .42591 Mdot
.704 .42618 Mdot
.704 .42671 Mdot
.704 .42744 Mdot
.704 .42887 Mdot
.704 .42943 Mdot
.704 .42962 Mdot
.704 .42982 Mdot
.704 .43077 Mdot
.704 .43178 Mdot
.704 .43197 Mdot
.704 .43282 Mdot
.704 .43314 Mdot
.704 .4334 Mdot
.704 .43348 Mdot
.704 .43349 Mdot
.704 .43477 Mdot
.704 .43555 Mdot
.704 .43558 Mdot
.704 .43606 Mdot
.704 .43665 Mdot
.704 .43678 Mdot
.704 .43694 Mdot
.704 .43804 Mdot
.704 .43872 Mdot
.704 .43874 Mdot
.704 .43875 Mdot
.704 .43947 Mdot
.704 .43953 Mdot
.704 .43961 Mdot
.704 .43981 Mdot
.704 .43982 Mdot
.704 .43995 Mdot
.704 .44074 Mdot
.704 .44136 Mdot
.704 .44179 Mdot
.704 .4421 Mdot
.704 .44513 Mdot
.704 .45002 Mdot
.704 .45036 Mdot
.704 .4508 Mdot
.704 .45293 Mdot
.704 .45319 Mdot
.704 .45451 Mdot
.704 .45514 Mdot
.704 .45524 Mdot
.704 .45577 Mdot
.704 .45649 Mdot
.704 .45754 Mdot
.704 .45886 Mdot
.704 .45886 Mdot
.704 .45908 Mdot
.704 .4591 Mdot
.704 .45944 Mdot
.704 .45957 Mdot
.704 .45966 Mdot
.704 .46086 Mdot
.704 .46088 Mdot
.704 .46092 Mdot
.704 .46204 Mdot
.704 .46385 Mdot
.704 .46412 Mdot
.704 .46432 Mdot
.704 .46444 Mdot
.704 .46528 Mdot
.704 .46606 Mdot
.704 .46612 Mdot
.704 .46616 Mdot
.704 .46697 Mdot
.704 .46737 Mdot
.704 .46822 Mdot
.704 .46918 Mdot
.704 .46942 Mdot
.704 .46944 Mdot
.704 .46956 Mdot
.704 .46998 Mdot
.704 .47048 Mdot
.704 .47183 Mdot
.704 .47212 Mdot
.704 .47225 Mdot
.704 .47341 Mdot
.704 .47369 Mdot
.704 .47517 Mdot
.704 .47548 Mdot
.704 .47577 Mdot
.704 .47664 Mdot
.704 .47846 Mdot
.704 .47878 Mdot
.704 .47882 Mdot
.704 .47992 Mdot
.704 .48071 Mdot
.704 .48111 Mdot
.704 .48117 Mdot
.704 .48145 Mdot
.704 .4817 Mdot
.704 .482 Mdot
.704 .48219 Mdot
.704 .48258 Mdot
.704 .48259 Mdot
.704 .48263 Mdot
.704 .48321 Mdot
.704 .48328 Mdot
.704 .4834 Mdot
.704 .48414 Mdot
.704 .48422 Mdot
.704 .48461 Mdot
.704 .48485 Mdot
.704 .48504 Mdot
.704 .48618 Mdot
.704 .48649 Mdot
.704 .48706 Mdot
.704 .48732 Mdot
.704 .48733 Mdot
.704 .48821 Mdot
.704 .48826 Mdot
.704 .48838 Mdot
.704 .48856 Mdot
.704 .4894 Mdot
.704 .48978 Mdot
.704 .49146 Mdot
.704 .49315 Mdot
.704 .49506 Mdot
.704 .49544 Mdot
.704 .49557 Mdot
.704 .49584 Mdot
.704 .49587 Mdot
.704 .49618 Mdot
.704 .49638 Mdot
.704 .49639 Mdot
.704 .49698 Mdot
.704 .49711 Mdot
.704 .49745 Mdot
.704 .49754 Mdot
.704 .49765 Mdot
.704 .49768 Mdot
.704 .49784 Mdot
.704 .49792 Mdot
.704 .49798 Mdot
.704 .49957 Mdot
.704 .49997 Mdot
.704 .5002 Mdot
.704 .50032 Mdot
.704 .50041 Mdot
.704 .50148 Mdot
.704 .50201 Mdot
.704 .50225 Mdot
.704 .50239 Mdot
.704 .5025 Mdot
.704 .50288 Mdot
.704 .50296 Mdot
.704 .50344 Mdot
.704 .50359 Mdot
.704 .50362 Mdot
.704 .5045 Mdot
.704 .50461 Mdot
.704 .50526 Mdot
.704 .50563 Mdot
.704 .50585 Mdot
.704 .50608 Mdot
.704 .50649 Mdot
.704 .50698 Mdot
.704 .50699 Mdot
.704 .50708 Mdot
.704 .50751 Mdot
.704 .50765 Mdot
.704 .5078 Mdot
.704 .50843 Mdot
.704 .5091 Mdot
.704 .50937 Mdot
.704 .51019 Mdot
.704 .51022 Mdot
.704 .51082 Mdot
.704 .51087 Mdot
.704 .51103 Mdot
.704 .51116 Mdot
.704 .51202 Mdot
.704 .5122 Mdot
.704 .51224 Mdot
.704 .51236 Mdot
.704 .51315 Mdot
.704 .51327 Mdot
.704 .51344 Mdot
.704 .51382 Mdot
.704 .51441 Mdot
.704 .51515 Mdot
.704 .51533 Mdot
.704 .5157 Mdot
.704 .51623 Mdot
.704 .51644 Mdot
.704 .51656 Mdot
.704 .5167 Mdot
.704 .51672 Mdot
.704 .51705 Mdot
.704 .51739 Mdot
.704 .51744 Mdot
.704 .51755 Mdot
.704 .51758 Mdot
.704 .51772 Mdot
.704 .51777 Mdot
.704 .51788 Mdot
.704 .51797 Mdot
.704 .51856 Mdot
.704 .51871 Mdot
.704 .51919 Mdot
.704 .51923 Mdot
.704 .51947 Mdot
.704 .51955 Mdot
.704 .52011 Mdot
.704 .52046 Mdot
.704 .5205 Mdot
.704 .52077 Mdot
.704 .52087 Mdot
.704 .52105 Mdot
.704 .5211 Mdot
.704 .52132 Mdot
.704 .52195 Mdot
.704 .52204 Mdot
.704 .52218 Mdot
.704 .52242 Mdot
.704 .52247 Mdot
.704 .52257 Mdot
.704 .52313 Mdot
.704 .52354 Mdot
.704 .52363 Mdot
.704 .52391 Mdot
.704 .52406 Mdot
.704 .52424 Mdot
.704 .52434 Mdot
.704 .52434 Mdot
.704 .52443 Mdot
.704 .52444 Mdot
.704 .52448 Mdot
.704 .52448 Mdot
.704 .52473 Mdot
.704 .52516 Mdot
.704 .52582 Mdot
.704 .52587 Mdot
.704 .52614 Mdot
.704 .52617 Mdot
.704 .52633 Mdot
.704 .52686 Mdot
.704 .52753 Mdot
.704 .52773 Mdot
.704 .52798 Mdot
.704 .52809 Mdot
.704 .52845 Mdot
.704 .52859 Mdot
.704 .52918 Mdot
.704 .5295 Mdot
.704 .53008 Mdot
.704 .53018 Mdot
.704 .53118 Mdot
.704 .53125 Mdot
.704 .53127 Mdot
.704 .5314 Mdot
.704 .53145 Mdot
.704 .53165 Mdot
.704 .53213 Mdot
.704 .53223 Mdot
.704 .53233 Mdot
.704 .5324 Mdot
.704 .53242 Mdot
.704 .53247 Mdot
.704 .53253 Mdot
.704 .53254 Mdot
.704 .53261 Mdot
.704 .53271 Mdot
.704 .53314 Mdot
.704 .53355 Mdot
.704 .53369 Mdot
.704 .53381 Mdot
.704 .53386 Mdot
.704 .53404 Mdot
.704 .53408 Mdot
.704 .5342 Mdot
.704 .53439 Mdot
.704 .53442 Mdot
.704 .53459 Mdot
.704 .53464 Mdot
.704 .53466 Mdot
.704 .53468 Mdot
.704 .5347 Mdot
.704 .53471 Mdot
.704 .53471 Mdot
.704 .53579 Mdot
.704 .53625 Mdot
.704 .53653 Mdot
.704 .53705 Mdot
.704 .53717 Mdot
.704 .53772 Mdot
.704 .53773 Mdot
.704 .53821 Mdot
.704 .53879 Mdot
.704 .53914 Mdot
.704 .5399 Mdot
.704 .53991 Mdot
.704 .53999 Mdot
.704 .54044 Mdot
.704 .54045 Mdot
.704 .54048 Mdot
.704 .54051 Mdot
.704 .54057 Mdot
.704 .54062 Mdot
.704 .54074 Mdot
.704 .54109 Mdot
.704 .54116 Mdot
.704 .54121 Mdot
.704 .54123 Mdot
.704 .54143 Mdot
.704 .54168 Mdot
.704 .54196 Mdot
.704 .54207 Mdot
.704 .54249 Mdot
.704 .54259 Mdot
.704 .5428 Mdot
.704 .54288 Mdot
.704 .54294 Mdot
.704 .5432 Mdot
.704 .54363 Mdot
.704 .54407 Mdot
.704 .54413 Mdot
.704 .54441 Mdot
.704 .54511 Mdot
.704 .54532 Mdot
.704 .54547 Mdot
.704 .54549 Mdot
.704 .54562 Mdot
.704 .54573 Mdot
.704 .54579 Mdot
.704 .54594 Mdot
.704 .54614 Mdot
.704 .54637 Mdot
.704 .54637 Mdot
.704 .54691 Mdot
.704 .54738 Mdot
.704 .54779 Mdot
.704 .54785 Mdot
.704 .5479 Mdot
.704 .54816 Mdot
.704 .54821 Mdot
.704 .54829 Mdot
.704 .54829 Mdot
.704 .54836 Mdot
.704 .54971 Mdot
.704 .5498 Mdot
.704 .54999 Mdot
.704 .55027 Mdot
.704 .55033 Mdot
.704 .55053 Mdot
.704 .55156 Mdot
.704 .55163 Mdot
.704 .55214 Mdot
.704 .55221 Mdot
.704 .55326 Mdot
.704 .5535 Mdot
.704 .55412 Mdot
.704 .55431 Mdot
.704 .55456 Mdot
.704 .55472 Mdot
.704 .55505 Mdot
.704 .55612 Mdot
.704 .55682 Mdot
.704 .55694 Mdot
.704 .55718 Mdot
.704 .55723 Mdot
.704 .55762 Mdot
.704 .5577 Mdot
.704 .55863 Mdot
.704 .55916 Mdot
.704 .55922 Mdot
.704 .55955 Mdot
.704 .55956 Mdot
.704 .55959 Mdot
.704 .55961 Mdot
.704 .55961 Mdot
.704 .55974 Mdot
.704 .55974 Mdot
.704 .55974 Mdot
.704 .55986 Mdot
.704 .56005 Mdot
.704 .56008 Mdot
.704 .5601 Mdot
.704 .56028 Mdot
.704 .56041 Mdot
.704 .56063 Mdot
.704 .56063 Mdot
.704 .56064 Mdot
.704 .56074 Mdot
.704 .56124 Mdot
.704 .56127 Mdot
.704 .56139 Mdot
.704 .56175 Mdot
.704 .56183 Mdot
.704 .56188 Mdot
.704 .56194 Mdot
.704 .56197 Mdot
.704 .56199 Mdot
.704 .56204 Mdot
.704 .56213 Mdot
.704 .56221 Mdot
.704 .56226 Mdot
.704 .56231 Mdot
.704 .56246 Mdot
.704 .56256 Mdot
.704 .56321 Mdot
.704 .56342 Mdot
.704 .56347 Mdot
.704 .56364 Mdot
.704 .56371 Mdot
.704 .56374 Mdot
.704 .56399 Mdot
.704 .56403 Mdot
.704 .56404 Mdot
.704 .56422 Mdot
.704 .56433 Mdot
.704 .56434 Mdot
.704 .56439 Mdot
.704 .56482 Mdot
.704 .56488 Mdot
.704 .56507 Mdot
.704 .5651 Mdot
.704 .5652 Mdot
.704 .56547 Mdot
.704 .56557 Mdot
.704 .56558 Mdot
.704 .56572 Mdot
.704 .56582 Mdot
.704 .56589 Mdot
.704 .566 Mdot
.704 .56606 Mdot
.704 .56612 Mdot
.704 .56612 Mdot
.704 .56616 Mdot
.704 .56617 Mdot
.704 .56625 Mdot
.704 .56627 Mdot
.704 .56634 Mdot
.704 .56637 Mdot
.704 .56645 Mdot
.704 .56654 Mdot
.704 .56655 Mdot
.704 .56657 Mdot
.704 .56676 Mdot
.704 .56677 Mdot
.704 .56685 Mdot
.704 .56692 Mdot
.704 .56701 Mdot
.704 .56702 Mdot
.704 .56706 Mdot
.704 .56728 Mdot
.704 .56735 Mdot
.704 .56744 Mdot
.704 .56751 Mdot
.704 .56752 Mdot
.704 .56759 Mdot
.704 .56767 Mdot
.704 .5678 Mdot
.704 .56781 Mdot
.704 .56797 Mdot
.704 .56797 Mdot
.704 .56799 Mdot
.704 .568 Mdot
.704 .56809 Mdot
.704 .56811 Mdot
.704 .56814 Mdot
.704 .56814 Mdot
.704 .56816 Mdot
.704 .56818 Mdot
.704 .56824 Mdot
.704 .5683 Mdot
.704 .56832 Mdot
.704 .56834 Mdot
.704 .56834 Mdot
.704 .56837 Mdot
.704 .5684 Mdot
.704 .56842 Mdot
.704 .56845 Mdot
.704 .56846 Mdot
.704 .56847 Mdot
.704 .56847 Mdot
.704 .56847 Mdot
.704 .56847 Mdot
.706 .13735 Mdot
.706 .13736 Mdot
.706 .13736 Mdot
.706 .13737 Mdot
.706 .13737 Mdot
.706 .13739 Mdot
.706 .13741 Mdot
.706 .13749 Mdot
.706 .13753 Mdot
.706 .13762 Mdot
.706 .13772 Mdot
.706 .13776 Mdot
.706 .13793 Mdot
.706 .138 Mdot
.706 .13807 Mdot
.706 .13834 Mdot
.706 .13857 Mdot
.706 .13859 Mdot
.706 .13874 Mdot
.706 .13892 Mdot
.706 .13893 Mdot
.706 .13895 Mdot
.706 .13925 Mdot
.706 .13965 Mdot
.706 .13974 Mdot
.706 .13976 Mdot
.706 .14013 Mdot
.706 .1403 Mdot
.706 .14046 Mdot
.706 .14072 Mdot
.706 .14081 Mdot
.706 .14132 Mdot
.706 .14149 Mdot
.706 .14167 Mdot
.706 .14202 Mdot
.706 .14206 Mdot
.706 .14216 Mdot
.706 .14226 Mdot
.706 .14243 Mdot
.706 .14261 Mdot
.706 .14263 Mdot
.706 .14271 Mdot
.706 .14293 Mdot
.706 .14295 Mdot
.706 .14302 Mdot
.706 .14507 Mdot
.706 .14628 Mdot
.706 .14637 Mdot
.706 .14639 Mdot
.706 .14889 Mdot
.706 .149 Mdot
.706 .1493 Mdot
.706 .14955 Mdot
.706 .14964 Mdot
.706 .14999 Mdot
.706 .15038 Mdot
.706 .15061 Mdot
.706 .15086 Mdot
.706 .15169 Mdot
.706 .15193 Mdot
.706 .15242 Mdot
.706 .15246 Mdot
.706 .15252 Mdot
.706 .15281 Mdot
.706 .15308 Mdot
.706 .15358 Mdot
.706 .15392 Mdot
.706 .15394 Mdot
.706 .15587 Mdot
.706 .15795 Mdot
.706 .15832 Mdot
.706 .15883 Mdot
.706 .15953 Mdot
.706 .15969 Mdot
.706 .16085 Mdot
.706 .16108 Mdot
.706 .16401 Mdot
.706 .16417 Mdot
.706 .16445 Mdot
.706 .16503 Mdot
.706 .16504 Mdot
.706 .16572 Mdot
.706 .16585 Mdot
.706 .16588 Mdot
.706 .16723 Mdot
.706 .168 Mdot
.706 .16801 Mdot
.706 .16826 Mdot
.706 .16842 Mdot
.706 .16882 Mdot
.706 .16896 Mdot
.706 .16903 Mdot
.706 .16942 Mdot
.706 .17079 Mdot
.706 .17243 Mdot
.706 .17251 Mdot
.706 .17253 Mdot
.706 .17332 Mdot
.706 .17361 Mdot
.706 .1738 Mdot
.706 .17457 Mdot
.706 .17502 Mdot
.706 .17592 Mdot
.706 .17698 Mdot
.706 .17727 Mdot
.706 .17889 Mdot
.706 .17923 Mdot
.706 .1798 Mdot
.706 .18093 Mdot
.706 .18128 Mdot
.706 .18165 Mdot
.706 .18174 Mdot
.706 .18282 Mdot
.706 .18311 Mdot
.706 .1832 Mdot
.706 .18439 Mdot
.706 .18448 Mdot
.706 .18673 Mdot
.706 .187 Mdot
.706 .18804 Mdot
.706 .18891 Mdot
.706 .18996 Mdot
.706 .19025 Mdot
.706 .19137 Mdot
.706 .19322 Mdot
.706 .19403 Mdot
.706 .19441 Mdot
.706 .19512 Mdot
.706 .19521 Mdot
.706 .19582 Mdot
.706 .19648 Mdot
.706 .19737 Mdot
.706 .19926 Mdot
.706 .20025 Mdot
.706 .20062 Mdot
.706 .2023 Mdot
.706 .20247 Mdot
.706 .20345 Mdot
.706 .20376 Mdot
.706 .20436 Mdot
.706 .20508 Mdot
.706 .20523 Mdot
.706 .20852 Mdot
.706 .20896 Mdot
.706 .20914 Mdot
.706 .20965 Mdot
.706 .21035 Mdot
.706 .21224 Mdot
.706 .21336 Mdot
.706 .2137 Mdot
.706 .21386 Mdot
.706 .21456 Mdot
.706 .21497 Mdot
.706 .21581 Mdot
.706 .21605 Mdot
.706 .21641 Mdot
.706 .21843 Mdot
.706 .21875 Mdot
.706 .21886 Mdot
.706 .2221 Mdot
.706 .22233 Mdot
.706 .22266 Mdot
.706 .22426 Mdot
.706 .22544 Mdot
.706 .22606 Mdot
.706 .22623 Mdot
.706 .22645 Mdot
.706 .22719 Mdot
.706 .22814 Mdot
.706 .22852 Mdot
.706 .22897 Mdot
.706 .22925 Mdot
.706 .22926 Mdot
.706 .2295 Mdot
.706 .23014 Mdot
.706 .23053 Mdot
.706 .23073 Mdot
.706 .23125 Mdot
.706 .23275 Mdot
.706 .23356 Mdot
.706 .23414 Mdot
.706 .23473 Mdot
.706 .23596 Mdot
.706 .23626 Mdot
.706 .23629 Mdot
.706 .23659 Mdot
.706 .23666 Mdot
.706 .23674 Mdot
.706 .23683 Mdot
.706 .23689 Mdot
.706 .23837 Mdot
.706 .23839 Mdot
.706 .23842 Mdot
.706 .23845 Mdot
.706 .23848 Mdot
.706 .23859 Mdot
.706 .23872 Mdot
.706 .23919 Mdot
.706 .23942 Mdot
.706 .23995 Mdot
.706 .24053 Mdot
.706 .24074 Mdot
.706 .24081 Mdot
.706 .24096 Mdot
.706 .24122 Mdot
.706 .24131 Mdot
.706 .24142 Mdot
.706 .2416 Mdot
.706 .24175 Mdot
.706 .24212 Mdot
.706 .24242 Mdot
.706 .2425 Mdot
.706 .24257 Mdot
.706 .24329 Mdot
.706 .24416 Mdot
.706 .24553 Mdot
.706 .24566 Mdot
.706 .2465 Mdot
.706 .24664 Mdot
.706 .2471 Mdot
.706 .24757 Mdot
.706 .24763 Mdot
.706 .24778 Mdot
.706 .24825 Mdot
.706 .24959 Mdot
.706 .24985 Mdot
.706 .2513 Mdot
.706 .25195 Mdot
.706 .2521 Mdot
.706 .25253 Mdot
.706 .25262 Mdot
.706 .254 Mdot
.706 .25489 Mdot
.706 .25562 Mdot
.706 .2559 Mdot
.706 .25595 Mdot
.706 .25628 Mdot
.706 .25686 Mdot
.706 .25776 Mdot
.706 .25831 Mdot
.706 .25846 Mdot
.706 .25898 Mdot
.706 .25942 Mdot
.706 .26008 Mdot
.706 .26125 Mdot
.706 .26191 Mdot
.706 .26196 Mdot
.706 .26212 Mdot
.706 .26274 Mdot
.706 .26313 Mdot
.706 .26375 Mdot
.706 .26406 Mdot
.706 .26425 Mdot
.706 .26515 Mdot
.706 .26644 Mdot
.706 .26669 Mdot
.706 .26726 Mdot
.706 .2679 Mdot
.706 .26791 Mdot
.706 .26895 Mdot
.706 .26979 Mdot
.706 .27004 Mdot
.706 .27008 Mdot
.706 .27017 Mdot
.706 .27053 Mdot
.706 .27068 Mdot
.706 .27069 Mdot
.706 .27118 Mdot
.706 .27206 Mdot
.706 .27208 Mdot
.706 .27217 Mdot
.706 .27263 Mdot
.706 .27302 Mdot
.706 .2765 Mdot
.706 .28125 Mdot
.706 .28223 Mdot
.706 .28227 Mdot
.706 .28293 Mdot
.706 .28416 Mdot
.706 .28488 Mdot
.706 .28552 Mdot
.706 .28833 Mdot
.706 .29278 Mdot
.706 .29312 Mdot
.706 .29324 Mdot
.706 .29354 Mdot
.706 .2938 Mdot
.706 .29396 Mdot
.706 .2941 Mdot
.706 .29756 Mdot
.706 .29837 Mdot
.706 .29955 Mdot
.706 .30034 Mdot
.706 .30143 Mdot
.706 .30219 Mdot
.706 .30483 Mdot
.706 .3061 Mdot
.706 .30643 Mdot
.706 .30764 Mdot
.706 .3083 Mdot
.706 .30855 Mdot
.706 .3088 Mdot
.706 .30988 Mdot
.706 .30999 Mdot
.706 .31072 Mdot
.706 .3126 Mdot
.706 .31339 Mdot
.706 .31424 Mdot
.706 .31452 Mdot
.706 .31484 Mdot
.706 .31667 Mdot
.706 .31709 Mdot
.706 .3176 Mdot
.706 .31763 Mdot
.706 .31942 Mdot
.706 .31964 Mdot
.706 .32081 Mdot
.706 .32112 Mdot
.706 .32162 Mdot
.706 .32178 Mdot
.706 .3227 Mdot
.706 .32298 Mdot
.706 .32329 Mdot
.706 .32386 Mdot
.706 .32477 Mdot
.706 .32527 Mdot
.706 .32538 Mdot
.706 .32812 Mdot
.706 .32957 Mdot
.706 .32967 Mdot
.706 .3324 Mdot
.706 .33281 Mdot
.706 .33306 Mdot
.706 .3335 Mdot
.706 .3341 Mdot
.706 .33433 Mdot
.706 .33533 Mdot
.706 .33586 Mdot
.706 .33611 Mdot
.706 .33635 Mdot
.706 .33707 Mdot
.706 .3371 Mdot
.706 .3387 Mdot
.706 .34034 Mdot
.706 .34063 Mdot
.706 .34101 Mdot
.706 .34166 Mdot
.706 .3425 Mdot
.706 .34267 Mdot
.706 .34472 Mdot
.706 .34483 Mdot
.706 .34541 Mdot
.706 .34761 Mdot
.706 .35008 Mdot
.706 .35061 Mdot
.706 .35089 Mdot
.706 .35212 Mdot
.706 .35272 Mdot
.706 .35509 Mdot
.706 .35534 Mdot
.706 .35674 Mdot
.706 .35809 Mdot
.706 .36156 Mdot
.706 .36273 Mdot
.706 .36448 Mdot
.706 .36465 Mdot
.706 .36634 Mdot
.706 .36667 Mdot
.706 .36837 Mdot
.706 .36867 Mdot
.706 .36897 Mdot
.706 .37076 Mdot
.706 .37129 Mdot
.706 .37255 Mdot
.706 .37397 Mdot
.706 .3741 Mdot
.706 .37521 Mdot
.706 .37672 Mdot
.706 .37839 Mdot
.706 .37943 Mdot
.706 .38023 Mdot
.706 .38023 Mdot
.706 .38025 Mdot
.706 .38026 Mdot
.706 .38027 Mdot
.706 .38031 Mdot
.706 .38036 Mdot
.706 .38054 Mdot
.706 .38062 Mdot
.706 .38082 Mdot
.706 .38104 Mdot
.706 .38112 Mdot
.706 .38133 Mdot
.706 .38149 Mdot
.706 .38163 Mdot
.706 .3818 Mdot
.706 .38239 Mdot
.706 .38289 Mdot
.706 .38294 Mdot
.706 .38325 Mdot
.706 .38347 Mdot
.706 .38364 Mdot
.706 .38367 Mdot
.706 .38372 Mdot
.706 .38438 Mdot
.706 .385 Mdot
.706 .38523 Mdot
.706 .38544 Mdot
.706 .38547 Mdot
.706 .38597 Mdot
.706 .38628 Mdot
.706 .38655 Mdot
.706 .38665 Mdot
.706 .38666 Mdot
.706 .38699 Mdot
.706 .38755 Mdot
.706 .38774 Mdot
.706 .38813 Mdot
.706 .38884 Mdot
.706 .38919 Mdot
.706 .38941 Mdot
.706 .38958 Mdot
.706 .39034 Mdot
.706 .39043 Mdot
.706 .39063 Mdot
.706 .39085 Mdot
.706 .39121 Mdot
.706 .3915 Mdot
.706 .39159 Mdot
.706 .39163 Mdot
.706 .39175 Mdot
.706 .3918 Mdot
.706 .39227 Mdot
.706 .39228 Mdot
.706 .39231 Mdot
.706 .39247 Mdot
.706 .39571 Mdot
.706 .39634 Mdot
.706 .39658 Mdot
.706 .39679 Mdot
.706 .39772 Mdot
.706 .39932 Mdot
.706 .39942 Mdot
.706 .39951 Mdot
.706 .39956 Mdot
.706 .40073 Mdot
.706 .40099 Mdot
.706 .40358 Mdot
.706 .40396 Mdot
.706 .40425 Mdot
.706 .40471 Mdot
.706 .40494 Mdot
.706 .40554 Mdot
.706 .40606 Mdot
.706 .40615 Mdot
.706 .40625 Mdot
.706 .40682 Mdot
.706 .40695 Mdot
.706 .40711 Mdot
.706 .40712 Mdot
.706 .40776 Mdot
.706 .40812 Mdot
.706 .40822 Mdot
.706 .40843 Mdot
.706 .40871 Mdot
.706 .4088 Mdot
.706 .40936 Mdot
.706 .40955 Mdot
.706 .4104 Mdot
.706 .41085 Mdot
.706 .41088 Mdot
.706 .41173 Mdot
.706 .41186 Mdot
.706 .41194 Mdot
.706 .41207 Mdot
.706 .41226 Mdot
.706 .41233 Mdot
.706 .41263 Mdot
.706 .41288 Mdot
.706 .41317 Mdot
.706 .41318 Mdot
.706 .41418 Mdot
.706 .41439 Mdot
.706 .41484 Mdot
.706 .4149 Mdot
.706 .41552 Mdot
.706 .41641 Mdot
.706 .41716 Mdot
.706 .41733 Mdot
.706 .41797 Mdot
.706 .4187 Mdot
.706 .4192 Mdot
.706 .41961 Mdot
.706 .42102 Mdot
.706 .42161 Mdot
.706 .42212 Mdot
.706 .42273 Mdot
.706 .42346 Mdot
.706 .42443 Mdot
.706 .42447 Mdot
.706 .42527 Mdot
.706 .42578 Mdot
.706 .42609 Mdot
.706 .42732 Mdot
.706 .42825 Mdot
.706 .42829 Mdot
.706 .42873 Mdot
.706 .42975 Mdot
.706 .42983 Mdot
.706 .43123 Mdot
.706 .43165 Mdot
.706 .43217 Mdot
.706 .43248 Mdot
.706 .43257 Mdot
.706 .43265 Mdot
.706 .43344 Mdot
.706 .43422 Mdot
.706 .43443 Mdot
.706 .43452 Mdot
.706 .43452 Mdot
.706 .43504 Mdot
.706 .43527 Mdot
.706 .43567 Mdot
.706 .43594 Mdot
.706 .4361 Mdot
.706 .43612 Mdot
.706 .43738 Mdot
.706 .43761 Mdot
.706 .43766 Mdot
.706 .43786 Mdot
.706 .43836 Mdot
.706 .43898 Mdot
.706 .43987 Mdot
.706 .44012 Mdot
.706 .44152 Mdot
.706 .44154 Mdot
.706 .44198 Mdot
.706 .44228 Mdot
.706 .44238 Mdot
.706 .4424 Mdot
.706 .44243 Mdot
.706 .44268 Mdot
.706 .44299 Mdot
.706 .44325 Mdot
.706 .44338 Mdot
.706 .44407 Mdot
.706 .44551 Mdot
.706 .44651 Mdot
.706 .4478 Mdot
.706 .44939 Mdot
.706 .44953 Mdot
.706 .44954 Mdot
.706 .44956 Mdot
.706 .45094 Mdot
.706 .45143 Mdot
.706 .45177 Mdot
.706 .45205 Mdot
.706 .45309 Mdot
.706 .45324 Mdot
.706 .45346 Mdot
.706 .45386 Mdot
.706 .45391 Mdot
.706 .45444 Mdot
.706 .45487 Mdot
.706 .45491 Mdot
.706 .45496 Mdot
.706 .45512 Mdot
.706 .4554 Mdot
.706 .45563 Mdot
.706 .45637 Mdot
.706 .45641 Mdot
.706 .45721 Mdot
.706 .4577 Mdot
.706 .45877 Mdot
.706 .45918 Mdot
.706 .46041 Mdot
.706 .46067 Mdot
.706 .46097 Mdot
.706 .4617 Mdot
.706 .46191 Mdot
.706 .46253 Mdot
.706 .46286 Mdot
.706 .46294 Mdot
.706 .46332 Mdot
.706 .46377 Mdot
.706 .46435 Mdot
.706 .46495 Mdot
.706 .4651 Mdot
.706 .46538 Mdot
.706 .46542 Mdot
.706 .46568 Mdot
.706 .46611 Mdot
.706 .46676 Mdot
.706 .46686 Mdot
.706 .46713 Mdot
.706 .46732 Mdot
.706 .46747 Mdot
.706 .46796 Mdot
.706 .46796 Mdot
.706 .46811 Mdot
.706 .46844 Mdot
.706 .46937 Mdot
.706 .46951 Mdot
.706 .46969 Mdot
.706 .47095 Mdot
.706 .47107 Mdot
.706 .4717 Mdot
.706 .47252 Mdot
.706 .47306 Mdot
.706 .47318 Mdot
.706 .47348 Mdot
.706 .4751 Mdot
.706 .47535 Mdot
.706 .47547 Mdot
.706 .47645 Mdot
.706 .47704 Mdot
.706 .47772 Mdot
.706 .47778 Mdot
.706 .47804 Mdot
.706 .47849 Mdot
.706 .4792 Mdot
.706 .48018 Mdot
.706 .48104 Mdot
.706 .48151 Mdot
.706 .48227 Mdot
.706 .48295 Mdot
.706 .48345 Mdot
.706 .48351 Mdot
.706 .48414 Mdot
.706 .4847 Mdot
.706 .48494 Mdot
.706 .48573 Mdot
.706 .48586 Mdot
.706 .486 Mdot
.706 .48675 Mdot
.706 .48689 Mdot
.706 .48763 Mdot
.706 .48771 Mdot
.706 .48847 Mdot
.706 .48898 Mdot
.706 .49048 Mdot
.706 .49106 Mdot
.706 .49166 Mdot
.706 .49177 Mdot
.706 .49278 Mdot
.706 .49304 Mdot
.706 .49356 Mdot
.706 .49368 Mdot
.706 .4939 Mdot
.706 .49494 Mdot
.706 .49586 Mdot
.706 .49611 Mdot
.706 .49615 Mdot
.706 .49701 Mdot
.706 .49708 Mdot
.706 .49743 Mdot
.706 .49769 Mdot
.706 .49785 Mdot
.706 .49797 Mdot
.706 .49865 Mdot
.706 .49931 Mdot
.706 .49932 Mdot
.706 .49962 Mdot
.706 .49971 Mdot
.706 .49982 Mdot
.706 .50004 Mdot
.706 .50044 Mdot
.706 .50054 Mdot
.706 .50078 Mdot
.706 .50096 Mdot
.706 .50106 Mdot
.706 .50123 Mdot
.706 .50234 Mdot
.706 .50238 Mdot
.706 .50296 Mdot
.706 .50406 Mdot
.706 .50411 Mdot
.706 .50431 Mdot
.706 .50467 Mdot
.706 .5049 Mdot
.706 .50502 Mdot
.706 .50513 Mdot
.706 .5055 Mdot
.706 .50556 Mdot
.706 .50576 Mdot
.706 .50589 Mdot
.706 .50635 Mdot
.706 .50644 Mdot
.706 .50715 Mdot
.706 .50716 Mdot
.706 .50736 Mdot
.706 .50752 Mdot
.706 .50824 Mdot
.706 .50837 Mdot
.706 .50848 Mdot
.706 .50881 Mdot
.706 .50912 Mdot
.706 .50985 Mdot
.706 .51014 Mdot
.706 .51018 Mdot
.706 .5106 Mdot
.706 .5107 Mdot
.706 .51079 Mdot
.706 .51105 Mdot
.706 .51152 Mdot
.706 .51164 Mdot
.706 .51213 Mdot
.706 .51315 Mdot
.706 .51343 Mdot
.706 .51385 Mdot
.706 .51461 Mdot
.706 .51491 Mdot
.706 .51622 Mdot
.706 .51627 Mdot
.706 .51634 Mdot
.706 .51643 Mdot
.706 .51655 Mdot
.706 .51659 Mdot
.706 .51672 Mdot
.706 .51839 Mdot
.706 .51943 Mdot
.706 .51967 Mdot
.706 .51994 Mdot
.706 .52039 Mdot
.706 .52064 Mdot
.706 .52065 Mdot
.706 .52101 Mdot
.706 .52276 Mdot
.706 .52403 Mdot
.706 .52417 Mdot
.706 .52434 Mdot
.706 .52437 Mdot
.706 .52437 Mdot
.706 .52469 Mdot
.706 .52487 Mdot
.706 .52488 Mdot
.706 .52493 Mdot
.706 .52506 Mdot
.706 .52509 Mdot
.706 .52511 Mdot
.706 .5252 Mdot
.706 .5255 Mdot
.706 .52588 Mdot
.706 .52588 Mdot
.706 .52611 Mdot
.706 .52631 Mdot
.706 .52641 Mdot
.706 .52687 Mdot
.706 .52719 Mdot
.706 .52726 Mdot
.706 .52737 Mdot
.706 .52759 Mdot
.706 .52773 Mdot
.706 .52796 Mdot
.706 .52801 Mdot
.706 .52803 Mdot
.706 .52827 Mdot
.706 .52868 Mdot
.706 .52892 Mdot
.706 .52907 Mdot
.706 .52926 Mdot
.706 .52931 Mdot
.706 .5295 Mdot
.706 .52982 Mdot
.706 .53003 Mdot
.706 .53015 Mdot
.706 .53016 Mdot
.706 .53026 Mdot
.706 .53052 Mdot
.706 .53083 Mdot
.706 .53132 Mdot
.706 .53135 Mdot
.706 .5315 Mdot
.706 .53155 Mdot
.706 .53178 Mdot
.706 .53229 Mdot
.706 .53238 Mdot
.706 .53285 Mdot
.706 .53302 Mdot
.706 .53307 Mdot
.706 .53309 Mdot
.706 .53325 Mdot
.706 .53341 Mdot
.706 .53346 Mdot
.706 .53375 Mdot
.706 .5338 Mdot
.706 .53428 Mdot
.706 .53458 Mdot
.706 .53483 Mdot
.706 .53485 Mdot
.706 .53488 Mdot
.706 .53498 Mdot
.706 .53511 Mdot
.706 .53516 Mdot
.706 .53522 Mdot
.706 .53526 Mdot
.706 .53529 Mdot
.706 .53538 Mdot
.706 .53543 Mdot
.706 .53546 Mdot
.706 .53553 Mdot
.706 .53573 Mdot
.706 .53592 Mdot
.706 .53599 Mdot
.706 .53616 Mdot
.706 .5362 Mdot
.706 .53624 Mdot
.706 .53625 Mdot
.706 .53626 Mdot
.706 .53627 Mdot
.706 .53628 Mdot
.706 .53678 Mdot
.706 .5368 Mdot
.706 .53684 Mdot
.706 .53686 Mdot
.706 .53689 Mdot
.706 .53699 Mdot
.706 .537 Mdot
.706 .5371 Mdot
.706 .53752 Mdot
.706 .53773 Mdot
.706 .53792 Mdot
.706 .5382 Mdot
.706 .53871 Mdot
.706 .53889 Mdot
.706 .53896 Mdot
.706 .53909 Mdot
.706 .53931 Mdot
.706 .53939 Mdot
.706 .53939 Mdot
.706 .53948 Mdot
.706 .53964 Mdot
.706 .53977 Mdot
.706 .54009 Mdot
.706 .54034 Mdot
.706 .54041 Mdot
.706 .54047 Mdot
.706 .54068 Mdot
.706 .54108 Mdot
.706 .54162 Mdot
.706 .54173 Mdot
.706 .5418 Mdot
.706 .54289 Mdot
.706 .54293 Mdot
.706 .54304 Mdot
.706 .54371 Mdot
.706 .54383 Mdot
.706 .54391 Mdot
.706 .54419 Mdot
.706 .54432 Mdot
.706 .54456 Mdot
.706 .54461 Mdot
.706 .54472 Mdot
.706 .54509 Mdot
.706 .54572 Mdot
.706 .54595 Mdot
.706 .54612 Mdot
.706 .54618 Mdot
.706 .54632 Mdot
.706 .5474 Mdot
.706 .54745 Mdot
.706 .54769 Mdot
.706 .54788 Mdot
.706 .54799 Mdot
.706 .5483 Mdot
.706 .54836 Mdot
.706 .54891 Mdot
.706 .54903 Mdot
.706 .54935 Mdot
.706 .54997 Mdot
.706 .55026 Mdot
.706 .55047 Mdot
.706 .55067 Mdot
.706 .5507 Mdot
.706 .55092 Mdot
.706 .55105 Mdot
.706 .55131 Mdot
.706 .55191 Mdot
.706 .55226 Mdot
.706 .55236 Mdot
.706 .55269 Mdot
.706 .55297 Mdot
.706 .55331 Mdot
.706 .55339 Mdot
.706 .55411 Mdot
.706 .55414 Mdot
.706 .55452 Mdot
.706 .55455 Mdot
.706 .55464 Mdot
.706 .55498 Mdot
.706 .55501 Mdot
.706 .55513 Mdot
.706 .55524 Mdot
.706 .5556 Mdot
.706 .55578 Mdot
.706 .55589 Mdot
.706 .5564 Mdot
.706 .55649 Mdot
.706 .55683 Mdot
.706 .55711 Mdot
.706 .55725 Mdot
.706 .55749 Mdot
.706 .55756 Mdot
.706 .55765 Mdot
.706 .5579 Mdot
.706 .5579 Mdot
.706 .55793 Mdot
.706 .55844 Mdot
.706 .55887 Mdot
.706 .55899 Mdot
.706 .55901 Mdot
.706 .55906 Mdot
.706 .55918 Mdot
.706 .55923 Mdot
.706 .55931 Mdot
.706 .55931 Mdot
.706 .55955 Mdot
.706 .55998 Mdot
.706 .55998 Mdot
.706 .56002 Mdot
.706 .56024 Mdot
.706 .56024 Mdot
.706 .56042 Mdot
.706 .56051 Mdot
.706 .56056 Mdot
.706 .56147 Mdot
.706 .56154 Mdot
.706 .5619 Mdot
.706 .56195 Mdot
.706 .56216 Mdot
.706 .56232 Mdot
.706 .56243 Mdot
.706 .56307 Mdot
.706 .56367 Mdot
.706 .56367 Mdot
.706 .56378 Mdot
.706 .56393 Mdot
.706 .56401 Mdot
.706 .5641 Mdot
.706 .56412 Mdot
.706 .56413 Mdot
.706 .56428 Mdot
.706 .56436 Mdot
.706 .56461 Mdot
.706 .56469 Mdot
.706 .56476 Mdot
.706 .56488 Mdot
.706 .56498 Mdot
.706 .56501 Mdot
.706 .56509 Mdot
.706 .56518 Mdot
.706 .56521 Mdot
.706 .56597 Mdot
.706 .56598 Mdot
.706 .56601 Mdot
.706 .56638 Mdot
.706 .567 Mdot
.706 .56702 Mdot
.706 .56702 Mdot
.706 .56709 Mdot
.706 .56712 Mdot
.706 .56712 Mdot
.706 .56718 Mdot
.706 .56723 Mdot
.706 .56726 Mdot
.706 .56729 Mdot
.706 .5673 Mdot
.706 .56741 Mdot
.706 .56746 Mdot
.706 .56751 Mdot
.706 .56767 Mdot
.706 .56769 Mdot
.706 .56777 Mdot
.706 .56782 Mdot
.706 .56787 Mdot
.706 .56798 Mdot
.706 .56799 Mdot
.706 .56802 Mdot
.706 .56814 Mdot
.706 .56823 Mdot
.706 .56823 Mdot
.706 .56824 Mdot
.706 .56829 Mdot
.706 .56833 Mdot
.706 .56834 Mdot
.706 .56841 Mdot
.706 .56849 Mdot
.706 .56852 Mdot
.706 .56853 Mdot
.706 .56859 Mdot
.706 .5686 Mdot
.706 .56863 Mdot
.706 .56865 Mdot
.706 .56867 Mdot
.706 .56869 Mdot
.706 .5687 Mdot
.706 .5687 Mdot
.706 .5687 Mdot
.706 .56871 Mdot
.706 .56871 Mdot
.706 .56871 Mdot
.708 .13662 Mdot
.708 .13663 Mdot
.708 .13663 Mdot
.708 .13665 Mdot
.708 .13666 Mdot
.708 .13667 Mdot
.708 .13668 Mdot
.708 .13669 Mdot
.708 .13672 Mdot
.708 .13674 Mdot
.708 .13676 Mdot
.708 .13679 Mdot
.708 .13685 Mdot
.708 .13687 Mdot
.708 .13689 Mdot
.708 .13699 Mdot
.708 .13701 Mdot
.708 .13703 Mdot
.708 .13705 Mdot
.708 .13706 Mdot
.708 .13715 Mdot
.708 .13717 Mdot
.708 .13719 Mdot
.708 .13729 Mdot
.708 .13739 Mdot
.708 .13837 Mdot
.708 .13844 Mdot
.708 .1386 Mdot
.708 .13869 Mdot
.708 .13884 Mdot
.708 .13897 Mdot
.708 .13903 Mdot
.708 .13912 Mdot
.708 .13925 Mdot
.708 .1394 Mdot
.708 .14046 Mdot
.708 .1406 Mdot
.708 .14065 Mdot
.708 .1409 Mdot
.708 .14091 Mdot
.708 .14115 Mdot
.708 .1413 Mdot
.708 .14141 Mdot
.708 .14172 Mdot
.708 .14191 Mdot
.708 .14204 Mdot
.708 .14277 Mdot
.708 .14295 Mdot
.708 .14363 Mdot
.708 .14368 Mdot
.708 .14437 Mdot
.708 .14454 Mdot
.708 .14489 Mdot
.708 .14504 Mdot
.708 .14505 Mdot
.708 .14511 Mdot
.708 .1459 Mdot
.708 .14604 Mdot
.708 .14642 Mdot
.708 .14695 Mdot
.708 .14802 Mdot
.708 .14817 Mdot
.708 .14836 Mdot
.708 .14844 Mdot
.708 .1488 Mdot
.708 .14916 Mdot
.708 .1494 Mdot
.708 .14965 Mdot
.708 .1517 Mdot
.708 .15177 Mdot
.708 .1518 Mdot
.708 .1518 Mdot
.708 .15181 Mdot
.708 .15286 Mdot
.708 .15286 Mdot
.708 .153 Mdot
.708 .15439 Mdot
.708 .15621 Mdot
.708 .15718 Mdot
.708 .15774 Mdot
.708 .15785 Mdot
.708 .15813 Mdot
.708 .15848 Mdot
.708 .15858 Mdot
.708 .15889 Mdot
.708 .1593 Mdot
.708 .15962 Mdot
.708 .16001 Mdot
.708 .16419 Mdot
.708 .16423 Mdot
.708 .16452 Mdot
.708 .1649 Mdot
.708 .16507 Mdot
.708 .16678 Mdot
.708 .16687 Mdot
.708 .16733 Mdot
.708 .16742 Mdot
.708 .16834 Mdot
.708 .16966 Mdot
.708 .1722 Mdot
.708 .17281 Mdot
.708 .17309 Mdot
.708 .17422 Mdot
.708 .17424 Mdot
.708 .17561 Mdot
.708 .17769 Mdot
.708 .18025 Mdot
.708 .18058 Mdot
.708 .1812 Mdot
.708 .18158 Mdot
.708 .18248 Mdot
.708 .18294 Mdot
.708 .18383 Mdot
.708 .18424 Mdot
.708 .18519 Mdot
.708 .18711 Mdot
.708 .18733 Mdot
.708 .18741 Mdot
.708 .18806 Mdot
.708 .18812 Mdot
.708 .19033 Mdot
.708 .19102 Mdot
.708 .19267 Mdot
.708 .19806 Mdot
.708 .20216 Mdot
.708 .20222 Mdot
.708 .20327 Mdot
.708 .20599 Mdot
.708 .20676 Mdot
.708 .2075 Mdot
.708 .20863 Mdot
.708 .20878 Mdot
.708 .2092 Mdot
.708 .21014 Mdot
.708 .21058 Mdot
.708 .21173 Mdot
.708 .21187 Mdot
.708 .21189 Mdot
.708 .21192 Mdot
.708 .21207 Mdot
.708 .21214 Mdot
.708 .2127 Mdot
.708 .21281 Mdot
.708 .21307 Mdot
.708 .21332 Mdot
.708 .21384 Mdot
.708 .214 Mdot
.708 .21401 Mdot
.708 .21454 Mdot
.708 .21459 Mdot
.708 .21564 Mdot
.708 .21639 Mdot
.708 .21676 Mdot
.708 .21697 Mdot
.708 .21706 Mdot
.708 .21806 Mdot
.708 .21818 Mdot
.708 .21857 Mdot
.708 .22025 Mdot
.708 .2203 Mdot
.708 .22063 Mdot
.708 .22137 Mdot
.708 .22153 Mdot
.708 .22218 Mdot
.708 .22342 Mdot
.708 .22429 Mdot
.708 .22439 Mdot
.708 .22538 Mdot
.708 .22596 Mdot
.708 .22656 Mdot
.708 .22709 Mdot
.708 .22721 Mdot
.708 .22749 Mdot
.708 .22866 Mdot
.708 .22872 Mdot
.708 .22891 Mdot
.708 .22932 Mdot
.708 .22996 Mdot
.708 .23008 Mdot
.708 .23245 Mdot
.708 .23246 Mdot
.708 .23263 Mdot
.708 .23348 Mdot
.708 .23399 Mdot
.708 .23399 Mdot
.708 .23401 Mdot
.708 .23402 Mdot
.708 .23413 Mdot
.708 .23421 Mdot
.708 .23429 Mdot
.708 .23431 Mdot
.708 .2344 Mdot
.708 .23456 Mdot
.708 .23467 Mdot
.708 .23476 Mdot
.708 .23494 Mdot
.708 .23525 Mdot
.708 .23531 Mdot
.708 .23545 Mdot
.708 .23554 Mdot
.708 .23587 Mdot
.708 .23601 Mdot
.708 .2361 Mdot
.708 .23619 Mdot
.708 .23627 Mdot
.708 .23632 Mdot
.708 .23649 Mdot
.708 .23653 Mdot
.708 .23668 Mdot
.708 .23704 Mdot
.708 .23707 Mdot
.708 .23719 Mdot
.708 .23726 Mdot
.708 .2377 Mdot
.708 .23785 Mdot
.708 .2381 Mdot
.708 .23842 Mdot
.708 .23926 Mdot
.708 .23946 Mdot
.708 .23978 Mdot
.708 .23985 Mdot
.708 .24081 Mdot
.708 .24106 Mdot
.708 .24123 Mdot
.708 .24132 Mdot
.708 .24178 Mdot
.708 .24189 Mdot
.708 .24194 Mdot
.708 .24215 Mdot
.708 .24238 Mdot
.708 .24262 Mdot
.708 .24301 Mdot
.708 .24305 Mdot
.708 .24389 Mdot
.708 .24415 Mdot
.708 .24422 Mdot
.708 .24452 Mdot
.708 .24465 Mdot
.708 .24468 Mdot
.708 .24552 Mdot
.708 .24557 Mdot
.708 .24602 Mdot
.708 .2461 Mdot
.708 .24626 Mdot
.708 .24657 Mdot
.708 .24701 Mdot
.708 .24703 Mdot
.708 .24726 Mdot
.708 .24732 Mdot
.708 .24754 Mdot
.708 .24776 Mdot
.708 .2478 Mdot
.708 .24804 Mdot
.708 .24807 Mdot
.708 .24814 Mdot
.708 .24815 Mdot
.708 .24816 Mdot
.708 .24871 Mdot
.708 .2493 Mdot
.708 .24948 Mdot
.708 .24954 Mdot
.708 .25036 Mdot
.708 .2519 Mdot
.708 .25237 Mdot
.708 .2524 Mdot
.708 .25682 Mdot
.708 .25762 Mdot
.708 .25796 Mdot
.708 .25909 Mdot
.708 .25941 Mdot
.708 .25945 Mdot
.708 .25957 Mdot
.708 .26103 Mdot
.708 .26124 Mdot
.708 .26171 Mdot
.708 .26195 Mdot
.708 .26243 Mdot
.708 .26263 Mdot
.708 .26297 Mdot
.708 .26314 Mdot
.708 .26455 Mdot
.708 .26571 Mdot
.708 .2665 Mdot
.708 .26651 Mdot
.708 .26734 Mdot
.708 .2677 Mdot
.708 .26923 Mdot
.708 .27005 Mdot
.708 .27068 Mdot
.708 .27098 Mdot
.708 .27103 Mdot
.708 .27215 Mdot
.708 .2727 Mdot
.708 .27564 Mdot
.708 .27592 Mdot
.708 .27646 Mdot
.708 .27676 Mdot
.708 .27703 Mdot
.708 .27775 Mdot
.708 .27851 Mdot
.708 .27997 Mdot
.708 .28114 Mdot
.708 .28219 Mdot
.708 .28222 Mdot
.708 .28418 Mdot
.708 .28442 Mdot
.708 .28466 Mdot
.708 .28537 Mdot
.708 .28545 Mdot
.708 .2858 Mdot
.708 .28692 Mdot
.708 .28792 Mdot
.708 .28808 Mdot
.708 .29083 Mdot
.708 .29175 Mdot
.708 .29199 Mdot
.708 .29323 Mdot
.708 .29417 Mdot
.708 .29441 Mdot
.708 .2948 Mdot
.708 .29524 Mdot
.708 .29759 Mdot
.708 .29789 Mdot
.708 .29817 Mdot
.708 .29879 Mdot
.708 .29916 Mdot
.708 .29995 Mdot
.708 .30231 Mdot
.708 .30447 Mdot
.708 .30546 Mdot
.708 .30557 Mdot
.708 .30573 Mdot
.708 .30665 Mdot
.708 .30717 Mdot
.708 .30739 Mdot
.708 .30745 Mdot
.708 .30793 Mdot
.708 .30893 Mdot
.708 .30951 Mdot
.708 .30958 Mdot
.708 .31036 Mdot
.708 .31118 Mdot
.708 .31153 Mdot
.708 .31181 Mdot
.708 .31316 Mdot
.708 .31332 Mdot
.708 .31338 Mdot
.708 .31353 Mdot
.708 .31402 Mdot
.708 .31412 Mdot
.708 .31417 Mdot
.708 .31461 Mdot
.708 .31501 Mdot
.708 .31828 Mdot
.708 .31866 Mdot
.708 .31953 Mdot
.708 .31966 Mdot
.708 .32247 Mdot
.708 .3227 Mdot
.708 .32321 Mdot
.708 .32404 Mdot
.708 .32452 Mdot
.708 .325 Mdot
.708 .32727 Mdot
.708 .32814 Mdot
.708 .32835 Mdot
.708 .32878 Mdot
.708 .32895 Mdot
.708 .32897 Mdot
.708 .32903 Mdot
.708 .33053 Mdot
.708 .33239 Mdot
.708 .33302 Mdot
.708 .33575 Mdot
.708 .33584 Mdot
.708 .33585 Mdot
.708 .33677 Mdot
.708 .33677 Mdot
.708 .34071 Mdot
.708 .34079 Mdot
.708 .34134 Mdot
.708 .34188 Mdot
.708 .3453 Mdot
.708 .34552 Mdot
.708 .34577 Mdot
.708 .3474 Mdot
.708 .35086 Mdot
.708 .35749 Mdot
.708 .35898 Mdot
.708 .36376 Mdot
.708 .36734 Mdot
.708 .368 Mdot
.708 .36914 Mdot
.708 .36982 Mdot
.708 .37039 Mdot
.708 .37078 Mdot
.708 .37205 Mdot
.708 .37267 Mdot
.708 .37464 Mdot
.708 .37673 Mdot
.708 .37726 Mdot
.708 .37819 Mdot
.708 .37877 Mdot
.708 .37878 Mdot
.708 .37878 Mdot
.708 .37882 Mdot
.708 .37885 Mdot
.708 .37888 Mdot
.708 .37889 Mdot
.708 .37893 Mdot
.708 .37899 Mdot
.708 .37903 Mdot
.708 .37907 Mdot
.708 .37914 Mdot
.708 .37925 Mdot
.708 .37928 Mdot
.708 .37933 Mdot
.708 .37936 Mdot
.708 .37949 Mdot
.708 .37958 Mdot
.708 .37964 Mdot
.708 .37966 Mdot
.708 .37973 Mdot
.708 .37974 Mdot
.708 .3798 Mdot
.708 .37994 Mdot
.708 .37999 Mdot
.708 .38002 Mdot
.708 .38024 Mdot
.708 .38045 Mdot
.708 .38144 Mdot
.708 .38175 Mdot
.708 .38218 Mdot
.708 .38261 Mdot
.708 .38277 Mdot
.708 .38311 Mdot
.708 .3833 Mdot
.708 .38364 Mdot
.708 .38392 Mdot
.708 .38405 Mdot
.708 .38425 Mdot
.708 .38446 Mdot
.708 .38453 Mdot
.708 .38485 Mdot
.708 .38716 Mdot
.708 .38744 Mdot
.708 .38756 Mdot
.708 .38808 Mdot
.708 .38812 Mdot
.708 .38864 Mdot
.708 .38887 Mdot
.708 .38896 Mdot
.708 .3892 Mdot
.708 .38986 Mdot
.708 .39026 Mdot
.708 .39054 Mdot
.708 .39175 Mdot
.708 .39197 Mdot
.708 .39209 Mdot
.708 .39247 Mdot
.708 .39392 Mdot
.708 .39403 Mdot
.708 .39411 Mdot
.708 .39436 Mdot
.708 .3951 Mdot
.708 .39549 Mdot
.708 .39584 Mdot
.708 .39658 Mdot
.708 .39689 Mdot
.708 .39692 Mdot
.708 .39703 Mdot
.708 .39869 Mdot
.708 .39898 Mdot
.708 .39906 Mdot
.708 .39977 Mdot
.708 .40012 Mdot
.708 .40088 Mdot
.708 .40138 Mdot
.708 .40309 Mdot
.708 .4034 Mdot
.708 .40378 Mdot
.708 .40395 Mdot
.708 .40451 Mdot
.708 .40469 Mdot
.708 .40542 Mdot
.708 .40585 Mdot
.708 .40591 Mdot
.708 .40643 Mdot
.708 .40757 Mdot
.708 .40785 Mdot
.708 .40876 Mdot
.708 .40899 Mdot
.708 .40955 Mdot
.708 .41026 Mdot
.708 .41059 Mdot
.708 .41072 Mdot
.708 .41078 Mdot
.708 .41078 Mdot
.708 .4108 Mdot
.708 .41184 Mdot
.708 .41288 Mdot
.708 .41291 Mdot
.708 .41291 Mdot
.708 .41319 Mdot
.708 .41319 Mdot
.708 .4144 Mdot
.708 .41443 Mdot
.708 .4146 Mdot
.708 .41595 Mdot
.708 .41645 Mdot
.708 .41751 Mdot
.708 .41953 Mdot
.708 .42143 Mdot
.708 .42251 Mdot
.708 .42271 Mdot
.708 .42306 Mdot
.708 .42326 Mdot
.708 .42344 Mdot
.708 .42356 Mdot
.708 .42394 Mdot
.708 .42413 Mdot
.708 .42472 Mdot
.708 .42552 Mdot
.708 .4258 Mdot
.708 .42612 Mdot
.708 .42619 Mdot
.708 .42629 Mdot
.708 .42678 Mdot
.708 .42688 Mdot
.708 .42904 Mdot
.708 .43213 Mdot
.708 .43245 Mdot
.708 .43473 Mdot
.708 .43481 Mdot
.708 .43516 Mdot
.708 .43533 Mdot
.708 .43604 Mdot
.708 .43635 Mdot
.708 .43682 Mdot
.708 .43688 Mdot
.708 .43949 Mdot
.708 .43961 Mdot
.708 .43965 Mdot
.708 .44047 Mdot
.708 .4405 Mdot
.708 .44065 Mdot
.708 .44135 Mdot
.708 .44232 Mdot
.708 .44327 Mdot
.708 .44467 Mdot
.708 .44916 Mdot
.708 .45022 Mdot
.708 .45071 Mdot
.708 .45119 Mdot
.708 .45268 Mdot
.708 .45271 Mdot
.708 .45361 Mdot
.708 .45507 Mdot
.708 .45524 Mdot
.708 .45688 Mdot
.708 .45807 Mdot
.708 .45833 Mdot
.708 .45838 Mdot
.708 .45858 Mdot
.708 .45975 Mdot
.708 .45981 Mdot
.708 .46001 Mdot
.708 .46286 Mdot
.708 .46339 Mdot
.708 .46433 Mdot
.708 .46441 Mdot
.708 .46442 Mdot
.708 .46503 Mdot
.708 .46519 Mdot
.708 .46571 Mdot
.708 .46649 Mdot
.708 .46684 Mdot
.708 .46712 Mdot
.708 .46723 Mdot
.708 .46769 Mdot
.708 .46782 Mdot
.708 .46867 Mdot
.708 .46932 Mdot
.708 .47084 Mdot
.708 .47145 Mdot
.708 .47195 Mdot
.708 .47384 Mdot
.708 .4742 Mdot
.708 .47431 Mdot
.708 .47532 Mdot
.708 .47542 Mdot
.708 .47677 Mdot
.708 .47881 Mdot
.708 .47986 Mdot
.708 .48006 Mdot
.708 .4802 Mdot
.708 .48095 Mdot
.708 .48109 Mdot
.708 .48119 Mdot
.708 .48168 Mdot
.708 .48209 Mdot
.708 .48233 Mdot
.708 .48327 Mdot
.708 .48415 Mdot
.708 .48443 Mdot
.708 .48499 Mdot
.708 .48517 Mdot
.708 .48542 Mdot
.708 .48572 Mdot
.708 .48623 Mdot
.708 .48652 Mdot
.708 .48809 Mdot
.708 .49016 Mdot
.708 .4908 Mdot
.708 .49363 Mdot
.708 .49509 Mdot
.708 .49577 Mdot
.708 .49588 Mdot
.708 .49597 Mdot
.708 .49739 Mdot
.708 .49761 Mdot
.708 .49784 Mdot
.708 .49788 Mdot
.708 .4995 Mdot
.708 .4995 Mdot
.708 .49988 Mdot
.708 .49988 Mdot
.708 .49992 Mdot
.708 .50103 Mdot
.708 .50129 Mdot
.708 .50204 Mdot
.708 .50265 Mdot
.708 .50267 Mdot
.708 .50268 Mdot
.708 .50275 Mdot
.708 .50292 Mdot
.708 .50301 Mdot
.708 .50336 Mdot
.708 .50427 Mdot
.708 .50446 Mdot
.708 .50465 Mdot
.708 .50499 Mdot
.708 .50519 Mdot
.708 .50528 Mdot
.708 .50639 Mdot
.708 .50644 Mdot
.708 .50679 Mdot
.708 .50694 Mdot
.708 .50823 Mdot
.708 .50838 Mdot
.708 .50855 Mdot
.708 .50858 Mdot
.708 .50861 Mdot
.708 .50881 Mdot
.708 .50887 Mdot
.708 .50889 Mdot
.708 .50895 Mdot
.708 .50948 Mdot
.708 .50959 Mdot
.708 .50972 Mdot
.708 .51004 Mdot
.708 .51034 Mdot
.708 .51037 Mdot
.708 .5106 Mdot
.708 .51098 Mdot
.708 .51117 Mdot
.708 .51119 Mdot
.708 .51128 Mdot
.708 .51148 Mdot
.708 .51183 Mdot
.708 .5119 Mdot
.708 .51194 Mdot
.708 .51232 Mdot
.708 .51315 Mdot
.708 .51405 Mdot
.708 .51435 Mdot
.708 .51449 Mdot
.708 .51473 Mdot
.708 .51483 Mdot
.708 .51495 Mdot
.708 .51584 Mdot
.708 .516 Mdot
.708 .51615 Mdot
.708 .51624 Mdot
.708 .51659 Mdot
.708 .51706 Mdot
.708 .51715 Mdot
.708 .51749 Mdot
.708 .51852 Mdot
.708 .51858 Mdot
.708 .51896 Mdot
.708 .51937 Mdot
.708 .5195 Mdot
.708 .51953 Mdot
.708 .51979 Mdot
.708 .51988 Mdot
.708 .51997 Mdot
.708 .5207 Mdot
.708 .52071 Mdot
.708 .52109 Mdot
.708 .52153 Mdot
.708 .52206 Mdot
.708 .52234 Mdot
.708 .52261 Mdot
.708 .5227 Mdot
.708 .52281 Mdot
.708 .52301 Mdot
.708 .52311 Mdot
.708 .52418 Mdot
.708 .52438 Mdot
.708 .52479 Mdot
.708 .52481 Mdot
.708 .52491 Mdot
.708 .52514 Mdot
.708 .52544 Mdot
.708 .52599 Mdot
.708 .52612 Mdot
.708 .52642 Mdot
.708 .52642 Mdot
.708 .5267 Mdot
.708 .52712 Mdot
.708 .52763 Mdot
.708 .52769 Mdot
.708 .52781 Mdot
.708 .52788 Mdot
.708 .52805 Mdot
.708 .52814 Mdot
.708 .5283 Mdot
.708 .52838 Mdot
.708 .5289 Mdot
.708 .52894 Mdot
.708 .52895 Mdot
.708 .52907 Mdot
.708 .52947 Mdot
.708 .52959 Mdot
.708 .52988 Mdot
.708 .53143 Mdot
.708 .53144 Mdot
.708 .53161 Mdot
.708 .53215 Mdot
.708 .53243 Mdot
.708 .53246 Mdot
.708 .53252 Mdot
.708 .53273 Mdot
.708 .53292 Mdot
.708 .53292 Mdot
.708 .53293 Mdot
.708 .53295 Mdot
.708 .53296 Mdot
.708 .53304 Mdot
.708 .53306 Mdot
.708 .53313 Mdot
.708 .53321 Mdot
.708 .53323 Mdot
.708 .53331 Mdot
.708 .53332 Mdot
.708 .53347 Mdot
.708 .53358 Mdot
.708 .53363 Mdot
.708 .53366 Mdot
.708 .53382 Mdot
.708 .53384 Mdot
.708 .53413 Mdot
.708 .53414 Mdot
.708 .53418 Mdot
.708 .53429 Mdot
.708 .53431 Mdot
.708 .5344 Mdot
.708 .53469 Mdot
.708 .53471 Mdot
.708 .53484 Mdot
.708 .53492 Mdot
.708 .53501 Mdot
.708 .53508 Mdot
.708 .53509 Mdot
.708 .53513 Mdot
.708 .53529 Mdot
.708 .53532 Mdot
.708 .53538 Mdot
.708 .53547 Mdot
.708 .5358 Mdot
.708 .53582 Mdot
.708 .53593 Mdot
.708 .536 Mdot
.708 .53629 Mdot
.708 .5364 Mdot
.708 .53649 Mdot
.708 .53654 Mdot
.708 .53669 Mdot
.708 .53671 Mdot
.708 .53675 Mdot
.708 .53676 Mdot
.708 .53689 Mdot
.708 .53694 Mdot
.708 .53695 Mdot
.708 .53701 Mdot
.708 .53703 Mdot
.708 .53706 Mdot
.708 .53709 Mdot
.708 .53717 Mdot
.708 .53728 Mdot
.708 .53731 Mdot
.708 .53736 Mdot
.708 .53738 Mdot
.708 .53748 Mdot
.708 .53755 Mdot
.708 .53758 Mdot
.708 .53761 Mdot
.708 .53767 Mdot
.708 .5377 Mdot
.708 .53771 Mdot
.708 .53774 Mdot
.708 .53776 Mdot
.708 .5378 Mdot
.708 .5378 Mdot
.708 .53781 Mdot
.708 .53781 Mdot
.708 .53798 Mdot
.708 .53827 Mdot
.708 .53833 Mdot
.708 .53833 Mdot
.708 .53914 Mdot
.708 .53918 Mdot
.708 .5394 Mdot
.708 .53954 Mdot
.708 .5396 Mdot
.708 .53962 Mdot
.708 .54002 Mdot
.708 .54011 Mdot
.708 .54016 Mdot
.708 .54033 Mdot
.708 .54053 Mdot
.708 .54073 Mdot
.708 .54107 Mdot
.708 .5411 Mdot
.708 .54139 Mdot
.708 .54181 Mdot
.708 .54202 Mdot
.708 .54208 Mdot
.708 .54233 Mdot
.708 .54244 Mdot
.708 .54246 Mdot
.708 .54302 Mdot
.708 .54315 Mdot
.708 .54319 Mdot
.708 .54352 Mdot
.708 .54355 Mdot
.708 .54362 Mdot
.708 .54374 Mdot
.708 .54399 Mdot
.708 .54434 Mdot
.708 .54436 Mdot
.708 .54453 Mdot
.708 .54454 Mdot
.708 .54459 Mdot
.708 .54476 Mdot
.708 .54484 Mdot
.708 .54493 Mdot
.708 .54497 Mdot
.708 .54515 Mdot
.708 .54518 Mdot
.708 .54523 Mdot
.708 .54524 Mdot
.708 .54524 Mdot
.708 .54529 Mdot
.708 .54567 Mdot
.708 .54581 Mdot
.708 .54613 Mdot
.708 .54626 Mdot
.708 .54631 Mdot
.708 .54668 Mdot
.708 .54693 Mdot
.708 .54718 Mdot
.708 .54807 Mdot
.708 .54841 Mdot
.708 .54843 Mdot
.708 .54977 Mdot
.708 .55151 Mdot
.708 .55204 Mdot
.708 .55226 Mdot
.708 .55297 Mdot
.708 .55299 Mdot
.708 .5532 Mdot
.708 .55322 Mdot
.708 .5533 Mdot
.708 .55391 Mdot
.708 .55421 Mdot
.708 .55434 Mdot
.708 .55463 Mdot
.708 .55477 Mdot
.708 .55506 Mdot
.708 .55518 Mdot
.708 .55538 Mdot
.708 .55548 Mdot
.708 .55629 Mdot
.708 .55695 Mdot
.708 .55738 Mdot
.708 .55738 Mdot
.708 .55774 Mdot
.708 .55783 Mdot
.708 .55802 Mdot
.708 .55882 Mdot
.708 .55923 Mdot
.708 .55952 Mdot
.708 .55954 Mdot
.708 .55969 Mdot
.708 .55971 Mdot
.708 .56025 Mdot
.708 .5603 Mdot
.708 .56042 Mdot
.708 .56051 Mdot
.708 .56052 Mdot
.708 .56181 Mdot
.708 .56194 Mdot
.708 .56203 Mdot
.708 .56216 Mdot
.708 .56226 Mdot
.708 .56229 Mdot
.708 .5624 Mdot
.708 .56248 Mdot
.708 .56252 Mdot
.708 .56269 Mdot
.708 .56299 Mdot
.708 .56355 Mdot
.708 .56397 Mdot
.708 .56402 Mdot
.708 .56402 Mdot
.708 .56434 Mdot
.708 .56434 Mdot
.708 .56434 Mdot
.708 .56435 Mdot
.708 .56437 Mdot
.708 .565 Mdot
.708 .56508 Mdot
.708 .56515 Mdot
.708 .56526 Mdot
.708 .56537 Mdot
.708 .56539 Mdot
.708 .56545 Mdot
.708 .5655 Mdot
.708 .56582 Mdot
.708 .56598 Mdot
.708 .5661 Mdot
.708 .56614 Mdot
.708 .56638 Mdot
.708 .5664 Mdot
.708 .5664 Mdot
.708 .56645 Mdot
.708 .56655 Mdot
.708 .5666 Mdot
.708 .56681 Mdot
.708 .56683 Mdot
.708 .56704 Mdot
.708 .56709 Mdot
.708 .56731 Mdot
.708 .56735 Mdot
.708 .56741 Mdot
.708 .5675 Mdot
.708 .56753 Mdot
.708 .56758 Mdot
.708 .56765 Mdot
.708 .56766 Mdot
.708 .56773 Mdot
.708 .56775 Mdot
.708 .56779 Mdot
.708 .56811 Mdot
.708 .56815 Mdot
.708 .56819 Mdot
.708 .56822 Mdot
.708 .56824 Mdot
.708 .56828 Mdot
.708 .56832 Mdot
.708 .56835 Mdot
.708 .5684 Mdot
.708 .56842 Mdot
.708 .56866 Mdot
.708 .56871 Mdot
.708 .56874 Mdot
.708 .56877 Mdot
.708 .56878 Mdot
.708 .56878 Mdot
.708 .56881 Mdot
.708 .56881 Mdot
.708 .56882 Mdot
.708 .56883 Mdot
.708 .56883 Mdot
.708 .56886 Mdot
.708 .56887 Mdot
.708 .56888 Mdot
.708 .56889 Mdot
.708 .5689 Mdot
.708 .56891 Mdot
.708 .56891 Mdot
.708 .56892 Mdot
.708 .56893 Mdot
.708 .56893 Mdot
.708 .56893 Mdot
.708 .56894 Mdot
.708 .56894 Mdot
.708 .56894 Mdot
.708 .56894 Mdot
.71 .13589 Mdot
.71 .13589 Mdot
.71 .1359 Mdot
.71 .13598 Mdot
.71 .13601 Mdot
.71 .13607 Mdot
.71 .13619 Mdot
.71 .13622 Mdot
.71 .13629 Mdot
.71 .13634 Mdot
.71 .13638 Mdot
.71 .1365 Mdot
.71 .13652 Mdot
.71 .13656 Mdot
.71 .13661 Mdot
.71 .13664 Mdot
.71 .13677 Mdot
.71 .1369 Mdot
.71 .13712 Mdot
.71 .13744 Mdot
.71 .13766 Mdot
.71 .13772 Mdot
.71 .13782 Mdot
.71 .13851 Mdot
.71 .13869 Mdot
.71 .13873 Mdot
.71 .13882 Mdot
.71 .139 Mdot
.71 .13903 Mdot
.71 .13909 Mdot
.71 .13915 Mdot
.71 .1392 Mdot
.71 .13953 Mdot
.71 .13965 Mdot
.71 .13967 Mdot
.71 .14028 Mdot
.71 .14041 Mdot
.71 .14133 Mdot
.71 .14171 Mdot
.71 .14246 Mdot
.71 .14251 Mdot
.71 .14262 Mdot
.71 .1429 Mdot
.71 .1429 Mdot
.71 .14292 Mdot
.71 .14436 Mdot
.71 .14437 Mdot
.71 .14459 Mdot
.71 .14482 Mdot
.71 .14511 Mdot
.71 .14598 Mdot
.71 .14614 Mdot
.71 .14645 Mdot
.71 .14678 Mdot
.71 .14679 Mdot
.71 .14684 Mdot
.71 .14728 Mdot
.71 .1473 Mdot
.71 .14781 Mdot
.71 .14797 Mdot
.71 .148 Mdot
.71 .14903 Mdot
.71 .14915 Mdot
.71 .14953 Mdot
.71 .15049 Mdot
.71 .15072 Mdot
.71 .15191 Mdot
.71 .15206 Mdot
.71 .15214 Mdot
.71 .15227 Mdot
.71 .15238 Mdot
.71 .15294 Mdot
.71 .15313 Mdot
.71 .15339 Mdot
.71 .154 Mdot
.71 .1546 Mdot
.71 .15546 Mdot
.71 .15557 Mdot
.71 .15604 Mdot
.71 .15632 Mdot
.71 .15932 Mdot
.71 .15949 Mdot
.71 .1608 Mdot
.71 .16116 Mdot
.71 .16134 Mdot
.71 .1629 Mdot
.71 .16304 Mdot
.71 .16468 Mdot
.71 .16482 Mdot
.71 .16482 Mdot
.71 .16524 Mdot
.71 .16663 Mdot
.71 .16758 Mdot
.71 .16776 Mdot
.71 .16867 Mdot
.71 .169 Mdot
.71 .16923 Mdot
.71 .16977 Mdot
.71 .1716 Mdot
.71 .17509 Mdot
.71 .17578 Mdot
.71 .176 Mdot
.71 .17728 Mdot
.71 .17731 Mdot
.71 .17816 Mdot
.71 .179 Mdot
.71 .18129 Mdot
.71 .18142 Mdot
.71 .18162 Mdot
.71 .18186 Mdot
.71 .18196 Mdot
.71 .18238 Mdot
.71 .18295 Mdot
.71 .18406 Mdot
.71 .18412 Mdot
.71 .18584 Mdot
.71 .1859 Mdot
.71 .18613 Mdot
.71 .18646 Mdot
.71 .18881 Mdot
.71 .18975 Mdot
.71 .19127 Mdot
.71 .19166 Mdot
.71 .19167 Mdot
.71 .19289 Mdot
.71 .19305 Mdot
.71 .19317 Mdot
.71 .19417 Mdot
.71 .19449 Mdot
.71 .19465 Mdot
.71 .19585 Mdot
.71 .19632 Mdot
.71 .19713 Mdot
.71 .19848 Mdot
.71 .19882 Mdot
.71 .1993 Mdot
.71 .19944 Mdot
.71 .20105 Mdot
.71 .20221 Mdot
.71 .20224 Mdot
.71 .20257 Mdot
.71 .20261 Mdot
.71 .20297 Mdot
.71 .20369 Mdot
.71 .20447 Mdot
.71 .20475 Mdot
.71 .20704 Mdot
.71 .20768 Mdot
.71 .20818 Mdot
.71 .20836 Mdot
.71 .20918 Mdot
.71 .2092 Mdot
.71 .20988 Mdot
.71 .21068 Mdot
.71 .2112 Mdot
.71 .21134 Mdot
.71 .2115 Mdot
.71 .212 Mdot
.71 .21211 Mdot
.71 .21262 Mdot
.71 .21455 Mdot
.71 .21515 Mdot
.71 .21578 Mdot
.71 .2164 Mdot
.71 .21703 Mdot
.71 .21724 Mdot
.71 .21907 Mdot
.71 .21979 Mdot
.71 .22234 Mdot
.71 .22328 Mdot
.71 .22422 Mdot
.71 .22559 Mdot
.71 .22656 Mdot
.71 .22693 Mdot
.71 .22776 Mdot
.71 .2289 Mdot
.71 .22931 Mdot
.71 .22962 Mdot
.71 .22963 Mdot
.71 .22967 Mdot
.71 .23014 Mdot
.71 .2303 Mdot
.71 .23056 Mdot
.71 .23063 Mdot
.71 .23063 Mdot
.71 .23089 Mdot
.71 .23113 Mdot
.71 .23133 Mdot
.71 .23155 Mdot
.71 .23177 Mdot
.71 .2319 Mdot
.71 .23218 Mdot
.71 .23243 Mdot
.71 .23261 Mdot
.71 .23313 Mdot
.71 .23323 Mdot
.71 .23331 Mdot
.71 .23334 Mdot
.71 .23347 Mdot
.71 .23378 Mdot
.71 .23392 Mdot
.71 .2347 Mdot
.71 .23508 Mdot
.71 .23545 Mdot
.71 .23607 Mdot
.71 .23612 Mdot
.71 .23624 Mdot
.71 .23673 Mdot
.71 .23819 Mdot
.71 .23864 Mdot
.71 .23958 Mdot
.71 .2399 Mdot
.71 .24014 Mdot
.71 .24024 Mdot
.71 .24034 Mdot
.71 .24085 Mdot
.71 .24101 Mdot
.71 .24145 Mdot
.71 .24178 Mdot
.71 .24192 Mdot
.71 .2436 Mdot
.71 .24463 Mdot
.71 .24492 Mdot
.71 .24566 Mdot
.71 .24601 Mdot
.71 .24627 Mdot
.71 .24678 Mdot
.71 .2478 Mdot
.71 .24785 Mdot
.71 .24806 Mdot
.71 .24819 Mdot
.71 .24841 Mdot
.71 .24875 Mdot
.71 .24904 Mdot
.71 .24905 Mdot
.71 .2494 Mdot
.71 .24948 Mdot
.71 .24969 Mdot
.71 .24997 Mdot
.71 .25109 Mdot
.71 .25144 Mdot
.71 .25176 Mdot
.71 .25192 Mdot
.71 .25194 Mdot
.71 .2521 Mdot
.71 .25262 Mdot
.71 .25335 Mdot
.71 .25342 Mdot
.71 .25379 Mdot
.71 .25441 Mdot
.71 .25501 Mdot
.71 .25557 Mdot
.71 .25565 Mdot
.71 .2558 Mdot
.71 .25628 Mdot
.71 .25641 Mdot
.71 .257 Mdot
.71 .257 Mdot
.71 .25719 Mdot
.71 .25793 Mdot
.71 .25839 Mdot
.71 .25973 Mdot
.71 .25985 Mdot
.71 .25988 Mdot
.71 .26076 Mdot
.71 .26166 Mdot
.71 .26194 Mdot
.71 .26206 Mdot
.71 .26217 Mdot
.71 .26224 Mdot
.71 .26441 Mdot
.71 .26525 Mdot
.71 .26563 Mdot
.71 .26766 Mdot
.71 .26875 Mdot
.71 .26908 Mdot
.71 .26942 Mdot
.71 .2701 Mdot
.71 .27159 Mdot
.71 .27186 Mdot
.71 .27187 Mdot
.71 .27196 Mdot
.71 .27564 Mdot
.71 .27846 Mdot
.71 .27972 Mdot
.71 .28107 Mdot
.71 .28116 Mdot
.71 .28128 Mdot
.71 .28253 Mdot
.71 .28398 Mdot
.71 .28513 Mdot
.71 .28583 Mdot
.71 .28702 Mdot
.71 .2885 Mdot
.71 .28903 Mdot
.71 .29084 Mdot
.71 .29121 Mdot
.71 .29136 Mdot
.71 .29143 Mdot
.71 .29247 Mdot
.71 .29444 Mdot
.71 .29464 Mdot
.71 .29655 Mdot
.71 .29665 Mdot
.71 .29686 Mdot
.71 .29693 Mdot
.71 .29729 Mdot
.71 .29755 Mdot
.71 .29949 Mdot
.71 .29975 Mdot
.71 .2999 Mdot
.71 .30142 Mdot
.71 .30319 Mdot
.71 .30341 Mdot
.71 .30423 Mdot
.71 .30444 Mdot
.71 .30527 Mdot
.71 .30899 Mdot
.71 .30929 Mdot
.71 .30966 Mdot
.71 .31108 Mdot
.71 .31138 Mdot
.71 .31189 Mdot
.71 .31299 Mdot
.71 .31333 Mdot
.71 .31437 Mdot
.71 .31445 Mdot
.71 .31494 Mdot
.71 .31545 Mdot
.71 .31591 Mdot
.71 .31756 Mdot
.71 .3201 Mdot
.71 .32057 Mdot
.71 .32128 Mdot
.71 .32211 Mdot
.71 .3223 Mdot
.71 .32235 Mdot
.71 .32501 Mdot
.71 .32556 Mdot
.71 .32719 Mdot
.71 .32721 Mdot
.71 .32902 Mdot
.71 .32927 Mdot
.71 .32987 Mdot
.71 .33084 Mdot
.71 .33134 Mdot
.71 .33169 Mdot
.71 .3317 Mdot
.71 .33175 Mdot
.71 .33223 Mdot
.71 .33274 Mdot
.71 .33293 Mdot
.71 .33393 Mdot
.71 .33529 Mdot
.71 .33656 Mdot
.71 .33669 Mdot
.71 .33744 Mdot
.71 .3376 Mdot
.71 .33781 Mdot
.71 .3388 Mdot
.71 .33949 Mdot
.71 .33994 Mdot
.71 .34016 Mdot
.71 .34252 Mdot
.71 .34345 Mdot
.71 .3437 Mdot
.71 .34383 Mdot
.71 .34489 Mdot
.71 .34499 Mdot
.71 .34733 Mdot
.71 .34805 Mdot
.71 .34881 Mdot
.71 .35291 Mdot
.71 .35364 Mdot
.71 .35411 Mdot
.71 .35457 Mdot
.71 .35615 Mdot
.71 .35666 Mdot
.71 .35724 Mdot
.71 .35847 Mdot
.71 .3617 Mdot
.71 .36324 Mdot
.71 .3644 Mdot
.71 .36595 Mdot
.71 .36706 Mdot
.71 .36991 Mdot
.71 .37045 Mdot
.71 .3715 Mdot
.71 .37228 Mdot
.71 .37481 Mdot
.71 .37519 Mdot
.71 .37573 Mdot
.71 .37731 Mdot
.71 .37731 Mdot
.71 .37732 Mdot
.71 .37751 Mdot
.71 .37757 Mdot
.71 .37767 Mdot
.71 .3777 Mdot
.71 .37797 Mdot
.71 .37805 Mdot
.71 .37818 Mdot
.71 .37829 Mdot
.71 .37839 Mdot
.71 .37866 Mdot
.71 .3787 Mdot
.71 .37873 Mdot
.71 .37874 Mdot
.71 .37879 Mdot
.71 .3789 Mdot
.71 .37896 Mdot
.71 .37925 Mdot
.71 .37954 Mdot
.71 .37977 Mdot
.71 .37979 Mdot
.71 .38002 Mdot
.71 .38057 Mdot
.71 .38074 Mdot
.71 .38109 Mdot
.71 .38121 Mdot
.71 .38134 Mdot
.71 .38137 Mdot
.71 .38156 Mdot
.71 .38162 Mdot
.71 .38306 Mdot
.71 .38346 Mdot
.71 .38356 Mdot
.71 .38374 Mdot
.71 .38413 Mdot
.71 .38421 Mdot
.71 .38433 Mdot
.71 .38446 Mdot
.71 .38456 Mdot
.71 .3853 Mdot
.71 .38554 Mdot
.71 .3856 Mdot
.71 .38566 Mdot
.71 .38611 Mdot
.71 .38693 Mdot
.71 .38698 Mdot
.71 .38719 Mdot
.71 .38903 Mdot
.71 .38917 Mdot
.71 .38921 Mdot
.71 .38923 Mdot
.71 .38999 Mdot
.71 .39041 Mdot
.71 .39159 Mdot
.71 .39171 Mdot
.71 .39194 Mdot
.71 .39254 Mdot
.71 .39254 Mdot
.71 .39257 Mdot
.71 .39517 Mdot
.71 .39562 Mdot
.71 .39565 Mdot
.71 .39611 Mdot
.71 .39659 Mdot
.71 .39697 Mdot
.71 .3972 Mdot
.71 .39759 Mdot
.71 .39807 Mdot
.71 .39884 Mdot
.71 .399 Mdot
.71 .39903 Mdot
.71 .39936 Mdot
.71 .4 Mdot
.71 .40007 Mdot
.71 .40069 Mdot
.71 .40072 Mdot
.71 .40081 Mdot
.71 .40092 Mdot
.71 .40172 Mdot
.71 .40176 Mdot
.71 .40282 Mdot
.71 .40315 Mdot
.71 .40321 Mdot
.71 .40466 Mdot
.71 .40475 Mdot
.71 .40487 Mdot
.71 .40532 Mdot
.71 .40558 Mdot
.71 .40636 Mdot
.71 .40638 Mdot
.71 .4083 Mdot
.71 .40852 Mdot
.71 .40877 Mdot
.71 .41036 Mdot
.71 .41092 Mdot
.71 .41118 Mdot
.71 .41148 Mdot
.71 .41164 Mdot
.71 .41174 Mdot
.71 .41175 Mdot
.71 .41176 Mdot
.71 .41191 Mdot
.71 .41207 Mdot
.71 .41213 Mdot
.71 .41243 Mdot
.71 .41285 Mdot
.71 .41324 Mdot
.71 .41351 Mdot
.71 .41363 Mdot
.71 .41393 Mdot
.71 .41414 Mdot
.71 .41428 Mdot
.71 .41535 Mdot
.71 .41654 Mdot
.71 .41675 Mdot
.71 .41823 Mdot
.71 .41845 Mdot
.71 .41937 Mdot
.71 .41992 Mdot
.71 .42137 Mdot
.71 .42252 Mdot
.71 .4241 Mdot
.71 .42573 Mdot
.71 .42605 Mdot
.71 .42605 Mdot
.71 .42661 Mdot
.71 .42685 Mdot
.71 .42692 Mdot
.71 .42814 Mdot
.71 .42854 Mdot
.71 .42917 Mdot
.71 .42923 Mdot
.71 .42958 Mdot
.71 .43103 Mdot
.71 .43176 Mdot
.71 .43251 Mdot
.71 .43277 Mdot
.71 .43394 Mdot
.71 .43443 Mdot
.71 .43582 Mdot
.71 .43607 Mdot
.71 .43608 Mdot
.71 .43628 Mdot
.71 .43685 Mdot
.71 .43761 Mdot
.71 .43939 Mdot
.71 .44048 Mdot
.71 .44065 Mdot
.71 .44113 Mdot
.71 .44145 Mdot
.71 .44309 Mdot
.71 .44368 Mdot
.71 .44409 Mdot
.71 .445 Mdot
.71 .44505 Mdot
.71 .4483 Mdot
.71 .45071 Mdot
.71 .45081 Mdot
.71 .45238 Mdot
.71 .4531 Mdot
.71 .4541 Mdot
.71 .45437 Mdot
.71 .45553 Mdot
.71 .45592 Mdot
.71 .45691 Mdot
.71 .45745 Mdot
.71 .45809 Mdot
.71 .45813 Mdot
.71 .45825 Mdot
.71 .45855 Mdot
.71 .45956 Mdot
.71 .46038 Mdot
.71 .46097 Mdot
.71 .46332 Mdot
.71 .46457 Mdot
.71 .46475 Mdot
.71 .46496 Mdot
.71 .46529 Mdot
.71 .4655 Mdot
.71 .46568 Mdot
.71 .46583 Mdot
.71 .46584 Mdot
.71 .46584 Mdot
.71 .46625 Mdot
.71 .46653 Mdot
.71 .46744 Mdot
.71 .46849 Mdot
.71 .46923 Mdot
.71 .46928 Mdot
.71 .46933 Mdot
.71 .47114 Mdot
.71 .47155 Mdot
.71 .47206 Mdot
.71 .47214 Mdot
.71 .47251 Mdot
.71 .47274 Mdot
.71 .47303 Mdot
.71 .47389 Mdot
.71 .47613 Mdot
.71 .47668 Mdot
.71 .47669 Mdot
.71 .47677 Mdot
.71 .47772 Mdot
.71 .47812 Mdot
.71 .47833 Mdot
.71 .48018 Mdot
.71 .4803 Mdot
.71 .48043 Mdot
.71 .48066 Mdot
.71 .48102 Mdot
.71 .48103 Mdot
.71 .4815 Mdot
.71 .4815 Mdot
.71 .48198 Mdot
.71 .48285 Mdot
.71 .4831 Mdot
.71 .48327 Mdot
.71 .4844 Mdot
.71 .48474 Mdot
.71 .48521 Mdot
.71 .48545 Mdot
.71 .48671 Mdot
.71 .48719 Mdot
.71 .48787 Mdot
.71 .48838 Mdot
.71 .48905 Mdot
.71 .49044 Mdot
.71 .49097 Mdot
.71 .49122 Mdot
.71 .49144 Mdot
.71 .49211 Mdot
.71 .49231 Mdot
.71 .49251 Mdot
.71 .49282 Mdot
.71 .49455 Mdot
.71 .49488 Mdot
.71 .49518 Mdot
.71 .49616 Mdot
.71 .4962 Mdot
.71 .49664 Mdot
.71 .49669 Mdot
.71 .4968 Mdot
.71 .49719 Mdot
.71 .49816 Mdot
.71 .49825 Mdot
.71 .49844 Mdot
.71 .49872 Mdot
.71 .49913 Mdot
.71 .49922 Mdot
.71 .49928 Mdot
.71 .49959 Mdot
.71 .49964 Mdot
.71 .50016 Mdot
.71 .50071 Mdot
.71 .50112 Mdot
.71 .5012 Mdot
.71 .50141 Mdot
.71 .5016 Mdot
.71 .50162 Mdot
.71 .50163 Mdot
.71 .50177 Mdot
.71 .50197 Mdot
.71 .50237 Mdot
.71 .50261 Mdot
.71 .50271 Mdot
.71 .50344 Mdot
.71 .50344 Mdot
.71 .5041 Mdot
.71 .50432 Mdot
.71 .50538 Mdot
.71 .5054 Mdot
.71 .50547 Mdot
.71 .5058 Mdot
.71 .50608 Mdot
.71 .50627 Mdot
.71 .50727 Mdot
.71 .50792 Mdot
.71 .5081 Mdot
.71 .5083 Mdot
.71 .5085 Mdot
.71 .50853 Mdot
.71 .50893 Mdot
.71 .50907 Mdot
.71 .50949 Mdot
.71 .50969 Mdot
.71 .50981 Mdot
.71 .51036 Mdot
.71 .51051 Mdot
.71 .51062 Mdot
.71 .51206 Mdot
.71 .51238 Mdot
.71 .51246 Mdot
.71 .51277 Mdot
.71 .51286 Mdot
.71 .51354 Mdot
.71 .51411 Mdot
.71 .51417 Mdot
.71 .51427 Mdot
.71 .51501 Mdot
.71 .51511 Mdot
.71 .51524 Mdot
.71 .51527 Mdot
.71 .51535 Mdot
.71 .51538 Mdot
.71 .51611 Mdot
.71 .51618 Mdot
.71 .51693 Mdot
.71 .51731 Mdot
.71 .51734 Mdot
.71 .51739 Mdot
.71 .51753 Mdot
.71 .51821 Mdot
.71 .51841 Mdot
.71 .51896 Mdot
.71 .5194 Mdot
.71 .51966 Mdot
.71 .52009 Mdot
.71 .52063 Mdot
.71 .52109 Mdot
.71 .52113 Mdot
.71 .52116 Mdot
.71 .52166 Mdot
.71 .52212 Mdot
.71 .52315 Mdot
.71 .52449 Mdot
.71 .52453 Mdot
.71 .52453 Mdot
.71 .52462 Mdot
.71 .52517 Mdot
.71 .52541 Mdot
.71 .52553 Mdot
.71 .52565 Mdot
.71 .52605 Mdot
.71 .52677 Mdot
.71 .52691 Mdot
.71 .52721 Mdot
.71 .52799 Mdot
.71 .52801 Mdot
.71 .52805 Mdot
.71 .52809 Mdot
.71 .52819 Mdot
.71 .52851 Mdot
.71 .52883 Mdot
.71 .52884 Mdot
.71 .52888 Mdot
.71 .52935 Mdot
.71 .52952 Mdot
.71 .52978 Mdot
.71 .52985 Mdot
.71 .52985 Mdot
.71 .53006 Mdot
.71 .5301 Mdot
.71 .53027 Mdot
.71 .53032 Mdot
.71 .53035 Mdot
.71 .53055 Mdot
.71 .53076 Mdot
.71 .53098 Mdot
.71 .53111 Mdot
.71 .53113 Mdot
.71 .53139 Mdot
.71 .53157 Mdot
.71 .53163 Mdot
.71 .53164 Mdot
.71 .53169 Mdot
.71 .5318 Mdot
.71 .53193 Mdot
.71 .53232 Mdot
.71 .53242 Mdot
.71 .53249 Mdot
.71 .53252 Mdot
.71 .53264 Mdot
.71 .53264 Mdot
.71 .53275 Mdot
.71 .53287 Mdot
.71 .53294 Mdot
.71 .53299 Mdot
.71 .53306 Mdot
.71 .53308 Mdot
.71 .53343 Mdot
.71 .53361 Mdot
.71 .5337 Mdot
.71 .53382 Mdot
.71 .53408 Mdot
.71 .53418 Mdot
.71 .53454 Mdot
.71 .53512 Mdot
.71 .53517 Mdot
.71 .53528 Mdot
.71 .53543 Mdot
.71 .53549 Mdot
.71 .53566 Mdot
.71 .5357 Mdot
.71 .53573 Mdot
.71 .53582 Mdot
.71 .53593 Mdot
.71 .53625 Mdot
.71 .5364 Mdot
.71 .5369 Mdot
.71 .53707 Mdot
.71 .53711 Mdot
.71 .53713 Mdot
.71 .53734 Mdot
.71 .53747 Mdot
.71 .5376 Mdot
.71 .53787 Mdot
.71 .53791 Mdot
.71 .53802 Mdot
.71 .53806 Mdot
.71 .53807 Mdot
.71 .5381 Mdot
.71 .53813 Mdot
.71 .53831 Mdot
.71 .53837 Mdot
.71 .53846 Mdot
.71 .53855 Mdot
.71 .5386 Mdot
.71 .53867 Mdot
.71 .53875 Mdot
.71 .53881 Mdot
.71 .5389 Mdot
.71 .53898 Mdot
.71 .53898 Mdot
.71 .53901 Mdot
.71 .5391 Mdot
.71 .53915 Mdot
.71 .53931 Mdot
.71 .53932 Mdot
.71 .53933 Mdot
.71 .53943 Mdot
.71 .53957 Mdot
.71 .53996 Mdot
.71 .54024 Mdot
.71 .54036 Mdot
.71 .54069 Mdot
.71 .54115 Mdot
.71 .54147 Mdot
.71 .54178 Mdot
.71 .54264 Mdot
.71 .54288 Mdot
.71 .54349 Mdot
.71 .54356 Mdot
.71 .54377 Mdot
.71 .54397 Mdot
.71 .54419 Mdot
.71 .54438 Mdot
.71 .54502 Mdot
.71 .54519 Mdot
.71 .54523 Mdot
.71 .54539 Mdot
.71 .54545 Mdot
.71 .54549 Mdot
.71 .54566 Mdot
.71 .54593 Mdot
.71 .54615 Mdot
.71 .54616 Mdot
.71 .54643 Mdot
.71 .54649 Mdot
.71 .54665 Mdot
.71 .54686 Mdot
.71 .54761 Mdot
.71 .5477 Mdot
.71 .54796 Mdot
.71 .5482 Mdot
.71 .54831 Mdot
.71 .54833 Mdot
.71 .54843 Mdot
.71 .54844 Mdot
.71 .54882 Mdot
.71 .54935 Mdot
.71 .54939 Mdot
.71 .54955 Mdot
.71 .54966 Mdot
.71 .55009 Mdot
.71 .55036 Mdot
.71 .55051 Mdot
.71 .5509 Mdot
.71 .55095 Mdot
.71 .55105 Mdot
.71 .55137 Mdot
.71 .55141 Mdot
.71 .55146 Mdot
.71 .55186 Mdot
.71 .55186 Mdot
.71 .55199 Mdot
.71 .55247 Mdot
.71 .55277 Mdot
.71 .55353 Mdot
.71 .55363 Mdot
.71 .55371 Mdot
.71 .55372 Mdot
.71 .55427 Mdot
.71 .55429 Mdot
.71 .55465 Mdot
.71 .55483 Mdot
.71 .55496 Mdot
.71 .55499 Mdot
.71 .55507 Mdot
.71 .55513 Mdot
.71 .55517 Mdot
.71 .5559 Mdot
.71 .55616 Mdot
.71 .55643 Mdot
.71 .55644 Mdot
.71 .55684 Mdot
.71 .55692 Mdot
.71 .55713 Mdot
.71 .55823 Mdot
.71 .5588 Mdot
.71 .55897 Mdot
.71 .55904 Mdot
.71 .55914 Mdot
.71 .55943 Mdot
.71 .55948 Mdot
.71 .55978 Mdot
.71 .56021 Mdot
.71 .56034 Mdot
.71 .56034 Mdot
.71 .56039 Mdot
.71 .5609 Mdot
.71 .56094 Mdot
.71 .56142 Mdot
.71 .56148 Mdot
.71 .56159 Mdot
.71 .562 Mdot
.71 .56205 Mdot
.71 .56297 Mdot
.71 .56306 Mdot
.71 .5632 Mdot
.71 .56324 Mdot
.71 .5635 Mdot
.71 .56368 Mdot
.71 .56387 Mdot
.71 .56395 Mdot
.71 .56401 Mdot
.71 .56418 Mdot
.71 .56421 Mdot
.71 .56425 Mdot
.71 .56428 Mdot
.71 .56432 Mdot
.71 .56469 Mdot
.71 .56476 Mdot
.71 .56505 Mdot
.71 .56517 Mdot
.71 .56521 Mdot
.71 .56552 Mdot
.71 .56553 Mdot
.71 .56558 Mdot
.71 .56573 Mdot
.71 .56574 Mdot
.71 .56587 Mdot
.71 .56589 Mdot
.71 .56589 Mdot
.71 .56599 Mdot
.71 .56608 Mdot
.71 .56613 Mdot
.71 .5664 Mdot
.71 .56649 Mdot
.71 .56655 Mdot
.71 .56662 Mdot
.71 .56662 Mdot
.71 .56706 Mdot
.71 .56707 Mdot
.71 .56707 Mdot
.71 .56715 Mdot
.71 .56718 Mdot
.71 .5672 Mdot
.71 .56743 Mdot
.71 .56743 Mdot
.71 .56754 Mdot
.71 .56782 Mdot
.71 .56786 Mdot
.71 .56804 Mdot
.71 .56805 Mdot
.71 .56808 Mdot
.71 .56819 Mdot
.71 .5682 Mdot
.71 .56822 Mdot
.71 .56823 Mdot
.71 .56825 Mdot
.71 .5683 Mdot
.71 .56833 Mdot
.71 .56834 Mdot
.71 .56839 Mdot
.71 .5686 Mdot
.71 .56863 Mdot
.71 .56865 Mdot
.71 .56871 Mdot
.71 .56881 Mdot
.71 .56888 Mdot
.71 .56892 Mdot
.71 .56896 Mdot
.71 .56896 Mdot
.71 .56898 Mdot
.71 .56899 Mdot
.71 .569 Mdot
.71 .56903 Mdot
.71 .56905 Mdot
.71 .56906 Mdot
.71 .56908 Mdot
.71 .56909 Mdot
.71 .56913 Mdot
.71 .56914 Mdot
.71 .56915 Mdot
.71 .56918 Mdot
.71 .56918 Mdot
.71 .56918 Mdot
.712 .13516 Mdot
.712 .13516 Mdot
.712 .13516 Mdot
.712 .13519 Mdot
.712 .1352 Mdot
.712 .1353 Mdot
.712 .13542 Mdot
.712 .13549 Mdot
.712 .13555 Mdot
.712 .13566 Mdot
.712 .13574 Mdot
.712 .13625 Mdot
.712 .13652 Mdot
.712 .13691 Mdot
.712 .13722 Mdot
.712 .13742 Mdot
.712 .1376 Mdot
.712 .13787 Mdot
.712 .13789 Mdot
.712 .13814 Mdot
.712 .13821 Mdot
.712 .13836 Mdot
.712 .13848 Mdot
.712 .13857 Mdot
.712 .13864 Mdot
.712 .13878 Mdot
.712 .13889 Mdot
.712 .13948 Mdot
.712 .13962 Mdot
.712 .14018 Mdot
.712 .14043 Mdot
.712 .14069 Mdot
.712 .14086 Mdot
.712 .14207 Mdot
.712 .1422 Mdot
.712 .14234 Mdot
.712 .14267 Mdot
.712 .14282 Mdot
.712 .14296 Mdot
.712 .14305 Mdot
.712 .14314 Mdot
.712 .14334 Mdot
.712 .14344 Mdot
.712 .14358 Mdot
.712 .14382 Mdot
.712 .14436 Mdot
.712 .14444 Mdot
.712 .14507 Mdot
.712 .14547 Mdot
.712 .14561 Mdot
.712 .1457 Mdot
.712 .1468 Mdot
.712 .14729 Mdot
.712 .14803 Mdot
.712 .14887 Mdot
.712 .15027 Mdot
.712 .15051 Mdot
.712 .15061 Mdot
.712 .15063 Mdot
.712 .15065 Mdot
.712 .15069 Mdot
.712 .1511 Mdot
.712 .15148 Mdot
.712 .15157 Mdot
.712 .15163 Mdot
.712 .1517 Mdot
.712 .15284 Mdot
.712 .15328 Mdot
.712 .15414 Mdot
.712 .15493 Mdot
.712 .15493 Mdot
.712 .15512 Mdot
.712 .1559 Mdot
.712 .15631 Mdot
.712 .15635 Mdot
.712 .15792 Mdot
.712 .1583 Mdot
.712 .15845 Mdot
.712 .15847 Mdot
.712 .15918 Mdot
.712 .15945 Mdot
.712 .16005 Mdot
.712 .16058 Mdot
.712 .16169 Mdot
.712 .16188 Mdot
.712 .16277 Mdot
.712 .16278 Mdot
.712 .16325 Mdot
.712 .16364 Mdot
.712 .16388 Mdot
.712 .16389 Mdot
.712 .16403 Mdot
.712 .16465 Mdot
.712 .16498 Mdot
.712 .165 Mdot
.712 .16539 Mdot
.712 .16647 Mdot
.712 .16763 Mdot
.712 .16799 Mdot
.712 .16976 Mdot
.712 .16977 Mdot
.712 .16978 Mdot
.712 .16986 Mdot
.712 .17097 Mdot
.712 .17127 Mdot
.712 .17192 Mdot
.712 .17267 Mdot
.712 .17286 Mdot
.712 .17469 Mdot
.712 .17556 Mdot
.712 .17561 Mdot
.712 .17638 Mdot
.712 .17761 Mdot
.712 .17803 Mdot
.712 .17832 Mdot
.712 .17892 Mdot
.712 .17953 Mdot
.712 .18059 Mdot
.712 .18102 Mdot
.712 .18167 Mdot
.712 .18203 Mdot
.712 .18218 Mdot
.712 .18415 Mdot
.712 .18617 Mdot
.712 .18618 Mdot
.712 .18666 Mdot
.712 .18674 Mdot
.712 .18875 Mdot
.712 .18887 Mdot
.712 .19134 Mdot
.712 .19213 Mdot
.712 .19262 Mdot
.712 .19532 Mdot
.712 .19558 Mdot
.712 .19757 Mdot
.712 .19952 Mdot
.712 .201 Mdot
.712 .20293 Mdot
.712 .20293 Mdot
.712 .20374 Mdot
.712 .20484 Mdot
.712 .20487 Mdot
.712 .2065 Mdot
.712 .20731 Mdot
.712 .20843 Mdot
.712 .20871 Mdot
.712 .21015 Mdot
.712 .21319 Mdot
.712 .21322 Mdot
.712 .21405 Mdot
.712 .21448 Mdot
.712 .21477 Mdot
.712 .21682 Mdot
.712 .21683 Mdot
.712 .21705 Mdot
.712 .21745 Mdot
.712 .21778 Mdot
.712 .21911 Mdot
.712 .22093 Mdot
.712 .22143 Mdot
.712 .22226 Mdot
.712 .22257 Mdot
.712 .2227 Mdot
.712 .22313 Mdot
.712 .22318 Mdot
.712 .22426 Mdot
.712 .22527 Mdot
.712 .22528 Mdot
.712 .22531 Mdot
.712 .22544 Mdot
.712 .22552 Mdot
.712 .22608 Mdot
.712 .22652 Mdot
.712 .22677 Mdot
.712 .22715 Mdot
.712 .2275 Mdot
.712 .22768 Mdot
.712 .22806 Mdot
.712 .22814 Mdot
.712 .22831 Mdot
.712 .22842 Mdot
.712 .22861 Mdot
.712 .22881 Mdot
.712 .23072 Mdot
.712 .23154 Mdot
.712 .23252 Mdot
.712 .23296 Mdot
.712 .23308 Mdot
.712 .23521 Mdot
.712 .23533 Mdot
.712 .23537 Mdot
.712 .23539 Mdot
.712 .2372 Mdot
.712 .23721 Mdot
.712 .23762 Mdot
.712 .23831 Mdot
.712 .23833 Mdot
.712 .23838 Mdot
.712 .23939 Mdot
.712 .24102 Mdot
.712 .24111 Mdot
.712 .24126 Mdot
.712 .2426 Mdot
.712 .24303 Mdot
.712 .24305 Mdot
.712 .24322 Mdot
.712 .24327 Mdot
.712 .2434 Mdot
.712 .24373 Mdot
.712 .24393 Mdot
.712 .24466 Mdot
.712 .24521 Mdot
.712 .24559 Mdot
.712 .24644 Mdot
.712 .24674 Mdot
.712 .24708 Mdot
.712 .2471 Mdot
.712 .24911 Mdot
.712 .24959 Mdot
.712 .24994 Mdot
.712 .25066 Mdot
.712 .25115 Mdot
.712 .25151 Mdot
.712 .25236 Mdot
.712 .25392 Mdot
.712 .25496 Mdot
.712 .25623 Mdot
.712 .25647 Mdot
.712 .25685 Mdot
.712 .25805 Mdot
.712 .2591 Mdot
.712 .25939 Mdot
.712 .26041 Mdot
.712 .26151 Mdot
.712 .26169 Mdot
.712 .26226 Mdot
.712 .26283 Mdot
.712 .26316 Mdot
.712 .26348 Mdot
.712 .26363 Mdot
.712 .26386 Mdot
.712 .26497 Mdot
.712 .265 Mdot
.712 .26548 Mdot
.712 .26653 Mdot
.712 .26664 Mdot
.712 .26745 Mdot
.712 .26763 Mdot
.712 .26829 Mdot
.712 .26835 Mdot
.712 .26965 Mdot
.712 .27037 Mdot
.712 .27131 Mdot
.712 .27132 Mdot
.712 .27153 Mdot
.712 .27194 Mdot
.712 .27203 Mdot
.712 .27204 Mdot
.712 .27219 Mdot
.712 .27245 Mdot
.712 .27277 Mdot
.712 .27337 Mdot
.712 .27463 Mdot
.712 .27505 Mdot
.712 .27524 Mdot
.712 .27587 Mdot
.712 .27615 Mdot
.712 .27732 Mdot
.712 .27766 Mdot
.712 .27826 Mdot
.712 .27841 Mdot
.712 .27973 Mdot
.712 .2801 Mdot
.712 .28105 Mdot
.712 .28111 Mdot
.712 .28116 Mdot
.712 .28156 Mdot
.712 .28196 Mdot
.712 .28357 Mdot
.712 .28509 Mdot
.712 .28559 Mdot
.712 .28673 Mdot
.712 .28682 Mdot
.712 .2882 Mdot
.712 .2891 Mdot
.712 .28928 Mdot
.712 .28963 Mdot
.712 .29064 Mdot
.712 .29099 Mdot
.712 .29265 Mdot
.712 .2929 Mdot
.712 .29477 Mdot
.712 .29578 Mdot
.712 .29676 Mdot
.712 .29704 Mdot
.712 .2977 Mdot
.712 .29773 Mdot
.712 .29994 Mdot
.712 .30185 Mdot
.712 .30416 Mdot
.712 .30473 Mdot
.712 .30508 Mdot
.712 .30643 Mdot
.712 .3076 Mdot
.712 .30906 Mdot
.712 .30916 Mdot
.712 .30954 Mdot
.712 .3102 Mdot
.712 .31253 Mdot
.712 .31406 Mdot
.712 .31426 Mdot
.712 .31701 Mdot
.712 .31886 Mdot
.712 .31933 Mdot
.712 .31971 Mdot
.712 .32084 Mdot
.712 .32151 Mdot
.712 .32168 Mdot
.712 .3218 Mdot
.712 .32205 Mdot
.712 .32349 Mdot
.712 .32438 Mdot
.712 .32475 Mdot
.712 .32722 Mdot
.712 .32781 Mdot
.712 .328 Mdot
.712 .32817 Mdot
.712 .32828 Mdot
.712 .32864 Mdot
.712 .32921 Mdot
.712 .32992 Mdot
.712 .33062 Mdot
.712 .33106 Mdot
.712 .33366 Mdot
.712 .33574 Mdot
.712 .33594 Mdot
.712 .33603 Mdot
.712 .33606 Mdot
.712 .33611 Mdot
.712 .33679 Mdot
.712 .33899 Mdot
.712 .33962 Mdot
.712 .34068 Mdot
.712 .34227 Mdot
.712 .34228 Mdot
.712 .34378 Mdot
.712 .34454 Mdot
.712 .34527 Mdot
.712 .34861 Mdot
.712 .34968 Mdot
.712 .34969 Mdot
.712 .35096 Mdot
.712 .35349 Mdot
.712 .35599 Mdot
.712 .3566 Mdot
.712 .35865 Mdot
.712 .35889 Mdot
.712 .35993 Mdot
.712 .36319 Mdot
.712 .365 Mdot
.712 .36653 Mdot
.712 .36738 Mdot
.712 .36904 Mdot
.712 .36965 Mdot
.712 .37147 Mdot
.712 .37244 Mdot
.712 .37253 Mdot
.712 .37269 Mdot
.712 .37583 Mdot
.712 .37583 Mdot
.712 .37584 Mdot
.712 .3759 Mdot
.712 .37592 Mdot
.712 .37615 Mdot
.712 .37632 Mdot
.712 .37642 Mdot
.712 .37656 Mdot
.712 .3767 Mdot
.712 .37695 Mdot
.712 .37706 Mdot
.712 .37713 Mdot
.712 .37721 Mdot
.712 .37795 Mdot
.712 .37826 Mdot
.712 .3788 Mdot
.712 .37885 Mdot
.712 .37973 Mdot
.712 .38041 Mdot
.712 .38057 Mdot
.712 .38085 Mdot
.712 .38123 Mdot
.712 .38183 Mdot
.712 .38186 Mdot
.712 .38192 Mdot
.712 .38241 Mdot
.712 .38257 Mdot
.712 .38258 Mdot
.712 .3829 Mdot
.712 .38317 Mdot
.712 .38337 Mdot
.712 .38351 Mdot
.712 .38381 Mdot
.712 .38392 Mdot
.712 .38405 Mdot
.712 .38405 Mdot
.712 .38478 Mdot
.712 .38534 Mdot
.712 .38564 Mdot
.712 .38594 Mdot
.712 .38687 Mdot
.712 .3874 Mdot
.712 .38753 Mdot
.712 .38795 Mdot
.712 .38832 Mdot
.712 .38842 Mdot
.712 .38878 Mdot
.712 .38916 Mdot
.712 .38984 Mdot
.712 .39036 Mdot
.712 .39092 Mdot
.712 .3912 Mdot
.712 .39149 Mdot
.712 .3922 Mdot
.712 .39251 Mdot
.712 .39281 Mdot
.712 .3929 Mdot
.712 .39301 Mdot
.712 .39321 Mdot
.712 .39363 Mdot
.712 .39384 Mdot
.712 .39405 Mdot
.712 .39414 Mdot
.712 .39453 Mdot
.712 .39465 Mdot
.712 .39579 Mdot
.712 .39581 Mdot
.712 .39594 Mdot
.712 .39607 Mdot
.712 .39727 Mdot
.712 .39764 Mdot
.712 .39767 Mdot
.712 .39812 Mdot
.712 .39842 Mdot
.712 .39847 Mdot
.712 .39859 Mdot
.712 .39903 Mdot
.712 .39957 Mdot
.712 .39965 Mdot
.712 .4009 Mdot
.712 .40191 Mdot
.712 .40253 Mdot
.712 .40344 Mdot
.712 .40435 Mdot
.712 .40497 Mdot
.712 .40517 Mdot
.712 .40591 Mdot
.712 .40639 Mdot
.712 .40645 Mdot
.712 .40731 Mdot
.712 .40803 Mdot
.712 .40815 Mdot
.712 .4085 Mdot
.712 .40871 Mdot
.712 .40876 Mdot
.712 .4088 Mdot
.712 .40888 Mdot
.712 .40972 Mdot
.712 .41048 Mdot
.712 .41066 Mdot
.712 .41077 Mdot
.712 .41081 Mdot
.712 .41092 Mdot
.712 .41109 Mdot
.712 .41131 Mdot
.712 .41166 Mdot
.712 .41246 Mdot
.712 .4131 Mdot
.712 .4132 Mdot
.712 .41321 Mdot
.712 .41342 Mdot
.712 .4141 Mdot
.712 .41461 Mdot
.712 .41556 Mdot
.712 .41579 Mdot
.712 .41601 Mdot
.712 .41736 Mdot
.712 .41736 Mdot
.712 .41774 Mdot
.712 .41927 Mdot
.712 .41945 Mdot
.712 .42007 Mdot
.712 .42015 Mdot
.712 .42145 Mdot
.712 .42199 Mdot
.712 .42321 Mdot
.712 .4234 Mdot
.712 .42395 Mdot
.712 .42424 Mdot
.712 .42426 Mdot
.712 .42431 Mdot
.712 .42563 Mdot
.712 .42568 Mdot
.712 .42616 Mdot
.712 .4271 Mdot
.712 .42729 Mdot
.712 .4277 Mdot
.712 .42774 Mdot
.712 .42796 Mdot
.712 .42831 Mdot
.712 .42879 Mdot
.712 .42906 Mdot
.712 .42949 Mdot
.712 .42965 Mdot
.712 .43041 Mdot
.712 .43076 Mdot
.712 .43091 Mdot
.712 .4321 Mdot
.712 .43227 Mdot
.712 .43243 Mdot
.712 .43246 Mdot
.712 .43333 Mdot
.712 .43407 Mdot
.712 .43436 Mdot
.712 .4345 Mdot
.712 .43452 Mdot
.712 .43478 Mdot
.712 .43504 Mdot
.712 .43594 Mdot
.712 .43611 Mdot
.712 .43655 Mdot
.712 .43659 Mdot
.712 .43665 Mdot
.712 .43731 Mdot
.712 .43928 Mdot
.712 .44086 Mdot
.712 .44105 Mdot
.712 .44106 Mdot
.712 .44113 Mdot
.712 .44139 Mdot
.712 .44147 Mdot
.712 .4416 Mdot
.712 .44205 Mdot
.712 .44312 Mdot
.712 .44367 Mdot
.712 .44384 Mdot
.712 .44523 Mdot
.712 .44523 Mdot
.712 .44525 Mdot
.712 .4454 Mdot
.712 .44589 Mdot
.712 .44606 Mdot
.712 .44682 Mdot
.712 .44737 Mdot
.712 .4478 Mdot
.712 .4479 Mdot
.712 .44904 Mdot
.712 .44914 Mdot
.712 .44944 Mdot
.712 .45029 Mdot
.712 .45036 Mdot
.712 .45055 Mdot
.712 .45059 Mdot
.712 .45059 Mdot
.712 .4507 Mdot
.712 .453 Mdot
.712 .45329 Mdot
.712 .45387 Mdot
.712 .45424 Mdot
.712 .45535 Mdot
.712 .45544 Mdot
.712 .45608 Mdot
.712 .45675 Mdot
.712 .45683 Mdot
.712 .45706 Mdot
.712 .4572 Mdot
.712 .45764 Mdot
.712 .45775 Mdot
.712 .45777 Mdot
.712 .45809 Mdot
.712 .45883 Mdot
.712 .45954 Mdot
.712 .46001 Mdot
.712 .46074 Mdot
.712 .46102 Mdot
.712 .46204 Mdot
.712 .46378 Mdot
.712 .46401 Mdot
.712 .46449 Mdot
.712 .46508 Mdot
.712 .46519 Mdot
.712 .46525 Mdot
.712 .46556 Mdot
.712 .46596 Mdot
.712 .46614 Mdot
.712 .46625 Mdot
.712 .46639 Mdot
.712 .4677 Mdot
.712 .46812 Mdot
.712 .46854 Mdot
.712 .46857 Mdot
.712 .4688 Mdot
.712 .46926 Mdot
.712 .46956 Mdot
.712 .47044 Mdot
.712 .47183 Mdot
.712 .47187 Mdot
.712 .47213 Mdot
.712 .47239 Mdot
.712 .47277 Mdot
.712 .47279 Mdot
.712 .47354 Mdot
.712 .47366 Mdot
.712 .47426 Mdot
.712 .47449 Mdot
.712 .47504 Mdot
.712 .47622 Mdot
.712 .47647 Mdot
.712 .47679 Mdot
.712 .47696 Mdot
.712 .47713 Mdot
.712 .47754 Mdot
.712 .47827 Mdot
.712 .47881 Mdot
.712 .47915 Mdot
.712 .4792 Mdot
.712 .47982 Mdot
.712 .48012 Mdot
.712 .48074 Mdot
.712 .48154 Mdot
.712 .48192 Mdot
.712 .48226 Mdot
.712 .48232 Mdot
.712 .48266 Mdot
.712 .48428 Mdot
.712 .48435 Mdot
.712 .48439 Mdot
.712 .48482 Mdot
.712 .48563 Mdot
.712 .4859 Mdot
.712 .48663 Mdot
.712 .487 Mdot
.712 .48767 Mdot
.712 .48846 Mdot
.712 .48988 Mdot
.712 .49033 Mdot
.712 .49043 Mdot
.712 .49131 Mdot
.712 .49157 Mdot
.712 .49263 Mdot
.712 .49371 Mdot
.712 .49424 Mdot
.712 .49425 Mdot
.712 .4947 Mdot
.712 .4961 Mdot
.712 .4964 Mdot
.712 .49672 Mdot
.712 .49734 Mdot
.712 .49735 Mdot
.712 .498 Mdot
.712 .49844 Mdot
.712 .4987 Mdot
.712 .4996 Mdot
.712 .49988 Mdot
.712 .4999 Mdot
.712 .49991 Mdot
.712 .49995 Mdot
.712 .50003 Mdot
.712 .50088 Mdot
.712 .50194 Mdot
.712 .50212 Mdot
.712 .5024 Mdot
.712 .50268 Mdot
.712 .50291 Mdot
.712 .50306 Mdot
.712 .5031 Mdot
.712 .50317 Mdot
.712 .50325 Mdot
.712 .50349 Mdot
.712 .50447 Mdot
.712 .50462 Mdot
.712 .50498 Mdot
.712 .50555 Mdot
.712 .50565 Mdot
.712 .5057 Mdot
.712 .50576 Mdot
.712 .50603 Mdot
.712 .50647 Mdot
.712 .50663 Mdot
.712 .50681 Mdot
.712 .50754 Mdot
.712 .50862 Mdot
.712 .5087 Mdot
.712 .50929 Mdot
.712 .5102 Mdot
.712 .51046 Mdot
.712 .5106 Mdot
.712 .51064 Mdot
.712 .51121 Mdot
.712 .51166 Mdot
.712 .51218 Mdot
.712 .51231 Mdot
.712 .51253 Mdot
.712 .51341 Mdot
.712 .51415 Mdot
.712 .51498 Mdot
.712 .515 Mdot
.712 .51524 Mdot
.712 .51535 Mdot
.712 .51572 Mdot
.712 .5161 Mdot
.712 .51681 Mdot
.712 .5169 Mdot
.712 .51752 Mdot
.712 .51765 Mdot
.712 .51803 Mdot
.712 .51816 Mdot
.712 .51823 Mdot
.712 .51857 Mdot
.712 .51908 Mdot
.712 .51911 Mdot
.712 .51954 Mdot
.712 .51972 Mdot
.712 .52028 Mdot
.712 .52088 Mdot
.712 .52102 Mdot
.712 .52117 Mdot
.712 .52119 Mdot
.712 .52121 Mdot
.712 .52156 Mdot
.712 .5217 Mdot
.712 .52218 Mdot
.712 .52224 Mdot
.712 .52245 Mdot
.712 .52258 Mdot
.712 .52301 Mdot
.712 .52311 Mdot
.712 .52334 Mdot
.712 .52341 Mdot
.712 .52356 Mdot
.712 .52402 Mdot
.712 .52424 Mdot
.712 .52435 Mdot
.712 .52445 Mdot
.712 .5245 Mdot
.712 .52451 Mdot
.712 .52454 Mdot
.712 .52469 Mdot
.712 .52476 Mdot
.712 .52477 Mdot
.712 .52511 Mdot
.712 .52537 Mdot
.712 .52584 Mdot
.712 .52586 Mdot
.712 .52609 Mdot
.712 .52616 Mdot
.712 .52645 Mdot
.712 .52649 Mdot
.712 .52686 Mdot
.712 .52704 Mdot
.712 .52705 Mdot
.712 .52744 Mdot
.712 .52753 Mdot
.712 .52758 Mdot
.712 .5277 Mdot
.712 .52781 Mdot
.712 .52801 Mdot
.712 .52822 Mdot
.712 .52828 Mdot
.712 .52867 Mdot
.712 .52904 Mdot
.712 .52914 Mdot
.712 .52951 Mdot
.712 .52994 Mdot
.712 .53007 Mdot
.712 .53015 Mdot
.712 .5306 Mdot
.712 .53097 Mdot
.712 .53152 Mdot
.712 .53182 Mdot
.712 .53194 Mdot
.712 .53211 Mdot
.712 .53237 Mdot
.712 .53249 Mdot
.712 .53266 Mdot
.712 .53336 Mdot
.712 .53336 Mdot
.712 .53348 Mdot
.712 .53359 Mdot
.712 .53388 Mdot
.712 .53401 Mdot
.712 .5342 Mdot
.712 .53446 Mdot
.712 .53453 Mdot
.712 .53464 Mdot
.712 .53468 Mdot
.712 .5347 Mdot
.712 .53476 Mdot
.712 .53477 Mdot
.712 .53492 Mdot
.712 .53538 Mdot
.712 .53543 Mdot
.712 .53546 Mdot
.712 .53602 Mdot
.712 .53637 Mdot
.712 .53639 Mdot
.712 .53639 Mdot
.712 .53663 Mdot
.712 .53677 Mdot
.712 .53677 Mdot
.712 .53739 Mdot
.712 .5374 Mdot
.712 .53742 Mdot
.712 .53746 Mdot
.712 .53818 Mdot
.712 .53823 Mdot
.712 .53837 Mdot
.712 .53871 Mdot
.712 .53899 Mdot
.712 .53963 Mdot
.712 .5397 Mdot
.712 .53977 Mdot
.712 .5398 Mdot
.712 .53986 Mdot
.712 .53989 Mdot
.712 .54001 Mdot
.712 .54007 Mdot
.712 .5402 Mdot
.712 .54032 Mdot
.712 .54041 Mdot
.712 .54055 Mdot
.712 .54075 Mdot
.712 .54077 Mdot
.712 .54082 Mdot
.712 .54083 Mdot
.712 .54083 Mdot
.712 .54117 Mdot
.712 .54153 Mdot
.712 .54155 Mdot
.712 .54169 Mdot
.712 .54173 Mdot
.712 .54184 Mdot
.712 .54212 Mdot
.712 .54229 Mdot
.712 .54289 Mdot
.712 .54334 Mdot
.712 .54345 Mdot
.712 .54358 Mdot
.712 .54365 Mdot
.712 .54366 Mdot
.712 .54434 Mdot
.712 .54444 Mdot
.712 .54458 Mdot
.712 .54485 Mdot
.712 .54486 Mdot
.712 .54587 Mdot
.712 .54634 Mdot
.712 .54643 Mdot
.712 .5468 Mdot
.712 .54706 Mdot
.712 .5476 Mdot
.712 .54761 Mdot
.712 .54797 Mdot
.712 .54823 Mdot
.712 .54823 Mdot
.712 .54886 Mdot
.712 .54934 Mdot
.712 .54998 Mdot
.712 .55062 Mdot
.712 .5507 Mdot
.712 .55157 Mdot
.712 .55173 Mdot
.712 .55199 Mdot
.712 .55278 Mdot
.712 .55282 Mdot
.712 .55346 Mdot
.712 .55349 Mdot
.712 .55364 Mdot
.712 .55364 Mdot
.712 .55429 Mdot
.712 .55491 Mdot
.712 .55496 Mdot
.712 .55507 Mdot
.712 .55528 Mdot
.712 .55542 Mdot
.712 .55575 Mdot
.712 .55595 Mdot
.712 .55614 Mdot
.712 .55623 Mdot
.712 .55636 Mdot
.712 .55675 Mdot
.712 .55699 Mdot
.712 .55701 Mdot
.712 .55728 Mdot
.712 .55785 Mdot
.712 .55791 Mdot
.712 .55815 Mdot
.712 .55835 Mdot
.712 .55845 Mdot
.712 .55879 Mdot
.712 .55882 Mdot
.712 .55882 Mdot
.712 .55882 Mdot
.712 .55938 Mdot
.712 .55949 Mdot
.712 .55985 Mdot
.712 .56019 Mdot
.712 .56031 Mdot
.712 .56031 Mdot
.712 .56042 Mdot
.712 .56061 Mdot
.712 .56065 Mdot
.712 .56066 Mdot
.712 .56073 Mdot
.712 .56085 Mdot
.712 .561 Mdot
.712 .561 Mdot
.712 .56128 Mdot
.712 .56133 Mdot
.712 .56168 Mdot
.712 .56184 Mdot
.712 .56203 Mdot
.712 .56211 Mdot
.712 .56233 Mdot
.712 .56233 Mdot
.712 .56238 Mdot
.712 .5625 Mdot
.712 .56298 Mdot
.712 .56299 Mdot
.712 .56312 Mdot
.712 .56336 Mdot
.712 .56342 Mdot
.712 .56342 Mdot
.712 .56366 Mdot
.712 .56392 Mdot
.712 .56406 Mdot
.712 .56441 Mdot
.712 .56443 Mdot
.712 .56445 Mdot
.712 .56447 Mdot
.712 .56459 Mdot
.712 .56472 Mdot
.712 .56473 Mdot
.712 .56473 Mdot
.712 .56474 Mdot
.712 .56477 Mdot
.712 .56484 Mdot
.712 .56527 Mdot
.712 .56553 Mdot
.712 .56575 Mdot
.712 .5659 Mdot
.712 .56624 Mdot
.712 .56626 Mdot
.712 .5663 Mdot
.712 .56643 Mdot
.712 .56662 Mdot
.712 .56664 Mdot
.712 .5668 Mdot
.712 .56688 Mdot
.712 .56692 Mdot
.712 .56695 Mdot
.712 .56701 Mdot
.712 .56704 Mdot
.712 .56707 Mdot
.712 .56711 Mdot
.712 .56715 Mdot
.712 .56725 Mdot
.712 .56729 Mdot
.712 .56733 Mdot
.712 .5677 Mdot
.712 .56775 Mdot
.712 .56783 Mdot
.712 .5679 Mdot
.712 .56807 Mdot
.712 .56812 Mdot
.712 .56829 Mdot
.712 .56833 Mdot
.712 .56837 Mdot
.712 .56839 Mdot
.712 .56842 Mdot
.712 .56845 Mdot
.712 .5685 Mdot
.712 .56852 Mdot
.712 .5686 Mdot
.712 .5686 Mdot
.712 .56868 Mdot
.712 .56873 Mdot
.712 .56879 Mdot
.712 .56889 Mdot
.712 .56901 Mdot
.712 .56909 Mdot
.712 .56924 Mdot
.712 .56926 Mdot
.712 .5693 Mdot
.712 .56932 Mdot
.712 .56934 Mdot
.712 .56937 Mdot
.712 .5694 Mdot
.712 .56941 Mdot
.712 .56941 Mdot
.712 .56942 Mdot
.712 .56942 Mdot
.714 .13442 Mdot
.714 .13442 Mdot
.714 .13443 Mdot
.714 .13444 Mdot
.714 .13444 Mdot
.714 .13451 Mdot
.714 .13457 Mdot
.714 .13459 Mdot
.714 .13466 Mdot
.714 .13467 Mdot
.714 .13491 Mdot
.714 .13491 Mdot
.714 .13522 Mdot
.714 .13537 Mdot
.714 .13541 Mdot
.714 .13542 Mdot
.714 .1356 Mdot
.714 .13577 Mdot
.714 .13584 Mdot
.714 .13588 Mdot
.714 .13606 Mdot
.714 .13609 Mdot
.714 .13629 Mdot
.714 .13644 Mdot
.714 .13653 Mdot
.714 .13655 Mdot
.714 .13656 Mdot
.714 .13672 Mdot
.714 .13696 Mdot
.714 .13756 Mdot
.714 .13819 Mdot
.714 .13858 Mdot
.714 .13861 Mdot
.714 .13889 Mdot
.714 .13902 Mdot
.714 .13954 Mdot
.714 .13978 Mdot
.714 .13981 Mdot
.714 .13991 Mdot
.714 .14013 Mdot
.714 .14014 Mdot
.714 .14097 Mdot
.714 .14102 Mdot
.714 .1412 Mdot
.714 .14186 Mdot
.714 .14206 Mdot
.714 .14209 Mdot
.714 .1425 Mdot
.714 .14263 Mdot
.714 .1427 Mdot
.714 .14302 Mdot
.714 .14319 Mdot
.714 .14348 Mdot
.714 .14388 Mdot
.714 .14513 Mdot
.714 .14521 Mdot
.714 .14567 Mdot
.714 .14598 Mdot
.714 .14621 Mdot
.714 .14708 Mdot
.714 .14714 Mdot
.714 .14715 Mdot
.714 .14724 Mdot
.714 .1474 Mdot
.714 .14754 Mdot
.714 .14836 Mdot
.714 .14872 Mdot
.714 .14961 Mdot
.714 .14992 Mdot
.714 .15001 Mdot
.714 .15034 Mdot
.714 .15089 Mdot
.714 .15118 Mdot
.714 .15168 Mdot
.714 .15183 Mdot
.714 .15241 Mdot
.714 .15297 Mdot
.714 .15435 Mdot
.714 .1547 Mdot
.714 .15477 Mdot
.714 .15485 Mdot
.714 .15522 Mdot
.714 .15706 Mdot
.714 .15712 Mdot
.714 .15811 Mdot
.714 .15894 Mdot
.714 .16011 Mdot
.714 .16013 Mdot
.714 .16072 Mdot
.714 .16109 Mdot
.714 .16124 Mdot
.714 .16232 Mdot
.714 .1634 Mdot
.714 .16343 Mdot
.714 .16357 Mdot
.714 .16488 Mdot
.714 .16546 Mdot
.714 .16621 Mdot
.714 .16705 Mdot
.714 .16751 Mdot
.714 .16779 Mdot
.714 .16824 Mdot
.714 .16864 Mdot
.714 .16877 Mdot
.714 .16996 Mdot
.714 .17021 Mdot
.714 .17078 Mdot
.714 .17183 Mdot
.714 .17218 Mdot
.714 .17276 Mdot
.714 .17284 Mdot
.714 .17437 Mdot
.714 .17556 Mdot
.714 .17574 Mdot
.714 .17838 Mdot
.714 .18062 Mdot
.714 .18097 Mdot
.714 .1817 Mdot
.714 .18198 Mdot
.714 .18235 Mdot
.714 .18251 Mdot
.714 .18306 Mdot
.714 .18416 Mdot
.714 .18454 Mdot
.714 .18484 Mdot
.714 .18989 Mdot
.714 .19027 Mdot
.714 .1904 Mdot
.714 .19114 Mdot
.714 .1915 Mdot
.714 .19407 Mdot
.714 .19545 Mdot
.714 .19552 Mdot
.714 .19619 Mdot
.714 .19703 Mdot
.714 .19714 Mdot
.714 .19835 Mdot
.714 .19845 Mdot
.714 .19898 Mdot
.714 .19991 Mdot
.714 .20027 Mdot
.714 .20209 Mdot
.714 .20257 Mdot
.714 .2035 Mdot
.714 .20408 Mdot
.714 .20579 Mdot
.714 .20685 Mdot
.714 .20697 Mdot
.714 .20728 Mdot
.714 .20827 Mdot
.714 .20873 Mdot
.714 .21096 Mdot
.714 .2116 Mdot
.714 .21282 Mdot
.714 .21329 Mdot
.714 .21416 Mdot
.714 .21461 Mdot
.714 .21525 Mdot
.714 .21695 Mdot
.714 .21732 Mdot
.714 .21815 Mdot
.714 .21816 Mdot
.714 .21915 Mdot
.714 .22032 Mdot
.714 .22095 Mdot
.714 .22096 Mdot
.714 .22099 Mdot
.714 .22104 Mdot
.714 .22108 Mdot
.714 .22144 Mdot
.714 .2218 Mdot
.714 .22182 Mdot
.714 .22192 Mdot
.714 .22207 Mdot
.714 .22229 Mdot
.714 .22234 Mdot
.714 .22323 Mdot
.714 .22369 Mdot
.714 .2237 Mdot
.714 .22441 Mdot
.714 .22464 Mdot
.714 .22519 Mdot
.714 .22548 Mdot
.714 .22629 Mdot
.714 .22653 Mdot
.714 .22658 Mdot
.714 .22763 Mdot
.714 .22863 Mdot
.714 .2289 Mdot
.714 .229 Mdot
.714 .22926 Mdot
.714 .23025 Mdot
.714 .23045 Mdot
.714 .23158 Mdot
.714 .23248 Mdot
.714 .23291 Mdot
.714 .23298 Mdot
.714 .23313 Mdot
.714 .2332 Mdot
.714 .23409 Mdot
.714 .23493 Mdot
.714 .23519 Mdot
.714 .23553 Mdot
.714 .23564 Mdot
.714 .23817 Mdot
.714 .23903 Mdot
.714 .24201 Mdot
.714 .24232 Mdot
.714 .24278 Mdot
.714 .24324 Mdot
.714 .24334 Mdot
.714 .24394 Mdot
.714 .24441 Mdot
.714 .24481 Mdot
.714 .24481 Mdot
.714 .24515 Mdot
.714 .2453 Mdot
.714 .246 Mdot
.714 .24626 Mdot
.714 .24645 Mdot
.714 .247 Mdot
.714 .24778 Mdot
.714 .24872 Mdot
.714 .24892 Mdot
.714 .24934 Mdot
.714 .24948 Mdot
.714 .24953 Mdot
.714 .25073 Mdot
.714 .25098 Mdot
.714 .25242 Mdot
.714 .25258 Mdot
.714 .253 Mdot
.714 .25324 Mdot
.714 .25328 Mdot
.714 .25458 Mdot
.714 .25461 Mdot
.714 .25525 Mdot
.714 .25647 Mdot
.714 .25706 Mdot
.714 .25974 Mdot
.714 .25989 Mdot
.714 .26008 Mdot
.714 .26064 Mdot
.714 .26092 Mdot
.714 .26119 Mdot
.714 .26172 Mdot
.714 .26191 Mdot
.714 .26453 Mdot
.714 .26463 Mdot
.714 .26529 Mdot
.714 .26653 Mdot
.714 .26674 Mdot
.714 .26768 Mdot
.714 .26783 Mdot
.714 .26854 Mdot
.714 .26886 Mdot
.714 .2693 Mdot
.714 .27011 Mdot
.714 .27058 Mdot
.714 .27094 Mdot
.714 .27179 Mdot
.714 .27261 Mdot
.714 .27343 Mdot
.714 .27368 Mdot
.714 .2741 Mdot
.714 .27551 Mdot
.714 .27623 Mdot
.714 .27627 Mdot
.714 .27765 Mdot
.714 .27805 Mdot
.714 .28035 Mdot
.714 .28048 Mdot
.714 .28114 Mdot
.714 .28161 Mdot
.714 .2819 Mdot
.714 .28198 Mdot
.714 .28225 Mdot
.714 .28305 Mdot
.714 .28417 Mdot
.714 .28429 Mdot
.714 .28445 Mdot
.714 .28454 Mdot
.714 .28454 Mdot
.714 .28601 Mdot
.714 .28649 Mdot
.714 .28658 Mdot
.714 .28793 Mdot
.714 .28954 Mdot
.714 .29008 Mdot
.714 .29141 Mdot
.714 .29149 Mdot
.714 .29297 Mdot
.714 .29313 Mdot
.714 .29317 Mdot
.714 .29505 Mdot
.714 .29573 Mdot
.714 .2969 Mdot
.714 .29865 Mdot
.714 .29903 Mdot
.714 .29909 Mdot
.714 .29929 Mdot
.714 .29968 Mdot
.714 .30074 Mdot
.714 .30106 Mdot
.714 .30159 Mdot
.714 .30222 Mdot
.714 .30237 Mdot
.714 .30423 Mdot
.714 .30561 Mdot
.714 .30567 Mdot
.714 .30617 Mdot
.714 .30635 Mdot
.714 .30698 Mdot
.714 .30843 Mdot
.714 .30874 Mdot
.714 .30934 Mdot
.714 .3099 Mdot
.714 .31007 Mdot
.714 .31379 Mdot
.714 .31514 Mdot
.714 .31584 Mdot
.714 .31716 Mdot
.714 .31776 Mdot
.714 .31786 Mdot
.714 .31903 Mdot
.714 .31992 Mdot
.714 .32302 Mdot
.714 .32349 Mdot
.714 .32369 Mdot
.714 .32451 Mdot
.714 .32538 Mdot
.714 .32539 Mdot
.714 .32686 Mdot
.714 .3277 Mdot
.714 .32799 Mdot
.714 .32865 Mdot
.714 .32874 Mdot
.714 .32912 Mdot
.714 .32932 Mdot
.714 .32965 Mdot
.714 .33233 Mdot
.714 .33256 Mdot
.714 .33343 Mdot
.714 .33465 Mdot
.714 .33714 Mdot
.714 .33816 Mdot
.714 .33862 Mdot
.714 .33971 Mdot
.714 .34004 Mdot
.714 .3401 Mdot
.714 .34311 Mdot
.714 .34394 Mdot
.714 .3447 Mdot
.714 .34614 Mdot
.714 .34615 Mdot
.714 .34845 Mdot
.714 .3489 Mdot
.714 .34942 Mdot
.714 .35069 Mdot
.714 .35183 Mdot
.714 .35188 Mdot
.714 .35494 Mdot
.714 .35669 Mdot
.714 .35703 Mdot
.714 .36079 Mdot
.714 .36104 Mdot
.714 .36139 Mdot
.714 .36376 Mdot
.714 .36415 Mdot
.714 .3642 Mdot
.714 .36643 Mdot
.714 .36664 Mdot
.714 .36805 Mdot
.714 .37052 Mdot
.714 .37122 Mdot
.714 .37435 Mdot
.714 .37435 Mdot
.714 .37436 Mdot
.714 .37438 Mdot
.714 .3744 Mdot
.714 .37454 Mdot
.714 .37468 Mdot
.714 .37473 Mdot
.714 .37488 Mdot
.714 .3749 Mdot
.714 .37543 Mdot
.714 .37544 Mdot
.714 .37581 Mdot
.714 .37613 Mdot
.714 .37645 Mdot
.714 .37655 Mdot
.714 .37657 Mdot
.714 .37697 Mdot
.714 .37736 Mdot
.714 .37747 Mdot
.714 .3775 Mdot
.714 .3776 Mdot
.714 .37798 Mdot
.714 .37806 Mdot
.714 .37849 Mdot
.714 .37884 Mdot
.714 .37903 Mdot
.714 .37908 Mdot
.714 .37911 Mdot
.714 .37945 Mdot
.714 .37976 Mdot
.714 .37999 Mdot
.714 .38003 Mdot
.714 .38098 Mdot
.714 .3813 Mdot
.714 .38268 Mdot
.714 .38288 Mdot
.714 .38327 Mdot
.714 .38342 Mdot
.714 .38342 Mdot
.714 .38354 Mdot
.714 .3836 Mdot
.714 .38385 Mdot
.714 .38401 Mdot
.714 .38421 Mdot
.714 .38449 Mdot
.714 .3851 Mdot
.714 .38564 Mdot
.714 .38615 Mdot
.714 .38621 Mdot
.714 .38635 Mdot
.714 .38644 Mdot
.714 .38691 Mdot
.714 .38692 Mdot
.714 .38715 Mdot
.714 .38872 Mdot
.714 .38884 Mdot
.714 .38922 Mdot
.714 .38947 Mdot
.714 .39037 Mdot
.714 .39063 Mdot
.714 .39106 Mdot
.714 .39113 Mdot
.714 .39185 Mdot
.714 .392 Mdot
.714 .39227 Mdot
.714 .39243 Mdot
.714 .39312 Mdot
.714 .39348 Mdot
.714 .39409 Mdot
.714 .39493 Mdot
.714 .39633 Mdot
.714 .39756 Mdot
.714 .39774 Mdot
.714 .39819 Mdot
.714 .39871 Mdot
.714 .39932 Mdot
.714 .39934 Mdot
.714 .39982 Mdot
.714 .40049 Mdot
.714 .40164 Mdot
.714 .40176 Mdot
.714 .40178 Mdot
.714 .40185 Mdot
.714 .40197 Mdot
.714 .40231 Mdot
.714 .40241 Mdot
.714 .40258 Mdot
.714 .40283 Mdot
.714 .40386 Mdot
.714 .40403 Mdot
.714 .40409 Mdot
.714 .40429 Mdot
.714 .40484 Mdot
.714 .40503 Mdot
.714 .40526 Mdot
.714 .40685 Mdot
.714 .40748 Mdot
.714 .40767 Mdot
.714 .4077 Mdot
.714 .40806 Mdot
.714 .40834 Mdot
.714 .40945 Mdot
.714 .40951 Mdot
.714 .41003 Mdot
.714 .41003 Mdot
.714 .41049 Mdot
.714 .41084 Mdot
.714 .41104 Mdot
.714 .41124 Mdot
.714 .41135 Mdot
.714 .41217 Mdot
.714 .41251 Mdot
.714 .41288 Mdot
.714 .41364 Mdot
.714 .41409 Mdot
.714 .41443 Mdot
.714 .41455 Mdot
.714 .41572 Mdot
.714 .41638 Mdot
.714 .41639 Mdot
.714 .41708 Mdot
.714 .41722 Mdot
.714 .41738 Mdot
.714 .41811 Mdot
.714 .42082 Mdot
.714 .42171 Mdot
.714 .42183 Mdot
.714 .423 Mdot
.714 .42375 Mdot
.714 .42534 Mdot
.714 .42584 Mdot
.714 .42661 Mdot
.714 .42747 Mdot
.714 .42759 Mdot
.714 .42763 Mdot
.714 .42852 Mdot
.714 .42876 Mdot
.714 .42946 Mdot
.714 .42973 Mdot
.714 .43017 Mdot
.714 .43152 Mdot
.714 .43177 Mdot
.714 .43209 Mdot
.714 .43243 Mdot
.714 .43278 Mdot
.714 .43337 Mdot
.714 .43381 Mdot
.714 .43386 Mdot
.714 .4341 Mdot
.714 .43423 Mdot
.714 .43508 Mdot
.714 .43582 Mdot
.714 .43593 Mdot
.714 .43655 Mdot
.714 .43692 Mdot
.714 .43702 Mdot
.714 .43762 Mdot
.714 .43898 Mdot
.714 .44053 Mdot
.714 .44077 Mdot
.714 .44103 Mdot
.714 .44136 Mdot
.714 .44187 Mdot
.714 .44258 Mdot
.714 .44269 Mdot
.714 .44287 Mdot
.714 .44314 Mdot
.714 .4434 Mdot
.714 .44363 Mdot
.714 .44398 Mdot
.714 .44401 Mdot
.714 .44576 Mdot
.714 .44594 Mdot
.714 .44621 Mdot
.714 .44683 Mdot
.714 .44711 Mdot
.714 .4472 Mdot
.714 .44723 Mdot
.714 .44726 Mdot
.714 .44731 Mdot
.714 .44747 Mdot
.714 .44797 Mdot
.714 .44905 Mdot
.714 .44907 Mdot
.714 .44954 Mdot
.714 .44969 Mdot
.714 .44985 Mdot
.714 .4507 Mdot
.714 .45085 Mdot
.714 .45289 Mdot
.714 .45295 Mdot
.714 .45349 Mdot
.714 .45354 Mdot
.714 .45394 Mdot
.714 .4544 Mdot
.714 .45486 Mdot
.714 .45517 Mdot
.714 .45536 Mdot
.714 .45555 Mdot
.714 .45584 Mdot
.714 .45656 Mdot
.714 .45744 Mdot
.714 .45798 Mdot
.714 .45843 Mdot
.714 .45884 Mdot
.714 .46031 Mdot
.714 .46143 Mdot
.714 .46368 Mdot
.714 .46402 Mdot
.714 .46461 Mdot
.714 .46467 Mdot
.714 .46483 Mdot
.714 .46544 Mdot
.714 .46579 Mdot
.714 .46626 Mdot
.714 .46646 Mdot
.714 .46663 Mdot
.714 .46686 Mdot
.714 .46711 Mdot
.714 .46783 Mdot
.714 .468 Mdot
.714 .4692 Mdot
.714 .4694 Mdot
.714 .46977 Mdot
.714 .46979 Mdot
.714 .46988 Mdot
.714 .47038 Mdot
.714 .47058 Mdot
.714 .47085 Mdot
.714 .4715 Mdot
.714 .47207 Mdot
.714 .47261 Mdot
.714 .47311 Mdot
.714 .47349 Mdot
.714 .4756 Mdot
.714 .47629 Mdot
.714 .47671 Mdot
.714 .47779 Mdot
.714 .47816 Mdot
.714 .47873 Mdot
.714 .47931 Mdot
.714 .47951 Mdot
.714 .47951 Mdot
.714 .47957 Mdot
.714 .47975 Mdot
.714 .48062 Mdot
.714 .48105 Mdot
.714 .48117 Mdot
.714 .48221 Mdot
.714 .48296 Mdot
.714 .485 Mdot
.714 .48531 Mdot
.714 .4864 Mdot
.714 .48702 Mdot
.714 .48712 Mdot
.714 .48809 Mdot
.714 .48811 Mdot
.714 .48828 Mdot
.714 .48931 Mdot
.714 .48946 Mdot
.714 .48957 Mdot
.714 .49119 Mdot
.714 .49133 Mdot
.714 .49208 Mdot
.714 .49338 Mdot
.714 .4934 Mdot
.714 .49388 Mdot
.714 .49442 Mdot
.714 .49464 Mdot
.714 .49483 Mdot
.714 .49579 Mdot
.714 .49579 Mdot
.714 .49639 Mdot
.714 .49671 Mdot
.714 .49705 Mdot
.714 .4983 Mdot
.714 .49832 Mdot
.714 .49846 Mdot
.714 .49891 Mdot
.714 .4991 Mdot
.714 .49952 Mdot
.714 .50054 Mdot
.714 .50103 Mdot
.714 .50138 Mdot
.714 .50147 Mdot
.714 .50256 Mdot
.714 .50269 Mdot
.714 .50277 Mdot
.714 .50293 Mdot
.714 .50296 Mdot
.714 .50323 Mdot
.714 .50334 Mdot
.714 .50368 Mdot
.714 .50427 Mdot
.714 .50427 Mdot
.714 .50462 Mdot
.714 .50495 Mdot
.714 .50503 Mdot
.714 .50521 Mdot
.714 .50644 Mdot
.714 .50679 Mdot
.714 .50726 Mdot
.714 .5073 Mdot
.714 .50753 Mdot
.714 .50805 Mdot
.714 .50832 Mdot
.714 .50885 Mdot
.714 .5103 Mdot
.714 .51037 Mdot
.714 .51058 Mdot
.714 .51082 Mdot
.714 .51093 Mdot
.714 .5115 Mdot
.714 .51174 Mdot
.714 .51181 Mdot
.714 .512 Mdot
.714 .51202 Mdot
.714 .51255 Mdot
.714 .51327 Mdot
.714 .51332 Mdot
.714 .51356 Mdot
.714 .51376 Mdot
.714 .51389 Mdot
.714 .51429 Mdot
.714 .51444 Mdot
.714 .51451 Mdot
.714 .51454 Mdot
.714 .51468 Mdot
.714 .51534 Mdot
.714 .51578 Mdot
.714 .51604 Mdot
.714 .51675 Mdot
.714 .51677 Mdot
.714 .51683 Mdot
.714 .51738 Mdot
.714 .51741 Mdot
.714 .51791 Mdot
.714 .51811 Mdot
.714 .51871 Mdot
.714 .51921 Mdot
.714 .51925 Mdot
.714 .51942 Mdot
.714 .51996 Mdot
.714 .51997 Mdot
.714 .52 Mdot
.714 .52006 Mdot
.714 .52011 Mdot
.714 .52052 Mdot
.714 .52081 Mdot
.714 .52091 Mdot
.714 .52094 Mdot
.714 .52105 Mdot
.714 .52122 Mdot
.714 .52146 Mdot
.714 .52151 Mdot
.714 .52236 Mdot
.714 .5225 Mdot
.714 .523 Mdot
.714 .52302 Mdot
.714 .52328 Mdot
.714 .52379 Mdot
.714 .52395 Mdot
.714 .52404 Mdot
.714 .52433 Mdot
.714 .52463 Mdot
.714 .52494 Mdot
.714 .52507 Mdot
.714 .52524 Mdot
.714 .52553 Mdot
.714 .52569 Mdot
.714 .5258 Mdot
.714 .52606 Mdot
.714 .52611 Mdot
.714 .52645 Mdot
.714 .52653 Mdot
.714 .52697 Mdot
.714 .52721 Mdot
.714 .52724 Mdot
.714 .52818 Mdot
.714 .52825 Mdot
.714 .52843 Mdot
.714 .52853 Mdot
.714 .52863 Mdot
.714 .52883 Mdot
.714 .5289 Mdot
.714 .52895 Mdot
.714 .5299 Mdot
.714 .53011 Mdot
.714 .53054 Mdot
.714 .53076 Mdot
.714 .53077 Mdot
.714 .53123 Mdot
.714 .53125 Mdot
.714 .53133 Mdot
.714 .53148 Mdot
.714 .53153 Mdot
.714 .53204 Mdot
.714 .53212 Mdot
.714 .53254 Mdot
.714 .53256 Mdot
.714 .53261 Mdot
.714 .53276 Mdot
.714 .53282 Mdot
.714 .53315 Mdot
.714 .53342 Mdot
.714 .53362 Mdot
.714 .53368 Mdot
.714 .53377 Mdot
.714 .53401 Mdot
.714 .53407 Mdot
.714 .53418 Mdot
.714 .53419 Mdot
.714 .53432 Mdot
.714 .53449 Mdot
.714 .53469 Mdot
.714 .53473 Mdot
.714 .53489 Mdot
.714 .53505 Mdot
.714 .53515 Mdot
.714 .53618 Mdot
.714 .53647 Mdot
.714 .53734 Mdot
.714 .53738 Mdot
.714 .5375 Mdot
.714 .53758 Mdot
.714 .53787 Mdot
.714 .53817 Mdot
.714 .5382 Mdot
.714 .53825 Mdot
.714 .53827 Mdot
.714 .53842 Mdot
.714 .53873 Mdot
.714 .53911 Mdot
.714 .53918 Mdot
.714 .53951 Mdot
.714 .5396 Mdot
.714 .53963 Mdot
.714 .53973 Mdot
.714 .54006 Mdot
.714 .54042 Mdot
.714 .54043 Mdot
.714 .54051 Mdot
.714 .54079 Mdot
.714 .54089 Mdot
.714 .54107 Mdot
.714 .54115 Mdot
.714 .54138 Mdot
.714 .54139 Mdot
.714 .54154 Mdot
.714 .54184 Mdot
.714 .54186 Mdot
.714 .54193 Mdot
.714 .54198 Mdot
.714 .54202 Mdot
.714 .54202 Mdot
.714 .54214 Mdot
.714 .54227 Mdot
.714 .54228 Mdot
.714 .5423 Mdot
.714 .54231 Mdot
.714 .54231 Mdot
.714 .54252 Mdot
.714 .54291 Mdot
.714 .54324 Mdot
.714 .54324 Mdot
.714 .54352 Mdot
.714 .54364 Mdot
.714 .54421 Mdot
.714 .54442 Mdot
.714 .54457 Mdot
.714 .54486 Mdot
.714 .54501 Mdot
.714 .54541 Mdot
.714 .54563 Mdot
.714 .54636 Mdot
.714 .54651 Mdot
.714 .54684 Mdot
.714 .54694 Mdot
.714 .54698 Mdot
.714 .54733 Mdot
.714 .54789 Mdot
.714 .54807 Mdot
.714 .54838 Mdot
.714 .54853 Mdot
.714 .54913 Mdot
.714 .54924 Mdot
.714 .54954 Mdot
.714 .54972 Mdot
.714 .54975 Mdot
.714 .55014 Mdot
.714 .55018 Mdot
.714 .55045 Mdot
.714 .55067 Mdot
.714 .55069 Mdot
.714 .55113 Mdot
.714 .55196 Mdot
.714 .55208 Mdot
.714 .55231 Mdot
.714 .55235 Mdot
.714 .55248 Mdot
.714 .55409 Mdot
.714 .55419 Mdot
.714 .55431 Mdot
.714 .55466 Mdot
.714 .55483 Mdot
.714 .55488 Mdot
.714 .555 Mdot
.714 .55509 Mdot
.714 .55532 Mdot
.714 .55543 Mdot
.714 .55614 Mdot
.714 .55697 Mdot
.714 .55703 Mdot
.714 .5574 Mdot
.714 .55788 Mdot
.714 .55791 Mdot
.714 .55809 Mdot
.714 .5582 Mdot
.714 .55853 Mdot
.714 .5587 Mdot
.714 .55878 Mdot
.714 .55915 Mdot
.714 .55919 Mdot
.714 .55932 Mdot
.714 .55946 Mdot
.714 .55955 Mdot
.714 .55969 Mdot
.714 .55995 Mdot
.714 .56018 Mdot
.714 .56036 Mdot
.714 .56077 Mdot
.714 .56081 Mdot
.714 .56082 Mdot
.714 .56116 Mdot
.714 .56149 Mdot
.714 .56154 Mdot
.714 .56165 Mdot
.714 .56183 Mdot
.714 .56184 Mdot
.714 .5622 Mdot
.714 .56246 Mdot
.714 .56276 Mdot
.714 .56278 Mdot
.714 .56335 Mdot
.714 .56346 Mdot
.714 .56348 Mdot
.714 .56351 Mdot
.714 .56361 Mdot
.714 .56404 Mdot
.714 .56421 Mdot
.714 .56439 Mdot
.714 .56443 Mdot
.714 .56458 Mdot
.714 .56467 Mdot
.714 .56484 Mdot
.714 .56494 Mdot
.714 .56497 Mdot
.714 .56506 Mdot
.714 .56533 Mdot
.714 .56544 Mdot
.714 .56569 Mdot
.714 .56573 Mdot
.714 .56578 Mdot
.714 .56581 Mdot
.714 .56581 Mdot
.714 .56583 Mdot
.714 .5661 Mdot
.714 .56617 Mdot
.714 .56626 Mdot
.714 .5664 Mdot
.714 .56643 Mdot
.714 .5668 Mdot
.714 .56692 Mdot
.714 .56701 Mdot
.714 .56706 Mdot
.714 .56716 Mdot
.714 .56718 Mdot
.714 .56722 Mdot
.714 .56734 Mdot
.714 .56735 Mdot
.714 .56741 Mdot
.714 .56761 Mdot
.714 .56767 Mdot
.714 .56768 Mdot
.714 .56793 Mdot
.714 .56793 Mdot
.714 .568 Mdot
.714 .56803 Mdot
.714 .56804 Mdot
.714 .56811 Mdot
.714 .56827 Mdot
.714 .56831 Mdot
.714 .56839 Mdot
.714 .5684 Mdot
.714 .56852 Mdot
.714 .56871 Mdot
.714 .56889 Mdot
.714 .56896 Mdot
.714 .56901 Mdot
.714 .56901 Mdot
.714 .56902 Mdot
.714 .56905 Mdot
.714 .56909 Mdot
.714 .56915 Mdot
.714 .56916 Mdot
.714 .56921 Mdot
.714 .56923 Mdot
.714 .56925 Mdot
.714 .5693 Mdot
.714 .56935 Mdot
.714 .56936 Mdot
.714 .56937 Mdot
.714 .56941 Mdot
.714 .5695 Mdot
.714 .5695 Mdot
.714 .56958 Mdot
.714 .56958 Mdot
.714 .5696 Mdot
.714 .56961 Mdot
.714 .56962 Mdot
.714 .56964 Mdot
.714 .56965 Mdot
.714 .56965 Mdot
.714 .56965 Mdot
.714 .56965 Mdot
.716 .13368 Mdot
.716 .1337 Mdot
.716 .13379 Mdot
.716 .13383 Mdot
.716 .13386 Mdot
.716 .13388 Mdot
.716 .13412 Mdot
.716 .13419 Mdot
.716 .13422 Mdot
.716 .13449 Mdot
.716 .13459 Mdot
.716 .13471 Mdot
.716 .13476 Mdot
.716 .13488 Mdot
.716 .1349 Mdot
.716 .13515 Mdot
.716 .1352 Mdot
.716 .13539 Mdot
.716 .13574 Mdot
.716 .13577 Mdot
.716 .13602 Mdot
.716 .1361 Mdot
.716 .13628 Mdot
.716 .13632 Mdot
.716 .13645 Mdot
.716 .13649 Mdot
.716 .13655 Mdot
.716 .13656 Mdot
.716 .1367 Mdot
.716 .13708 Mdot
.716 .1373 Mdot
.716 .13752 Mdot
.716 .13771 Mdot
.716 .13789 Mdot
.716 .13789 Mdot
.716 .13832 Mdot
.716 .13843 Mdot
.716 .13844 Mdot
.716 .13847 Mdot
.716 .13858 Mdot
.716 .13864 Mdot
.716 .13875 Mdot
.716 .139 Mdot
.716 .13906 Mdot
.716 .13913 Mdot
.716 .13925 Mdot
.716 .13958 Mdot
.716 .13981 Mdot
.716 .14059 Mdot
.716 .1411 Mdot
.716 .14131 Mdot
.716 .1415 Mdot
.716 .14156 Mdot
.716 .14176 Mdot
.716 .14197 Mdot
.716 .14215 Mdot
.716 .14247 Mdot
.716 .14264 Mdot
.716 .14269 Mdot
.716 .14291 Mdot
.716 .1436 Mdot
.716 .14534 Mdot
.716 .1456 Mdot
.716 .14567 Mdot
.716 .14651 Mdot
.716 .14688 Mdot
.716 .14697 Mdot
.716 .14706 Mdot
.716 .1475 Mdot
.716 .14935 Mdot
.716 .1494 Mdot
.716 .14992 Mdot
.716 .15093 Mdot
.716 .15106 Mdot
.716 .15108 Mdot
.716 .15124 Mdot
.716 .15178 Mdot
.716 .15226 Mdot
.716 .15302 Mdot
.716 .15472 Mdot
.716 .15554 Mdot
.716 .15614 Mdot
.716 .15636 Mdot
.716 .15668 Mdot
.716 .15752 Mdot
.716 .15778 Mdot
.716 .15943 Mdot
.716 .16205 Mdot
.716 .16214 Mdot
.716 .16271 Mdot
.716 .16339 Mdot
.716 .16366 Mdot
.716 .16387 Mdot
.716 .16494 Mdot
.716 .16545 Mdot
.716 .16561 Mdot
.716 .16654 Mdot
.716 .16691 Mdot
.716 .16717 Mdot
.716 .16867 Mdot
.716 .16889 Mdot
.716 .17053 Mdot
.716 .17256 Mdot
.716 .17439 Mdot
.716 .17439 Mdot
.716 .17475 Mdot
.716 .17483 Mdot
.716 .17492 Mdot
.716 .17579 Mdot
.716 .17619 Mdot
.716 .17726 Mdot
.716 .1779 Mdot
.716 .17932 Mdot
.716 .18009 Mdot
.716 .18015 Mdot
.716 .18144 Mdot
.716 .18222 Mdot
.716 .18271 Mdot
.716 .18371 Mdot
.716 .18447 Mdot
.716 .18459 Mdot
.716 .18656 Mdot
.716 .18857 Mdot
.716 .1891 Mdot
.716 .19088 Mdot
.716 .19119 Mdot
.716 .19129 Mdot
.716 .19146 Mdot
.716 .19258 Mdot
.716 .19488 Mdot
.716 .19683 Mdot
.716 .19783 Mdot
.716 .1992 Mdot
.716 .19943 Mdot
.716 .20132 Mdot
.716 .20262 Mdot
.716 .2028 Mdot
.716 .20383 Mdot
.716 .20537 Mdot
.716 .20562 Mdot
.716 .20572 Mdot
.716 .20659 Mdot
.716 .2071 Mdot
.716 .20718 Mdot
.716 .208 Mdot
.716 .20826 Mdot
.716 .2087 Mdot
.716 .20892 Mdot
.716 .20951 Mdot
.716 .20991 Mdot
.716 .21018 Mdot
.716 .21081 Mdot
.716 .21378 Mdot
.716 .21454 Mdot
.716 .2149 Mdot
.716 .21533 Mdot
.716 .21609 Mdot
.716 .21633 Mdot
.716 .21664 Mdot
.716 .21673 Mdot
.716 .21696 Mdot
.716 .21721 Mdot
.716 .21742 Mdot
.716 .21764 Mdot
.716 .21772 Mdot
.716 .21869 Mdot
.716 .21907 Mdot
.716 .21909 Mdot
.716 .21925 Mdot
.716 .21944 Mdot
.716 .21961 Mdot
.716 .221 Mdot
.716 .22114 Mdot
.716 .2217 Mdot
.716 .22236 Mdot
.716 .22269 Mdot
.716 .22333 Mdot
.716 .22347 Mdot
.716 .22387 Mdot
.716 .22426 Mdot
.716 .22484 Mdot
.716 .22486 Mdot
.716 .22514 Mdot
.716 .22624 Mdot
.716 .22743 Mdot
.716 .22744 Mdot
.716 .22827 Mdot
.716 .22842 Mdot
.716 .22921 Mdot
.716 .22989 Mdot
.716 .23033 Mdot
.716 .23037 Mdot
.716 .23125 Mdot
.716 .23141 Mdot
.716 .23163 Mdot
.716 .23196 Mdot
.716 .23235 Mdot
.716 .23259 Mdot
.716 .23285 Mdot
.716 .23299 Mdot
.716 .23303 Mdot
.716 .2331 Mdot
.716 .23322 Mdot
.716 .23332 Mdot
.716 .23386 Mdot
.716 .23403 Mdot
.716 .23424 Mdot
.716 .23547 Mdot
.716 .23609 Mdot
.716 .23638 Mdot
.716 .23665 Mdot
.716 .2368 Mdot
.716 .23713 Mdot
.716 .23736 Mdot
.716 .23742 Mdot
.716 .23832 Mdot
.716 .23867 Mdot
.716 .2387 Mdot
.716 .23918 Mdot
.716 .23945 Mdot
.716 .2398 Mdot
.716 .24023 Mdot
.716 .24091 Mdot
.716 .24092 Mdot
.716 .24192 Mdot
.716 .24344 Mdot
.716 .24414 Mdot
.716 .2442 Mdot
.716 .24436 Mdot
.716 .24506 Mdot
.716 .24531 Mdot
.716 .24541 Mdot
.716 .2459 Mdot
.716 .24605 Mdot
.716 .24636 Mdot
.716 .24759 Mdot
.716 .24785 Mdot
.716 .24797 Mdot
.716 .24814 Mdot
.716 .24839 Mdot
.716 .24848 Mdot
.716 .24867 Mdot
.716 .24878 Mdot
.716 .24913 Mdot
.716 .24916 Mdot
.716 .2499 Mdot
.716 .25057 Mdot
.716 .2511 Mdot
.716 .25167 Mdot
.716 .25251 Mdot
.716 .25262 Mdot
.716 .25324 Mdot
.716 .25369 Mdot
.716 .25459 Mdot
.716 .25566 Mdot
.716 .25619 Mdot
.716 .25631 Mdot
.716 .25732 Mdot
.716 .25757 Mdot
.716 .25953 Mdot
.716 .26049 Mdot
.716 .26073 Mdot
.716 .26181 Mdot
.716 .26184 Mdot
.716 .26224 Mdot
.716 .263 Mdot
.716 .26334 Mdot
.716 .26461 Mdot
.716 .26466 Mdot
.716 .26471 Mdot
.716 .26491 Mdot
.716 .26593 Mdot
.716 .2671 Mdot
.716 .2682 Mdot
.716 .2691 Mdot
.716 .27016 Mdot
.716 .27048 Mdot
.716 .27146 Mdot
.716 .2719 Mdot
.716 .27228 Mdot
.716 .27233 Mdot
.716 .27409 Mdot
.716 .27525 Mdot
.716 .27627 Mdot
.716 .27643 Mdot
.716 .27688 Mdot
.716 .2775 Mdot
.716 .27881 Mdot
.716 .27981 Mdot
.716 .28025 Mdot
.716 .28051 Mdot
.716 .28182 Mdot
.716 .28186 Mdot
.716 .28352 Mdot
.716 .28394 Mdot
.716 .28744 Mdot
.716 .28821 Mdot
.716 .28872 Mdot
.716 .28909 Mdot
.716 .28931 Mdot
.716 .28956 Mdot
.716 .28981 Mdot
.716 .28988 Mdot
.716 .29103 Mdot
.716 .29287 Mdot
.716 .29406 Mdot
.716 .2943 Mdot
.716 .29498 Mdot
.716 .29499 Mdot
.716 .29563 Mdot
.716 .29641 Mdot
.716 .29714 Mdot
.716 .29742 Mdot
.716 .29743 Mdot
.716 .29766 Mdot
.716 .298 Mdot
.716 .29838 Mdot
.716 .29857 Mdot
.716 .29915 Mdot
.716 .30062 Mdot
.716 .30147 Mdot
.716 .30155 Mdot
.716 .30191 Mdot
.716 .30288 Mdot
.716 .30403 Mdot
.716 .306 Mdot
.716 .30626 Mdot
.716 .30645 Mdot
.716 .30917 Mdot
.716 .3099 Mdot
.716 .31122 Mdot
.716 .31192 Mdot
.716 .31353 Mdot
.716 .31387 Mdot
.716 .31552 Mdot
.716 .31592 Mdot
.716 .31728 Mdot
.716 .31794 Mdot
.716 .31882 Mdot
.716 .32012 Mdot
.716 .32046 Mdot
.716 .32201 Mdot
.716 .32273 Mdot
.716 .32392 Mdot
.716 .32393 Mdot
.716 .32416 Mdot
.716 .32425 Mdot
.716 .32441 Mdot
.716 .32479 Mdot
.716 .32488 Mdot
.716 .32499 Mdot
.716 .32563 Mdot
.716 .32595 Mdot
.716 .32765 Mdot
.716 .32793 Mdot
.716 .32951 Mdot
.716 .32957 Mdot
.716 .33242 Mdot
.716 .33267 Mdot
.716 .33275 Mdot
.716 .33357 Mdot
.716 .33393 Mdot
.716 .33401 Mdot
.716 .33667 Mdot
.716 .33763 Mdot
.716 .33765 Mdot
.716 .33862 Mdot
.716 .34199 Mdot
.716 .3426 Mdot
.716 .34674 Mdot
.716 .34688 Mdot
.716 .34798 Mdot
.716 .34855 Mdot
.716 .34878 Mdot
.716 .34997 Mdot
.716 .35312 Mdot
.716 .3539 Mdot
.716 .35411 Mdot
.716 .3569 Mdot
.716 .35805 Mdot
.716 .35844 Mdot
.716 .35948 Mdot
.716 .36157 Mdot
.716 .36177 Mdot
.716 .36701 Mdot
.716 .36824 Mdot
.716 .36828 Mdot
.716 .36866 Mdot
.716 .37231 Mdot
.716 .37284 Mdot
.716 .37288 Mdot
.716 .37308 Mdot
.716 .37316 Mdot
.716 .37325 Mdot
.716 .37328 Mdot
.716 .37382 Mdot
.716 .37397 Mdot
.716 .37404 Mdot
.716 .37465 Mdot
.716 .37487 Mdot
.716 .37513 Mdot
.716 .37526 Mdot
.716 .37552 Mdot
.716 .37557 Mdot
.716 .37573 Mdot
.716 .37588 Mdot
.716 .37612 Mdot
.716 .37623 Mdot
.716 .37665 Mdot
.716 .37744 Mdot
.716 .3775 Mdot
.716 .37806 Mdot
.716 .37825 Mdot
.716 .37864 Mdot
.716 .37872 Mdot
.716 .379 Mdot
.716 .37909 Mdot
.716 .37919 Mdot
.716 .37924 Mdot
.716 .37926 Mdot
.716 .37928 Mdot
.716 .37957 Mdot
.716 .37963 Mdot
.716 .38017 Mdot
.716 .38041 Mdot
.716 .38051 Mdot
.716 .38079 Mdot
.716 .38088 Mdot
.716 .38136 Mdot
.716 .38155 Mdot
.716 .38178 Mdot
.716 .38219 Mdot
.716 .38219 Mdot
.716 .38311 Mdot
.716 .38337 Mdot
.716 .38339 Mdot
.716 .38345 Mdot
.716 .3837 Mdot
.716 .38383 Mdot
.716 .38406 Mdot
.716 .38462 Mdot
.716 .38475 Mdot
.716 .3849 Mdot
.716 .38517 Mdot
.716 .38587 Mdot
.716 .38637 Mdot
.716 .3871 Mdot
.716 .38747 Mdot
.716 .38805 Mdot
.716 .38915 Mdot
.716 .38924 Mdot
.716 .38962 Mdot
.716 .39002 Mdot
.716 .39014 Mdot
.716 .39057 Mdot
.716 .39068 Mdot
.716 .39102 Mdot
.716 .39142 Mdot
.716 .3921 Mdot
.716 .39246 Mdot
.716 .39256 Mdot
.716 .39304 Mdot
.716 .3945 Mdot
.716 .39491 Mdot
.716 .39582 Mdot
.716 .39591 Mdot
.716 .39635 Mdot
.716 .39818 Mdot
.716 .39871 Mdot
.716 .39886 Mdot
.716 .39993 Mdot
.716 .40061 Mdot
.716 .4014 Mdot
.716 .40147 Mdot
.716 .40158 Mdot
.716 .40176 Mdot
.716 .40241 Mdot
.716 .40268 Mdot
.716 .40282 Mdot
.716 .40411 Mdot
.716 .4042 Mdot
.716 .40511 Mdot
.716 .40534 Mdot
.716 .40575 Mdot
.716 .40597 Mdot
.716 .40648 Mdot
.716 .40658 Mdot
.716 .4071 Mdot
.716 .40765 Mdot
.716 .40863 Mdot
.716 .4097 Mdot
.716 .40971 Mdot
.716 .4098 Mdot
.716 .40985 Mdot
.716 .40997 Mdot
.716 .41 Mdot
.716 .41023 Mdot
.716 .41033 Mdot
.716 .41142 Mdot
.716 .41239 Mdot
.716 .41277 Mdot
.716 .4128 Mdot
.716 .41361 Mdot
.716 .4139 Mdot
.716 .41391 Mdot
.716 .41667 Mdot
.716 .41705 Mdot
.716 .41722 Mdot
.716 .41729 Mdot
.716 .41765 Mdot
.716 .4189 Mdot
.716 .41974 Mdot
.716 .42009 Mdot
.716 .42052 Mdot
.716 .42115 Mdot
.716 .42278 Mdot
.716 .42317 Mdot
.716 .42328 Mdot
.716 .42438 Mdot
.716 .4254 Mdot
.716 .42644 Mdot
.716 .42647 Mdot
.716 .42693 Mdot
.716 .42882 Mdot
.716 .4299 Mdot
.716 .43117 Mdot
.716 .43145 Mdot
.716 .43161 Mdot
.716 .43269 Mdot
.716 .43395 Mdot
.716 .43398 Mdot
.716 .43426 Mdot
.716 .43445 Mdot
.716 .43452 Mdot
.716 .43486 Mdot
.716 .43565 Mdot
.716 .43568 Mdot
.716 .43569 Mdot
.716 .43658 Mdot
.716 .43684 Mdot
.716 .43693 Mdot
.716 .43777 Mdot
.716 .43807 Mdot
.716 .43976 Mdot
.716 .44045 Mdot
.716 .44092 Mdot
.716 .44151 Mdot
.716 .44363 Mdot
.716 .44392 Mdot
.716 .44403 Mdot
.716 .44623 Mdot
.716 .44697 Mdot
.716 .44791 Mdot
.716 .4492 Mdot
.716 .45054 Mdot
.716 .45304 Mdot
.716 .45323 Mdot
.716 .45371 Mdot
.716 .45372 Mdot
.716 .45373 Mdot
.716 .45434 Mdot
.716 .45448 Mdot
.716 .45463 Mdot
.716 .45613 Mdot
.716 .4568 Mdot
.716 .45737 Mdot
.716 .45836 Mdot
.716 .45861 Mdot
.716 .45915 Mdot
.716 .45969 Mdot
.716 .46031 Mdot
.716 .46207 Mdot
.716 .46313 Mdot
.716 .46335 Mdot
.716 .46344 Mdot
.716 .46362 Mdot
.716 .46501 Mdot
.716 .46516 Mdot
.716 .46557 Mdot
.716 .46558 Mdot
.716 .46684 Mdot
.716 .46703 Mdot
.716 .46705 Mdot
.716 .4671 Mdot
.716 .46763 Mdot
.716 .46838 Mdot
.716 .46893 Mdot
.716 .46904 Mdot
.716 .46924 Mdot
.716 .46935 Mdot
.716 .46979 Mdot
.716 .46983 Mdot
.716 .47046 Mdot
.716 .47066 Mdot
.716 .47185 Mdot
.716 .47356 Mdot
.716 .47377 Mdot
.716 .47381 Mdot
.716 .47424 Mdot
.716 .47623 Mdot
.716 .47689 Mdot
.716 .47771 Mdot
.716 .47789 Mdot
.716 .48043 Mdot
.716 .48077 Mdot
.716 .4809 Mdot
.716 .48106 Mdot
.716 .4813 Mdot
.716 .48146 Mdot
.716 .4815 Mdot
.716 .48299 Mdot
.716 .48306 Mdot
.716 .48459 Mdot
.716 .4862 Mdot
.716 .48637 Mdot
.716 .48639 Mdot
.716 .48692 Mdot
.716 .48921 Mdot
.716 .48929 Mdot
.716 .4902 Mdot
.716 .49064 Mdot
.716 .49081 Mdot
.716 .49131 Mdot
.716 .49249 Mdot
.716 .49258 Mdot
.716 .49291 Mdot
.716 .49425 Mdot
.716 .49475 Mdot
.716 .49484 Mdot
.716 .49508 Mdot
.716 .49554 Mdot
.716 .4956 Mdot
.716 .49732 Mdot
.716 .49757 Mdot
.716 .49897 Mdot
.716 .49936 Mdot
.716 .49937 Mdot
.716 .49977 Mdot
.716 .50085 Mdot
.716 .50088 Mdot
.716 .50103 Mdot
.716 .50136 Mdot
.716 .50139 Mdot
.716 .5015 Mdot
.716 .50265 Mdot
.716 .50267 Mdot
.716 .50331 Mdot
.716 .50342 Mdot
.716 .5041 Mdot
.716 .50423 Mdot
.716 .50448 Mdot
.716 .50452 Mdot
.716 .50456 Mdot
.716 .50471 Mdot
.716 .50478 Mdot
.716 .50481 Mdot
.716 .5049 Mdot
.716 .50491 Mdot
.716 .50538 Mdot
.716 .50567 Mdot
.716 .50628 Mdot
.716 .50642 Mdot
.716 .50693 Mdot
.716 .50728 Mdot
.716 .50753 Mdot
.716 .50807 Mdot
.716 .50823 Mdot
.716 .50887 Mdot
.716 .509 Mdot
.716 .50963 Mdot
.716 .5099 Mdot
.716 .51041 Mdot
.716 .5107 Mdot
.716 .51175 Mdot
.716 .51182 Mdot
.716 .51192 Mdot
.716 .51268 Mdot
.716 .51311 Mdot
.716 .51348 Mdot
.716 .51362 Mdot
.716 .51365 Mdot
.716 .51398 Mdot
.716 .51454 Mdot
.716 .51476 Mdot
.716 .51483 Mdot
.716 .51497 Mdot
.716 .5151 Mdot
.716 .51519 Mdot
.716 .51519 Mdot
.716 .5153 Mdot
.716 .51557 Mdot
.716 .51587 Mdot
.716 .51611 Mdot
.716 .51611 Mdot
.716 .51637 Mdot
.716 .51646 Mdot
.716 .51691 Mdot
.716 .51759 Mdot
.716 .51803 Mdot
.716 .51805 Mdot
.716 .51814 Mdot
.716 .51824 Mdot
.716 .51832 Mdot
.716 .51846 Mdot
.716 .51865 Mdot
.716 .51893 Mdot
.716 .52023 Mdot
.716 .52038 Mdot
.716 .521 Mdot
.716 .52101 Mdot
.716 .52149 Mdot
.716 .52159 Mdot
.716 .52175 Mdot
.716 .52212 Mdot
.716 .5226 Mdot
.716 .52282 Mdot
.716 .52298 Mdot
.716 .52304 Mdot
.716 .52342 Mdot
.716 .52384 Mdot
.716 .52447 Mdot
.716 .52449 Mdot
.716 .52463 Mdot
.716 .52479 Mdot
.716 .52515 Mdot
.716 .52526 Mdot
.716 .52564 Mdot
.716 .52597 Mdot
.716 .52636 Mdot
.716 .52678 Mdot
.716 .52715 Mdot
.716 .52722 Mdot
.716 .52723 Mdot
.716 .52725 Mdot
.716 .52771 Mdot
.716 .52783 Mdot
.716 .5281 Mdot
.716 .52824 Mdot
.716 .52825 Mdot
.716 .52863 Mdot
.716 .52872 Mdot
.716 .52906 Mdot
.716 .52975 Mdot
.716 .52984 Mdot
.716 .5302 Mdot
.716 .53024 Mdot
.716 .53043 Mdot
.716 .53081 Mdot
.716 .53112 Mdot
.716 .53128 Mdot
.716 .5315 Mdot
.716 .53153 Mdot
.716 .53183 Mdot
.716 .53203 Mdot
.716 .53221 Mdot
.716 .53245 Mdot
.716 .53271 Mdot
.716 .53272 Mdot
.716 .53284 Mdot
.716 .53288 Mdot
.716 .53294 Mdot
.716 .53298 Mdot
.716 .53306 Mdot
.716 .53312 Mdot
.716 .53316 Mdot
.716 .53325 Mdot
.716 .53368 Mdot
.716 .53379 Mdot
.716 .53384 Mdot
.716 .53401 Mdot
.716 .53404 Mdot
.716 .53413 Mdot
.716 .53437 Mdot
.716 .53443 Mdot
.716 .53445 Mdot
.716 .53469 Mdot
.716 .53522 Mdot
.716 .53556 Mdot
.716 .53557 Mdot
.716 .5358 Mdot
.716 .53595 Mdot
.716 .53607 Mdot
.716 .53616 Mdot
.716 .53632 Mdot
.716 .53634 Mdot
.716 .53646 Mdot
.716 .53677 Mdot
.716 .53678 Mdot
.716 .53686 Mdot
.716 .53698 Mdot
.716 .53703 Mdot
.716 .53712 Mdot
.716 .53722 Mdot
.716 .53743 Mdot
.716 .53785 Mdot
.716 .53792 Mdot
.716 .53798 Mdot
.716 .53816 Mdot
.716 .5382 Mdot
.716 .53824 Mdot
.716 .53826 Mdot
.716 .53828 Mdot
.716 .53832 Mdot
.716 .53841 Mdot
.716 .53849 Mdot
.716 .53863 Mdot
.716 .53874 Mdot
.716 .53881 Mdot
.716 .53887 Mdot
.716 .53917 Mdot
.716 .53918 Mdot
.716 .53933 Mdot
.716 .53956 Mdot
.716 .53983 Mdot
.716 .53988 Mdot
.716 .54016 Mdot
.716 .54016 Mdot
.716 .54056 Mdot
.716 .54093 Mdot
.716 .54103 Mdot
.716 .54103 Mdot
.716 .54123 Mdot
.716 .54136 Mdot
.716 .54149 Mdot
.716 .54154 Mdot
.716 .54176 Mdot
.716 .54187 Mdot
.716 .54209 Mdot
.716 .54228 Mdot
.716 .54232 Mdot
.716 .54279 Mdot
.716 .54284 Mdot
.716 .5429 Mdot
.716 .54296 Mdot
.716 .54297 Mdot
.716 .54309 Mdot
.716 .54341 Mdot
.716 .54344 Mdot
.716 .54351 Mdot
.716 .54358 Mdot
.716 .54367 Mdot
.716 .54374 Mdot
.716 .54377 Mdot
.716 .54388 Mdot
.716 .54396 Mdot
.716 .54421 Mdot
.716 .54435 Mdot
.716 .54447 Mdot
.716 .54472 Mdot
.716 .5457 Mdot
.716 .54591 Mdot
.716 .546 Mdot
.716 .54613 Mdot
.716 .54632 Mdot
.716 .5464 Mdot
.716 .54654 Mdot
.716 .54663 Mdot
.716 .5469 Mdot
.716 .54692 Mdot
.716 .54709 Mdot
.716 .54737 Mdot
.716 .54741 Mdot
.716 .54749 Mdot
.716 .54799 Mdot
.716 .54833 Mdot
.716 .54839 Mdot
.716 .54881 Mdot
.716 .54942 Mdot
.716 .5495 Mdot
.716 .54994 Mdot
.716 .55027 Mdot
.716 .5509 Mdot
.716 .55164 Mdot
.716 .552 Mdot
.716 .55205 Mdot
.716 .55208 Mdot
.716 .55218 Mdot
.716 .55275 Mdot
.716 .55292 Mdot
.716 .55356 Mdot
.716 .55419 Mdot
.716 .55423 Mdot
.716 .55447 Mdot
.716 .55479 Mdot
.716 .55494 Mdot
.716 .55519 Mdot
.716 .5556 Mdot
.716 .55562 Mdot
.716 .55586 Mdot
.716 .55631 Mdot
.716 .55651 Mdot
.716 .55685 Mdot
.716 .55698 Mdot
.716 .55725 Mdot
.716 .55728 Mdot
.716 .5573 Mdot
.716 .55742 Mdot
.716 .55742 Mdot
.716 .55799 Mdot
.716 .55862 Mdot
.716 .55914 Mdot
.716 .55921 Mdot
.716 .55967 Mdot
.716 .55975 Mdot
.716 .55987 Mdot
.716 .56016 Mdot
.716 .56021 Mdot
.716 .56037 Mdot
.716 .5607 Mdot
.716 .56076 Mdot
.716 .56085 Mdot
.716 .56106 Mdot
.716 .56123 Mdot
.716 .56126 Mdot
.716 .56207 Mdot
.716 .56258 Mdot
.716 .56266 Mdot
.716 .56292 Mdot
.716 .56301 Mdot
.716 .56308 Mdot
.716 .56327 Mdot
.716 .56352 Mdot
.716 .56404 Mdot
.716 .56427 Mdot
.716 .56442 Mdot
.716 .56458 Mdot
.716 .56463 Mdot
.716 .56464 Mdot
.716 .56468 Mdot
.716 .56499 Mdot
.716 .56514 Mdot
.716 .56516 Mdot
.716 .56572 Mdot
.716 .56586 Mdot
.716 .56588 Mdot
.716 .56591 Mdot
.716 .56602 Mdot
.716 .56628 Mdot
.716 .5663 Mdot
.716 .56638 Mdot
.716 .5669 Mdot
.716 .56711 Mdot
.716 .56718 Mdot
.716 .56719 Mdot
.716 .56725 Mdot
.716 .56734 Mdot
.716 .5674 Mdot
.716 .56746 Mdot
.716 .56752 Mdot
.716 .56754 Mdot
.716 .56759 Mdot
.716 .56766 Mdot
.716 .56781 Mdot
.716 .56805 Mdot
.716 .56812 Mdot
.716 .56822 Mdot
.716 .56825 Mdot
.716 .56827 Mdot
.716 .56829 Mdot
.716 .56837 Mdot
.716 .5684 Mdot
.716 .56842 Mdot
.716 .56845 Mdot
.716 .56846 Mdot
.716 .56846 Mdot
.716 .5685 Mdot
.716 .56862 Mdot
.716 .56862 Mdot
.716 .56868 Mdot
.716 .56874 Mdot
.716 .5688 Mdot
.716 .56887 Mdot
.716 .56898 Mdot
.716 .56902 Mdot
.716 .56903 Mdot
.716 .56905 Mdot
.716 .56906 Mdot
.716 .5691 Mdot
.716 .56911 Mdot
.716 .56916 Mdot
.716 .56919 Mdot
.716 .56926 Mdot
.716 .56927 Mdot
.716 .56938 Mdot
.716 .56943 Mdot
.716 .56945 Mdot
.716 .56952 Mdot
.716 .56953 Mdot
.716 .56956 Mdot
.716 .56958 Mdot
.716 .56962 Mdot
.716 .56965 Mdot
.716 .56973 Mdot
.716 .56974 Mdot
.716 .56976 Mdot
.716 .56983 Mdot
.716 .56983 Mdot
.716 .56984 Mdot
.716 .56986 Mdot
.716 .56988 Mdot
.716 .56989 Mdot
.718 .13297 Mdot
.718 .2125 Mdot
.718 .31011 Mdot
.718 .37139 Mdot
.718 .51038 Mdot
.718 .54517 Mdot
.718 .57011 Mdot
.72 .13221 Mdot
.72 .13221 Mdot
.72 .13222 Mdot
.72 .13222 Mdot
.72 .13224 Mdot
.72 .13225 Mdot
.72 .13228 Mdot
.72 .13231 Mdot
.72 .13231 Mdot
.72 .13242 Mdot
.72 .1325 Mdot
.72 .13253 Mdot
.72 .13254 Mdot
.72 .13284 Mdot
.72 .13301 Mdot
.72 .13306 Mdot
.72 .1336 Mdot
.72 .13374 Mdot
.72 .13386 Mdot
.72 .13398 Mdot
.72 .13403 Mdot
.72 .13412 Mdot
.72 .13421 Mdot
.72 .13423 Mdot
.72 .13433 Mdot
.72 .13488 Mdot
.72 .13497 Mdot
.72 .13525 Mdot
.72 .13532 Mdot
.72 .13555 Mdot
.72 .13559 Mdot
.72 .13576 Mdot
.72 .13587 Mdot
.72 .13589 Mdot
.72 .13592 Mdot
.72 .13617 Mdot
.72 .13645 Mdot
.72 .13651 Mdot
.72 .13658 Mdot
.72 .13659 Mdot
.72 .13681 Mdot
.72 .13683 Mdot
.72 .13684 Mdot
.72 .13687 Mdot
.72 .13689 Mdot
.72 .13694 Mdot
.72 .13717 Mdot
.72 .13737 Mdot
.72 .13756 Mdot
.72 .13795 Mdot
.72 .13849 Mdot
.72 .13901 Mdot
.72 .13928 Mdot
.72 .13973 Mdot
.72 .14015 Mdot
.72 .14045 Mdot
.72 .14068 Mdot
.72 .14069 Mdot
.72 .1411 Mdot
.72 .14133 Mdot
.72 .14141 Mdot
.72 .14185 Mdot
.72 .14188 Mdot
.72 .14222 Mdot
.72 .14273 Mdot
.72 .14302 Mdot
.72 .14349 Mdot
.72 .14383 Mdot
.72 .14563 Mdot
.72 .14667 Mdot
.72 .14734 Mdot
.72 .14874 Mdot
.72 .14985 Mdot
.72 .15013 Mdot
.72 .15034 Mdot
.72 .15093 Mdot
.72 .15098 Mdot
.72 .15185 Mdot
.72 .15285 Mdot
.72 .15299 Mdot
.72 .15312 Mdot
.72 .15396 Mdot
.72 .15397 Mdot
.72 .15495 Mdot
.72 .15591 Mdot
.72 .15609 Mdot
.72 .15617 Mdot
.72 .15708 Mdot
.72 .15736 Mdot
.72 .15844 Mdot
.72 .15861 Mdot
.72 .16015 Mdot
.72 .16029 Mdot
.72 .16245 Mdot
.72 .16319 Mdot
.72 .1634 Mdot
.72 .16341 Mdot
.72 .16481 Mdot
.72 .16529 Mdot
.72 .16644 Mdot
.72 .16714 Mdot
.72 .16784 Mdot
.72 .16851 Mdot
.72 .16882 Mdot
.72 .17056 Mdot
.72 .17142 Mdot
.72 .17188 Mdot
.72 .17229 Mdot
.72 .17268 Mdot
.72 .17328 Mdot
.72 .17785 Mdot
.72 .17862 Mdot
.72 .1787 Mdot
.72 .1788 Mdot
.72 .18037 Mdot
.72 .18039 Mdot
.72 .18159 Mdot
.72 .18164 Mdot
.72 .18234 Mdot
.72 .18269 Mdot
.72 .18298 Mdot
.72 .18374 Mdot
.72 .18394 Mdot
.72 .18637 Mdot
.72 .18673 Mdot
.72 .18682 Mdot
.72 .18753 Mdot
.72 .18977 Mdot
.72 .18985 Mdot
.72 .19158 Mdot
.72 .19214 Mdot
.72 .1922 Mdot
.72 .19289 Mdot
.72 .1938 Mdot
.72 .19634 Mdot
.72 .19965 Mdot
.72 .20038 Mdot
.72 .20314 Mdot
.72 .20358 Mdot
.72 .20498 Mdot
.72 .20562 Mdot
.72 .20603 Mdot
.72 .2072 Mdot
.72 .20811 Mdot
.72 .20813 Mdot
.72 .20816 Mdot
.72 .20816 Mdot
.72 .20817 Mdot
.72 .20828 Mdot
.72 .20832 Mdot
.72 .20835 Mdot
.72 .20865 Mdot
.72 .20866 Mdot
.72 .20881 Mdot
.72 .20884 Mdot
.72 .20924 Mdot
.72 .20971 Mdot
.72 .20985 Mdot
.72 .20988 Mdot
.72 .20998 Mdot
.72 .2108 Mdot
.72 .21149 Mdot
.72 .21155 Mdot
.72 .21173 Mdot
.72 .21249 Mdot
.72 .21275 Mdot
.72 .21338 Mdot
.72 .21339 Mdot
.72 .21576 Mdot
.72 .2165 Mdot
.72 .217 Mdot
.72 .21721 Mdot
.72 .21736 Mdot
.72 .2177 Mdot
.72 .21788 Mdot
.72 .21812 Mdot
.72 .21846 Mdot
.72 .21864 Mdot
.72 .21881 Mdot
.72 .21902 Mdot
.72 .21917 Mdot
.72 .21926 Mdot
.72 .21976 Mdot
.72 .21986 Mdot
.72 .22012 Mdot
.72 .22101 Mdot
.72 .22243 Mdot
.72 .22296 Mdot
.72 .22297 Mdot
.72 .22348 Mdot
.72 .2249 Mdot
.72 .2251 Mdot
.72 .2251 Mdot
.72 .22539 Mdot
.72 .22549 Mdot
.72 .22601 Mdot
.72 .22679 Mdot
.72 .22706 Mdot
.72 .22804 Mdot
.72 .22805 Mdot
.72 .22857 Mdot
.72 .22869 Mdot
.72 .2288 Mdot
.72 .22896 Mdot
.72 .23034 Mdot
.72 .23045 Mdot
.72 .23206 Mdot
.72 .23213 Mdot
.72 .23244 Mdot
.72 .23284 Mdot
.72 .23292 Mdot
.72 .23292 Mdot
.72 .23417 Mdot
.72 .23433 Mdot
.72 .23438 Mdot
.72 .23457 Mdot
.72 .23469 Mdot
.72 .23497 Mdot
.72 .23527 Mdot
.72 .23636 Mdot
.72 .23752 Mdot
.72 .2384 Mdot
.72 .23869 Mdot
.72 .24004 Mdot
.72 .24102 Mdot
.72 .24137 Mdot
.72 .2422 Mdot
.72 .24297 Mdot
.72 .24332 Mdot
.72 .24384 Mdot
.72 .24398 Mdot
.72 .24429 Mdot
.72 .24442 Mdot
.72 .24603 Mdot
.72 .24603 Mdot
.72 .24671 Mdot
.72 .24744 Mdot
.72 .24791 Mdot
.72 .24792 Mdot
.72 .24813 Mdot
.72 .2486 Mdot
.72 .2491 Mdot
.72 .24927 Mdot
.72 .25015 Mdot
.72 .25034 Mdot
.72 .25186 Mdot
.72 .2545 Mdot
.72 .25492 Mdot
.72 .25524 Mdot
.72 .25635 Mdot
.72 .2578 Mdot
.72 .25784 Mdot
.72 .25921 Mdot
.72 .25969 Mdot
.72 .26001 Mdot
.72 .26037 Mdot
.72 .26039 Mdot
.72 .26183 Mdot
.72 .26188 Mdot
.72 .26192 Mdot
.72 .26232 Mdot
.72 .26479 Mdot
.72 .26512 Mdot
.72 .26533 Mdot
.72 .26556 Mdot
.72 .26583 Mdot
.72 .26749 Mdot
.72 .26789 Mdot
.72 .2683 Mdot
.72 .26942 Mdot
.72 .26971 Mdot
.72 .27058 Mdot
.72 .27059 Mdot
.72 .27072 Mdot
.72 .27118 Mdot
.72 .27259 Mdot
.72 .27541 Mdot
.72 .27546 Mdot
.72 .27559 Mdot
.72 .27629 Mdot
.72 .277 Mdot
.72 .27702 Mdot
.72 .27775 Mdot
.72 .27863 Mdot
.72 .27983 Mdot
.72 .28 Mdot
.72 .28298 Mdot
.72 .28569 Mdot
.72 .28652 Mdot
.72 .28683 Mdot
.72 .28837 Mdot
.72 .28863 Mdot
.72 .28911 Mdot
.72 .28912 Mdot
.72 .28939 Mdot
.72 .28975 Mdot
.72 .29028 Mdot
.72 .29085 Mdot
.72 .29189 Mdot
.72 .29265 Mdot
.72 .29321 Mdot
.72 .29427 Mdot
.72 .29474 Mdot
.72 .29542 Mdot
.72 .29615 Mdot
.72 .29698 Mdot
.72 .29932 Mdot
.72 .30058 Mdot
.72 .30359 Mdot
.72 .30515 Mdot
.72 .30684 Mdot
.72 .30686 Mdot
.72 .3072 Mdot
.72 .30756 Mdot
.72 .30779 Mdot
.72 .30855 Mdot
.72 .30887 Mdot
.72 .30971 Mdot
.72 .30978 Mdot
.72 .31215 Mdot
.72 .31273 Mdot
.72 .31292 Mdot
.72 .31514 Mdot
.72 .31531 Mdot
.72 .31707 Mdot
.72 .3178 Mdot
.72 .31811 Mdot
.72 .31822 Mdot
.72 .31845 Mdot
.72 .31868 Mdot
.72 .31896 Mdot
.72 .32017 Mdot
.72 .32036 Mdot
.72 .32092 Mdot
.72 .32149 Mdot
.72 .32157 Mdot
.72 .32208 Mdot
.72 .32212 Mdot
.72 .32217 Mdot
.72 .32307 Mdot
.72 .32318 Mdot
.72 .32331 Mdot
.72 .32366 Mdot
.72 .3237 Mdot
.72 .32371 Mdot
.72 .3238 Mdot
.72 .32387 Mdot
.72 .32423 Mdot
.72 .32453 Mdot
.72 .32683 Mdot
.72 .32975 Mdot
.72 .33025 Mdot
.72 .33028 Mdot
.72 .33066 Mdot
.72 .332 Mdot
.72 .33409 Mdot
.72 .33566 Mdot
.72 .33687 Mdot
.72 .3378 Mdot
.72 .33868 Mdot
.72 .33872 Mdot
.72 .34018 Mdot
.72 .34039 Mdot
.72 .34327 Mdot
.72 .34346 Mdot
.72 .3442 Mdot
.72 .34432 Mdot
.72 .34535 Mdot
.72 .34932 Mdot
.72 .35072 Mdot
.72 .35172 Mdot
.72 .35702 Mdot
.72 .35703 Mdot
.72 .35819 Mdot
.72 .35872 Mdot
.72 .36001 Mdot
.72 .36058 Mdot
.72 .36165 Mdot
.72 .3625 Mdot
.72 .36276 Mdot
.72 .36469 Mdot
.72 .36649 Mdot
.72 .36849 Mdot
.72 .36981 Mdot
.72 .36982 Mdot
.72 .36983 Mdot
.72 .36983 Mdot
.72 .36984 Mdot
.72 .36988 Mdot
.72 .36991 Mdot
.72 .36997 Mdot
.72 .37004 Mdot
.72 .37004 Mdot
.72 .37029 Mdot
.72 .37048 Mdot
.72 .37054 Mdot
.72 .37055 Mdot
.72 .37094 Mdot
.72 .37122 Mdot
.72 .37125 Mdot
.72 .37163 Mdot
.72 .37174 Mdot
.72 .37296 Mdot
.72 .37326 Mdot
.72 .37346 Mdot
.72 .37355 Mdot
.72 .37382 Mdot
.72 .37392 Mdot
.72 .37412 Mdot
.72 .37427 Mdot
.72 .37433 Mdot
.72 .37437 Mdot
.72 .37456 Mdot
.72 .3746 Mdot
.72 .37562 Mdot
.72 .37583 Mdot
.72 .37603 Mdot
.72 .37658 Mdot
.72 .37666 Mdot
.72 .37677 Mdot
.72 .37681 Mdot
.72 .37731 Mdot
.72 .37741 Mdot
.72 .37779 Mdot
.72 .37779 Mdot
.72 .37804 Mdot
.72 .37808 Mdot
.72 .37814 Mdot
.72 .37866 Mdot
.72 .37871 Mdot
.72 .37931 Mdot
.72 .37946 Mdot
.72 .37961 Mdot
.72 .37964 Mdot
.72 .3801 Mdot
.72 .38016 Mdot
.72 .38018 Mdot
.72 .38025 Mdot
.72 .3803 Mdot
.72 .3804 Mdot
.72 .38092 Mdot
.72 .38135 Mdot
.72 .38178 Mdot
.72 .38227 Mdot
.72 .38263 Mdot
.72 .38381 Mdot
.72 .38444 Mdot
.72 .38444 Mdot
.72 .38468 Mdot
.72 .38494 Mdot
.72 .38536 Mdot
.72 .38553 Mdot
.72 .38651 Mdot
.72 .38743 Mdot
.72 .38808 Mdot
.72 .38858 Mdot
.72 .38859 Mdot
.72 .38947 Mdot
.72 .38997 Mdot
.72 .39014 Mdot
.72 .39109 Mdot
.72 .39116 Mdot
.72 .39133 Mdot
.72 .39189 Mdot
.72 .39216 Mdot
.72 .39297 Mdot
.72 .3936 Mdot
.72 .39454 Mdot
.72 .3946 Mdot
.72 .39483 Mdot
.72 .39531 Mdot
.72 .39599 Mdot
.72 .39605 Mdot
.72 .39901 Mdot
.72 .3991 Mdot
.72 .40127 Mdot
.72 .40267 Mdot
.72 .40362 Mdot
.72 .40411 Mdot
.72 .40476 Mdot
.72 .40487 Mdot
.72 .40494 Mdot
.72 .40518 Mdot
.72 .40557 Mdot
.72 .40729 Mdot
.72 .40783 Mdot
.72 .40826 Mdot
.72 .40842 Mdot
.72 .40885 Mdot
.72 .40902 Mdot
.72 .4094 Mdot
.72 .41004 Mdot
.72 .41013 Mdot
.72 .41173 Mdot
.72 .41188 Mdot
.72 .41189 Mdot
.72 .41353 Mdot
.72 .4139 Mdot
.72 .41418 Mdot
.72 .41444 Mdot
.72 .41496 Mdot
.72 .41583 Mdot
.72 .41589 Mdot
.72 .41612 Mdot
.72 .41615 Mdot
.72 .41646 Mdot
.72 .41808 Mdot
.72 .41997 Mdot
.72 .41998 Mdot
.72 .42033 Mdot
.72 .42049 Mdot
.72 .42087 Mdot
.72 .42104 Mdot
.72 .42136 Mdot
.72 .42162 Mdot
.72 .42227 Mdot
.72 .42281 Mdot
.72 .42341 Mdot
.72 .42414 Mdot
.72 .4249 Mdot
.72 .42523 Mdot
.72 .42555 Mdot
.72 .4262 Mdot
.72 .42754 Mdot
.72 .42819 Mdot
.72 .42846 Mdot
.72 .43025 Mdot
.72 .43165 Mdot
.72 .43256 Mdot
.72 .43395 Mdot
.72 .43432 Mdot
.72 .43434 Mdot
.72 .43442 Mdot
.72 .43558 Mdot
.72 .43694 Mdot
.72 .43738 Mdot
.72 .43784 Mdot
.72 .43891 Mdot
.72 .43918 Mdot
.72 .43996 Mdot
.72 .44061 Mdot
.72 .44081 Mdot
.72 .44123 Mdot
.72 .44206 Mdot
.72 .4425 Mdot
.72 .44335 Mdot
.72 .44371 Mdot
.72 .44428 Mdot
.72 .44484 Mdot
.72 .44529 Mdot
.72 .44676 Mdot
.72 .44722 Mdot
.72 .44737 Mdot
.72 .44756 Mdot
.72 .44782 Mdot
.72 .44864 Mdot
.72 .44889 Mdot
.72 .44972 Mdot
.72 .45043 Mdot
.72 .45112 Mdot
.72 .45123 Mdot
.72 .45201 Mdot
.72 .45216 Mdot
.72 .45299 Mdot
.72 .45396 Mdot
.72 .45459 Mdot
.72 .45606 Mdot
.72 .4568 Mdot
.72 .45822 Mdot
.72 .45892 Mdot
.72 .45926 Mdot
.72 .45999 Mdot
.72 .46036 Mdot
.72 .46128 Mdot
.72 .46141 Mdot
.72 .46158 Mdot
.72 .46167 Mdot
.72 .46212 Mdot
.72 .4639 Mdot
.72 .46419 Mdot
.72 .46422 Mdot
.72 .46465 Mdot
.72 .46537 Mdot
.72 .46619 Mdot
.72 .46627 Mdot
.72 .46741 Mdot
.72 .4676 Mdot
.72 .46798 Mdot
.72 .46845 Mdot
.72 .46948 Mdot
.72 .46959 Mdot
.72 .46963 Mdot
.72 .46968 Mdot
.72 .47 Mdot
.72 .47023 Mdot
.72 .47245 Mdot
.72 .47385 Mdot
.72 .47388 Mdot
.72 .47443 Mdot
.72 .47457 Mdot
.72 .47568 Mdot
.72 .47607 Mdot
.72 .47883 Mdot
.72 .47914 Mdot
.72 .47925 Mdot
.72 .47925 Mdot
.72 .48024 Mdot
.72 .48188 Mdot
.72 .48227 Mdot
.72 .48273 Mdot
.72 .48282 Mdot
.72 .48325 Mdot
.72 .48372 Mdot
.72 .48385 Mdot
.72 .48421 Mdot
.72 .4852 Mdot
.72 .48533 Mdot
.72 .48641 Mdot
.72 .48728 Mdot
.72 .48807 Mdot
.72 .48891 Mdot
.72 .48902 Mdot
.72 .48939 Mdot
.72 .48985 Mdot
.72 .49009 Mdot
.72 .49065 Mdot
.72 .49087 Mdot
.72 .49137 Mdot
.72 .49138 Mdot
.72 .49363 Mdot
.72 .49405 Mdot
.72 .49464 Mdot
.72 .4963 Mdot
.72 .49673 Mdot
.72 .49677 Mdot
.72 .49708 Mdot
.72 .49716 Mdot
.72 .49835 Mdot
.72 .49844 Mdot
.72 .49904 Mdot
.72 .49905 Mdot
.72 .49941 Mdot
.72 .49979 Mdot
.72 .50029 Mdot
.72 .50093 Mdot
.72 .50177 Mdot
.72 .50232 Mdot
.72 .50247 Mdot
.72 .50248 Mdot
.72 .50268 Mdot
.72 .50385 Mdot
.72 .50477 Mdot
.72 .50489 Mdot
.72 .50503 Mdot
.72 .50506 Mdot
.72 .5051 Mdot
.72 .5051 Mdot
.72 .50512 Mdot
.72 .50525 Mdot
.72 .50531 Mdot
.72 .50535 Mdot
.72 .50571 Mdot
.72 .50573 Mdot
.72 .50574 Mdot
.72 .50595 Mdot
.72 .50598 Mdot
.72 .5062 Mdot
.72 .50643 Mdot
.72 .5065 Mdot
.72 .50697 Mdot
.72 .50709 Mdot
.72 .50718 Mdot
.72 .50727 Mdot
.72 .50731 Mdot
.72 .50743 Mdot
.72 .50772 Mdot
.72 .50841 Mdot
.72 .50848 Mdot
.72 .50934 Mdot
.72 .50942 Mdot
.72 .50964 Mdot
.72 .51056 Mdot
.72 .51059 Mdot
.72 .51091 Mdot
.72 .51103 Mdot
.72 .51132 Mdot
.72 .51142 Mdot
.72 .51155 Mdot
.72 .51169 Mdot
.72 .51169 Mdot
.72 .51234 Mdot
.72 .51294 Mdot
.72 .51408 Mdot
.72 .51456 Mdot
.72 .51545 Mdot
.72 .51576 Mdot
.72 .51604 Mdot
.72 .51629 Mdot
.72 .51647 Mdot
.72 .51687 Mdot
.72 .51708 Mdot
.72 .51736 Mdot
.72 .51775 Mdot
.72 .51796 Mdot
.72 .51816 Mdot
.72 .51829 Mdot
.72 .5184 Mdot
.72 .5184 Mdot
.72 .51858 Mdot
.72 .51867 Mdot
.72 .51925 Mdot
.72 .51936 Mdot
.72 .51967 Mdot
.72 .52067 Mdot
.72 .52176 Mdot
.72 .52183 Mdot
.72 .52227 Mdot
.72 .52259 Mdot
.72 .52285 Mdot
.72 .52286 Mdot
.72 .52312 Mdot
.72 .52337 Mdot
.72 .52342 Mdot
.72 .52344 Mdot
.72 .52446 Mdot
.72 .52497 Mdot
.72 .52514 Mdot
.72 .52518 Mdot
.72 .52519 Mdot
.72 .5255 Mdot
.72 .52561 Mdot
.72 .52601 Mdot
.72 .52616 Mdot
.72 .5263 Mdot
.72 .52689 Mdot
.72 .52699 Mdot
.72 .52707 Mdot
.72 .52715 Mdot
.72 .52727 Mdot
.72 .52814 Mdot
.72 .52829 Mdot
.72 .5283 Mdot
.72 .52832 Mdot
.72 .52883 Mdot
.72 .52884 Mdot
.72 .52896 Mdot
.72 .52908 Mdot
.72 .52925 Mdot
.72 .52973 Mdot
.72 .52975 Mdot
.72 .53026 Mdot
.72 .53065 Mdot
.72 .53076 Mdot
.72 .53091 Mdot
.72 .53183 Mdot
.72 .53236 Mdot
.72 .53243 Mdot
.72 .53274 Mdot
.72 .5328 Mdot
.72 .53297 Mdot
.72 .53313 Mdot
.72 .53321 Mdot
.72 .53321 Mdot
.72 .53338 Mdot
.72 .53363 Mdot
.72 .53386 Mdot
.72 .53386 Mdot
.72 .53442 Mdot
.72 .53447 Mdot
.72 .53457 Mdot
.72 .53462 Mdot
.72 .5348 Mdot
.72 .53492 Mdot
.72 .53519 Mdot
.72 .53547 Mdot
.72 .53559 Mdot
.72 .53593 Mdot
.72 .53639 Mdot
.72 .53649 Mdot
.72 .5368 Mdot
.72 .53719 Mdot
.72 .53756 Mdot
.72 .53766 Mdot
.72 .53776 Mdot
.72 .5378 Mdot
.72 .53787 Mdot
.72 .53788 Mdot
.72 .53794 Mdot
.72 .53836 Mdot
.72 .53836 Mdot
.72 .53839 Mdot
.72 .53853 Mdot
.72 .53863 Mdot
.72 .53866 Mdot
.72 .5392 Mdot
.72 .53924 Mdot
.72 .5397 Mdot
.72 .53976 Mdot
.72 .5398 Mdot
.72 .53984 Mdot
.72 .54001 Mdot
.72 .54002 Mdot
.72 .54035 Mdot
.72 .54044 Mdot
.72 .5407 Mdot
.72 .54087 Mdot
.72 .54091 Mdot
.72 .541 Mdot
.72 .54101 Mdot
.72 .54107 Mdot
.72 .54155 Mdot
.72 .54172 Mdot
.72 .54172 Mdot
.72 .5419 Mdot
.72 .54238 Mdot
.72 .54267 Mdot
.72 .54276 Mdot
.72 .54279 Mdot
.72 .54296 Mdot
.72 .54299 Mdot
.72 .54304 Mdot
.72 .54311 Mdot
.72 .54316 Mdot
.72 .54323 Mdot
.72 .54334 Mdot
.72 .54342 Mdot
.72 .54348 Mdot
.72 .54359 Mdot
.72 .54364 Mdot
.72 .54371 Mdot
.72 .54388 Mdot
.72 .54412 Mdot
.72 .54491 Mdot
.72 .54491 Mdot
.72 .54512 Mdot
.72 .5452 Mdot
.72 .54545 Mdot
.72 .54551 Mdot
.72 .54553 Mdot
.72 .54576 Mdot
.72 .54603 Mdot
.72 .54606 Mdot
.72 .54607 Mdot
.72 .54612 Mdot
.72 .54627 Mdot
.72 .54641 Mdot
.72 .54641 Mdot
.72 .54647 Mdot
.72 .54647 Mdot
.72 .54652 Mdot
.72 .54657 Mdot
.72 .54658 Mdot
.72 .54659 Mdot
.72 .54662 Mdot
.72 .54663 Mdot
.72 .54663 Mdot
.72 .54664 Mdot
.72 .54665 Mdot
.72 .54694 Mdot
.72 .54733 Mdot
.72 .54746 Mdot
.72 .54767 Mdot
.72 .54813 Mdot
.72 .54827 Mdot
.72 .54917 Mdot
.72 .5494 Mdot
.72 .55048 Mdot
.72 .55129 Mdot
.72 .55159 Mdot
.72 .55181 Mdot
.72 .55183 Mdot
.72 .55201 Mdot
.72 .55256 Mdot
.72 .55258 Mdot
.72 .5533 Mdot
.72 .55353 Mdot
.72 .55356 Mdot
.72 .55367 Mdot
.72 .55445 Mdot
.72 .55451 Mdot
.72 .55475 Mdot
.72 .55484 Mdot
.72 .55495 Mdot
.72 .55518 Mdot
.72 .55519 Mdot
.72 .55557 Mdot
.72 .55558 Mdot
.72 .55607 Mdot
.72 .5561 Mdot
.72 .55613 Mdot
.72 .55637 Mdot
.72 .55781 Mdot
.72 .55799 Mdot
.72 .55812 Mdot
.72 .55824 Mdot
.72 .55839 Mdot
.72 .55866 Mdot
.72 .5592 Mdot
.72 .5593 Mdot
.72 .55951 Mdot
.72 .55972 Mdot
.72 .55994 Mdot
.72 .5603 Mdot
.72 .56045 Mdot
.72 .56088 Mdot
.72 .56088 Mdot
.72 .56095 Mdot
.72 .56118 Mdot
.72 .56184 Mdot
.72 .56189 Mdot
.72 .56236 Mdot
.72 .56241 Mdot
.72 .56275 Mdot
.72 .56283 Mdot
.72 .56311 Mdot
.72 .56314 Mdot
.72 .56319 Mdot
.72 .56349 Mdot
.72 .56378 Mdot
.72 .56379 Mdot
.72 .56404 Mdot
.72 .56409 Mdot
.72 .56413 Mdot
.72 .56443 Mdot
.72 .5647 Mdot
.72 .56471 Mdot
.72 .56489 Mdot
.72 .56496 Mdot
.72 .56504 Mdot
.72 .56538 Mdot
.72 .5658 Mdot
.72 .56601 Mdot
.72 .56632 Mdot
.72 .56687 Mdot
.72 .56697 Mdot
.72 .56711 Mdot
.72 .5672 Mdot
.72 .56735 Mdot
.72 .56746 Mdot
.72 .56747 Mdot
.72 .5676 Mdot
.72 .56762 Mdot
.72 .56769 Mdot
.72 .56781 Mdot
.72 .56782 Mdot
.72 .56789 Mdot
.72 .56798 Mdot
.72 .5681 Mdot
.72 .56824 Mdot
.72 .56832 Mdot
.72 .56848 Mdot
.72 .56864 Mdot
.72 .56875 Mdot
.72 .56881 Mdot
.72 .56887 Mdot
.72 .56894 Mdot
.72 .56896 Mdot
.72 .56896 Mdot
.72 .56897 Mdot
.72 .56897 Mdot
.72 .56898 Mdot
.72 .56905 Mdot
.72 .56905 Mdot
.72 .56907 Mdot
.72 .56909 Mdot
.72 .56917 Mdot
.72 .56925 Mdot
.72 .56926 Mdot
.72 .56926 Mdot
.72 .5693 Mdot
.72 .56935 Mdot
.72 .56936 Mdot
.72 .56943 Mdot
.72 .56945 Mdot
.72 .56953 Mdot
.72 .56956 Mdot
.72 .56972 Mdot
.72 .56975 Mdot
.72 .56976 Mdot
.72 .56979 Mdot
.72 .56981 Mdot
.72 .56983 Mdot
.72 .56986 Mdot
.72 .5699 Mdot
.72 .56994 Mdot
.72 .5701 Mdot
.72 .57012 Mdot
.72 .57017 Mdot
.72 .57026 Mdot
.72 .57026 Mdot
.72 .57027 Mdot
.72 .57029 Mdot
.72 .57033 Mdot
.72 .57033 Mdot
.72 .57034 Mdot
.72 .57034 Mdot
.72 .57035 Mdot
.72 .57035 Mdot
.72 .57035 Mdot
.72 .57036 Mdot
.72 .57036 Mdot
.722 .13147 Mdot
.722 .13147 Mdot
.722 .13147 Mdot
.722 .13147 Mdot
.722 .13147 Mdot
.722 .13147 Mdot
.722 .13147 Mdot
.722 .13147 Mdot
.722 .13147 Mdot
.722 .13148 Mdot
.722 .13149 Mdot
.722 .13149 Mdot
.722 .1315 Mdot
.722 .13151 Mdot
.722 .13152 Mdot
.722 .13162 Mdot
.722 .13171 Mdot
.722 .13172 Mdot
.722 .13185 Mdot
.722 .13189 Mdot
.722 .13191 Mdot
.722 .13212 Mdot
.722 .1322 Mdot
.722 .13224 Mdot
.722 .13259 Mdot
.722 .13274 Mdot
.722 .13282 Mdot
.722 .13298 Mdot
.722 .13306 Mdot
.722 .13312 Mdot
.722 .13356 Mdot
.722 .13382 Mdot
.722 .13412 Mdot
.722 .13422 Mdot
.722 .13424 Mdot
.722 .13434 Mdot
.722 .13468 Mdot
.722 .13526 Mdot
.722 .13535 Mdot
.722 .13607 Mdot
.722 .13615 Mdot
.722 .13661 Mdot
.722 .13685 Mdot
.722 .13758 Mdot
.722 .1377 Mdot
.722 .13835 Mdot
.722 .1386 Mdot
.722 .13893 Mdot
.722 .13945 Mdot
.722 .1397 Mdot
.722 .13987 Mdot
.722 .1399 Mdot
.722 .14017 Mdot
.722 .14022 Mdot
.722 .14027 Mdot
.722 .14033 Mdot
.722 .14047 Mdot
.722 .14059 Mdot
.722 .14087 Mdot
.722 .14131 Mdot
.722 .14171 Mdot
.722 .14199 Mdot
.722 .14219 Mdot
.722 .1437 Mdot
.722 .14377 Mdot
.722 .14554 Mdot
.722 .14563 Mdot
.722 .14567 Mdot
.722 .14588 Mdot
.722 .14637 Mdot
.722 .14657 Mdot
.722 .14686 Mdot
.722 .14689 Mdot
.722 .14741 Mdot
.722 .14744 Mdot
.722 .14752 Mdot
.722 .14778 Mdot
.722 .14797 Mdot
.722 .14809 Mdot
.722 .14821 Mdot
.722 .1484 Mdot
.722 .14843 Mdot
.722 .14851 Mdot
.722 .14852 Mdot
.722 .14854 Mdot
.722 .14855 Mdot
.722 .14856 Mdot
.722 .14856 Mdot
.722 .14857 Mdot
.722 .14857 Mdot
.722 .14877 Mdot
.722 .1516 Mdot
.722 .15166 Mdot
.722 .15196 Mdot
.722 .15253 Mdot
.722 .15262 Mdot
.722 .15274 Mdot
.722 .15336 Mdot
.722 .1561 Mdot
.722 .15784 Mdot
.722 .15923 Mdot
.722 .16234 Mdot
.722 .16286 Mdot
.722 .16513 Mdot
.722 .16551 Mdot
.722 .16821 Mdot
.722 .16826 Mdot
.722 .16895 Mdot
.722 .16915 Mdot
.722 .16994 Mdot
.722 .16997 Mdot
.722 .1705 Mdot
.722 .17082 Mdot
.722 .17109 Mdot
.722 .17369 Mdot
.722 .17586 Mdot
.722 .17628 Mdot
.722 .17847 Mdot
.722 .17905 Mdot
.722 .17922 Mdot
.722 .17947 Mdot
.722 .18268 Mdot
.722 .18389 Mdot
.722 .18462 Mdot
.722 .18755 Mdot
.722 .18767 Mdot
.722 .18878 Mdot
.722 .18905 Mdot
.722 .18943 Mdot
.722 .19077 Mdot
.722 .19091 Mdot
.722 .19096 Mdot
.722 .19146 Mdot
.722 .19168 Mdot
.722 .19174 Mdot
.722 .19234 Mdot
.722 .19249 Mdot
.722 .19249 Mdot
.722 .1925 Mdot
.722 .19281 Mdot
.722 .19311 Mdot
.722 .19498 Mdot
.722 .19622 Mdot
.722 .19678 Mdot
.722 .19722 Mdot
.722 .19806 Mdot
.722 .19968 Mdot
.722 .2009 Mdot
.722 .20151 Mdot
.722 .20315 Mdot
.722 .20389 Mdot
.722 .20389 Mdot
.722 .20389 Mdot
.722 .20389 Mdot
.722 .20389 Mdot
.722 .20389 Mdot
.722 .2039 Mdot
.722 .2039 Mdot
.722 .20392 Mdot
.722 .20393 Mdot
.722 .20398 Mdot
.722 .20401 Mdot
.722 .20404 Mdot
.722 .20409 Mdot
.722 .20416 Mdot
.722 .20469 Mdot
.722 .2052 Mdot
.722 .20522 Mdot
.722 .20592 Mdot
.722 .20612 Mdot
.722 .20626 Mdot
.722 .20648 Mdot
.722 .20732 Mdot
.722 .20737 Mdot
.722 .20769 Mdot
.722 .2078 Mdot
.722 .20805 Mdot
.722 .20914 Mdot
.722 .20991 Mdot
.722 .21071 Mdot
.722 .21077 Mdot
.722 .2112 Mdot
.722 .21209 Mdot
.722 .2125 Mdot
.722 .21286 Mdot
.722 .21533 Mdot
.722 .21567 Mdot
.722 .21586 Mdot
.722 .21676 Mdot
.722 .21834 Mdot
.722 .21847 Mdot
.722 .21899 Mdot
.722 .21901 Mdot
.722 .2191 Mdot
.722 .2195 Mdot
.722 .21967 Mdot
.722 .22077 Mdot
.722 .22098 Mdot
.722 .22112 Mdot
.722 .22113 Mdot
.722 .22165 Mdot
.722 .22241 Mdot
.722 .22388 Mdot
.722 .22497 Mdot
.722 .22551 Mdot
.722 .22756 Mdot
.722 .22808 Mdot
.722 .2297 Mdot
.722 .22981 Mdot
.722 .23005 Mdot
.722 .23014 Mdot
.722 .23031 Mdot
.722 .23172 Mdot
.722 .2326 Mdot
.722 .23286 Mdot
.722 .2343 Mdot
.722 .23455 Mdot
.722 .23499 Mdot
.722 .23619 Mdot
.722 .23831 Mdot
.722 .23864 Mdot
.722 .23935 Mdot
.722 .24162 Mdot
.722 .24284 Mdot
.722 .24334 Mdot
.722 .24353 Mdot
.722 .24486 Mdot
.722 .24688 Mdot
.722 .24754 Mdot
.722 .2483 Mdot
.722 .24865 Mdot
.722 .25007 Mdot
.722 .25078 Mdot
.722 .25158 Mdot
.722 .25229 Mdot
.722 .25267 Mdot
.722 .25286 Mdot
.722 .25312 Mdot
.722 .25453 Mdot
.722 .25467 Mdot
.722 .25482 Mdot
.722 .25482 Mdot
.722 .25489 Mdot
.722 .25516 Mdot
.722 .25529 Mdot
.722 .25553 Mdot
.722 .25555 Mdot
.722 .25561 Mdot
.722 .25624 Mdot
.722 .25642 Mdot
.722 .25655 Mdot
.722 .25714 Mdot
.722 .25891 Mdot
.722 .26127 Mdot
.722 .26166 Mdot
.722 .26281 Mdot
.722 .2642 Mdot
.722 .26563 Mdot
.722 .26597 Mdot
.722 .26626 Mdot
.722 .26685 Mdot
.722 .26727 Mdot
.722 .26887 Mdot
.722 .27049 Mdot
.722 .27376 Mdot
.722 .27694 Mdot
.722 .27741 Mdot
.722 .27822 Mdot
.722 .28054 Mdot
.722 .28215 Mdot
.722 .28217 Mdot
.722 .28261 Mdot
.722 .28324 Mdot
.722 .28664 Mdot
.722 .28715 Mdot
.722 .28759 Mdot
.722 .28839 Mdot
.722 .28868 Mdot
.722 .28875 Mdot
.722 .28887 Mdot
.722 .28943 Mdot
.722 .28972 Mdot
.722 .29036 Mdot
.722 .29078 Mdot
.722 .29111 Mdot
.722 .29426 Mdot
.722 .29557 Mdot
.722 .29573 Mdot
.722 .29679 Mdot
.722 .29747 Mdot
.722 .29767 Mdot
.722 .29771 Mdot
.722 .29856 Mdot
.722 .29915 Mdot
.722 .30025 Mdot
.722 .30109 Mdot
.722 .30132 Mdot
.722 .30181 Mdot
.722 .30352 Mdot
.722 .30447 Mdot
.722 .30481 Mdot
.722 .3056 Mdot
.722 .30563 Mdot
.722 .30636 Mdot
.722 .30767 Mdot
.722 .30784 Mdot
.722 .30809 Mdot
.722 .30837 Mdot
.722 .30842 Mdot
.722 .30859 Mdot
.722 .30861 Mdot
.722 .30869 Mdot
.722 .30871 Mdot
.722 .30875 Mdot
.722 .30879 Mdot
.722 .30882 Mdot
.722 .30927 Mdot
.722 .31007 Mdot
.722 .31057 Mdot
.722 .31343 Mdot
.722 .31484 Mdot
.722 .31502 Mdot
.722 .3174 Mdot
.722 .3176 Mdot
.722 .32013 Mdot
.722 .32366 Mdot
.722 .32449 Mdot
.722 .32485 Mdot
.722 .32588 Mdot
.722 .32605 Mdot
.722 .32881 Mdot
.722 .32885 Mdot
.722 .32922 Mdot
.722 .32951 Mdot
.722 .32996 Mdot
.722 .33118 Mdot
.722 .33293 Mdot
.722 .333 Mdot
.722 .33468 Mdot
.722 .33476 Mdot
.722 .33499 Mdot
.722 .3356 Mdot
.722 .33634 Mdot
.722 .33637 Mdot
.722 .33643 Mdot
.722 .33666 Mdot
.722 .33682 Mdot
.722 .33693 Mdot
.722 .33702 Mdot
.722 .33719 Mdot
.722 .33721 Mdot
.722 .33728 Mdot
.722 .33729 Mdot
.722 .33731 Mdot
.722 .33731 Mdot
.722 .33732 Mdot
.722 .33732 Mdot
.722 .33733 Mdot
.722 .33733 Mdot
.722 .33977 Mdot
.722 .34004 Mdot
.722 .34047 Mdot
.722 .34054 Mdot
.722 .34307 Mdot
.722 .3452 Mdot
.722 .34721 Mdot
.722 .34893 Mdot
.722 .35079 Mdot
.722 .3513 Mdot
.722 .35175 Mdot
.722 .35225 Mdot
.722 .35501 Mdot
.722 .35667 Mdot
.722 .35689 Mdot
.722 .35852 Mdot
.722 .35948 Mdot
.722 .36096 Mdot
.722 .36284 Mdot
.722 .36322 Mdot
.722 .36436 Mdot
.722 .36699 Mdot
.722 .36828 Mdot
.722 .36828 Mdot
.722 .36828 Mdot
.722 .36828 Mdot
.722 .36828 Mdot
.722 .36828 Mdot
.722 .36829 Mdot
.722 .36829 Mdot
.722 .3683 Mdot
.722 .3683 Mdot
.722 .36832 Mdot
.722 .36833 Mdot
.722 .36835 Mdot
.722 .36837 Mdot
.722 .3684 Mdot
.722 .36862 Mdot
.722 .36884 Mdot
.722 .36885 Mdot
.722 .36915 Mdot
.722 .36923 Mdot
.722 .36929 Mdot
.722 .36976 Mdot
.722 .36989 Mdot
.722 .36994 Mdot
.722 .37004 Mdot
.722 .37082 Mdot
.722 .37117 Mdot
.722 .37135 Mdot
.722 .37172 Mdot
.722 .37188 Mdot
.722 .37203 Mdot
.722 .37303 Mdot
.722 .37324 Mdot
.722 .3736 Mdot
.722 .37423 Mdot
.722 .37429 Mdot
.722 .37449 Mdot
.722 .37454 Mdot
.722 .37476 Mdot
.722 .37528 Mdot
.722 .37533 Mdot
.722 .37533 Mdot
.722 .37554 Mdot
.722 .37584 Mdot
.722 .37683 Mdot
.722 .37704 Mdot
.722 .37782 Mdot
.722 .37802 Mdot
.722 .37864 Mdot
.722 .37877 Mdot
.722 .3788 Mdot
.722 .37887 Mdot
.722 .37983 Mdot
.722 .38036 Mdot
.722 .38045 Mdot
.722 .38062 Mdot
.722 .38106 Mdot
.722 .38196 Mdot
.722 .38222 Mdot
.722 .38367 Mdot
.722 .38421 Mdot
.722 .38494 Mdot
.722 .38556 Mdot
.722 .38606 Mdot
.722 .3866 Mdot
.722 .38685 Mdot
.722 .38698 Mdot
.722 .38705 Mdot
.722 .38713 Mdot
.722 .38763 Mdot
.722 .38767 Mdot
.722 .38773 Mdot
.722 .38775 Mdot
.722 .38785 Mdot
.722 .38797 Mdot
.722 .388 Mdot
.722 .38828 Mdot
.722 .38853 Mdot
.722 .38914 Mdot
.722 .39008 Mdot
.722 .39095 Mdot
.722 .39143 Mdot
.722 .39154 Mdot
.722 .39164 Mdot
.722 .39184 Mdot
.722 .39198 Mdot
.722 .3952 Mdot
.722 .39535 Mdot
.722 .39867 Mdot
.722 .39908 Mdot
.722 .39926 Mdot
.722 .39936 Mdot
.722 .3998 Mdot
.722 .40081 Mdot
.722 .40123 Mdot
.722 .40161 Mdot
.722 .40183 Mdot
.722 .40189 Mdot
.722 .40191 Mdot
.722 .40297 Mdot
.722 .40305 Mdot
.722 .4032 Mdot
.722 .40374 Mdot
.722 .40404 Mdot
.722 .40414 Mdot
.722 .40439 Mdot
.722 .4044 Mdot
.722 .40463 Mdot
.722 .40504 Mdot
.722 .40509 Mdot
.722 .40526 Mdot
.722 .40527 Mdot
.722 .40533 Mdot
.722 .40533 Mdot
.722 .40536 Mdot
.722 .40536 Mdot
.722 .40537 Mdot
.722 .40539 Mdot
.722 .4054 Mdot
.722 .40579 Mdot
.722 .40806 Mdot
.722 .41157 Mdot
.722 .41168 Mdot
.722 .41228 Mdot
.722 .41336 Mdot
.722 .41344 Mdot
.722 .41362 Mdot
.722 .41384 Mdot
.722 .41496 Mdot
.722 .4151 Mdot
.722 .41512 Mdot
.722 .41588 Mdot
.722 .41765 Mdot
.722 .4182 Mdot
.722 .41849 Mdot
.722 .41864 Mdot
.722 .41947 Mdot
.722 .42003 Mdot
.722 .42052 Mdot
.722 .42193 Mdot
.722 .42227 Mdot
.722 .42392 Mdot
.722 .4266 Mdot
.722 .42907 Mdot
.722 .42923 Mdot
.722 .42933 Mdot
.722 .43042 Mdot
.722 .43253 Mdot
.722 .4335 Mdot
.722 .43425 Mdot
.722 .43455 Mdot
.722 .43696 Mdot
.722 .43744 Mdot
.722 .43749 Mdot
.722 .43772 Mdot
.722 .43826 Mdot
.722 .43843 Mdot
.722 .43852 Mdot
.722 .43967 Mdot
.722 .44181 Mdot
.722 .44184 Mdot
.722 .44336 Mdot
.722 .44345 Mdot
.722 .4442 Mdot
.722 .44436 Mdot
.722 .4446 Mdot
.722 .44468 Mdot
.722 .44504 Mdot
.722 .44571 Mdot
.722 .44572 Mdot
.722 .44646 Mdot
.722 .44651 Mdot
.722 .44659 Mdot
.722 .44694 Mdot
.722 .44733 Mdot
.722 .44745 Mdot
.722 .44761 Mdot
.722 .44782 Mdot
.722 .44802 Mdot
.722 .44851 Mdot
.722 .44851 Mdot
.722 .44913 Mdot
.722 .44926 Mdot
.722 .44935 Mdot
.722 .45066 Mdot
.722 .45067 Mdot
.722 .45184 Mdot
.722 .45247 Mdot
.722 .45261 Mdot
.722 .45303 Mdot
.722 .45305 Mdot
.722 .45331 Mdot
.722 .45461 Mdot
.722 .45477 Mdot
.722 .4568 Mdot
.722 .45738 Mdot
.722 .45743 Mdot
.722 .45751 Mdot
.722 .46104 Mdot
.722 .46121 Mdot
.722 .46218 Mdot
.722 .46247 Mdot
.722 .46289 Mdot
.722 .46296 Mdot
.722 .46311 Mdot
.722 .46339 Mdot
.722 .46428 Mdot
.722 .46466 Mdot
.722 .46474 Mdot
.722 .46554 Mdot
.722 .46816 Mdot
.722 .46945 Mdot
.722 .46994 Mdot
.722 .47011 Mdot
.722 .47114 Mdot
.722 .47128 Mdot
.722 .47269 Mdot
.722 .47591 Mdot
.722 .476 Mdot
.722 .4761 Mdot
.722 .47769 Mdot
.722 .47781 Mdot
.722 .47784 Mdot
.722 .47809 Mdot
.722 .47822 Mdot
.722 .47881 Mdot
.722 .48086 Mdot
.722 .48107 Mdot
.722 .48114 Mdot
.722 .48186 Mdot
.722 .4819 Mdot
.722 .48224 Mdot
.722 .48233 Mdot
.722 .48322 Mdot
.722 .48344 Mdot
.722 .48344 Mdot
.722 .48347 Mdot
.722 .48393 Mdot
.722 .48437 Mdot
.722 .48586 Mdot
.722 .48713 Mdot
.722 .48828 Mdot
.722 .48877 Mdot
.722 .48893 Mdot
.722 .48975 Mdot
.722 .49039 Mdot
.722 .4908 Mdot
.722 .49149 Mdot
.722 .49159 Mdot
.722 .4923 Mdot
.722 .49346 Mdot
.722 .49367 Mdot
.722 .49386 Mdot
.722 .49408 Mdot
.722 .49486 Mdot
.722 .49558 Mdot
.722 .49642 Mdot
.722 .4973 Mdot
.722 .49834 Mdot
.722 .49837 Mdot
.722 .49855 Mdot
.722 .49866 Mdot
.722 .49966 Mdot
.722 .49966 Mdot
.722 .49967 Mdot
.722 .49967 Mdot
.722 .49967 Mdot
.722 .49967 Mdot
.722 .49968 Mdot
.722 .49968 Mdot
.722 .49971 Mdot
.722 .49972 Mdot
.722 .49979 Mdot
.722 .49983 Mdot
.722 .49987 Mdot
.722 .49994 Mdot
.722 .50003 Mdot
.722 .50007 Mdot
.722 .50037 Mdot
.722 .50062 Mdot
.722 .50071 Mdot
.722 .50074 Mdot
.722 .50142 Mdot
.722 .50145 Mdot
.722 .50216 Mdot
.722 .50265 Mdot
.722 .50283 Mdot
.722 .50295 Mdot
.722 .5031 Mdot
.722 .50311 Mdot
.722 .50422 Mdot
.722 .50428 Mdot
.722 .5047 Mdot
.722 .50484 Mdot
.722 .50517 Mdot
.722 .50657 Mdot
.722 .50756 Mdot
.722 .50764 Mdot
.722 .50857 Mdot
.722 .50864 Mdot
.722 .50919 Mdot
.722 .5103 Mdot
.722 .51049 Mdot
.722 .5108 Mdot
.722 .51098 Mdot
.722 .51099 Mdot
.722 .511 Mdot
.722 .51102 Mdot
.722 .51103 Mdot
.722 .51106 Mdot
.722 .51106 Mdot
.722 .51113 Mdot
.722 .51115 Mdot
.722 .51126 Mdot
.722 .51135 Mdot
.722 .51142 Mdot
.722 .51192 Mdot
.722 .5122 Mdot
.722 .51221 Mdot
.722 .51252 Mdot
.722 .51265 Mdot
.722 .51301 Mdot
.722 .51366 Mdot
.722 .51385 Mdot
.722 .51394 Mdot
.722 .51426 Mdot
.722 .51468 Mdot
.722 .5149 Mdot
.722 .51522 Mdot
.722 .51523 Mdot
.722 .51531 Mdot
.722 .51557 Mdot
.722 .51596 Mdot
.722 .51602 Mdot
.722 .51652 Mdot
.722 .5177 Mdot
.722 .51782 Mdot
.722 .51798 Mdot
.722 .51821 Mdot
.722 .51832 Mdot
.722 .51853 Mdot
.722 .51858 Mdot
.722 .5186 Mdot
.722 .51871 Mdot
.722 .51901 Mdot
.722 .51917 Mdot
.722 .51936 Mdot
.722 .52062 Mdot
.722 .52085 Mdot
.722 .52101 Mdot
.722 .52102 Mdot
.722 .52161 Mdot
.722 .52245 Mdot
.722 .52275 Mdot
.722 .52292 Mdot
.722 .52408 Mdot
.722 .52526 Mdot
.722 .52584 Mdot
.722 .52641 Mdot
.722 .52657 Mdot
.722 .52678 Mdot
.722 .52688 Mdot
.722 .527 Mdot
.722 .52751 Mdot
.722 .52801 Mdot
.722 .52842 Mdot
.722 .52855 Mdot
.722 .52939 Mdot
.722 .53002 Mdot
.722 .53022 Mdot
.722 .53027 Mdot
.722 .53033 Mdot
.722 .53055 Mdot
.722 .53058 Mdot
.722 .53058 Mdot
.722 .53067 Mdot
.722 .53071 Mdot
.722 .53081 Mdot
.722 .53083 Mdot
.722 .53083 Mdot
.722 .53089 Mdot
.722 .53093 Mdot
.722 .53143 Mdot
.722 .53152 Mdot
.722 .53159 Mdot
.722 .53172 Mdot
.722 .53197 Mdot
.722 .53225 Mdot
.722 .53249 Mdot
.722 .53299 Mdot
.722 .53311 Mdot
.722 .53337 Mdot
.722 .5336 Mdot
.722 .5343 Mdot
.722 .53476 Mdot
.722 .53483 Mdot
.722 .535 Mdot
.722 .53542 Mdot
.722 .5362 Mdot
.722 .53645 Mdot
.722 .53656 Mdot
.722 .53728 Mdot
.722 .53769 Mdot
.722 .53784 Mdot
.722 .53793 Mdot
.722 .53841 Mdot
.722 .5385 Mdot
.722 .5388 Mdot
.722 .53928 Mdot
.722 .53934 Mdot
.722 .53937 Mdot
.722 .53945 Mdot
.722 .53948 Mdot
.722 .54003 Mdot
.722 .54021 Mdot
.722 .5409 Mdot
.722 .54108 Mdot
.722 .54144 Mdot
.722 .54194 Mdot
.722 .54219 Mdot
.722 .54237 Mdot
.722 .54237 Mdot
.722 .54242 Mdot
.722 .54248 Mdot
.722 .54285 Mdot
.722 .54291 Mdot
.722 .54304 Mdot
.722 .54307 Mdot
.722 .54308 Mdot
.722 .54325 Mdot
.722 .5433 Mdot
.722 .54382 Mdot
.722 .54412 Mdot
.722 .54418 Mdot
.722 .54429 Mdot
.722 .54511 Mdot
.722 .54523 Mdot
.722 .54536 Mdot
.722 .54566 Mdot
.722 .5458 Mdot
.722 .54582 Mdot
.722 .54608 Mdot
.722 .54634 Mdot
.722 .54669 Mdot
.722 .54677 Mdot
.722 .54681 Mdot
.722 .54691 Mdot
.722 .54693 Mdot
.722 .54721 Mdot
.722 .54728 Mdot
.722 .54732 Mdot
.722 .54739 Mdot
.722 .54762 Mdot
.722 .54762 Mdot
.722 .54779 Mdot
.722 .54796 Mdot
.722 .54799 Mdot
.722 .548 Mdot
.722 .54801 Mdot
.722 .54802 Mdot
.722 .54804 Mdot
.722 .54804 Mdot
.722 .54805 Mdot
.722 .54805 Mdot
.722 .54805 Mdot
.722 .54805 Mdot
.722 .54805 Mdot
.722 .54805 Mdot
.722 .54805 Mdot
.722 .54805 Mdot
.722 .54829 Mdot
.722 .54883 Mdot
.722 .54902 Mdot
.722 .54942 Mdot
.722 .54994 Mdot
.722 .55021 Mdot
.722 .55036 Mdot
.722 .55054 Mdot
.722 .55094 Mdot
.722 .55154 Mdot
.722 .55163 Mdot
.722 .55173 Mdot
.722 .55174 Mdot
.722 .55174 Mdot
.722 .55179 Mdot
.722 .55198 Mdot
.722 .552 Mdot
.722 .55207 Mdot
.722 .55223 Mdot
.722 .55225 Mdot
.722 .55229 Mdot
.722 .55272 Mdot
.722 .55284 Mdot
.722 .55293 Mdot
.722 .55328 Mdot
.722 .55332 Mdot
.722 .55425 Mdot
.722 .55448 Mdot
.722 .55487 Mdot
.722 .55588 Mdot
.722 .55596 Mdot
.722 .55602 Mdot
.722 .5562 Mdot
.722 .55689 Mdot
.722 .55702 Mdot
.722 .5577 Mdot
.722 .55851 Mdot
.722 .5586 Mdot
.722 .5587 Mdot
.722 .55886 Mdot
.722 .55887 Mdot
.722 .55912 Mdot
.722 .55918 Mdot
.722 .55939 Mdot
.722 .55941 Mdot
.722 .56025 Mdot
.722 .56037 Mdot
.722 .56107 Mdot
.722 .56123 Mdot
.722 .56219 Mdot
.722 .56262 Mdot
.722 .56315 Mdot
.722 .56399 Mdot
.722 .56418 Mdot
.722 .56421 Mdot
.722 .56424 Mdot
.722 .56442 Mdot
.722 .56451 Mdot
.722 .56452 Mdot
.722 .56539 Mdot
.722 .56545 Mdot
.722 .56545 Mdot
.722 .56545 Mdot
.722 .56545 Mdot
.722 .56546 Mdot
.722 .56546 Mdot
.722 .56546 Mdot
.722 .56547 Mdot
.722 .56549 Mdot
.722 .5655 Mdot
.722 .56556 Mdot
.722 .56559 Mdot
.722 .56563 Mdot
.722 .56569 Mdot
.722 .56577 Mdot
.722 .56579 Mdot
.722 .5658 Mdot
.722 .56596 Mdot
.722 .56597 Mdot
.722 .56606 Mdot
.722 .56612 Mdot
.722 .56626 Mdot
.722 .56633 Mdot
.722 .56634 Mdot
.722 .56637 Mdot
.722 .5669 Mdot
.722 .56692 Mdot
.722 .56738 Mdot
.722 .56744 Mdot
.722 .56752 Mdot
.722 .56765 Mdot
.722 .56778 Mdot
.722 .56786 Mdot
.722 .5679 Mdot
.722 .56794 Mdot
.722 .56796 Mdot
.722 .56797 Mdot
.722 .56799 Mdot
.722 .56807 Mdot
.722 .56808 Mdot
.722 .56813 Mdot
.722 .5682 Mdot
.722 .56836 Mdot
.722 .56846 Mdot
.722 .56853 Mdot
.722 .56873 Mdot
.722 .56877 Mdot
.722 .56898 Mdot
.722 .56906 Mdot
.722 .5692 Mdot
.722 .56922 Mdot
.722 .56943 Mdot
.722 .56946 Mdot
.722 .56963 Mdot
.722 .56974 Mdot
.722 .56977 Mdot
.722 .56977 Mdot
.722 .5698 Mdot
.722 .56989 Mdot
.722 .56997 Mdot
.722 .5701 Mdot
.722 .57012 Mdot
.722 .57014 Mdot
.722 .57019 Mdot
.722 .57021 Mdot
.722 .57026 Mdot
.722 .57036 Mdot
.722 .57038 Mdot
.722 .5704 Mdot
.722 .57046 Mdot
.722 .57047 Mdot
.722 .57048 Mdot
.722 .57052 Mdot
.722 .57052 Mdot
.722 .57055 Mdot
.722 .57058 Mdot
.722 .57058 Mdot
.722 .57058 Mdot
.722 .57059 Mdot
.722 .57059 Mdot
.722 .57059 Mdot
.722 .57059 Mdot
.722 .57059 Mdot
.722 .57059 Mdot
.722 .57059 Mdot
.722 .57059 Mdot
.722 .57059 Mdot
.722 .57059 Mdot
.722 .57059 Mdot
.722 .57059 Mdot
.724 .13073 Mdot
.724 .13073 Mdot
.724 .13073 Mdot
.724 .13075 Mdot
.724 .13078 Mdot
.724 .13081 Mdot
.724 .13082 Mdot
.724 .13083 Mdot
.724 .13087 Mdot
.724 .13106 Mdot
.724 .13128 Mdot
.724 .13129 Mdot
.724 .13138 Mdot
.724 .13145 Mdot
.724 .13146 Mdot
.724 .13147 Mdot
.724 .13166 Mdot
.724 .13176 Mdot
.724 .13186 Mdot
.724 .13186 Mdot
.724 .1319 Mdot
.724 .13192 Mdot
.724 .13192 Mdot
.724 .13204 Mdot
.724 .13233 Mdot
.724 .13245 Mdot
.724 .13268 Mdot
.724 .13297 Mdot
.724 .13341 Mdot
.724 .1335 Mdot
.724 .13352 Mdot
.724 .13371 Mdot
.724 .13404 Mdot
.724 .13411 Mdot
.724 .13465 Mdot
.724 .13484 Mdot
.724 .13561 Mdot
.724 .13567 Mdot
.724 .13606 Mdot
.724 .13608 Mdot
.724 .1367 Mdot
.724 .13679 Mdot
.724 .13686 Mdot
.724 .1369 Mdot
.724 .13729 Mdot
.724 .13784 Mdot
.724 .13804 Mdot
.724 .13818 Mdot
.724 .13825 Mdot
.724 .13885 Mdot
.724 .13995 Mdot
.724 .14 Mdot
.724 .14008 Mdot
.724 .14013 Mdot
.724 .14037 Mdot
.724 .14042 Mdot
.724 .14046 Mdot
.724 .1406 Mdot
.724 .14095 Mdot
.724 .14104 Mdot
.724 .14166 Mdot
.724 .1425 Mdot
.724 .14251 Mdot
.724 .14271 Mdot
.724 .1428 Mdot
.724 .14446 Mdot
.724 .14456 Mdot
.724 .145 Mdot
.724 .14534 Mdot
.724 .14542 Mdot
.724 .14545 Mdot
.724 .14579 Mdot
.724 .14594 Mdot
.724 .1462 Mdot
.724 .1465 Mdot
.724 .14671 Mdot
.724 .14715 Mdot
.724 .14724 Mdot
.724 .14748 Mdot
.724 .14771 Mdot
.724 .1485 Mdot
.724 .14855 Mdot
.724 .14876 Mdot
.724 .1489 Mdot
.724 .14948 Mdot
.724 .14963 Mdot
.724 .1503 Mdot
.724 .15086 Mdot
.724 .15141 Mdot
.724 .15241 Mdot
.724 .15261 Mdot
.724 .15271 Mdot
.724 .15297 Mdot
.724 .15346 Mdot
.724 .15347 Mdot
.724 .15572 Mdot
.724 .1575 Mdot
.724 .15761 Mdot
.724 .15824 Mdot
.724 .15864 Mdot
.724 .15957 Mdot
.724 .16119 Mdot
.724 .16158 Mdot
.724 .16207 Mdot
.724 .16348 Mdot
.724 .16415 Mdot
.724 .16423 Mdot
.724 .16456 Mdot
.724 .16499 Mdot
.724 .16502 Mdot
.724 .16516 Mdot
.724 .16617 Mdot
.724 .16692 Mdot
.724 .16755 Mdot
.724 .16771 Mdot
.724 .16773 Mdot
.724 .16934 Mdot
.724 .16971 Mdot
.724 .17264 Mdot
.724 .1737 Mdot
.724 .17433 Mdot
.724 .17464 Mdot
.724 .17562 Mdot
.724 .17754 Mdot
.724 .18118 Mdot
.724 .1824 Mdot
.724 .18537 Mdot
.724 .18689 Mdot
.724 .18783 Mdot
.724 .18855 Mdot
.724 .18875 Mdot
.724 .1892 Mdot
.724 .18981 Mdot
.724 .18996 Mdot
.724 .19321 Mdot
.724 .19383 Mdot
.724 .19399 Mdot
.724 .19422 Mdot
.724 .19467 Mdot
.724 .195 Mdot
.724 .19563 Mdot
.724 .19569 Mdot
.724 .19943 Mdot
.724 .1997 Mdot
.724 .1997 Mdot
.724 .19973 Mdot
.724 .19984 Mdot
.724 .19998 Mdot
.724 .20016 Mdot
.724 .20019 Mdot
.724 .20026 Mdot
.724 .20046 Mdot
.724 .20146 Mdot
.724 .20198 Mdot
.724 .20246 Mdot
.724 .20263 Mdot
.724 .2027 Mdot
.724 .20318 Mdot
.724 .20352 Mdot
.724 .20361 Mdot
.724 .20362 Mdot
.724 .20387 Mdot
.724 .20421 Mdot
.724 .20465 Mdot
.724 .20516 Mdot
.724 .20551 Mdot
.724 .20571 Mdot
.724 .20574 Mdot
.724 .20593 Mdot
.724 .20603 Mdot
.724 .20606 Mdot
.724 .20647 Mdot
.724 .20672 Mdot
.724 .20731 Mdot
.724 .20828 Mdot
.724 .20858 Mdot
.724 .20893 Mdot
.724 .20978 Mdot
.724 .21014 Mdot
.724 .2102 Mdot
.724 .21041 Mdot
.724 .21164 Mdot
.724 .2118 Mdot
.724 .21237 Mdot
.724 .21314 Mdot
.724 .21367 Mdot
.724 .21405 Mdot
.724 .21425 Mdot
.724 .21477 Mdot
.724 .21489 Mdot
.724 .21594 Mdot
.724 .21614 Mdot
.724 .2174 Mdot
.724 .21776 Mdot
.724 .21778 Mdot
.724 .21818 Mdot
.724 .21917 Mdot
.724 .22063 Mdot
.724 .22073 Mdot
.724 .22076 Mdot
.724 .22127 Mdot
.724 .2214 Mdot
.724 .22187 Mdot
.724 .22237 Mdot
.724 .22405 Mdot
.724 .22685 Mdot
.724 .22716 Mdot
.724 .22721 Mdot
.724 .22907 Mdot
.724 .22948 Mdot
.724 .22959 Mdot
.724 .23286 Mdot
.724 .23291 Mdot
.724 .23295 Mdot
.724 .23323 Mdot
.724 .23378 Mdot
.724 .23421 Mdot
.724 .23443 Mdot
.724 .23559 Mdot
.724 .23611 Mdot
.724 .23647 Mdot
.724 .2368 Mdot
.724 .23699 Mdot
.724 .23798 Mdot
.724 .23942 Mdot
.724 .24012 Mdot
.724 .24133 Mdot
.724 .24218 Mdot
.724 .24236 Mdot
.724 .24261 Mdot
.724 .24262 Mdot
.724 .24324 Mdot
.724 .24379 Mdot
.724 .24444 Mdot
.724 .24596 Mdot
.724 .24626 Mdot
.724 .24676 Mdot
.724 .24687 Mdot
.724 .24702 Mdot
.724 .2495 Mdot
.724 .2531 Mdot
.724 .25338 Mdot
.724 .25384 Mdot
.724 .25391 Mdot
.724 .25419 Mdot
.724 .25569 Mdot
.724 .25577 Mdot
.724 .25605 Mdot
.724 .25626 Mdot
.724 .25636 Mdot
.724 .2567 Mdot
.724 .25714 Mdot
.724 .25788 Mdot
.724 .25933 Mdot
.724 .25994 Mdot
.724 .2628 Mdot
.724 .26332 Mdot
.724 .26349 Mdot
.724 .26383 Mdot
.724 .2644 Mdot
.724 .26603 Mdot
.724 .26876 Mdot
.724 .26923 Mdot
.724 .26928 Mdot
.724 .27056 Mdot
.724 .27087 Mdot
.724 .27111 Mdot
.724 .27215 Mdot
.724 .27276 Mdot
.724 .27345 Mdot
.724 .27787 Mdot
.724 .2783 Mdot
.724 .27926 Mdot
.724 .27938 Mdot
.724 .28083 Mdot
.724 .28122 Mdot
.724 .28186 Mdot
.724 .28248 Mdot
.724 .28279 Mdot
.724 .28282 Mdot
.724 .28289 Mdot
.724 .2832 Mdot
.724 .28537 Mdot
.724 .28757 Mdot
.724 .28772 Mdot
.724 .28776 Mdot
.724 .28809 Mdot
.724 .28829 Mdot
.724 .29057 Mdot
.724 .29082 Mdot
.724 .29154 Mdot
.724 .29208 Mdot
.724 .29213 Mdot
.724 .29324 Mdot
.724 .29327 Mdot
.724 .29519 Mdot
.724 .29662 Mdot
.724 .29724 Mdot
.724 .29785 Mdot
.724 .29949 Mdot
.724 .30008 Mdot
.724 .3012 Mdot
.724 .30157 Mdot
.724 .30164 Mdot
.724 .30177 Mdot
.724 .30316 Mdot
.724 .30323 Mdot
.724 .30388 Mdot
.724 .30394 Mdot
.724 .30507 Mdot
.724 .30678 Mdot
.724 .30844 Mdot
.724 .30872 Mdot
.724 .30927 Mdot
.724 .31016 Mdot
.724 .31059 Mdot
.724 .31103 Mdot
.724 .3111 Mdot
.724 .31162 Mdot
.724 .31455 Mdot
.724 .31488 Mdot
.724 .3156 Mdot
.724 .31593 Mdot
.724 .31628 Mdot
.724 .31645 Mdot
.724 .31764 Mdot
.724 .31922 Mdot
.724 .32037 Mdot
.724 .32041 Mdot
.724 .32155 Mdot
.724 .32252 Mdot
.724 .32408 Mdot
.724 .32417 Mdot
.724 .32568 Mdot
.724 .3258 Mdot
.724 .32764 Mdot
.724 .32773 Mdot
.724 .32846 Mdot
.724 .3298 Mdot
.724 .32989 Mdot
.724 .33021 Mdot
.724 .33084 Mdot
.724 .33094 Mdot
.724 .33159 Mdot
.724 .33245 Mdot
.724 .33246 Mdot
.724 .33275 Mdot
.724 .33434 Mdot
.724 .33443 Mdot
.724 .33568 Mdot
.724 .33591 Mdot
.724 .33636 Mdot
.724 .33673 Mdot
.724 .33701 Mdot
.724 .33786 Mdot
.724 .3379 Mdot
.724 .33808 Mdot
.724 .33818 Mdot
.724 .3393 Mdot
.724 .34091 Mdot
.724 .34106 Mdot
.724 .34113 Mdot
.724 .34132 Mdot
.724 .34168 Mdot
.724 .34169 Mdot
.724 .34329 Mdot
.724 .34451 Mdot
.724 .34501 Mdot
.724 .34834 Mdot
.724 .349 Mdot
.724 .34926 Mdot
.724 .34936 Mdot
.724 .34996 Mdot
.724 .3504 Mdot
.724 .35077 Mdot
.724 .35086 Mdot
.724 .35087 Mdot
.724 .35179 Mdot
.724 .35624 Mdot
.724 .3643 Mdot
.724 .3645 Mdot
.724 .36496 Mdot
.724 .36662 Mdot
.724 .36674 Mdot
.724 .36674 Mdot
.724 .36675 Mdot
.724 .3668 Mdot
.724 .36686 Mdot
.724 .36693 Mdot
.724 .36695 Mdot
.724 .36698 Mdot
.724 .36707 Mdot
.724 .3675 Mdot
.724 .36772 Mdot
.724 .36793 Mdot
.724 .368 Mdot
.724 .36803 Mdot
.724 .36824 Mdot
.724 .36838 Mdot
.724 .36842 Mdot
.724 .36843 Mdot
.724 .36868 Mdot
.724 .36887 Mdot
.724 .36908 Mdot
.724 .36923 Mdot
.724 .36932 Mdot
.724 .36933 Mdot
.724 .36941 Mdot
.724 .36945 Mdot
.724 .36946 Mdot
.724 .36974 Mdot
.724 .36999 Mdot
.724 .37039 Mdot
.724 .37051 Mdot
.724 .37066 Mdot
.724 .37118 Mdot
.724 .37184 Mdot
.724 .37239 Mdot
.724 .3726 Mdot
.724 .37275 Mdot
.724 .37284 Mdot
.724 .37305 Mdot
.724 .37309 Mdot
.724 .37351 Mdot
.724 .37409 Mdot
.724 .37424 Mdot
.724 .3744 Mdot
.724 .37537 Mdot
.724 .37562 Mdot
.724 .37605 Mdot
.724 .37777 Mdot
.724 .37789 Mdot
.724 .37877 Mdot
.724 .37881 Mdot
.724 .38003 Mdot
.724 .38007 Mdot
.724 .38017 Mdot
.724 .38037 Mdot
.724 .38053 Mdot
.724 .38062 Mdot
.724 .38137 Mdot
.724 .38149 Mdot
.724 .3827 Mdot
.724 .38314 Mdot
.724 .38344 Mdot
.724 .38351 Mdot
.724 .3836 Mdot
.724 .38402 Mdot
.724 .3849 Mdot
.724 .38605 Mdot
.724 .38731 Mdot
.724 .38741 Mdot
.724 .38757 Mdot
.724 .38759 Mdot
.724 .38769 Mdot
.724 .38821 Mdot
.724 .38823 Mdot
.724 .38833 Mdot
.724 .38841 Mdot
.724 .38871 Mdot
.724 .38946 Mdot
.724 .38967 Mdot
.724 .39064 Mdot
.724 .39099 Mdot
.724 .39173 Mdot
.724 .39265 Mdot
.724 .39281 Mdot
.724 .39282 Mdot
.724 .39325 Mdot
.724 .39335 Mdot
.724 .39343 Mdot
.724 .39378 Mdot
.724 .39421 Mdot
.724 .3958 Mdot
.724 .39612 Mdot
.724 .39697 Mdot
.724 .39717 Mdot
.724 .39728 Mdot
.724 .3981 Mdot
.724 .39881 Mdot
.724 .39887 Mdot
.724 .39898 Mdot
.724 .39904 Mdot
.724 .39977 Mdot
.724 .40009 Mdot
.724 .40063 Mdot
.724 .40125 Mdot
.724 .4017 Mdot
.724 .40261 Mdot
.724 .40279 Mdot
.724 .40328 Mdot
.724 .40332 Mdot
.724 .40376 Mdot
.724 .404 Mdot
.724 .40541 Mdot
.724 .4055 Mdot
.724 .40594 Mdot
.724 .40608 Mdot
.724 .40621 Mdot
.724 .4073 Mdot
.724 .4074 Mdot
.724 .40773 Mdot
.724 .40874 Mdot
.724 .40909 Mdot
.724 .41023 Mdot
.724 .41026 Mdot
.724 .41076 Mdot
.724 .41134 Mdot
.724 .41278 Mdot
.724 .41278 Mdot
.724 .41335 Mdot
.724 .41376 Mdot
.724 .41396 Mdot
.724 .41408 Mdot
.724 .41448 Mdot
.724 .41538 Mdot
.724 .41546 Mdot
.724 .41548 Mdot
.724 .41557 Mdot
.724 .41642 Mdot
.724 .41994 Mdot
.724 .42254 Mdot
.724 .42343 Mdot
.724 .42365 Mdot
.724 .42476 Mdot
.724 .42486 Mdot
.724 .42526 Mdot
.724 .42564 Mdot
.724 .42703 Mdot
.724 .42704 Mdot
.724 .42743 Mdot
.724 .43053 Mdot
.724 .4308 Mdot
.724 .43101 Mdot
.724 .43127 Mdot
.724 .43174 Mdot
.724 .43184 Mdot
.724 .43218 Mdot
.724 .434 Mdot
.724 .4342 Mdot
.724 .43483 Mdot
.724 .43519 Mdot
.724 .43609 Mdot
.724 .43624 Mdot
.724 .43685 Mdot
.724 .43724 Mdot
.724 .43763 Mdot
.724 .43769 Mdot
.724 .43795 Mdot
.724 .43981 Mdot
.724 .44064 Mdot
.724 .44119 Mdot
.724 .44119 Mdot
.724 .44234 Mdot
.724 .44263 Mdot
.724 .44266 Mdot
.724 .44333 Mdot
.724 .44557 Mdot
.724 .44624 Mdot
.724 .44993 Mdot
.724 .45111 Mdot
.724 .45141 Mdot
.724 .45326 Mdot
.724 .45436 Mdot
.724 .45489 Mdot
.724 .455 Mdot
.724 .45615 Mdot
.724 .4562 Mdot
.724 .45659 Mdot
.724 .4567 Mdot
.724 .45866 Mdot
.724 .45867 Mdot
.724 .45959 Mdot
.724 .45985 Mdot
.724 .46099 Mdot
.724 .46409 Mdot
.724 .46452 Mdot
.724 .46461 Mdot
.724 .46527 Mdot
.724 .46591 Mdot
.724 .46591 Mdot
.724 .46691 Mdot
.724 .46716 Mdot
.724 .4679 Mdot
.724 .46861 Mdot
.724 .4692 Mdot
.724 .47021 Mdot
.724 .47054 Mdot
.724 .47267 Mdot
.724 .47343 Mdot
.724 .47397 Mdot
.724 .47412 Mdot
.724 .47487 Mdot
.724 .47507 Mdot
.724 .47527 Mdot
.724 .4756 Mdot
.724 .47603 Mdot
.724 .47654 Mdot
.724 .47765 Mdot
.724 .47796 Mdot
.724 .47866 Mdot
.724 .47959 Mdot
.724 .47982 Mdot
.724 .4808 Mdot
.724 .48138 Mdot
.724 .4814 Mdot
.724 .48349 Mdot
.724 .48406 Mdot
.724 .48466 Mdot
.724 .48472 Mdot
.724 .48482 Mdot
.724 .48565 Mdot
.724 .48588 Mdot
.724 .48621 Mdot
.724 .48646 Mdot
.724 .48678 Mdot
.724 .48687 Mdot
.724 .48736 Mdot
.724 .48808 Mdot
.724 .48828 Mdot
.724 .48837 Mdot
.724 .49183 Mdot
.724 .49372 Mdot
.724 .49411 Mdot
.724 .49411 Mdot
.724 .49415 Mdot
.724 .4943 Mdot
.724 .49449 Mdot
.724 .49474 Mdot
.724 .49478 Mdot
.724 .49489 Mdot
.724 .49517 Mdot
.724 .49656 Mdot
.724 .49676 Mdot
.724 .49727 Mdot
.724 .49793 Mdot
.724 .49793 Mdot
.724 .49805 Mdot
.724 .49808 Mdot
.724 .49816 Mdot
.724 .49819 Mdot
.724 .49825 Mdot
.724 .49891 Mdot
.724 .49937 Mdot
.724 .49941 Mdot
.724 .49949 Mdot
.724 .4995 Mdot
.724 .49985 Mdot
.724 .49996 Mdot
.724 .50011 Mdot
.724 .5003 Mdot
.724 .50039 Mdot
.724 .5009 Mdot
.724 .50093 Mdot
.724 .50158 Mdot
.724 .5017 Mdot
.724 .5017 Mdot
.724 .50205 Mdot
.724 .50231 Mdot
.724 .50235 Mdot
.724 .5026 Mdot
.724 .50273 Mdot
.724 .50277 Mdot
.724 .50331 Mdot
.724 .5036 Mdot
.724 .50363 Mdot
.724 .50437 Mdot
.724 .50442 Mdot
.724 .50502 Mdot
.724 .50505 Mdot
.724 .50567 Mdot
.724 .50606 Mdot
.724 .50651 Mdot
.724 .50652 Mdot
.724 .50697 Mdot
.724 .50759 Mdot
.724 .50806 Mdot
.724 .50813 Mdot
.724 .50827 Mdot
.724 .50839 Mdot
.724 .50868 Mdot
.724 .50881 Mdot
.724 .50994 Mdot
.724 .51014 Mdot
.724 .51017 Mdot
.724 .51034 Mdot
.724 .51051 Mdot
.724 .51085 Mdot
.724 .51106 Mdot
.724 .51117 Mdot
.724 .51181 Mdot
.724 .51247 Mdot
.724 .5129 Mdot
.724 .51292 Mdot
.724 .51317 Mdot
.724 .51319 Mdot
.724 .51372 Mdot
.724 .51377 Mdot
.724 .5138 Mdot
.724 .51394 Mdot
.724 .51437 Mdot
.724 .51459 Mdot
.724 .51521 Mdot
.724 .51544 Mdot
.724 .51568 Mdot
.724 .51621 Mdot
.724 .51693 Mdot
.724 .51694 Mdot
.724 .51736 Mdot
.724 .51738 Mdot
.724 .51758 Mdot
.724 .51785 Mdot
.724 .51794 Mdot
.724 .51879 Mdot
.724 .51886 Mdot
.724 .51899 Mdot
.724 .519 Mdot
.724 .51906 Mdot
.724 .51987 Mdot
.724 .52067 Mdot
.724 .52079 Mdot
.724 .52081 Mdot
.724 .52082 Mdot
.724 .52094 Mdot
.724 .52116 Mdot
.724 .5214 Mdot
.724 .52154 Mdot
.724 .52207 Mdot
.724 .52212 Mdot
.724 .52247 Mdot
.724 .52262 Mdot
.724 .52423 Mdot
.724 .52448 Mdot
.724 .5247 Mdot
.724 .52507 Mdot
.724 .52516 Mdot
.724 .52527 Mdot
.724 .52573 Mdot
.724 .52575 Mdot
.724 .52592 Mdot
.724 .5269 Mdot
.724 .52748 Mdot
.724 .52768 Mdot
.724 .5278 Mdot
.724 .52786 Mdot
.724 .52805 Mdot
.724 .52906 Mdot
.724 .52928 Mdot
.724 .52979 Mdot
.724 .53005 Mdot
.724 .53021 Mdot
.724 .53033 Mdot
.724 .53036 Mdot
.724 .53044 Mdot
.724 .53054 Mdot
.724 .53056 Mdot
.724 .53109 Mdot
.724 .53119 Mdot
.724 .53121 Mdot
.724 .53137 Mdot
.724 .53147 Mdot
.724 .53273 Mdot
.724 .53359 Mdot
.724 .53364 Mdot
.724 .53368 Mdot
.724 .53385 Mdot
.724 .53396 Mdot
.724 .53448 Mdot
.724 .5347 Mdot
.724 .5349 Mdot
.724 .53511 Mdot
.724 .53511 Mdot
.724 .5352 Mdot
.724 .53526 Mdot
.724 .53555 Mdot
.724 .53597 Mdot
.724 .53621 Mdot
.724 .5367 Mdot
.724 .53704 Mdot
.724 .53711 Mdot
.724 .53722 Mdot
.724 .53734 Mdot
.724 .53752 Mdot
.724 .53791 Mdot
.724 .53799 Mdot
.724 .53814 Mdot
.724 .53832 Mdot
.724 .53842 Mdot
.724 .53843 Mdot
.724 .53845 Mdot
.724 .53955 Mdot
.724 .53959 Mdot
.724 .53973 Mdot
.724 .54036 Mdot
.724 .54037 Mdot
.724 .54048 Mdot
.724 .54142 Mdot
.724 .54198 Mdot
.724 .54215 Mdot
.724 .5423 Mdot
.724 .54235 Mdot
.724 .54252 Mdot
.724 .54253 Mdot
.724 .54256 Mdot
.724 .54305 Mdot
.724 .54338 Mdot
.724 .54351 Mdot
.724 .54352 Mdot
.724 .54364 Mdot
.724 .54405 Mdot
.724 .54412 Mdot
.724 .54447 Mdot
.724 .54451 Mdot
.724 .54468 Mdot
.724 .54475 Mdot
.724 .54487 Mdot
.724 .54504 Mdot
.724 .5453 Mdot
.724 .54549 Mdot
.724 .54554 Mdot
.724 .54595 Mdot
.724 .54601 Mdot
.724 .54603 Mdot
.724 .54615 Mdot
.724 .54643 Mdot
.724 .54655 Mdot
.724 .54664 Mdot
.724 .54696 Mdot
.724 .54716 Mdot
.724 .54724 Mdot
.724 .54737 Mdot
.724 .54738 Mdot
.724 .54741 Mdot
.724 .54747 Mdot
.724 .54748 Mdot
.724 .54755 Mdot
.724 .54766 Mdot
.724 .54783 Mdot
.724 .54797 Mdot
.724 .54808 Mdot
.724 .54817 Mdot
.724 .54817 Mdot
.724 .5482 Mdot
.724 .54831 Mdot
.724 .54847 Mdot
.724 .54849 Mdot
.724 .54854 Mdot
.724 .5487 Mdot
.724 .54887 Mdot
.724 .54919 Mdot
.724 .54926 Mdot
.724 .54928 Mdot
.724 .54929 Mdot
.724 .54935 Mdot
.724 .54939 Mdot
.724 .54943 Mdot
.724 .54944 Mdot
.724 .54944 Mdot
.724 .54953 Mdot
.724 .55073 Mdot
.724 .55075 Mdot
.724 .55096 Mdot
.724 .55106 Mdot
.724 .55121 Mdot
.724 .55128 Mdot
.724 .55133 Mdot
.724 .55153 Mdot
.724 .55257 Mdot
.724 .55262 Mdot
.724 .55281 Mdot
.724 .55296 Mdot
.724 .55302 Mdot
.724 .55325 Mdot
.724 .55355 Mdot
.724 .55404 Mdot
.724 .55498 Mdot
.724 .55536 Mdot
.724 .55651 Mdot
.724 .55711 Mdot
.724 .55742 Mdot
.724 .55752 Mdot
.724 .55772 Mdot
.724 .55805 Mdot
.724 .55896 Mdot
.724 .55908 Mdot
.724 .55958 Mdot
.724 .55958 Mdot
.724 .55963 Mdot
.724 .55983 Mdot
.724 .56006 Mdot
.724 .56038 Mdot
.724 .56042 Mdot
.724 .56043 Mdot
.724 .56056 Mdot
.724 .56066 Mdot
.724 .56069 Mdot
.724 .5609 Mdot
.724 .56133 Mdot
.724 .56148 Mdot
.724 .5616 Mdot
.724 .5621 Mdot
.724 .56239 Mdot
.724 .56251 Mdot
.724 .5627 Mdot
.724 .56274 Mdot
.724 .56329 Mdot
.724 .56397 Mdot
.724 .56398 Mdot
.724 .56413 Mdot
.724 .56421 Mdot
.724 .56424 Mdot
.724 .5643 Mdot
.724 .5646 Mdot
.724 .56477 Mdot
.724 .56494 Mdot
.724 .56514 Mdot
.724 .56519 Mdot
.724 .56537 Mdot
.724 .56541 Mdot
.724 .56547 Mdot
.724 .56549 Mdot
.724 .56573 Mdot
.724 .5658 Mdot
.724 .56587 Mdot
.724 .5659 Mdot
.724 .56603 Mdot
.724 .56609 Mdot
.724 .56618 Mdot
.724 .56626 Mdot
.724 .56631 Mdot
.724 .56641 Mdot
.724 .56642 Mdot
.724 .56645 Mdot
.724 .56655 Mdot
.724 .56668 Mdot
.724 .56671 Mdot
.724 .56721 Mdot
.724 .56724 Mdot
.724 .5673 Mdot
.724 .5673 Mdot
.724 .56756 Mdot
.724 .56774 Mdot
.724 .56777 Mdot
.724 .56788 Mdot
.724 .56792 Mdot
.724 .56793 Mdot
.724 .56794 Mdot
.724 .56802 Mdot
.724 .56803 Mdot
.724 .56806 Mdot
.724 .56807 Mdot
.724 .5684 Mdot
.724 .56858 Mdot
.724 .5686 Mdot
.724 .56864 Mdot
.724 .5687 Mdot
.724 .56887 Mdot
.724 .56899 Mdot
.724 .569 Mdot
.724 .56902 Mdot
.724 .56905 Mdot
.724 .56923 Mdot
.724 .56924 Mdot
.724 .56935 Mdot
.724 .56937 Mdot
.724 .5696 Mdot
.724 .56966 Mdot
.724 .56982 Mdot
.724 .56984 Mdot
.724 .56994 Mdot
.724 .56999 Mdot
.724 .57 Mdot
.724 .57003 Mdot
.724 .57016 Mdot
.724 .57025 Mdot
.724 .57032 Mdot
.724 .57035 Mdot
.724 .57044 Mdot
.724 .57047 Mdot
.724 .57047 Mdot
.724 .57048 Mdot
.724 .57049 Mdot
.724 .57049 Mdot
.724 .57052 Mdot
.724 .57055 Mdot
.724 .57061 Mdot
.724 .57061 Mdot
.724 .57061 Mdot
.724 .57063 Mdot
.724 .57066 Mdot
.724 .57066 Mdot
.724 .57073 Mdot
.724 .57078 Mdot
.724 .5708 Mdot
.724 .5708 Mdot
.724 .5708 Mdot
.724 .57081 Mdot
.724 .57082 Mdot
.724 .57083 Mdot
.724 .57083 Mdot
.724 .57083 Mdot
.726 .12999 Mdot
.726 .12999 Mdot
.726 .12999 Mdot
.726 .13 Mdot
.726 .13 Mdot
.726 .13005 Mdot
.726 .13005 Mdot
.726 .1301 Mdot
.726 .13015 Mdot
.726 .13016 Mdot
.726 .13017 Mdot
.726 .13018 Mdot
.726 .13029 Mdot
.726 .13032 Mdot
.726 .13034 Mdot
.726 .1305 Mdot
.726 .13063 Mdot
.726 .13077 Mdot
.726 .13082 Mdot
.726 .1311 Mdot
.726 .13116 Mdot
.726 .1315 Mdot
.726 .13165 Mdot
.726 .132 Mdot
.726 .13204 Mdot
.726 .13217 Mdot
.726 .13228 Mdot
.726 .13229 Mdot
.726 .13238 Mdot
.726 .13277 Mdot
.726 .13333 Mdot
.726 .1335 Mdot
.726 .13359 Mdot
.726 .13365 Mdot
.726 .13374 Mdot
.726 .1346 Mdot
.726 .13463 Mdot
.726 .13472 Mdot
.726 .13476 Mdot
.726 .13521 Mdot
.726 .13608 Mdot
.726 .13617 Mdot
.726 .13633 Mdot
.726 .13674 Mdot
.726 .13696 Mdot
.726 .13702 Mdot
.726 .1378 Mdot
.726 .13841 Mdot
.726 .13843 Mdot
.726 .13994 Mdot
.726 .13997 Mdot
.726 .14009 Mdot
.726 .14036 Mdot
.726 .14109 Mdot
.726 .14192 Mdot
.726 .14301 Mdot
.726 .14358 Mdot
.726 .14456 Mdot
.726 .145 Mdot
.726 .14531 Mdot
.726 .1459 Mdot
.726 .14622 Mdot
.726 .14763 Mdot
.726 .14798 Mdot
.726 .14801 Mdot
.726 .14866 Mdot
.726 .14893 Mdot
.726 .14984 Mdot
.726 .15081 Mdot
.726 .15187 Mdot
.726 .15304 Mdot
.726 .15326 Mdot
.726 .15454 Mdot
.726 .15512 Mdot
.726 .15589 Mdot
.726 .15641 Mdot
.726 .15699 Mdot
.726 .15721 Mdot
.726 .15727 Mdot
.726 .15747 Mdot
.726 .15837 Mdot
.726 .15854 Mdot
.726 .16007 Mdot
.726 .1611 Mdot
.726 .16345 Mdot
.726 .16345 Mdot
.726 .16351 Mdot
.726 .1651 Mdot
.726 .16513 Mdot
.726 .16662 Mdot
.726 .16789 Mdot
.726 .16867 Mdot
.726 .17001 Mdot
.726 .17001 Mdot
.726 .17044 Mdot
.726 .17118 Mdot
.726 .17118 Mdot
.726 .17376 Mdot
.726 .17438 Mdot
.726 .17513 Mdot
.726 .1753 Mdot
.726 .17648 Mdot
.726 .17735 Mdot
.726 .178 Mdot
.726 .17816 Mdot
.726 .1796 Mdot
.726 .17996 Mdot
.726 .18071 Mdot
.726 .18093 Mdot
.726 .18142 Mdot
.726 .18256 Mdot
.726 .18639 Mdot
.726 .18665 Mdot
.726 .18675 Mdot
.726 .18705 Mdot
.726 .18715 Mdot
.726 .18764 Mdot
.726 .18786 Mdot
.726 .18942 Mdot
.726 .18953 Mdot
.726 .19077 Mdot
.726 .19091 Mdot
.726 .19125 Mdot
.726 .19142 Mdot
.726 .19148 Mdot
.726 .19311 Mdot
.726 .1932 Mdot
.726 .19332 Mdot
.726 .19358 Mdot
.726 .1936 Mdot
.726 .19368 Mdot
.726 .19376 Mdot
.726 .19431 Mdot
.726 .19484 Mdot
.726 .19495 Mdot
.726 .19533 Mdot
.726 .19557 Mdot
.726 .19558 Mdot
.726 .19559 Mdot
.726 .1956 Mdot
.726 .19563 Mdot
.726 .19566 Mdot
.726 .19589 Mdot
.726 .19591 Mdot
.726 .19616 Mdot
.726 .19641 Mdot
.726 .19648 Mdot
.726 .1965 Mdot
.726 .19659 Mdot
.726 .19714 Mdot
.726 .19731 Mdot
.726 .19738 Mdot
.726 .19742 Mdot
.726 .19806 Mdot
.726 .19824 Mdot
.726 .19839 Mdot
.726 .19891 Mdot
.726 .19903 Mdot
.726 .19932 Mdot
.726 .19968 Mdot
.726 .19994 Mdot
.726 .20137 Mdot
.726 .20169 Mdot
.726 .20197 Mdot
.726 .20345 Mdot
.726 .20354 Mdot
.726 .20434 Mdot
.726 .20625 Mdot
.726 .20647 Mdot
.726 .20679 Mdot
.726 .20715 Mdot
.726 .20775 Mdot
.726 .2078 Mdot
.726 .20782 Mdot
.726 .20833 Mdot
.726 .20848 Mdot
.726 .20913 Mdot
.726 .20933 Mdot
.726 .21044 Mdot
.726 .21141 Mdot
.726 .21142 Mdot
.726 .21246 Mdot
.726 .21259 Mdot
.726 .21318 Mdot
.726 .21359 Mdot
.726 .21384 Mdot
.726 .21402 Mdot
.726 .21455 Mdot
.726 .21506 Mdot
.726 .21536 Mdot
.726 .21546 Mdot
.726 .21554 Mdot
.726 .21561 Mdot
.726 .21587 Mdot
.726 .21631 Mdot
.726 .21639 Mdot
.726 .21644 Mdot
.726 .21764 Mdot
.726 .218 Mdot
.726 .2191 Mdot
.726 .21915 Mdot
.726 .22078 Mdot
.726 .22094 Mdot
.726 .22151 Mdot
.726 .22169 Mdot
.726 .22326 Mdot
.726 .22434 Mdot
.726 .22456 Mdot
.726 .22591 Mdot
.726 .22725 Mdot
.726 .22764 Mdot
.726 .22778 Mdot
.726 .22923 Mdot
.726 .22941 Mdot
.726 .22999 Mdot
.726 .23091 Mdot
.726 .23232 Mdot
.726 .23334 Mdot
.726 .23358 Mdot
.726 .23467 Mdot
.726 .23503 Mdot
.726 .23975 Mdot
.726 .2404 Mdot
.726 .24092 Mdot
.726 .24142 Mdot
.726 .24347 Mdot
.726 .24361 Mdot
.726 .24444 Mdot
.726 .24505 Mdot
.726 .24512 Mdot
.726 .24563 Mdot
.726 .2461 Mdot
.726 .24801 Mdot
.726 .25204 Mdot
.726 .25295 Mdot
.726 .25312 Mdot
.726 .25391 Mdot
.726 .2547 Mdot
.726 .25559 Mdot
.726 .25638 Mdot
.726 .25691 Mdot
.726 .26022 Mdot
.726 .26114 Mdot
.726 .26122 Mdot
.726 .26155 Mdot
.726 .26271 Mdot
.726 .26344 Mdot
.726 .26484 Mdot
.726 .26548 Mdot
.726 .26668 Mdot
.726 .2683 Mdot
.726 .26929 Mdot
.726 .27073 Mdot
.726 .27139 Mdot
.726 .27237 Mdot
.726 .27248 Mdot
.726 .2734 Mdot
.726 .27467 Mdot
.726 .27598 Mdot
.726 .27614 Mdot
.726 .27854 Mdot
.726 .27947 Mdot
.726 .28002 Mdot
.726 .28176 Mdot
.726 .28227 Mdot
.726 .28255 Mdot
.726 .28438 Mdot
.726 .28544 Mdot
.726 .28733 Mdot
.726 .28747 Mdot
.726 .2875 Mdot
.726 .29094 Mdot
.726 .29131 Mdot
.726 .29185 Mdot
.726 .29206 Mdot
.726 .29344 Mdot
.726 .29583 Mdot
.726 .29598 Mdot
.726 .29624 Mdot
.726 .29766 Mdot
.726 .29847 Mdot
.726 .2987 Mdot
.726 .29896 Mdot
.726 .29925 Mdot
.726 .30023 Mdot
.726 .30184 Mdot
.726 .30277 Mdot
.726 .30355 Mdot
.726 .30411 Mdot
.726 .30493 Mdot
.726 .30504 Mdot
.726 .30524 Mdot
.726 .30623 Mdot
.726 .30814 Mdot
.726 .30834 Mdot
.726 .30853 Mdot
.726 .30959 Mdot
.726 .31003 Mdot
.726 .31077 Mdot
.726 .31083 Mdot
.726 .31137 Mdot
.726 .31191 Mdot
.726 .31193 Mdot
.726 .31207 Mdot
.726 .31507 Mdot
.726 .31639 Mdot
.726 .3174 Mdot
.726 .31869 Mdot
.726 .31935 Mdot
.726 .32147 Mdot
.726 .32195 Mdot
.726 .32365 Mdot
.726 .32369 Mdot
.726 .32385 Mdot
.726 .32389 Mdot
.726 .32583 Mdot
.726 .32701 Mdot
.726 .32807 Mdot
.726 .3288 Mdot
.726 .32883 Mdot
.726 .33099 Mdot
.726 .33176 Mdot
.726 .33419 Mdot
.726 .33509 Mdot
.726 .33655 Mdot
.726 .33773 Mdot
.726 .33804 Mdot
.726 .33878 Mdot
.726 .34024 Mdot
.726 .34104 Mdot
.726 .34296 Mdot
.726 .34389 Mdot
.726 .34425 Mdot
.726 .34478 Mdot
.726 .34482 Mdot
.726 .34495 Mdot
.726 .34874 Mdot
.726 .34878 Mdot
.726 .34975 Mdot
.726 .35062 Mdot
.726 .3518 Mdot
.726 .35255 Mdot
.726 .35279 Mdot
.726 .35319 Mdot
.726 .35492 Mdot
.726 .35541 Mdot
.726 .35603 Mdot
.726 .35763 Mdot
.726 .35819 Mdot
.726 .35829 Mdot
.726 .35854 Mdot
.726 .3591 Mdot
.726 .36096 Mdot
.726 .36108 Mdot
.726 .36127 Mdot
.726 .36132 Mdot
.726 .36155 Mdot
.726 .36239 Mdot
.726 .36301 Mdot
.726 .36308 Mdot
.726 .36323 Mdot
.726 .36331 Mdot
.726 .36408 Mdot
.726 .36418 Mdot
.726 .36429 Mdot
.726 .3643 Mdot
.726 .36434 Mdot
.726 .36438 Mdot
.726 .36462 Mdot
.726 .36486 Mdot
.726 .36519 Mdot
.726 .36519 Mdot
.726 .3652 Mdot
.726 .3652 Mdot
.726 .36521 Mdot
.726 .36523 Mdot
.726 .36533 Mdot
.726 .36534 Mdot
.726 .36545 Mdot
.726 .36556 Mdot
.726 .36559 Mdot
.726 .3656 Mdot
.726 .36564 Mdot
.726 .36589 Mdot
.726 .36596 Mdot
.726 .36601 Mdot
.726 .36629 Mdot
.726 .36637 Mdot
.726 .36643 Mdot
.726 .36648 Mdot
.726 .36666 Mdot
.726 .36671 Mdot
.726 .36684 Mdot
.726 .36699 Mdot
.726 .36711 Mdot
.726 .36773 Mdot
.726 .36787 Mdot
.726 .36799 Mdot
.726 .36862 Mdot
.726 .36866 Mdot
.726 .36899 Mdot
.726 .3698 Mdot
.726 .36989 Mdot
.726 .37017 Mdot
.726 .37042 Mdot
.726 .37044 Mdot
.726 .37045 Mdot
.726 .37066 Mdot
.726 .37072 Mdot
.726 .37099 Mdot
.726 .37108 Mdot
.726 .37153 Mdot
.726 .37193 Mdot
.726 .37235 Mdot
.726 .37264 Mdot
.726 .37281 Mdot
.726 .37319 Mdot
.726 .3734 Mdot
.726 .37352 Mdot
.726 .37356 Mdot
.726 .37372 Mdot
.726 .3739 Mdot
.726 .37393 Mdot
.726 .37395 Mdot
.726 .375 Mdot
.726 .37502 Mdot
.726 .37565 Mdot
.726 .37572 Mdot
.726 .37594 Mdot
.726 .37601 Mdot
.726 .37703 Mdot
.726 .37814 Mdot
.726 .37834 Mdot
.726 .37889 Mdot
.726 .37895 Mdot
.726 .37917 Mdot
.726 .37952 Mdot
.726 .38004 Mdot
.726 .38042 Mdot
.726 .38051 Mdot
.726 .38091 Mdot
.726 .38104 Mdot
.726 .38276 Mdot
.726 .38319 Mdot
.726 .3841 Mdot
.726 .38415 Mdot
.726 .38467 Mdot
.726 .38487 Mdot
.726 .38504 Mdot
.726 .38744 Mdot
.726 .3875 Mdot
.726 .38777 Mdot
.726 .38836 Mdot
.726 .38994 Mdot
.726 .39028 Mdot
.726 .39103 Mdot
.726 .3915 Mdot
.726 .39172 Mdot
.726 .39266 Mdot
.726 .39299 Mdot
.726 .39401 Mdot
.726 .39405 Mdot
.726 .39435 Mdot
.726 .3952 Mdot
.726 .39525 Mdot
.726 .39604 Mdot
.726 .39734 Mdot
.726 .39793 Mdot
.726 .39828 Mdot
.726 .39893 Mdot
.726 .40015 Mdot
.726 .40033 Mdot
.726 .40083 Mdot
.726 .40377 Mdot
.726 .40448 Mdot
.726 .40454 Mdot
.726 .40551 Mdot
.726 .4059 Mdot
.726 .40603 Mdot
.726 .40626 Mdot
.726 .40628 Mdot
.726 .40645 Mdot
.726 .40666 Mdot
.726 .40799 Mdot
.726 .40831 Mdot
.726 .41029 Mdot
.726 .4118 Mdot
.726 .41245 Mdot
.726 .41268 Mdot
.726 .41342 Mdot
.726 .41413 Mdot
.726 .4148 Mdot
.726 .41524 Mdot
.726 .41548 Mdot
.726 .41645 Mdot
.726 .41661 Mdot
.726 .41662 Mdot
.726 .41779 Mdot
.726 .41781 Mdot
.726 .41893 Mdot
.726 .42045 Mdot
.726 .42148 Mdot
.726 .42205 Mdot
.726 .42207 Mdot
.726 .42253 Mdot
.726 .4226 Mdot
.726 .42303 Mdot
.726 .42307 Mdot
.726 .42316 Mdot
.726 .42354 Mdot
.726 .42519 Mdot
.726 .42529 Mdot
.726 .4253 Mdot
.726 .42531 Mdot
.726 .42562 Mdot
.726 .42563 Mdot
.726 .42806 Mdot
.726 .42856 Mdot
.726 .43053 Mdot
.726 .43189 Mdot
.726 .43245 Mdot
.726 .43317 Mdot
.726 .43472 Mdot
.726 .43488 Mdot
.726 .43495 Mdot
.726 .43496 Mdot
.726 .43507 Mdot
.726 .43688 Mdot
.726 .43773 Mdot
.726 .43802 Mdot
.726 .43807 Mdot
.726 .43972 Mdot
.726 .43973 Mdot
.726 .44071 Mdot
.726 .44072 Mdot
.726 .44081 Mdot
.726 .44313 Mdot
.726 .44361 Mdot
.726 .44454 Mdot
.726 .44516 Mdot
.726 .44516 Mdot
.726 .44547 Mdot
.726 .44547 Mdot
.726 .44637 Mdot
.726 .44695 Mdot
.726 .44695 Mdot
.726 .44724 Mdot
.726 .44751 Mdot
.726 .44771 Mdot
.726 .44786 Mdot
.726 .44835 Mdot
.726 .44885 Mdot
.726 .44885 Mdot
.726 .44902 Mdot
.726 .44902 Mdot
.726 .44988 Mdot
.726 .45147 Mdot
.726 .45147 Mdot
.726 .45201 Mdot
.726 .45201 Mdot
.726 .45309 Mdot
.726 .45355 Mdot
.726 .45462 Mdot
.726 .45471 Mdot
.726 .45553 Mdot
.726 .45591 Mdot
.726 .45621 Mdot
.726 .45823 Mdot
.726 .45949 Mdot
.726 .45965 Mdot
.726 .45966 Mdot
.726 .45971 Mdot
.726 .4608 Mdot
.726 .46108 Mdot
.726 .46132 Mdot
.726 .46133 Mdot
.726 .46348 Mdot
.726 .46408 Mdot
.726 .46408 Mdot
.726 .46417 Mdot
.726 .46465 Mdot
.726 .46532 Mdot
.726 .46568 Mdot
.726 .46604 Mdot
.726 .46648 Mdot
.726 .46835 Mdot
.726 .469 Mdot
.726 .46918 Mdot
.726 .46919 Mdot
.726 .46931 Mdot
.726 .46956 Mdot
.726 .47205 Mdot
.726 .47319 Mdot
.726 .47409 Mdot
.726 .47448 Mdot
.726 .47488 Mdot
.726 .47504 Mdot
.726 .47552 Mdot
.726 .47567 Mdot
.726 .47621 Mdot
.726 .47643 Mdot
.726 .47678 Mdot
.726 .4792 Mdot
.726 .47927 Mdot
.726 .47937 Mdot
.726 .48004 Mdot
.726 .48125 Mdot
.726 .48147 Mdot
.726 .48199 Mdot
.726 .48223 Mdot
.726 .48232 Mdot
.726 .48372 Mdot
.726 .48373 Mdot
.726 .48419 Mdot
.726 .4842 Mdot
.726 .48422 Mdot
.726 .48437 Mdot
.726 .48477 Mdot
.726 .4849 Mdot
.726 .48509 Mdot
.726 .48547 Mdot
.726 .4855 Mdot
.726 .48562 Mdot
.726 .48574 Mdot
.726 .48655 Mdot
.726 .48682 Mdot
.726 .48732 Mdot
.726 .48738 Mdot
.726 .48748 Mdot
.726 .4875 Mdot
.726 .48757 Mdot
.726 .48804 Mdot
.726 .48819 Mdot
.726 .48829 Mdot
.726 .4884 Mdot
.726 .48841 Mdot
.726 .48843 Mdot
.726 .48843 Mdot
.726 .48848 Mdot
.726 .48853 Mdot
.726 .48886 Mdot
.726 .48889 Mdot
.726 .48896 Mdot
.726 .48899 Mdot
.726 .48926 Mdot
.726 .48962 Mdot
.726 .48972 Mdot
.726 .48974 Mdot
.726 .48982 Mdot
.726 .48987 Mdot
.726 .49067 Mdot
.726 .49091 Mdot
.726 .49102 Mdot
.726 .49106 Mdot
.726 .4913 Mdot
.726 .49198 Mdot
.726 .49225 Mdot
.726 .49245 Mdot
.726 .49319 Mdot
.726 .49336 Mdot
.726 .49346 Mdot
.726 .49378 Mdot
.726 .49427 Mdot
.726 .49464 Mdot
.726 .49504 Mdot
.726 .49506 Mdot
.726 .49664 Mdot
.726 .49669 Mdot
.726 .49671 Mdot
.726 .49693 Mdot
.726 .49708 Mdot
.726 .49746 Mdot
.726 .49825 Mdot
.726 .49858 Mdot
.726 .49918 Mdot
.726 .49948 Mdot
.726 .49961 Mdot
.726 .50009 Mdot
.726 .50069 Mdot
.726 .50105 Mdot
.726 .50203 Mdot
.726 .50234 Mdot
.726 .50321 Mdot
.726 .50322 Mdot
.726 .50351 Mdot
.726 .50394 Mdot
.726 .50441 Mdot
.726 .50518 Mdot
.726 .5052 Mdot
.726 .50526 Mdot
.726 .50528 Mdot
.726 .50595 Mdot
.726 .50614 Mdot
.726 .50698 Mdot
.726 .50724 Mdot
.726 .50774 Mdot
.726 .50814 Mdot
.726 .50865 Mdot
.726 .50982 Mdot
.726 .50987 Mdot
.726 .50988 Mdot
.726 .51009 Mdot
.726 .5103 Mdot
.726 .51032 Mdot
.726 .51061 Mdot
.726 .51078 Mdot
.726 .51118 Mdot
.726 .51126 Mdot
.726 .51133 Mdot
.726 .51207 Mdot
.726 .51245 Mdot
.726 .51252 Mdot
.726 .51257 Mdot
.726 .51288 Mdot
.726 .51309 Mdot
.726 .51339 Mdot
.726 .51374 Mdot
.726 .51436 Mdot
.726 .51473 Mdot
.726 .51484 Mdot
.726 .51493 Mdot
.726 .51502 Mdot
.726 .51533 Mdot
.726 .51586 Mdot
.726 .51596 Mdot
.726 .51602 Mdot
.726 .51691 Mdot
.726 .51743 Mdot
.726 .51751 Mdot
.726 .51771 Mdot
.726 .51785 Mdot
.726 .51913 Mdot
.726 .51914 Mdot
.726 .51919 Mdot
.726 .51989 Mdot
.726 .52028 Mdot
.726 .52095 Mdot
.726 .52105 Mdot
.726 .52124 Mdot
.726 .52188 Mdot
.726 .52208 Mdot
.726 .52242 Mdot
.726 .52329 Mdot
.726 .52335 Mdot
.726 .52383 Mdot
.726 .52429 Mdot
.726 .52462 Mdot
.726 .52466 Mdot
.726 .52501 Mdot
.726 .52525 Mdot
.726 .52577 Mdot
.726 .52612 Mdot
.726 .5267 Mdot
.726 .52713 Mdot
.726 .52736 Mdot
.726 .52786 Mdot
.726 .52812 Mdot
.726 .52853 Mdot
.726 .52865 Mdot
.726 .52868 Mdot
.726 .529 Mdot
.726 .53017 Mdot
.726 .53036 Mdot
.726 .53063 Mdot
.726 .53095 Mdot
.726 .53122 Mdot
.726 .5315 Mdot
.726 .53156 Mdot
.726 .53188 Mdot
.726 .53328 Mdot
.726 .53394 Mdot
.726 .5341 Mdot
.726 .53428 Mdot
.726 .5343 Mdot
.726 .53451 Mdot
.726 .5348 Mdot
.726 .53485 Mdot
.726 .53556 Mdot
.726 .53573 Mdot
.726 .53591 Mdot
.726 .53613 Mdot
.726 .53774 Mdot
.726 .53786 Mdot
.726 .53823 Mdot
.726 .53831 Mdot
.726 .53866 Mdot
.726 .53914 Mdot
.726 .53945 Mdot
.726 .53965 Mdot
.726 .53971 Mdot
.726 .54019 Mdot
.726 .54024 Mdot
.726 .54037 Mdot
.726 .54082 Mdot
.726 .54128 Mdot
.726 .54135 Mdot
.726 .54171 Mdot
.726 .54224 Mdot
.726 .5423 Mdot
.726 .54248 Mdot
.726 .54254 Mdot
.726 .54308 Mdot
.726 .5431 Mdot
.726 .54347 Mdot
.726 .54359 Mdot
.726 .54398 Mdot
.726 .544 Mdot
.726 .54402 Mdot
.726 .54417 Mdot
.726 .54428 Mdot
.726 .54431 Mdot
.726 .54434 Mdot
.726 .54444 Mdot
.726 .54461 Mdot
.726 .54478 Mdot
.726 .54484 Mdot
.726 .54493 Mdot
.726 .54506 Mdot
.726 .54526 Mdot
.726 .5453 Mdot
.726 .54564 Mdot
.726 .54564 Mdot
.726 .54596 Mdot
.726 .54633 Mdot
.726 .54639 Mdot
.726 .5466 Mdot
.726 .54665 Mdot
.726 .54682 Mdot
.726 .54683 Mdot
.726 .54684 Mdot
.726 .54704 Mdot
.726 .54716 Mdot
.726 .54726 Mdot
.726 .54734 Mdot
.726 .54796 Mdot
.726 .54822 Mdot
.726 .54825 Mdot
.726 .54873 Mdot
.726 .54882 Mdot
.726 .54892 Mdot
.726 .54939 Mdot
.726 .54947 Mdot
.726 .54959 Mdot
.726 .54968 Mdot
.726 .54972 Mdot
.726 .54989 Mdot
.726 .54993 Mdot
.726 .54999 Mdot
.726 .5502 Mdot
.726 .55021 Mdot
.726 .55024 Mdot
.726 .55029 Mdot
.726 .55047 Mdot
.726 .5505 Mdot
.726 .5505 Mdot
.726 .55053 Mdot
.726 .55061 Mdot
.726 .55069 Mdot
.726 .55069 Mdot
.726 .55077 Mdot
.726 .55078 Mdot
.726 .55079 Mdot
.726 .55079 Mdot
.726 .55079 Mdot
.726 .5508 Mdot
.726 .55088 Mdot
.726 .551 Mdot
.726 .55103 Mdot
.726 .5512 Mdot
.726 .55138 Mdot
.726 .5514 Mdot
.726 .55143 Mdot
.726 .55144 Mdot
.726 .55152 Mdot
.726 .55156 Mdot
.726 .55159 Mdot
.726 .55211 Mdot
.726 .55213 Mdot
.726 .55218 Mdot
.726 .55229 Mdot
.726 .55234 Mdot
.726 .55273 Mdot
.726 .55277 Mdot
.726 .55327 Mdot
.726 .55334 Mdot
.726 .55349 Mdot
.726 .55352 Mdot
.726 .55362 Mdot
.726 .55365 Mdot
.726 .55373 Mdot
.726 .55495 Mdot
.726 .55531 Mdot
.726 .55547 Mdot
.726 .55553 Mdot
.726 .55577 Mdot
.726 .55589 Mdot
.726 .55634 Mdot
.726 .55639 Mdot
.726 .55659 Mdot
.726 .55687 Mdot
.726 .55724 Mdot
.726 .55729 Mdot
.726 .55753 Mdot
.726 .55772 Mdot
.726 .55853 Mdot
.726 .55853 Mdot
.726 .55876 Mdot
.726 .55889 Mdot
.726 .55889 Mdot
.726 .55931 Mdot
.726 .55955 Mdot
.726 .55995 Mdot
.726 .56041 Mdot
.726 .56042 Mdot
.726 .56091 Mdot
.726 .56093 Mdot
.726 .56093 Mdot
.726 .56165 Mdot
.726 .56197 Mdot
.726 .56244 Mdot
.726 .56249 Mdot
.726 .56277 Mdot
.726 .56283 Mdot
.726 .56285 Mdot
.726 .56291 Mdot
.726 .56309 Mdot
.726 .56325 Mdot
.726 .56349 Mdot
.726 .56366 Mdot
.726 .56405 Mdot
.726 .56412 Mdot
.726 .56448 Mdot
.726 .5648 Mdot
.726 .5651 Mdot
.726 .56537 Mdot
.726 .56546 Mdot
.726 .56565 Mdot
.726 .56566 Mdot
.726 .56577 Mdot
.726 .56619 Mdot
.726 .56629 Mdot
.726 .56647 Mdot
.726 .56656 Mdot
.726 .5667 Mdot
.726 .56699 Mdot
.726 .56716 Mdot
.726 .56749 Mdot
.726 .56774 Mdot
.726 .56796 Mdot
.726 .56804 Mdot
.726 .56808 Mdot
.726 .56809 Mdot
.726 .56854 Mdot
.726 .56855 Mdot
.726 .56873 Mdot
.726 .56896 Mdot
.726 .56898 Mdot
.726 .56905 Mdot
.726 .56917 Mdot
.726 .56922 Mdot
.726 .56925 Mdot
.726 .56951 Mdot
.726 .56964 Mdot
.726 .56965 Mdot
.726 .56968 Mdot
.726 .56969 Mdot
.726 .56995 Mdot
.726 .56997 Mdot
.726 .56999 Mdot
.726 .57002 Mdot
.726 .57007 Mdot
.726 .57024 Mdot
.726 .57035 Mdot
.726 .57038 Mdot
.726 .57038 Mdot
.726 .57041 Mdot
.726 .57045 Mdot
.726 .57046 Mdot
.726 .57057 Mdot
.726 .57061 Mdot
.726 .57071 Mdot
.726 .57073 Mdot
.726 .57081 Mdot
.726 .57083 Mdot
.726 .57087 Mdot
.726 .57091 Mdot
.726 .57096 Mdot
.726 .57096 Mdot
.726 .57097 Mdot
.726 .571 Mdot
.726 .57101 Mdot
.726 .57101 Mdot
.726 .57101 Mdot
.726 .57103 Mdot
.726 .57104 Mdot
.726 .57104 Mdot
.726 .57106 Mdot
.726 .57106 Mdot
.726 .57106 Mdot
.726 .57106 Mdot
.726 .57106 Mdot
.728 .12924 Mdot
.728 .12925 Mdot
.728 .12927 Mdot
.728 .12933 Mdot
.728 .12935 Mdot
.728 .12936 Mdot
.728 .12951 Mdot
.728 .12956 Mdot
.728 .12963 Mdot
.728 .12996 Mdot
.728 .13034 Mdot
.728 .1306 Mdot
.728 .13064 Mdot
.728 .13084 Mdot
.728 .13087 Mdot
.728 .13105 Mdot
.728 .13107 Mdot
.728 .13121 Mdot
.728 .13138 Mdot
.728 .13172 Mdot
.728 .13183 Mdot
.728 .13185 Mdot
.728 .13203 Mdot
.728 .13207 Mdot
.728 .13214 Mdot
.728 .13224 Mdot
.728 .13225 Mdot
.728 .13243 Mdot
.728 .13262 Mdot
.728 .13265 Mdot
.728 .13289 Mdot
.728 .13371 Mdot
.728 .13375 Mdot
.728 .13384 Mdot
.728 .13434 Mdot
.728 .13456 Mdot
.728 .13464 Mdot
.728 .13466 Mdot
.728 .13471 Mdot
.728 .13523 Mdot
.728 .13607 Mdot
.728 .13642 Mdot
.728 .13652 Mdot
.728 .13653 Mdot
.728 .13686 Mdot
.728 .13699 Mdot
.728 .13742 Mdot
.728 .13768 Mdot
.728 .13823 Mdot
.728 .13839 Mdot
.728 .13851 Mdot
.728 .13895 Mdot
.728 .13974 Mdot
.728 .14011 Mdot
.728 .14055 Mdot
.728 .14064 Mdot
.728 .14078 Mdot
.728 .14089 Mdot
.728 .14115 Mdot
.728 .14202 Mdot
.728 .1427 Mdot
.728 .14277 Mdot
.728 .14304 Mdot
.728 .14306 Mdot
.728 .14373 Mdot
.728 .14419 Mdot
.728 .14473 Mdot
.728 .14543 Mdot
.728 .14548 Mdot
.728 .14572 Mdot
.728 .14581 Mdot
.728 .14639 Mdot
.728 .14691 Mdot
.728 .14712 Mdot
.728 .14725 Mdot
.728 .14737 Mdot
.728 .15027 Mdot
.728 .15038 Mdot
.728 .15093 Mdot
.728 .15271 Mdot
.728 .15447 Mdot
.728 .15498 Mdot
.728 .15539 Mdot
.728 .15708 Mdot
.728 .15721 Mdot
.728 .1574 Mdot
.728 .15809 Mdot
.728 .15834 Mdot
.728 .15846 Mdot
.728 .15893 Mdot
.728 .15979 Mdot
.728 .15988 Mdot
.728 .16008 Mdot
.728 .1608 Mdot
.728 .16087 Mdot
.728 .16118 Mdot
.728 .16235 Mdot
.728 .16343 Mdot
.728 .16403 Mdot
.728 .16495 Mdot
.728 .16628 Mdot
.728 .1671 Mdot
.728 .16768 Mdot
.728 .16815 Mdot
.728 .1683 Mdot
.728 .16835 Mdot
.728 .16869 Mdot
.728 .17063 Mdot
.728 .17112 Mdot
.728 .17252 Mdot
.728 .17253 Mdot
.728 .17307 Mdot
.728 .175 Mdot
.728 .17739 Mdot
.728 .17794 Mdot
.728 .17863 Mdot
.728 .17901 Mdot
.728 .18047 Mdot
.728 .18055 Mdot
.728 .18119 Mdot
.728 .18207 Mdot
.728 .18346 Mdot
.728 .18525 Mdot
.728 .18543 Mdot
.728 .18646 Mdot
.728 .18683 Mdot
.728 .18727 Mdot
.728 .18782 Mdot
.728 .18814 Mdot
.728 .19147 Mdot
.728 .19152 Mdot
.728 .19158 Mdot
.728 .1919 Mdot
.728 .192 Mdot
.728 .19205 Mdot
.728 .19248 Mdot
.728 .19266 Mdot
.728 .19281 Mdot
.728 .19309 Mdot
.728 .19344 Mdot
.728 .19516 Mdot
.728 .19554 Mdot
.728 .1962 Mdot
.728 .19712 Mdot
.728 .19715 Mdot
.728 .19772 Mdot
.728 .19809 Mdot
.728 .19848 Mdot
.728 .19871 Mdot
.728 .19975 Mdot
.728 .19991 Mdot
.728 .20048 Mdot
.728 .20085 Mdot
.728 .20094 Mdot
.728 .20096 Mdot
.728 .20173 Mdot
.728 .20264 Mdot
.728 .20445 Mdot
.728 .20453 Mdot
.728 .20455 Mdot
.728 .20508 Mdot
.728 .20515 Mdot
.728 .20518 Mdot
.728 .20613 Mdot
.728 .20638 Mdot
.728 .20673 Mdot
.728 .20708 Mdot
.728 .2073 Mdot
.728 .20737 Mdot
.728 .20834 Mdot
.728 .20912 Mdot
.728 .20935 Mdot
.728 .20937 Mdot
.728 .20953 Mdot
.728 .2104 Mdot
.728 .21087 Mdot
.728 .21155 Mdot
.728 .21192 Mdot
.728 .21201 Mdot
.728 .21254 Mdot
.728 .21339 Mdot
.728 .2144 Mdot
.728 .21469 Mdot
.728 .21552 Mdot
.728 .21561 Mdot
.728 .21573 Mdot
.728 .21587 Mdot
.728 .2161 Mdot
.728 .21624 Mdot
.728 .21675 Mdot
.728 .21714 Mdot
.728 .21794 Mdot
.728 .21795 Mdot
.728 .21866 Mdot
.728 .21913 Mdot
.728 .21947 Mdot
.728 .22038 Mdot
.728 .22051 Mdot
.728 .22086 Mdot
.728 .22087 Mdot
.728 .22097 Mdot
.728 .22126 Mdot
.728 .22135 Mdot
.728 .22215 Mdot
.728 .22369 Mdot
.728 .22427 Mdot
.728 .22429 Mdot
.728 .22501 Mdot
.728 .22557 Mdot
.728 .22583 Mdot
.728 .22596 Mdot
.728 .22924 Mdot
.728 .22938 Mdot
.728 .23129 Mdot
.728 .23189 Mdot
.728 .23199 Mdot
.728 .23364 Mdot
.728 .23391 Mdot
.728 .23469 Mdot
.728 .23729 Mdot
.728 .23888 Mdot
.728 .2408 Mdot
.728 .24103 Mdot
.728 .24226 Mdot
.728 .24266 Mdot
.728 .24298 Mdot
.728 .24325 Mdot
.728 .24373 Mdot
.728 .24398 Mdot
.728 .24454 Mdot
.728 .24627 Mdot
.728 .2467 Mdot
.728 .24764 Mdot
.728 .24843 Mdot
.728 .2487 Mdot
.728 .25042 Mdot
.728 .25162 Mdot
.728 .25395 Mdot
.728 .25595 Mdot
.728 .25635 Mdot
.728 .25673 Mdot
.728 .25722 Mdot
.728 .25731 Mdot
.728 .25817 Mdot
.728 .25885 Mdot
.728 .25964 Mdot
.728 .26037 Mdot
.728 .26056 Mdot
.728 .26092 Mdot
.728 .26585 Mdot
.728 .26603 Mdot
.728 .26607 Mdot
.728 .26641 Mdot
.728 .26674 Mdot
.728 .26721 Mdot
.728 .26889 Mdot
.728 .27026 Mdot
.728 .27049 Mdot
.728 .27094 Mdot
.728 .27107 Mdot
.728 .27112 Mdot
.728 .27267 Mdot
.728 .27279 Mdot
.728 .27287 Mdot
.728 .27401 Mdot
.728 .27717 Mdot
.728 .27759 Mdot
.728 .28003 Mdot
.728 .28014 Mdot
.728 .28031 Mdot
.728 .28123 Mdot
.728 .28151 Mdot
.728 .28155 Mdot
.728 .28216 Mdot
.728 .28263 Mdot
.728 .28304 Mdot
.728 .28366 Mdot
.728 .28464 Mdot
.728 .28548 Mdot
.728 .28586 Mdot
.728 .28654 Mdot
.728 .28693 Mdot
.728 .28827 Mdot
.728 .28841 Mdot
.728 .28859 Mdot
.728 .28954 Mdot
.728 .29022 Mdot
.728 .29062 Mdot
.728 .29064 Mdot
.728 .29077 Mdot
.728 .29317 Mdot
.728 .29442 Mdot
.728 .29462 Mdot
.728 .29603 Mdot
.728 .29646 Mdot
.728 .29721 Mdot
.728 .29766 Mdot
.728 .29803 Mdot
.728 .29806 Mdot
.728 .29831 Mdot
.728 .29946 Mdot
.728 .30033 Mdot
.728 .30096 Mdot
.728 .30108 Mdot
.728 .30188 Mdot
.728 .30514 Mdot
.728 .30549 Mdot
.728 .30788 Mdot
.728 .30958 Mdot
.728 .30987 Mdot
.728 .31108 Mdot
.728 .31127 Mdot
.728 .31138 Mdot
.728 .31328 Mdot
.728 .31481 Mdot
.728 .31762 Mdot
.728 .31816 Mdot
.728 .31822 Mdot
.728 .31897 Mdot
.728 .32047 Mdot
.728 .32059 Mdot
.728 .3208 Mdot
.728 .32117 Mdot
.728 .32152 Mdot
.728 .32347 Mdot
.728 .32439 Mdot
.728 .32472 Mdot
.728 .32484 Mdot
.728 .32494 Mdot
.728 .32568 Mdot
.728 .32682 Mdot
.728 .32797 Mdot
.728 .3288 Mdot
.728 .33025 Mdot
.728 .33194 Mdot
.728 .33204 Mdot
.728 .33228 Mdot
.728 .33404 Mdot
.728 .33411 Mdot
.728 .33436 Mdot
.728 .33674 Mdot
.728 .3373 Mdot
.728 .3381 Mdot
.728 .34037 Mdot
.728 .34216 Mdot
.728 .3434 Mdot
.728 .34375 Mdot
.728 .34582 Mdot
.728 .34598 Mdot
.728 .34606 Mdot
.728 .34636 Mdot
.728 .34758 Mdot
.728 .34849 Mdot
.728 .34951 Mdot
.728 .35005 Mdot
.728 .35188 Mdot
.728 .35326 Mdot
.728 .35353 Mdot
.728 .35429 Mdot
.728 .35429 Mdot
.728 .35458 Mdot
.728 .3556 Mdot
.728 .35684 Mdot
.728 .35843 Mdot
.728 .35875 Mdot
.728 .35886 Mdot
.728 .36147 Mdot
.728 .36194 Mdot
.728 .36362 Mdot
.728 .36364 Mdot
.728 .36367 Mdot
.728 .36382 Mdot
.728 .36386 Mdot
.728 .36389 Mdot
.728 .36417 Mdot
.728 .36423 Mdot
.728 .36436 Mdot
.728 .36452 Mdot
.728 .36528 Mdot
.728 .36545 Mdot
.728 .36575 Mdot
.728 .36615 Mdot
.728 .36616 Mdot
.728 .36657 Mdot
.728 .36675 Mdot
.728 .36684 Mdot
.728 .36729 Mdot
.728 .36736 Mdot
.728 .36777 Mdot
.728 .36781 Mdot
.728 .36782 Mdot
.728 .36815 Mdot
.728 .36853 Mdot
.728 .3693 Mdot
.728 .36934 Mdot
.728 .36956 Mdot
.728 .36959 Mdot
.728 .37 Mdot
.728 .37011 Mdot
.728 .37025 Mdot
.728 .37049 Mdot
.728 .37052 Mdot
.728 .37092 Mdot
.728 .37124 Mdot
.728 .37134 Mdot
.728 .37141 Mdot
.728 .37195 Mdot
.728 .37222 Mdot
.728 .37238 Mdot
.728 .37241 Mdot
.728 .37262 Mdot
.728 .37297 Mdot
.728 .37337 Mdot
.728 .37382 Mdot
.728 .37385 Mdot
.728 .3739 Mdot
.728 .37396 Mdot
.728 .3741 Mdot
.728 .37446 Mdot
.728 .37478 Mdot
.728 .37524 Mdot
.728 .37573 Mdot
.728 .37591 Mdot
.728 .37592 Mdot
.728 .37595 Mdot
.728 .37607 Mdot
.728 .3761 Mdot
.728 .37641 Mdot
.728 .37722 Mdot
.728 .37751 Mdot
.728 .37772 Mdot
.728 .37782 Mdot
.728 .37787 Mdot
.728 .3791 Mdot
.728 .37987 Mdot
.728 .38009 Mdot
.728 .38013 Mdot
.728 .38084 Mdot
.728 .38112 Mdot
.728 .38207 Mdot
.728 .38265 Mdot
.728 .38342 Mdot
.728 .38386 Mdot
.728 .38401 Mdot
.728 .38422 Mdot
.728 .38448 Mdot
.728 .38529 Mdot
.728 .38544 Mdot
.728 .38577 Mdot
.728 .38716 Mdot
.728 .38797 Mdot
.728 .38892 Mdot
.728 .38909 Mdot
.728 .38912 Mdot
.728 .38942 Mdot
.728 .38965 Mdot
.728 .38992 Mdot
.728 .39016 Mdot
.728 .39023 Mdot
.728 .39035 Mdot
.728 .39201 Mdot
.728 .39208 Mdot
.728 .39231 Mdot
.728 .39348 Mdot
.728 .39355 Mdot
.728 .3937 Mdot
.728 .39427 Mdot
.728 .39431 Mdot
.728 .39471 Mdot
.728 .39575 Mdot
.728 .39671 Mdot
.728 .39737 Mdot
.728 .39785 Mdot
.728 .39817 Mdot
.728 .39844 Mdot
.728 .39878 Mdot
.728 .39933 Mdot
.728 .39943 Mdot
.728 .39974 Mdot
.728 .39995 Mdot
.728 .40013 Mdot
.728 .40135 Mdot
.728 .40243 Mdot
.728 .40287 Mdot
.728 .40314 Mdot
.728 .40338 Mdot
.728 .40476 Mdot
.728 .40655 Mdot
.728 .40658 Mdot
.728 .40937 Mdot
.728 .40941 Mdot
.728 .40947 Mdot
.728 .40958 Mdot
.728 .41028 Mdot
.728 .41056 Mdot
.728 .4107 Mdot
.728 .41234 Mdot
.728 .4143 Mdot
.728 .41447 Mdot
.728 .41471 Mdot
.728 .41593 Mdot
.728 .4164 Mdot
.728 .41702 Mdot
.728 .41782 Mdot
.728 .41884 Mdot
.728 .41925 Mdot
.728 .41955 Mdot
.728 .41964 Mdot
.728 .42079 Mdot
.728 .42169 Mdot
.728 .42296 Mdot
.728 .42309 Mdot
.728 .42321 Mdot
.728 .42357 Mdot
.728 .42403 Mdot
.728 .42489 Mdot
.728 .42493 Mdot
.728 .425 Mdot
.728 .42511 Mdot
.728 .4254 Mdot
.728 .42564 Mdot
.728 .42655 Mdot
.728 .42821 Mdot
.728 .42838 Mdot
.728 .42876 Mdot
.728 .42891 Mdot
.728 .43014 Mdot
.728 .43027 Mdot
.728 .43085 Mdot
.728 .43236 Mdot
.728 .43268 Mdot
.728 .43307 Mdot
.728 .4351 Mdot
.728 .43511 Mdot
.728 .43598 Mdot
.728 .43623 Mdot
.728 .43631 Mdot
.728 .43793 Mdot
.728 .43807 Mdot
.728 .43826 Mdot
.728 .43893 Mdot
.728 .43967 Mdot
.728 .44038 Mdot
.728 .44068 Mdot
.728 .44071 Mdot
.728 .44187 Mdot
.728 .44293 Mdot
.728 .44378 Mdot
.728 .44405 Mdot
.728 .44415 Mdot
.728 .4447 Mdot
.728 .44475 Mdot
.728 .44519 Mdot
.728 .44676 Mdot
.728 .44823 Mdot
.728 .4491 Mdot
.728 .44938 Mdot
.728 .45157 Mdot
.728 .45159 Mdot
.728 .45214 Mdot
.728 .45254 Mdot
.728 .4529 Mdot
.728 .453 Mdot
.728 .45395 Mdot
.728 .45413 Mdot
.728 .45459 Mdot
.728 .45589 Mdot
.728 .45606 Mdot
.728 .45787 Mdot
.728 .45985 Mdot
.728 .4599 Mdot
.728 .45996 Mdot
.728 .4604 Mdot
.728 .46089 Mdot
.728 .4616 Mdot
.728 .46206 Mdot
.728 .46269 Mdot
.728 .46284 Mdot
.728 .46396 Mdot
.728 .46427 Mdot
.728 .46451 Mdot
.728 .46512 Mdot
.728 .46524 Mdot
.728 .4663 Mdot
.728 .46717 Mdot
.728 .46731 Mdot
.728 .46771 Mdot
.728 .46774 Mdot
.728 .46912 Mdot
.728 .46914 Mdot
.728 .47 Mdot
.728 .47241 Mdot
.728 .47287 Mdot
.728 .47303 Mdot
.728 .47316 Mdot
.728 .47354 Mdot
.728 .47479 Mdot
.728 .47537 Mdot
.728 .47591 Mdot
.728 .47605 Mdot
.728 .47682 Mdot
.728 .47691 Mdot
.728 .47702 Mdot
.728 .4774 Mdot
.728 .47893 Mdot
.728 .47915 Mdot
.728 .47974 Mdot
.728 .48 Mdot
.728 .48251 Mdot
.728 .48253 Mdot
.728 .48258 Mdot
.728 .48268 Mdot
.728 .48317 Mdot
.728 .4833 Mdot
.728 .48339 Mdot
.728 .48389 Mdot
.728 .48403 Mdot
.728 .48426 Mdot
.728 .4843 Mdot
.728 .48452 Mdot
.728 .4847 Mdot
.728 .48485 Mdot
.728 .48494 Mdot
.728 .48496 Mdot
.728 .48503 Mdot
.728 .48546 Mdot
.728 .4863 Mdot
.728 .48697 Mdot
.728 .48751 Mdot
.728 .48768 Mdot
.728 .48787 Mdot
.728 .48799 Mdot
.728 .48855 Mdot
.728 .48952 Mdot
.728 .48972 Mdot
.728 .49084 Mdot
.728 .49089 Mdot
.728 .49102 Mdot
.728 .4917 Mdot
.728 .49223 Mdot
.728 .49266 Mdot
.728 .49278 Mdot
.728 .49278 Mdot
.728 .4931 Mdot
.728 .49322 Mdot
.728 .4938 Mdot
.728 .49457 Mdot
.728 .4948 Mdot
.728 .49522 Mdot
.728 .4956 Mdot
.728 .49611 Mdot
.728 .49624 Mdot
.728 .49627 Mdot
.728 .49633 Mdot
.728 .49719 Mdot
.728 .49734 Mdot
.728 .49785 Mdot
.728 .49859 Mdot
.728 .49952 Mdot
.728 .49984 Mdot
.728 .50007 Mdot
.728 .50104 Mdot
.728 .50114 Mdot
.728 .50116 Mdot
.728 .50188 Mdot
.728 .50198 Mdot
.728 .50201 Mdot
.728 .5027 Mdot
.728 .50328 Mdot
.728 .50361 Mdot
.728 .50407 Mdot
.728 .50452 Mdot
.728 .50482 Mdot
.728 .50486 Mdot
.728 .50491 Mdot
.728 .50503 Mdot
.728 .5054 Mdot
.728 .50617 Mdot
.728 .50631 Mdot
.728 .50645 Mdot
.728 .50654 Mdot
.728 .50659 Mdot
.728 .50717 Mdot
.728 .50747 Mdot
.728 .50749 Mdot
.728 .5077 Mdot
.728 .5088 Mdot
.728 .5094 Mdot
.728 .51013 Mdot
.728 .51017 Mdot
.728 .51025 Mdot
.728 .51072 Mdot
.728 .51083 Mdot
.728 .51148 Mdot
.728 .5124 Mdot
.728 .51253 Mdot
.728 .51378 Mdot
.728 .51408 Mdot
.728 .51413 Mdot
.728 .51436 Mdot
.728 .51469 Mdot
.728 .51513 Mdot
.728 .51522 Mdot
.728 .51523 Mdot
.728 .51537 Mdot
.728 .51554 Mdot
.728 .51582 Mdot
.728 .51599 Mdot
.728 .51651 Mdot
.728 .51659 Mdot
.728 .51706 Mdot
.728 .51795 Mdot
.728 .518 Mdot
.728 .51801 Mdot
.728 .51816 Mdot
.728 .51841 Mdot
.728 .51876 Mdot
.728 .51883 Mdot
.728 .51888 Mdot
.728 .51938 Mdot
.728 .51952 Mdot
.728 .51978 Mdot
.728 .51991 Mdot
.728 .52022 Mdot
.728 .52059 Mdot
.728 .52081 Mdot
.728 .52096 Mdot
.728 .52114 Mdot
.728 .52136 Mdot
.728 .52138 Mdot
.728 .52148 Mdot
.728 .52181 Mdot
.728 .52188 Mdot
.728 .52192 Mdot
.728 .52281 Mdot
.728 .52296 Mdot
.728 .52411 Mdot
.728 .52452 Mdot
.728 .52455 Mdot
.728 .52459 Mdot
.728 .52515 Mdot
.728 .52517 Mdot
.728 .52521 Mdot
.728 .52537 Mdot
.728 .52546 Mdot
.728 .52595 Mdot
.728 .52655 Mdot
.728 .52672 Mdot
.728 .52684 Mdot
.728 .52696 Mdot
.728 .52697 Mdot
.728 .52704 Mdot
.728 .52879 Mdot
.728 .52892 Mdot
.728 .52898 Mdot
.728 .52924 Mdot
.728 .52952 Mdot
.728 .52976 Mdot
.728 .53006 Mdot
.728 .53009 Mdot
.728 .53027 Mdot
.728 .5304 Mdot
.728 .53054 Mdot
.728 .53124 Mdot
.728 .53206 Mdot
.728 .53248 Mdot
.728 .53307 Mdot
.728 .53317 Mdot
.728 .53344 Mdot
.728 .53377 Mdot
.728 .53392 Mdot
.728 .53471 Mdot
.728 .53479 Mdot
.728 .53496 Mdot
.728 .53505 Mdot
.728 .53516 Mdot
.728 .5353 Mdot
.728 .53572 Mdot
.728 .5358 Mdot
.728 .53646 Mdot
.728 .537 Mdot
.728 .53789 Mdot
.728 .53815 Mdot
.728 .53824 Mdot
.728 .53881 Mdot
.728 .53884 Mdot
.728 .53904 Mdot
.728 .53969 Mdot
.728 .53973 Mdot
.728 .54084 Mdot
.728 .54088 Mdot
.728 .54097 Mdot
.728 .54116 Mdot
.728 .5414 Mdot
.728 .5414 Mdot
.728 .5416 Mdot
.728 .54211 Mdot
.728 .54238 Mdot
.728 .54241 Mdot
.728 .54251 Mdot
.728 .54254 Mdot
.728 .54254 Mdot
.728 .54266 Mdot
.728 .5427 Mdot
.728 .543 Mdot
.728 .54312 Mdot
.728 .54327 Mdot
.728 .54351 Mdot
.728 .54351 Mdot
.728 .54378 Mdot
.728 .54391 Mdot
.728 .54408 Mdot
.728 .54412 Mdot
.728 .5442 Mdot
.728 .54425 Mdot
.728 .54429 Mdot
.728 .54431 Mdot
.728 .54459 Mdot
.728 .54468 Mdot
.728 .54502 Mdot
.728 .5453 Mdot
.728 .54547 Mdot
.728 .5455 Mdot
.728 .54563 Mdot
.728 .54585 Mdot
.728 .546 Mdot
.728 .54629 Mdot
.728 .54634 Mdot
.728 .54635 Mdot
.728 .54642 Mdot
.728 .54668 Mdot
.728 .54699 Mdot
.728 .54702 Mdot
.728 .54709 Mdot
.728 .5472 Mdot
.728 .54732 Mdot
.728 .5474 Mdot
.728 .54771 Mdot
.728 .54772 Mdot
.728 .54774 Mdot
.728 .54792 Mdot
.728 .54792 Mdot
.728 .54795 Mdot
.728 .54854 Mdot
.728 .54883 Mdot
.728 .54908 Mdot
.728 .54909 Mdot
.728 .54912 Mdot
.728 .54924 Mdot
.728 .54942 Mdot
.728 .54947 Mdot
.728 .54981 Mdot
.728 .54988 Mdot
.728 .55001 Mdot
.728 .55013 Mdot
.728 .55031 Mdot
.728 .55032 Mdot
.728 .55062 Mdot
.728 .55083 Mdot
.728 .55095 Mdot
.728 .55151 Mdot
.728 .55162 Mdot
.728 .55171 Mdot
.728 .55176 Mdot
.728 .55181 Mdot
.728 .55195 Mdot
.728 .55197 Mdot
.728 .552 Mdot
.728 .5521 Mdot
.728 .55212 Mdot
.728 .55214 Mdot
.728 .5532 Mdot
.728 .5533 Mdot
.728 .55348 Mdot
.728 .55362 Mdot
.728 .55373 Mdot
.728 .55406 Mdot
.728 .55412 Mdot
.728 .55469 Mdot
.728 .55513 Mdot
.728 .55533 Mdot
.728 .55541 Mdot
.728 .55561 Mdot
.728 .55563 Mdot
.728 .55609 Mdot
.728 .55621 Mdot
.728 .55643 Mdot
.728 .5566 Mdot
.728 .55735 Mdot
.728 .55796 Mdot
.728 .55813 Mdot
.728 .55813 Mdot
.728 .55857 Mdot
.728 .55872 Mdot
.728 .55932 Mdot
.728 .55943 Mdot
.728 .55944 Mdot
.728 .55949 Mdot
.728 .55964 Mdot
.728 .55982 Mdot
.728 .56007 Mdot
.728 .56048 Mdot
.728 .56076 Mdot
.728 .56095 Mdot
.728 .56129 Mdot
.728 .56165 Mdot
.728 .56174 Mdot
.728 .56176 Mdot
.728 .56198 Mdot
.728 .56204 Mdot
.728 .56207 Mdot
.728 .56234 Mdot
.728 .56248 Mdot
.728 .56252 Mdot
.728 .56259 Mdot
.728 .56281 Mdot
.728 .56287 Mdot
.728 .5629 Mdot
.728 .56342 Mdot
.728 .56355 Mdot
.728 .5637 Mdot
.728 .56424 Mdot
.728 .56478 Mdot
.728 .56495 Mdot
.728 .56498 Mdot
.728 .56587 Mdot
.728 .5659 Mdot
.728 .56594 Mdot
.728 .566 Mdot
.728 .56616 Mdot
.728 .56634 Mdot
.728 .56636 Mdot
.728 .56644 Mdot
.728 .56645 Mdot
.728 .56666 Mdot
.728 .56683 Mdot
.728 .56696 Mdot
.728 .56717 Mdot
.728 .56717 Mdot
.728 .56725 Mdot
.728 .56727 Mdot
.728 .56748 Mdot
.728 .56774 Mdot
.728 .56782 Mdot
.728 .56785 Mdot
.728 .56789 Mdot
.728 .56792 Mdot
.728 .56805 Mdot
.728 .56817 Mdot
.728 .5684 Mdot
.728 .56853 Mdot
.728 .56857 Mdot
.728 .56862 Mdot
.728 .56878 Mdot
.728 .56886 Mdot
.728 .56899 Mdot
.728 .56903 Mdot
.728 .56913 Mdot
.728 .56913 Mdot
.728 .56916 Mdot
.728 .56926 Mdot
.728 .56952 Mdot
.728 .56967 Mdot
.728 .56968 Mdot
.728 .56969 Mdot
.728 .56972 Mdot
.728 .56978 Mdot
.728 .56993 Mdot
.728 .56996 Mdot
.728 .56997 Mdot
.728 .57021 Mdot
.728 .57029 Mdot
.728 .5703 Mdot
.728 .57035 Mdot
.728 .5704 Mdot
.728 .57041 Mdot
.728 .57044 Mdot
.728 .57046 Mdot
.728 .57047 Mdot
.728 .57052 Mdot
.728 .57053 Mdot
.728 .57056 Mdot
.728 .57066 Mdot
.728 .57071 Mdot
.728 .57076 Mdot
.728 .57076 Mdot
.728 .57081 Mdot
.728 .57082 Mdot
.728 .57088 Mdot
.728 .57089 Mdot
.728 .57097 Mdot
.728 .57108 Mdot
.728 .57118 Mdot
.728 .5712 Mdot
.728 .57122 Mdot
.728 .57126 Mdot
.728 .57127 Mdot
.728 .57127 Mdot
.728 .57129 Mdot
.728 .57129 Mdot
.728 .5713 Mdot
.73 .12853 Mdot
.73 .12868 Mdot
.73 .12873 Mdot
.73 .12875 Mdot
.73 .12892 Mdot
.73 .12905 Mdot
.73 .12909 Mdot
.73 .12912 Mdot
.73 .1292 Mdot
.73 .12921 Mdot
.73 .1293 Mdot
.73 .12966 Mdot
.73 .12974 Mdot
.73 .13007 Mdot
.73 .13024 Mdot
.73 .13044 Mdot
.73 .13045 Mdot
.73 .1305 Mdot
.73 .13052 Mdot
.73 .13052 Mdot
.73 .13101 Mdot
.73 .13111 Mdot
.73 .13149 Mdot
.73 .13159 Mdot
.73 .13161 Mdot
.73 .13163 Mdot
.73 .13321 Mdot
.73 .13342 Mdot
.73 .13363 Mdot
.73 .13378 Mdot
.73 .1338 Mdot
.73 .13538 Mdot
.73 .1354 Mdot
.73 .13547 Mdot
.73 .1358 Mdot
.73 .13654 Mdot
.73 .13663 Mdot
.73 .13699 Mdot
.73 .13701 Mdot
.73 .13704 Mdot
.73 .13772 Mdot
.73 .13818 Mdot
.73 .13855 Mdot
.73 .13856 Mdot
.73 .13934 Mdot
.73 .13988 Mdot
.73 .14066 Mdot
.73 .14144 Mdot
.73 .14223 Mdot
.73 .14376 Mdot
.73 .14473 Mdot
.73 .14496 Mdot
.73 .14543 Mdot
.73 .14556 Mdot
.73 .14585 Mdot
.73 .14709 Mdot
.73 .14768 Mdot
.73 .14905 Mdot
.73 .14968 Mdot
.73 .14982 Mdot
.73 .14998 Mdot
.73 .15142 Mdot
.73 .15252 Mdot
.73 .15275 Mdot
.73 .15718 Mdot
.73 .15727 Mdot
.73 .15735 Mdot
.73 .15839 Mdot
.73 .1597 Mdot
.73 .16012 Mdot
.73 .16015 Mdot
.73 .16047 Mdot
.73 .16061 Mdot
.73 .16122 Mdot
.73 .16144 Mdot
.73 .16343 Mdot
.73 .16345 Mdot
.73 .16401 Mdot
.73 .16424 Mdot
.73 .16508 Mdot
.73 .1652 Mdot
.73 .16531 Mdot
.73 .1658 Mdot
.73 .16619 Mdot
.73 .16796 Mdot
.73 .16966 Mdot
.73 .17011 Mdot
.73 .17088 Mdot
.73 .17146 Mdot
.73 .17299 Mdot
.73 .17331 Mdot
.73 .17454 Mdot
.73 .17558 Mdot
.73 .17567 Mdot
.73 .1757 Mdot
.73 .17606 Mdot
.73 .17641 Mdot
.73 .17653 Mdot
.73 .17702 Mdot
.73 .17807 Mdot
.73 .17836 Mdot
.73 .1787 Mdot
.73 .17945 Mdot
.73 .18079 Mdot
.73 .18255 Mdot
.73 .18344 Mdot
.73 .18414 Mdot
.73 .18415 Mdot
.73 .18447 Mdot
.73 .18449 Mdot
.73 .18595 Mdot
.73 .18599 Mdot
.73 .18666 Mdot
.73 .18755 Mdot
.73 .18794 Mdot
.73 .1883 Mdot
.73 .18849 Mdot
.73 .18858 Mdot
.73 .18865 Mdot
.73 .18874 Mdot
.73 .1895 Mdot
.73 .19017 Mdot
.73 .19031 Mdot
.73 .19037 Mdot
.73 .19052 Mdot
.73 .19091 Mdot
.73 .19094 Mdot
.73 .19099 Mdot
.73 .19143 Mdot
.73 .1922 Mdot
.73 .19227 Mdot
.73 .19328 Mdot
.73 .19372 Mdot
.73 .19417 Mdot
.73 .19449 Mdot
.73 .19512 Mdot
.73 .19516 Mdot
.73 .19542 Mdot
.73 .19628 Mdot
.73 .19721 Mdot
.73 .19738 Mdot
.73 .19742 Mdot
.73 .19765 Mdot
.73 .19772 Mdot
.73 .19778 Mdot
.73 .1978 Mdot
.73 .19873 Mdot
.73 .19901 Mdot
.73 .19938 Mdot
.73 .2003 Mdot
.73 .20038 Mdot
.73 .20071 Mdot
.73 .20091 Mdot
.73 .20184 Mdot
.73 .20189 Mdot
.73 .20297 Mdot
.73 .20311 Mdot
.73 .20352 Mdot
.73 .20364 Mdot
.73 .20369 Mdot
.73 .20505 Mdot
.73 .20547 Mdot
.73 .20598 Mdot
.73 .2066 Mdot
.73 .20744 Mdot
.73 .20868 Mdot
.73 .20913 Mdot
.73 .21245 Mdot
.73 .21362 Mdot
.73 .21384 Mdot
.73 .21433 Mdot
.73 .21484 Mdot
.73 .215 Mdot
.73 .21506 Mdot
.73 .21572 Mdot
.73 .21579 Mdot
.73 .21693 Mdot
.73 .21767 Mdot
.73 .21827 Mdot
.73 .21869 Mdot
.73 .21883 Mdot
.73 .21909 Mdot
.73 .22102 Mdot
.73 .22203 Mdot
.73 .22432 Mdot
.73 .22439 Mdot
.73 .22498 Mdot
.73 .22498 Mdot
.73 .22509 Mdot
.73 .22535 Mdot
.73 .22551 Mdot
.73 .22649 Mdot
.73 .22682 Mdot
.73 .22747 Mdot
.73 .2284 Mdot
.73 .22872 Mdot
.73 .22896 Mdot
.73 .22927 Mdot
.73 .22936 Mdot
.73 .22964 Mdot
.73 .23187 Mdot
.73 .23239 Mdot
.73 .23313 Mdot
.73 .2332 Mdot
.73 .23386 Mdot
.73 .23427 Mdot
.73 .23458 Mdot
.73 .23459 Mdot
.73 .23472 Mdot
.73 .23487 Mdot
.73 .23517 Mdot
.73 .23525 Mdot
.73 .2365 Mdot
.73 .23686 Mdot
.73 .23871 Mdot
.73 .23891 Mdot
.73 .23903 Mdot
.73 .23962 Mdot
.73 .23975 Mdot
.73 .24018 Mdot
.73 .24054 Mdot
.73 .24057 Mdot
.73 .24145 Mdot
.73 .24183 Mdot
.73 .24258 Mdot
.73 .24273 Mdot
.73 .24416 Mdot
.73 .24418 Mdot
.73 .24445 Mdot
.73 .24465 Mdot
.73 .24673 Mdot
.73 .24724 Mdot
.73 .24758 Mdot
.73 .24784 Mdot
.73 .24823 Mdot
.73 .24904 Mdot
.73 .25006 Mdot
.73 .25091 Mdot
.73 .25157 Mdot
.73 .25247 Mdot
.73 .25249 Mdot
.73 .25379 Mdot
.73 .25437 Mdot
.73 .25465 Mdot
.73 .25537 Mdot
.73 .25549 Mdot
.73 .25574 Mdot
.73 .25634 Mdot
.73 .25665 Mdot
.73 .25737 Mdot
.73 .25738 Mdot
.73 .25787 Mdot
.73 .2583 Mdot
.73 .25916 Mdot
.73 .2602 Mdot
.73 .26104 Mdot
.73 .26172 Mdot
.73 .26232 Mdot
.73 .26297 Mdot
.73 .26314 Mdot
.73 .26395 Mdot
.73 .26688 Mdot
.73 .26738 Mdot
.73 .26744 Mdot
.73 .26801 Mdot
.73 .26814 Mdot
.73 .26847 Mdot
.73 .26848 Mdot
.73 .27027 Mdot
.73 .27049 Mdot
.73 .27075 Mdot
.73 .27235 Mdot
.73 .27735 Mdot
.73 .27748 Mdot
.73 .27758 Mdot
.73 .27805 Mdot
.73 .28059 Mdot
.73 .28375 Mdot
.73 .28525 Mdot
.73 .28659 Mdot
.73 .28742 Mdot
.73 .28783 Mdot
.73 .28834 Mdot
.73 .28915 Mdot
.73 .28918 Mdot
.73 .29105 Mdot
.73 .29114 Mdot
.73 .29336 Mdot
.73 .29338 Mdot
.73 .29361 Mdot
.73 .29699 Mdot
.73 .29701 Mdot
.73 .29705 Mdot
.73 .29725 Mdot
.73 .29823 Mdot
.73 .29933 Mdot
.73 .29934 Mdot
.73 .29952 Mdot
.73 .30005 Mdot
.73 .30168 Mdot
.73 .30292 Mdot
.73 .30326 Mdot
.73 .30329 Mdot
.73 .30395 Mdot
.73 .30459 Mdot
.73 .30772 Mdot
.73 .31194 Mdot
.73 .31236 Mdot
.73 .31245 Mdot
.73 .31427 Mdot
.73 .31439 Mdot
.73 .31662 Mdot
.73 .31755 Mdot
.73 .31853 Mdot
.73 .31863 Mdot
.73 .32001 Mdot
.73 .32378 Mdot
.73 .3241 Mdot
.73 .32687 Mdot
.73 .32741 Mdot
.73 .32832 Mdot
.73 .32842 Mdot
.73 .32891 Mdot
.73 .33062 Mdot
.73 .332 Mdot
.73 .33353 Mdot
.73 .33566 Mdot
.73 .3365 Mdot
.73 .3367 Mdot
.73 .33709 Mdot
.73 .3372 Mdot
.73 .33845 Mdot
.73 .33892 Mdot
.73 .34174 Mdot
.73 .34252 Mdot
.73 .34269 Mdot
.73 .34574 Mdot
.73 .34579 Mdot
.73 .34646 Mdot
.73 .34756 Mdot
.73 .34785 Mdot
.73 .34822 Mdot
.73 .34836 Mdot
.73 .35052 Mdot
.73 .35093 Mdot
.73 .35216 Mdot
.73 .3531 Mdot
.73 .35335 Mdot
.73 .35376 Mdot
.73 .35625 Mdot
.73 .3563 Mdot
.73 .3565 Mdot
.73 .35668 Mdot
.73 .35674 Mdot
.73 .35752 Mdot
.73 .35766 Mdot
.73 .35821 Mdot
.73 .3605 Mdot
.73 .3605 Mdot
.73 .36136 Mdot
.73 .36211 Mdot
.73 .36246 Mdot
.73 .36259 Mdot
.73 .36262 Mdot
.73 .36301 Mdot
.73 .36332 Mdot
.73 .36341 Mdot
.73 .36348 Mdot
.73 .36366 Mdot
.73 .36367 Mdot
.73 .36369 Mdot
.73 .36389 Mdot
.73 .36427 Mdot
.73 .36473 Mdot
.73 .36493 Mdot
.73 .36512 Mdot
.73 .36527 Mdot
.73 .36568 Mdot
.73 .36606 Mdot
.73 .36654 Mdot
.73 .36656 Mdot
.73 .36666 Mdot
.73 .36669 Mdot
.73 .36671 Mdot
.73 .36672 Mdot
.73 .36725 Mdot
.73 .3674 Mdot
.73 .3678 Mdot
.73 .36784 Mdot
.73 .36806 Mdot
.73 .36846 Mdot
.73 .36848 Mdot
.73 .36893 Mdot
.73 .36916 Mdot
.73 .36921 Mdot
.73 .36924 Mdot
.73 .36998 Mdot
.73 .37149 Mdot
.73 .37283 Mdot
.73 .3733 Mdot
.73 .37378 Mdot
.73 .37413 Mdot
.73 .37416 Mdot
.73 .37461 Mdot
.73 .3749 Mdot
.73 .37513 Mdot
.73 .37535 Mdot
.73 .37771 Mdot
.73 .37772 Mdot
.73 .37776 Mdot
.73 .37792 Mdot
.73 .37865 Mdot
.73 .37921 Mdot
.73 .37936 Mdot
.73 .37947 Mdot
.73 .38029 Mdot
.73 .38049 Mdot
.73 .38075 Mdot
.73 .38078 Mdot
.73 .38102 Mdot
.73 .38129 Mdot
.73 .38129 Mdot
.73 .38134 Mdot
.73 .38139 Mdot
.73 .3815 Mdot
.73 .38199 Mdot
.73 .38212 Mdot
.73 .3829 Mdot
.73 .38311 Mdot
.73 .38391 Mdot
.73 .38423 Mdot
.73 .38473 Mdot
.73 .38474 Mdot
.73 .38582 Mdot
.73 .38594 Mdot
.73 .38603 Mdot
.73 .38645 Mdot
.73 .3868 Mdot
.73 .3871 Mdot
.73 .38733 Mdot
.73 .38764 Mdot
.73 .38764 Mdot
.73 .38809 Mdot
.73 .38829 Mdot
.73 .38897 Mdot
.73 .38932 Mdot
.73 .38949 Mdot
.73 .38993 Mdot
.73 .39028 Mdot
.73 .39079 Mdot
.73 .391 Mdot
.73 .39127 Mdot
.73 .39271 Mdot
.73 .39289 Mdot
.73 .3938 Mdot
.73 .39433 Mdot
.73 .39597 Mdot
.73 .39604 Mdot
.73 .39619 Mdot
.73 .39803 Mdot
.73 .39851 Mdot
.73 .3995 Mdot
.73 .39977 Mdot
.73 .40039 Mdot
.73 .40109 Mdot
.73 .40117 Mdot
.73 .40223 Mdot
.73 .40225 Mdot
.73 .40263 Mdot
.73 .40297 Mdot
.73 .40409 Mdot
.73 .40421 Mdot
.73 .40461 Mdot
.73 .40688 Mdot
.73 .40701 Mdot
.73 .40704 Mdot
.73 .40759 Mdot
.73 .40763 Mdot
.73 .40831 Mdot
.73 .4086 Mdot
.73 .40893 Mdot
.73 .4105 Mdot
.73 .4116 Mdot
.73 .41187 Mdot
.73 .4119 Mdot
.73 .41344 Mdot
.73 .41408 Mdot
.73 .41455 Mdot
.73 .41591 Mdot
.73 .4171 Mdot
.73 .41785 Mdot
.73 .41789 Mdot
.73 .41853 Mdot
.73 .41937 Mdot
.73 .4195 Mdot
.73 .42036 Mdot
.73 .4215 Mdot
.73 .4215 Mdot
.73 .42243 Mdot
.73 .42333 Mdot
.73 .4235 Mdot
.73 .42366 Mdot
.73 .42386 Mdot
.73 .42568 Mdot
.73 .4259 Mdot
.73 .4275 Mdot
.73 .42758 Mdot
.73 .42791 Mdot
.73 .4282 Mdot
.73 .429 Mdot
.73 .42904 Mdot
.73 .42906 Mdot
.73 .42968 Mdot
.73 .42994 Mdot
.73 .43022 Mdot
.73 .43033 Mdot
.73 .43062 Mdot
.73 .4311 Mdot
.73 .43153 Mdot
.73 .434 Mdot
.73 .43444 Mdot
.73 .43527 Mdot
.73 .43531 Mdot
.73 .4355 Mdot
.73 .43636 Mdot
.73 .43669 Mdot
.73 .43678 Mdot
.73 .43799 Mdot
.73 .43835 Mdot
.73 .43857 Mdot
.73 .43878 Mdot
.73 .43903 Mdot
.73 .43907 Mdot
.73 .43967 Mdot
.73 .44039 Mdot
.73 .44152 Mdot
.73 .44363 Mdot
.73 .44395 Mdot
.73 .44432 Mdot
.73 .44505 Mdot
.73 .44582 Mdot
.73 .44669 Mdot
.73 .44692 Mdot
.73 .4475 Mdot
.73 .44824 Mdot
.73 .44886 Mdot
.73 .44928 Mdot
.73 .44969 Mdot
.73 .44989 Mdot
.73 .45122 Mdot
.73 .45256 Mdot
.73 .45258 Mdot
.73 .45315 Mdot
.73 .45385 Mdot
.73 .45448 Mdot
.73 .45505 Mdot
.73 .45528 Mdot
.73 .45707 Mdot
.73 .45722 Mdot
.73 .45728 Mdot
.73 .4579 Mdot
.73 .45849 Mdot
.73 .45866 Mdot
.73 .4587 Mdot
.73 .45953 Mdot
.73 .46058 Mdot
.73 .46131 Mdot
.73 .46179 Mdot
.73 .46179 Mdot
.73 .46236 Mdot
.73 .4628 Mdot
.73 .46286 Mdot
.73 .46329 Mdot
.73 .46361 Mdot
.73 .46363 Mdot
.73 .46401 Mdot
.73 .4646 Mdot
.73 .46583 Mdot
.73 .46659 Mdot
.73 .46675 Mdot
.73 .46729 Mdot
.73 .46869 Mdot
.73 .46871 Mdot
.73 .46899 Mdot
.73 .46906 Mdot
.73 .47015 Mdot
.73 .47041 Mdot
.73 .47111 Mdot
.73 .47129 Mdot
.73 .4713 Mdot
.73 .47181 Mdot
.73 .47184 Mdot
.73 .47417 Mdot
.73 .47424 Mdot
.73 .47504 Mdot
.73 .47529 Mdot
.73 .47571 Mdot
.73 .47647 Mdot
.73 .47669 Mdot
.73 .47693 Mdot
.73 .47709 Mdot
.73 .47729 Mdot
.73 .47754 Mdot
.73 .47785 Mdot
.73 .47794 Mdot
.73 .47814 Mdot
.73 .47829 Mdot
.73 .4784 Mdot
.73 .47853 Mdot
.73 .47889 Mdot
.73 .47893 Mdot
.73 .47898 Mdot
.73 .47971 Mdot
.73 .48021 Mdot
.73 .48067 Mdot
.73 .48073 Mdot
.73 .48095 Mdot
.73 .48104 Mdot
.73 .48116 Mdot
.73 .48127 Mdot
.73 .48128 Mdot
.73 .48186 Mdot
.73 .48191 Mdot
.73 .48198 Mdot
.73 .48265 Mdot
.73 .48371 Mdot
.73 .4838 Mdot
.73 .48391 Mdot
.73 .48404 Mdot
.73 .48542 Mdot
.73 .48608 Mdot
.73 .48674 Mdot
.73 .48675 Mdot
.73 .48704 Mdot
.73 .48721 Mdot
.73 .48728 Mdot
.73 .48752 Mdot
.73 .48814 Mdot
.73 .4882 Mdot
.73 .48857 Mdot
.73 .48884 Mdot
.73 .48983 Mdot
.73 .4902 Mdot
.73 .4902 Mdot
.73 .49118 Mdot
.73 .49141 Mdot
.73 .49147 Mdot
.73 .49181 Mdot
.73 .49183 Mdot
.73 .49191 Mdot
.73 .49199 Mdot
.73 .49201 Mdot
.73 .49307 Mdot
.73 .49324 Mdot
.73 .49335 Mdot
.73 .49374 Mdot
.73 .49426 Mdot
.73 .49443 Mdot
.73 .49534 Mdot
.73 .49539 Mdot
.73 .49555 Mdot
.73 .49567 Mdot
.73 .49613 Mdot
.73 .49641 Mdot
.73 .49643 Mdot
.73 .49769 Mdot
.73 .49776 Mdot
.73 .49808 Mdot
.73 .49924 Mdot
.73 .49943 Mdot
.73 .49994 Mdot
.73 .49998 Mdot
.73 .50014 Mdot
.73 .50022 Mdot
.73 .50057 Mdot
.73 .50143 Mdot
.73 .50204 Mdot
.73 .5026 Mdot
.73 .50329 Mdot
.73 .50348 Mdot
.73 .50352 Mdot
.73 .50389 Mdot
.73 .5041 Mdot
.73 .5052 Mdot
.73 .50533 Mdot
.73 .50682 Mdot
.73 .50736 Mdot
.73 .5074 Mdot
.73 .50778 Mdot
.73 .50815 Mdot
.73 .50901 Mdot
.73 .50906 Mdot
.73 .50977 Mdot
.73 .5098 Mdot
.73 .50997 Mdot
.73 .51159 Mdot
.73 .51279 Mdot
.73 .51303 Mdot
.73 .51328 Mdot
.73 .5133 Mdot
.73 .51343 Mdot
.73 .5139 Mdot
.73 .51452 Mdot
.73 .51471 Mdot
.73 .51478 Mdot
.73 .51479 Mdot
.73 .5152 Mdot
.73 .51557 Mdot
.73 .51565 Mdot
.73 .51566 Mdot
.73 .51567 Mdot
.73 .51694 Mdot
.73 .51703 Mdot
.73 .51703 Mdot
.73 .51786 Mdot
.73 .5179 Mdot
.73 .51859 Mdot
.73 .5186 Mdot
.73 .5189 Mdot
.73 .51909 Mdot
.73 .51924 Mdot
.73 .51955 Mdot
.73 .52004 Mdot
.73 .52059 Mdot
.73 .52175 Mdot
.73 .52268 Mdot
.73 .52285 Mdot
.73 .52289 Mdot
.73 .52293 Mdot
.73 .52474 Mdot
.73 .52532 Mdot
.73 .52541 Mdot
.73 .52549 Mdot
.73 .52613 Mdot
.73 .52614 Mdot
.73 .52626 Mdot
.73 .52631 Mdot
.73 .52651 Mdot
.73 .52653 Mdot
.73 .52671 Mdot
.73 .52775 Mdot
.73 .52804 Mdot
.73 .5281 Mdot
.73 .52833 Mdot
.73 .52854 Mdot
.73 .52878 Mdot
.73 .52908 Mdot
.73 .52945 Mdot
.73 .52975 Mdot
.73 .5299 Mdot
.73 .53008 Mdot
.73 .53008 Mdot
.73 .53033 Mdot
.73 .53044 Mdot
.73 .53065 Mdot
.73 .53074 Mdot
.73 .53103 Mdot
.73 .53113 Mdot
.73 .53133 Mdot
.73 .53179 Mdot
.73 .5318 Mdot
.73 .53211 Mdot
.73 .53234 Mdot
.73 .53264 Mdot
.73 .53299 Mdot
.73 .53327 Mdot
.73 .53341 Mdot
.73 .5335 Mdot
.73 .53362 Mdot
.73 .53379 Mdot
.73 .53451 Mdot
.73 .53458 Mdot
.73 .53467 Mdot
.73 .53468 Mdot
.73 .53517 Mdot
.73 .53522 Mdot
.73 .53548 Mdot
.73 .53561 Mdot
.73 .53591 Mdot
.73 .53592 Mdot
.73 .53605 Mdot
.73 .53619 Mdot
.73 .53624 Mdot
.73 .53644 Mdot
.73 .53648 Mdot
.73 .53655 Mdot
.73 .53718 Mdot
.73 .5373 Mdot
.73 .53773 Mdot
.73 .53776 Mdot
.73 .53786 Mdot
.73 .53791 Mdot
.73 .53795 Mdot
.73 .53796 Mdot
.73 .53806 Mdot
.73 .5382 Mdot
.73 .53843 Mdot
.73 .53845 Mdot
.73 .5387 Mdot
.73 .53888 Mdot
.73 .53963 Mdot
.73 .53972 Mdot
.73 .53975 Mdot
.73 .53986 Mdot
.73 .53994 Mdot
.73 .54005 Mdot
.73 .54036 Mdot
.73 .54058 Mdot
.73 .54069 Mdot
.73 .54102 Mdot
.73 .54107 Mdot
.73 .54116 Mdot
.73 .54119 Mdot
.73 .54119 Mdot
.73 .54139 Mdot
.73 .54142 Mdot
.73 .54218 Mdot
.73 .54252 Mdot
.73 .54316 Mdot
.73 .54325 Mdot
.73 .54329 Mdot
.73 .54343 Mdot
.73 .54363 Mdot
.73 .54387 Mdot
.73 .54425 Mdot
.73 .54428 Mdot
.73 .54449 Mdot
.73 .54451 Mdot
.73 .54457 Mdot
.73 .54474 Mdot
.73 .5449 Mdot
.73 .54497 Mdot
.73 .54535 Mdot
.73 .54644 Mdot
.73 .54659 Mdot
.73 .547 Mdot
.73 .54727 Mdot
.73 .54747 Mdot
.73 .54764 Mdot
.73 .54778 Mdot
.73 .54822 Mdot
.73 .54824 Mdot
.73 .54828 Mdot
.73 .54841 Mdot
.73 .54846 Mdot
.73 .54881 Mdot
.73 .54882 Mdot
.73 .54912 Mdot
.73 .54919 Mdot
.73 .54929 Mdot
.73 .54932 Mdot
.73 .54962 Mdot
.73 .54974 Mdot
.73 .54983 Mdot
.73 .55013 Mdot
.73 .55013 Mdot
.73 .55015 Mdot
.73 .55018 Mdot
.73 .55025 Mdot
.73 .55026 Mdot
.73 .55032 Mdot
.73 .55062 Mdot
.73 .5509 Mdot
.73 .55098 Mdot
.73 .55099 Mdot
.73 .55119 Mdot
.73 .5513 Mdot
.73 .55144 Mdot
.73 .55158 Mdot
.73 .55191 Mdot
.73 .55193 Mdot
.73 .55217 Mdot
.73 .55232 Mdot
.73 .55233 Mdot
.73 .55234 Mdot
.73 .55234 Mdot
.73 .55246 Mdot
.73 .55251 Mdot
.73 .55253 Mdot
.73 .55258 Mdot
.73 .55279 Mdot
.73 .55303 Mdot
.73 .55306 Mdot
.73 .55308 Mdot
.73 .55311 Mdot
.73 .55317 Mdot
.73 .55329 Mdot
.73 .55341 Mdot
.73 .5537 Mdot
.73 .55391 Mdot
.73 .55392 Mdot
.73 .55438 Mdot
.73 .55439 Mdot
.73 .55449 Mdot
.73 .55449 Mdot
.73 .55472 Mdot
.73 .555 Mdot
.73 .55555 Mdot
.73 .55598 Mdot
.73 .55621 Mdot
.73 .55632 Mdot
.73 .55641 Mdot
.73 .55674 Mdot
.73 .55689 Mdot
.73 .55693 Mdot
.73 .55704 Mdot
.73 .55715 Mdot
.73 .55716 Mdot
.73 .55719 Mdot
.73 .55752 Mdot
.73 .5579 Mdot
.73 .558 Mdot
.73 .55848 Mdot
.73 .55866 Mdot
.73 .5589 Mdot
.73 .55904 Mdot
.73 .55957 Mdot
.73 .56012 Mdot
.73 .56024 Mdot
.73 .56039 Mdot
.73 .56042 Mdot
.73 .56046 Mdot
.73 .56072 Mdot
.73 .56079 Mdot
.73 .56096 Mdot
.73 .56097 Mdot
.73 .56158 Mdot
.73 .56165 Mdot
.73 .56184 Mdot
.73 .56188 Mdot
.73 .56198 Mdot
.73 .56199 Mdot
.73 .56212 Mdot
.73 .56252 Mdot
.73 .56284 Mdot
.73 .56287 Mdot
.73 .56289 Mdot
.73 .56425 Mdot
.73 .56432 Mdot
.73 .56465 Mdot
.73 .56509 Mdot
.73 .56514 Mdot
.73 .56518 Mdot
.73 .56537 Mdot
.73 .56579 Mdot
.73 .56597 Mdot
.73 .56634 Mdot
.73 .56643 Mdot
.73 .56647 Mdot
.73 .56661 Mdot
.73 .56668 Mdot
.73 .56697 Mdot
.73 .56743 Mdot
.73 .56767 Mdot
.73 .5679 Mdot
.73 .56814 Mdot
.73 .5683 Mdot
.73 .56854 Mdot
.73 .56854 Mdot
.73 .56865 Mdot
.73 .56879 Mdot
.73 .56899 Mdot
.73 .569 Mdot
.73 .569 Mdot
.73 .56911 Mdot
.73 .56914 Mdot
.73 .56936 Mdot
.73 .56946 Mdot
.73 .56948 Mdot
.73 .56949 Mdot
.73 .56996 Mdot
.73 .56996 Mdot
.73 .57001 Mdot
.73 .57007 Mdot
.73 .57013 Mdot
.73 .5706 Mdot
.73 .57061 Mdot
.73 .57061 Mdot
.73 .57064 Mdot
.73 .57076 Mdot
.73 .57079 Mdot
.73 .57093 Mdot
.73 .57093 Mdot
.73 .57094 Mdot
.73 .57095 Mdot
.73 .57096 Mdot
.73 .57102 Mdot
.73 .57107 Mdot
.73 .57116 Mdot
.73 .57119 Mdot
.73 .5713 Mdot
.73 .57132 Mdot
.73 .57132 Mdot
.73 .57135 Mdot
.73 .57136 Mdot
.73 .57137 Mdot
.73 .57141 Mdot
.73 .57146 Mdot
.73 .57146 Mdot
.73 .57148 Mdot
.73 .57152 Mdot
.732 .12775 Mdot
.732 .12776 Mdot
.732 .12776 Mdot
.732 .12776 Mdot
.732 .12776 Mdot
.732 .12777 Mdot
.732 .12787 Mdot
.732 .12799 Mdot
.732 .12821 Mdot
.732 .12823 Mdot
.732 .12825 Mdot
.732 .12825 Mdot
.732 .12842 Mdot
.732 .12842 Mdot
.732 .12845 Mdot
.732 .12845 Mdot
.732 .12845 Mdot
.732 .12848 Mdot
.732 .1286 Mdot
.732 .12876 Mdot
.732 .12896 Mdot
.732 .12906 Mdot
.732 .12931 Mdot
.732 .12934 Mdot
.732 .12946 Mdot
.732 .12983 Mdot
.732 .13029 Mdot
.732 .1303 Mdot
.732 .13049 Mdot
.732 .13059 Mdot
.732 .13084 Mdot
.732 .13097 Mdot
.732 .13114 Mdot
.732 .1312 Mdot
.732 .13185 Mdot
.732 .13189 Mdot
.732 .13198 Mdot
.732 .13289 Mdot
.732 .13384 Mdot
.732 .1344 Mdot
.732 .13447 Mdot
.732 .13459 Mdot
.732 .13483 Mdot
.732 .1349 Mdot
.732 .13661 Mdot
.732 .13713 Mdot
.732 .1378 Mdot
.732 .13807 Mdot
.732 .13818 Mdot
.732 .13848 Mdot
.732 .13891 Mdot
.732 .13893 Mdot
.732 .13907 Mdot
.732 .13934 Mdot
.732 .13992 Mdot
.732 .14004 Mdot
.732 .14019 Mdot
.732 .14095 Mdot
.732 .14262 Mdot
.732 .14275 Mdot
.732 .14282 Mdot
.732 .14456 Mdot
.732 .1458 Mdot
.732 .14588 Mdot
.732 .14646 Mdot
.732 .1467 Mdot
.732 .14674 Mdot
.732 .1474 Mdot
.732 .14758 Mdot
.732 .14782 Mdot
.732 .14802 Mdot
.732 .14838 Mdot
.732 .14865 Mdot
.732 .14865 Mdot
.732 .14866 Mdot
.732 .14954 Mdot
.732 .15184 Mdot
.732 .15439 Mdot
.732 .15504 Mdot
.732 .15649 Mdot
.732 .15663 Mdot
.732 .15667 Mdot
.732 .15823 Mdot
.732 .15891 Mdot
.732 .16033 Mdot
.732 .16037 Mdot
.732 .1608 Mdot
.732 .16149 Mdot
.732 .16177 Mdot
.732 .16193 Mdot
.732 .16212 Mdot
.732 .16381 Mdot
.732 .16412 Mdot
.732 .16432 Mdot
.732 .16445 Mdot
.732 .16574 Mdot
.732 .16668 Mdot
.732 .1671 Mdot
.732 .16817 Mdot
.732 .16824 Mdot
.732 .16833 Mdot
.732 .16906 Mdot
.732 .17332 Mdot
.732 .17364 Mdot
.732 .17391 Mdot
.732 .17399 Mdot
.732 .17671 Mdot
.732 .1775 Mdot
.732 .17765 Mdot
.732 .17846 Mdot
.732 .17919 Mdot
.732 .18009 Mdot
.732 .18193 Mdot
.732 .18295 Mdot
.732 .18337 Mdot
.732 .18344 Mdot
.732 .18344 Mdot
.732 .18345 Mdot
.732 .18345 Mdot
.732 .18346 Mdot
.732 .18396 Mdot
.732 .18422 Mdot
.732 .18455 Mdot
.732 .18481 Mdot
.732 .18564 Mdot
.732 .18576 Mdot
.732 .18585 Mdot
.732 .18585 Mdot
.732 .1867 Mdot
.732 .18671 Mdot
.732 .18684 Mdot
.732 .18685 Mdot
.732 .18686 Mdot
.732 .187 Mdot
.732 .18751 Mdot
.732 .1876 Mdot
.732 .18839 Mdot
.732 .18856 Mdot
.732 .18874 Mdot
.732 .18941 Mdot
.732 .18951 Mdot
.732 .18992 Mdot
.732 .19005 Mdot
.732 .19041 Mdot
.732 .19119 Mdot
.732 .19135 Mdot
.732 .19195 Mdot
.732 .19247 Mdot
.732 .1927 Mdot
.732 .19275 Mdot
.732 .19387 Mdot
.732 .19414 Mdot
.732 .19478 Mdot
.732 .19491 Mdot
.732 .19518 Mdot
.732 .19574 Mdot
.732 .19625 Mdot
.732 .19634 Mdot
.732 .19666 Mdot
.732 .19731 Mdot
.732 .19784 Mdot
.732 .19785 Mdot
.732 .19795 Mdot
.732 .19862 Mdot
.732 .19901 Mdot
.732 .19917 Mdot
.732 .19991 Mdot
.732 .20081 Mdot
.732 .20081 Mdot
.732 .20112 Mdot
.732 .20261 Mdot
.732 .20272 Mdot
.732 .20298 Mdot
.732 .20312 Mdot
.732 .20467 Mdot
.732 .20488 Mdot
.732 .20536 Mdot
.732 .20681 Mdot
.732 .20753 Mdot
.732 .2077 Mdot
.732 .20892 Mdot
.732 .2092 Mdot
.732 .21044 Mdot
.732 .21221 Mdot
.732 .21266 Mdot
.732 .21335 Mdot
.732 .21434 Mdot
.732 .21455 Mdot
.732 .21581 Mdot
.732 .21584 Mdot
.732 .21904 Mdot
.732 .21909 Mdot
.732 .21937 Mdot
.732 .21945 Mdot
.732 .22017 Mdot
.732 .22071 Mdot
.732 .22155 Mdot
.732 .22169 Mdot
.732 .22198 Mdot
.732 .22252 Mdot
.732 .22354 Mdot
.732 .22435 Mdot
.732 .22469 Mdot
.732 .22585 Mdot
.732 .22586 Mdot
.732 .22683 Mdot
.732 .22932 Mdot
.732 .23071 Mdot
.732 .23073 Mdot
.732 .23213 Mdot
.732 .23215 Mdot
.732 .23295 Mdot
.732 .23532 Mdot
.732 .23532 Mdot
.732 .23627 Mdot
.732 .23744 Mdot
.732 .23795 Mdot
.732 .23796 Mdot
.732 .23941 Mdot
.732 .24104 Mdot
.732 .24135 Mdot
.732 .24173 Mdot
.732 .24225 Mdot
.732 .24362 Mdot
.732 .2446 Mdot
.732 .24627 Mdot
.732 .24638 Mdot
.732 .24688 Mdot
.732 .24695 Mdot
.732 .24725 Mdot
.732 .24878 Mdot
.732 .24895 Mdot
.732 .25052 Mdot
.732 .25098 Mdot
.732 .25102 Mdot
.732 .25153 Mdot
.732 .25218 Mdot
.732 .2523 Mdot
.732 .25264 Mdot
.732 .25326 Mdot
.732 .25338 Mdot
.732 .25431 Mdot
.732 .25508 Mdot
.732 .25918 Mdot
.732 .25999 Mdot
.732 .26039 Mdot
.732 .26086 Mdot
.732 .26244 Mdot
.732 .26534 Mdot
.732 .26538 Mdot
.732 .26597 Mdot
.732 .26748 Mdot
.732 .26756 Mdot
.732 .26768 Mdot
.732 .26885 Mdot
.732 .26896 Mdot
.732 .26906 Mdot
.732 .26991 Mdot
.732 .26993 Mdot
.732 .27081 Mdot
.732 .27124 Mdot
.732 .27235 Mdot
.732 .27374 Mdot
.732 .27549 Mdot
.732 .27715 Mdot
.732 .27781 Mdot
.732 .27782 Mdot
.732 .27802 Mdot
.732 .27845 Mdot
.732 .27877 Mdot
.732 .27933 Mdot
.732 .28005 Mdot
.732 .28107 Mdot
.732 .28257 Mdot
.732 .28263 Mdot
.732 .28275 Mdot
.732 .28501 Mdot
.732 .28526 Mdot
.732 .28612 Mdot
.732 .28626 Mdot
.732 .28628 Mdot
.732 .28877 Mdot
.732 .29084 Mdot
.732 .2914 Mdot
.732 .29149 Mdot
.732 .29505 Mdot
.732 .29526 Mdot
.732 .2964 Mdot
.732 .29651 Mdot
.732 .29682 Mdot
.732 .29708 Mdot
.732 .29778 Mdot
.732 .30052 Mdot
.732 .30123 Mdot
.732 .30153 Mdot
.732 .30273 Mdot
.732 .30318 Mdot
.732 .30331 Mdot
.732 .30332 Mdot
.732 .30342 Mdot
.732 .30343 Mdot
.732 .30418 Mdot
.732 .30427 Mdot
.732 .3044 Mdot
.732 .30567 Mdot
.732 .30663 Mdot
.732 .30803 Mdot
.732 .30809 Mdot
.732 .30872 Mdot
.732 .30988 Mdot
.732 .30989 Mdot
.732 .30994 Mdot
.732 .31385 Mdot
.732 .31473 Mdot
.732 .31585 Mdot
.732 .3176 Mdot
.732 .3179 Mdot
.732 .31882 Mdot
.732 .31984 Mdot
.732 .31987 Mdot
.732 .32046 Mdot
.732 .32284 Mdot
.732 .3234 Mdot
.732 .32442 Mdot
.732 .32579 Mdot
.732 .3268 Mdot
.732 .3271 Mdot
.732 .32985 Mdot
.732 .33059 Mdot
.732 .33099 Mdot
.732 .33131 Mdot
.732 .33219 Mdot
.732 .33288 Mdot
.732 .33376 Mdot
.732 .33805 Mdot
.732 .33852 Mdot
.732 .33874 Mdot
.732 .3394 Mdot
.732 .33974 Mdot
.732 .34022 Mdot
.732 .34473 Mdot
.732 .34578 Mdot
.732 .3458 Mdot
.732 .34838 Mdot
.732 .3488 Mdot
.732 .35018 Mdot
.732 .35129 Mdot
.732 .35182 Mdot
.732 .35274 Mdot
.732 .35314 Mdot
.732 .35542 Mdot
.732 .35573 Mdot
.732 .35577 Mdot
.732 .35757 Mdot
.732 .35841 Mdot
.732 .35975 Mdot
.732 .36024 Mdot
.732 .36044 Mdot
.732 .36047 Mdot
.732 .36047 Mdot
.732 .36048 Mdot
.732 .36048 Mdot
.732 .36048 Mdot
.732 .36072 Mdot
.732 .36085 Mdot
.732 .361 Mdot
.732 .36113 Mdot
.732 .36152 Mdot
.732 .36157 Mdot
.732 .36162 Mdot
.732 .36162 Mdot
.732 .36201 Mdot
.732 .36202 Mdot
.732 .36208 Mdot
.732 .36208 Mdot
.732 .36209 Mdot
.732 .36216 Mdot
.732 .36239 Mdot
.732 .36243 Mdot
.732 .3628 Mdot
.732 .36287 Mdot
.732 .36327 Mdot
.732 .36331 Mdot
.732 .3635 Mdot
.732 .36356 Mdot
.732 .36407 Mdot
.732 .36415 Mdot
.732 .36441 Mdot
.732 .36475 Mdot
.732 .36527 Mdot
.732 .36568 Mdot
.732 .36609 Mdot
.732 .36632 Mdot
.732 .36636 Mdot
.732 .36678 Mdot
.732 .36701 Mdot
.732 .36735 Mdot
.732 .36758 Mdot
.732 .3679 Mdot
.732 .36828 Mdot
.732 .36828 Mdot
.732 .36841 Mdot
.732 .36904 Mdot
.732 .3692 Mdot
.732 .3699 Mdot
.732 .36999 Mdot
.732 .37019 Mdot
.732 .37226 Mdot
.732 .37297 Mdot
.732 .37315 Mdot
.732 .37382 Mdot
.732 .37391 Mdot
.732 .3744 Mdot
.732 .37566 Mdot
.732 .37568 Mdot
.732 .37582 Mdot
.732 .3761 Mdot
.732 .37663 Mdot
.732 .37679 Mdot
.732 .37739 Mdot
.732 .37769 Mdot
.732 .37782 Mdot
.732 .37826 Mdot
.732 .37826 Mdot
.732 .37956 Mdot
.732 .3806 Mdot
.732 .3809 Mdot
.732 .38176 Mdot
.732 .38211 Mdot
.732 .38253 Mdot
.732 .38323 Mdot
.732 .38382 Mdot
.732 .38393 Mdot
.732 .38406 Mdot
.732 .38425 Mdot
.732 .38473 Mdot
.732 .38567 Mdot
.732 .38571 Mdot
.732 .38601 Mdot
.732 .38654 Mdot
.732 .3866 Mdot
.732 .38715 Mdot
.732 .3875 Mdot
.732 .38772 Mdot
.732 .38776 Mdot
.732 .38788 Mdot
.732 .38809 Mdot
.732 .38813 Mdot
.732 .38845 Mdot
.732 .39011 Mdot
.732 .39038 Mdot
.732 .39052 Mdot
.732 .39068 Mdot
.732 .39239 Mdot
.732 .39289 Mdot
.732 .39291 Mdot
.732 .39295 Mdot
.732 .39338 Mdot
.732 .39341 Mdot
.732 .3937 Mdot
.732 .39398 Mdot
.732 .39412 Mdot
.732 .39494 Mdot
.732 .39627 Mdot
.732 .39627 Mdot
.732 .39658 Mdot
.732 .39676 Mdot
.732 .39699 Mdot
.732 .3978 Mdot
.732 .39782 Mdot
.732 .39899 Mdot
.732 .39978 Mdot
.732 .40044 Mdot
.732 .40062 Mdot
.732 .40064 Mdot
.732 .40176 Mdot
.732 .40183 Mdot
.732 .40232 Mdot
.732 .4024 Mdot
.732 .40262 Mdot
.732 .40379 Mdot
.732 .40417 Mdot
.732 .40431 Mdot
.732 .40434 Mdot
.732 .40435 Mdot
.732 .40438 Mdot
.732 .40438 Mdot
.732 .40462 Mdot
.732 .40464 Mdot
.732 .40508 Mdot
.732 .40581 Mdot
.732 .40602 Mdot
.732 .40638 Mdot
.732 .40638 Mdot
.732 .40639 Mdot
.732 .40786 Mdot
.732 .4082 Mdot
.732 .40874 Mdot
.732 .40942 Mdot
.732 .40943 Mdot
.732 .40961 Mdot
.732 .41081 Mdot
.732 .41153 Mdot
.732 .41162 Mdot
.732 .41245 Mdot
.732 .41279 Mdot
.732 .41289 Mdot
.732 .41363 Mdot
.732 .41512 Mdot
.732 .41556 Mdot
.732 .418 Mdot
.732 .41853 Mdot
.732 .41929 Mdot
.732 .42097 Mdot
.732 .42152 Mdot
.732 .42215 Mdot
.732 .42243 Mdot
.732 .4225 Mdot
.732 .42362 Mdot
.732 .42412 Mdot
.732 .42553 Mdot
.732 .42659 Mdot
.732 .42672 Mdot
.732 .42685 Mdot
.732 .42723 Mdot
.732 .42958 Mdot
.732 .42966 Mdot
.732 .42976 Mdot
.732 .43047 Mdot
.732 .43179 Mdot
.732 .43233 Mdot
.732 .43264 Mdot
.732 .43299 Mdot
.732 .43564 Mdot
.732 .4359 Mdot
.732 .4361 Mdot
.732 .43616 Mdot
.732 .43652 Mdot
.732 .43673 Mdot
.732 .43676 Mdot
.732 .43701 Mdot
.732 .43711 Mdot
.732 .43736 Mdot
.732 .43781 Mdot
.732 .43974 Mdot
.732 .44128 Mdot
.732 .44147 Mdot
.732 .44224 Mdot
.732 .44419 Mdot
.732 .44432 Mdot
.732 .44447 Mdot
.732 .44579 Mdot
.732 .45146 Mdot
.732 .45334 Mdot
.732 .45377 Mdot
.732 .4539 Mdot
.732 .45403 Mdot
.732 .45426 Mdot
.732 .45436 Mdot
.732 .4545 Mdot
.732 .45761 Mdot
.732 .45893 Mdot
.732 .45919 Mdot
.732 .45926 Mdot
.732 .46053 Mdot
.732 .46079 Mdot
.732 .46186 Mdot
.732 .46214 Mdot
.732 .46337 Mdot
.732 .46486 Mdot
.732 .46508 Mdot
.732 .46583 Mdot
.732 .46624 Mdot
.732 .46641 Mdot
.732 .46682 Mdot
.732 .46686 Mdot
.732 .46721 Mdot
.732 .4678 Mdot
.732 .46789 Mdot
.732 .4679 Mdot
.732 .46823 Mdot
.732 .46866 Mdot
.732 .46955 Mdot
.732 .47023 Mdot
.732 .47034 Mdot
.732 .47034 Mdot
.732 .47036 Mdot
.732 .47036 Mdot
.732 .47038 Mdot
.732 .47119 Mdot
.732 .4716 Mdot
.732 .47213 Mdot
.732 .47254 Mdot
.732 .47292 Mdot
.732 .47348 Mdot
.732 .47387 Mdot
.732 .47398 Mdot
.732 .47406 Mdot
.732 .47421 Mdot
.732 .47421 Mdot
.732 .47483 Mdot
.732 .47555 Mdot
.732 .47556 Mdot
.732 .47576 Mdot
.732 .47578 Mdot
.732 .47579 Mdot
.732 .47602 Mdot
.732 .47682 Mdot
.732 .47689 Mdot
.732 .47695 Mdot
.732 .47801 Mdot
.732 .47816 Mdot
.732 .47818 Mdot
.732 .47828 Mdot
.732 .47845 Mdot
.732 .47872 Mdot
.732 .47977 Mdot
.732 .47992 Mdot
.732 .48055 Mdot
.732 .48074 Mdot
.732 .48129 Mdot
.732 .48189 Mdot
.732 .48247 Mdot
.732 .48248 Mdot
.732 .48267 Mdot
.732 .48273 Mdot
.732 .48287 Mdot
.732 .48363 Mdot
.732 .48442 Mdot
.732 .48445 Mdot
.732 .48475 Mdot
.732 .48483 Mdot
.732 .48649 Mdot
.732 .48656 Mdot
.732 .48689 Mdot
.732 .4873 Mdot
.732 .48784 Mdot
.732 .48803 Mdot
.732 .48843 Mdot
.732 .48895 Mdot
.732 .48905 Mdot
.732 .48924 Mdot
.732 .48945 Mdot
.732 .48999 Mdot
.732 .49011 Mdot
.732 .49037 Mdot
.732 .49058 Mdot
.732 .49115 Mdot
.732 .49151 Mdot
.732 .49228 Mdot
.732 .4923 Mdot
.732 .49243 Mdot
.732 .49339 Mdot
.732 .49356 Mdot
.732 .49395 Mdot
.732 .49417 Mdot
.732 .49464 Mdot
.732 .49521 Mdot
.732 .49538 Mdot
.732 .49646 Mdot
.732 .49647 Mdot
.732 .4969 Mdot
.732 .49876 Mdot
.732 .49896 Mdot
.732 .4991 Mdot
.732 .49937 Mdot
.732 .49946 Mdot
.732 .49965 Mdot
.732 .50139 Mdot
.732 .50174 Mdot
.732 .50202 Mdot
.732 .50238 Mdot
.732 .50251 Mdot
.732 .50267 Mdot
.732 .50296 Mdot
.732 .50406 Mdot
.732 .50418 Mdot
.732 .50458 Mdot
.732 .50513 Mdot
.732 .50553 Mdot
.732 .50575 Mdot
.732 .50669 Mdot
.732 .50692 Mdot
.732 .50694 Mdot
.732 .50734 Mdot
.732 .50769 Mdot
.732 .50781 Mdot
.732 .5085 Mdot
.732 .50893 Mdot
.732 .50927 Mdot
.732 .51079 Mdot
.732 .51081 Mdot
.732 .51081 Mdot
.732 .51126 Mdot
.732 .5115 Mdot
.732 .51152 Mdot
.732 .51206 Mdot
.732 .51243 Mdot
.732 .51291 Mdot
.732 .51296 Mdot
.732 .51299 Mdot
.732 .51328 Mdot
.732 .51328 Mdot
.732 .51332 Mdot
.732 .51332 Mdot
.732 .51337 Mdot
.732 .51354 Mdot
.732 .514 Mdot
.732 .51412 Mdot
.732 .51438 Mdot
.732 .51542 Mdot
.732 .51568 Mdot
.732 .51578 Mdot
.732 .5159 Mdot
.732 .51594 Mdot
.732 .51637 Mdot
.732 .51644 Mdot
.732 .51777 Mdot
.732 .51781 Mdot
.732 .51802 Mdot
.732 .51878 Mdot
.732 .5197 Mdot
.732 .51971 Mdot
.732 .51976 Mdot
.732 .52008 Mdot
.732 .52017 Mdot
.732 .521 Mdot
.732 .52105 Mdot
.732 .52107 Mdot
.732 .52162 Mdot
.732 .52199 Mdot
.732 .52226 Mdot
.732 .52246 Mdot
.732 .52257 Mdot
.732 .52273 Mdot
.732 .52281 Mdot
.732 .52281 Mdot
.732 .52305 Mdot
.732 .52365 Mdot
.732 .52428 Mdot
.732 .52478 Mdot
.732 .52518 Mdot
.732 .52534 Mdot
.732 .52565 Mdot
.732 .52566 Mdot
.732 .52597 Mdot
.732 .526 Mdot
.732 .52604 Mdot
.732 .52646 Mdot
.732 .5265 Mdot
.732 .52653 Mdot
.732 .52707 Mdot
.732 .52728 Mdot
.732 .52729 Mdot
.732 .52832 Mdot
.732 .52888 Mdot
.732 .52905 Mdot
.732 .52919 Mdot
.732 .52948 Mdot
.732 .53092 Mdot
.732 .53119 Mdot
.732 .53151 Mdot
.732 .53156 Mdot
.732 .53177 Mdot
.732 .53189 Mdot
.732 .53193 Mdot
.732 .53216 Mdot
.732 .53234 Mdot
.732 .53235 Mdot
.732 .53251 Mdot
.732 .53306 Mdot
.732 .53312 Mdot
.732 .53365 Mdot
.732 .53375 Mdot
.732 .53377 Mdot
.732 .53395 Mdot
.732 .53398 Mdot
.732 .53456 Mdot
.732 .5349 Mdot
.732 .53537 Mdot
.732 .53555 Mdot
.732 .53568 Mdot
.732 .53579 Mdot
.732 .53634 Mdot
.732 .53684 Mdot
.732 .53684 Mdot
.732 .53702 Mdot
.732 .53741 Mdot
.732 .53774 Mdot
.732 .53774 Mdot
.732 .53854 Mdot
.732 .53881 Mdot
.732 .53882 Mdot
.732 .53929 Mdot
.732 .5393 Mdot
.732 .53977 Mdot
.732 .54061 Mdot
.732 .54093 Mdot
.732 .54094 Mdot
.732 .54132 Mdot
.732 .54144 Mdot
.732 .54171 Mdot
.732 .54205 Mdot
.732 .54223 Mdot
.732 .54232 Mdot
.732 .54237 Mdot
.732 .54265 Mdot
.732 .54283 Mdot
.732 .54307 Mdot
.732 .5431 Mdot
.732 .54319 Mdot
.732 .5432 Mdot
.732 .54426 Mdot
.732 .54428 Mdot
.732 .54469 Mdot
.732 .54476 Mdot
.732 .54509 Mdot
.732 .54531 Mdot
.732 .54546 Mdot
.732 .54604 Mdot
.732 .54645 Mdot
.732 .54654 Mdot
.732 .54694 Mdot
.732 .547 Mdot
.732 .54723 Mdot
.732 .5477 Mdot
.732 .54786 Mdot
.732 .54793 Mdot
.732 .54843 Mdot
.732 .54848 Mdot
.732 .54856 Mdot
.732 .5486 Mdot
.732 .54908 Mdot
.732 .54918 Mdot
.732 .54918 Mdot
.732 .54947 Mdot
.732 .54971 Mdot
.732 .54976 Mdot
.732 .54989 Mdot
.732 .55011 Mdot
.732 .55014 Mdot
.732 .55014 Mdot
.732 .55031 Mdot
.732 .55052 Mdot
.732 .55062 Mdot
.732 .55065 Mdot
.732 .55082 Mdot
.732 .551 Mdot
.732 .55108 Mdot
.732 .55112 Mdot
.732 .55133 Mdot
.732 .55142 Mdot
.732 .55178 Mdot
.732 .55179 Mdot
.732 .55186 Mdot
.732 .55203 Mdot
.732 .55222 Mdot
.732 .55228 Mdot
.732 .55253 Mdot
.732 .55264 Mdot
.732 .55268 Mdot
.732 .55281 Mdot
.732 .55284 Mdot
.732 .55306 Mdot
.732 .55311 Mdot
.732 .55317 Mdot
.732 .55342 Mdot
.732 .55345 Mdot
.732 .55361 Mdot
.732 .55366 Mdot
.732 .55366 Mdot
.732 .55366 Mdot
.732 .5537 Mdot
.732 .55371 Mdot
.732 .55398 Mdot
.732 .55398 Mdot
.732 .554 Mdot
.732 .55404 Mdot
.732 .55431 Mdot
.732 .55439 Mdot
.732 .55449 Mdot
.732 .55457 Mdot
.732 .55473 Mdot
.732 .55474 Mdot
.732 .55474 Mdot
.732 .55474 Mdot
.732 .55474 Mdot
.732 .55476 Mdot
.732 .55489 Mdot
.732 .55522 Mdot
.732 .5558 Mdot
.732 .55608 Mdot
.732 .55631 Mdot
.732 .55656 Mdot
.732 .55661 Mdot
.732 .55686 Mdot
.732 .55771 Mdot
.732 .55774 Mdot
.732 .55782 Mdot
.732 .55792 Mdot
.732 .55925 Mdot
.732 .55947 Mdot
.732 .5595 Mdot
.732 .55952 Mdot
.732 .55985 Mdot
.732 .55999 Mdot
.732 .56028 Mdot
.732 .56067 Mdot
.732 .56072 Mdot
.732 .56078 Mdot
.732 .56087 Mdot
.732 .56139 Mdot
.732 .56145 Mdot
.732 .5615 Mdot
.732 .56159 Mdot
.732 .5618 Mdot
.732 .56193 Mdot
.732 .56195 Mdot
.732 .56238 Mdot
.732 .56259 Mdot
.732 .56307 Mdot
.732 .56308 Mdot
.732 .56312 Mdot
.732 .56357 Mdot
.732 .56376 Mdot
.732 .56454 Mdot
.732 .56524 Mdot
.732 .56551 Mdot
.732 .56551 Mdot
.732 .56551 Mdot
.732 .56559 Mdot
.732 .5657 Mdot
.732 .56576 Mdot
.732 .56583 Mdot
.732 .56589 Mdot
.732 .56609 Mdot
.732 .5661 Mdot
.732 .56617 Mdot
.732 .56635 Mdot
.732 .56637 Mdot
.732 .56675 Mdot
.732 .56727 Mdot
.732 .56729 Mdot
.732 .56733 Mdot
.732 .56783 Mdot
.732 .56806 Mdot
.732 .56811 Mdot
.732 .56814 Mdot
.732 .56832 Mdot
.732 .5684 Mdot
.732 .56844 Mdot
.732 .56845 Mdot
.732 .56857 Mdot
.732 .56866 Mdot
.732 .56878 Mdot
.732 .56898 Mdot
.732 .56913 Mdot
.732 .56964 Mdot
.732 .56967 Mdot
.732 .56974 Mdot
.732 .56977 Mdot
.732 .56979 Mdot
.732 .56996 Mdot
.732 .57024 Mdot
.732 .57051 Mdot
.732 .57054 Mdot
.732 .57055 Mdot
.732 .57075 Mdot
.732 .57076 Mdot
.732 .57081 Mdot
.732 .57085 Mdot
.732 .57093 Mdot
.732 .57096 Mdot
.732 .57101 Mdot
.732 .57102 Mdot
.732 .57115 Mdot
.732 .57126 Mdot
.732 .5713 Mdot
.732 .57131 Mdot
.732 .57138 Mdot
.732 .57141 Mdot
.732 .57147 Mdot
.732 .57152 Mdot
.732 .57155 Mdot
.732 .57156 Mdot
.732 .57156 Mdot
.732 .57156 Mdot
.732 .57157 Mdot
.732 .57157 Mdot
.732 .57162 Mdot
.732 .57162 Mdot
.732 .57163 Mdot
.732 .57163 Mdot
.732 .5717 Mdot
.732 .57173 Mdot
.732 .57176 Mdot
.732 .57176 Mdot
.732 .57176 Mdot
.732 .57177 Mdot
.732 .57177 Mdot
.732 .57177 Mdot
.734 .127 Mdot
.734 .12704 Mdot
.734 .12705 Mdot
.734 .12705 Mdot
.734 .12705 Mdot
.734 .12709 Mdot
.734 .12711 Mdot
.734 .12714 Mdot
.734 .12715 Mdot
.734 .12715 Mdot
.734 .12734 Mdot
.734 .12748 Mdot
.734 .12751 Mdot
.734 .12775 Mdot
.734 .12786 Mdot
.734 .12799 Mdot
.734 .12818 Mdot
.734 .12826 Mdot
.734 .12839 Mdot
.734 .1285 Mdot
.734 .12906 Mdot
.734 .12908 Mdot
.734 .12915 Mdot
.734 .12919 Mdot
.734 .12926 Mdot
.734 .12964 Mdot
.734 .12975 Mdot
.734 .12984 Mdot
.734 .13002 Mdot
.734 .13008 Mdot
.734 .1301 Mdot
.734 .13033 Mdot
.734 .13138 Mdot
.734 .13139 Mdot
.734 .13157 Mdot
.734 .13192 Mdot
.734 .13225 Mdot
.734 .13227 Mdot
.734 .13256 Mdot
.734 .13303 Mdot
.734 .13319 Mdot
.734 .13328 Mdot
.734 .1337 Mdot
.734 .13409 Mdot
.734 .13449 Mdot
.734 .13499 Mdot
.734 .13502 Mdot
.734 .13577 Mdot
.734 .1372 Mdot
.734 .13731 Mdot
.734 .13852 Mdot
.734 .13883 Mdot
.734 .13943 Mdot
.734 .13945 Mdot
.734 .13951 Mdot
.734 .13974 Mdot
.734 .14008 Mdot
.734 .1402 Mdot
.734 .14049 Mdot
.734 .14057 Mdot
.734 .14124 Mdot
.734 .14137 Mdot
.734 .14242 Mdot
.734 .14387 Mdot
.734 .14418 Mdot
.734 .14431 Mdot
.734 .14476 Mdot
.734 .1449 Mdot
.734 .14501 Mdot
.734 .14526 Mdot
.734 .14564 Mdot
.734 .14581 Mdot
.734 .14588 Mdot
.734 .14618 Mdot
.734 .14638 Mdot
.734 .14757 Mdot
.734 .1478 Mdot
.734 .14828 Mdot
.734 .1491 Mdot
.734 .14951 Mdot
.734 .14996 Mdot
.734 .15 Mdot
.734 .15014 Mdot
.734 .15027 Mdot
.734 .15028 Mdot
.734 .15035 Mdot
.734 .15088 Mdot
.734 .15175 Mdot
.734 .15207 Mdot
.734 .15218 Mdot
.734 .15339 Mdot
.734 .1534 Mdot
.734 .15358 Mdot
.734 .1538 Mdot
.734 .15421 Mdot
.734 .15421 Mdot
.734 .15491 Mdot
.734 .15505 Mdot
.734 .15643 Mdot
.734 .15753 Mdot
.734 .15852 Mdot
.734 .15855 Mdot
.734 .1605 Mdot
.734 .16178 Mdot
.734 .16179 Mdot
.734 .16458 Mdot
.734 .16652 Mdot
.734 .16819 Mdot
.734 .17094 Mdot
.734 .17255 Mdot
.734 .17414 Mdot
.734 .17475 Mdot
.734 .17489 Mdot
.734 .17576 Mdot
.734 .17715 Mdot
.734 .1794 Mdot
.734 .17962 Mdot
.734 .17963 Mdot
.734 .17964 Mdot
.734 .17964 Mdot
.734 .17985 Mdot
.734 .17986 Mdot
.734 .17989 Mdot
.734 .17991 Mdot
.734 .1801 Mdot
.734 .18011 Mdot
.734 .18013 Mdot
.734 .18107 Mdot
.734 .18174 Mdot
.734 .18188 Mdot
.734 .18296 Mdot
.734 .18306 Mdot
.734 .18349 Mdot
.734 .18358 Mdot
.734 .18387 Mdot
.734 .18415 Mdot
.734 .1842 Mdot
.734 .18515 Mdot
.734 .18556 Mdot
.734 .18572 Mdot
.734 .1862 Mdot
.734 .18654 Mdot
.734 .18678 Mdot
.734 .18712 Mdot
.734 .18792 Mdot
.734 .18925 Mdot
.734 .18959 Mdot
.734 .1896 Mdot
.734 .1897 Mdot
.734 .18972 Mdot
.734 .19006 Mdot
.734 .19027 Mdot
.734 .19033 Mdot
.734 .19063 Mdot
.734 .19064 Mdot
.734 .1914 Mdot
.734 .19259 Mdot
.734 .1927 Mdot
.734 .19315 Mdot
.734 .19331 Mdot
.734 .19361 Mdot
.734 .19378 Mdot
.734 .19456 Mdot
.734 .19486 Mdot
.734 .19501 Mdot
.734 .19616 Mdot
.734 .1962 Mdot
.734 .19625 Mdot
.734 .19677 Mdot
.734 .19963 Mdot
.734 .20061 Mdot
.734 .20088 Mdot
.734 .20185 Mdot
.734 .20192 Mdot
.734 .20229 Mdot
.734 .20286 Mdot
.734 .20322 Mdot
.734 .2037 Mdot
.734 .20479 Mdot
.734 .20614 Mdot
.734 .20662 Mdot
.734 .20672 Mdot
.734 .20746 Mdot
.734 .20836 Mdot
.734 .20935 Mdot
.734 .20946 Mdot
.734 .20999 Mdot
.734 .211 Mdot
.734 .21132 Mdot
.734 .21189 Mdot
.734 .21225 Mdot
.734 .21244 Mdot
.734 .2133 Mdot
.734 .21481 Mdot
.734 .21487 Mdot
.734 .21704 Mdot
.734 .21807 Mdot
.734 .21939 Mdot
.734 .21949 Mdot
.734 .21983 Mdot
.734 .21987 Mdot
.734 .2223 Mdot
.734 .2225 Mdot
.734 .2226 Mdot
.734 .22304 Mdot
.734 .22658 Mdot
.734 .22696 Mdot
.734 .22699 Mdot
.734 .22783 Mdot
.734 .22833 Mdot
.734 .22937 Mdot
.734 .22949 Mdot
.734 .22954 Mdot
.734 .22994 Mdot
.734 .2323 Mdot
.734 .23284 Mdot
.734 .23374 Mdot
.734 .23481 Mdot
.734 .23488 Mdot
.734 .23559 Mdot
.734 .23625 Mdot
.734 .23665 Mdot
.734 .23803 Mdot
.734 .23825 Mdot
.734 .23863 Mdot
.734 .23882 Mdot
.734 .23913 Mdot
.734 .23928 Mdot
.734 .24184 Mdot
.734 .24252 Mdot
.734 .24377 Mdot
.734 .24439 Mdot
.734 .24571 Mdot
.734 .24592 Mdot
.734 .24946 Mdot
.734 .24957 Mdot
.734 .24999 Mdot
.734 .25122 Mdot
.734 .25144 Mdot
.734 .25273 Mdot
.734 .25358 Mdot
.734 .25392 Mdot
.734 .25406 Mdot
.734 .25434 Mdot
.734 .2544 Mdot
.734 .25516 Mdot
.734 .25553 Mdot
.734 .25617 Mdot
.734 .25669 Mdot
.734 .25748 Mdot
.734 .25896 Mdot
.734 .26101 Mdot
.734 .26145 Mdot
.734 .26153 Mdot
.734 .26184 Mdot
.734 .26266 Mdot
.734 .26351 Mdot
.734 .26702 Mdot
.734 .26864 Mdot
.734 .26941 Mdot
.734 .27292 Mdot
.734 .27339 Mdot
.734 .27476 Mdot
.734 .27506 Mdot
.734 .27567 Mdot
.734 .27792 Mdot
.734 .2781 Mdot
.734 .2796 Mdot
.734 .2799 Mdot
.734 .28011 Mdot
.734 .28019 Mdot
.734 .2803 Mdot
.734 .28105 Mdot
.734 .28322 Mdot
.734 .28333 Mdot
.734 .28395 Mdot
.734 .28403 Mdot
.734 .28441 Mdot
.734 .28473 Mdot
.734 .28495 Mdot
.734 .28502 Mdot
.734 .28562 Mdot
.734 .28731 Mdot
.734 .28889 Mdot
.734 .28982 Mdot
.734 .29094 Mdot
.734 .29144 Mdot
.734 .29212 Mdot
.734 .29343 Mdot
.734 .29396 Mdot
.734 .29451 Mdot
.734 .29479 Mdot
.734 .29758 Mdot
.734 .29906 Mdot
.734 .29927 Mdot
.734 .30069 Mdot
.734 .30165 Mdot
.734 .30272 Mdot
.734 .30414 Mdot
.734 .30428 Mdot
.734 .30635 Mdot
.734 .30639 Mdot
.734 .30693 Mdot
.734 .30746 Mdot
.734 .30749 Mdot
.734 .30754 Mdot
.734 .30869 Mdot
.734 .31057 Mdot
.734 .31162 Mdot
.734 .31302 Mdot
.734 .31492 Mdot
.734 .31576 Mdot
.734 .31664 Mdot
.734 .31702 Mdot
.734 .31881 Mdot
.734 .31907 Mdot
.734 .31923 Mdot
.734 .32005 Mdot
.734 .32027 Mdot
.734 .32081 Mdot
.734 .32092 Mdot
.734 .32097 Mdot
.734 .3214 Mdot
.734 .32323 Mdot
.734 .32457 Mdot
.734 .32503 Mdot
.734 .32569 Mdot
.734 .32604 Mdot
.734 .32761 Mdot
.734 .32826 Mdot
.734 .33084 Mdot
.734 .3321 Mdot
.734 .333 Mdot
.734 .33373 Mdot
.734 .33575 Mdot
.734 .33725 Mdot
.734 .33736 Mdot
.734 .33857 Mdot
.734 .33863 Mdot
.734 .33886 Mdot
.734 .33902 Mdot
.734 .34047 Mdot
.734 .34108 Mdot
.734 .34138 Mdot
.734 .34171 Mdot
.734 .34173 Mdot
.734 .34184 Mdot
.734 .34193 Mdot
.734 .34194 Mdot
.734 .34198 Mdot
.734 .34319 Mdot
.734 .3441 Mdot
.734 .3441 Mdot
.734 .34423 Mdot
.734 .34437 Mdot
.734 .34465 Mdot
.734 .3452 Mdot
.734 .3461 Mdot
.734 .3468 Mdot
.734 .34742 Mdot
.734 .34743 Mdot
.734 .34939 Mdot
.734 .35212 Mdot
.734 .35304 Mdot
.734 .35772 Mdot
.734 .35884 Mdot
.734 .35894 Mdot
.734 .35895 Mdot
.734 .35896 Mdot
.734 .35896 Mdot
.734 .35905 Mdot
.734 .35906 Mdot
.734 .35909 Mdot
.734 .35918 Mdot
.734 .35918 Mdot
.734 .3592 Mdot
.734 .35965 Mdot
.734 .35997 Mdot
.734 .36004 Mdot
.734 .3606 Mdot
.734 .36081 Mdot
.734 .36085 Mdot
.734 .36099 Mdot
.734 .36112 Mdot
.734 .36115 Mdot
.734 .36159 Mdot
.734 .36178 Mdot
.734 .36208 Mdot
.734 .36224 Mdot
.734 .36235 Mdot
.734 .36348 Mdot
.734 .36364 Mdot
.734 .36369 Mdot
.734 .36385 Mdot
.734 .36395 Mdot
.734 .36411 Mdot
.734 .36498 Mdot
.734 .36503 Mdot
.734 .36523 Mdot
.734 .36544 Mdot
.734 .36551 Mdot
.734 .36585 Mdot
.734 .36599 Mdot
.734 .36605 Mdot
.734 .36655 Mdot
.734 .36657 Mdot
.734 .36898 Mdot
.734 .36901 Mdot
.734 .36916 Mdot
.734 .3694 Mdot
.734 .36955 Mdot
.734 .36975 Mdot
.734 .37021 Mdot
.734 .37076 Mdot
.734 .37096 Mdot
.734 .371 Mdot
.734 .3713 Mdot
.734 .37167 Mdot
.734 .37207 Mdot
.734 .37273 Mdot
.734 .37286 Mdot
.734 .37309 Mdot
.734 .37323 Mdot
.734 .3733 Mdot
.734 .37424 Mdot
.734 .37511 Mdot
.734 .37602 Mdot
.734 .37606 Mdot
.734 .37621 Mdot
.734 .37714 Mdot
.734 .37721 Mdot
.734 .37725 Mdot
.734 .37742 Mdot
.734 .37889 Mdot
.734 .37983 Mdot
.734 .37985 Mdot
.734 .38086 Mdot
.734 .38106 Mdot
.734 .3818 Mdot
.734 .38206 Mdot
.734 .3823 Mdot
.734 .38294 Mdot
.734 .38302 Mdot
.734 .38333 Mdot
.734 .38339 Mdot
.734 .38454 Mdot
.734 .38498 Mdot
.734 .38566 Mdot
.734 .38696 Mdot
.734 .387 Mdot
.734 .38715 Mdot
.734 .38757 Mdot
.734 .38765 Mdot
.734 .38838 Mdot
.734 .38864 Mdot
.734 .38892 Mdot
.734 .38904 Mdot
.734 .38926 Mdot
.734 .38944 Mdot
.734 .3909 Mdot
.734 .39118 Mdot
.734 .39173 Mdot
.734 .3929 Mdot
.734 .39343 Mdot
.734 .39369 Mdot
.734 .39484 Mdot
.734 .39646 Mdot
.734 .39652 Mdot
.734 .397 Mdot
.734 .3971 Mdot
.734 .39717 Mdot
.734 .39719 Mdot
.734 .39723 Mdot
.734 .39747 Mdot
.734 .3984 Mdot
.734 .39842 Mdot
.734 .39872 Mdot
.734 .39874 Mdot
.734 .39893 Mdot
.734 .39946 Mdot
.734 .40026 Mdot
.734 .40061 Mdot
.734 .40077 Mdot
.734 .4014 Mdot
.734 .40156 Mdot
.734 .40174 Mdot
.734 .40182 Mdot
.734 .4027 Mdot
.734 .40367 Mdot
.734 .40396 Mdot
.734 .40429 Mdot
.734 .40478 Mdot
.734 .40542 Mdot
.734 .40543 Mdot
.734 .40576 Mdot
.734 .40577 Mdot
.734 .40746 Mdot
.734 .4083 Mdot
.734 .40923 Mdot
.734 .40931 Mdot
.734 .40936 Mdot
.734 .4096 Mdot
.734 .40984 Mdot
.734 .40987 Mdot
.734 .40989 Mdot
.734 .41002 Mdot
.734 .41097 Mdot
.734 .41111 Mdot
.734 .41209 Mdot
.734 .41286 Mdot
.734 .41351 Mdot
.734 .41373 Mdot
.734 .41478 Mdot
.734 .41519 Mdot
.734 .41526 Mdot
.734 .41531 Mdot
.734 .41593 Mdot
.734 .41602 Mdot
.734 .41612 Mdot
.734 .41615 Mdot
.734 .41618 Mdot
.734 .4162 Mdot
.734 .41656 Mdot
.734 .41683 Mdot
.734 .41683 Mdot
.734 .41686 Mdot
.734 .41691 Mdot
.734 .41699 Mdot
.734 .41763 Mdot
.734 .41781 Mdot
.734 .41782 Mdot
.734 .41921 Mdot
.734 .41948 Mdot
.734 .42087 Mdot
.734 .4222 Mdot
.734 .42257 Mdot
.734 .42436 Mdot
.734 .4251 Mdot
.734 .42628 Mdot
.734 .42633 Mdot
.734 .42668 Mdot
.734 .42968 Mdot
.734 .43008 Mdot
.734 .4325 Mdot
.734 .43252 Mdot
.734 .43254 Mdot
.734 .43299 Mdot
.734 .43498 Mdot
.734 .43663 Mdot
.734 .43777 Mdot
.734 .4396 Mdot
.734 .44012 Mdot
.734 .44137 Mdot
.734 .44441 Mdot
.734 .44532 Mdot
.734 .44933 Mdot
.734 .45219 Mdot
.734 .45247 Mdot
.734 .45407 Mdot
.734 .45495 Mdot
.734 .45601 Mdot
.734 .45626 Mdot
.734 .45774 Mdot
.734 .4593 Mdot
.734 .46012 Mdot
.734 .46141 Mdot
.734 .46228 Mdot
.734 .46391 Mdot
.734 .46428 Mdot
.734 .4643 Mdot
.734 .46432 Mdot
.734 .46432 Mdot
.734 .46465 Mdot
.734 .46467 Mdot
.734 .46472 Mdot
.734 .46477 Mdot
.734 .46507 Mdot
.734 .4651 Mdot
.734 .46513 Mdot
.734 .46533 Mdot
.734 .46667 Mdot
.734 .46722 Mdot
.734 .46778 Mdot
.734 .46801 Mdot
.734 .46976 Mdot
.734 .46992 Mdot
.734 .46992 Mdot
.734 .47062 Mdot
.734 .47077 Mdot
.734 .47123 Mdot
.734 .47169 Mdot
.734 .47177 Mdot
.734 .47312 Mdot
.734 .47328 Mdot
.734 .47383 Mdot
.734 .47386 Mdot
.734 .47389 Mdot
.734 .47394 Mdot
.734 .47419 Mdot
.734 .47495 Mdot
.734 .47549 Mdot
.734 .47586 Mdot
.734 .4764 Mdot
.734 .47765 Mdot
.734 .4777 Mdot
.734 .47832 Mdot
.734 .47971 Mdot
.734 .48023 Mdot
.734 .48026 Mdot
.734 .4804 Mdot
.734 .48044 Mdot
.734 .48095 Mdot
.734 .48129 Mdot
.734 .48137 Mdot
.734 .48183 Mdot
.734 .48184 Mdot
.734 .48292 Mdot
.734 .483 Mdot
.734 .48346 Mdot
.734 .48353 Mdot
.734 .48478 Mdot
.734 .48495 Mdot
.734 .4853 Mdot
.734 .48563 Mdot
.734 .48587 Mdot
.734 .48631 Mdot
.734 .4864 Mdot
.734 .48657 Mdot
.734 .48771 Mdot
.734 .48816 Mdot
.734 .48837 Mdot
.734 .48904 Mdot
.734 .48958 Mdot
.734 .49006 Mdot
.734 .49011 Mdot
.734 .49019 Mdot
.734 .49094 Mdot
.734 .49151 Mdot
.734 .49349 Mdot
.734 .49388 Mdot
.734 .49502 Mdot
.734 .49584 Mdot
.734 .49585 Mdot
.734 .4961 Mdot
.734 .4964 Mdot
.734 .49677 Mdot
.734 .49699 Mdot
.734 .49711 Mdot
.734 .49717 Mdot
.734 .49722 Mdot
.734 .49722 Mdot
.734 .4976 Mdot
.734 .49809 Mdot
.734 .49811 Mdot
.734 .49811 Mdot
.734 .49815 Mdot
.734 .4982 Mdot
.734 .49821 Mdot
.734 .49834 Mdot
.734 .49846 Mdot
.734 .49871 Mdot
.734 .49931 Mdot
.734 .49937 Mdot
.734 .49947 Mdot
.734 .49949 Mdot
.734 .49998 Mdot
.734 .50003 Mdot
.734 .50064 Mdot
.734 .50145 Mdot
.734 .50175 Mdot
.734 .50211 Mdot
.734 .50262 Mdot
.734 .50365 Mdot
.734 .50391 Mdot
.734 .50454 Mdot
.734 .50468 Mdot
.734 .50494 Mdot
.734 .50512 Mdot
.734 .50565 Mdot
.734 .50637 Mdot
.734 .50654 Mdot
.734 .50656 Mdot
.734 .5066 Mdot
.734 .50682 Mdot
.734 .5069 Mdot
.734 .50723 Mdot
.734 .50729 Mdot
.734 .50739 Mdot
.734 .50809 Mdot
.734 .50824 Mdot
.734 .50858 Mdot
.734 .50891 Mdot
.734 .50964 Mdot
.734 .51019 Mdot
.734 .51059 Mdot
.734 .51131 Mdot
.734 .51176 Mdot
.734 .51177 Mdot
.734 .51179 Mdot
.734 .51199 Mdot
.734 .5122 Mdot
.734 .51221 Mdot
.734 .513 Mdot
.734 .51305 Mdot
.734 .5136 Mdot
.734 .514 Mdot
.734 .51436 Mdot
.734 .5149 Mdot
.734 .51498 Mdot
.734 .51554 Mdot
.734 .51659 Mdot
.734 .51669 Mdot
.734 .5169 Mdot
.734 .51709 Mdot
.734 .51758 Mdot
.734 .51784 Mdot
.734 .51802 Mdot
.734 .51844 Mdot
.734 .51878 Mdot
.734 .51937 Mdot
.734 .51999 Mdot
.734 .52021 Mdot
.734 .52024 Mdot
.734 .52032 Mdot
.734 .52044 Mdot
.734 .52058 Mdot
.734 .5206 Mdot
.734 .52083 Mdot
.734 .52087 Mdot
.734 .52167 Mdot
.734 .52194 Mdot
.734 .52198 Mdot
.734 .52201 Mdot
.734 .52209 Mdot
.734 .5222 Mdot
.734 .52274 Mdot
.734 .52281 Mdot
.734 .52362 Mdot
.734 .52384 Mdot
.734 .52395 Mdot
.734 .52445 Mdot
.734 .52462 Mdot
.734 .52588 Mdot
.734 .52616 Mdot
.734 .52674 Mdot
.734 .52798 Mdot
.734 .52828 Mdot
.734 .52857 Mdot
.734 .52868 Mdot
.734 .52871 Mdot
.734 .52887 Mdot
.734 .52959 Mdot
.734 .53011 Mdot
.734 .53039 Mdot
.734 .53057 Mdot
.734 .5308 Mdot
.734 .53093 Mdot
.734 .53119 Mdot
.734 .53121 Mdot
.734 .53131 Mdot
.734 .53136 Mdot
.734 .53148 Mdot
.734 .53178 Mdot
.734 .53223 Mdot
.734 .5323 Mdot
.734 .53273 Mdot
.734 .53287 Mdot
.734 .53291 Mdot
.734 .53414 Mdot
.734 .53421 Mdot
.734 .53467 Mdot
.734 .53488 Mdot
.734 .53531 Mdot
.734 .53554 Mdot
.734 .53642 Mdot
.734 .53647 Mdot
.734 .53658 Mdot
.734 .53664 Mdot
.734 .53677 Mdot
.734 .53684 Mdot
.734 .53732 Mdot
.734 .53745 Mdot
.734 .53768 Mdot
.734 .53792 Mdot
.734 .53794 Mdot
.734 .53831 Mdot
.734 .53861 Mdot
.734 .53879 Mdot
.734 .53959 Mdot
.734 .53973 Mdot
.734 .53974 Mdot
.734 .53978 Mdot
.734 .54013 Mdot
.734 .5403 Mdot
.734 .54058 Mdot
.734 .54059 Mdot
.734 .54072 Mdot
.734 .5419 Mdot
.734 .54205 Mdot
.734 .54208 Mdot
.734 .54215 Mdot
.734 .54296 Mdot
.734 .54297 Mdot
.734 .54308 Mdot
.734 .54312 Mdot
.734 .54356 Mdot
.734 .54389 Mdot
.734 .54461 Mdot
.734 .54463 Mdot
.734 .54513 Mdot
.734 .54541 Mdot
.734 .54548 Mdot
.734 .54559 Mdot
.734 .54578 Mdot
.734 .54589 Mdot
.734 .54622 Mdot
.734 .54639 Mdot
.734 .54643 Mdot
.734 .54675 Mdot
.734 .54704 Mdot
.734 .54729 Mdot
.734 .54732 Mdot
.734 .54747 Mdot
.734 .54791 Mdot
.734 .54827 Mdot
.734 .54843 Mdot
.734 .54854 Mdot
.734 .54873 Mdot
.734 .54885 Mdot
.734 .54887 Mdot
.734 .54918 Mdot
.734 .54927 Mdot
.734 .54959 Mdot
.734 .55051 Mdot
.734 .55068 Mdot
.734 .55069 Mdot
.734 .55071 Mdot
.734 .55108 Mdot
.734 .55112 Mdot
.734 .55122 Mdot
.734 .55147 Mdot
.734 .55152 Mdot
.734 .55162 Mdot
.734 .55167 Mdot
.734 .55182 Mdot
.734 .55185 Mdot
.734 .55223 Mdot
.734 .55248 Mdot
.734 .55248 Mdot
.734 .55257 Mdot
.734 .55259 Mdot
.734 .55266 Mdot
.734 .55277 Mdot
.734 .55278 Mdot
.734 .5528 Mdot
.734 .55281 Mdot
.734 .55292 Mdot
.734 .55334 Mdot
.734 .5536 Mdot
.734 .5537 Mdot
.734 .55378 Mdot
.734 .55389 Mdot
.734 .55404 Mdot
.734 .55409 Mdot
.734 .55422 Mdot
.734 .55452 Mdot
.734 .55454 Mdot
.734 .55463 Mdot
.734 .55472 Mdot
.734 .55475 Mdot
.734 .55488 Mdot
.734 .55491 Mdot
.734 .55525 Mdot
.734 .5553 Mdot
.734 .55551 Mdot
.734 .5558 Mdot
.734 .55581 Mdot
.734 .55582 Mdot
.734 .55587 Mdot
.734 .55588 Mdot
.734 .55589 Mdot
.734 .5559 Mdot
.734 .55596 Mdot
.734 .55596 Mdot
.734 .55596 Mdot
.734 .55597 Mdot
.734 .55603 Mdot
.734 .55674 Mdot
.734 .55718 Mdot
.734 .55745 Mdot
.734 .5575 Mdot
.734 .55769 Mdot
.734 .55818 Mdot
.734 .55868 Mdot
.734 .55954 Mdot
.734 .56005 Mdot
.734 .56066 Mdot
.734 .56152 Mdot
.734 .56152 Mdot
.734 .56191 Mdot
.734 .56251 Mdot
.734 .56252 Mdot
.734 .56282 Mdot
.734 .56316 Mdot
.734 .56358 Mdot
.734 .56362 Mdot
.734 .56384 Mdot
.734 .56384 Mdot
.734 .56396 Mdot
.734 .56403 Mdot
.734 .56408 Mdot
.734 .56409 Mdot
.734 .56446 Mdot
.734 .56449 Mdot
.734 .56459 Mdot
.734 .56485 Mdot
.734 .56501 Mdot
.734 .56503 Mdot
.734 .56503 Mdot
.734 .56507 Mdot
.734 .56512 Mdot
.734 .56513 Mdot
.734 .56527 Mdot
.734 .56539 Mdot
.734 .56564 Mdot
.734 .56578 Mdot
.734 .56585 Mdot
.734 .56621 Mdot
.734 .56627 Mdot
.734 .56636 Mdot
.734 .56639 Mdot
.734 .56644 Mdot
.734 .56655 Mdot
.734 .56663 Mdot
.734 .56666 Mdot
.734 .5667 Mdot
.734 .56684 Mdot
.734 .56688 Mdot
.734 .56697 Mdot
.734 .56741 Mdot
.734 .56772 Mdot
.734 .56776 Mdot
.734 .56796 Mdot
.734 .56799 Mdot
.734 .56807 Mdot
.734 .56811 Mdot
.734 .56821 Mdot
.734 .56828 Mdot
.734 .5683 Mdot
.734 .56831 Mdot
.734 .56848 Mdot
.734 .56858 Mdot
.734 .56894 Mdot
.734 .56897 Mdot
.734 .5694 Mdot
.734 .56962 Mdot
.734 .56963 Mdot
.734 .56978 Mdot
.734 .5699 Mdot
.734 .57002 Mdot
.734 .57014 Mdot
.734 .57017 Mdot
.734 .57022 Mdot
.734 .57036 Mdot
.734 .57044 Mdot
.734 .57045 Mdot
.734 .57055 Mdot
.734 .57065 Mdot
.734 .5707 Mdot
.734 .57071 Mdot
.734 .57102 Mdot
.734 .57109 Mdot
.734 .57109 Mdot
.734 .57111 Mdot
.734 .57116 Mdot
.734 .57119 Mdot
.734 .57122 Mdot
.734 .57133 Mdot
.734 .57136 Mdot
.734 .57137 Mdot
.734 .57139 Mdot
.734 .57139 Mdot
.734 .57156 Mdot
.734 .57159 Mdot
.734 .57163 Mdot
.734 .57166 Mdot
.734 .57171 Mdot
.734 .57175 Mdot
.734 .57178 Mdot
.734 .57185 Mdot
.734 .57186 Mdot
.734 .5719 Mdot
.734 .57196 Mdot
.734 .57196 Mdot
.734 .57196 Mdot
.734 .57198 Mdot
.734 .57199 Mdot
.734 .57199 Mdot
.734 .57199 Mdot
.734 .57199 Mdot
.734 .572 Mdot
.736 .12625 Mdot
.736 .12627 Mdot
.736 .12633 Mdot
.736 .1266 Mdot
.736 .12663 Mdot
.736 .1267 Mdot
.736 .12673 Mdot
.736 .12674 Mdot
.736 .12684 Mdot
.736 .12689 Mdot
.736 .12714 Mdot
.736 .12728 Mdot
.736 .12729 Mdot
.736 .12737 Mdot
.736 .12748 Mdot
.736 .12766 Mdot
.736 .12788 Mdot
.736 .12834 Mdot
.736 .12855 Mdot
.736 .12885 Mdot
.736 .12897 Mdot
.736 .12934 Mdot
.736 .12971 Mdot
.736 .12973 Mdot
.736 .1301 Mdot
.736 .13034 Mdot
.736 .13038 Mdot
.736 .13071 Mdot
.736 .1308 Mdot
.736 .13087 Mdot
.736 .13116 Mdot
.736 .13142 Mdot
.736 .13151 Mdot
.736 .13161 Mdot
.736 .13175 Mdot
.736 .13297 Mdot
.736 .1332 Mdot
.736 .13379 Mdot
.736 .13387 Mdot
.736 .13404 Mdot
.736 .13456 Mdot
.736 .13481 Mdot
.736 .13518 Mdot
.736 .13538 Mdot
.736 .13595 Mdot
.736 .13622 Mdot
.736 .13666 Mdot
.736 .13699 Mdot
.736 .13802 Mdot
.736 .13862 Mdot
.736 .13895 Mdot
.736 .13933 Mdot
.736 .1397 Mdot
.736 .1397 Mdot
.736 .14024 Mdot
.736 .14034 Mdot
.736 .14062 Mdot
.736 .1417 Mdot
.736 .14202 Mdot
.736 .14218 Mdot
.736 .14338 Mdot
.736 .14477 Mdot
.736 .14522 Mdot
.736 .14534 Mdot
.736 .1457 Mdot
.736 .14696 Mdot
.736 .14703 Mdot
.736 .1472 Mdot
.736 .14835 Mdot
.736 .14944 Mdot
.736 .14968 Mdot
.736 .15109 Mdot
.736 .15124 Mdot
.736 .15194 Mdot
.736 .15249 Mdot
.736 .15506 Mdot
.736 .15531 Mdot
.736 .15632 Mdot
.736 .15728 Mdot
.736 .1575 Mdot
.736 .15883 Mdot
.736 .16019 Mdot
.736 .16105 Mdot
.736 .16129 Mdot
.736 .1625 Mdot
.736 .16294 Mdot
.736 .16387 Mdot
.736 .16407 Mdot
.736 .16436 Mdot
.736 .16494 Mdot
.736 .16517 Mdot
.736 .16535 Mdot
.736 .16569 Mdot
.736 .16773 Mdot
.736 .16813 Mdot
.736 .16948 Mdot
.736 .16965 Mdot
.736 .17086 Mdot
.736 .17115 Mdot
.736 .17288 Mdot
.736 .17302 Mdot
.736 .17475 Mdot
.736 .17549 Mdot
.736 .17558 Mdot
.736 .17588 Mdot
.736 .17713 Mdot
.736 .17726 Mdot
.736 .17763 Mdot
.736 .17775 Mdot
.736 .17781 Mdot
.736 .17811 Mdot
.736 .17812 Mdot
.736 .17827 Mdot
.736 .1785 Mdot
.736 .17888 Mdot
.736 .17974 Mdot
.736 .17991 Mdot
.736 .18038 Mdot
.736 .1804 Mdot
.736 .18046 Mdot
.736 .1807 Mdot
.736 .18077 Mdot
.736 .18085 Mdot
.736 .18087 Mdot
.736 .18138 Mdot
.736 .1814 Mdot
.736 .18163 Mdot
.736 .18223 Mdot
.736 .18253 Mdot
.736 .18334 Mdot
.736 .18334 Mdot
.736 .18393 Mdot
.736 .18397 Mdot
.736 .18415 Mdot
.736 .18492 Mdot
.736 .18561 Mdot
.736 .18666 Mdot
.736 .18722 Mdot
.736 .18823 Mdot
.736 .18864 Mdot
.736 .18882 Mdot
.736 .1891 Mdot
.736 .18958 Mdot
.736 .18993 Mdot
.736 .19042 Mdot
.736 .1907 Mdot
.736 .19081 Mdot
.736 .19112 Mdot
.736 .19163 Mdot
.736 .19267 Mdot
.736 .19275 Mdot
.736 .1932 Mdot
.736 .19357 Mdot
.736 .19372 Mdot
.736 .1947 Mdot
.736 .19497 Mdot
.736 .19598 Mdot
.736 .1962 Mdot
.736 .19643 Mdot
.736 .19645 Mdot
.736 .1965 Mdot
.736 .19792 Mdot
.736 .19842 Mdot
.736 .19881 Mdot
.736 .19929 Mdot
.736 .19954 Mdot
.736 .2004 Mdot
.736 .20143 Mdot
.736 .20177 Mdot
.736 .20201 Mdot
.736 .2023 Mdot
.736 .20269 Mdot
.736 .20272 Mdot
.736 .20282 Mdot
.736 .20316 Mdot
.736 .20359 Mdot
.736 .20573 Mdot
.736 .20592 Mdot
.736 .20694 Mdot
.736 .20782 Mdot
.736 .20937 Mdot
.736 .20947 Mdot
.736 .21021 Mdot
.736 .21027 Mdot
.736 .21044 Mdot
.736 .21176 Mdot
.736 .21295 Mdot
.736 .21333 Mdot
.736 .21512 Mdot
.736 .21558 Mdot
.736 .21659 Mdot
.736 .21722 Mdot
.736 .21922 Mdot
.736 .2196 Mdot
.736 .22107 Mdot
.736 .22266 Mdot
.736 .22327 Mdot
.736 .22372 Mdot
.736 .22399 Mdot
.736 .22447 Mdot
.736 .22506 Mdot
.736 .22661 Mdot
.736 .2276 Mdot
.736 .22776 Mdot
.736 .22789 Mdot
.736 .22948 Mdot
.736 .22953 Mdot
.736 .23011 Mdot
.736 .23218 Mdot
.736 .23418 Mdot
.736 .23468 Mdot
.736 .238 Mdot
.736 .23863 Mdot
.736 .24004 Mdot
.736 .24054 Mdot
.736 .24262 Mdot
.736 .24414 Mdot
.736 .24429 Mdot
.736 .24535 Mdot
.736 .24572 Mdot
.736 .24634 Mdot
.736 .24711 Mdot
.736 .24873 Mdot
.736 .24976 Mdot
.736 .25106 Mdot
.736 .25108 Mdot
.736 .25109 Mdot
.736 .25172 Mdot
.736 .25342 Mdot
.736 .25356 Mdot
.736 .25395 Mdot
.736 .25454 Mdot
.736 .25518 Mdot
.736 .25671 Mdot
.736 .25699 Mdot
.736 .25825 Mdot
.736 .25863 Mdot
.736 .25913 Mdot
.736 .26119 Mdot
.736 .26207 Mdot
.736 .26393 Mdot
.736 .266 Mdot
.736 .26629 Mdot
.736 .26675 Mdot
.736 .26691 Mdot
.736 .26703 Mdot
.736 .26853 Mdot
.736 .27 Mdot
.736 .27082 Mdot
.736 .27096 Mdot
.736 .27221 Mdot
.736 .27407 Mdot
.736 .27492 Mdot
.736 .27783 Mdot
.736 .27899 Mdot
.736 .28187 Mdot
.736 .28359 Mdot
.736 .28409 Mdot
.736 .2848 Mdot
.736 .28511 Mdot
.736 .2871 Mdot
.736 .28786 Mdot
.736 .29029 Mdot
.736 .29112 Mdot
.736 .29311 Mdot
.736 .29332 Mdot
.736 .29523 Mdot
.736 .2953 Mdot
.736 .29571 Mdot
.736 .29636 Mdot
.736 .29783 Mdot
.736 .29807 Mdot
.736 .29874 Mdot
.736 .29922 Mdot
.736 .30036 Mdot
.736 .30209 Mdot
.736 .30213 Mdot
.736 .3036 Mdot
.736 .30431 Mdot
.736 .30485 Mdot
.736 .30806 Mdot
.736 .30872 Mdot
.736 .31099 Mdot
.736 .31302 Mdot
.736 .31359 Mdot
.736 .31377 Mdot
.736 .31422 Mdot
.736 .31543 Mdot
.736 .31621 Mdot
.736 .31655 Mdot
.736 .31706 Mdot
.736 .32093 Mdot
.736 .32164 Mdot
.736 .32333 Mdot
.736 .32348 Mdot
.736 .32359 Mdot
.736 .32405 Mdot
.736 .32443 Mdot
.736 .32458 Mdot
.736 .32661 Mdot
.736 .32765 Mdot
.736 .32796 Mdot
.736 .32858 Mdot
.736 .32888 Mdot
.736 .3293 Mdot
.736 .32953 Mdot
.736 .33046 Mdot
.736 .33128 Mdot
.736 .33233 Mdot
.736 .3336 Mdot
.736 .33395 Mdot
.736 .33454 Mdot
.736 .3348 Mdot
.736 .33575 Mdot
.736 .33603 Mdot
.736 .33718 Mdot
.736 .33831 Mdot
.736 .33867 Mdot
.736 .33876 Mdot
.736 .34002 Mdot
.736 .34007 Mdot
.736 .34105 Mdot
.736 .34184 Mdot
.736 .34201 Mdot
.736 .34301 Mdot
.736 .34359 Mdot
.736 .34567 Mdot
.736 .34647 Mdot
.736 .34885 Mdot
.736 .34936 Mdot
.736 .35021 Mdot
.736 .35047 Mdot
.736 .35161 Mdot
.736 .35184 Mdot
.736 .35316 Mdot
.736 .35337 Mdot
.736 .35419 Mdot
.736 .35483 Mdot
.736 .35499 Mdot
.736 .35589 Mdot
.736 .35722 Mdot
.736 .35726 Mdot
.736 .35742 Mdot
.736 .35804 Mdot
.736 .35811 Mdot
.736 .35829 Mdot
.736 .35835 Mdot
.736 .35838 Mdot
.736 .35853 Mdot
.736 .35853 Mdot
.736 .3586 Mdot
.736 .35872 Mdot
.736 .35932 Mdot
.736 .35963 Mdot
.736 .35964 Mdot
.736 .35967 Mdot
.736 .35982 Mdot
.736 .35986 Mdot
.736 .35987 Mdot
.736 .36012 Mdot
.736 .36012 Mdot
.736 .36023 Mdot
.736 .36052 Mdot
.736 .36066 Mdot
.736 .36105 Mdot
.736 .36134 Mdot
.736 .36143 Mdot
.736 .36179 Mdot
.736 .36211 Mdot
.736 .36259 Mdot
.736 .36331 Mdot
.736 .36358 Mdot
.736 .36371 Mdot
.736 .36392 Mdot
.736 .3643 Mdot
.736 .36442 Mdot
.736 .36484 Mdot
.736 .3653 Mdot
.736 .36534 Mdot
.736 .36553 Mdot
.736 .36569 Mdot
.736 .36576 Mdot
.736 .36619 Mdot
.736 .36674 Mdot
.736 .36684 Mdot
.736 .36758 Mdot
.736 .36779 Mdot
.736 .36796 Mdot
.736 .36816 Mdot
.736 .36863 Mdot
.736 .36906 Mdot
.736 .36921 Mdot
.736 .36943 Mdot
.736 .36959 Mdot
.736 .3696 Mdot
.736 .36965 Mdot
.736 .36979 Mdot
.736 .36996 Mdot
.736 .37084 Mdot
.736 .37134 Mdot
.736 .37236 Mdot
.736 .37266 Mdot
.736 .37275 Mdot
.736 .37327 Mdot
.736 .37459 Mdot
.736 .37477 Mdot
.736 .37517 Mdot
.736 .37618 Mdot
.736 .37633 Mdot
.736 .37689 Mdot
.736 .37772 Mdot
.736 .37789 Mdot
.736 .37818 Mdot
.736 .37839 Mdot
.736 .37897 Mdot
.736 .37934 Mdot
.736 .37945 Mdot
.736 .38005 Mdot
.736 .38027 Mdot
.736 .38103 Mdot
.736 .38175 Mdot
.736 .38193 Mdot
.736 .38312 Mdot
.736 .38403 Mdot
.736 .38476 Mdot
.736 .3853 Mdot
.736 .38535 Mdot
.736 .38572 Mdot
.736 .38606 Mdot
.736 .38633 Mdot
.736 .38689 Mdot
.736 .38725 Mdot
.736 .3877 Mdot
.736 .38771 Mdot
.736 .38771 Mdot
.736 .38869 Mdot
.736 .38889 Mdot
.736 .3891 Mdot
.736 .38962 Mdot
.736 .38972 Mdot
.736 .39113 Mdot
.736 .39204 Mdot
.736 .39273 Mdot
.736 .39282 Mdot
.736 .39303 Mdot
.736 .39307 Mdot
.736 .39436 Mdot
.736 .39565 Mdot
.736 .39659 Mdot
.736 .39788 Mdot
.736 .39859 Mdot
.736 .39892 Mdot
.736 .39955 Mdot
.736 .39979 Mdot
.736 .40055 Mdot
.736 .4015 Mdot
.736 .4021 Mdot
.736 .40212 Mdot
.736 .40225 Mdot
.736 .40299 Mdot
.736 .4032 Mdot
.736 .40335 Mdot
.736 .4037 Mdot
.736 .40424 Mdot
.736 .40425 Mdot
.736 .40492 Mdot
.736 .40607 Mdot
.736 .40697 Mdot
.736 .40796 Mdot
.736 .40833 Mdot
.736 .40882 Mdot
.736 .40999 Mdot
.736 .41072 Mdot
.736 .41076 Mdot
.736 .4108 Mdot
.736 .41094 Mdot
.736 .41105 Mdot
.736 .41171 Mdot
.736 .412 Mdot
.736 .41202 Mdot
.736 .41239 Mdot
.736 .41252 Mdot
.736 .41259 Mdot
.736 .41286 Mdot
.736 .41311 Mdot
.736 .41342 Mdot
.736 .4138 Mdot
.736 .41391 Mdot
.736 .41408 Mdot
.736 .41416 Mdot
.736 .41453 Mdot
.736 .41572 Mdot
.736 .41631 Mdot
.736 .41678 Mdot
.736 .4174 Mdot
.736 .41834 Mdot
.736 .41882 Mdot
.736 .41916 Mdot
.736 .41968 Mdot
.736 .41992 Mdot
.736 .42016 Mdot
.736 .42042 Mdot
.736 .4212 Mdot
.736 .4212 Mdot
.736 .42167 Mdot
.736 .4217 Mdot
.736 .42203 Mdot
.736 .42216 Mdot
.736 .42273 Mdot
.736 .42279 Mdot
.736 .42291 Mdot
.736 .42332 Mdot
.736 .42404 Mdot
.736 .42446 Mdot
.736 .42452 Mdot
.736 .42498 Mdot
.736 .42706 Mdot
.736 .42909 Mdot
.736 .42967 Mdot
.736 .43009 Mdot
.736 .43037 Mdot
.736 .43131 Mdot
.736 .43176 Mdot
.736 .43281 Mdot
.736 .43406 Mdot
.736 .43432 Mdot
.736 .4349 Mdot
.736 .43662 Mdot
.736 .43669 Mdot
.736 .43672 Mdot
.736 .43701 Mdot
.736 .43712 Mdot
.736 .43755 Mdot
.736 .43844 Mdot
.736 .43862 Mdot
.736 .43891 Mdot
.736 .43905 Mdot
.736 .43938 Mdot
.736 .43977 Mdot
.736 .44002 Mdot
.736 .44025 Mdot
.736 .44375 Mdot
.736 .44447 Mdot
.736 .44448 Mdot
.736 .44461 Mdot
.736 .44542 Mdot
.736 .44557 Mdot
.736 .44692 Mdot
.736 .44722 Mdot
.736 .4493 Mdot
.736 .44938 Mdot
.736 .44983 Mdot
.736 .4499 Mdot
.736 .45222 Mdot
.736 .45247 Mdot
.736 .45294 Mdot
.736 .45319 Mdot
.736 .4539 Mdot
.736 .45411 Mdot
.736 .45413 Mdot
.736 .45539 Mdot
.736 .45619 Mdot
.736 .45748 Mdot
.736 .45762 Mdot
.736 .45814 Mdot
.736 .46027 Mdot
.736 .46051 Mdot
.736 .46112 Mdot
.736 .46133 Mdot
.736 .46139 Mdot
.736 .46142 Mdot
.736 .46178 Mdot
.736 .46194 Mdot
.736 .46196 Mdot
.736 .4622 Mdot
.736 .4622 Mdot
.736 .46259 Mdot
.736 .46285 Mdot
.736 .46323 Mdot
.736 .4634 Mdot
.736 .46364 Mdot
.736 .46412 Mdot
.736 .46442 Mdot
.736 .46466 Mdot
.736 .46495 Mdot
.736 .46573 Mdot
.736 .46577 Mdot
.736 .46585 Mdot
.736 .46591 Mdot
.736 .46625 Mdot
.736 .46637 Mdot
.736 .46651 Mdot
.736 .46654 Mdot
.736 .4666 Mdot
.736 .46679 Mdot
.736 .46726 Mdot
.736 .46732 Mdot
.736 .46739 Mdot
.736 .4674 Mdot
.736 .46742 Mdot
.736 .46778 Mdot
.736 .46877 Mdot
.736 .46925 Mdot
.736 .47024 Mdot
.736 .47057 Mdot
.736 .47057 Mdot
.736 .47117 Mdot
.736 .47152 Mdot
.736 .47158 Mdot
.736 .47159 Mdot
.736 .47188 Mdot
.736 .47311 Mdot
.736 .4736 Mdot
.736 .47421 Mdot
.736 .47525 Mdot
.736 .47587 Mdot
.736 .47597 Mdot
.736 .47676 Mdot
.736 .47745 Mdot
.736 .47788 Mdot
.736 .47833 Mdot
.736 .47854 Mdot
.736 .47896 Mdot
.736 .47924 Mdot
.736 .47943 Mdot
.736 .47968 Mdot
.736 .48042 Mdot
.736 .48096 Mdot
.736 .48171 Mdot
.736 .48213 Mdot
.736 .48229 Mdot
.736 .48255 Mdot
.736 .48278 Mdot
.736 .48354 Mdot
.736 .4851 Mdot
.736 .48523 Mdot
.736 .48568 Mdot
.736 .4859 Mdot
.736 .48636 Mdot
.736 .48645 Mdot
.736 .48645 Mdot
.736 .48668 Mdot
.736 .48707 Mdot
.736 .48812 Mdot
.736 .48815 Mdot
.736 .48852 Mdot
.736 .48875 Mdot
.736 .48891 Mdot
.736 .48901 Mdot
.736 .48983 Mdot
.736 .48999 Mdot
.736 .49003 Mdot
.736 .49032 Mdot
.736 .4905 Mdot
.736 .49055 Mdot
.736 .49066 Mdot
.736 .49068 Mdot
.736 .49076 Mdot
.736 .49123 Mdot
.736 .49123 Mdot
.736 .49235 Mdot
.736 .49273 Mdot
.736 .4928 Mdot
.736 .49307 Mdot
.736 .49341 Mdot
.736 .4935 Mdot
.736 .49406 Mdot
.736 .49415 Mdot
.736 .49463 Mdot
.736 .49474 Mdot
.736 .49509 Mdot
.736 .49531 Mdot
.736 .4963 Mdot
.736 .49663 Mdot
.736 .49749 Mdot
.736 .49773 Mdot
.736 .49814 Mdot
.736 .49821 Mdot
.736 .49853 Mdot
.736 .49893 Mdot
.736 .49896 Mdot
.736 .49947 Mdot
.736 .49951 Mdot
.736 .49965 Mdot
.736 .50011 Mdot
.736 .50058 Mdot
.736 .50069 Mdot
.736 .50108 Mdot
.736 .50118 Mdot
.736 .50142 Mdot
.736 .50156 Mdot
.736 .50207 Mdot
.736 .5025 Mdot
.736 .50282 Mdot
.736 .5032 Mdot
.736 .50329 Mdot
.736 .50346 Mdot
.736 .50358 Mdot
.736 .50382 Mdot
.736 .50395 Mdot
.736 .50397 Mdot
.736 .50436 Mdot
.736 .50517 Mdot
.736 .50523 Mdot
.736 .50538 Mdot
.736 .50556 Mdot
.736 .5056 Mdot
.736 .50566 Mdot
.736 .50633 Mdot
.736 .50661 Mdot
.736 .50812 Mdot
.736 .50832 Mdot
.736 .50846 Mdot
.736 .50876 Mdot
.736 .50923 Mdot
.736 .5094 Mdot
.736 .50947 Mdot
.736 .50969 Mdot
.736 .51048 Mdot
.736 .51135 Mdot
.736 .5116 Mdot
.736 .51283 Mdot
.736 .51303 Mdot
.736 .51331 Mdot
.736 .51387 Mdot
.736 .51388 Mdot
.736 .51454 Mdot
.736 .51496 Mdot
.736 .51515 Mdot
.736 .5154 Mdot
.736 .51549 Mdot
.736 .51604 Mdot
.736 .51629 Mdot
.736 .51644 Mdot
.736 .51647 Mdot
.736 .51718 Mdot
.736 .51726 Mdot
.736 .518 Mdot
.736 .51831 Mdot
.736 .51921 Mdot
.736 .51949 Mdot
.736 .52022 Mdot
.736 .52033 Mdot
.736 .52059 Mdot
.736 .52078 Mdot
.736 .52141 Mdot
.736 .52246 Mdot
.736 .52288 Mdot
.736 .52393 Mdot
.736 .52424 Mdot
.736 .52491 Mdot
.736 .52536 Mdot
.736 .52541 Mdot
.736 .52571 Mdot
.736 .52623 Mdot
.736 .52677 Mdot
.736 .52681 Mdot
.736 .52687 Mdot
.736 .52703 Mdot
.736 .52713 Mdot
.736 .52787 Mdot
.736 .52853 Mdot
.736 .52884 Mdot
.736 .52957 Mdot
.736 .52975 Mdot
.736 .52988 Mdot
.736 .53032 Mdot
.736 .53042 Mdot
.736 .53095 Mdot
.736 .53118 Mdot
.736 .53138 Mdot
.736 .53152 Mdot
.736 .53157 Mdot
.736 .53216 Mdot
.736 .53238 Mdot
.736 .53238 Mdot
.736 .53239 Mdot
.736 .53284 Mdot
.736 .5332 Mdot
.736 .53376 Mdot
.736 .53403 Mdot
.736 .53424 Mdot
.736 .53437 Mdot
.736 .53473 Mdot
.736 .53479 Mdot
.736 .53531 Mdot
.736 .53602 Mdot
.736 .53619 Mdot
.736 .53667 Mdot
.736 .53689 Mdot
.736 .53802 Mdot
.736 .53819 Mdot
.736 .53886 Mdot
.736 .53956 Mdot
.736 .53976 Mdot
.736 .53977 Mdot
.736 .54031 Mdot
.736 .54035 Mdot
.736 .54041 Mdot
.736 .54074 Mdot
.736 .54126 Mdot
.736 .54145 Mdot
.736 .54162 Mdot
.736 .5417 Mdot
.736 .54186 Mdot
.736 .54206 Mdot
.736 .54259 Mdot
.736 .54308 Mdot
.736 .5432 Mdot
.736 .54387 Mdot
.736 .54407 Mdot
.736 .54441 Mdot
.736 .54456 Mdot
.736 .54515 Mdot
.736 .54527 Mdot
.736 .54567 Mdot
.736 .5461 Mdot
.736 .54615 Mdot
.736 .54617 Mdot
.736 .54641 Mdot
.736 .54645 Mdot
.736 .54695 Mdot
.736 .54724 Mdot
.736 .54757 Mdot
.736 .54763 Mdot
.736 .54833 Mdot
.736 .54847 Mdot
.736 .54858 Mdot
.736 .54861 Mdot
.736 .54862 Mdot
.736 .54875 Mdot
.736 .54884 Mdot
.736 .54892 Mdot
.736 .54903 Mdot
.736 .54937 Mdot
.736 .54964 Mdot
.736 .54972 Mdot
.736 .54988 Mdot
.736 .55 Mdot
.736 .55016 Mdot
.736 .55062 Mdot
.736 .55064 Mdot
.736 .55064 Mdot
.736 .55072 Mdot
.736 .55079 Mdot
.736 .55111 Mdot
.736 .5512 Mdot
.736 .55151 Mdot
.736 .55156 Mdot
.736 .55168 Mdot
.736 .55182 Mdot
.736 .55185 Mdot
.736 .55218 Mdot
.736 .55234 Mdot
.736 .55245 Mdot
.736 .55248 Mdot
.736 .55257 Mdot
.736 .55272 Mdot
.736 .55284 Mdot
.736 .55299 Mdot
.736 .55308 Mdot
.736 .55314 Mdot
.736 .55327 Mdot
.736 .55359 Mdot
.736 .55376 Mdot
.736 .5541 Mdot
.736 .55432 Mdot
.736 .55456 Mdot
.736 .55462 Mdot
.736 .55463 Mdot
.736 .55482 Mdot
.736 .55482 Mdot
.736 .55507 Mdot
.736 .55517 Mdot
.736 .55536 Mdot
.736 .55543 Mdot
.736 .55543 Mdot
.736 .55559 Mdot
.736 .5556 Mdot
.736 .55563 Mdot
.736 .55565 Mdot
.736 .55573 Mdot
.736 .55574 Mdot
.736 .55575 Mdot
.736 .5559 Mdot
.736 .55595 Mdot
.736 .55622 Mdot
.736 .55634 Mdot
.736 .55641 Mdot
.736 .55646 Mdot
.736 .55646 Mdot
.736 .55656 Mdot
.736 .55658 Mdot
.736 .55661 Mdot
.736 .55673 Mdot
.736 .55677 Mdot
.736 .55716 Mdot
.736 .55726 Mdot
.736 .55728 Mdot
.736 .55752 Mdot
.736 .55806 Mdot
.736 .5581 Mdot
.736 .55864 Mdot
.736 .55873 Mdot
.736 .5591 Mdot
.736 .55916 Mdot
.736 .55958 Mdot
.736 .5597 Mdot
.736 .56033 Mdot
.736 .56044 Mdot
.736 .56049 Mdot
.736 .56056 Mdot
.736 .56074 Mdot
.736 .56083 Mdot
.736 .56089 Mdot
.736 .56118 Mdot
.736 .56132 Mdot
.736 .56169 Mdot
.736 .56176 Mdot
.736 .56203 Mdot
.736 .56244 Mdot
.736 .56285 Mdot
.736 .56292 Mdot
.736 .56321 Mdot
.736 .56352 Mdot
.736 .56359 Mdot
.736 .56438 Mdot
.736 .56455 Mdot
.736 .56476 Mdot
.736 .5648 Mdot
.736 .56523 Mdot
.736 .56531 Mdot
.736 .56564 Mdot
.736 .56598 Mdot
.736 .56603 Mdot
.736 .56606 Mdot
.736 .56644 Mdot
.736 .56655 Mdot
.736 .56658 Mdot
.736 .56672 Mdot
.736 .56713 Mdot
.736 .5675 Mdot
.736 .56754 Mdot
.736 .56764 Mdot
.736 .56796 Mdot
.736 .56805 Mdot
.736 .56808 Mdot
.736 .56824 Mdot
.736 .56824 Mdot
.736 .56835 Mdot
.736 .56847 Mdot
.736 .56856 Mdot
.736 .56874 Mdot
.736 .56905 Mdot
.736 .56915 Mdot
.736 .56928 Mdot
.736 .56936 Mdot
.736 .56953 Mdot
.736 .56959 Mdot
.736 .5697 Mdot
.736 .56978 Mdot
.736 .56993 Mdot
.736 .56998 Mdot
.736 .57001 Mdot
.736 .57018 Mdot
.736 .57025 Mdot
.736 .57061 Mdot
.736 .57065 Mdot
.736 .57068 Mdot
.736 .57071 Mdot
.736 .57079 Mdot
.736 .57087 Mdot
.736 .57089 Mdot
.736 .57092 Mdot
.736 .57102 Mdot
.736 .57103 Mdot
.736 .5711 Mdot
.736 .57121 Mdot
.736 .57122 Mdot
.736 .57133 Mdot
.736 .57144 Mdot
.736 .57147 Mdot
.736 .57156 Mdot
.736 .57162 Mdot
.736 .57176 Mdot
.736 .57182 Mdot
.736 .57188 Mdot
.736 .57191 Mdot
.736 .57193 Mdot
.736 .57194 Mdot
.736 .57198 Mdot
.736 .57205 Mdot
.736 .57207 Mdot
.736 .5721 Mdot
.736 .5721 Mdot
.736 .57211 Mdot
.736 .57213 Mdot
.736 .57214 Mdot
.736 .57222 Mdot
.736 .57224 Mdot
.736 .57224 Mdot
.738 .1255 Mdot
.738 .1255 Mdot
.738 .12553 Mdot
.738 .12556 Mdot
.738 .12557 Mdot
.738 .12568 Mdot
.738 .12572 Mdot
.738 .12577 Mdot
.738 .12589 Mdot
.738 .12589 Mdot
.738 .12589 Mdot
.738 .1261 Mdot
.738 .12611 Mdot
.738 .12619 Mdot
.738 .12627 Mdot
.738 .1263 Mdot
.738 .12633 Mdot
.738 .12646 Mdot
.738 .12653 Mdot
.738 .12654 Mdot
.738 .12663 Mdot
.738 .12681 Mdot
.738 .12681 Mdot
.738 .1269 Mdot
.738 .12715 Mdot
.738 .12719 Mdot
.738 .12752 Mdot
.738 .12762 Mdot
.738 .12766 Mdot
.738 .12769 Mdot
.738 .12778 Mdot
.738 .12818 Mdot
.738 .12865 Mdot
.738 .1289 Mdot
.738 .12894 Mdot
.738 .12987 Mdot
.738 .1305 Mdot
.738 .13059 Mdot
.738 .13084 Mdot
.738 .13086 Mdot
.738 .13088 Mdot
.738 .13123 Mdot
.738 .13319 Mdot
.738 .13337 Mdot
.738 .13343 Mdot
.738 .13343 Mdot
.738 .13379 Mdot
.738 .13456 Mdot
.738 .13469 Mdot
.738 .13494 Mdot
.738 .13614 Mdot
.738 .13804 Mdot
.738 .13839 Mdot
.738 .13946 Mdot
.738 .13966 Mdot
.738 .14019 Mdot
.738 .14221 Mdot
.738 .14467 Mdot
.738 .14518 Mdot
.738 .14637 Mdot
.738 .14784 Mdot
.738 .1482 Mdot
.738 .14822 Mdot
.738 .14931 Mdot
.738 .14937 Mdot
.738 .14962 Mdot
.738 .14966 Mdot
.738 .14989 Mdot
.738 .15227 Mdot
.738 .15416 Mdot
.738 .15455 Mdot
.738 .15484 Mdot
.738 .15519 Mdot
.738 .15732 Mdot
.738 .15785 Mdot
.738 .15962 Mdot
.738 .1599 Mdot
.738 .16002 Mdot
.738 .16019 Mdot
.738 .16064 Mdot
.738 .16166 Mdot
.738 .16168 Mdot
.738 .16237 Mdot
.738 .1628 Mdot
.738 .16374 Mdot
.738 .16412 Mdot
.738 .16511 Mdot
.738 .16543 Mdot
.738 .16617 Mdot
.738 .16637 Mdot
.738 .16678 Mdot
.738 .1678 Mdot
.738 .1687 Mdot
.738 .16942 Mdot
.738 .16949 Mdot
.738 .17111 Mdot
.738 .17164 Mdot
.738 .17167 Mdot
.738 .17178 Mdot
.738 .17191 Mdot
.738 .17197 Mdot
.738 .17248 Mdot
.738 .17267 Mdot
.738 .17289 Mdot
.738 .17344 Mdot
.738 .17346 Mdot
.738 .17346 Mdot
.738 .17406 Mdot
.738 .17414 Mdot
.738 .17444 Mdot
.738 .17446 Mdot
.738 .17484 Mdot
.738 .17503 Mdot
.738 .17522 Mdot
.738 .17534 Mdot
.738 .17534 Mdot
.738 .17552 Mdot
.738 .1761 Mdot
.738 .1762 Mdot
.738 .17642 Mdot
.738 .17651 Mdot
.738 .17693 Mdot
.738 .17753 Mdot
.738 .17779 Mdot
.738 .1778 Mdot
.738 .17823 Mdot
.738 .17869 Mdot
.738 .1788 Mdot
.738 .17901 Mdot
.738 .17929 Mdot
.738 .17944 Mdot
.738 .1796 Mdot
.738 .1796 Mdot
.738 .18088 Mdot
.738 .18123 Mdot
.738 .18169 Mdot
.738 .1817 Mdot
.738 .18189 Mdot
.738 .18204 Mdot
.738 .18249 Mdot
.738 .18308 Mdot
.738 .18452 Mdot
.738 .18638 Mdot
.738 .18655 Mdot
.738 .18686 Mdot
.738 .18753 Mdot
.738 .18814 Mdot
.738 .18835 Mdot
.738 .18882 Mdot
.738 .1921 Mdot
.738 .19223 Mdot
.738 .19321 Mdot
.738 .19328 Mdot
.738 .19654 Mdot
.738 .19656 Mdot
.738 .19672 Mdot
.738 .19704 Mdot
.738 .19806 Mdot
.738 .19836 Mdot
.738 .19846 Mdot
.738 .19858 Mdot
.738 .19952 Mdot
.738 .19988 Mdot
.738 .2005 Mdot
.738 .20178 Mdot
.738 .20218 Mdot
.738 .20368 Mdot
.738 .20428 Mdot
.738 .20585 Mdot
.738 .20772 Mdot
.738 .20843 Mdot
.738 .20854 Mdot
.738 .20944 Mdot
.738 .21135 Mdot
.738 .21145 Mdot
.738 .21252 Mdot
.738 .21262 Mdot
.738 .21284 Mdot
.738 .21284 Mdot
.738 .21316 Mdot
.738 .21375 Mdot
.738 .21422 Mdot
.738 .21496 Mdot
.738 .21626 Mdot
.738 .21743 Mdot
.738 .21912 Mdot
.738 .21944 Mdot
.738 .22021 Mdot
.738 .22161 Mdot
.738 .2217 Mdot
.738 .22197 Mdot
.738 .22323 Mdot
.738 .22423 Mdot
.738 .22465 Mdot
.738 .22674 Mdot
.738 .2289 Mdot
.738 .23107 Mdot
.738 .23275 Mdot
.738 .23396 Mdot
.738 .23958 Mdot
.738 .24011 Mdot
.738 .24058 Mdot
.738 .24231 Mdot
.738 .24276 Mdot
.738 .24356 Mdot
.738 .24397 Mdot
.738 .24468 Mdot
.738 .24613 Mdot
.738 .24689 Mdot
.738 .2484 Mdot
.738 .24857 Mdot
.738 .24951 Mdot
.738 .25013 Mdot
.738 .2507 Mdot
.738 .25077 Mdot
.738 .25271 Mdot
.738 .25416 Mdot
.738 .25475 Mdot
.738 .2568 Mdot
.738 .25785 Mdot
.738 .25846 Mdot
.738 .25861 Mdot
.738 .25875 Mdot
.738 .26071 Mdot
.738 .26116 Mdot
.738 .26272 Mdot
.738 .26357 Mdot
.738 .26672 Mdot
.738 .26725 Mdot
.738 .26749 Mdot
.738 .2685 Mdot
.738 .26877 Mdot
.738 .2691 Mdot
.738 .27184 Mdot
.738 .27537 Mdot
.738 .27574 Mdot
.738 .27655 Mdot
.738 .27683 Mdot
.738 .27883 Mdot
.738 .27923 Mdot
.738 .28122 Mdot
.738 .28345 Mdot
.738 .28363 Mdot
.738 .28463 Mdot
.738 .28687 Mdot
.738 .28816 Mdot
.738 .28859 Mdot
.738 .28948 Mdot
.738 .28999 Mdot
.738 .29333 Mdot
.738 .29372 Mdot
.738 .29484 Mdot
.738 .29791 Mdot
.738 .30021 Mdot
.738 .3003 Mdot
.738 .3018 Mdot
.738 .30208 Mdot
.738 .30306 Mdot
.738 .30371 Mdot
.738 .30374 Mdot
.738 .30475 Mdot
.738 .30475 Mdot
.738 .30477 Mdot
.738 .30547 Mdot
.738 .30579 Mdot
.738 .3061 Mdot
.738 .30718 Mdot
.738 .30735 Mdot
.738 .30931 Mdot
.738 .30961 Mdot
.738 .31023 Mdot
.738 .31466 Mdot
.738 .31508 Mdot
.738 .31522 Mdot
.738 .31589 Mdot
.738 .31679 Mdot
.738 .31679 Mdot
.738 .31705 Mdot
.738 .31866 Mdot
.738 .31888 Mdot
.738 .31897 Mdot
.738 .31904 Mdot
.738 .31924 Mdot
.738 .32104 Mdot
.738 .32151 Mdot
.738 .32159 Mdot
.738 .32417 Mdot
.738 .32468 Mdot
.738 .32474 Mdot
.738 .32524 Mdot
.738 .32782 Mdot
.738 .32811 Mdot
.738 .32811 Mdot
.738 .32959 Mdot
.738 .33307 Mdot
.738 .33506 Mdot
.738 .34011 Mdot
.738 .34146 Mdot
.738 .34225 Mdot
.738 .34247 Mdot
.738 .3425 Mdot
.738 .34429 Mdot
.738 .34554 Mdot
.738 .34579 Mdot
.738 .34597 Mdot
.738 .34753 Mdot
.738 .34786 Mdot
.738 .34909 Mdot
.738 .34916 Mdot
.738 .35012 Mdot
.738 .35014 Mdot
.738 .35154 Mdot
.738 .35208 Mdot
.738 .35226 Mdot
.738 .35267 Mdot
.738 .35278 Mdot
.738 .35301 Mdot
.738 .35356 Mdot
.738 .35404 Mdot
.738 .35443 Mdot
.738 .35559 Mdot
.738 .35561 Mdot
.738 .35566 Mdot
.738 .35573 Mdot
.738 .35576 Mdot
.738 .35603 Mdot
.738 .35612 Mdot
.738 .35624 Mdot
.738 .35652 Mdot
.738 .35653 Mdot
.738 .35653 Mdot
.738 .35683 Mdot
.738 .35703 Mdot
.738 .35704 Mdot
.738 .35723 Mdot
.738 .35742 Mdot
.738 .35748 Mdot
.738 .35748 Mdot
.738 .35757 Mdot
.738 .35786 Mdot
.738 .35791 Mdot
.738 .35802 Mdot
.738 .35806 Mdot
.738 .35827 Mdot
.738 .35856 Mdot
.738 .35869 Mdot
.738 .3587 Mdot
.738 .35891 Mdot
.738 .35913 Mdot
.738 .35918 Mdot
.738 .35949 Mdot
.738 .35957 Mdot
.738 .36036 Mdot
.738 .36057 Mdot
.738 .36058 Mdot
.738 .36067 Mdot
.738 .36074 Mdot
.738 .36095 Mdot
.738 .3619 Mdot
.738 .36276 Mdot
.738 .36284 Mdot
.738 .36298 Mdot
.738 .36356 Mdot
.738 .36366 Mdot
.738 .36538 Mdot
.738 .36582 Mdot
.738 .36585 Mdot
.738 .36726 Mdot
.738 .36747 Mdot
.738 .36803 Mdot
.738 .36808 Mdot
.738 .36813 Mdot
.738 .36868 Mdot
.738 .36893 Mdot
.738 .37025 Mdot
.738 .3705 Mdot
.738 .37218 Mdot
.738 .37223 Mdot
.738 .37259 Mdot
.738 .37339 Mdot
.738 .37381 Mdot
.738 .37385 Mdot
.738 .37393 Mdot
.738 .37394 Mdot
.738 .37429 Mdot
.738 .37476 Mdot
.738 .37637 Mdot
.738 .37649 Mdot
.738 .37678 Mdot
.738 .37732 Mdot
.738 .37735 Mdot
.738 .3783 Mdot
.738 .37924 Mdot
.738 .38003 Mdot
.738 .38083 Mdot
.738 .38144 Mdot
.738 .38188 Mdot
.738 .38388 Mdot
.738 .38424 Mdot
.738 .38485 Mdot
.738 .38501 Mdot
.738 .38543 Mdot
.738 .38568 Mdot
.738 .38618 Mdot
.738 .38644 Mdot
.738 .38702 Mdot
.738 .38735 Mdot
.738 .38756 Mdot
.738 .38775 Mdot
.738 .38778 Mdot
.738 .38844 Mdot
.738 .38894 Mdot
.738 .38983 Mdot
.738 .39018 Mdot
.738 .39039 Mdot
.738 .39044 Mdot
.738 .39048 Mdot
.738 .39114 Mdot
.738 .39181 Mdot
.738 .39209 Mdot
.738 .39313 Mdot
.738 .3933 Mdot
.738 .39371 Mdot
.738 .39391 Mdot
.738 .39595 Mdot
.738 .39706 Mdot
.738 .39719 Mdot
.738 .39854 Mdot
.738 .39962 Mdot
.738 .40003 Mdot
.738 .40016 Mdot
.738 .40044 Mdot
.738 .40165 Mdot
.738 .40212 Mdot
.738 .40379 Mdot
.738 .40437 Mdot
.738 .40467 Mdot
.738 .40487 Mdot
.738 .40519 Mdot
.738 .4056 Mdot
.738 .40593 Mdot
.738 .40599 Mdot
.738 .40687 Mdot
.738 .40822 Mdot
.738 .40834 Mdot
.738 .40839 Mdot
.738 .40886 Mdot
.738 .40886 Mdot
.738 .40894 Mdot
.738 .40943 Mdot
.738 .40952 Mdot
.738 .40954 Mdot
.738 .41015 Mdot
.738 .41029 Mdot
.738 .41109 Mdot
.738 .41124 Mdot
.738 .41126 Mdot
.738 .41141 Mdot
.738 .41227 Mdot
.738 .41227 Mdot
.738 .41272 Mdot
.738 .41426 Mdot
.738 .41649 Mdot
.738 .41655 Mdot
.738 .41656 Mdot
.738 .41709 Mdot
.738 .41746 Mdot
.738 .41759 Mdot
.738 .41805 Mdot
.738 .41853 Mdot
.738 .41882 Mdot
.738 .41882 Mdot
.738 .41924 Mdot
.738 .4194 Mdot
.738 .4196 Mdot
.738 .41983 Mdot
.738 .42009 Mdot
.738 .4208 Mdot
.738 .42112 Mdot
.738 .4219 Mdot
.738 .42254 Mdot
.738 .42257 Mdot
.738 .42332 Mdot
.738 .42345 Mdot
.738 .42428 Mdot
.738 .42532 Mdot
.738 .42533 Mdot
.738 .42543 Mdot
.738 .42655 Mdot
.738 .42682 Mdot
.738 .42711 Mdot
.738 .42739 Mdot
.738 .42786 Mdot
.738 .42804 Mdot
.738 .42816 Mdot
.738 .42875 Mdot
.738 .42904 Mdot
.738 .42928 Mdot
.738 .42943 Mdot
.738 .42951 Mdot
.738 .42984 Mdot
.738 .4301 Mdot
.738 .43061 Mdot
.738 .43067 Mdot
.738 .43068 Mdot
.738 .4307 Mdot
.738 .43089 Mdot
.738 .43109 Mdot
.738 .43171 Mdot
.738 .43231 Mdot
.738 .43264 Mdot
.738 .43268 Mdot
.738 .43356 Mdot
.738 .43364 Mdot
.738 .434 Mdot
.738 .43463 Mdot
.738 .4348 Mdot
.738 .43489 Mdot
.738 .43517 Mdot
.738 .43652 Mdot
.738 .43656 Mdot
.738 .43685 Mdot
.738 .43685 Mdot
.738 .4369 Mdot
.738 .43715 Mdot
.738 .43729 Mdot
.738 .43841 Mdot
.738 .4387 Mdot
.738 .43911 Mdot
.738 .43942 Mdot
.738 .43971 Mdot
.738 .44004 Mdot
.738 .44046 Mdot
.738 .44107 Mdot
.738 .44144 Mdot
.738 .44169 Mdot
.738 .44189 Mdot
.738 .44219 Mdot
.738 .44231 Mdot
.738 .44267 Mdot
.738 .44276 Mdot
.738 .44406 Mdot
.738 .44447 Mdot
.738 .44467 Mdot
.738 .44505 Mdot
.738 .44569 Mdot
.738 .44698 Mdot
.738 .4471 Mdot
.738 .44968 Mdot
.738 .4499 Mdot
.738 .45 Mdot
.738 .45095 Mdot
.738 .45099 Mdot
.738 .45119 Mdot
.738 .45142 Mdot
.738 .45153 Mdot
.738 .45219 Mdot
.738 .45243 Mdot
.738 .45276 Mdot
.738 .45315 Mdot
.738 .4533 Mdot
.738 .45398 Mdot
.738 .45412 Mdot
.738 .45414 Mdot
.738 .45414 Mdot
.738 .45432 Mdot
.738 .45504 Mdot
.738 .45519 Mdot
.738 .45532 Mdot
.738 .45585 Mdot
.738 .45589 Mdot
.738 .45655 Mdot
.738 .45687 Mdot
.738 .45719 Mdot
.738 .45729 Mdot
.738 .4574 Mdot
.738 .45741 Mdot
.738 .45744 Mdot
.738 .45771 Mdot
.738 .45806 Mdot
.738 .45826 Mdot
.738 .45872 Mdot
.738 .45878 Mdot
.738 .45888 Mdot
.738 .45912 Mdot
.738 .45926 Mdot
.738 .45941 Mdot
.738 .45955 Mdot
.738 .46013 Mdot
.738 .46019 Mdot
.738 .46114 Mdot
.738 .46121 Mdot
.738 .46159 Mdot
.738 .4616 Mdot
.738 .46193 Mdot
.738 .46233 Mdot
.738 .46249 Mdot
.738 .46298 Mdot
.738 .46309 Mdot
.738 .46328 Mdot
.738 .46349 Mdot
.738 .46363 Mdot
.738 .4641 Mdot
.738 .46417 Mdot
.738 .46435 Mdot
.738 .46462 Mdot
.738 .46462 Mdot
.738 .46465 Mdot
.738 .46653 Mdot
.738 .46674 Mdot
.738 .46674 Mdot
.738 .46717 Mdot
.738 .46724 Mdot
.738 .46725 Mdot
.738 .46732 Mdot
.738 .46772 Mdot
.738 .46779 Mdot
.738 .46808 Mdot
.738 .46809 Mdot
.738 .46841 Mdot
.738 .46865 Mdot
.738 .46938 Mdot
.738 .46999 Mdot
.738 .47035 Mdot
.738 .47044 Mdot
.738 .47059 Mdot
.738 .47087 Mdot
.738 .47189 Mdot
.738 .47246 Mdot
.738 .4726 Mdot
.738 .47266 Mdot
.738 .474 Mdot
.738 .47406 Mdot
.738 .47459 Mdot
.738 .47554 Mdot
.738 .47563 Mdot
.738 .4759 Mdot
.738 .47638 Mdot
.738 .47652 Mdot
.738 .47682 Mdot
.738 .47713 Mdot
.738 .47715 Mdot
.738 .47717 Mdot
.738 .47727 Mdot
.738 .47743 Mdot
.738 .47807 Mdot
.738 .47838 Mdot
.738 .47847 Mdot
.738 .47872 Mdot
.738 .47898 Mdot
.738 .4791 Mdot
.738 .47933 Mdot
.738 .47945 Mdot
.738 .47971 Mdot
.738 .48015 Mdot
.738 .48106 Mdot
.738 .48126 Mdot
.738 .48153 Mdot
.738 .48224 Mdot
.738 .48266 Mdot
.738 .4831 Mdot
.738 .48352 Mdot
.738 .48445 Mdot
.738 .48464 Mdot
.738 .4852 Mdot
.738 .48536 Mdot
.738 .48538 Mdot
.738 .48612 Mdot
.738 .48622 Mdot
.738 .48692 Mdot
.738 .48814 Mdot
.738 .48835 Mdot
.738 .48944 Mdot
.738 .48948 Mdot
.738 .49042 Mdot
.738 .49101 Mdot
.738 .49103 Mdot
.738 .49127 Mdot
.738 .49155 Mdot
.738 .49174 Mdot
.738 .49201 Mdot
.738 .49303 Mdot
.738 .49319 Mdot
.738 .49339 Mdot
.738 .49363 Mdot
.738 .49372 Mdot
.738 .49377 Mdot
.738 .49394 Mdot
.738 .49401 Mdot
.738 .49424 Mdot
.738 .49483 Mdot
.738 .49484 Mdot
.738 .49524 Mdot
.738 .49527 Mdot
.738 .49578 Mdot
.738 .49592 Mdot
.738 .49656 Mdot
.738 .49664 Mdot
.738 .49674 Mdot
.738 .49726 Mdot
.738 .49799 Mdot
.738 .49801 Mdot
.738 .4981 Mdot
.738 .49842 Mdot
.738 .49897 Mdot
.738 .50103 Mdot
.738 .50115 Mdot
.738 .50183 Mdot
.738 .50323 Mdot
.738 .50382 Mdot
.738 .50382 Mdot
.738 .50393 Mdot
.738 .50496 Mdot
.738 .50516 Mdot
.738 .50518 Mdot
.738 .50538 Mdot
.738 .5064 Mdot
.738 .50643 Mdot
.738 .50661 Mdot
.738 .50732 Mdot
.738 .5074 Mdot
.738 .50743 Mdot
.738 .50746 Mdot
.738 .50755 Mdot
.738 .50818 Mdot
.738 .50828 Mdot
.738 .50828 Mdot
.738 .50863 Mdot
.738 .50889 Mdot
.738 .50894 Mdot
.738 .50911 Mdot
.738 .51082 Mdot
.738 .51106 Mdot
.738 .51117 Mdot
.738 .51192 Mdot
.738 .51199 Mdot
.738 .5124 Mdot
.738 .51252 Mdot
.738 .51264 Mdot
.738 .51291 Mdot
.738 .51292 Mdot
.738 .51292 Mdot
.738 .5133 Mdot
.738 .51331 Mdot
.738 .51356 Mdot
.738 .51393 Mdot
.738 .51404 Mdot
.738 .5146 Mdot
.738 .51464 Mdot
.738 .5155 Mdot
.738 .51665 Mdot
.738 .51707 Mdot
.738 .51722 Mdot
.738 .51846 Mdot
.738 .51865 Mdot
.738 .51898 Mdot
.738 .51914 Mdot
.738 .51961 Mdot
.738 .52044 Mdot
.738 .5208 Mdot
.738 .52087 Mdot
.738 .52169 Mdot
.738 .52241 Mdot
.738 .52256 Mdot
.738 .52328 Mdot
.738 .52338 Mdot
.738 .52368 Mdot
.738 .52381 Mdot
.738 .52508 Mdot
.738 .52606 Mdot
.738 .52618 Mdot
.738 .52628 Mdot
.738 .52664 Mdot
.738 .52673 Mdot
.738 .52692 Mdot
.738 .52804 Mdot
.738 .52834 Mdot
.738 .52889 Mdot
.738 .52905 Mdot
.738 .52974 Mdot
.738 .52979 Mdot
.738 .52984 Mdot
.738 .53006 Mdot
.738 .53042 Mdot
.738 .53114 Mdot
.738 .53135 Mdot
.738 .53185 Mdot
.738 .53253 Mdot
.738 .53255 Mdot
.738 .53275 Mdot
.738 .53296 Mdot
.738 .53329 Mdot
.738 .53335 Mdot
.738 .53387 Mdot
.738 .53413 Mdot
.738 .53463 Mdot
.738 .53488 Mdot
.738 .53502 Mdot
.738 .53529 Mdot
.738 .53545 Mdot
.738 .53604 Mdot
.738 .5362 Mdot
.738 .53638 Mdot
.738 .53829 Mdot
.738 .5387 Mdot
.738 .53927 Mdot
.738 .54 Mdot
.738 .54072 Mdot
.738 .54142 Mdot
.738 .54156 Mdot
.738 .5419 Mdot
.738 .54232 Mdot
.738 .54241 Mdot
.738 .54244 Mdot
.738 .5429 Mdot
.738 .54316 Mdot
.738 .54326 Mdot
.738 .54382 Mdot
.738 .54421 Mdot
.738 .54464 Mdot
.738 .54488 Mdot
.738 .54504 Mdot
.738 .54523 Mdot
.738 .54534 Mdot
.738 .54534 Mdot
.738 .54541 Mdot
.738 .54544 Mdot
.738 .54579 Mdot
.738 .54582 Mdot
.738 .54645 Mdot
.738 .54675 Mdot
.738 .54678 Mdot
.738 .54701 Mdot
.738 .54762 Mdot
.738 .54813 Mdot
.738 .54833 Mdot
.738 .54881 Mdot
.738 .54894 Mdot
.738 .54936 Mdot
.738 .54956 Mdot
.738 .54967 Mdot
.738 .54998 Mdot
.738 .55001 Mdot
.738 .55005 Mdot
.738 .55015 Mdot
.738 .55047 Mdot
.738 .55057 Mdot
.738 .55063 Mdot
.738 .55063 Mdot
.738 .55168 Mdot
.738 .5517 Mdot
.738 .55201 Mdot
.738 .55206 Mdot
.738 .5531 Mdot
.738 .55325 Mdot
.738 .55332 Mdot
.738 .55351 Mdot
.738 .55372 Mdot
.738 .55382 Mdot
.738 .55388 Mdot
.738 .55447 Mdot
.738 .55492 Mdot
.738 .55511 Mdot
.738 .55525 Mdot
.738 .55529 Mdot
.738 .55536 Mdot
.738 .55536 Mdot
.738 .5555 Mdot
.738 .55561 Mdot
.738 .55602 Mdot
.738 .55602 Mdot
.738 .55607 Mdot
.738 .55611 Mdot
.738 .5562 Mdot
.738 .55627 Mdot
.738 .5563 Mdot
.738 .55645 Mdot
.738 .55658 Mdot
.738 .55658 Mdot
.738 .55667 Mdot
.738 .55685 Mdot
.738 .55699 Mdot
.738 .55701 Mdot
.738 .55708 Mdot
.738 .55711 Mdot
.738 .5573 Mdot
.738 .55735 Mdot
.738 .55735 Mdot
.738 .55739 Mdot
.738 .55745 Mdot
.738 .55751 Mdot
.738 .55763 Mdot
.738 .55763 Mdot
.738 .55773 Mdot
.738 .55775 Mdot
.738 .55794 Mdot
.738 .55794 Mdot
.738 .55794 Mdot
.738 .55812 Mdot
.738 .55819 Mdot
.738 .55825 Mdot
.738 .5584 Mdot
.738 .55842 Mdot
.738 .55846 Mdot
.738 .5585 Mdot
.738 .55851 Mdot
.738 .55867 Mdot
.738 .55918 Mdot
.738 .5592 Mdot
.738 .55942 Mdot
.738 .5597 Mdot
.738 .56001 Mdot
.738 .56014 Mdot
.738 .5602 Mdot
.738 .56043 Mdot
.738 .56053 Mdot
.738 .56083 Mdot
.738 .56095 Mdot
.738 .56124 Mdot
.738 .56137 Mdot
.738 .56159 Mdot
.738 .56159 Mdot
.738 .56191 Mdot
.738 .56205 Mdot
.738 .5621 Mdot
.738 .56213 Mdot
.738 .56222 Mdot
.738 .56276 Mdot
.738 .56292 Mdot
.738 .56358 Mdot
.738 .56368 Mdot
.738 .56377 Mdot
.738 .56389 Mdot
.738 .56446 Mdot
.738 .56518 Mdot
.738 .56526 Mdot
.738 .56527 Mdot
.738 .56534 Mdot
.738 .56536 Mdot
.738 .56569 Mdot
.738 .5657 Mdot
.738 .56581 Mdot
.738 .56625 Mdot
.738 .56661 Mdot
.738 .56676 Mdot
.738 .5675 Mdot
.738 .56811 Mdot
.738 .56827 Mdot
.738 .56833 Mdot
.738 .56865 Mdot
.738 .56875 Mdot
.738 .56932 Mdot
.738 .56968 Mdot
.738 .56975 Mdot
.738 .56979 Mdot
.738 .57002 Mdot
.738 .57013 Mdot
.738 .57013 Mdot
.738 .57014 Mdot
.738 .5702 Mdot
.738 .57078 Mdot
.738 .57088 Mdot
.738 .57089 Mdot
.738 .5709 Mdot
.738 .57097 Mdot
.738 .571 Mdot
.738 .57118 Mdot
.738 .57146 Mdot
.738 .57147 Mdot
.738 .57155 Mdot
.738 .57168 Mdot
.738 .5718 Mdot
.738 .57183 Mdot
.738 .57184 Mdot
.738 .57185 Mdot
.738 .57188 Mdot
.738 .57198 Mdot
.738 .57199 Mdot
.738 .57206 Mdot
.738 .57209 Mdot
.738 .57209 Mdot
.738 .57214 Mdot
.738 .57217 Mdot
.738 .57217 Mdot
.738 .57223 Mdot
.738 .57224 Mdot
.738 .57225 Mdot
.738 .57227 Mdot
.738 .5723 Mdot
.738 .5723 Mdot
.738 .57236 Mdot
.738 .57236 Mdot
.738 .57236 Mdot
.738 .5724 Mdot
.738 .57241 Mdot
.738 .57242 Mdot
.738 .57245 Mdot
.738 .57246 Mdot
.738 .57247 Mdot
.738 .57247 Mdot
.738 .57248 Mdot
.74 .12479 Mdot
.74 .12479 Mdot
.74 .12489 Mdot
.74 .12493 Mdot
.74 .12498 Mdot
.74 .12498 Mdot
.74 .12503 Mdot
.74 .12505 Mdot
.74 .12536 Mdot
.74 .12554 Mdot
.74 .12563 Mdot
.74 .12587 Mdot
.74 .12591 Mdot
.74 .12612 Mdot
.74 .12624 Mdot
.74 .12674 Mdot
.74 .12681 Mdot
.74 .12702 Mdot
.74 .1272 Mdot
.74 .12748 Mdot
.74 .12779 Mdot
.74 .12787 Mdot
.74 .12802 Mdot
.74 .12817 Mdot
.74 .12825 Mdot
.74 .12838 Mdot
.74 .1284 Mdot
.74 .12852 Mdot
.74 .12922 Mdot
.74 .12925 Mdot
.74 .12991 Mdot
.74 .12996 Mdot
.74 .13002 Mdot
.74 .13023 Mdot
.74 .13058 Mdot
.74 .13063 Mdot
.74 .13113 Mdot
.74 .13127 Mdot
.74 .13155 Mdot
.74 .13162 Mdot
.74 .13176 Mdot
.74 .13194 Mdot
.74 .13283 Mdot
.74 .13302 Mdot
.74 .1333 Mdot
.74 .1336 Mdot
.74 .13378 Mdot
.74 .13556 Mdot
.74 .13666 Mdot
.74 .13684 Mdot
.74 .13694 Mdot
.74 .13738 Mdot
.74 .13774 Mdot
.74 .13838 Mdot
.74 .139 Mdot
.74 .13934 Mdot
.74 .14104 Mdot
.74 .14198 Mdot
.74 .14223 Mdot
.74 .1425 Mdot
.74 .14297 Mdot
.74 .1442 Mdot
.74 .14423 Mdot
.74 .14552 Mdot
.74 .14592 Mdot
.74 .14603 Mdot
.74 .14618 Mdot
.74 .14633 Mdot
.74 .14728 Mdot
.74 .14751 Mdot
.74 .14796 Mdot
.74 .14889 Mdot
.74 .14986 Mdot
.74 .1501 Mdot
.74 .15129 Mdot
.74 .15132 Mdot
.74 .1519 Mdot
.74 .15223 Mdot
.74 .15348 Mdot
.74 .15362 Mdot
.74 .15385 Mdot
.74 .15388 Mdot
.74 .15392 Mdot
.74 .1543 Mdot
.74 .15436 Mdot
.74 .15577 Mdot
.74 .1578 Mdot
.74 .15795 Mdot
.74 .15859 Mdot
.74 .15893 Mdot
.74 .15923 Mdot
.74 .16011 Mdot
.74 .16091 Mdot
.74 .16191 Mdot
.74 .16246 Mdot
.74 .16487 Mdot
.74 .16574 Mdot
.74 .1668 Mdot
.74 .16804 Mdot
.74 .16807 Mdot
.74 .16851 Mdot
.74 .16869 Mdot
.74 .16889 Mdot
.74 .16892 Mdot
.74 .16908 Mdot
.74 .16915 Mdot
.74 .16924 Mdot
.74 .17061 Mdot
.74 .17145 Mdot
.74 .17185 Mdot
.74 .17296 Mdot
.74 .17316 Mdot
.74 .17353 Mdot
.74 .17415 Mdot
.74 .17447 Mdot
.74 .17469 Mdot
.74 .17477 Mdot
.74 .17632 Mdot
.74 .17662 Mdot
.74 .17691 Mdot
.74 .1771 Mdot
.74 .17731 Mdot
.74 .17735 Mdot
.74 .17743 Mdot
.74 .17843 Mdot
.74 .17932 Mdot
.74 .17951 Mdot
.74 .17997 Mdot
.74 .18068 Mdot
.74 .1822 Mdot
.74 .18262 Mdot
.74 .18338 Mdot
.74 .18411 Mdot
.74 .18454 Mdot
.74 .18516 Mdot
.74 .18526 Mdot
.74 .1859 Mdot
.74 .18716 Mdot
.74 .1888 Mdot
.74 .18935 Mdot
.74 .18947 Mdot
.74 .18962 Mdot
.74 .19017 Mdot
.74 .19242 Mdot
.74 .19293 Mdot
.74 .19313 Mdot
.74 .19336 Mdot
.74 .19371 Mdot
.74 .19416 Mdot
.74 .19481 Mdot
.74 .19499 Mdot
.74 .1952 Mdot
.74 .19619 Mdot
.74 .19671 Mdot
.74 .19698 Mdot
.74 .1987 Mdot
.74 .19886 Mdot
.74 .19966 Mdot
.74 .20003 Mdot
.74 .20046 Mdot
.74 .20088 Mdot
.74 .20167 Mdot
.74 .20172 Mdot
.74 .20196 Mdot
.74 .20199 Mdot
.74 .2024 Mdot
.74 .20316 Mdot
.74 .2036 Mdot
.74 .20415 Mdot
.74 .20526 Mdot
.74 .20607 Mdot
.74 .20618 Mdot
.74 .20661 Mdot
.74 .20707 Mdot
.74 .20749 Mdot
.74 .20783 Mdot
.74 .2089 Mdot
.74 .20919 Mdot
.74 .20957 Mdot
.74 .21026 Mdot
.74 .2103 Mdot
.74 .21187 Mdot
.74 .21361 Mdot
.74 .21467 Mdot
.74 .21509 Mdot
.74 .21518 Mdot
.74 .21531 Mdot
.74 .21538 Mdot
.74 .21617 Mdot
.74 .2162 Mdot
.74 .21695 Mdot
.74 .22117 Mdot
.74 .22165 Mdot
.74 .22419 Mdot
.74 .22434 Mdot
.74 .22523 Mdot
.74 .22679 Mdot
.74 .22722 Mdot
.74 .22757 Mdot
.74 .22956 Mdot
.74 .22981 Mdot
.74 .23094 Mdot
.74 .23172 Mdot
.74 .23191 Mdot
.74 .23276 Mdot
.74 .23279 Mdot
.74 .23291 Mdot
.74 .23301 Mdot
.74 .23364 Mdot
.74 .23441 Mdot
.74 .23495 Mdot
.74 .23634 Mdot
.74 .23638 Mdot
.74 .23677 Mdot
.74 .23755 Mdot
.74 .23828 Mdot
.74 .23857 Mdot
.74 .23948 Mdot
.74 .24048 Mdot
.74 .24227 Mdot
.74 .24256 Mdot
.74 .24257 Mdot
.74 .24288 Mdot
.74 .2429 Mdot
.74 .24299 Mdot
.74 .24542 Mdot
.74 .24598 Mdot
.74 .24634 Mdot
.74 .24651 Mdot
.74 .24824 Mdot
.74 .24868 Mdot
.74 .24903 Mdot
.74 .25153 Mdot
.74 .25228 Mdot
.74 .25819 Mdot
.74 .25923 Mdot
.74 .25925 Mdot
.74 .25959 Mdot
.74 .26051 Mdot
.74 .26464 Mdot
.74 .26522 Mdot
.74 .2657 Mdot
.74 .26737 Mdot
.74 .26794 Mdot
.74 .26841 Mdot
.74 .26911 Mdot
.74 .26969 Mdot
.74 .27223 Mdot
.74 .27225 Mdot
.74 .2733 Mdot
.74 .27473 Mdot
.74 .27623 Mdot
.74 .27742 Mdot
.74 .27772 Mdot
.74 .27901 Mdot
.74 .28001 Mdot
.74 .28039 Mdot
.74 .28061 Mdot
.74 .28396 Mdot
.74 .28456 Mdot
.74 .28532 Mdot
.74 .28671 Mdot
.74 .2892 Mdot
.74 .29107 Mdot
.74 .29125 Mdot
.74 .29191 Mdot
.74 .29265 Mdot
.74 .29346 Mdot
.74 .29356 Mdot
.74 .29362 Mdot
.74 .29465 Mdot
.74 .29586 Mdot
.74 .29611 Mdot
.74 .29634 Mdot
.74 .29649 Mdot
.74 .29676 Mdot
.74 .29705 Mdot
.74 .2984 Mdot
.74 .29928 Mdot
.74 .30107 Mdot
.74 .30184 Mdot
.74 .30265 Mdot
.74 .30371 Mdot
.74 .30569 Mdot
.74 .3075 Mdot
.74 .30759 Mdot
.74 .31164 Mdot
.74 .31196 Mdot
.74 .3123 Mdot
.74 .31267 Mdot
.74 .3128 Mdot
.74 .31506 Mdot
.74 .31633 Mdot
.74 .31729 Mdot
.74 .31859 Mdot
.74 .31923 Mdot
.74 .32021 Mdot
.74 .32082 Mdot
.74 .32195 Mdot
.74 .32333 Mdot
.74 .32487 Mdot
.74 .32545 Mdot
.74 .32632 Mdot
.74 .32668 Mdot
.74 .32718 Mdot
.74 .32828 Mdot
.74 .3285 Mdot
.74 .32918 Mdot
.74 .32939 Mdot
.74 .33243 Mdot
.74 .33261 Mdot
.74 .33313 Mdot
.74 .33464 Mdot
.74 .33495 Mdot
.74 .33643 Mdot
.74 .33722 Mdot
.74 .339 Mdot
.74 .34001 Mdot
.74 .34039 Mdot
.74 .3405 Mdot
.74 .34131 Mdot
.74 .34148 Mdot
.74 .34246 Mdot
.74 .34314 Mdot
.74 .34411 Mdot
.74 .34413 Mdot
.74 .34451 Mdot
.74 .34555 Mdot
.74 .34564 Mdot
.74 .34583 Mdot
.74 .34608 Mdot
.74 .34611 Mdot
.74 .347 Mdot
.74 .34825 Mdot
.74 .34872 Mdot
.74 .34911 Mdot
.74 .35098 Mdot
.74 .35405 Mdot
.74 .35407 Mdot
.74 .35431 Mdot
.74 .3544 Mdot
.74 .35451 Mdot
.74 .35452 Mdot
.74 .3546 Mdot
.74 .35464 Mdot
.74 .35469 Mdot
.74 .35541 Mdot
.74 .35584 Mdot
.74 .35605 Mdot
.74 .35661 Mdot
.74 .35672 Mdot
.74 .3569 Mdot
.74 .35722 Mdot
.74 .35738 Mdot
.74 .35749 Mdot
.74 .3583 Mdot
.74 .35858 Mdot
.74 .35868 Mdot
.74 .35884 Mdot
.74 .35933 Mdot
.74 .35976 Mdot
.74 .36007 Mdot
.74 .36041 Mdot
.74 .36112 Mdot
.74 .36132 Mdot
.74 .36167 Mdot
.74 .36202 Mdot
.74 .36221 Mdot
.74 .3625 Mdot
.74 .36254 Mdot
.74 .36284 Mdot
.74 .36341 Mdot
.74 .36415 Mdot
.74 .36439 Mdot
.74 .36445 Mdot
.74 .36451 Mdot
.74 .36476 Mdot
.74 .36597 Mdot
.74 .36606 Mdot
.74 .36616 Mdot
.74 .36631 Mdot
.74 .36678 Mdot
.74 .36686 Mdot
.74 .36695 Mdot
.74 .36737 Mdot
.74 .3676 Mdot
.74 .36771 Mdot
.74 .36844 Mdot
.74 .36851 Mdot
.74 .36884 Mdot
.74 .36918 Mdot
.74 .36968 Mdot
.74 .3697 Mdot
.74 .36981 Mdot
.74 .36998 Mdot
.74 .37029 Mdot
.74 .37047 Mdot
.74 .3707 Mdot
.74 .37115 Mdot
.74 .37148 Mdot
.74 .37188 Mdot
.74 .37219 Mdot
.74 .37273 Mdot
.74 .37288 Mdot
.74 .37315 Mdot
.74 .37317 Mdot
.74 .37379 Mdot
.74 .37447 Mdot
.74 .37488 Mdot
.74 .37508 Mdot
.74 .37737 Mdot
.74 .3785 Mdot
.74 .37889 Mdot
.74 .37962 Mdot
.74 .38057 Mdot
.74 .38098 Mdot
.74 .38134 Mdot
.74 .38164 Mdot
.74 .38173 Mdot
.74 .38196 Mdot
.74 .38224 Mdot
.74 .38243 Mdot
.74 .38293 Mdot
.74 .38294 Mdot
.74 .38336 Mdot
.74 .38372 Mdot
.74 .38404 Mdot
.74 .38513 Mdot
.74 .38524 Mdot
.74 .38644 Mdot
.74 .3865 Mdot
.74 .38724 Mdot
.74 .38737 Mdot
.74 .39082 Mdot
.74 .39093 Mdot
.74 .39261 Mdot
.74 .39296 Mdot
.74 .3935 Mdot
.74 .39407 Mdot
.74 .39426 Mdot
.74 .39509 Mdot
.74 .39509 Mdot
.74 .39544 Mdot
.74 .3959 Mdot
.74 .39676 Mdot
.74 .39727 Mdot
.74 .39759 Mdot
.74 .39771 Mdot
.74 .39778 Mdot
.74 .39885 Mdot
.74 .39904 Mdot
.74 .39928 Mdot
.74 .39972 Mdot
.74 .4005 Mdot
.74 .40114 Mdot
.74 .40135 Mdot
.74 .40158 Mdot
.74 .40188 Mdot
.74 .4022 Mdot
.74 .40258 Mdot
.74 .40277 Mdot
.74 .40364 Mdot
.74 .40419 Mdot
.74 .40468 Mdot
.74 .405 Mdot
.74 .40561 Mdot
.74 .40619 Mdot
.74 .40752 Mdot
.74 .40762 Mdot
.74 .40953 Mdot
.74 .40972 Mdot
.74 .41002 Mdot
.74 .41159 Mdot
.74 .41211 Mdot
.74 .41244 Mdot
.74 .41251 Mdot
.74 .41271 Mdot
.74 .41368 Mdot
.74 .41373 Mdot
.74 .41434 Mdot
.74 .4151 Mdot
.74 .41593 Mdot
.74 .41666 Mdot
.74 .41686 Mdot
.74 .41714 Mdot
.74 .41726 Mdot
.74 .4176 Mdot
.74 .41765 Mdot
.74 .41773 Mdot
.74 .41774 Mdot
.74 .41851 Mdot
.74 .41862 Mdot
.74 .42024 Mdot
.74 .42092 Mdot
.74 .42141 Mdot
.74 .42312 Mdot
.74 .42358 Mdot
.74 .42384 Mdot
.74 .42399 Mdot
.74 .4243 Mdot
.74 .42467 Mdot
.74 .4252 Mdot
.74 .42532 Mdot
.74 .4254 Mdot
.74 .42569 Mdot
.74 .42625 Mdot
.74 .42693 Mdot
.74 .42726 Mdot
.74 .42759 Mdot
.74 .42799 Mdot
.74 .42818 Mdot
.74 .42835 Mdot
.74 .42888 Mdot
.74 .42959 Mdot
.74 .42986 Mdot
.74 .4314 Mdot
.74 .43189 Mdot
.74 .43223 Mdot
.74 .43237 Mdot
.74 .43263 Mdot
.74 .43324 Mdot
.74 .4333 Mdot
.74 .43337 Mdot
.74 .43434 Mdot
.74 .4344 Mdot
.74 .43506 Mdot
.74 .43646 Mdot
.74 .43702 Mdot
.74 .43717 Mdot
.74 .43765 Mdot
.74 .43831 Mdot
.74 .43885 Mdot
.74 .4398 Mdot
.74 .44046 Mdot
.74 .44082 Mdot
.74 .44109 Mdot
.74 .44193 Mdot
.74 .44204 Mdot
.74 .4422 Mdot
.74 .44242 Mdot
.74 .44311 Mdot
.74 .44322 Mdot
.74 .44353 Mdot
.74 .44408 Mdot
.74 .44468 Mdot
.74 .44472 Mdot
.74 .44553 Mdot
.74 .44584 Mdot
.74 .44593 Mdot
.74 .44622 Mdot
.74 .44627 Mdot
.74 .44655 Mdot
.74 .44668 Mdot
.74 .44685 Mdot
.74 .4493 Mdot
.74 .45032 Mdot
.74 .45062 Mdot
.74 .45079 Mdot
.74 .45085 Mdot
.74 .45135 Mdot
.74 .45143 Mdot
.74 .45149 Mdot
.74 .45195 Mdot
.74 .4521 Mdot
.74 .45265 Mdot
.74 .45345 Mdot
.74 .45381 Mdot
.74 .45406 Mdot
.74 .45415 Mdot
.74 .45444 Mdot
.74 .45519 Mdot
.74 .45554 Mdot
.74 .45609 Mdot
.74 .45615 Mdot
.74 .45648 Mdot
.74 .45661 Mdot
.74 .45668 Mdot
.74 .45686 Mdot
.74 .45807 Mdot
.74 .45843 Mdot
.74 .45871 Mdot
.74 .4589 Mdot
.74 .45928 Mdot
.74 .45979 Mdot
.74 .46028 Mdot
.74 .46034 Mdot
.74 .4606 Mdot
.74 .46079 Mdot
.74 .46095 Mdot
.74 .46103 Mdot
.74 .46116 Mdot
.74 .4614 Mdot
.74 .46252 Mdot
.74 .46286 Mdot
.74 .46412 Mdot
.74 .46435 Mdot
.74 .46466 Mdot
.74 .46502 Mdot
.74 .46543 Mdot
.74 .46611 Mdot
.74 .46661 Mdot
.74 .46691 Mdot
.74 .46716 Mdot
.74 .46808 Mdot
.74 .4691 Mdot
.74 .46979 Mdot
.74 .47036 Mdot
.74 .47102 Mdot
.74 .47143 Mdot
.74 .47152 Mdot
.74 .47221 Mdot
.74 .47288 Mdot
.74 .47309 Mdot
.74 .47321 Mdot
.74 .4733 Mdot
.74 .47389 Mdot
.74 .47404 Mdot
.74 .47428 Mdot
.74 .47468 Mdot
.74 .4749 Mdot
.74 .47506 Mdot
.74 .47545 Mdot
.74 .47622 Mdot
.74 .47704 Mdot
.74 .47863 Mdot
.74 .47906 Mdot
.74 .47961 Mdot
.74 .48015 Mdot
.74 .48046 Mdot
.74 .48065 Mdot
.74 .48088 Mdot
.74 .48096 Mdot
.74 .48123 Mdot
.74 .48153 Mdot
.74 .48171 Mdot
.74 .48214 Mdot
.74 .48264 Mdot
.74 .48315 Mdot
.74 .48417 Mdot
.74 .48501 Mdot
.74 .48514 Mdot
.74 .48544 Mdot
.74 .48558 Mdot
.74 .48575 Mdot
.74 .4859 Mdot
.74 .48619 Mdot
.74 .48653 Mdot
.74 .48654 Mdot
.74 .48705 Mdot
.74 .48708 Mdot
.74 .48755 Mdot
.74 .48773 Mdot
.74 .48777 Mdot
.74 .48816 Mdot
.74 .48868 Mdot
.74 .48884 Mdot
.74 .48894 Mdot
.74 .48926 Mdot
.74 .4907 Mdot
.74 .49133 Mdot
.74 .49145 Mdot
.74 .49184 Mdot
.74 .49204 Mdot
.74 .49301 Mdot
.74 .49454 Mdot
.74 .49532 Mdot
.74 .49548 Mdot
.74 .49568 Mdot
.74 .49619 Mdot
.74 .49656 Mdot
.74 .49658 Mdot
.74 .49668 Mdot
.74 .49676 Mdot
.74 .4968 Mdot
.74 .49722 Mdot
.74 .49738 Mdot
.74 .49739 Mdot
.74 .49779 Mdot
.74 .49807 Mdot
.74 .49847 Mdot
.74 .49854 Mdot
.74 .49887 Mdot
.74 .49891 Mdot
.74 .49907 Mdot
.74 .49948 Mdot
.74 .50021 Mdot
.74 .50053 Mdot
.74 .50113 Mdot
.74 .50125 Mdot
.74 .50186 Mdot
.74 .50207 Mdot
.74 .50214 Mdot
.74 .50336 Mdot
.74 .50344 Mdot
.74 .50371 Mdot
.74 .5038 Mdot
.74 .50424 Mdot
.74 .50444 Mdot
.74 .50458 Mdot
.74 .50493 Mdot
.74 .50515 Mdot
.74 .50576 Mdot
.74 .50631 Mdot
.74 .50675 Mdot
.74 .50699 Mdot
.74 .50738 Mdot
.74 .50763 Mdot
.74 .50813 Mdot
.74 .50851 Mdot
.74 .509 Mdot
.74 .50988 Mdot
.74 .50993 Mdot
.74 .51007 Mdot
.74 .5102 Mdot
.74 .51032 Mdot
.74 .51188 Mdot
.74 .51191 Mdot
.74 .5126 Mdot
.74 .51336 Mdot
.74 .51376 Mdot
.74 .51407 Mdot
.74 .51436 Mdot
.74 .51503 Mdot
.74 .51536 Mdot
.74 .51587 Mdot
.74 .51598 Mdot
.74 .51608 Mdot
.74 .51614 Mdot
.74 .51622 Mdot
.74 .51632 Mdot
.74 .51677 Mdot
.74 .51715 Mdot
.74 .51718 Mdot
.74 .51721 Mdot
.74 .51751 Mdot
.74 .51779 Mdot
.74 .51804 Mdot
.74 .5181 Mdot
.74 .5188 Mdot
.74 .51971 Mdot
.74 .52023 Mdot
.74 .52051 Mdot
.74 .52073 Mdot
.74 .52195 Mdot
.74 .52203 Mdot
.74 .52217 Mdot
.74 .52253 Mdot
.74 .523 Mdot
.74 .52311 Mdot
.74 .52354 Mdot
.74 .52408 Mdot
.74 .5246 Mdot
.74 .52498 Mdot
.74 .52498 Mdot
.74 .52589 Mdot
.74 .5261 Mdot
.74 .52635 Mdot
.74 .52652 Mdot
.74 .52672 Mdot
.74 .52732 Mdot
.74 .52749 Mdot
.74 .52769 Mdot
.74 .52916 Mdot
.74 .52948 Mdot
.74 .5296 Mdot
.74 .52961 Mdot
.74 .52997 Mdot
.74 .53204 Mdot
.74 .5323 Mdot
.74 .53316 Mdot
.74 .53329 Mdot
.74 .53344 Mdot
.74 .53404 Mdot
.74 .5341 Mdot
.74 .53422 Mdot
.74 .53441 Mdot
.74 .53525 Mdot
.74 .53528 Mdot
.74 .53529 Mdot
.74 .53539 Mdot
.74 .5354 Mdot
.74 .53549 Mdot
.74 .53611 Mdot
.74 .53645 Mdot
.74 .53676 Mdot
.74 .53686 Mdot
.74 .53711 Mdot
.74 .53737 Mdot
.74 .5375 Mdot
.74 .53752 Mdot
.74 .53799 Mdot
.74 .53817 Mdot
.74 .53843 Mdot
.74 .53865 Mdot
.74 .53868 Mdot
.74 .53872 Mdot
.74 .53873 Mdot
.74 .53902 Mdot
.74 .53908 Mdot
.74 .53934 Mdot
.74 .53972 Mdot
.74 .53981 Mdot
.74 .54048 Mdot
.74 .5406 Mdot
.74 .54074 Mdot
.74 .54126 Mdot
.74 .54156 Mdot
.74 .54161 Mdot
.74 .54245 Mdot
.74 .54261 Mdot
.74 .54401 Mdot
.74 .54426 Mdot
.74 .54427 Mdot
.74 .54453 Mdot
.74 .54455 Mdot
.74 .5446 Mdot
.74 .54463 Mdot
.74 .54476 Mdot
.74 .54511 Mdot
.74 .54568 Mdot
.74 .5462 Mdot
.74 .54621 Mdot
.74 .54644 Mdot
.74 .54656 Mdot
.74 .54666 Mdot
.74 .547 Mdot
.74 .54711 Mdot
.74 .54725 Mdot
.74 .5474 Mdot
.74 .54754 Mdot
.74 .54758 Mdot
.74 .54784 Mdot
.74 .5482 Mdot
.74 .54838 Mdot
.74 .54852 Mdot
.74 .54877 Mdot
.74 .5489 Mdot
.74 .54891 Mdot
.74 .54899 Mdot
.74 .54901 Mdot
.74 .54926 Mdot
.74 .54939 Mdot
.74 .54953 Mdot
.74 .54965 Mdot
.74 .54991 Mdot
.74 .54996 Mdot
.74 .55052 Mdot
.74 .5506 Mdot
.74 .55077 Mdot
.74 .55109 Mdot
.74 .55116 Mdot
.74 .55121 Mdot
.74 .55142 Mdot
.74 .55157 Mdot
.74 .55168 Mdot
.74 .55175 Mdot
.74 .55181 Mdot
.74 .55198 Mdot
.74 .5527 Mdot
.74 .55287 Mdot
.74 .55292 Mdot
.74 .55296 Mdot
.74 .55313 Mdot
.74 .55365 Mdot
.74 .55405 Mdot
.74 .55425 Mdot
.74 .55428 Mdot
.74 .55448 Mdot
.74 .55462 Mdot
.74 .55485 Mdot
.74 .55509 Mdot
.74 .55522 Mdot
.74 .5557 Mdot
.74 .55592 Mdot
.74 .55607 Mdot
.74 .55613 Mdot
.74 .55641 Mdot
.74 .55672 Mdot
.74 .55674 Mdot
.74 .55676 Mdot
.74 .55682 Mdot
.74 .55688 Mdot
.74 .55697 Mdot
.74 .55707 Mdot
.74 .55755 Mdot
.74 .55758 Mdot
.74 .55765 Mdot
.74 .55774 Mdot
.74 .55794 Mdot
.74 .55805 Mdot
.74 .55812 Mdot
.74 .55846 Mdot
.74 .55859 Mdot
.74 .55885 Mdot
.74 .55927 Mdot
.74 .5593 Mdot
.74 .55932 Mdot
.74 .55937 Mdot
.74 .55938 Mdot
.74 .55944 Mdot
.74 .5595 Mdot
.74 .55964 Mdot
.74 .55964 Mdot
.74 .56003 Mdot
.74 .56036 Mdot
.74 .56062 Mdot
.74 .56137 Mdot
.74 .56154 Mdot
.74 .56184 Mdot
.74 .56209 Mdot
.74 .56236 Mdot
.74 .56245 Mdot
.74 .56256 Mdot
.74 .56275 Mdot
.74 .56279 Mdot
.74 .56342 Mdot
.74 .56385 Mdot
.74 .56386 Mdot
.74 .56398 Mdot
.74 .56399 Mdot
.74 .564 Mdot
.74 .56407 Mdot
.74 .56411 Mdot
.74 .56449 Mdot
.74 .56459 Mdot
.74 .56477 Mdot
.74 .56478 Mdot
.74 .56514 Mdot
.74 .56521 Mdot
.74 .56551 Mdot
.74 .56579 Mdot
.74 .56592 Mdot
.74 .56599 Mdot
.74 .56628 Mdot
.74 .56633 Mdot
.74 .56637 Mdot
.74 .5664 Mdot
.74 .56652 Mdot
.74 .56691 Mdot
.74 .56692 Mdot
.74 .56729 Mdot
.74 .56743 Mdot
.74 .56751 Mdot
.74 .56759 Mdot
.74 .56787 Mdot
.74 .56838 Mdot
.74 .56848 Mdot
.74 .56867 Mdot
.74 .56886 Mdot
.74 .56897 Mdot
.74 .5691 Mdot
.74 .56913 Mdot
.74 .56918 Mdot
.74 .56951 Mdot
.74 .57004 Mdot
.74 .57009 Mdot
.74 .57018 Mdot
.74 .57027 Mdot
.74 .57032 Mdot
.74 .57059 Mdot
.74 .57064 Mdot
.74 .57068 Mdot
.74 .5707 Mdot
.74 .57078 Mdot
.74 .57083 Mdot
.74 .57097 Mdot
.74 .57099 Mdot
.74 .57109 Mdot
.74 .57115 Mdot
.74 .57117 Mdot
.74 .57119 Mdot
.74 .57138 Mdot
.74 .57139 Mdot
.74 .5716 Mdot
.74 .57163 Mdot
.74 .57164 Mdot
.74 .57168 Mdot
.74 .5717 Mdot
.74 .57174 Mdot
.74 .57179 Mdot
.74 .57181 Mdot
.74 .5719 Mdot
.74 .57199 Mdot
.74 .57204 Mdot
.74 .5721 Mdot
.74 .57212 Mdot
.74 .57227 Mdot
.74 .5723 Mdot
.74 .57237 Mdot
.74 .57238 Mdot
.74 .57245 Mdot
.74 .57248 Mdot
.74 .57253 Mdot
.74 .57262 Mdot
.74 .57263 Mdot
.74 .57264 Mdot
.74 .57264 Mdot
.74 .57266 Mdot
.74 .57267 Mdot
.74 .5727 Mdot
.74 .5727 Mdot
.742 .12399 Mdot
.742 .12399 Mdot
.742 .12399 Mdot
.742 .12401 Mdot
.742 .12409 Mdot
.742 .1241 Mdot
.742 .1241 Mdot
.742 .12411 Mdot
.742 .12421 Mdot
.742 .12421 Mdot
.742 .12428 Mdot
.742 .12437 Mdot
.742 .1245 Mdot
.742 .1245 Mdot
.742 .12453 Mdot
.742 .12473 Mdot
.742 .12479 Mdot
.742 .12481 Mdot
.742 .12509 Mdot
.742 .12513 Mdot
.742 .12536 Mdot
.742 .12537 Mdot
.742 .12562 Mdot
.742 .1258 Mdot
.742 .12603 Mdot
.742 .12677 Mdot
.742 .12712 Mdot
.742 .12745 Mdot
.742 .12757 Mdot
.742 .12761 Mdot
.742 .12793 Mdot
.742 .12854 Mdot
.742 .12872 Mdot
.742 .12936 Mdot
.742 .12948 Mdot
.742 .12964 Mdot
.742 .12974 Mdot
.742 .12978 Mdot
.742 .12982 Mdot
.742 .12988 Mdot
.742 .13003 Mdot
.742 .13011 Mdot
.742 .13104 Mdot
.742 .13193 Mdot
.742 .13219 Mdot
.742 .13238 Mdot
.742 .13255 Mdot
.742 .13256 Mdot
.742 .13306 Mdot
.742 .13409 Mdot
.742 .13499 Mdot
.742 .13499 Mdot
.742 .13517 Mdot
.742 .13533 Mdot
.742 .13535 Mdot
.742 .13625 Mdot
.742 .13649 Mdot
.742 .13705 Mdot
.742 .13709 Mdot
.742 .13714 Mdot
.742 .13723 Mdot
.742 .13868 Mdot
.742 .14081 Mdot
.742 .14108 Mdot
.742 .14167 Mdot
.742 .14319 Mdot
.742 .14601 Mdot
.742 .14612 Mdot
.742 .14677 Mdot
.742 .14755 Mdot
.742 .14789 Mdot
.742 .14877 Mdot
.742 .1489 Mdot
.742 .1495 Mdot
.742 .1496 Mdot
.742 .14977 Mdot
.742 .15028 Mdot
.742 .15059 Mdot
.742 .15089 Mdot
.742 .15143 Mdot
.742 .15255 Mdot
.742 .15263 Mdot
.742 .1528 Mdot
.742 .15502 Mdot
.742 .15576 Mdot
.742 .15761 Mdot
.742 .15765 Mdot
.742 .15801 Mdot
.742 .16063 Mdot
.742 .16286 Mdot
.742 .16334 Mdot
.742 .16352 Mdot
.742 .16384 Mdot
.742 .16413 Mdot
.742 .16413 Mdot
.742 .16415 Mdot
.742 .16423 Mdot
.742 .16458 Mdot
.742 .1646 Mdot
.742 .16463 Mdot
.742 .16467 Mdot
.742 .16508 Mdot
.742 .1651 Mdot
.742 .16541 Mdot
.742 .16579 Mdot
.742 .16605 Mdot
.742 .16628 Mdot
.742 .16634 Mdot
.742 .16635 Mdot
.742 .1665 Mdot
.742 .16689 Mdot
.742 .16732 Mdot
.742 .1674 Mdot
.742 .16763 Mdot
.742 .16775 Mdot
.742 .16792 Mdot
.742 .16899 Mdot
.742 .16918 Mdot
.742 .17024 Mdot
.742 .17026 Mdot
.742 .17031 Mdot
.742 .17144 Mdot
.742 .17226 Mdot
.742 .17335 Mdot
.742 .17396 Mdot
.742 .1744 Mdot
.742 .17551 Mdot
.742 .17587 Mdot
.742 .17625 Mdot
.742 .17671 Mdot
.742 .17686 Mdot
.742 .17856 Mdot
.742 .17915 Mdot
.742 .1802 Mdot
.742 .18035 Mdot
.742 .18078 Mdot
.742 .18097 Mdot
.742 .18258 Mdot
.742 .18455 Mdot
.742 .18532 Mdot
.742 .18567 Mdot
.742 .18657 Mdot
.742 .18692 Mdot
.742 .18993 Mdot
.742 .19051 Mdot
.742 .19087 Mdot
.742 .19138 Mdot
.742 .1919 Mdot
.742 .19215 Mdot
.742 .19235 Mdot
.742 .19265 Mdot
.742 .19329 Mdot
.742 .19347 Mdot
.742 .1939 Mdot
.742 .19595 Mdot
.742 .19895 Mdot
.742 .19947 Mdot
.742 .19994 Mdot
.742 .20084 Mdot
.742 .20094 Mdot
.742 .20098 Mdot
.742 .20112 Mdot
.742 .20387 Mdot
.742 .2048 Mdot
.742 .20531 Mdot
.742 .20537 Mdot
.742 .20544 Mdot
.742 .20553 Mdot
.742 .20626 Mdot
.742 .20639 Mdot
.742 .20643 Mdot
.742 .20692 Mdot
.742 .20739 Mdot
.742 .20741 Mdot
.742 .20888 Mdot
.742 .20977 Mdot
.742 .21031 Mdot
.742 .21058 Mdot
.742 .21095 Mdot
.742 .21138 Mdot
.742 .21201 Mdot
.742 .21275 Mdot
.742 .2163 Mdot
.742 .21739 Mdot
.742 .21869 Mdot
.742 .22164 Mdot
.742 .222 Mdot
.742 .22224 Mdot
.742 .22266 Mdot
.742 .22271 Mdot
.742 .22331 Mdot
.742 .22368 Mdot
.742 .22375 Mdot
.742 .22524 Mdot
.742 .2266 Mdot
.742 .22829 Mdot
.742 .22924 Mdot
.742 .23056 Mdot
.742 .23069 Mdot
.742 .23071 Mdot
.742 .23073 Mdot
.742 .23154 Mdot
.742 .23223 Mdot
.742 .23417 Mdot
.742 .23439 Mdot
.742 .23468 Mdot
.742 .2347 Mdot
.742 .23489 Mdot
.742 .23521 Mdot
.742 .23523 Mdot
.742 .23528 Mdot
.742 .2353 Mdot
.742 .23542 Mdot
.742 .2355 Mdot
.742 .23638 Mdot
.742 .23692 Mdot
.742 .23698 Mdot
.742 .23781 Mdot
.742 .23843 Mdot
.742 .24395 Mdot
.742 .24437 Mdot
.742 .24597 Mdot
.742 .24652 Mdot
.742 .24833 Mdot
.742 .24838 Mdot
.742 .24844 Mdot
.742 .24881 Mdot
.742 .25269 Mdot
.742 .25444 Mdot
.742 .25552 Mdot
.742 .25804 Mdot
.742 .25963 Mdot
.742 .25981 Mdot
.742 .26036 Mdot
.742 .26058 Mdot
.742 .26368 Mdot
.742 .264 Mdot
.742 .26456 Mdot
.742 .26468 Mdot
.742 .26607 Mdot
.742 .26924 Mdot
.742 .26948 Mdot
.742 .2706 Mdot
.742 .27246 Mdot
.742 .27263 Mdot
.742 .27336 Mdot
.742 .27372 Mdot
.742 .27392 Mdot
.742 .27466 Mdot
.742 .27577 Mdot
.742 .27704 Mdot
.742 .28119 Mdot
.742 .28303 Mdot
.742 .28444 Mdot
.742 .28506 Mdot
.742 .28529 Mdot
.742 .28636 Mdot
.742 .2892 Mdot
.742 .2926 Mdot
.742 .29268 Mdot
.742 .29333 Mdot
.742 .29774 Mdot
.742 .30038 Mdot
.742 .30193 Mdot
.742 .30288 Mdot
.742 .30298 Mdot
.742 .30419 Mdot
.742 .3042 Mdot
.742 .30484 Mdot
.742 .30533 Mdot
.742 .30661 Mdot
.742 .30682 Mdot
.742 .30869 Mdot
.742 .30869 Mdot
.742 .30954 Mdot
.742 .31008 Mdot
.742 .31127 Mdot
.742 .31133 Mdot
.742 .3122 Mdot
.742 .31222 Mdot
.742 .314 Mdot
.742 .31485 Mdot
.742 .31624 Mdot
.742 .31694 Mdot
.742 .31695 Mdot
.742 .31812 Mdot
.742 .31868 Mdot
.742 .32098 Mdot
.742 .3216 Mdot
.742 .32181 Mdot
.742 .32188 Mdot
.742 .32245 Mdot
.742 .32345 Mdot
.742 .32372 Mdot
.742 .32486 Mdot
.742 .3251 Mdot
.742 .32524 Mdot
.742 .3253 Mdot
.742 .32565 Mdot
.742 .32576 Mdot
.742 .32699 Mdot
.742 .32809 Mdot
.742 .3284 Mdot
.742 .32863 Mdot
.742 .32883 Mdot
.742 .32941 Mdot
.742 .33055 Mdot
.742 .33149 Mdot
.742 .33149 Mdot
.742 .33184 Mdot
.742 .33185 Mdot
.742 .33351 Mdot
.742 .33355 Mdot
.742 .33368 Mdot
.742 .33707 Mdot
.742 .33756 Mdot
.742 .33877 Mdot
.742 .34091 Mdot
.742 .34146 Mdot
.742 .34202 Mdot
.742 .34287 Mdot
.742 .34297 Mdot
.742 .34344 Mdot
.742 .34356 Mdot
.742 .34391 Mdot
.742 .34545 Mdot
.742 .34697 Mdot
.742 .34858 Mdot
.742 .35033 Mdot
.742 .3516 Mdot
.742 .35186 Mdot
.742 .35214 Mdot
.742 .3523 Mdot
.742 .3523 Mdot
.742 .35231 Mdot
.742 .35236 Mdot
.742 .35255 Mdot
.742 .35256 Mdot
.742 .35258 Mdot
.742 .3526 Mdot
.742 .35282 Mdot
.742 .35283 Mdot
.742 .35301 Mdot
.742 .35321 Mdot
.742 .35351 Mdot
.742 .35351 Mdot
.742 .3536 Mdot
.742 .3538 Mdot
.742 .35407 Mdot
.742 .3542 Mdot
.742 .35426 Mdot
.742 .35492 Mdot
.742 .35502 Mdot
.742 .35557 Mdot
.742 .35557 Mdot
.742 .35618 Mdot
.742 .3566 Mdot
.742 .35715 Mdot
.742 .35859 Mdot
.742 .35881 Mdot
.742 .35888 Mdot
.742 .35971 Mdot
.742 .36049 Mdot
.742 .36056 Mdot
.742 .36076 Mdot
.742 .36085 Mdot
.742 .36161 Mdot
.742 .36287 Mdot
.742 .36303 Mdot
.742 .36343 Mdot
.742 .36493 Mdot
.742 .36519 Mdot
.742 .36557 Mdot
.742 .3658 Mdot
.742 .36591 Mdot
.742 .36599 Mdot
.742 .36613 Mdot
.742 .3664 Mdot
.742 .36648 Mdot
.742 .36666 Mdot
.742 .36754 Mdot
.742 .36881 Mdot
.742 .36902 Mdot
.742 .36963 Mdot
.742 .37083 Mdot
.742 .37121 Mdot
.742 .37142 Mdot
.742 .37144 Mdot
.742 .37147 Mdot
.742 .3718 Mdot
.742 .37185 Mdot
.742 .37187 Mdot
.742 .37225 Mdot
.742 .37226 Mdot
.742 .37285 Mdot
.742 .3732 Mdot
.742 .37341 Mdot
.742 .37352 Mdot
.742 .37383 Mdot
.742 .37437 Mdot
.742 .37574 Mdot
.742 .37616 Mdot
.742 .37665 Mdot
.742 .37777 Mdot
.742 .3779 Mdot
.742 .37799 Mdot
.742 .37814 Mdot
.742 .37816 Mdot
.742 .37839 Mdot
.742 .37853 Mdot
.742 .37855 Mdot
.742 .37911 Mdot
.742 .38057 Mdot
.742 .3811 Mdot
.742 .38111 Mdot
.742 .38141 Mdot
.742 .38235 Mdot
.742 .38243 Mdot
.742 .38254 Mdot
.742 .38272 Mdot
.742 .38275 Mdot
.742 .38594 Mdot
.742 .38669 Mdot
.742 .38938 Mdot
.742 .39059 Mdot
.742 .39112 Mdot
.742 .39118 Mdot
.742 .39136 Mdot
.742 .39246 Mdot
.742 .39257 Mdot
.742 .39275 Mdot
.742 .39324 Mdot
.742 .39561 Mdot
.742 .39573 Mdot
.742 .3968 Mdot
.742 .39812 Mdot
.742 .3987 Mdot
.742 .39915 Mdot
.742 .39941 Mdot
.742 .39975 Mdot
.742 .4017 Mdot
.742 .40193 Mdot
.742 .4033 Mdot
.742 .40411 Mdot
.742 .40459 Mdot
.742 .40488 Mdot
.742 .40491 Mdot
.742 .40528 Mdot
.742 .40548 Mdot
.742 .40563 Mdot
.742 .40609 Mdot
.742 .40666 Mdot
.742 .40691 Mdot
.742 .40744 Mdot
.742 .40772 Mdot
.742 .40852 Mdot
.742 .40894 Mdot
.742 .40916 Mdot
.742 .40951 Mdot
.742 .40968 Mdot
.742 .41037 Mdot
.742 .41056 Mdot
.742 .41081 Mdot
.742 .41119 Mdot
.742 .41153 Mdot
.742 .41167 Mdot
.742 .4118 Mdot
.742 .41217 Mdot
.742 .41289 Mdot
.742 .41351 Mdot
.742 .41351 Mdot
.742 .41361 Mdot
.742 .41362 Mdot
.742 .41411 Mdot
.742 .41412 Mdot
.742 .41517 Mdot
.742 .41531 Mdot
.742 .41567 Mdot
.742 .4163 Mdot
.742 .41647 Mdot
.742 .41663 Mdot
.742 .41688 Mdot
.742 .41765 Mdot
.742 .41946 Mdot
.742 .41953 Mdot
.742 .41961 Mdot
.742 .4201 Mdot
.742 .42151 Mdot
.742 .42157 Mdot
.742 .42276 Mdot
.742 .4238 Mdot
.742 .42521 Mdot
.742 .42528 Mdot
.742 .42528 Mdot
.742 .42539 Mdot
.742 .42579 Mdot
.742 .42597 Mdot
.742 .4268 Mdot
.742 .42719 Mdot
.742 .42724 Mdot
.742 .42731 Mdot
.742 .42819 Mdot
.742 .42858 Mdot
.742 .42974 Mdot
.742 .43053 Mdot
.742 .43104 Mdot
.742 .43152 Mdot
.742 .43166 Mdot
.742 .4331 Mdot
.742 .43327 Mdot
.742 .4334 Mdot
.742 .43358 Mdot
.742 .43487 Mdot
.742 .43501 Mdot
.742 .43509 Mdot
.742 .43521 Mdot
.742 .43527 Mdot
.742 .43562 Mdot
.742 .4357 Mdot
.742 .43617 Mdot
.742 .43651 Mdot
.742 .43672 Mdot
.742 .43685 Mdot
.742 .4371 Mdot
.742 .43765 Mdot
.742 .43765 Mdot
.742 .43768 Mdot
.742 .43783 Mdot
.742 .43848 Mdot
.742 .43853 Mdot
.742 .43858 Mdot
.742 .43866 Mdot
.742 .43943 Mdot
.742 .43945 Mdot
.742 .44004 Mdot
.742 .44042 Mdot
.742 .44073 Mdot
.742 .44121 Mdot
.742 .44163 Mdot
.742 .44175 Mdot
.742 .44176 Mdot
.742 .44205 Mdot
.742 .44276 Mdot
.742 .44306 Mdot
.742 .4431 Mdot
.742 .44354 Mdot
.742 .44359 Mdot
.742 .44368 Mdot
.742 .44412 Mdot
.742 .44414 Mdot
.742 .44418 Mdot
.742 .4443 Mdot
.742 .44433 Mdot
.742 .44464 Mdot
.742 .44658 Mdot
.742 .44675 Mdot
.742 .44692 Mdot
.742 .44693 Mdot
.742 .44697 Mdot
.742 .44883 Mdot
.742 .44885 Mdot
.742 .44895 Mdot
.742 .4503 Mdot
.742 .45036 Mdot
.742 .45038 Mdot
.742 .45069 Mdot
.742 .45096 Mdot
.742 .45098 Mdot
.742 .45241 Mdot
.742 .45433 Mdot
.742 .4544 Mdot
.742 .45495 Mdot
.742 .45499 Mdot
.742 .4552 Mdot
.742 .45527 Mdot
.742 .45531 Mdot
.742 .45539 Mdot
.742 .45607 Mdot
.742 .45616 Mdot
.742 .45623 Mdot
.742 .45632 Mdot
.742 .45707 Mdot
.742 .45715 Mdot
.742 .45767 Mdot
.742 .45808 Mdot
.742 .45868 Mdot
.742 .45888 Mdot
.742 .45934 Mdot
.742 .45938 Mdot
.742 .4594 Mdot
.742 .4596 Mdot
.742 .46012 Mdot
.742 .46032 Mdot
.742 .46038 Mdot
.742 .46114 Mdot
.742 .46167 Mdot
.742 .4623 Mdot
.742 .46326 Mdot
.742 .4633 Mdot
.742 .46334 Mdot
.742 .46425 Mdot
.742 .46463 Mdot
.742 .46475 Mdot
.742 .46483 Mdot
.742 .46491 Mdot
.742 .466 Mdot
.742 .466 Mdot
.742 .46625 Mdot
.742 .46625 Mdot
.742 .4663 Mdot
.742 .4663 Mdot
.742 .46696 Mdot
.742 .46721 Mdot
.742 .46727 Mdot
.742 .46763 Mdot
.742 .46784 Mdot
.742 .46818 Mdot
.742 .46874 Mdot
.742 .46952 Mdot
.742 .46964 Mdot
.742 .46992 Mdot
.742 .47021 Mdot
.742 .47031 Mdot
.742 .4705 Mdot
.742 .47064 Mdot
.742 .47087 Mdot
.742 .47295 Mdot
.742 .47311 Mdot
.742 .47323 Mdot
.742 .47344 Mdot
.742 .47372 Mdot
.742 .47434 Mdot
.742 .47489 Mdot
.742 .476 Mdot
.742 .47623 Mdot
.742 .47631 Mdot
.742 .47687 Mdot
.742 .47698 Mdot
.742 .47778 Mdot
.742 .47902 Mdot
.742 .48082 Mdot
.742 .48141 Mdot
.742 .48154 Mdot
.742 .48244 Mdot
.742 .48276 Mdot
.742 .48287 Mdot
.742 .48294 Mdot
.742 .48298 Mdot
.742 .48353 Mdot
.742 .48375 Mdot
.742 .48455 Mdot
.742 .48478 Mdot
.742 .48492 Mdot
.742 .48506 Mdot
.742 .48522 Mdot
.742 .48566 Mdot
.742 .48568 Mdot
.742 .48582 Mdot
.742 .48584 Mdot
.742 .48594 Mdot
.742 .48663 Mdot
.742 .48689 Mdot
.742 .48754 Mdot
.742 .48803 Mdot
.742 .48956 Mdot
.742 .49055 Mdot
.742 .49129 Mdot
.742 .49139 Mdot
.742 .49341 Mdot
.742 .49411 Mdot
.742 .49423 Mdot
.742 .49434 Mdot
.742 .49487 Mdot
.742 .4956 Mdot
.742 .49626 Mdot
.742 .49689 Mdot
.742 .49753 Mdot
.742 .49767 Mdot
.742 .49772 Mdot
.742 .49792 Mdot
.742 .49796 Mdot
.742 .49831 Mdot
.742 .49853 Mdot
.742 .49876 Mdot
.742 .49963 Mdot
.742 .50012 Mdot
.742 .50032 Mdot
.742 .50169 Mdot
.742 .50175 Mdot
.742 .50176 Mdot
.742 .50243 Mdot
.742 .50243 Mdot
.742 .50257 Mdot
.742 .50257 Mdot
.742 .50295 Mdot
.742 .5034 Mdot
.742 .50363 Mdot
.742 .50371 Mdot
.742 .50381 Mdot
.742 .50393 Mdot
.742 .50437 Mdot
.742 .50486 Mdot
.742 .5049 Mdot
.742 .50504 Mdot
.742 .50506 Mdot
.742 .50512 Mdot
.742 .50521 Mdot
.742 .50566 Mdot
.742 .50577 Mdot
.742 .50616 Mdot
.742 .50639 Mdot
.742 .50641 Mdot
.742 .5065 Mdot
.742 .50674 Mdot
.742 .50764 Mdot
.742 .50786 Mdot
.742 .50831 Mdot
.742 .50832 Mdot
.742 .50859 Mdot
.742 .50913 Mdot
.742 .50946 Mdot
.742 .51015 Mdot
.742 .51016 Mdot
.742 .51049 Mdot
.742 .51051 Mdot
.742 .51097 Mdot
.742 .51118 Mdot
.742 .5115 Mdot
.742 .5115 Mdot
.742 .51222 Mdot
.742 .5123 Mdot
.742 .51279 Mdot
.742 .51297 Mdot
.742 .51322 Mdot
.742 .51322 Mdot
.742 .51368 Mdot
.742 .51372 Mdot
.742 .51408 Mdot
.742 .51467 Mdot
.742 .51566 Mdot
.742 .5173 Mdot
.742 .51755 Mdot
.742 .51758 Mdot
.742 .51884 Mdot
.742 .51989 Mdot
.742 .52028 Mdot
.742 .52037 Mdot
.742 .52059 Mdot
.742 .52111 Mdot
.742 .52178 Mdot
.742 .52329 Mdot
.742 .52375 Mdot
.742 .52415 Mdot
.742 .52442 Mdot
.742 .52449 Mdot
.742 .52462 Mdot
.742 .52488 Mdot
.742 .52494 Mdot
.742 .52561 Mdot
.742 .52601 Mdot
.742 .52609 Mdot
.742 .52722 Mdot
.742 .52772 Mdot
.742 .52776 Mdot
.742 .52796 Mdot
.742 .52807 Mdot
.742 .52917 Mdot
.742 .52925 Mdot
.742 .52944 Mdot
.742 .5295 Mdot
.742 .53006 Mdot
.742 .53094 Mdot
.742 .53132 Mdot
.742 .53193 Mdot
.742 .53327 Mdot
.742 .5334 Mdot
.742 .53342 Mdot
.742 .53344 Mdot
.742 .53407 Mdot
.742 .53426 Mdot
.742 .53481 Mdot
.742 .53495 Mdot
.742 .53684 Mdot
.742 .53705 Mdot
.742 .53733 Mdot
.742 .53735 Mdot
.742 .53754 Mdot
.742 .53783 Mdot
.742 .53786 Mdot
.742 .5379 Mdot
.742 .53791 Mdot
.742 .53792 Mdot
.742 .53793 Mdot
.742 .53804 Mdot
.742 .5381 Mdot
.742 .53811 Mdot
.742 .53821 Mdot
.742 .53829 Mdot
.742 .53894 Mdot
.742 .53917 Mdot
.742 .53945 Mdot
.742 .53945 Mdot
.742 .53946 Mdot
.742 .5395 Mdot
.742 .53995 Mdot
.742 .54027 Mdot
.742 .54083 Mdot
.742 .54129 Mdot
.742 .54178 Mdot
.742 .54181 Mdot
.742 .54193 Mdot
.742 .54213 Mdot
.742 .54215 Mdot
.742 .54229 Mdot
.742 .54237 Mdot
.742 .54248 Mdot
.742 .54346 Mdot
.742 .54389 Mdot
.742 .54425 Mdot
.742 .54542 Mdot
.742 .54566 Mdot
.742 .54587 Mdot
.742 .54601 Mdot
.742 .54613 Mdot
.742 .54622 Mdot
.742 .5464 Mdot
.742 .54669 Mdot
.742 .54717 Mdot
.742 .54717 Mdot
.742 .54733 Mdot
.742 .54749 Mdot
.742 .5475 Mdot
.742 .54754 Mdot
.742 .54778 Mdot
.742 .54781 Mdot
.742 .54783 Mdot
.742 .54785 Mdot
.742 .54802 Mdot
.742 .54832 Mdot
.742 .54921 Mdot
.742 .54925 Mdot
.742 .54926 Mdot
.742 .5493 Mdot
.742 .54959 Mdot
.742 .54974 Mdot
.742 .54991 Mdot
.742 .55087 Mdot
.742 .55153 Mdot
.742 .55167 Mdot
.742 .55172 Mdot
.742 .55193 Mdot
.742 .55202 Mdot
.742 .55209 Mdot
.742 .55217 Mdot
.742 .55233 Mdot
.742 .5525 Mdot
.742 .55261 Mdot
.742 .5528 Mdot
.742 .55375 Mdot
.742 .55386 Mdot
.742 .55415 Mdot
.742 .55426 Mdot
.742 .5545 Mdot
.742 .55512 Mdot
.742 .55563 Mdot
.742 .55569 Mdot
.742 .55583 Mdot
.742 .55587 Mdot
.742 .5562 Mdot
.742 .55639 Mdot
.742 .55692 Mdot
.742 .55697 Mdot
.742 .55711 Mdot
.742 .55723 Mdot
.742 .55734 Mdot
.742 .55769 Mdot
.742 .55783 Mdot
.742 .55801 Mdot
.742 .55835 Mdot
.742 .55861 Mdot
.742 .55896 Mdot
.742 .55898 Mdot
.742 .55898 Mdot
.742 .55931 Mdot
.742 .55937 Mdot
.742 .5597 Mdot
.742 .55975 Mdot
.742 .55979 Mdot
.742 .55986 Mdot
.742 .55989 Mdot
.742 .56002 Mdot
.742 .56014 Mdot
.742 .56019 Mdot
.742 .56019 Mdot
.742 .56021 Mdot
.742 .56028 Mdot
.742 .56036 Mdot
.742 .56048 Mdot
.742 .56057 Mdot
.742 .56058 Mdot
.742 .56071 Mdot
.742 .56072 Mdot
.742 .56073 Mdot
.742 .56073 Mdot
.742 .56084 Mdot
.742 .56087 Mdot
.742 .56087 Mdot
.742 .56087 Mdot
.742 .56096 Mdot
.742 .56106 Mdot
.742 .56112 Mdot
.742 .56126 Mdot
.742 .56195 Mdot
.742 .56275 Mdot
.742 .56286 Mdot
.742 .56287 Mdot
.742 .56344 Mdot
.742 .56366 Mdot
.742 .56434 Mdot
.742 .56439 Mdot
.742 .56441 Mdot
.742 .56475 Mdot
.742 .56492 Mdot
.742 .56501 Mdot
.742 .5651 Mdot
.742 .56526 Mdot
.742 .56531 Mdot
.742 .56534 Mdot
.742 .56552 Mdot
.742 .56556 Mdot
.742 .56582 Mdot
.742 .56593 Mdot
.742 .56616 Mdot
.742 .56636 Mdot
.742 .56639 Mdot
.742 .56724 Mdot
.742 .5677 Mdot
.742 .56787 Mdot
.742 .56796 Mdot
.742 .56859 Mdot
.742 .56903 Mdot
.742 .56905 Mdot
.742 .56907 Mdot
.742 .56908 Mdot
.742 .56925 Mdot
.742 .56932 Mdot
.742 .56959 Mdot
.742 .56959 Mdot
.742 .56964 Mdot
.742 .56969 Mdot
.742 .56969 Mdot
.742 .56996 Mdot
.742 .57027 Mdot
.742 .57042 Mdot
.742 .57042 Mdot
.742 .57047 Mdot
.742 .57053 Mdot
.742 .5706 Mdot
.742 .57086 Mdot
.742 .57114 Mdot
.742 .57116 Mdot
.742 .57121 Mdot
.742 .57123 Mdot
.742 .57124 Mdot
.742 .57125 Mdot
.742 .57128 Mdot
.742 .57133 Mdot
.742 .57136 Mdot
.742 .57155 Mdot
.742 .57161 Mdot
.742 .57179 Mdot
.742 .57188 Mdot
.742 .57189 Mdot
.742 .57193 Mdot
.742 .57202 Mdot
.742 .57213 Mdot
.742 .57234 Mdot
.742 .57241 Mdot
.742 .57247 Mdot
.742 .57254 Mdot
.742 .57254 Mdot
.742 .57261 Mdot
.742 .57262 Mdot
.742 .5727 Mdot
.742 .57271 Mdot
.742 .57273 Mdot
.742 .57279 Mdot
.742 .5728 Mdot
.742 .5728 Mdot
.742 .57283 Mdot
.742 .57286 Mdot
.742 .57288 Mdot
.742 .57288 Mdot
.742 .57291 Mdot
.742 .57291 Mdot
.742 .57291 Mdot
.742 .57292 Mdot
.742 .57294 Mdot
.742 .57295 Mdot
.742 .57295 Mdot
.742 .57295 Mdot
.744 .12323 Mdot
.744 .12324 Mdot
.744 .12327 Mdot
.744 .12336 Mdot
.744 .12339 Mdot
.744 .12353 Mdot
.744 .12374 Mdot
.744 .12375 Mdot
.744 .12421 Mdot
.744 .12425 Mdot
.744 .12436 Mdot
.744 .12445 Mdot
.744 .12459 Mdot
.744 .12464 Mdot
.744 .12468 Mdot
.744 .12523 Mdot
.744 .12551 Mdot
.744 .12566 Mdot
.744 .12576 Mdot
.744 .12586 Mdot
.744 .12622 Mdot
.744 .12668 Mdot
.744 .12674 Mdot
.744 .12698 Mdot
.744 .127 Mdot
.744 .12758 Mdot
.744 .12897 Mdot
.744 .12916 Mdot
.744 .12956 Mdot
.744 .13008 Mdot
.744 .13013 Mdot
.744 .13031 Mdot
.744 .13038 Mdot
.744 .13046 Mdot
.744 .13073 Mdot
.744 .13099 Mdot
.744 .13103 Mdot
.744 .13153 Mdot
.744 .1316 Mdot
.744 .1318 Mdot
.744 .13214 Mdot
.744 .13219 Mdot
.744 .13236 Mdot
.744 .13305 Mdot
.744 .13337 Mdot
.744 .13473 Mdot
.744 .13565 Mdot
.744 .1363 Mdot
.744 .13691 Mdot
.744 .13692 Mdot
.744 .13815 Mdot
.744 .13829 Mdot
.744 .13845 Mdot
.744 .13899 Mdot
.744 .13924 Mdot
.744 .13946 Mdot
.744 .13991 Mdot
.744 .14057 Mdot
.744 .14071 Mdot
.744 .14084 Mdot
.744 .14102 Mdot
.744 .14195 Mdot
.744 .14219 Mdot
.744 .14472 Mdot
.744 .14555 Mdot
.744 .14569 Mdot
.744 .14656 Mdot
.744 .14684 Mdot
.744 .1486 Mdot
.744 .14912 Mdot
.744 .14947 Mdot
.744 .15106 Mdot
.744 .15225 Mdot
.744 .15274 Mdot
.744 .15451 Mdot
.744 .15544 Mdot
.744 .15927 Mdot
.744 .15991 Mdot
.744 .16036 Mdot
.744 .16047 Mdot
.744 .16049 Mdot
.744 .16061 Mdot
.744 .16101 Mdot
.744 .16103 Mdot
.744 .16115 Mdot
.744 .16125 Mdot
.744 .16175 Mdot
.744 .16264 Mdot
.744 .16265 Mdot
.744 .1627 Mdot
.744 .16351 Mdot
.744 .16386 Mdot
.744 .16392 Mdot
.744 .16404 Mdot
.744 .16467 Mdot
.744 .16482 Mdot
.744 .16507 Mdot
.744 .16532 Mdot
.744 .16571 Mdot
.744 .16636 Mdot
.744 .16656 Mdot
.744 .16674 Mdot
.744 .16725 Mdot
.744 .16732 Mdot
.744 .1679 Mdot
.744 .16911 Mdot
.744 .16926 Mdot
.744 .17051 Mdot
.744 .17123 Mdot
.744 .17168 Mdot
.744 .17186 Mdot
.744 .17214 Mdot
.744 .17223 Mdot
.744 .17362 Mdot
.744 .17386 Mdot
.744 .1751 Mdot
.744 .17575 Mdot
.744 .17608 Mdot
.744 .17637 Mdot
.744 .17642 Mdot
.744 .17679 Mdot
.744 .17753 Mdot
.744 .17763 Mdot
.744 .17787 Mdot
.744 .17819 Mdot
.744 .17986 Mdot
.744 .17989 Mdot
.744 .18046 Mdot
.744 .18048 Mdot
.744 .18084 Mdot
.744 .1813 Mdot
.744 .18185 Mdot
.744 .18227 Mdot
.744 .18252 Mdot
.744 .18475 Mdot
.744 .18542 Mdot
.744 .18567 Mdot
.744 .18758 Mdot
.744 .18817 Mdot
.744 .18849 Mdot
.744 .18855 Mdot
.744 .18862 Mdot
.744 .19039 Mdot
.744 .19068 Mdot
.744 .19106 Mdot
.744 .19147 Mdot
.744 .19148 Mdot
.744 .19262 Mdot
.744 .19346 Mdot
.744 .19371 Mdot
.744 .19443 Mdot
.744 .19466 Mdot
.744 .19472 Mdot
.744 .19504 Mdot
.744 .19546 Mdot
.744 .19611 Mdot
.744 .19697 Mdot
.744 .19817 Mdot
.744 .19819 Mdot
.744 .19839 Mdot
.744 .19863 Mdot
.744 .20135 Mdot
.744 .20154 Mdot
.744 .20157 Mdot
.744 .20175 Mdot
.744 .20287 Mdot
.744 .20427 Mdot
.744 .20479 Mdot
.744 .20509 Mdot
.744 .20521 Mdot
.744 .20527 Mdot
.744 .20569 Mdot
.744 .20603 Mdot
.744 .2062 Mdot
.744 .21002 Mdot
.744 .21189 Mdot
.744 .21319 Mdot
.744 .21407 Mdot
.744 .21437 Mdot
.744 .21472 Mdot
.744 .21499 Mdot
.744 .21515 Mdot
.744 .21517 Mdot
.744 .21661 Mdot
.744 .21668 Mdot
.744 .21694 Mdot
.744 .21889 Mdot
.744 .21928 Mdot
.744 .21989 Mdot
.744 .21993 Mdot
.744 .22025 Mdot
.744 .22141 Mdot
.744 .22233 Mdot
.744 .22502 Mdot
.744 .22541 Mdot
.744 .22542 Mdot
.744 .22552 Mdot
.744 .227 Mdot
.744 .22941 Mdot
.744 .22968 Mdot
.744 .23127 Mdot
.744 .23318 Mdot
.744 .23322 Mdot
.744 .23337 Mdot
.744 .2341 Mdot
.744 .23576 Mdot
.744 .23709 Mdot
.744 .23807 Mdot
.744 .24013 Mdot
.744 .24057 Mdot
.744 .24069 Mdot
.744 .24094 Mdot
.744 .24182 Mdot
.744 .24195 Mdot
.744 .24267 Mdot
.744 .24281 Mdot
.744 .24326 Mdot
.744 .24601 Mdot
.744 .24622 Mdot
.744 .24628 Mdot
.744 .24638 Mdot
.744 .24789 Mdot
.744 .2479 Mdot
.744 .24929 Mdot
.744 .25087 Mdot
.744 .25165 Mdot
.744 .25214 Mdot
.744 .25232 Mdot
.744 .25483 Mdot
.744 .25647 Mdot
.744 .25694 Mdot
.744 .25711 Mdot
.744 .25738 Mdot
.744 .2574 Mdot
.744 .25819 Mdot
.744 .25886 Mdot
.744 .25937 Mdot
.744 .25968 Mdot
.744 .26334 Mdot
.744 .26364 Mdot
.744 .26368 Mdot
.744 .26484 Mdot
.744 .2655 Mdot
.744 .26708 Mdot
.744 .26772 Mdot
.744 .26809 Mdot
.744 .27037 Mdot
.744 .27205 Mdot
.744 .27237 Mdot
.744 .27314 Mdot
.744 .27443 Mdot
.744 .27479 Mdot
.744 .27601 Mdot
.744 .27967 Mdot
.744 .28042 Mdot
.744 .28056 Mdot
.744 .28067 Mdot
.744 .28078 Mdot
.744 .2819 Mdot
.744 .28258 Mdot
.744 .28272 Mdot
.744 .28396 Mdot
.744 .28396 Mdot
.744 .28453 Mdot
.744 .28954 Mdot
.744 .29018 Mdot
.744 .2905 Mdot
.744 .29103 Mdot
.744 .29126 Mdot
.744 .2959 Mdot
.744 .29594 Mdot
.744 .29636 Mdot
.744 .29647 Mdot
.744 .29734 Mdot
.744 .29828 Mdot
.744 .29849 Mdot
.744 .29946 Mdot
.744 .3009 Mdot
.744 .30101 Mdot
.744 .30114 Mdot
.744 .30157 Mdot
.744 .30222 Mdot
.744 .30234 Mdot
.744 .30631 Mdot
.744 .30658 Mdot
.744 .30915 Mdot
.744 .30954 Mdot
.744 .31025 Mdot
.744 .31273 Mdot
.744 .31384 Mdot
.744 .31385 Mdot
.744 .31618 Mdot
.744 .3192 Mdot
.744 .31996 Mdot
.744 .3231 Mdot
.744 .32521 Mdot
.744 .32547 Mdot
.744 .32603 Mdot
.744 .32671 Mdot
.744 .32709 Mdot
.744 .32719 Mdot
.744 .3279 Mdot
.744 .32858 Mdot
.744 .32881 Mdot
.744 .3292 Mdot
.744 .32926 Mdot
.744 .32945 Mdot
.744 .33022 Mdot
.744 .33057 Mdot
.744 .33197 Mdot
.744 .33287 Mdot
.744 .33519 Mdot
.744 .33592 Mdot
.744 .33632 Mdot
.744 .3367 Mdot
.744 .33855 Mdot
.744 .34049 Mdot
.744 .3411 Mdot
.744 .3412 Mdot
.744 .34182 Mdot
.744 .34384 Mdot
.744 .34709 Mdot
.744 .35057 Mdot
.744 .35063 Mdot
.744 .35065 Mdot
.744 .35071 Mdot
.744 .35094 Mdot
.744 .35102 Mdot
.744 .35107 Mdot
.744 .35136 Mdot
.744 .35185 Mdot
.744 .35186 Mdot
.744 .35189 Mdot
.744 .35234 Mdot
.744 .35256 Mdot
.744 .35263 Mdot
.744 .35297 Mdot
.744 .35306 Mdot
.744 .35332 Mdot
.744 .35353 Mdot
.744 .35388 Mdot
.744 .35399 Mdot
.744 .35408 Mdot
.744 .35533 Mdot
.744 .35541 Mdot
.744 .35605 Mdot
.744 .35642 Mdot
.744 .35665 Mdot
.744 .35673 Mdot
.744 .35688 Mdot
.744 .35692 Mdot
.744 .35762 Mdot
.744 .35774 Mdot
.744 .35883 Mdot
.744 .35897 Mdot
.744 .35899 Mdot
.744 .35953 Mdot
.744 .35957 Mdot
.744 .35969 Mdot
.744 .36093 Mdot
.744 .36131 Mdot
.744 .36176 Mdot
.744 .36188 Mdot
.744 .3629 Mdot
.744 .36332 Mdot
.744 .36418 Mdot
.744 .36444 Mdot
.744 .36458 Mdot
.744 .36461 Mdot
.744 .36464 Mdot
.744 .36542 Mdot
.744 .36554 Mdot
.744 .36589 Mdot
.744 .36675 Mdot
.744 .36686 Mdot
.744 .36726 Mdot
.744 .36728 Mdot
.744 .36742 Mdot
.744 .3676 Mdot
.744 .36787 Mdot
.744 .36824 Mdot
.744 .36875 Mdot
.744 .36883 Mdot
.744 .36893 Mdot
.744 .37006 Mdot
.744 .37022 Mdot
.744 .37068 Mdot
.744 .37124 Mdot
.744 .37145 Mdot
.744 .37158 Mdot
.744 .37162 Mdot
.744 .37196 Mdot
.744 .37354 Mdot
.744 .37427 Mdot
.744 .37511 Mdot
.744 .37547 Mdot
.744 .37553 Mdot
.744 .37553 Mdot
.744 .37611 Mdot
.744 .37695 Mdot
.744 .37733 Mdot
.744 .37824 Mdot
.744 .37924 Mdot
.744 .37938 Mdot
.744 .37938 Mdot
.744 .37942 Mdot
.744 .38084 Mdot
.744 .38151 Mdot
.744 .3822 Mdot
.744 .38221 Mdot
.744 .38253 Mdot
.744 .38312 Mdot
.744 .38359 Mdot
.744 .38494 Mdot
.744 .38525 Mdot
.744 .38529 Mdot
.744 .38554 Mdot
.744 .38559 Mdot
.744 .38575 Mdot
.744 .3867 Mdot
.744 .38679 Mdot
.744 .38682 Mdot
.744 .38734 Mdot
.744 .38734 Mdot
.744 .38782 Mdot
.744 .38879 Mdot
.744 .38885 Mdot
.744 .38969 Mdot
.744 .39024 Mdot
.744 .39039 Mdot
.744 .39045 Mdot
.744 .39054 Mdot
.744 .39055 Mdot
.744 .39081 Mdot
.744 .3912 Mdot
.744 .39131 Mdot
.744 .39322 Mdot
.744 .39374 Mdot
.744 .39395 Mdot
.744 .39407 Mdot
.744 .3948 Mdot
.744 .39535 Mdot
.744 .39545 Mdot
.744 .39623 Mdot
.744 .39802 Mdot
.744 .39807 Mdot
.744 .39849 Mdot
.744 .39871 Mdot
.744 .39914 Mdot
.744 .39932 Mdot
.744 .40089 Mdot
.744 .40119 Mdot
.744 .40301 Mdot
.744 .4036 Mdot
.744 .40441 Mdot
.744 .40444 Mdot
.744 .40448 Mdot
.744 .40461 Mdot
.744 .40481 Mdot
.744 .40606 Mdot
.744 .40692 Mdot
.744 .40704 Mdot
.744 .40726 Mdot
.744 .40834 Mdot
.744 .40835 Mdot
.744 .40905 Mdot
.744 .40996 Mdot
.744 .41018 Mdot
.744 .41113 Mdot
.744 .41176 Mdot
.744 .4122 Mdot
.744 .41232 Mdot
.744 .41256 Mdot
.744 .41296 Mdot
.744 .41302 Mdot
.744 .41335 Mdot
.744 .41403 Mdot
.744 .41472 Mdot
.744 .41494 Mdot
.744 .41506 Mdot
.744 .41572 Mdot
.744 .41727 Mdot
.744 .41823 Mdot
.744 .41925 Mdot
.744 .41977 Mdot
.744 .42065 Mdot
.744 .42112 Mdot
.744 .42132 Mdot
.744 .42172 Mdot
.744 .4224 Mdot
.744 .42253 Mdot
.744 .42287 Mdot
.744 .42336 Mdot
.744 .42374 Mdot
.744 .42415 Mdot
.744 .42531 Mdot
.744 .42644 Mdot
.744 .42654 Mdot
.744 .42673 Mdot
.744 .42768 Mdot
.744 .42769 Mdot
.744 .42831 Mdot
.744 .4286 Mdot
.744 .42878 Mdot
.744 .42891 Mdot
.744 .42982 Mdot
.744 .43001 Mdot
.744 .4307 Mdot
.744 .43091 Mdot
.744 .43092 Mdot
.744 .43095 Mdot
.744 .43117 Mdot
.744 .43195 Mdot
.744 .43198 Mdot
.744 .4322 Mdot
.744 .43239 Mdot
.744 .43314 Mdot
.744 .43316 Mdot
.744 .43335 Mdot
.744 .43353 Mdot
.744 .43502 Mdot
.744 .43503 Mdot
.744 .43505 Mdot
.744 .43508 Mdot
.744 .43514 Mdot
.744 .4358 Mdot
.744 .43666 Mdot
.744 .43701 Mdot
.744 .43733 Mdot
.744 .43743 Mdot
.744 .43767 Mdot
.744 .43787 Mdot
.744 .43884 Mdot
.744 .43912 Mdot
.744 .43958 Mdot
.744 .44004 Mdot
.744 .44037 Mdot
.744 .44065 Mdot
.744 .44077 Mdot
.744 .44089 Mdot
.744 .44158 Mdot
.744 .44196 Mdot
.744 .44214 Mdot
.744 .44232 Mdot
.744 .44266 Mdot
.744 .4436 Mdot
.744 .44361 Mdot
.744 .44372 Mdot
.744 .44419 Mdot
.744 .44478 Mdot
.744 .44504 Mdot
.744 .44596 Mdot
.744 .44698 Mdot
.744 .44724 Mdot
.744 .44948 Mdot
.744 .44999 Mdot
.744 .45046 Mdot
.744 .45078 Mdot
.744 .45158 Mdot
.744 .45188 Mdot
.744 .45226 Mdot
.744 .45238 Mdot
.744 .45254 Mdot
.744 .45388 Mdot
.744 .45434 Mdot
.744 .45498 Mdot
.744 .45537 Mdot
.744 .45539 Mdot
.744 .45619 Mdot
.744 .45638 Mdot
.744 .45639 Mdot
.744 .45755 Mdot
.744 .45803 Mdot
.744 .4586 Mdot
.744 .45867 Mdot
.744 .45891 Mdot
.744 .45923 Mdot
.744 .45924 Mdot
.744 .45973 Mdot
.744 .45983 Mdot
.744 .45988 Mdot
.744 .46046 Mdot
.744 .46105 Mdot
.744 .46126 Mdot
.744 .46145 Mdot
.744 .4617 Mdot
.744 .46187 Mdot
.744 .46194 Mdot
.744 .46228 Mdot
.744 .46248 Mdot
.744 .46282 Mdot
.744 .46327 Mdot
.744 .46404 Mdot
.744 .46452 Mdot
.744 .46562 Mdot
.744 .46568 Mdot
.744 .46612 Mdot
.744 .46646 Mdot
.744 .46662 Mdot
.744 .46665 Mdot
.744 .46685 Mdot
.744 .46702 Mdot
.744 .46724 Mdot
.744 .46755 Mdot
.744 .46801 Mdot
.744 .46812 Mdot
.744 .46891 Mdot
.744 .46954 Mdot
.744 .4696 Mdot
.744 .47001 Mdot
.744 .47061 Mdot
.744 .47071 Mdot
.744 .47077 Mdot
.744 .47079 Mdot
.744 .47081 Mdot
.744 .47322 Mdot
.744 .47351 Mdot
.744 .47362 Mdot
.744 .47382 Mdot
.744 .47384 Mdot
.744 .47468 Mdot
.744 .47504 Mdot
.744 .47509 Mdot
.744 .47534 Mdot
.744 .47569 Mdot
.744 .47574 Mdot
.744 .47697 Mdot
.744 .47732 Mdot
.744 .47736 Mdot
.744 .47739 Mdot
.744 .47771 Mdot
.744 .4781 Mdot
.744 .47879 Mdot
.744 .47902 Mdot
.744 .47908 Mdot
.744 .47951 Mdot
.744 .47961 Mdot
.744 .47972 Mdot
.744 .48049 Mdot
.744 .48071 Mdot
.744 .48097 Mdot
.744 .48143 Mdot
.744 .48237 Mdot
.744 .48239 Mdot
.744 .48245 Mdot
.744 .4829 Mdot
.744 .48347 Mdot
.744 .48384 Mdot
.744 .4841 Mdot
.744 .4841 Mdot
.744 .48413 Mdot
.744 .48429 Mdot
.744 .48582 Mdot
.744 .48599 Mdot
.744 .48708 Mdot
.744 .48746 Mdot
.744 .48772 Mdot
.744 .48832 Mdot
.744 .48852 Mdot
.744 .48886 Mdot
.744 .48889 Mdot
.744 .48895 Mdot
.744 .48943 Mdot
.744 .48961 Mdot
.744 .49004 Mdot
.744 .4901 Mdot
.744 .49029 Mdot
.744 .49098 Mdot
.744 .49128 Mdot
.744 .49186 Mdot
.744 .49216 Mdot
.744 .49224 Mdot
.744 .49283 Mdot
.744 .49396 Mdot
.744 .49399 Mdot
.744 .49409 Mdot
.744 .49428 Mdot
.744 .49462 Mdot
.744 .49483 Mdot
.744 .49627 Mdot
.744 .49762 Mdot
.744 .49844 Mdot
.744 .4987 Mdot
.744 .49874 Mdot
.744 .49899 Mdot
.744 .49978 Mdot
.744 .50053 Mdot
.744 .50068 Mdot
.744 .50084 Mdot
.744 .50114 Mdot
.744 .50207 Mdot
.744 .50243 Mdot
.744 .503 Mdot
.744 .50313 Mdot
.744 .50344 Mdot
.744 .50352 Mdot
.744 .50354 Mdot
.744 .5037 Mdot
.744 .50379 Mdot
.744 .50406 Mdot
.744 .50434 Mdot
.744 .50438 Mdot
.744 .50453 Mdot
.744 .5048 Mdot
.744 .50502 Mdot
.744 .50512 Mdot
.744 .50596 Mdot
.744 .50719 Mdot
.744 .50749 Mdot
.744 .50866 Mdot
.744 .50957 Mdot
.744 .50957 Mdot
.744 .51 Mdot
.744 .51095 Mdot
.744 .51123 Mdot
.744 .51138 Mdot
.744 .51236 Mdot
.744 .51246 Mdot
.744 .51397 Mdot
.744 .51401 Mdot
.744 .51426 Mdot
.744 .51442 Mdot
.744 .51447 Mdot
.744 .51451 Mdot
.744 .51506 Mdot
.744 .51542 Mdot
.744 .5155 Mdot
.744 .51585 Mdot
.744 .51618 Mdot
.744 .51622 Mdot
.744 .51638 Mdot
.744 .51639 Mdot
.744 .51812 Mdot
.744 .5182 Mdot
.744 .5184 Mdot
.744 .51852 Mdot
.744 .51876 Mdot
.744 .5206 Mdot
.744 .52081 Mdot
.744 .52081 Mdot
.744 .52126 Mdot
.744 .52131 Mdot
.744 .52156 Mdot
.744 .52197 Mdot
.744 .52201 Mdot
.744 .52205 Mdot
.744 .5221 Mdot
.744 .52238 Mdot
.744 .5237 Mdot
.744 .52414 Mdot
.744 .52427 Mdot
.744 .52474 Mdot
.744 .52501 Mdot
.744 .52512 Mdot
.744 .52573 Mdot
.744 .52654 Mdot
.744 .52667 Mdot
.744 .5269 Mdot
.744 .52746 Mdot
.744 .5277 Mdot
.744 .52811 Mdot
.744 .52812 Mdot
.744 .52823 Mdot
.744 .52952 Mdot
.744 .52963 Mdot
.744 .52981 Mdot
.744 .53004 Mdot
.744 .53032 Mdot
.744 .53033 Mdot
.744 .53042 Mdot
.744 .53048 Mdot
.744 .53065 Mdot
.744 .53122 Mdot
.744 .53209 Mdot
.744 .53215 Mdot
.744 .53233 Mdot
.744 .5326 Mdot
.744 .53314 Mdot
.744 .53362 Mdot
.744 .53363 Mdot
.744 .53415 Mdot
.744 .53418 Mdot
.744 .5342 Mdot
.744 .53428 Mdot
.744 .53522 Mdot
.744 .53538 Mdot
.744 .53542 Mdot
.744 .53567 Mdot
.744 .53571 Mdot
.744 .53602 Mdot
.744 .5361 Mdot
.744 .53614 Mdot
.744 .53629 Mdot
.744 .53699 Mdot
.744 .53732 Mdot
.744 .53778 Mdot
.744 .53834 Mdot
.744 .53859 Mdot
.744 .53864 Mdot
.744 .53865 Mdot
.744 .5393 Mdot
.744 .53983 Mdot
.744 .53992 Mdot
.744 .54073 Mdot
.744 .54122 Mdot
.744 .54126 Mdot
.744 .54126 Mdot
.744 .54139 Mdot
.744 .54228 Mdot
.744 .54259 Mdot
.744 .54298 Mdot
.744 .54308 Mdot
.744 .54309 Mdot
.744 .5433 Mdot
.744 .54343 Mdot
.744 .54407 Mdot
.744 .54416 Mdot
.744 .54418 Mdot
.744 .54466 Mdot
.744 .54466 Mdot
.744 .54471 Mdot
.744 .5448 Mdot
.744 .54492 Mdot
.744 .54502 Mdot
.744 .54531 Mdot
.744 .54573 Mdot
.744 .54634 Mdot
.744 .54759 Mdot
.744 .54764 Mdot
.744 .54775 Mdot
.744 .54789 Mdot
.744 .54791 Mdot
.744 .54795 Mdot
.744 .54805 Mdot
.744 .54822 Mdot
.744 .54867 Mdot
.744 .54903 Mdot
.744 .54909 Mdot
.744 .5491 Mdot
.744 .54916 Mdot
.744 .55004 Mdot
.744 .55011 Mdot
.744 .55018 Mdot
.744 .55018 Mdot
.744 .55057 Mdot
.744 .55085 Mdot
.744 .55105 Mdot
.744 .55119 Mdot
.744 .55129 Mdot
.744 .55131 Mdot
.744 .55138 Mdot
.744 .55161 Mdot
.744 .55169 Mdot
.744 .55196 Mdot
.744 .55233 Mdot
.744 .55233 Mdot
.744 .55246 Mdot
.744 .55258 Mdot
.744 .55267 Mdot
.744 .55323 Mdot
.744 .55326 Mdot
.744 .55328 Mdot
.744 .55338 Mdot
.744 .55356 Mdot
.744 .55417 Mdot
.744 .55425 Mdot
.744 .55446 Mdot
.744 .55516 Mdot
.744 .55524 Mdot
.744 .55538 Mdot
.744 .55555 Mdot
.744 .55569 Mdot
.744 .55581 Mdot
.744 .55581 Mdot
.744 .55599 Mdot
.744 .556 Mdot
.744 .55652 Mdot
.744 .55663 Mdot
.744 .5567 Mdot
.744 .55673 Mdot
.744 .55696 Mdot
.744 .55708 Mdot
.744 .5571 Mdot
.744 .55719 Mdot
.744 .55729 Mdot
.744 .55749 Mdot
.744 .55788 Mdot
.744 .55795 Mdot
.744 .55839 Mdot
.744 .55841 Mdot
.744 .5585 Mdot
.744 .55855 Mdot
.744 .55869 Mdot
.744 .55892 Mdot
.744 .55931 Mdot
.744 .55935 Mdot
.744 .55973 Mdot
.744 .55991 Mdot
.744 .55993 Mdot
.744 .56009 Mdot
.744 .56014 Mdot
.744 .5602 Mdot
.744 .5604 Mdot
.744 .56052 Mdot
.744 .5606 Mdot
.744 .56068 Mdot
.744 .56072 Mdot
.744 .56092 Mdot
.744 .56096 Mdot
.744 .56097 Mdot
.744 .56108 Mdot
.744 .56133 Mdot
.744 .56135 Mdot
.744 .56135 Mdot
.744 .56162 Mdot
.744 .56178 Mdot
.744 .56181 Mdot
.744 .56184 Mdot
.744 .56185 Mdot
.744 .56197 Mdot
.744 .56201 Mdot
.744 .56202 Mdot
.744 .56205 Mdot
.744 .56219 Mdot
.744 .56238 Mdot
.744 .56355 Mdot
.744 .56384 Mdot
.744 .56437 Mdot
.744 .56452 Mdot
.744 .56488 Mdot
.744 .56537 Mdot
.744 .56547 Mdot
.744 .56563 Mdot
.744 .56616 Mdot
.744 .56624 Mdot
.744 .5665 Mdot
.744 .56655 Mdot
.744 .5668 Mdot
.744 .56756 Mdot
.744 .56763 Mdot
.744 .56791 Mdot
.744 .56796 Mdot
.744 .568 Mdot
.744 .56804 Mdot
.744 .56824 Mdot
.744 .56837 Mdot
.744 .56844 Mdot
.744 .56852 Mdot
.744 .56868 Mdot
.744 .56872 Mdot
.744 .56877 Mdot
.744 .56913 Mdot
.744 .56914 Mdot
.744 .56932 Mdot
.744 .56951 Mdot
.744 .56979 Mdot
.744 .57019 Mdot
.744 .57028 Mdot
.744 .57049 Mdot
.744 .57054 Mdot
.744 .57056 Mdot
.744 .57066 Mdot
.744 .57072 Mdot
.744 .57074 Mdot
.744 .57088 Mdot
.744 .5709 Mdot
.744 .57097 Mdot
.744 .57105 Mdot
.744 .57108 Mdot
.744 .5711 Mdot
.744 .57115 Mdot
.744 .57116 Mdot
.744 .57132 Mdot
.744 .57144 Mdot
.744 .57149 Mdot
.744 .5719 Mdot
.744 .57207 Mdot
.744 .57208 Mdot
.744 .57215 Mdot
.744 .57217 Mdot
.744 .5723 Mdot
.744 .57241 Mdot
.744 .57244 Mdot
.744 .57247 Mdot
.744 .57251 Mdot
.744 .57259 Mdot
.744 .57276 Mdot
.744 .57277 Mdot
.744 .57278 Mdot
.744 .57283 Mdot
.744 .57285 Mdot
.744 .57288 Mdot
.744 .5729 Mdot
.744 .57303 Mdot
.744 .57303 Mdot
.744 .57309 Mdot
.744 .57314 Mdot
.744 .57314 Mdot
.744 .57317 Mdot
.744 .57318 Mdot
.744 .57318 Mdot
.746 .12251 Mdot
.746 .12251 Mdot
.746 .12254 Mdot
.746 .12255 Mdot
.746 .12257 Mdot
.746 .12262 Mdot
.746 .12267 Mdot
.746 .1227 Mdot
.746 .1229 Mdot
.746 .12309 Mdot
.746 .12318 Mdot
.746 .12352 Mdot
.746 .12372 Mdot
.746 .12374 Mdot
.746 .12376 Mdot
.746 .12406 Mdot
.746 .12414 Mdot
.746 .12422 Mdot
.746 .12446 Mdot
.746 .12458 Mdot
.746 .12507 Mdot
.746 .12532 Mdot
.746 .12541 Mdot
.746 .12556 Mdot
.746 .12583 Mdot
.746 .12612 Mdot
.746 .12625 Mdot
.746 .12627 Mdot
.746 .12646 Mdot
.746 .12674 Mdot
.746 .12676 Mdot
.746 .12688 Mdot
.746 .12703 Mdot
.746 .12734 Mdot
.746 .12768 Mdot
.746 .12876 Mdot
.746 .12888 Mdot
.746 .12905 Mdot
.746 .12906 Mdot
.746 .12945 Mdot
.746 .12976 Mdot
.746 .13029 Mdot
.746 .13109 Mdot
.746 .13166 Mdot
.746 .13169 Mdot
.746 .13258 Mdot
.746 .13262 Mdot
.746 .13266 Mdot
.746 .13286 Mdot
.746 .13349 Mdot
.746 .13385 Mdot
.746 .13508 Mdot
.746 .13697 Mdot
.746 .13724 Mdot
.746 .1379 Mdot
.746 .13838 Mdot
.746 .1386 Mdot
.746 .13925 Mdot
.746 .14226 Mdot
.746 .14299 Mdot
.746 .14341 Mdot
.746 .14443 Mdot
.746 .14578 Mdot
.746 .14701 Mdot
.746 .14729 Mdot
.746 .14859 Mdot
.746 .14887 Mdot
.746 .15013 Mdot
.746 .15047 Mdot
.746 .1505 Mdot
.746 .1509 Mdot
.746 .15155 Mdot
.746 .15158 Mdot
.746 .15173 Mdot
.746 .15228 Mdot
.746 .15304 Mdot
.746 .15365 Mdot
.746 .15448 Mdot
.746 .15465 Mdot
.746 .15543 Mdot
.746 .15548 Mdot
.746 .15558 Mdot
.746 .15573 Mdot
.746 .15701 Mdot
.746 .15705 Mdot
.746 .15714 Mdot
.746 .1572 Mdot
.746 .15727 Mdot
.746 .15748 Mdot
.746 .1577 Mdot
.746 .15781 Mdot
.746 .15865 Mdot
.746 .15944 Mdot
.746 .15956 Mdot
.746 .15972 Mdot
.746 .15976 Mdot
.746 .15979 Mdot
.746 .16126 Mdot
.746 .16175 Mdot
.746 .16183 Mdot
.746 .16211 Mdot
.746 .16218 Mdot
.746 .16228 Mdot
.746 .16232 Mdot
.746 .16247 Mdot
.746 .16293 Mdot
.746 .1636 Mdot
.746 .16395 Mdot
.746 .16427 Mdot
.746 .16534 Mdot
.746 .16591 Mdot
.746 .16707 Mdot
.746 .16789 Mdot
.746 .16809 Mdot
.746 .16876 Mdot
.746 .169 Mdot
.746 .16924 Mdot
.746 .16967 Mdot
.746 .17036 Mdot
.746 .17163 Mdot
.746 .17193 Mdot
.746 .1725 Mdot
.746 .173 Mdot
.746 .17363 Mdot
.746 .1737 Mdot
.746 .17393 Mdot
.746 .17464 Mdot
.746 .1758 Mdot
.746 .17588 Mdot
.746 .17598 Mdot
.746 .17607 Mdot
.746 .17608 Mdot
.746 .17668 Mdot
.746 .17738 Mdot
.746 .17878 Mdot
.746 .17893 Mdot
.746 .18064 Mdot
.746 .18167 Mdot
.746 .18285 Mdot
.746 .18396 Mdot
.746 .18546 Mdot
.746 .18613 Mdot
.746 .18616 Mdot
.746 .1868 Mdot
.746 .18766 Mdot
.746 .18774 Mdot
.746 .18948 Mdot
.746 .18955 Mdot
.746 .18976 Mdot
.746 .19021 Mdot
.746 .19145 Mdot
.746 .19327 Mdot
.746 .19428 Mdot
.746 .19437 Mdot
.746 .19524 Mdot
.746 .1954 Mdot
.746 .19579 Mdot
.746 .1972 Mdot
.746 .19724 Mdot
.746 .19822 Mdot
.746 .19833 Mdot
.746 .19866 Mdot
.746 .19938 Mdot
.746 .19973 Mdot
.746 .201 Mdot
.746 .20186 Mdot
.746 .20203 Mdot
.746 .20274 Mdot
.746 .20331 Mdot
.746 .2043 Mdot
.746 .20457 Mdot
.746 .2064 Mdot
.746 .20707 Mdot
.746 .2073 Mdot
.746 .20754 Mdot
.746 .20834 Mdot
.746 .20872 Mdot
.746 .20894 Mdot
.746 .21025 Mdot
.746 .21153 Mdot
.746 .21159 Mdot
.746 .21165 Mdot
.746 .21236 Mdot
.746 .21361 Mdot
.746 .21368 Mdot
.746 .21401 Mdot
.746 .21449 Mdot
.746 .21514 Mdot
.746 .21762 Mdot
.746 .21904 Mdot
.746 .2218 Mdot
.746 .22186 Mdot
.746 .22229 Mdot
.746 .22243 Mdot
.746 .22273 Mdot
.746 .22305 Mdot
.746 .22321 Mdot
.746 .22533 Mdot
.746 .22547 Mdot
.746 .22805 Mdot
.746 .22837 Mdot
.746 .22888 Mdot
.746 .22958 Mdot
.746 .23098 Mdot
.746 .23161 Mdot
.746 .23196 Mdot
.746 .23223 Mdot
.746 .23339 Mdot
.746 .23461 Mdot
.746 .23512 Mdot
.746 .23607 Mdot
.746 .23748 Mdot
.746 .23925 Mdot
.746 .23954 Mdot
.746 .23975 Mdot
.746 .2408 Mdot
.746 .24228 Mdot
.746 .24284 Mdot
.746 .24287 Mdot
.746 .24363 Mdot
.746 .24365 Mdot
.746 .24367 Mdot
.746 .24417 Mdot
.746 .24468 Mdot
.746 .24653 Mdot
.746 .24786 Mdot
.746 .24944 Mdot
.746 .25019 Mdot
.746 .25063 Mdot
.746 .2527 Mdot
.746 .25422 Mdot
.746 .25519 Mdot
.746 .25898 Mdot
.746 .26299 Mdot
.746 .26341 Mdot
.746 .26564 Mdot
.746 .26597 Mdot
.746 .26753 Mdot
.746 .26992 Mdot
.746 .26995 Mdot
.746 .27042 Mdot
.746 .27142 Mdot
.746 .2719 Mdot
.746 .27234 Mdot
.746 .27236 Mdot
.746 .27279 Mdot
.746 .27306 Mdot
.746 .27328 Mdot
.746 .27412 Mdot
.746 .27431 Mdot
.746 .2752 Mdot
.746 .28201 Mdot
.746 .283 Mdot
.746 .28325 Mdot
.746 .285 Mdot
.746 .28753 Mdot
.746 .28918 Mdot
.746 .29013 Mdot
.746 .29078 Mdot
.746 .29118 Mdot
.746 .29208 Mdot
.746 .29413 Mdot
.746 .29504 Mdot
.746 .29508 Mdot
.746 .29554 Mdot
.746 .29613 Mdot
.746 .29764 Mdot
.746 .29815 Mdot
.746 .29922 Mdot
.746 .29952 Mdot
.746 .3003 Mdot
.746 .30051 Mdot
.746 .30144 Mdot
.746 .30149 Mdot
.746 .30372 Mdot
.746 .3046 Mdot
.746 .30602 Mdot
.746 .30695 Mdot
.746 .30716 Mdot
.746 .30735 Mdot
.746 .30784 Mdot
.746 .31035 Mdot
.746 .31157 Mdot
.746 .31222 Mdot
.746 .31466 Mdot
.746 .31592 Mdot
.746 .31666 Mdot
.746 .31791 Mdot
.746 .32058 Mdot
.746 .32087 Mdot
.746 .32138 Mdot
.746 .32213 Mdot
.746 .32216 Mdot
.746 .32319 Mdot
.746 .32342 Mdot
.746 .32442 Mdot
.746 .32611 Mdot
.746 .32633 Mdot
.746 .32635 Mdot
.746 .3295 Mdot
.746 .32953 Mdot
.746 .33055 Mdot
.746 .33059 Mdot
.746 .33081 Mdot
.746 .33146 Mdot
.746 .33183 Mdot
.746 .33482 Mdot
.746 .33561 Mdot
.746 .33621 Mdot
.746 .33676 Mdot
.746 .33917 Mdot
.746 .33973 Mdot
.746 .34005 Mdot
.746 .3408 Mdot
.746 .34178 Mdot
.746 .34264 Mdot
.746 .34499 Mdot
.746 .34578 Mdot
.746 .347 Mdot
.746 .3475 Mdot
.746 .34817 Mdot
.746 .34827 Mdot
.746 .34903 Mdot
.746 .34905 Mdot
.746 .3491 Mdot
.746 .34914 Mdot
.746 .34918 Mdot
.746 .3493 Mdot
.746 .34943 Mdot
.746 .3495 Mdot
.746 .34999 Mdot
.746 .35044 Mdot
.746 .3506 Mdot
.746 .35062 Mdot
.746 .35064 Mdot
.746 .35147 Mdot
.746 .35174 Mdot
.746 .35179 Mdot
.746 .35195 Mdot
.746 .35198 Mdot
.746 .35204 Mdot
.746 .35214 Mdot
.746 .35277 Mdot
.746 .35295 Mdot
.746 .35312 Mdot
.746 .3537 Mdot
.746 .354 Mdot
.746 .35515 Mdot
.746 .3555 Mdot
.746 .35562 Mdot
.746 .35574 Mdot
.746 .35597 Mdot
.746 .35632 Mdot
.746 .35696 Mdot
.746 .35711 Mdot
.746 .35739 Mdot
.746 .35764 Mdot
.746 .35796 Mdot
.746 .35799 Mdot
.746 .3581 Mdot
.746 .35845 Mdot
.746 .35901 Mdot
.746 .3591 Mdot
.746 .35914 Mdot
.746 .35915 Mdot
.746 .35944 Mdot
.746 .35978 Mdot
.746 .36044 Mdot
.746 .36051 Mdot
.746 .36131 Mdot
.746 .36179 Mdot
.746 .36233 Mdot
.746 .36351 Mdot
.746 .36383 Mdot
.746 .36412 Mdot
.746 .3645 Mdot
.746 .36453 Mdot
.746 .3653 Mdot
.746 .36542 Mdot
.746 .36562 Mdot
.746 .36616 Mdot
.746 .36737 Mdot
.746 .36777 Mdot
.746 .36801 Mdot
.746 .36861 Mdot
.746 .36902 Mdot
.746 .36907 Mdot
.746 .36921 Mdot
.746 .3695 Mdot
.746 .36964 Mdot
.746 .37052 Mdot
.746 .37059 Mdot
.746 .37087 Mdot
.746 .37111 Mdot
.746 .37162 Mdot
.746 .37234 Mdot
.746 .37261 Mdot
.746 .3727 Mdot
.746 .3728 Mdot
.746 .37311 Mdot
.746 .37326 Mdot
.746 .37468 Mdot
.746 .37532 Mdot
.746 .3755 Mdot
.746 .37669 Mdot
.746 .37826 Mdot
.746 .37844 Mdot
.746 .3786 Mdot
.746 .37872 Mdot
.746 .37956 Mdot
.746 .37961 Mdot
.746 .38067 Mdot
.746 .38086 Mdot
.746 .38111 Mdot
.746 .38161 Mdot
.746 .38184 Mdot
.746 .38206 Mdot
.746 .38247 Mdot
.746 .38309 Mdot
.746 .38392 Mdot
.746 .38454 Mdot
.746 .38472 Mdot
.746 .38508 Mdot
.746 .3856 Mdot
.746 .38579 Mdot
.746 .38606 Mdot
.746 .38608 Mdot
.746 .38625 Mdot
.746 .38751 Mdot
.746 .38805 Mdot
.746 .3883 Mdot
.746 .39124 Mdot
.746 .39343 Mdot
.746 .39354 Mdot
.746 .39405 Mdot
.746 .39483 Mdot
.746 .39546 Mdot
.746 .39561 Mdot
.746 .39583 Mdot
.746 .3959 Mdot
.746 .39651 Mdot
.746 .39868 Mdot
.746 .39907 Mdot
.746 .39962 Mdot
.746 .40092 Mdot
.746 .40122 Mdot
.746 .40142 Mdot
.746 .40154 Mdot
.746 .40183 Mdot
.746 .40246 Mdot
.746 .40274 Mdot
.746 .40275 Mdot
.746 .40308 Mdot
.746 .4037 Mdot
.746 .40412 Mdot
.746 .40471 Mdot
.746 .40472 Mdot
.746 .4054 Mdot
.746 .4061 Mdot
.746 .40665 Mdot
.746 .40741 Mdot
.746 .40798 Mdot
.746 .40871 Mdot
.746 .41058 Mdot
.746 .41095 Mdot
.746 .41127 Mdot
.746 .41134 Mdot
.746 .41214 Mdot
.746 .41221 Mdot
.746 .41221 Mdot
.746 .41315 Mdot
.746 .41316 Mdot
.746 .41347 Mdot
.746 .41354 Mdot
.746 .41384 Mdot
.746 .41496 Mdot
.746 .41513 Mdot
.746 .41626 Mdot
.746 .41649 Mdot
.746 .41677 Mdot
.746 .41772 Mdot
.746 .41795 Mdot
.746 .41846 Mdot
.746 .41868 Mdot
.746 .41936 Mdot
.746 .41971 Mdot
.746 .42127 Mdot
.746 .42135 Mdot
.746 .42156 Mdot
.746 .42183 Mdot
.746 .42186 Mdot
.746 .42314 Mdot
.746 .42438 Mdot
.746 .42445 Mdot
.746 .42463 Mdot
.746 .42475 Mdot
.746 .42489 Mdot
.746 .42493 Mdot
.746 .42529 Mdot
.746 .42535 Mdot
.746 .4255 Mdot
.746 .42571 Mdot
.746 .42594 Mdot
.746 .42698 Mdot
.746 .42749 Mdot
.746 .42754 Mdot
.746 .42757 Mdot
.746 .42783 Mdot
.746 .42814 Mdot
.746 .4282 Mdot
.746 .42842 Mdot
.746 .42909 Mdot
.746 .42932 Mdot
.746 .42943 Mdot
.746 .42964 Mdot
.746 .42972 Mdot
.746 .42977 Mdot
.746 .43228 Mdot
.746 .43247 Mdot
.746 .4326 Mdot
.746 .43352 Mdot
.746 .43369 Mdot
.746 .43416 Mdot
.746 .43421 Mdot
.746 .43433 Mdot
.746 .43452 Mdot
.746 .4346 Mdot
.746 .43461 Mdot
.746 .4347 Mdot
.746 .43488 Mdot
.746 .43539 Mdot
.746 .43559 Mdot
.746 .43576 Mdot
.746 .43703 Mdot
.746 .4374 Mdot
.746 .43767 Mdot
.746 .43768 Mdot
.746 .43826 Mdot
.746 .4386 Mdot
.746 .43875 Mdot
.746 .43932 Mdot
.746 .44026 Mdot
.746 .44118 Mdot
.746 .44131 Mdot
.746 .4418 Mdot
.746 .44216 Mdot
.746 .44254 Mdot
.746 .44345 Mdot
.746 .44396 Mdot
.746 .44413 Mdot
.746 .44495 Mdot
.746 .44531 Mdot
.746 .44536 Mdot
.746 .44629 Mdot
.746 .44652 Mdot
.746 .44696 Mdot
.746 .44701 Mdot
.746 .44739 Mdot
.746 .44789 Mdot
.746 .44817 Mdot
.746 .44851 Mdot
.746 .44901 Mdot
.746 .4494 Mdot
.746 .44991 Mdot
.746 .45059 Mdot
.746 .45068 Mdot
.746 .45146 Mdot
.746 .45166 Mdot
.746 .45186 Mdot
.746 .45219 Mdot
.746 .4532 Mdot
.746 .45351 Mdot
.746 .45359 Mdot
.746 .45408 Mdot
.746 .45423 Mdot
.746 .45519 Mdot
.746 .4553 Mdot
.746 .45566 Mdot
.746 .45571 Mdot
.746 .45595 Mdot
.746 .45684 Mdot
.746 .45694 Mdot
.746 .45842 Mdot
.746 .45895 Mdot
.746 .45906 Mdot
.746 .45909 Mdot
.746 .45925 Mdot
.746 .4594 Mdot
.746 .45942 Mdot
.746 .45969 Mdot
.746 .46045 Mdot
.746 .46052 Mdot
.746 .46074 Mdot
.746 .46165 Mdot
.746 .46232 Mdot
.746 .4639 Mdot
.746 .46401 Mdot
.746 .46426 Mdot
.746 .46485 Mdot
.746 .4651 Mdot
.746 .46566 Mdot
.746 .46664 Mdot
.746 .46664 Mdot
.746 .4671 Mdot
.746 .46711 Mdot
.746 .46772 Mdot
.746 .46881 Mdot
.746 .4698 Mdot
.746 .47007 Mdot
.746 .47041 Mdot
.746 .47073 Mdot
.746 .47122 Mdot
.746 .47152 Mdot
.746 .47168 Mdot
.746 .47168 Mdot
.746 .47182 Mdot
.746 .47212 Mdot
.746 .47231 Mdot
.746 .4724 Mdot
.746 .47254 Mdot
.746 .47316 Mdot
.746 .47342 Mdot
.746 .47491 Mdot
.746 .47494 Mdot
.746 .47511 Mdot
.746 .47541 Mdot
.746 .47601 Mdot
.746 .47606 Mdot
.746 .47707 Mdot
.746 .47842 Mdot
.746 .47854 Mdot
.746 .47936 Mdot
.746 .47944 Mdot
.746 .47957 Mdot
.746 .47989 Mdot
.746 .48005 Mdot
.746 .48041 Mdot
.746 .48125 Mdot
.746 .48135 Mdot
.746 .48146 Mdot
.746 .48168 Mdot
.746 .48179 Mdot
.746 .48188 Mdot
.746 .48235 Mdot
.746 .48237 Mdot
.746 .48275 Mdot
.746 .4828 Mdot
.746 .48287 Mdot
.746 .48365 Mdot
.746 .48426 Mdot
.746 .48523 Mdot
.746 .48557 Mdot
.746 .48589 Mdot
.746 .48611 Mdot
.746 .48622 Mdot
.746 .48675 Mdot
.746 .48682 Mdot
.746 .487 Mdot
.746 .48703 Mdot
.746 .4872 Mdot
.746 .48747 Mdot
.746 .48757 Mdot
.746 .4885 Mdot
.746 .48864 Mdot
.746 .48941 Mdot
.746 .48991 Mdot
.746 .49015 Mdot
.746 .49072 Mdot
.746 .49128 Mdot
.746 .49133 Mdot
.746 .49172 Mdot
.746 .49202 Mdot
.746 .49214 Mdot
.746 .49277 Mdot
.746 .49282 Mdot
.746 .49423 Mdot
.746 .49438 Mdot
.746 .4944 Mdot
.746 .49486 Mdot
.746 .49487 Mdot
.746 .49584 Mdot
.746 .49588 Mdot
.746 .49616 Mdot
.746 .49637 Mdot
.746 .49687 Mdot
.746 .4972 Mdot
.746 .49816 Mdot
.746 .49852 Mdot
.746 .49892 Mdot
.746 .49922 Mdot
.746 .49935 Mdot
.746 .49958 Mdot
.746 .50056 Mdot
.746 .50078 Mdot
.746 .50102 Mdot
.746 .50134 Mdot
.746 .50254 Mdot
.746 .50269 Mdot
.746 .50295 Mdot
.746 .50304 Mdot
.746 .50306 Mdot
.746 .50346 Mdot
.746 .50347 Mdot
.746 .50473 Mdot
.746 .50473 Mdot
.746 .50482 Mdot
.746 .50549 Mdot
.746 .50588 Mdot
.746 .50597 Mdot
.746 .50638 Mdot
.746 .50639 Mdot
.746 .50669 Mdot
.746 .50689 Mdot
.746 .507 Mdot
.746 .50804 Mdot
.746 .50853 Mdot
.746 .50881 Mdot
.746 .5093 Mdot
.746 .51025 Mdot
.746 .51049 Mdot
.746 .51096 Mdot
.746 .51193 Mdot
.746 .51211 Mdot
.746 .51219 Mdot
.746 .51226 Mdot
.746 .51262 Mdot
.746 .51316 Mdot
.746 .51349 Mdot
.746 .51434 Mdot
.746 .51435 Mdot
.746 .5147 Mdot
.746 .51478 Mdot
.746 .51508 Mdot
.746 .51519 Mdot
.746 .51559 Mdot
.746 .51578 Mdot
.746 .51635 Mdot
.746 .51657 Mdot
.746 .51674 Mdot
.746 .51676 Mdot
.746 .5171 Mdot
.746 .51786 Mdot
.746 .51819 Mdot
.746 .51834 Mdot
.746 .51858 Mdot
.746 .51893 Mdot
.746 .51954 Mdot
.746 .52047 Mdot
.746 .52111 Mdot
.746 .5212 Mdot
.746 .52156 Mdot
.746 .52403 Mdot
.746 .52435 Mdot
.746 .52442 Mdot
.746 .52472 Mdot
.746 .5248 Mdot
.746 .5249 Mdot
.746 .52505 Mdot
.746 .52506 Mdot
.746 .52522 Mdot
.746 .52539 Mdot
.746 .52575 Mdot
.746 .52592 Mdot
.746 .52593 Mdot
.746 .52678 Mdot
.746 .52733 Mdot
.746 .52745 Mdot
.746 .52824 Mdot
.746 .52839 Mdot
.746 .5298 Mdot
.746 .53113 Mdot
.746 .53147 Mdot
.746 .53199 Mdot
.746 .53272 Mdot
.746 .53287 Mdot
.746 .53313 Mdot
.746 .53367 Mdot
.746 .53413 Mdot
.746 .53477 Mdot
.746 .53494 Mdot
.746 .53511 Mdot
.746 .53512 Mdot
.746 .53513 Mdot
.746 .53539 Mdot
.746 .5354 Mdot
.746 .53559 Mdot
.746 .53609 Mdot
.746 .53645 Mdot
.746 .53653 Mdot
.746 .53662 Mdot
.746 .53723 Mdot
.746 .5377 Mdot
.746 .53802 Mdot
.746 .5382 Mdot
.746 .53861 Mdot
.746 .539 Mdot
.746 .53909 Mdot
.746 .53921 Mdot
.746 .53942 Mdot
.746 .53989 Mdot
.746 .54013 Mdot
.746 .5403 Mdot
.746 .54041 Mdot
.746 .54127 Mdot
.746 .54132 Mdot
.746 .54202 Mdot
.746 .54208 Mdot
.746 .54218 Mdot
.746 .54228 Mdot
.746 .54233 Mdot
.746 .54247 Mdot
.746 .54249 Mdot
.746 .5434 Mdot
.746 .54387 Mdot
.746 .54469 Mdot
.746 .5449 Mdot
.746 .54506 Mdot
.746 .54517 Mdot
.746 .54519 Mdot
.746 .5456 Mdot
.746 .54584 Mdot
.746 .54586 Mdot
.746 .54588 Mdot
.746 .54629 Mdot
.746 .54672 Mdot
.746 .54679 Mdot
.746 .54692 Mdot
.746 .54718 Mdot
.746 .54725 Mdot
.746 .54733 Mdot
.746 .54755 Mdot
.746 .54814 Mdot
.746 .54823 Mdot
.746 .54855 Mdot
.746 .54874 Mdot
.746 .54897 Mdot
.746 .54902 Mdot
.746 .5493 Mdot
.746 .54971 Mdot
.746 .54982 Mdot
.746 .55005 Mdot
.746 .55016 Mdot
.746 .55019 Mdot
.746 .55051 Mdot
.746 .55052 Mdot
.746 .55097 Mdot
.746 .5511 Mdot
.746 .55115 Mdot
.746 .55143 Mdot
.746 .55146 Mdot
.746 .55236 Mdot
.746 .55275 Mdot
.746 .5529 Mdot
.746 .55296 Mdot
.746 .55298 Mdot
.746 .55354 Mdot
.746 .55356 Mdot
.746 .55383 Mdot
.746 .55404 Mdot
.746 .55405 Mdot
.746 .55426 Mdot
.746 .55473 Mdot
.746 .55508 Mdot
.746 .55545 Mdot
.746 .55578 Mdot
.746 .55631 Mdot
.746 .55636 Mdot
.746 .5568 Mdot
.746 .55702 Mdot
.746 .55721 Mdot
.746 .55721 Mdot
.746 .55724 Mdot
.746 .55727 Mdot
.746 .55729 Mdot
.746 .55766 Mdot
.746 .55788 Mdot
.746 .55795 Mdot
.746 .55797 Mdot
.746 .55817 Mdot
.746 .55832 Mdot
.746 .5585 Mdot
.746 .55859 Mdot
.746 .55899 Mdot
.746 .5592 Mdot
.746 .55933 Mdot
.746 .55941 Mdot
.746 .55948 Mdot
.746 .55969 Mdot
.746 .55975 Mdot
.746 .56 Mdot
.746 .56036 Mdot
.746 .56054 Mdot
.746 .56087 Mdot
.746 .56097 Mdot
.746 .56107 Mdot
.746 .56128 Mdot
.746 .56142 Mdot
.746 .56147 Mdot
.746 .56148 Mdot
.746 .56151 Mdot
.746 .56153 Mdot
.746 .56162 Mdot
.746 .56164 Mdot
.746 .56179 Mdot
.746 .56224 Mdot
.746 .56225 Mdot
.746 .56226 Mdot
.746 .56231 Mdot
.746 .56235 Mdot
.746 .56259 Mdot
.746 .56285 Mdot
.746 .56288 Mdot
.746 .56295 Mdot
.746 .56301 Mdot
.746 .56303 Mdot
.746 .56305 Mdot
.746 .56308 Mdot
.746 .56309 Mdot
.746 .56348 Mdot
.746 .56353 Mdot
.746 .56356 Mdot
.746 .56357 Mdot
.746 .56381 Mdot
.746 .56386 Mdot
.746 .56411 Mdot
.746 .5643 Mdot
.746 .56453 Mdot
.746 .5647 Mdot
.746 .56474 Mdot
.746 .56475 Mdot
.746 .56495 Mdot
.746 .56507 Mdot
.746 .56508 Mdot
.746 .56518 Mdot
.746 .56556 Mdot
.746 .56565 Mdot
.746 .56604 Mdot
.746 .56612 Mdot
.746 .56649 Mdot
.746 .5669 Mdot
.746 .56721 Mdot
.746 .56733 Mdot
.746 .56755 Mdot
.746 .56845 Mdot
.746 .56865 Mdot
.746 .56871 Mdot
.746 .56886 Mdot
.746 .56905 Mdot
.746 .56914 Mdot
.746 .5697 Mdot
.746 .57006 Mdot
.746 .57017 Mdot
.746 .57035 Mdot
.746 .57042 Mdot
.746 .57043 Mdot
.746 .57044 Mdot
.746 .5707 Mdot
.746 .57071 Mdot
.746 .57088 Mdot
.746 .57112 Mdot
.746 .57127 Mdot
.746 .57137 Mdot
.746 .57148 Mdot
.746 .57148 Mdot
.746 .57153 Mdot
.746 .57157 Mdot
.746 .57189 Mdot
.746 .57199 Mdot
.746 .57208 Mdot
.746 .57212 Mdot
.746 .57216 Mdot
.746 .57217 Mdot
.746 .57225 Mdot
.746 .5723 Mdot
.746 .57231 Mdot
.746 .57235 Mdot
.746 .57243 Mdot
.746 .57251 Mdot
.746 .57256 Mdot
.746 .57258 Mdot
.746 .57266 Mdot
.746 .5728 Mdot
.746 .57284 Mdot
.746 .57291 Mdot
.746 .57293 Mdot
.746 .57295 Mdot
.746 .57304 Mdot
.746 .57305 Mdot
.746 .57305 Mdot
.746 .57311 Mdot
.746 .57321 Mdot
.746 .57324 Mdot
.746 .57329 Mdot
.746 .57335 Mdot
.746 .57336 Mdot
.746 .57338 Mdot
.746 .57339 Mdot
.746 .5734 Mdot
.746 .5734 Mdot
.746 .57341 Mdot
.746 .57341 Mdot
.748 .12172 Mdot
.748 .12172 Mdot
.748 .12184 Mdot
.748 .12189 Mdot
.748 .12196 Mdot
.748 .12219 Mdot
.748 .12256 Mdot
.748 .12268 Mdot
.748 .12271 Mdot
.748 .12274 Mdot
.748 .12277 Mdot
.748 .12281 Mdot
.748 .12309 Mdot
.748 .12324 Mdot
.748 .1233 Mdot
.748 .12337 Mdot
.748 .12341 Mdot
.748 .12363 Mdot
.748 .12366 Mdot
.748 .12484 Mdot
.748 .12621 Mdot
.748 .12631 Mdot
.748 .12643 Mdot
.748 .12643 Mdot
.748 .12679 Mdot
.748 .12693 Mdot
.748 .12742 Mdot
.748 .12838 Mdot
.748 .12914 Mdot
.748 .12957 Mdot
.748 .12959 Mdot
.748 .13004 Mdot
.748 .13048 Mdot
.748 .13052 Mdot
.748 .13056 Mdot
.748 .13069 Mdot
.748 .1309 Mdot
.748 .13175 Mdot
.748 .13204 Mdot
.748 .13253 Mdot
.748 .13282 Mdot
.748 .13371 Mdot
.748 .13389 Mdot
.748 .13406 Mdot
.748 .13423 Mdot
.748 .13431 Mdot
.748 .13457 Mdot
.748 .13528 Mdot
.748 .1356 Mdot
.748 .13658 Mdot
.748 .13744 Mdot
.748 .13973 Mdot
.748 .14063 Mdot
.748 .14068 Mdot
.748 .14068 Mdot
.748 .14119 Mdot
.748 .14135 Mdot
.748 .14209 Mdot
.748 .14356 Mdot
.748 .14405 Mdot
.748 .14416 Mdot
.748 .14513 Mdot
.748 .14546 Mdot
.748 .14561 Mdot
.748 .14624 Mdot
.748 .14712 Mdot
.748 .1474 Mdot
.748 .14742 Mdot
.748 .14748 Mdot
.748 .14834 Mdot
.748 .14837 Mdot
.748 .14879 Mdot
.748 .14887 Mdot
.748 .14962 Mdot
.748 .1515 Mdot
.748 .15273 Mdot
.748 .15327 Mdot
.748 .15339 Mdot
.748 .1534 Mdot
.748 .15353 Mdot
.748 .15378 Mdot
.748 .15389 Mdot
.748 .15408 Mdot
.748 .15437 Mdot
.748 .1547 Mdot
.748 .15485 Mdot
.748 .15526 Mdot
.748 .15544 Mdot
.748 .15583 Mdot
.748 .1564 Mdot
.748 .15642 Mdot
.748 .15665 Mdot
.748 .15666 Mdot
.748 .15677 Mdot
.748 .15725 Mdot
.748 .15732 Mdot
.748 .15741 Mdot
.748 .15753 Mdot
.748 .15765 Mdot
.748 .15783 Mdot
.748 .1582 Mdot
.748 .15836 Mdot
.748 .15899 Mdot
.748 .15953 Mdot
.748 .15962 Mdot
.748 .15986 Mdot
.748 .16019 Mdot
.748 .16035 Mdot
.748 .16088 Mdot
.748 .16127 Mdot
.748 .1613 Mdot
.748 .16136 Mdot
.748 .16143 Mdot
.748 .16222 Mdot
.748 .16262 Mdot
.748 .16413 Mdot
.748 .16445 Mdot
.748 .16578 Mdot
.748 .16579 Mdot
.748 .16651 Mdot
.748 .16665 Mdot
.748 .16893 Mdot
.748 .1694 Mdot
.748 .17016 Mdot
.748 .17191 Mdot
.748 .17231 Mdot
.748 .17304 Mdot
.748 .17353 Mdot
.748 .17411 Mdot
.748 .17413 Mdot
.748 .17452 Mdot
.748 .17457 Mdot
.748 .17472 Mdot
.748 .17584 Mdot
.748 .17656 Mdot
.748 .17896 Mdot
.748 .17916 Mdot
.748 .17925 Mdot
.748 .17977 Mdot
.748 .17997 Mdot
.748 .18137 Mdot
.748 .18248 Mdot
.748 .18291 Mdot
.748 .18389 Mdot
.748 .18449 Mdot
.748 .18574 Mdot
.748 .18599 Mdot
.748 .18782 Mdot
.748 .18945 Mdot
.748 .18969 Mdot
.748 .18978 Mdot
.748 .1901 Mdot
.748 .19021 Mdot
.748 .19028 Mdot
.748 .19034 Mdot
.748 .19133 Mdot
.748 .19141 Mdot
.748 .19266 Mdot
.748 .19307 Mdot
.748 .19397 Mdot
.748 .19409 Mdot
.748 .19505 Mdot
.748 .19526 Mdot
.748 .19547 Mdot
.748 .1962 Mdot
.748 .19738 Mdot
.748 .19868 Mdot
.748 .19897 Mdot
.748 .19911 Mdot
.748 .19918 Mdot
.748 .19931 Mdot
.748 .20024 Mdot
.748 .20179 Mdot
.748 .20196 Mdot
.748 .20212 Mdot
.748 .20213 Mdot
.748 .20374 Mdot
.748 .20376 Mdot
.748 .20417 Mdot
.748 .20441 Mdot
.748 .20489 Mdot
.748 .20523 Mdot
.748 .20568 Mdot
.748 .2065 Mdot
.748 .20656 Mdot
.748 .20826 Mdot
.748 .20884 Mdot
.748 .21304 Mdot
.748 .21342 Mdot
.748 .21373 Mdot
.748 .21452 Mdot
.748 .21525 Mdot
.748 .21553 Mdot
.748 .21652 Mdot
.748 .21686 Mdot
.748 .21703 Mdot
.748 .21808 Mdot
.748 .21855 Mdot
.748 .22148 Mdot
.748 .22175 Mdot
.748 .22276 Mdot
.748 .22286 Mdot
.748 .22337 Mdot
.748 .22395 Mdot
.748 .22483 Mdot
.748 .22506 Mdot
.748 .22651 Mdot
.748 .22805 Mdot
.748 .2289 Mdot
.748 .22943 Mdot
.748 .23086 Mdot
.748 .23089 Mdot
.748 .23117 Mdot
.748 .23625 Mdot
.748 .23958 Mdot
.748 .23968 Mdot
.748 .24141 Mdot
.748 .2454 Mdot
.748 .24591 Mdot
.748 .24624 Mdot
.748 .24633 Mdot
.748 .24722 Mdot
.748 .2483 Mdot
.748 .25053 Mdot
.748 .25091 Mdot
.748 .25211 Mdot
.748 .25232 Mdot
.748 .25466 Mdot
.748 .25557 Mdot
.748 .25673 Mdot
.748 .25706 Mdot
.748 .2571 Mdot
.748 .25922 Mdot
.748 .25929 Mdot
.748 .2604 Mdot
.748 .26148 Mdot
.748 .2621 Mdot
.748 .26373 Mdot
.748 .26373 Mdot
.748 .26444 Mdot
.748 .26612 Mdot
.748 .26617 Mdot
.748 .26639 Mdot
.748 .26715 Mdot
.748 .2688 Mdot
.748 .26894 Mdot
.748 .26895 Mdot
.748 .27053 Mdot
.748 .27068 Mdot
.748 .27084 Mdot
.748 .27398 Mdot
.748 .274 Mdot
.748 .27463 Mdot
.748 .27483 Mdot
.748 .27587 Mdot
.748 .27621 Mdot
.748 .27734 Mdot
.748 .27952 Mdot
.748 .28028 Mdot
.748 .28219 Mdot
.748 .28412 Mdot
.748 .28478 Mdot
.748 .28543 Mdot
.748 .28562 Mdot
.748 .2868 Mdot
.748 .28855 Mdot
.748 .28879 Mdot
.748 .28898 Mdot
.748 .28903 Mdot
.748 .28954 Mdot
.748 .2901 Mdot
.748 .29063 Mdot
.748 .29361 Mdot
.748 .29383 Mdot
.748 .29437 Mdot
.748 .29473 Mdot
.748 .2971 Mdot
.748 .29961 Mdot
.748 .29969 Mdot
.748 .30034 Mdot
.748 .30069 Mdot
.748 .30196 Mdot
.748 .3021 Mdot
.748 .30229 Mdot
.748 .30242 Mdot
.748 .30284 Mdot
.748 .3044 Mdot
.748 .30661 Mdot
.748 .30874 Mdot
.748 .30894 Mdot
.748 .31184 Mdot
.748 .31237 Mdot
.748 .31584 Mdot
.748 .31692 Mdot
.748 .31749 Mdot
.748 .31779 Mdot
.748 .32347 Mdot
.748 .32366 Mdot
.748 .32512 Mdot
.748 .32644 Mdot
.748 .32796 Mdot
.748 .32909 Mdot
.748 .33041 Mdot
.748 .33072 Mdot
.748 .33153 Mdot
.748 .33276 Mdot
.748 .33292 Mdot
.748 .33301 Mdot
.748 .33421 Mdot
.748 .33509 Mdot
.748 .33846 Mdot
.748 .3385 Mdot
.748 .3389 Mdot
.748 .33903 Mdot
.748 .33959 Mdot
.748 .34105 Mdot
.748 .34113 Mdot
.748 .34206 Mdot
.748 .34261 Mdot
.748 .34341 Mdot
.748 .34346 Mdot
.748 .34434 Mdot
.748 .34439 Mdot
.748 .34488 Mdot
.748 .34608 Mdot
.748 .34686 Mdot
.748 .34727 Mdot
.748 .34727 Mdot
.748 .34758 Mdot
.748 .34769 Mdot
.748 .34787 Mdot
.748 .34807 Mdot
.748 .34816 Mdot
.748 .3484 Mdot
.748 .34851 Mdot
.748 .34874 Mdot
.748 .34922 Mdot
.748 .3493 Mdot
.748 .34958 Mdot
.748 .34967 Mdot
.748 .34974 Mdot
.748 .34981 Mdot
.748 .34991 Mdot
.748 .35013 Mdot
.748 .35022 Mdot
.748 .35058 Mdot
.748 .35094 Mdot
.748 .35107 Mdot
.748 .35126 Mdot
.748 .35135 Mdot
.748 .35188 Mdot
.748 .35195 Mdot
.748 .35238 Mdot
.748 .3526 Mdot
.748 .35342 Mdot
.748 .35468 Mdot
.748 .35475 Mdot
.748 .35617 Mdot
.748 .35743 Mdot
.748 .35799 Mdot
.748 .35823 Mdot
.748 .35852 Mdot
.748 .35853 Mdot
.748 .35872 Mdot
.748 .35936 Mdot
.748 .3597 Mdot
.748 .36084 Mdot
.748 .36121 Mdot
.748 .36195 Mdot
.748 .36265 Mdot
.748 .3631 Mdot
.748 .36393 Mdot
.748 .36404 Mdot
.748 .36485 Mdot
.748 .36557 Mdot
.748 .36567 Mdot
.748 .36585 Mdot
.748 .3659 Mdot
.748 .36595 Mdot
.748 .36638 Mdot
.748 .36641 Mdot
.748 .36695 Mdot
.748 .36756 Mdot
.748 .36796 Mdot
.748 .36805 Mdot
.748 .36814 Mdot
.748 .36844 Mdot
.748 .36893 Mdot
.748 .36947 Mdot
.748 .36959 Mdot
.748 .36965 Mdot
.748 .36968 Mdot
.748 .37011 Mdot
.748 .37074 Mdot
.748 .37087 Mdot
.748 .37088 Mdot
.748 .37152 Mdot
.748 .37153 Mdot
.748 .37199 Mdot
.748 .3723 Mdot
.748 .37265 Mdot
.748 .37332 Mdot
.748 .37355 Mdot
.748 .37517 Mdot
.748 .37532 Mdot
.748 .37544 Mdot
.748 .37574 Mdot
.748 .37602 Mdot
.748 .37612 Mdot
.748 .3765 Mdot
.748 .37669 Mdot
.748 .37709 Mdot
.748 .37726 Mdot
.748 .37883 Mdot
.748 .37887 Mdot
.748 .37905 Mdot
.748 .37927 Mdot
.748 .37959 Mdot
.748 .37967 Mdot
.748 .3802 Mdot
.748 .38076 Mdot
.748 .38107 Mdot
.748 .38126 Mdot
.748 .38177 Mdot
.748 .38188 Mdot
.748 .38368 Mdot
.748 .38485 Mdot
.748 .38488 Mdot
.748 .38548 Mdot
.748 .38703 Mdot
.748 .38748 Mdot
.748 .38785 Mdot
.748 .38873 Mdot
.748 .3892 Mdot
.748 .39029 Mdot
.748 .39067 Mdot
.748 .39078 Mdot
.748 .3908 Mdot
.748 .39149 Mdot
.748 .39188 Mdot
.748 .39224 Mdot
.748 .39244 Mdot
.748 .39298 Mdot
.748 .39375 Mdot
.748 .39377 Mdot
.748 .39384 Mdot
.748 .39462 Mdot
.748 .39467 Mdot
.748 .39522 Mdot
.748 .39629 Mdot
.748 .39649 Mdot
.748 .39688 Mdot
.748 .39699 Mdot
.748 .39735 Mdot
.748 .39804 Mdot
.748 .39828 Mdot
.748 .39888 Mdot
.748 .3997 Mdot
.748 .3999 Mdot
.748 .40033 Mdot
.748 .40087 Mdot
.748 .40094 Mdot
.748 .40102 Mdot
.748 .40135 Mdot
.748 .40244 Mdot
.748 .40267 Mdot
.748 .40428 Mdot
.748 .4045 Mdot
.748 .40504 Mdot
.748 .4051 Mdot
.748 .40514 Mdot
.748 .40526 Mdot
.748 .40574 Mdot
.748 .40641 Mdot
.748 .40706 Mdot
.748 .40712 Mdot
.748 .40799 Mdot
.748 .40815 Mdot
.748 .40951 Mdot
.748 .40969 Mdot
.748 .41196 Mdot
.748 .41353 Mdot
.748 .41423 Mdot
.748 .41465 Mdot
.748 .41491 Mdot
.748 .41603 Mdot
.748 .41667 Mdot
.748 .41669 Mdot
.748 .41696 Mdot
.748 .41712 Mdot
.748 .41736 Mdot
.748 .41737 Mdot
.748 .41763 Mdot
.748 .41765 Mdot
.748 .41814 Mdot
.748 .41837 Mdot
.748 .41875 Mdot
.748 .41933 Mdot
.748 .41999 Mdot
.748 .42005 Mdot
.748 .42029 Mdot
.748 .42109 Mdot
.748 .42146 Mdot
.748 .42222 Mdot
.748 .42335 Mdot
.748 .42339 Mdot
.748 .42383 Mdot
.748 .42386 Mdot
.748 .42408 Mdot
.748 .42441 Mdot
.748 .425 Mdot
.748 .42502 Mdot
.748 .42503 Mdot
.748 .42515 Mdot
.748 .42534 Mdot
.748 .42557 Mdot
.748 .4257 Mdot
.748 .42579 Mdot
.748 .42615 Mdot
.748 .42687 Mdot
.748 .42718 Mdot
.748 .42809 Mdot
.748 .4284 Mdot
.748 .42944 Mdot
.748 .42945 Mdot
.748 .42963 Mdot
.748 .43008 Mdot
.748 .43032 Mdot
.748 .43071 Mdot
.748 .43103 Mdot
.748 .43138 Mdot
.748 .43166 Mdot
.748 .43181 Mdot
.748 .43204 Mdot
.748 .43231 Mdot
.748 .43247 Mdot
.748 .43278 Mdot
.748 .43284 Mdot
.748 .43296 Mdot
.748 .43309 Mdot
.748 .43378 Mdot
.748 .43384 Mdot
.748 .43413 Mdot
.748 .43459 Mdot
.748 .43535 Mdot
.748 .43575 Mdot
.748 .43739 Mdot
.748 .43819 Mdot
.748 .43879 Mdot
.748 .43979 Mdot
.748 .44109 Mdot
.748 .44126 Mdot
.748 .44127 Mdot
.748 .4426 Mdot
.748 .44286 Mdot
.748 .44318 Mdot
.748 .44326 Mdot
.748 .44401 Mdot
.748 .44676 Mdot
.748 .44679 Mdot
.748 .44702 Mdot
.748 .44787 Mdot
.748 .44923 Mdot
.748 .44924 Mdot
.748 .45076 Mdot
.748 .45116 Mdot
.748 .45121 Mdot
.748 .45234 Mdot
.748 .45304 Mdot
.748 .45433 Mdot
.748 .4552 Mdot
.748 .45606 Mdot
.748 .45621 Mdot
.748 .45624 Mdot
.748 .45693 Mdot
.748 .45701 Mdot
.748 .45727 Mdot
.748 .45735 Mdot
.748 .4575 Mdot
.748 .45805 Mdot
.748 .4585 Mdot
.748 .45921 Mdot
.748 .46043 Mdot
.748 .46078 Mdot
.748 .46079 Mdot
.748 .46109 Mdot
.748 .4633 Mdot
.748 .46451 Mdot
.748 .46484 Mdot
.748 .46498 Mdot
.748 .46499 Mdot
.748 .46586 Mdot
.748 .46598 Mdot
.748 .4662 Mdot
.748 .46731 Mdot
.748 .4685 Mdot
.748 .47 Mdot
.748 .47032 Mdot
.748 .47066 Mdot
.748 .47102 Mdot
.748 .4719 Mdot
.748 .47261 Mdot
.748 .47265 Mdot
.748 .47311 Mdot
.748 .4732 Mdot
.748 .47359 Mdot
.748 .4743 Mdot
.748 .47452 Mdot
.748 .47471 Mdot
.748 .4748 Mdot
.748 .4753 Mdot
.748 .47556 Mdot
.748 .47558 Mdot
.748 .47597 Mdot
.748 .47598 Mdot
.748 .47634 Mdot
.748 .47659 Mdot
.748 .47703 Mdot
.748 .47758 Mdot
.748 .47808 Mdot
.748 .4787 Mdot
.748 .47887 Mdot
.748 .47907 Mdot
.748 .47978 Mdot
.748 .48005 Mdot
.748 .48007 Mdot
.748 .4814 Mdot
.748 .48168 Mdot
.748 .48177 Mdot
.748 .48191 Mdot
.748 .48216 Mdot
.748 .48239 Mdot
.748 .48257 Mdot
.748 .48267 Mdot
.748 .48277 Mdot
.748 .48354 Mdot
.748 .48402 Mdot
.748 .48428 Mdot
.748 .48439 Mdot
.748 .48511 Mdot
.748 .48566 Mdot
.748 .48579 Mdot
.748 .48599 Mdot
.748 .48628 Mdot
.748 .48634 Mdot
.748 .48661 Mdot
.748 .4868 Mdot
.748 .48682 Mdot
.748 .48684 Mdot
.748 .48689 Mdot
.748 .48773 Mdot
.748 .48822 Mdot
.748 .48824 Mdot
.748 .48842 Mdot
.748 .48854 Mdot
.748 .48859 Mdot
.748 .48924 Mdot
.748 .48929 Mdot
.748 .48984 Mdot
.748 .49014 Mdot
.748 .49046 Mdot
.748 .49152 Mdot
.748 .49206 Mdot
.748 .4926 Mdot
.748 .49322 Mdot
.748 .49375 Mdot
.748 .4941 Mdot
.748 .49419 Mdot
.748 .49509 Mdot
.748 .49513 Mdot
.748 .49551 Mdot
.748 .4957 Mdot
.748 .4958 Mdot
.748 .49595 Mdot
.748 .49599 Mdot
.748 .49648 Mdot
.748 .4968 Mdot
.748 .4973 Mdot
.748 .4975 Mdot
.748 .49752 Mdot
.748 .49789 Mdot
.748 .4979 Mdot
.748 .49823 Mdot
.748 .49846 Mdot
.748 .49884 Mdot
.748 .49887 Mdot
.748 .49946 Mdot
.748 .49969 Mdot
.748 .49975 Mdot
.748 .49991 Mdot
.748 .49992 Mdot
.748 .50129 Mdot
.748 .50164 Mdot
.748 .50213 Mdot
.748 .50216 Mdot
.748 .50222 Mdot
.748 .50272 Mdot
.748 .50304 Mdot
.748 .50316 Mdot
.748 .50369 Mdot
.748 .50414 Mdot
.748 .50474 Mdot
.748 .50526 Mdot
.748 .50584 Mdot
.748 .50591 Mdot
.748 .50814 Mdot
.748 .50825 Mdot
.748 .50848 Mdot
.748 .50889 Mdot
.748 .51023 Mdot
.748 .51044 Mdot
.748 .51155 Mdot
.748 .51163 Mdot
.748 .51244 Mdot
.748 .51328 Mdot
.748 .51387 Mdot
.748 .51403 Mdot
.748 .51408 Mdot
.748 .51415 Mdot
.748 .51421 Mdot
.748 .51468 Mdot
.748 .51481 Mdot
.748 .51506 Mdot
.748 .51509 Mdot
.748 .51603 Mdot
.748 .51692 Mdot
.748 .51705 Mdot
.748 .51725 Mdot
.748 .51733 Mdot
.748 .51844 Mdot
.748 .51863 Mdot
.748 .51884 Mdot
.748 .51903 Mdot
.748 .51905 Mdot
.748 .51912 Mdot
.748 .51921 Mdot
.748 .51985 Mdot
.748 .52029 Mdot
.748 .52035 Mdot
.748 .52059 Mdot
.748 .52084 Mdot
.748 .52154 Mdot
.748 .52223 Mdot
.748 .52251 Mdot
.748 .5233 Mdot
.748 .52371 Mdot
.748 .52383 Mdot
.748 .52421 Mdot
.748 .52428 Mdot
.748 .5245 Mdot
.748 .52451 Mdot
.748 .52564 Mdot
.748 .52569 Mdot
.748 .52575 Mdot
.748 .52631 Mdot
.748 .52631 Mdot
.748 .52637 Mdot
.748 .52695 Mdot
.748 .52722 Mdot
.748 .5273 Mdot
.748 .52732 Mdot
.748 .52791 Mdot
.748 .52816 Mdot
.748 .52816 Mdot
.748 .52874 Mdot
.748 .52896 Mdot
.748 .52934 Mdot
.748 .52973 Mdot
.748 .52975 Mdot
.748 .5305 Mdot
.748 .53051 Mdot
.748 .53063 Mdot
.748 .53103 Mdot
.748 .53135 Mdot
.748 .53216 Mdot
.748 .53224 Mdot
.748 .53265 Mdot
.748 .53278 Mdot
.748 .53355 Mdot
.748 .53393 Mdot
.748 .53423 Mdot
.748 .53427 Mdot
.748 .53438 Mdot
.748 .53455 Mdot
.748 .53592 Mdot
.748 .53651 Mdot
.748 .53655 Mdot
.748 .53767 Mdot
.748 .53939 Mdot
.748 .53948 Mdot
.748 .53949 Mdot
.748 .53997 Mdot
.748 .54015 Mdot
.748 .54044 Mdot
.748 .54095 Mdot
.748 .54144 Mdot
.748 .54151 Mdot
.748 .54181 Mdot
.748 .542 Mdot
.748 .54217 Mdot
.748 .5422 Mdot
.748 .54254 Mdot
.748 .54263 Mdot
.748 .5436 Mdot
.748 .54375 Mdot
.748 .5441 Mdot
.748 .54415 Mdot
.748 .54427 Mdot
.748 .54459 Mdot
.748 .54468 Mdot
.748 .54492 Mdot
.748 .54518 Mdot
.748 .54528 Mdot
.748 .54541 Mdot
.748 .54678 Mdot
.748 .54697 Mdot
.748 .54752 Mdot
.748 .54754 Mdot
.748 .54781 Mdot
.748 .54795 Mdot
.748 .54806 Mdot
.748 .54822 Mdot
.748 .5483 Mdot
.748 .54843 Mdot
.748 .54844 Mdot
.748 .54896 Mdot
.748 .54896 Mdot
.748 .54901 Mdot
.748 .54907 Mdot
.748 .54957 Mdot
.748 .54987 Mdot
.748 .54991 Mdot
.748 .54993 Mdot
.748 .54998 Mdot
.748 .55007 Mdot
.748 .55049 Mdot
.748 .55087 Mdot
.748 .5511 Mdot
.748 .55117 Mdot
.748 .55123 Mdot
.748 .55154 Mdot
.748 .55158 Mdot
.748 .55187 Mdot
.748 .552 Mdot
.748 .5524 Mdot
.748 .55242 Mdot
.748 .55273 Mdot
.748 .55276 Mdot
.748 .55277 Mdot
.748 .55281 Mdot
.748 .55291 Mdot
.748 .55294 Mdot
.748 .55302 Mdot
.748 .55353 Mdot
.748 .55412 Mdot
.748 .55419 Mdot
.748 .55459 Mdot
.748 .55478 Mdot
.748 .55509 Mdot
.748 .55522 Mdot
.748 .55557 Mdot
.748 .55601 Mdot
.748 .55607 Mdot
.748 .55624 Mdot
.748 .55626 Mdot
.748 .55633 Mdot
.748 .55708 Mdot
.748 .5573 Mdot
.748 .55765 Mdot
.748 .5577 Mdot
.748 .55771 Mdot
.748 .55784 Mdot
.748 .55784 Mdot
.748 .55802 Mdot
.748 .55818 Mdot
.748 .5584 Mdot
.748 .55853 Mdot
.748 .55907 Mdot
.748 .5593 Mdot
.748 .55945 Mdot
.748 .56015 Mdot
.748 .5602 Mdot
.748 .56042 Mdot
.748 .56042 Mdot
.748 .56083 Mdot
.748 .56093 Mdot
.748 .56139 Mdot
.748 .56152 Mdot
.748 .56176 Mdot
.748 .56178 Mdot
.748 .5618 Mdot
.748 .56181 Mdot
.748 .56193 Mdot
.748 .56209 Mdot
.748 .56214 Mdot
.748 .56224 Mdot
.748 .56231 Mdot
.748 .56234 Mdot
.748 .56251 Mdot
.748 .5627 Mdot
.748 .56275 Mdot
.748 .56286 Mdot
.748 .56292 Mdot
.748 .56295 Mdot
.748 .56299 Mdot
.748 .56302 Mdot
.748 .56304 Mdot
.748 .56318 Mdot
.748 .56322 Mdot
.748 .56322 Mdot
.748 .56329 Mdot
.748 .5633 Mdot
.748 .56347 Mdot
.748 .56359 Mdot
.748 .56364 Mdot
.748 .56377 Mdot
.748 .56381 Mdot
.748 .56391 Mdot
.748 .564 Mdot
.748 .56406 Mdot
.748 .56409 Mdot
.748 .56417 Mdot
.748 .56421 Mdot
.748 .56421 Mdot
.748 .56425 Mdot
.748 .56441 Mdot
.748 .56479 Mdot
.748 .56536 Mdot
.748 .56558 Mdot
.748 .5656 Mdot
.748 .56573 Mdot
.748 .56574 Mdot
.748 .566 Mdot
.748 .56602 Mdot
.748 .56602 Mdot
.748 .56611 Mdot
.748 .56637 Mdot
.748 .56656 Mdot
.748 .56661 Mdot
.748 .56671 Mdot
.748 .567 Mdot
.748 .56703 Mdot
.748 .56718 Mdot
.748 .56762 Mdot
.748 .56784 Mdot
.748 .56789 Mdot
.748 .56804 Mdot
.748 .56804 Mdot
.748 .56806 Mdot
.748 .56832 Mdot
.748 .56901 Mdot
.748 .56927 Mdot
.748 .56956 Mdot
.748 .56965 Mdot
.748 .56986 Mdot
.748 .56994 Mdot
.748 .56997 Mdot
.748 .57001 Mdot
.748 .57006 Mdot
.748 .57012 Mdot
.748 .57038 Mdot
.748 .57047 Mdot
.748 .57061 Mdot
.748 .5707 Mdot
.748 .57095 Mdot
.748 .57101 Mdot
.748 .57105 Mdot
.748 .57106 Mdot
.748 .57107 Mdot
.748 .5712 Mdot
.748 .57134 Mdot
.748 .57135 Mdot
.748 .57147 Mdot
.748 .57169 Mdot
.748 .57198 Mdot
.748 .57212 Mdot
.748 .57217 Mdot
.748 .57227 Mdot
.748 .57227 Mdot
.748 .57231 Mdot
.748 .57234 Mdot
.748 .57274 Mdot
.748 .57308 Mdot
.748 .57309 Mdot
.748 .57316 Mdot
.748 .57317 Mdot
.748 .57319 Mdot
.748 .57321 Mdot
.748 .57325 Mdot
.748 .57333 Mdot
.748 .57334 Mdot
.748 .57335 Mdot
.748 .57336 Mdot
.748 .57337 Mdot
.748 .57341 Mdot
.748 .57352 Mdot
.748 .57358 Mdot
.748 .5736 Mdot
.748 .57362 Mdot
.748 .57365 Mdot
.748 .57365 Mdot
.75 .121 Mdot
.75 .12111 Mdot
.75 .12118 Mdot
.75 .12124 Mdot
.75 .12151 Mdot
.75 .12155 Mdot
.75 .12183 Mdot
.75 .12203 Mdot
.75 .12208 Mdot
.75 .12249 Mdot
.75 .12278 Mdot
.75 .12301 Mdot
.75 .12313 Mdot
.75 .12326 Mdot
.75 .12361 Mdot
.75 .1239 Mdot
.75 .12417 Mdot
.75 .12426 Mdot
.75 .12495 Mdot
.75 .12522 Mdot
.75 .12546 Mdot
.75 .12585 Mdot
.75 .12594 Mdot
.75 .12597 Mdot
.75 .12612 Mdot
.75 .12613 Mdot
.75 .12664 Mdot
.75 .12707 Mdot
.75 .12721 Mdot
.75 .12729 Mdot
.75 .12846 Mdot
.75 .1287 Mdot
.75 .12874 Mdot
.75 .12942 Mdot
.75 .13005 Mdot
.75 .13021 Mdot
.75 .13096 Mdot
.75 .13177 Mdot
.75 .13225 Mdot
.75 .13277 Mdot
.75 .13293 Mdot
.75 .13411 Mdot
.75 .13448 Mdot
.75 .13552 Mdot
.75 .13617 Mdot
.75 .1364 Mdot
.75 .13682 Mdot
.75 .13682 Mdot
.75 .13806 Mdot
.75 .13873 Mdot
.75 .13875 Mdot
.75 .14005 Mdot
.75 .14032 Mdot
.75 .14183 Mdot
.75 .14525 Mdot
.75 .14677 Mdot
.75 .14691 Mdot
.75 .14763 Mdot
.75 .14874 Mdot
.75 .14888 Mdot
.75 .15014 Mdot
.75 .15055 Mdot
.75 .15078 Mdot
.75 .15082 Mdot
.75 .15104 Mdot
.75 .15211 Mdot
.75 .15227 Mdot
.75 .1525 Mdot
.75 .15321 Mdot
.75 .15336 Mdot
.75 .15338 Mdot
.75 .15417 Mdot
.75 .15428 Mdot
.75 .15431 Mdot
.75 .15437 Mdot
.75 .15473 Mdot
.75 .1554 Mdot
.75 .15553 Mdot
.75 .15602 Mdot
.75 .15674 Mdot
.75 .15687 Mdot
.75 .15701 Mdot
.75 .15702 Mdot
.75 .15713 Mdot
.75 .15722 Mdot
.75 .15784 Mdot
.75 .15818 Mdot
.75 .15868 Mdot
.75 .15871 Mdot
.75 .15877 Mdot
.75 .15925 Mdot
.75 .15938 Mdot
.75 .15947 Mdot
.75 .16049 Mdot
.75 .16071 Mdot
.75 .16076 Mdot
.75 .16096 Mdot
.75 .16106 Mdot
.75 .16202 Mdot
.75 .16236 Mdot
.75 .1632 Mdot
.75 .16337 Mdot
.75 .16347 Mdot
.75 .16363 Mdot
.75 .16421 Mdot
.75 .16477 Mdot
.75 .16616 Mdot
.75 .16618 Mdot
.75 .16628 Mdot
.75 .1666 Mdot
.75 .16673 Mdot
.75 .16794 Mdot
.75 .16798 Mdot
.75 .16913 Mdot
.75 .17033 Mdot
.75 .17097 Mdot
.75 .17111 Mdot
.75 .17141 Mdot
.75 .17152 Mdot
.75 .17225 Mdot
.75 .17227 Mdot
.75 .17286 Mdot
.75 .17298 Mdot
.75 .17363 Mdot
.75 .17474 Mdot
.75 .17475 Mdot
.75 .17501 Mdot
.75 .17629 Mdot
.75 .17691 Mdot
.75 .17758 Mdot
.75 .17796 Mdot
.75 .17883 Mdot
.75 .17963 Mdot
.75 .17978 Mdot
.75 .17997 Mdot
.75 .18048 Mdot
.75 .18183 Mdot
.75 .1838 Mdot
.75 .18395 Mdot
.75 .18433 Mdot
.75 .1852 Mdot
.75 .18542 Mdot
.75 .18576 Mdot
.75 .18779 Mdot
.75 .18899 Mdot
.75 .18945 Mdot
.75 .18957 Mdot
.75 .19099 Mdot
.75 .19214 Mdot
.75 .19242 Mdot
.75 .19298 Mdot
.75 .19311 Mdot
.75 .19331 Mdot
.75 .19519 Mdot
.75 .19531 Mdot
.75 .19542 Mdot
.75 .19576 Mdot
.75 .19696 Mdot
.75 .19716 Mdot
.75 .19721 Mdot
.75 .19744 Mdot
.75 .19802 Mdot
.75 .19869 Mdot
.75 .19915 Mdot
.75 .19916 Mdot
.75 .20198 Mdot
.75 .20276 Mdot
.75 .20381 Mdot
.75 .2047 Mdot
.75 .20517 Mdot
.75 .20771 Mdot
.75 .20788 Mdot
.75 .20827 Mdot
.75 .20862 Mdot
.75 .20867 Mdot
.75 .2092 Mdot
.75 .20981 Mdot
.75 .21486 Mdot
.75 .215 Mdot
.75 .21512 Mdot
.75 .2153 Mdot
.75 .21543 Mdot
.75 .21566 Mdot
.75 .21787 Mdot
.75 .21993 Mdot
.75 .22159 Mdot
.75 .22273 Mdot
.75 .22302 Mdot
.75 .2239 Mdot
.75 .22412 Mdot
.75 .22417 Mdot
.75 .22461 Mdot
.75 .22577 Mdot
.75 .22757 Mdot
.75 .22816 Mdot
.75 .2287 Mdot
.75 .22872 Mdot
.75 .2296 Mdot
.75 .22979 Mdot
.75 .23007 Mdot
.75 .23126 Mdot
.75 .23218 Mdot
.75 .2322 Mdot
.75 .23224 Mdot
.75 .23412 Mdot
.75 .23427 Mdot
.75 .23463 Mdot
.75 .2349 Mdot
.75 .23559 Mdot
.75 .23592 Mdot
.75 .23634 Mdot
.75 .23724 Mdot
.75 .23889 Mdot
.75 .24003 Mdot
.75 .24177 Mdot
.75 .24188 Mdot
.75 .24194 Mdot
.75 .24433 Mdot
.75 .24447 Mdot
.75 .24463 Mdot
.75 .24623 Mdot
.75 .24811 Mdot
.75 .24811 Mdot
.75 .24893 Mdot
.75 .24951 Mdot
.75 .25063 Mdot
.75 .25214 Mdot
.75 .25219 Mdot
.75 .25291 Mdot
.75 .2538 Mdot
.75 .25468 Mdot
.75 .25557 Mdot
.75 .25651 Mdot
.75 .25888 Mdot
.75 .25943 Mdot
.75 .2598 Mdot
.75 .26105 Mdot
.75 .26317 Mdot
.75 .2642 Mdot
.75 .2646 Mdot
.75 .26465 Mdot
.75 .26596 Mdot
.75 .2661 Mdot
.75 .26679 Mdot
.75 .26723 Mdot
.75 .26818 Mdot
.75 .26835 Mdot
.75 .26953 Mdot
.75 .27035 Mdot
.75 .27044 Mdot
.75 .27088 Mdot
.75 .27326 Mdot
.75 .27399 Mdot
.75 .27924 Mdot
.75 .28266 Mdot
.75 .28451 Mdot
.75 .28581 Mdot
.75 .28682 Mdot
.75 .28767 Mdot
.75 .28849 Mdot
.75 .2902 Mdot
.75 .29295 Mdot
.75 .29369 Mdot
.75 .2941 Mdot
.75 .29471 Mdot
.75 .29511 Mdot
.75 .29556 Mdot
.75 .29747 Mdot
.75 .29805 Mdot
.75 .29906 Mdot
.75 .29993 Mdot
.75 .30401 Mdot
.75 .31044 Mdot
.75 .31163 Mdot
.75 .3122 Mdot
.75 .31258 Mdot
.75 .31421 Mdot
.75 .31532 Mdot
.75 .316 Mdot
.75 .31615 Mdot
.75 .31735 Mdot
.75 .31866 Mdot
.75 .31894 Mdot
.75 .31923 Mdot
.75 .32108 Mdot
.75 .32126 Mdot
.75 .32407 Mdot
.75 .3241 Mdot
.75 .32433 Mdot
.75 .32569 Mdot
.75 .32587 Mdot
.75 .32598 Mdot
.75 .32749 Mdot
.75 .32778 Mdot
.75 .32864 Mdot
.75 .32936 Mdot
.75 .3317 Mdot
.75 .33238 Mdot
.75 .33386 Mdot
.75 .3348 Mdot
.75 .33558 Mdot
.75 .33594 Mdot
.75 .33594 Mdot
.75 .33698 Mdot
.75 .33753 Mdot
.75 .33755 Mdot
.75 .33858 Mdot
.75 .33994 Mdot
.75 .34241 Mdot
.75 .34346 Mdot
.75 .34356 Mdot
.75 .34486 Mdot
.75 .34567 Mdot
.75 .34593 Mdot
.75 .34608 Mdot
.75 .34611 Mdot
.75 .34625 Mdot
.75 .34691 Mdot
.75 .34701 Mdot
.75 .34769 Mdot
.75 .34817 Mdot
.75 .34824 Mdot
.75 .34825 Mdot
.75 .34829 Mdot
.75 .3489 Mdot
.75 .34898 Mdot
.75 .34927 Mdot
.75 .34976 Mdot
.75 .34984 Mdot
.75 .34991 Mdot
.75 .34996 Mdot
.75 .35032 Mdot
.75 .35051 Mdot
.75 .35081 Mdot
.75 .35085 Mdot
.75 .35112 Mdot
.75 .35119 Mdot
.75 .35181 Mdot
.75 .35196 Mdot
.75 .35213 Mdot
.75 .35265 Mdot
.75 .35284 Mdot
.75 .35329 Mdot
.75 .35352 Mdot
.75 .35412 Mdot
.75 .35485 Mdot
.75 .35492 Mdot
.75 .35508 Mdot
.75 .35515 Mdot
.75 .35577 Mdot
.75 .35579 Mdot
.75 .35638 Mdot
.75 .3573 Mdot
.75 .35737 Mdot
.75 .35752 Mdot
.75 .35757 Mdot
.75 .35793 Mdot
.75 .35795 Mdot
.75 .35829 Mdot
.75 .35915 Mdot
.75 .35927 Mdot
.75 .35988 Mdot
.75 .36018 Mdot
.75 .36049 Mdot
.75 .36067 Mdot
.75 .36108 Mdot
.75 .36145 Mdot
.75 .36161 Mdot
.75 .36184 Mdot
.75 .36342 Mdot
.75 .36359 Mdot
.75 .36398 Mdot
.75 .36408 Mdot
.75 .36564 Mdot
.75 .36651 Mdot
.75 .367 Mdot
.75 .36712 Mdot
.75 .36735 Mdot
.75 .36749 Mdot
.75 .36828 Mdot
.75 .36833 Mdot
.75 .36838 Mdot
.75 .36902 Mdot
.75 .36912 Mdot
.75 .36922 Mdot
.75 .36946 Mdot
.75 .36973 Mdot
.75 .37107 Mdot
.75 .37138 Mdot
.75 .37215 Mdot
.75 .37234 Mdot
.75 .37334 Mdot
.75 .37372 Mdot
.75 .37393 Mdot
.75 .37416 Mdot
.75 .37619 Mdot
.75 .37631 Mdot
.75 .3764 Mdot
.75 .37723 Mdot
.75 .37861 Mdot
.75 .37903 Mdot
.75 .37946 Mdot
.75 .37954 Mdot
.75 .37956 Mdot
.75 .37972 Mdot
.75 .38014 Mdot
.75 .38101 Mdot
.75 .3812 Mdot
.75 .38121 Mdot
.75 .38152 Mdot
.75 .38159 Mdot
.75 .38245 Mdot
.75 .38246 Mdot
.75 .38318 Mdot
.75 .38331 Mdot
.75 .38365 Mdot
.75 .38423 Mdot
.75 .3848 Mdot
.75 .3852 Mdot
.75 .38668 Mdot
.75 .38672 Mdot
.75 .38732 Mdot
.75 .38796 Mdot
.75 .38881 Mdot
.75 .38958 Mdot
.75 .39016 Mdot
.75 .39077 Mdot
.75 .39155 Mdot
.75 .39173 Mdot
.75 .39186 Mdot
.75 .39296 Mdot
.75 .39329 Mdot
.75 .39344 Mdot
.75 .39427 Mdot
.75 .39458 Mdot
.75 .39463 Mdot
.75 .39528 Mdot
.75 .39545 Mdot
.75 .39621 Mdot
.75 .39918 Mdot
.75 .39976 Mdot
.75 .40048 Mdot
.75 .40074 Mdot
.75 .40099 Mdot
.75 .40152 Mdot
.75 .40376 Mdot
.75 .40394 Mdot
.75 .40425 Mdot
.75 .40451 Mdot
.75 .40575 Mdot
.75 .40769 Mdot
.75 .40805 Mdot
.75 .40834 Mdot
.75 .40916 Mdot
.75 .41024 Mdot
.75 .41088 Mdot
.75 .41093 Mdot
.75 .41177 Mdot
.75 .41178 Mdot
.75 .41184 Mdot
.75 .41225 Mdot
.75 .4123 Mdot
.75 .41233 Mdot
.75 .41278 Mdot
.75 .41312 Mdot
.75 .41402 Mdot
.75 .41466 Mdot
.75 .41494 Mdot
.75 .41517 Mdot
.75 .41527 Mdot
.75 .41558 Mdot
.75 .41574 Mdot
.75 .41574 Mdot
.75 .41645 Mdot
.75 .41717 Mdot
.75 .41748 Mdot
.75 .41751 Mdot
.75 .41789 Mdot
.75 .41825 Mdot
.75 .41907 Mdot
.75 .41909 Mdot
.75 .41932 Mdot
.75 .41936 Mdot
.75 .41948 Mdot
.75 .41964 Mdot
.75 .41992 Mdot
.75 .42022 Mdot
.75 .4208 Mdot
.75 .42154 Mdot
.75 .42181 Mdot
.75 .42209 Mdot
.75 .42277 Mdot
.75 .42335 Mdot
.75 .42419 Mdot
.75 .42434 Mdot
.75 .42444 Mdot
.75 .42471 Mdot
.75 .42474 Mdot
.75 .42495 Mdot
.75 .42513 Mdot
.75 .42635 Mdot
.75 .42642 Mdot
.75 .42701 Mdot
.75 .42771 Mdot
.75 .42783 Mdot
.75 .42796 Mdot
.75 .42798 Mdot
.75 .42803 Mdot
.75 .42816 Mdot
.75 .42847 Mdot
.75 .42908 Mdot
.75 .42917 Mdot
.75 .42934 Mdot
.75 .42951 Mdot
.75 .43043 Mdot
.75 .43068 Mdot
.75 .43125 Mdot
.75 .43148 Mdot
.75 .43153 Mdot
.75 .43156 Mdot
.75 .43189 Mdot
.75 .43198 Mdot
.75 .43236 Mdot
.75 .43237 Mdot
.75 .43256 Mdot
.75 .43387 Mdot
.75 .43439 Mdot
.75 .43504 Mdot
.75 .43526 Mdot
.75 .43663 Mdot
.75 .43695 Mdot
.75 .43714 Mdot
.75 .4374 Mdot
.75 .43742 Mdot
.75 .4378 Mdot
.75 .43852 Mdot
.75 .43857 Mdot
.75 .43878 Mdot
.75 .43931 Mdot
.75 .43956 Mdot
.75 .43973 Mdot
.75 .43981 Mdot
.75 .44083 Mdot
.75 .44213 Mdot
.75 .44217 Mdot
.75 .44221 Mdot
.75 .44236 Mdot
.75 .44257 Mdot
.75 .44295 Mdot
.75 .44319 Mdot
.75 .44353 Mdot
.75 .44398 Mdot
.75 .44541 Mdot
.75 .44547 Mdot
.75 .44563 Mdot
.75 .44609 Mdot
.75 .44756 Mdot
.75 .44971 Mdot
.75 .44996 Mdot
.75 .45087 Mdot
.75 .45112 Mdot
.75 .45164 Mdot
.75 .45183 Mdot
.75 .45258 Mdot
.75 .45313 Mdot
.75 .45317 Mdot
.75 .4534 Mdot
.75 .45368 Mdot
.75 .45379 Mdot
.75 .45421 Mdot
.75 .45442 Mdot
.75 .45555 Mdot
.75 .45629 Mdot
.75 .45708 Mdot
.75 .45749 Mdot
.75 .45751 Mdot
.75 .45766 Mdot
.75 .45796 Mdot
.75 .45808 Mdot
.75 .45873 Mdot
.75 .4591 Mdot
.75 .45936 Mdot
.75 .45943 Mdot
.75 .45949 Mdot
.75 .46015 Mdot
.75 .46122 Mdot
.75 .46172 Mdot
.75 .46236 Mdot
.75 .463 Mdot
.75 .46345 Mdot
.75 .46359 Mdot
.75 .46387 Mdot
.75 .46429 Mdot
.75 .46446 Mdot
.75 .46518 Mdot
.75 .46553 Mdot
.75 .46561 Mdot
.75 .46581 Mdot
.75 .46606 Mdot
.75 .46638 Mdot
.75 .46682 Mdot
.75 .46722 Mdot
.75 .46745 Mdot
.75 .46748 Mdot
.75 .46792 Mdot
.75 .46823 Mdot
.75 .46875 Mdot
.75 .46946 Mdot
.75 .47099 Mdot
.75 .47135 Mdot
.75 .47241 Mdot
.75 .47266 Mdot
.75 .47291 Mdot
.75 .47325 Mdot
.75 .47352 Mdot
.75 .47491 Mdot
.75 .47527 Mdot
.75 .47535 Mdot
.75 .47565 Mdot
.75 .47567 Mdot
.75 .47581 Mdot
.75 .47627 Mdot
.75 .47643 Mdot
.75 .47693 Mdot
.75 .47699 Mdot
.75 .47707 Mdot
.75 .47743 Mdot
.75 .47833 Mdot
.75 .47872 Mdot
.75 .47901 Mdot
.75 .48016 Mdot
.75 .48042 Mdot
.75 .48068 Mdot
.75 .48083 Mdot
.75 .48089 Mdot
.75 .4816 Mdot
.75 .48178 Mdot
.75 .48178 Mdot
.75 .48225 Mdot
.75 .48244 Mdot
.75 .48252 Mdot
.75 .48256 Mdot
.75 .48275 Mdot
.75 .48293 Mdot
.75 .48396 Mdot
.75 .48401 Mdot
.75 .48491 Mdot
.75 .48501 Mdot
.75 .48571 Mdot
.75 .48613 Mdot
.75 .48685 Mdot
.75 .48697 Mdot
.75 .48711 Mdot
.75 .48716 Mdot
.75 .48743 Mdot
.75 .48745 Mdot
.75 .48747 Mdot
.75 .48788 Mdot
.75 .48803 Mdot
.75 .48825 Mdot
.75 .4895 Mdot
.75 .49025 Mdot
.75 .49035 Mdot
.75 .49042 Mdot
.75 .49057 Mdot
.75 .49108 Mdot
.75 .49134 Mdot
.75 .49176 Mdot
.75 .49215 Mdot
.75 .49282 Mdot
.75 .49311 Mdot
.75 .49318 Mdot
.75 .49321 Mdot
.75 .49352 Mdot
.75 .49406 Mdot
.75 .49435 Mdot
.75 .49449 Mdot
.75 .49474 Mdot
.75 .49489 Mdot
.75 .49511 Mdot
.75 .49528 Mdot
.75 .49531 Mdot
.75 .49534 Mdot
.75 .49566 Mdot
.75 .4957 Mdot
.75 .49597 Mdot
.75 .49597 Mdot
.75 .49686 Mdot
.75 .49737 Mdot
.75 .4979 Mdot
.75 .49794 Mdot
.75 .49837 Mdot
.75 .49938 Mdot
.75 .49993 Mdot
.75 .50035 Mdot
.75 .50036 Mdot
.75 .50058 Mdot
.75 .501 Mdot
.75 .501 Mdot
.75 .50115 Mdot
.75 .50146 Mdot
.75 .50184 Mdot
.75 .50243 Mdot
.75 .5027 Mdot
.75 .50363 Mdot
.75 .50392 Mdot
.75 .50426 Mdot
.75 .50438 Mdot
.75 .50498 Mdot
.75 .50502 Mdot
.75 .50509 Mdot
.75 .50563 Mdot
.75 .50572 Mdot
.75 .50573 Mdot
.75 .50683 Mdot
.75 .5069 Mdot
.75 .50763 Mdot
.75 .50774 Mdot
.75 .50785 Mdot
.75 .50836 Mdot
.75 .50882 Mdot
.75 .50888 Mdot
.75 .50914 Mdot
.75 .50957 Mdot
.75 .5102 Mdot
.75 .51035 Mdot
.75 .51057 Mdot
.75 .51103 Mdot
.75 .51348 Mdot
.75 .51501 Mdot
.75 .51534 Mdot
.75 .51572 Mdot
.75 .51594 Mdot
.75 .51665 Mdot
.75 .51682 Mdot
.75 .51697 Mdot
.75 .51719 Mdot
.75 .51735 Mdot
.75 .51762 Mdot
.75 .51864 Mdot
.75 .51927 Mdot
.75 .51957 Mdot
.75 .51989 Mdot
.75 .52026 Mdot
.75 .52073 Mdot
.75 .52141 Mdot
.75 .52265 Mdot
.75 .52455 Mdot
.75 .52481 Mdot
.75 .52566 Mdot
.75 .52582 Mdot
.75 .52585 Mdot
.75 .52614 Mdot
.75 .52657 Mdot
.75 .52662 Mdot
.75 .52696 Mdot
.75 .52712 Mdot
.75 .52736 Mdot
.75 .52741 Mdot
.75 .52788 Mdot
.75 .5279 Mdot
.75 .52804 Mdot
.75 .5284 Mdot
.75 .52915 Mdot
.75 .52959 Mdot
.75 .52972 Mdot
.75 .52991 Mdot
.75 .53074 Mdot
.75 .53107 Mdot
.75 .53138 Mdot
.75 .53168 Mdot
.75 .53199 Mdot
.75 .53224 Mdot
.75 .53226 Mdot
.75 .53278 Mdot
.75 .53317 Mdot
.75 .53337 Mdot
.75 .53365 Mdot
.75 .53365 Mdot
.75 .5343 Mdot
.75 .53485 Mdot
.75 .5349 Mdot
.75 .53495 Mdot
.75 .53577 Mdot
.75 .53579 Mdot
.75 .53583 Mdot
.75 .53642 Mdot
.75 .53681 Mdot
.75 .53737 Mdot
.75 .53768 Mdot
.75 .53782 Mdot
.75 .53793 Mdot
.75 .53816 Mdot
.75 .53826 Mdot
.75 .53838 Mdot
.75 .53843 Mdot
.75 .53906 Mdot
.75 .53908 Mdot
.75 .53908 Mdot
.75 .53939 Mdot
.75 .53979 Mdot
.75 .53988 Mdot
.75 .53995 Mdot
.75 .54024 Mdot
.75 .54025 Mdot
.75 .54043 Mdot
.75 .54063 Mdot
.75 .54123 Mdot
.75 .54161 Mdot
.75 .54176 Mdot
.75 .54178 Mdot
.75 .54185 Mdot
.75 .54214 Mdot
.75 .54224 Mdot
.75 .54262 Mdot
.75 .54317 Mdot
.75 .54385 Mdot
.75 .54458 Mdot
.75 .54465 Mdot
.75 .54469 Mdot
.75 .54475 Mdot
.75 .54479 Mdot
.75 .54484 Mdot
.75 .54649 Mdot
.75 .54669 Mdot
.75 .54686 Mdot
.75 .54688 Mdot
.75 .54699 Mdot
.75 .54712 Mdot
.75 .54718 Mdot
.75 .548 Mdot
.75 .54815 Mdot
.75 .54844 Mdot
.75 .54878 Mdot
.75 .54903 Mdot
.75 .54994 Mdot
.75 .54994 Mdot
.75 .55009 Mdot
.75 .55031 Mdot
.75 .55049 Mdot
.75 .55057 Mdot
.75 .55058 Mdot
.75 .55065 Mdot
.75 .55103 Mdot
.75 .55114 Mdot
.75 .55118 Mdot
.75 .55121 Mdot
.75 .55181 Mdot
.75 .55188 Mdot
.75 .55192 Mdot
.75 .5521 Mdot
.75 .55218 Mdot
.75 .55255 Mdot
.75 .553 Mdot
.75 .55304 Mdot
.75 .55319 Mdot
.75 .55357 Mdot
.75 .55421 Mdot
.75 .55432 Mdot
.75 .55439 Mdot
.75 .55466 Mdot
.75 .55478 Mdot
.75 .55483 Mdot
.75 .55545 Mdot
.75 .55587 Mdot
.75 .55603 Mdot
.75 .55609 Mdot
.75 .55614 Mdot
.75 .55639 Mdot
.75 .55666 Mdot
.75 .55678 Mdot
.75 .55699 Mdot
.75 .55718 Mdot
.75 .55758 Mdot
.75 .55766 Mdot
.75 .55767 Mdot
.75 .55801 Mdot
.75 .55821 Mdot
.75 .55825 Mdot
.75 .55843 Mdot
.75 .55844 Mdot
.75 .55867 Mdot
.75 .5587 Mdot
.75 .55879 Mdot
.75 .55884 Mdot
.75 .55904 Mdot
.75 .55941 Mdot
.75 .55976 Mdot
.75 .55977 Mdot
.75 .56015 Mdot
.75 .56019 Mdot
.75 .56029 Mdot
.75 .56032 Mdot
.75 .56033 Mdot
.75 .56075 Mdot
.75 .56092 Mdot
.75 .5611 Mdot
.75 .56115 Mdot
.75 .56118 Mdot
.75 .56123 Mdot
.75 .56149 Mdot
.75 .5616 Mdot
.75 .56189 Mdot
.75 .56192 Mdot
.75 .56198 Mdot
.75 .562 Mdot
.75 .56206 Mdot
.75 .56238 Mdot
.75 .5624 Mdot
.75 .56245 Mdot
.75 .56259 Mdot
.75 .56261 Mdot
.75 .56262 Mdot
.75 .56277 Mdot
.75 .56287 Mdot
.75 .56306 Mdot
.75 .56309 Mdot
.75 .56313 Mdot
.75 .56313 Mdot
.75 .56317 Mdot
.75 .56321 Mdot
.75 .56343 Mdot
.75 .56358 Mdot
.75 .56362 Mdot
.75 .56382 Mdot
.75 .56393 Mdot
.75 .56395 Mdot
.75 .56396 Mdot
.75 .56399 Mdot
.75 .56423 Mdot
.75 .56424 Mdot
.75 .56428 Mdot
.75 .5645 Mdot
.75 .56457 Mdot
.75 .56462 Mdot
.75 .56494 Mdot
.75 .56501 Mdot
.75 .56502 Mdot
.75 .56509 Mdot
.75 .56521 Mdot
.75 .56559 Mdot
.75 .56564 Mdot
.75 .56597 Mdot
.75 .56619 Mdot
.75 .56623 Mdot
.75 .56669 Mdot
.75 .56771 Mdot
.75 .56817 Mdot
.75 .56825 Mdot
.75 .56863 Mdot
.75 .56864 Mdot
.75 .56884 Mdot
.75 .56921 Mdot
.75 .56921 Mdot
.75 .56933 Mdot
.75 .5694 Mdot
.75 .5696 Mdot
.75 .5699 Mdot
.75 .57001 Mdot
.75 .57036 Mdot
.75 .57041 Mdot
.75 .57057 Mdot
.75 .57071 Mdot
.75 .57095 Mdot
.75 .57117 Mdot
.75 .57122 Mdot
.75 .5714 Mdot
.75 .5716 Mdot
.75 .57162 Mdot
.75 .57169 Mdot
.75 .57203 Mdot
.75 .57205 Mdot
.75 .57209 Mdot
.75 .57222 Mdot
.75 .57237 Mdot
.75 .57237 Mdot
.75 .57242 Mdot
.75 .57243 Mdot
.75 .57245 Mdot
.75 .57257 Mdot
.75 .57264 Mdot
.75 .57272 Mdot
.75 .57292 Mdot
.75 .57295 Mdot
.75 .57303 Mdot
.75 .57311 Mdot
.75 .57322 Mdot
.75 .57325 Mdot
.75 .57325 Mdot
.75 .57329 Mdot
.75 .57336 Mdot
.75 .57344 Mdot
.75 .57356 Mdot
.75 .57357 Mdot
.75 .57363 Mdot
.75 .57371 Mdot
.75 .57373 Mdot
.75 .57381 Mdot
.75 .57382 Mdot
.75 .57384 Mdot
.75 .57388 Mdot
.752 .1202 Mdot
.752 .12021 Mdot
.752 .12022 Mdot
.752 .12025 Mdot
.752 .12026 Mdot
.752 .12029 Mdot
.752 .12031 Mdot
.752 .12037 Mdot
.752 .12038 Mdot
.752 .12042 Mdot
.752 .1207 Mdot
.752 .12098 Mdot
.752 .12125 Mdot
.752 .12128 Mdot
.752 .12133 Mdot
.752 .12137 Mdot
.752 .1215 Mdot
.752 .12156 Mdot
.752 .12157 Mdot
.752 .12167 Mdot
.752 .1218 Mdot
.752 .12183 Mdot
.752 .12189 Mdot
.752 .12218 Mdot
.752 .12241 Mdot
.752 .12256 Mdot
.752 .12263 Mdot
.752 .12289 Mdot
.752 .12294 Mdot
.752 .12304 Mdot
.752 .12319 Mdot
.752 .12327 Mdot
.752 .12382 Mdot
.752 .12399 Mdot
.752 .1243 Mdot
.752 .12437 Mdot
.752 .12562 Mdot
.752 .12618 Mdot
.752 .12713 Mdot
.752 .12718 Mdot
.752 .12727 Mdot
.752 .12738 Mdot
.752 .1274 Mdot
.752 .12804 Mdot
.752 .12809 Mdot
.752 .12825 Mdot
.752 .129 Mdot
.752 .12915 Mdot
.752 .12996 Mdot
.752 .13092 Mdot
.752 .13111 Mdot
.752 .13125 Mdot
.752 .13158 Mdot
.752 .13192 Mdot
.752 .13223 Mdot
.752 .13238 Mdot
.752 .13265 Mdot
.752 .13295 Mdot
.752 .13316 Mdot
.752 .13526 Mdot
.752 .13624 Mdot
.752 .13628 Mdot
.752 .13632 Mdot
.752 .13664 Mdot
.752 .13803 Mdot
.752 .13818 Mdot
.752 .14067 Mdot
.752 .1407 Mdot
.752 .14076 Mdot
.752 .14164 Mdot
.752 .14189 Mdot
.752 .14416 Mdot
.752 .14418 Mdot
.752 .14494 Mdot
.752 .14544 Mdot
.752 .14572 Mdot
.752 .14666 Mdot
.752 .1467 Mdot
.752 .14674 Mdot
.752 .14684 Mdot
.752 .14689 Mdot
.752 .14697 Mdot
.752 .14707 Mdot
.752 .14729 Mdot
.752 .14731 Mdot
.752 .14748 Mdot
.752 .14793 Mdot
.752 .14847 Mdot
.752 .14851 Mdot
.752 .14864 Mdot
.752 .14936 Mdot
.752 .14958 Mdot
.752 .15061 Mdot
.752 .15073 Mdot
.752 .15091 Mdot
.752 .15108 Mdot
.752 .15159 Mdot
.752 .15164 Mdot
.752 .15169 Mdot
.752 .15183 Mdot
.752 .15186 Mdot
.752 .15227 Mdot
.752 .15227 Mdot
.752 .15278 Mdot
.752 .15288 Mdot
.752 .15314 Mdot
.752 .15409 Mdot
.752 .15429 Mdot
.752 .15436 Mdot
.752 .15524 Mdot
.752 .15524 Mdot
.752 .15585 Mdot
.752 .15616 Mdot
.752 .15651 Mdot
.752 .15662 Mdot
.752 .15723 Mdot
.752 .15728 Mdot
.752 .15746 Mdot
.752 .15751 Mdot
.752 .15788 Mdot
.752 .15851 Mdot
.752 .15858 Mdot
.752 .15884 Mdot
.752 .15933 Mdot
.752 .15976 Mdot
.752 .16074 Mdot
.752 .16126 Mdot
.752 .16192 Mdot
.752 .16198 Mdot
.752 .16327 Mdot
.752 .16339 Mdot
.752 .1637 Mdot
.752 .1651 Mdot
.752 .16674 Mdot
.752 .16874 Mdot
.752 .1688 Mdot
.752 .16882 Mdot
.752 .16946 Mdot
.752 .16966 Mdot
.752 .17184 Mdot
.752 .17218 Mdot
.752 .17381 Mdot
.752 .17544 Mdot
.752 .17643 Mdot
.752 .17683 Mdot
.752 .17687 Mdot
.752 .17708 Mdot
.752 .1774 Mdot
.752 .17751 Mdot
.752 .17773 Mdot
.752 .17809 Mdot
.752 .17819 Mdot
.752 .17825 Mdot
.752 .18116 Mdot
.752 .18143 Mdot
.752 .1817 Mdot
.752 .182 Mdot
.752 .18255 Mdot
.752 .1829 Mdot
.752 .18383 Mdot
.752 .18461 Mdot
.752 .18529 Mdot
.752 .18649 Mdot
.752 .18728 Mdot
.752 .18731 Mdot
.752 .18831 Mdot
.752 .18909 Mdot
.752 .18936 Mdot
.752 .19017 Mdot
.752 .19025 Mdot
.752 .19126 Mdot
.752 .19138 Mdot
.752 .19163 Mdot
.752 .19387 Mdot
.752 .19457 Mdot
.752 .19469 Mdot
.752 .19694 Mdot
.752 .19802 Mdot
.752 .19855 Mdot
.752 .19877 Mdot
.752 .19897 Mdot
.752 .19982 Mdot
.752 .20067 Mdot
.752 .20251 Mdot
.752 .20261 Mdot
.752 .20286 Mdot
.752 .20356 Mdot
.752 .20437 Mdot
.752 .20526 Mdot
.752 .20653 Mdot
.752 .20657 Mdot
.752 .20681 Mdot
.752 .20834 Mdot
.752 .20857 Mdot
.752 .20979 Mdot
.752 .20994 Mdot
.752 .2105 Mdot
.752 .21161 Mdot
.752 .21382 Mdot
.752 .21744 Mdot
.752 .22004 Mdot
.752 .22033 Mdot
.752 .22084 Mdot
.752 .22118 Mdot
.752 .22165 Mdot
.752 .22176 Mdot
.752 .2224 Mdot
.752 .22252 Mdot
.752 .2274 Mdot
.752 .22845 Mdot
.752 .22873 Mdot
.752 .22887 Mdot
.752 .22896 Mdot
.752 .22936 Mdot
.752 .23097 Mdot
.752 .23193 Mdot
.752 .23295 Mdot
.752 .23656 Mdot
.752 .23914 Mdot
.752 .23967 Mdot
.752 .23978 Mdot
.752 .24074 Mdot
.752 .24211 Mdot
.752 .2449 Mdot
.752 .24491 Mdot
.752 .2481 Mdot
.752 .24969 Mdot
.752 .24974 Mdot
.752 .25004 Mdot
.752 .25089 Mdot
.752 .25114 Mdot
.752 .25157 Mdot
.752 .25241 Mdot
.752 .25558 Mdot
.752 .25691 Mdot
.752 .25716 Mdot
.752 .25756 Mdot
.752 .25823 Mdot
.752 .25997 Mdot
.752 .26338 Mdot
.752 .26434 Mdot
.752 .26506 Mdot
.752 .27059 Mdot
.752 .27094 Mdot
.752 .27097 Mdot
.752 .27287 Mdot
.752 .27298 Mdot
.752 .27333 Mdot
.752 .2748 Mdot
.752 .27499 Mdot
.752 .27586 Mdot
.752 .2775 Mdot
.752 .27834 Mdot
.752 .27842 Mdot
.752 .28036 Mdot
.752 .28048 Mdot
.752 .28546 Mdot
.752 .28561 Mdot
.752 .28673 Mdot
.752 .28693 Mdot
.752 .28884 Mdot
.752 .28901 Mdot
.752 .28989 Mdot
.752 .29015 Mdot
.752 .29093 Mdot
.752 .29121 Mdot
.752 .29591 Mdot
.752 .29722 Mdot
.752 .29738 Mdot
.752 .29767 Mdot
.752 .29798 Mdot
.752 .29851 Mdot
.752 .29868 Mdot
.752 .29901 Mdot
.752 .29955 Mdot
.752 .30025 Mdot
.752 .30115 Mdot
.752 .30172 Mdot
.752 .30186 Mdot
.752 .30305 Mdot
.752 .3058 Mdot
.752 .30615 Mdot
.752 .30742 Mdot
.752 .30947 Mdot
.752 .30987 Mdot
.752 .31015 Mdot
.752 .31079 Mdot
.752 .31104 Mdot
.752 .31133 Mdot
.752 .31184 Mdot
.752 .3138 Mdot
.752 .31593 Mdot
.752 .31603 Mdot
.752 .3167 Mdot
.752 .3169 Mdot
.752 .31719 Mdot
.752 .31754 Mdot
.752 .31761 Mdot
.752 .32017 Mdot
.752 .32183 Mdot
.752 .32266 Mdot
.752 .32277 Mdot
.752 .32469 Mdot
.752 .3255 Mdot
.752 .32676 Mdot
.752 .32693 Mdot
.752 .32708 Mdot
.752 .32795 Mdot
.752 .33008 Mdot
.752 .33144 Mdot
.752 .33178 Mdot
.752 .33212 Mdot
.752 .33283 Mdot
.752 .33312 Mdot
.752 .33331 Mdot
.752 .33522 Mdot
.752 .33607 Mdot
.752 .33611 Mdot
.752 .33614 Mdot
.752 .33641 Mdot
.752 .33964 Mdot
.752 .34034 Mdot
.752 .34216 Mdot
.752 .3427 Mdot
.752 .34386 Mdot
.752 .34389 Mdot
.752 .34392 Mdot
.752 .34399 Mdot
.752 .34402 Mdot
.752 .34407 Mdot
.752 .34414 Mdot
.752 .34428 Mdot
.752 .3443 Mdot
.752 .34441 Mdot
.752 .34508 Mdot
.752 .34563 Mdot
.752 .34577 Mdot
.752 .34642 Mdot
.752 .34649 Mdot
.752 .34661 Mdot
.752 .34672 Mdot
.752 .34703 Mdot
.752 .34718 Mdot
.752 .34719 Mdot
.752 .34744 Mdot
.752 .34775 Mdot
.752 .34782 Mdot
.752 .34797 Mdot
.752 .34854 Mdot
.752 .34866 Mdot
.752 .3487 Mdot
.752 .34922 Mdot
.752 .34922 Mdot
.752 .34958 Mdot
.752 .34976 Mdot
.752 .34996 Mdot
.752 .35002 Mdot
.752 .35037 Mdot
.752 .3504 Mdot
.752 .3505 Mdot
.752 .35053 Mdot
.752 .35074 Mdot
.752 .35109 Mdot
.752 .35113 Mdot
.752 .35128 Mdot
.752 .35155 Mdot
.752 .35179 Mdot
.752 .35233 Mdot
.752 .35261 Mdot
.752 .353 Mdot
.752 .35376 Mdot
.752 .35392 Mdot
.752 .35551 Mdot
.752 .35652 Mdot
.752 .35655 Mdot
.752 .35657 Mdot
.752 .35688 Mdot
.752 .35699 Mdot
.752 .35823 Mdot
.752 .35902 Mdot
.752 .36027 Mdot
.752 .36045 Mdot
.752 .36057 Mdot
.752 .36072 Mdot
.752 .36077 Mdot
.752 .36104 Mdot
.752 .36109 Mdot
.752 .36258 Mdot
.752 .3627 Mdot
.752 .36283 Mdot
.752 .36308 Mdot
.752 .36324 Mdot
.752 .36366 Mdot
.752 .364 Mdot
.752 .36431 Mdot
.752 .36484 Mdot
.752 .36518 Mdot
.752 .36519 Mdot
.752 .36597 Mdot
.752 .36608 Mdot
.752 .36643 Mdot
.752 .36695 Mdot
.752 .36705 Mdot
.752 .36927 Mdot
.752 .36971 Mdot
.752 .37002 Mdot
.752 .3701 Mdot
.752 .37044 Mdot
.752 .37079 Mdot
.752 .37153 Mdot
.752 .37157 Mdot
.752 .37167 Mdot
.752 .37195 Mdot
.752 .37227 Mdot
.752 .37262 Mdot
.752 .37323 Mdot
.752 .37382 Mdot
.752 .37391 Mdot
.752 .37439 Mdot
.752 .37445 Mdot
.752 .37466 Mdot
.752 .37509 Mdot
.752 .37855 Mdot
.752 .37868 Mdot
.752 .37885 Mdot
.752 .37912 Mdot
.752 .37917 Mdot
.752 .38094 Mdot
.752 .38132 Mdot
.752 .38142 Mdot
.752 .3815 Mdot
.752 .38164 Mdot
.752 .38222 Mdot
.752 .38256 Mdot
.752 .38292 Mdot
.752 .38418 Mdot
.752 .38526 Mdot
.752 .3853 Mdot
.752 .38563 Mdot
.752 .38705 Mdot
.752 .38814 Mdot
.752 .38869 Mdot
.752 .38879 Mdot
.752 .39108 Mdot
.752 .39116 Mdot
.752 .39129 Mdot
.752 .39151 Mdot
.752 .39208 Mdot
.752 .39319 Mdot
.752 .3935 Mdot
.752 .39374 Mdot
.752 .39563 Mdot
.752 .39624 Mdot
.752 .39691 Mdot
.752 .39797 Mdot
.752 .3986 Mdot
.752 .39864 Mdot
.752 .4002 Mdot
.752 .40025 Mdot
.752 .40065 Mdot
.752 .40125 Mdot
.752 .4013 Mdot
.752 .40157 Mdot
.752 .40165 Mdot
.752 .40189 Mdot
.752 .40198 Mdot
.752 .40342 Mdot
.752 .40382 Mdot
.752 .40387 Mdot
.752 .40396 Mdot
.752 .40405 Mdot
.752 .40426 Mdot
.752 .40437 Mdot
.752 .40453 Mdot
.752 .40474 Mdot
.752 .40502 Mdot
.752 .40519 Mdot
.752 .40523 Mdot
.752 .40559 Mdot
.752 .40653 Mdot
.752 .40691 Mdot
.752 .40765 Mdot
.752 .40773 Mdot
.752 .40793 Mdot
.752 .408 Mdot
.752 .40883 Mdot
.752 .40949 Mdot
.752 .40976 Mdot
.752 .40995 Mdot
.752 .40997 Mdot
.752 .41073 Mdot
.752 .41207 Mdot
.752 .41231 Mdot
.752 .41268 Mdot
.752 .41273 Mdot
.752 .41303 Mdot
.752 .41406 Mdot
.752 .41416 Mdot
.752 .41426 Mdot
.752 .41455 Mdot
.752 .41461 Mdot
.752 .41543 Mdot
.752 .41544 Mdot
.752 .41647 Mdot
.752 .41667 Mdot
.752 .4172 Mdot
.752 .41911 Mdot
.752 .4195 Mdot
.752 .41961 Mdot
.752 .41964 Mdot
.752 .41982 Mdot
.752 .41994 Mdot
.752 .42017 Mdot
.752 .42139 Mdot
.752 .4214 Mdot
.752 .4214 Mdot
.752 .42152 Mdot
.752 .42211 Mdot
.752 .42248 Mdot
.752 .42261 Mdot
.752 .42322 Mdot
.752 .42356 Mdot
.752 .42365 Mdot
.752 .4239 Mdot
.752 .42413 Mdot
.752 .42426 Mdot
.752 .42441 Mdot
.752 .42533 Mdot
.752 .42543 Mdot
.752 .42574 Mdot
.752 .42578 Mdot
.752 .42586 Mdot
.752 .42659 Mdot
.752 .42781 Mdot
.752 .42796 Mdot
.752 .42847 Mdot
.752 .42904 Mdot
.752 .42941 Mdot
.752 .43025 Mdot
.752 .43056 Mdot
.752 .43171 Mdot
.752 .43212 Mdot
.752 .43292 Mdot
.752 .43311 Mdot
.752 .43407 Mdot
.752 .43438 Mdot
.752 .43447 Mdot
.752 .4345 Mdot
.752 .43459 Mdot
.752 .43501 Mdot
.752 .43693 Mdot
.752 .43716 Mdot
.752 .43775 Mdot
.752 .43988 Mdot
.752 .44035 Mdot
.752 .44098 Mdot
.752 .44304 Mdot
.752 .44339 Mdot
.752 .44375 Mdot
.752 .4441 Mdot
.752 .44425 Mdot
.752 .44438 Mdot
.752 .44682 Mdot
.752 .44703 Mdot
.752 .44714 Mdot
.752 .44719 Mdot
.752 .44723 Mdot
.752 .44797 Mdot
.752 .4481 Mdot
.752 .44833 Mdot
.752 .4487 Mdot
.752 .44877 Mdot
.752 .44919 Mdot
.752 .44941 Mdot
.752 .45075 Mdot
.752 .45082 Mdot
.752 .4509 Mdot
.752 .45109 Mdot
.752 .45148 Mdot
.752 .4526 Mdot
.752 .45319 Mdot
.752 .45578 Mdot
.752 .456 Mdot
.752 .45606 Mdot
.752 .45627 Mdot
.752 .45688 Mdot
.752 .45751 Mdot
.752 .45811 Mdot
.752 .45889 Mdot
.752 .46059 Mdot
.752 .46127 Mdot
.752 .46134 Mdot
.752 .46165 Mdot
.752 .4617 Mdot
.752 .46225 Mdot
.752 .46243 Mdot
.752 .46273 Mdot
.752 .4628 Mdot
.752 .46341 Mdot
.752 .46352 Mdot
.752 .46358 Mdot
.752 .46369 Mdot
.752 .4671 Mdot
.752 .46807 Mdot
.752 .46844 Mdot
.752 .46855 Mdot
.752 .469 Mdot
.752 .46943 Mdot
.752 .46992 Mdot
.752 .47083 Mdot
.752 .4714 Mdot
.752 .47159 Mdot
.752 .47228 Mdot
.752 .47243 Mdot
.752 .47247 Mdot
.752 .47262 Mdot
.752 .4729 Mdot
.752 .47312 Mdot
.752 .47416 Mdot
.752 .47466 Mdot
.752 .47497 Mdot
.752 .47526 Mdot
.752 .47625 Mdot
.752 .4769 Mdot
.752 .47717 Mdot
.752 .47841 Mdot
.752 .47846 Mdot
.752 .47871 Mdot
.752 .47921 Mdot
.752 .48002 Mdot
.752 .48051 Mdot
.752 .48108 Mdot
.752 .48124 Mdot
.752 .48165 Mdot
.752 .48196 Mdot
.752 .48275 Mdot
.752 .4829 Mdot
.752 .48297 Mdot
.752 .48303 Mdot
.752 .48457 Mdot
.752 .48475 Mdot
.752 .48485 Mdot
.752 .48512 Mdot
.752 .48594 Mdot
.752 .48607 Mdot
.752 .48613 Mdot
.752 .4866 Mdot
.752 .48675 Mdot
.752 .48812 Mdot
.752 .48834 Mdot
.752 .48849 Mdot
.752 .48854 Mdot
.752 .48887 Mdot
.752 .48926 Mdot
.752 .48939 Mdot
.752 .48954 Mdot
.752 .48971 Mdot
.752 .48989 Mdot
.752 .49079 Mdot
.752 .49098 Mdot
.752 .49151 Mdot
.752 .49237 Mdot
.752 .49255 Mdot
.752 .49256 Mdot
.752 .49257 Mdot
.752 .493 Mdot
.752 .49433 Mdot
.752 .49455 Mdot
.752 .49465 Mdot
.752 .49483 Mdot
.752 .49508 Mdot
.752 .49513 Mdot
.752 .49529 Mdot
.752 .49532 Mdot
.752 .49562 Mdot
.752 .49584 Mdot
.752 .4959 Mdot
.752 .49711 Mdot
.752 .49831 Mdot
.752 .49853 Mdot
.752 .49927 Mdot
.752 .49956 Mdot
.752 .50086 Mdot
.752 .50097 Mdot
.752 .50099 Mdot
.752 .501 Mdot
.752 .50134 Mdot
.752 .50211 Mdot
.752 .50219 Mdot
.752 .5023 Mdot
.752 .50259 Mdot
.752 .50272 Mdot
.752 .50286 Mdot
.752 .5034 Mdot
.752 .50425 Mdot
.752 .50459 Mdot
.752 .50465 Mdot
.752 .50472 Mdot
.752 .50522 Mdot
.752 .50553 Mdot
.752 .50629 Mdot
.752 .50634 Mdot
.752 .50666 Mdot
.752 .50731 Mdot
.752 .50831 Mdot
.752 .50833 Mdot
.752 .50858 Mdot
.752 .50866 Mdot
.752 .50892 Mdot
.752 .50896 Mdot
.752 .50978 Mdot
.752 .51053 Mdot
.752 .51073 Mdot
.752 .51084 Mdot
.752 .51094 Mdot
.752 .51118 Mdot
.752 .51129 Mdot
.752 .51145 Mdot
.752 .51223 Mdot
.752 .51271 Mdot
.752 .51284 Mdot
.752 .51388 Mdot
.752 .51433 Mdot
.752 .51439 Mdot
.752 .5146 Mdot
.752 .51494 Mdot
.752 .5152 Mdot
.752 .51541 Mdot
.752 .51553 Mdot
.752 .51559 Mdot
.752 .51579 Mdot
.752 .51591 Mdot
.752 .51602 Mdot
.752 .51607 Mdot
.752 .51656 Mdot
.752 .51831 Mdot
.752 .51841 Mdot
.752 .5187 Mdot
.752 .5188 Mdot
.752 .51912 Mdot
.752 .51918 Mdot
.752 .51989 Mdot
.752 .51996 Mdot
.752 .52037 Mdot
.752 .52043 Mdot
.752 .52224 Mdot
.752 .52229 Mdot
.752 .52299 Mdot
.752 .52302 Mdot
.752 .52332 Mdot
.752 .52391 Mdot
.752 .52422 Mdot
.752 .52429 Mdot
.752 .52482 Mdot
.752 .52495 Mdot
.752 .52499 Mdot
.752 .52567 Mdot
.752 .52568 Mdot
.752 .5258 Mdot
.752 .52777 Mdot
.752 .52802 Mdot
.752 .52836 Mdot
.752 .52956 Mdot
.752 .53017 Mdot
.752 .53041 Mdot
.752 .53055 Mdot
.752 .53063 Mdot
.752 .5311 Mdot
.752 .5322 Mdot
.752 .53249 Mdot
.752 .53264 Mdot
.752 .53273 Mdot
.752 .53302 Mdot
.752 .53312 Mdot
.752 .53314 Mdot
.752 .53369 Mdot
.752 .53479 Mdot
.752 .53479 Mdot
.752 .53575 Mdot
.752 .53621 Mdot
.752 .53654 Mdot
.752 .53658 Mdot
.752 .53676 Mdot
.752 .53763 Mdot
.752 .53885 Mdot
.752 .53919 Mdot
.752 .53952 Mdot
.752 .54006 Mdot
.752 .54019 Mdot
.752 .54022 Mdot
.752 .54027 Mdot
.752 .54036 Mdot
.752 .54071 Mdot
.752 .54234 Mdot
.752 .54238 Mdot
.752 .54259 Mdot
.752 .54263 Mdot
.752 .54278 Mdot
.752 .54289 Mdot
.752 .54307 Mdot
.752 .54316 Mdot
.752 .54402 Mdot
.752 .54521 Mdot
.752 .54593 Mdot
.752 .54629 Mdot
.752 .54647 Mdot
.752 .54652 Mdot
.752 .54692 Mdot
.752 .547 Mdot
.752 .54749 Mdot
.752 .54757 Mdot
.752 .54758 Mdot
.752 .548 Mdot
.752 .54828 Mdot
.752 .54855 Mdot
.752 .54877 Mdot
.752 .54885 Mdot
.752 .54889 Mdot
.752 .54948 Mdot
.752 .54975 Mdot
.752 .55003 Mdot
.752 .55009 Mdot
.752 .55016 Mdot
.752 .55033 Mdot
.752 .55068 Mdot
.752 .5514 Mdot
.752 .55143 Mdot
.752 .55166 Mdot
.752 .55237 Mdot
.752 .55245 Mdot
.752 .55249 Mdot
.752 .55281 Mdot
.752 .55284 Mdot
.752 .55309 Mdot
.752 .55318 Mdot
.752 .55343 Mdot
.752 .55374 Mdot
.752 .55375 Mdot
.752 .554 Mdot
.752 .55438 Mdot
.752 .5546 Mdot
.752 .55484 Mdot
.752 .55513 Mdot
.752 .55524 Mdot
.752 .55542 Mdot
.752 .55551 Mdot
.752 .55559 Mdot
.752 .55568 Mdot
.752 .55659 Mdot
.752 .55661 Mdot
.752 .55664 Mdot
.752 .55676 Mdot
.752 .55682 Mdot
.752 .55686 Mdot
.752 .55696 Mdot
.752 .55702 Mdot
.752 .55704 Mdot
.752 .55716 Mdot
.752 .55747 Mdot
.752 .55798 Mdot
.752 .55848 Mdot
.752 .55859 Mdot
.752 .55926 Mdot
.752 .55933 Mdot
.752 .55952 Mdot
.752 .55953 Mdot
.752 .55955 Mdot
.752 .56017 Mdot
.752 .56067 Mdot
.752 .5611 Mdot
.752 .5612 Mdot
.752 .56123 Mdot
.752 .56163 Mdot
.752 .56165 Mdot
.752 .56185 Mdot
.752 .56201 Mdot
.752 .56231 Mdot
.752 .56244 Mdot
.752 .56259 Mdot
.752 .56267 Mdot
.752 .56269 Mdot
.752 .56288 Mdot
.752 .563 Mdot
.752 .56301 Mdot
.752 .56306 Mdot
.752 .56308 Mdot
.752 .56327 Mdot
.752 .5633 Mdot
.752 .56341 Mdot
.752 .5635 Mdot
.752 .56368 Mdot
.752 .56369 Mdot
.752 .56395 Mdot
.752 .56398 Mdot
.752 .56403 Mdot
.752 .56432 Mdot
.752 .5644 Mdot
.752 .56443 Mdot
.752 .56459 Mdot
.752 .56459 Mdot
.752 .56471 Mdot
.752 .56472 Mdot
.752 .56476 Mdot
.752 .56478 Mdot
.752 .56479 Mdot
.752 .56495 Mdot
.752 .565 Mdot
.752 .56505 Mdot
.752 .56509 Mdot
.752 .5654 Mdot
.752 .56547 Mdot
.752 .56568 Mdot
.752 .56572 Mdot
.752 .56574 Mdot
.752 .5659 Mdot
.752 .56603 Mdot
.752 .56609 Mdot
.752 .56609 Mdot
.752 .56616 Mdot
.752 .56619 Mdot
.752 .56621 Mdot
.752 .56622 Mdot
.752 .56626 Mdot
.752 .56627 Mdot
.752 .56628 Mdot
.752 .56656 Mdot
.752 .56665 Mdot
.752 .5668 Mdot
.752 .56702 Mdot
.752 .56703 Mdot
.752 .56771 Mdot
.752 .56779 Mdot
.752 .56805 Mdot
.752 .56807 Mdot
.752 .56808 Mdot
.752 .56882 Mdot
.752 .56886 Mdot
.752 .56928 Mdot
.752 .56937 Mdot
.752 .56938 Mdot
.752 .5694 Mdot
.752 .56969 Mdot
.752 .57031 Mdot
.752 .57037 Mdot
.752 .57046 Mdot
.752 .57054 Mdot
.752 .57059 Mdot
.752 .57068 Mdot
.752 .57078 Mdot
.752 .57088 Mdot
.752 .57092 Mdot
.752 .57097 Mdot
.752 .57126 Mdot
.752 .5715 Mdot
.752 .57154 Mdot
.752 .57176 Mdot
.752 .57181 Mdot
.752 .57182 Mdot
.752 .57201 Mdot
.752 .57202 Mdot
.752 .57205 Mdot
.752 .57208 Mdot
.752 .57209 Mdot
.752 .57237 Mdot
.752 .57254 Mdot
.752 .5729 Mdot
.752 .57292 Mdot
.752 .57302 Mdot
.752 .57306 Mdot
.752 .57323 Mdot
.752 .57325 Mdot
.752 .57329 Mdot
.752 .57332 Mdot
.752 .57334 Mdot
.752 .57341 Mdot
.752 .57343 Mdot
.752 .57348 Mdot
.752 .57355 Mdot
.752 .57363 Mdot
.752 .57365 Mdot
.752 .57365 Mdot
.752 .57369 Mdot
.752 .57372 Mdot
.752 .57372 Mdot
.752 .57374 Mdot
.752 .57378 Mdot
.752 .57379 Mdot
.752 .57381 Mdot
.752 .57382 Mdot
.752 .57389 Mdot
.752 .57398 Mdot
.752 .57406 Mdot
.752 .57407 Mdot
.752 .57407 Mdot
.752 .57409 Mdot
.752 .5741 Mdot
.752 .5741 Mdot
.752 .57411 Mdot
.752 .57412 Mdot
.752 .57412 Mdot
.752 .57412 Mdot
.754 .11943 Mdot
.754 .11944 Mdot
.754 .11952 Mdot
.754 .11962 Mdot
.754 .11964 Mdot
.754 .11967 Mdot
.754 .11992 Mdot
.754 .1203 Mdot
.754 .1209 Mdot
.754 .12096 Mdot
.754 .12116 Mdot
.754 .12119 Mdot
.754 .1212 Mdot
.754 .12138 Mdot
.754 .12144 Mdot
.754 .12161 Mdot
.754 .12168 Mdot
.754 .12188 Mdot
.754 .12195 Mdot
.754 .12197 Mdot
.754 .12215 Mdot
.754 .12221 Mdot
.754 .12222 Mdot
.754 .12225 Mdot
.754 .12287 Mdot
.754 .12288 Mdot
.754 .12371 Mdot
.754 .12377 Mdot
.754 .12391 Mdot
.754 .12453 Mdot
.754 .12507 Mdot
.754 .12524 Mdot
.754 .12571 Mdot
.754 .1259 Mdot
.754 .12618 Mdot
.754 .12618 Mdot
.754 .12639 Mdot
.754 .12644 Mdot
.754 .12747 Mdot
.754 .12786 Mdot
.754 .12802 Mdot
.754 .12931 Mdot
.754 .12939 Mdot
.754 .12964 Mdot
.754 .12981 Mdot
.754 .13005 Mdot
.754 .13033 Mdot
.754 .13106 Mdot
.754 .1312 Mdot
.754 .13235 Mdot
.754 .13243 Mdot
.754 .13373 Mdot
.754 .13404 Mdot
.754 .13548 Mdot
.754 .13568 Mdot
.754 .13589 Mdot
.754 .13623 Mdot
.754 .1368 Mdot
.754 .13686 Mdot
.754 .13714 Mdot
.754 .13744 Mdot
.754 .13769 Mdot
.754 .13787 Mdot
.754 .13832 Mdot
.754 .13886 Mdot
.754 .13991 Mdot
.754 .141 Mdot
.754 .14124 Mdot
.754 .14139 Mdot
.754 .14224 Mdot
.754 .14263 Mdot
.754 .1434 Mdot
.754 .14341 Mdot
.754 .14372 Mdot
.754 .14406 Mdot
.754 .14411 Mdot
.754 .14416 Mdot
.754 .1442 Mdot
.754 .14424 Mdot
.754 .14435 Mdot
.754 .14437 Mdot
.754 .1444 Mdot
.754 .14514 Mdot
.754 .14652 Mdot
.754 .14695 Mdot
.754 .14876 Mdot
.754 .14901 Mdot
.754 .1496 Mdot
.754 .14978 Mdot
.754 .14987 Mdot
.754 .14994 Mdot
.754 .14996 Mdot
.754 .15013 Mdot
.754 .15063 Mdot
.754 .15085 Mdot
.754 .15154 Mdot
.754 .15182 Mdot
.754 .15205 Mdot
.754 .15239 Mdot
.754 .15249 Mdot
.754 .15262 Mdot
.754 .15274 Mdot
.754 .15286 Mdot
.754 .15288 Mdot
.754 .15299 Mdot
.754 .15319 Mdot
.754 .1537 Mdot
.754 .15395 Mdot
.754 .15402 Mdot
.754 .15414 Mdot
.754 .15457 Mdot
.754 .15603 Mdot
.754 .15671 Mdot
.754 .15673 Mdot
.754 .15705 Mdot
.754 .15709 Mdot
.754 .15831 Mdot
.754 .15863 Mdot
.754 .1593 Mdot
.754 .15977 Mdot
.754 .16032 Mdot
.754 .1606 Mdot
.754 .16124 Mdot
.754 .16192 Mdot
.754 .16401 Mdot
.754 .16554 Mdot
.754 .16652 Mdot
.754 .16679 Mdot
.754 .16729 Mdot
.754 .16745 Mdot
.754 .16767 Mdot
.754 .16951 Mdot
.754 .16977 Mdot
.754 .1698 Mdot
.754 .16993 Mdot
.754 .17045 Mdot
.754 .1707 Mdot
.754 .17105 Mdot
.754 .17134 Mdot
.754 .17177 Mdot
.754 .1718 Mdot
.754 .17281 Mdot
.754 .17295 Mdot
.754 .17305 Mdot
.754 .17351 Mdot
.754 .17567 Mdot
.754 .17819 Mdot
.754 .17867 Mdot
.754 .18003 Mdot
.754 .1802 Mdot
.754 .18102 Mdot
.754 .18172 Mdot
.754 .18476 Mdot
.754 .18773 Mdot
.754 .18783 Mdot
.754 .18828 Mdot
.754 .18894 Mdot
.754 .18961 Mdot
.754 .19046 Mdot
.754 .19052 Mdot
.754 .19087 Mdot
.754 .19088 Mdot
.754 .19182 Mdot
.754 .19212 Mdot
.754 .19249 Mdot
.754 .19336 Mdot
.754 .19351 Mdot
.754 .19608 Mdot
.754 .19617 Mdot
.754 .19664 Mdot
.754 .19747 Mdot
.754 .19825 Mdot
.754 .19944 Mdot
.754 .20089 Mdot
.754 .20264 Mdot
.754 .20423 Mdot
.754 .20484 Mdot
.754 .20523 Mdot
.754 .20532 Mdot
.754 .20569 Mdot
.754 .20785 Mdot
.754 .20953 Mdot
.754 .21044 Mdot
.754 .21296 Mdot
.754 .21369 Mdot
.754 .21373 Mdot
.754 .21386 Mdot
.754 .21475 Mdot
.754 .21482 Mdot
.754 .2157 Mdot
.754 .21698 Mdot
.754 .21712 Mdot
.754 .21755 Mdot
.754 .21792 Mdot
.754 .22246 Mdot
.754 .22259 Mdot
.754 .22261 Mdot
.754 .22362 Mdot
.754 .22379 Mdot
.754 .22487 Mdot
.754 .22557 Mdot
.754 .22559 Mdot
.754 .22577 Mdot
.754 .22616 Mdot
.754 .22828 Mdot
.754 .2291 Mdot
.754 .23012 Mdot
.754 .23126 Mdot
.754 .23183 Mdot
.754 .23207 Mdot
.754 .23225 Mdot
.754 .23402 Mdot
.754 .23551 Mdot
.754 .23592 Mdot
.754 .23628 Mdot
.754 .23747 Mdot
.754 .23862 Mdot
.754 .23863 Mdot
.754 .24064 Mdot
.754 .24117 Mdot
.754 .24153 Mdot
.754 .24186 Mdot
.754 .24316 Mdot
.754 .24351 Mdot
.754 .24416 Mdot
.754 .245 Mdot
.754 .24558 Mdot
.754 .24691 Mdot
.754 .24882 Mdot
.754 .24992 Mdot
.754 .25186 Mdot
.754 .25238 Mdot
.754 .25642 Mdot
.754 .25781 Mdot
.754 .25884 Mdot
.754 .2591 Mdot
.754 .26003 Mdot
.754 .26058 Mdot
.754 .26064 Mdot
.754 .26066 Mdot
.754 .26171 Mdot
.754 .26215 Mdot
.754 .26279 Mdot
.754 .26612 Mdot
.754 .26648 Mdot
.754 .26666 Mdot
.754 .26735 Mdot
.754 .26981 Mdot
.754 .26988 Mdot
.754 .27003 Mdot
.754 .27029 Mdot
.754 .27158 Mdot
.754 .27521 Mdot
.754 .27523 Mdot
.754 .27525 Mdot
.754 .27538 Mdot
.754 .27734 Mdot
.754 .27967 Mdot
.754 .28002 Mdot
.754 .28036 Mdot
.754 .2806 Mdot
.754 .28089 Mdot
.754 .28135 Mdot
.754 .28164 Mdot
.754 .28181 Mdot
.754 .28198 Mdot
.754 .28471 Mdot
.754 .2859 Mdot
.754 .28707 Mdot
.754 .28731 Mdot
.754 .28775 Mdot
.754 .28947 Mdot
.754 .29189 Mdot
.754 .29478 Mdot
.754 .29501 Mdot
.754 .29655 Mdot
.754 .29778 Mdot
.754 .29794 Mdot
.754 .29836 Mdot
.754 .2985 Mdot
.754 .2995 Mdot
.754 .29963 Mdot
.754 .30007 Mdot
.754 .30088 Mdot
.754 .30611 Mdot
.754 .30926 Mdot
.754 .30937 Mdot
.754 .31104 Mdot
.754 .31204 Mdot
.754 .31229 Mdot
.754 .31372 Mdot
.754 .31528 Mdot
.754 .31733 Mdot
.754 .31786 Mdot
.754 .31792 Mdot
.754 .31893 Mdot
.754 .3191 Mdot
.754 .31973 Mdot
.754 .32022 Mdot
.754 .32031 Mdot
.754 .32149 Mdot
.754 .32292 Mdot
.754 .32421 Mdot
.754 .325 Mdot
.754 .32523 Mdot
.754 .32588 Mdot
.754 .3265 Mdot
.754 .3265 Mdot
.754 .32677 Mdot
.754 .32683 Mdot
.754 .3281 Mdot
.754 .32875 Mdot
.754 .33019 Mdot
.754 .33054 Mdot
.754 .33126 Mdot
.754 .332 Mdot
.754 .33325 Mdot
.754 .33452 Mdot
.754 .3348 Mdot
.754 .33561 Mdot
.754 .3372 Mdot
.754 .33787 Mdot
.754 .33879 Mdot
.754 .33959 Mdot
.754 .34041 Mdot
.754 .34058 Mdot
.754 .3413 Mdot
.754 .34159 Mdot
.754 .34213 Mdot
.754 .34213 Mdot
.754 .34235 Mdot
.754 .34259 Mdot
.754 .34262 Mdot
.754 .34268 Mdot
.754 .34271 Mdot
.754 .34333 Mdot
.754 .34425 Mdot
.754 .34453 Mdot
.754 .3457 Mdot
.754 .34586 Mdot
.754 .34623 Mdot
.754 .34635 Mdot
.754 .3464 Mdot
.754 .34645 Mdot
.754 .34656 Mdot
.754 .34687 Mdot
.754 .34701 Mdot
.754 .34743 Mdot
.754 .3476 Mdot
.754 .34795 Mdot
.754 .34809 Mdot
.754 .34824 Mdot
.754 .3483 Mdot
.754 .34842 Mdot
.754 .34873 Mdot
.754 .34887 Mdot
.754 .34892 Mdot
.754 .34898 Mdot
.754 .34924 Mdot
.754 .35008 Mdot
.754 .35047 Mdot
.754 .35048 Mdot
.754 .35066 Mdot
.754 .35218 Mdot
.754 .35248 Mdot
.754 .35263 Mdot
.754 .35297 Mdot
.754 .35334 Mdot
.754 .35445 Mdot
.754 .35574 Mdot
.754 .35613 Mdot
.754 .35622 Mdot
.754 .35725 Mdot
.754 .35771 Mdot
.754 .35783 Mdot
.754 .35815 Mdot
.754 .35835 Mdot
.754 .35837 Mdot
.754 .35886 Mdot
.754 .35897 Mdot
.754 .3614 Mdot
.754 .36224 Mdot
.754 .36232 Mdot
.754 .36269 Mdot
.754 .363 Mdot
.754 .36436 Mdot
.754 .3657 Mdot
.754 .36589 Mdot
.754 .36646 Mdot
.754 .36682 Mdot
.754 .36685 Mdot
.754 .367 Mdot
.754 .367 Mdot
.754 .3674 Mdot
.754 .36753 Mdot
.754 .36768 Mdot
.754 .36805 Mdot
.754 .36917 Mdot
.754 .3694 Mdot
.754 .36974 Mdot
.754 .37006 Mdot
.754 .37054 Mdot
.754 .37183 Mdot
.754 .3727 Mdot
.754 .37285 Mdot
.754 .37288 Mdot
.754 .37583 Mdot
.754 .3761 Mdot
.754 .37612 Mdot
.754 .37653 Mdot
.754 .37734 Mdot
.754 .37755 Mdot
.754 .37769 Mdot
.754 .37936 Mdot
.754 .37978 Mdot
.754 .37985 Mdot
.754 .38023 Mdot
.754 .38049 Mdot
.754 .38049 Mdot
.754 .3807 Mdot
.754 .38146 Mdot
.754 .38272 Mdot
.754 .3828 Mdot
.754 .38287 Mdot
.754 .38349 Mdot
.754 .38415 Mdot
.754 .38428 Mdot
.754 .38469 Mdot
.754 .38509 Mdot
.754 .38509 Mdot
.754 .38609 Mdot
.754 .38665 Mdot
.754 .38699 Mdot
.754 .38727 Mdot
.754 .38747 Mdot
.754 .38856 Mdot
.754 .38958 Mdot
.754 .39108 Mdot
.754 .39154 Mdot
.754 .39196 Mdot
.754 .39247 Mdot
.754 .39281 Mdot
.754 .39296 Mdot
.754 .39436 Mdot
.754 .39463 Mdot
.754 .39549 Mdot
.754 .39599 Mdot
.754 .39714 Mdot
.754 .39714 Mdot
.754 .39715 Mdot
.754 .39719 Mdot
.754 .39781 Mdot
.754 .39854 Mdot
.754 .39865 Mdot
.754 .39876 Mdot
.754 .39883 Mdot
.754 .39892 Mdot
.754 .39915 Mdot
.754 .39921 Mdot
.754 .39926 Mdot
.754 .40084 Mdot
.754 .40158 Mdot
.754 .40375 Mdot
.754 .40413 Mdot
.754 .40465 Mdot
.754 .40469 Mdot
.754 .40482 Mdot
.754 .40665 Mdot
.754 .40763 Mdot
.754 .40813 Mdot
.754 .40843 Mdot
.754 .40893 Mdot
.754 .40939 Mdot
.754 .41 Mdot
.754 .41016 Mdot
.754 .41048 Mdot
.754 .41053 Mdot
.754 .41072 Mdot
.754 .41086 Mdot
.754 .41089 Mdot
.754 .41124 Mdot
.754 .41166 Mdot
.754 .41204 Mdot
.754 .41227 Mdot
.754 .41253 Mdot
.754 .41272 Mdot
.754 .41282 Mdot
.754 .41338 Mdot
.754 .41391 Mdot
.754 .41412 Mdot
.754 .41434 Mdot
.754 .4147 Mdot
.754 .41507 Mdot
.754 .41516 Mdot
.754 .41586 Mdot
.754 .41605 Mdot
.754 .41632 Mdot
.754 .41656 Mdot
.754 .4168 Mdot
.754 .41685 Mdot
.754 .41706 Mdot
.754 .41746 Mdot
.754 .418 Mdot
.754 .4185 Mdot
.754 .41899 Mdot
.754 .41913 Mdot
.754 .41937 Mdot
.754 .41962 Mdot
.754 .42022 Mdot
.754 .42314 Mdot
.754 .42336 Mdot
.754 .42376 Mdot
.754 .42447 Mdot
.754 .42452 Mdot
.754 .42472 Mdot
.754 .42515 Mdot
.754 .42521 Mdot
.754 .42761 Mdot
.754 .4281 Mdot
.754 .42824 Mdot
.754 .42842 Mdot
.754 .42952 Mdot
.754 .43044 Mdot
.754 .43076 Mdot
.754 .43149 Mdot
.754 .43163 Mdot
.754 .43204 Mdot
.754 .43244 Mdot
.754 .43292 Mdot
.754 .43325 Mdot
.754 .43455 Mdot
.754 .43529 Mdot
.754 .43546 Mdot
.754 .43549 Mdot
.754 .43603 Mdot
.754 .43646 Mdot
.754 .43683 Mdot
.754 .43715 Mdot
.754 .4375 Mdot
.754 .43761 Mdot
.754 .43775 Mdot
.754 .43816 Mdot
.754 .43828 Mdot
.754 .4385 Mdot
.754 .44095 Mdot
.754 .44107 Mdot
.754 .44135 Mdot
.754 .44246 Mdot
.754 .44316 Mdot
.754 .44342 Mdot
.754 .44366 Mdot
.754 .4438 Mdot
.754 .44457 Mdot
.754 .44458 Mdot
.754 .44474 Mdot
.754 .44487 Mdot
.754 .44518 Mdot
.754 .44526 Mdot
.754 .44538 Mdot
.754 .44542 Mdot
.754 .4471 Mdot
.754 .44738 Mdot
.754 .44752 Mdot
.754 .44759 Mdot
.754 .44819 Mdot
.754 .44844 Mdot
.754 .44861 Mdot
.754 .44875 Mdot
.754 .44908 Mdot
.754 .44913 Mdot
.754 .4492 Mdot
.754 .44936 Mdot
.754 .45028 Mdot
.754 .4503 Mdot
.754 .45041 Mdot
.754 .45065 Mdot
.754 .45074 Mdot
.754 .45116 Mdot
.754 .45137 Mdot
.754 .45189 Mdot
.754 .45264 Mdot
.754 .45271 Mdot
.754 .45414 Mdot
.754 .4542 Mdot
.754 .45442 Mdot
.754 .4545 Mdot
.754 .45456 Mdot
.754 .45474 Mdot
.754 .45491 Mdot
.754 .45511 Mdot
.754 .45533 Mdot
.754 .45562 Mdot
.754 .45564 Mdot
.754 .45572 Mdot
.754 .45697 Mdot
.754 .45722 Mdot
.754 .45764 Mdot
.754 .45809 Mdot
.754 .4593 Mdot
.754 .45947 Mdot
.754 .4612 Mdot
.754 .46169 Mdot
.754 .46189 Mdot
.754 .46377 Mdot
.754 .46458 Mdot
.754 .46603 Mdot
.754 .46639 Mdot
.754 .4666 Mdot
.754 .46686 Mdot
.754 .46713 Mdot
.754 .46727 Mdot
.754 .46751 Mdot
.754 .4677 Mdot
.754 .46827 Mdot
.754 .46851 Mdot
.754 .4688 Mdot
.754 .46941 Mdot
.754 .46965 Mdot
.754 .47013 Mdot
.754 .471 Mdot
.754 .47106 Mdot
.754 .47133 Mdot
.754 .47254 Mdot
.754 .47461 Mdot
.754 .47463 Mdot
.754 .47517 Mdot
.754 .47593 Mdot
.754 .47657 Mdot
.754 .47722 Mdot
.754 .47744 Mdot
.754 .47859 Mdot
.754 .47909 Mdot
.754 .47931 Mdot
.754 .47946 Mdot
.754 .48017 Mdot
.754 .48053 Mdot
.754 .4812 Mdot
.754 .48223 Mdot
.754 .48224 Mdot
.754 .48252 Mdot
.754 .48274 Mdot
.754 .48348 Mdot
.754 .48354 Mdot
.754 .48364 Mdot
.754 .48418 Mdot
.754 .48418 Mdot
.754 .48561 Mdot
.754 .48606 Mdot
.754 .48662 Mdot
.754 .48712 Mdot
.754 .48722 Mdot
.754 .48787 Mdot
.754 .48793 Mdot
.754 .48816 Mdot
.754 .48816 Mdot
.754 .48824 Mdot
.754 .4893 Mdot
.754 .48988 Mdot
.754 .4902 Mdot
.754 .49194 Mdot
.754 .49208 Mdot
.754 .49276 Mdot
.754 .49397 Mdot
.754 .49445 Mdot
.754 .49508 Mdot
.754 .49532 Mdot
.754 .49568 Mdot
.754 .49601 Mdot
.754 .49621 Mdot
.754 .49678 Mdot
.754 .49692 Mdot
.754 .49762 Mdot
.754 .49837 Mdot
.754 .49882 Mdot
.754 .49894 Mdot
.754 .49923 Mdot
.754 .4993 Mdot
.754 .49963 Mdot
.754 .49996 Mdot
.754 .50033 Mdot
.754 .5006 Mdot
.754 .50124 Mdot
.754 .50157 Mdot
.754 .50168 Mdot
.754 .50219 Mdot
.754 .50269 Mdot
.754 .50299 Mdot
.754 .50327 Mdot
.754 .50341 Mdot
.754 .50398 Mdot
.754 .50424 Mdot
.754 .50474 Mdot
.754 .50477 Mdot
.754 .50487 Mdot
.754 .50488 Mdot
.754 .50512 Mdot
.754 .50538 Mdot
.754 .50547 Mdot
.754 .50578 Mdot
.754 .50628 Mdot
.754 .50684 Mdot
.754 .50731 Mdot
.754 .50734 Mdot
.754 .50753 Mdot
.754 .50778 Mdot
.754 .50784 Mdot
.754 .50824 Mdot
.754 .50826 Mdot
.754 .50847 Mdot
.754 .50926 Mdot
.754 .50986 Mdot
.754 .51041 Mdot
.754 .51051 Mdot
.754 .51089 Mdot
.754 .51153 Mdot
.754 .51157 Mdot
.754 .51277 Mdot
.754 .51475 Mdot
.754 .51505 Mdot
.754 .51522 Mdot
.754 .51527 Mdot
.754 .51564 Mdot
.754 .51569 Mdot
.754 .51585 Mdot
.754 .51591 Mdot
.754 .51637 Mdot
.754 .51694 Mdot
.754 .51703 Mdot
.754 .5181 Mdot
.754 .519 Mdot
.754 .51963 Mdot
.754 .51979 Mdot
.754 .51988 Mdot
.754 .52031 Mdot
.754 .52074 Mdot
.754 .52174 Mdot
.754 .5218 Mdot
.754 .52186 Mdot
.754 .52197 Mdot
.754 .52214 Mdot
.754 .52224 Mdot
.754 .52233 Mdot
.754 .52245 Mdot
.754 .52258 Mdot
.754 .52342 Mdot
.754 .52413 Mdot
.754 .52417 Mdot
.754 .52418 Mdot
.754 .52419 Mdot
.754 .52549 Mdot
.754 .52595 Mdot
.754 .52604 Mdot
.754 .5261 Mdot
.754 .52612 Mdot
.754 .527 Mdot
.754 .52724 Mdot
.754 .5273 Mdot
.754 .52743 Mdot
.754 .52861 Mdot
.754 .52883 Mdot
.754 .52899 Mdot
.754 .52936 Mdot
.754 .52936 Mdot
.754 .52939 Mdot
.754 .52958 Mdot
.754 .5299 Mdot
.754 .53 Mdot
.754 .53036 Mdot
.754 .53084 Mdot
.754 .53225 Mdot
.754 .53243 Mdot
.754 .5331 Mdot
.754 .53348 Mdot
.754 .53414 Mdot
.754 .53459 Mdot
.754 .53479 Mdot
.754 .53508 Mdot
.754 .5353 Mdot
.754 .53542 Mdot
.754 .53586 Mdot
.754 .53598 Mdot
.754 .5361 Mdot
.754 .53628 Mdot
.754 .53696 Mdot
.754 .53697 Mdot
.754 .53735 Mdot
.754 .53776 Mdot
.754 .53788 Mdot
.754 .53802 Mdot
.754 .53852 Mdot
.754 .53912 Mdot
.754 .53918 Mdot
.754 .53926 Mdot
.754 .53945 Mdot
.754 .53984 Mdot
.754 .54017 Mdot
.754 .54045 Mdot
.754 .54116 Mdot
.754 .54129 Mdot
.754 .54135 Mdot
.754 .54136 Mdot
.754 .54159 Mdot
.754 .54194 Mdot
.754 .542 Mdot
.754 .54234 Mdot
.754 .54234 Mdot
.754 .54239 Mdot
.754 .54389 Mdot
.754 .54401 Mdot
.754 .54415 Mdot
.754 .5442 Mdot
.754 .54462 Mdot
.754 .54491 Mdot
.754 .54493 Mdot
.754 .54522 Mdot
.754 .54526 Mdot
.754 .54528 Mdot
.754 .54552 Mdot
.754 .54634 Mdot
.754 .54664 Mdot
.754 .54718 Mdot
.754 .54788 Mdot
.754 .548 Mdot
.754 .54803 Mdot
.754 .54816 Mdot
.754 .54836 Mdot
.754 .54887 Mdot
.754 .54943 Mdot
.754 .5499 Mdot
.754 .55028 Mdot
.754 .55053 Mdot
.754 .5508 Mdot
.754 .55095 Mdot
.754 .55098 Mdot
.754 .5518 Mdot
.754 .55184 Mdot
.754 .55212 Mdot
.754 .55224 Mdot
.754 .55234 Mdot
.754 .55263 Mdot
.754 .55264 Mdot
.754 .55275 Mdot
.754 .55277 Mdot
.754 .55304 Mdot
.754 .55325 Mdot
.754 .55346 Mdot
.754 .5536 Mdot
.754 .55363 Mdot
.754 .55457 Mdot
.754 .55553 Mdot
.754 .55575 Mdot
.754 .556 Mdot
.754 .55606 Mdot
.754 .55648 Mdot
.754 .55663 Mdot
.754 .55742 Mdot
.754 .55809 Mdot
.754 .55823 Mdot
.754 .55826 Mdot
.754 .55831 Mdot
.754 .55862 Mdot
.754 .55863 Mdot
.754 .55876 Mdot
.754 .55885 Mdot
.754 .55896 Mdot
.754 .55904 Mdot
.754 .5592 Mdot
.754 .55924 Mdot
.754 .55925 Mdot
.754 .55933 Mdot
.754 .5599 Mdot
.754 .55997 Mdot
.754 .56002 Mdot
.754 .56017 Mdot
.754 .56025 Mdot
.754 .56055 Mdot
.754 .56102 Mdot
.754 .56167 Mdot
.754 .56187 Mdot
.754 .56207 Mdot
.754 .56216 Mdot
.754 .56232 Mdot
.754 .56247 Mdot
.754 .56267 Mdot
.754 .56277 Mdot
.754 .56314 Mdot
.754 .56315 Mdot
.754 .56325 Mdot
.754 .56326 Mdot
.754 .56346 Mdot
.754 .56391 Mdot
.754 .56404 Mdot
.754 .56407 Mdot
.754 .56409 Mdot
.754 .56417 Mdot
.754 .56433 Mdot
.754 .56439 Mdot
.754 .56442 Mdot
.754 .56443 Mdot
.754 .56446 Mdot
.754 .5645 Mdot
.754 .56454 Mdot
.754 .56457 Mdot
.754 .56467 Mdot
.754 .56474 Mdot
.754 .56483 Mdot
.754 .56503 Mdot
.754 .5651 Mdot
.754 .56525 Mdot
.754 .5653 Mdot
.754 .56531 Mdot
.754 .56533 Mdot
.754 .56536 Mdot
.754 .56541 Mdot
.754 .56559 Mdot
.754 .56566 Mdot
.754 .56621 Mdot
.754 .56634 Mdot
.754 .56675 Mdot
.754 .56698 Mdot
.754 .56698 Mdot
.754 .56699 Mdot
.754 .56702 Mdot
.754 .56704 Mdot
.754 .56705 Mdot
.754 .56706 Mdot
.754 .56708 Mdot
.754 .56718 Mdot
.754 .56727 Mdot
.754 .56728 Mdot
.754 .5675 Mdot
.754 .56762 Mdot
.754 .56788 Mdot
.754 .56792 Mdot
.754 .56799 Mdot
.754 .56832 Mdot
.754 .56863 Mdot
.754 .56879 Mdot
.754 .56893 Mdot
.754 .56898 Mdot
.754 .56905 Mdot
.754 .56914 Mdot
.754 .56923 Mdot
.754 .56925 Mdot
.754 .56941 Mdot
.754 .56952 Mdot
.754 .56958 Mdot
.754 .56964 Mdot
.754 .57007 Mdot
.754 .57016 Mdot
.754 .57054 Mdot
.754 .57057 Mdot
.754 .57091 Mdot
.754 .57095 Mdot
.754 .57116 Mdot
.754 .57125 Mdot
.754 .57132 Mdot
.754 .57137 Mdot
.754 .57144 Mdot
.754 .57146 Mdot
.754 .57184 Mdot
.754 .57189 Mdot
.754 .57201 Mdot
.754 .57231 Mdot
.754 .57232 Mdot
.754 .57238 Mdot
.754 .57239 Mdot
.754 .57247 Mdot
.754 .57252 Mdot
.754 .57266 Mdot
.754 .57271 Mdot
.754 .57287 Mdot
.754 .57305 Mdot
.754 .57309 Mdot
.754 .57311 Mdot
.754 .57335 Mdot
.754 .57336 Mdot
.754 .57354 Mdot
.754 .57354 Mdot
.754 .57355 Mdot
.754 .57357 Mdot
.754 .57362 Mdot
.754 .57363 Mdot
.754 .57364 Mdot
.754 .5737 Mdot
.754 .57372 Mdot
.754 .57378 Mdot
.754 .57379 Mdot
.754 .57384 Mdot
.754 .57385 Mdot
.754 .57385 Mdot
.754 .57391 Mdot
.754 .57393 Mdot
.754 .57411 Mdot
.754 .57422 Mdot
.754 .57429 Mdot
.754 .5743 Mdot
.754 .57431 Mdot
.754 .57433 Mdot
.754 .57436 Mdot
.754 .57436 Mdot
.756 .11867 Mdot
.756 .11867 Mdot
.756 .1187 Mdot
.756 .11881 Mdot
.756 .11882 Mdot
.756 .11903 Mdot
.756 .11925 Mdot
.756 .11926 Mdot
.756 .11941 Mdot
.756 .11957 Mdot
.756 .11963 Mdot
.756 .11965 Mdot
.756 .11991 Mdot
.756 .12007 Mdot
.756 .12027 Mdot
.756 .12059 Mdot
.756 .12066 Mdot
.756 .1212 Mdot
.756 .12159 Mdot
.756 .12159 Mdot
.756 .12176 Mdot
.756 .12181 Mdot
.756 .12184 Mdot
.756 .12244 Mdot
.756 .12321 Mdot
.756 .12393 Mdot
.756 .12488 Mdot
.756 .12528 Mdot
.756 .12566 Mdot
.756 .1263 Mdot
.756 .12631 Mdot
.756 .12635 Mdot
.756 .12668 Mdot
.756 .12702 Mdot
.756 .12715 Mdot
.756 .12762 Mdot
.756 .12829 Mdot
.756 .1291 Mdot
.756 .13025 Mdot
.756 .13071 Mdot
.756 .13071 Mdot
.756 .13132 Mdot
.756 .13153 Mdot
.756 .13209 Mdot
.756 .13215 Mdot
.756 .13244 Mdot
.756 .13307 Mdot
.756 .13331 Mdot
.756 .13497 Mdot
.756 .13622 Mdot
.756 .1368 Mdot
.756 .13695 Mdot
.756 .13734 Mdot
.756 .13748 Mdot
.756 .138 Mdot
.756 .14003 Mdot
.756 .14008 Mdot
.756 .14025 Mdot
.756 .14026 Mdot
.756 .14037 Mdot
.756 .14072 Mdot
.756 .14075 Mdot
.756 .14128 Mdot
.756 .14148 Mdot
.756 .14157 Mdot
.756 .14193 Mdot
.756 .14222 Mdot
.756 .14226 Mdot
.756 .14243 Mdot
.756 .14279 Mdot
.756 .14336 Mdot
.756 .14353 Mdot
.756 .14358 Mdot
.756 .14365 Mdot
.756 .14407 Mdot
.756 .14408 Mdot
.756 .14457 Mdot
.756 .14516 Mdot
.756 .14529 Mdot
.756 .14556 Mdot
.756 .14589 Mdot
.756 .14658 Mdot
.756 .14697 Mdot
.756 .14708 Mdot
.756 .14736 Mdot
.756 .14923 Mdot
.756 .14945 Mdot
.756 .15002 Mdot
.756 .15098 Mdot
.756 .15099 Mdot
.756 .15167 Mdot
.756 .15186 Mdot
.756 .15199 Mdot
.756 .15258 Mdot
.756 .15316 Mdot
.756 .1537 Mdot
.756 .15399 Mdot
.756 .15411 Mdot
.756 .15447 Mdot
.756 .1551 Mdot
.756 .15617 Mdot
.756 .15639 Mdot
.756 .15655 Mdot
.756 .15664 Mdot
.756 .15735 Mdot
.756 .15772 Mdot
.756 .15829 Mdot
.756 .1583 Mdot
.756 .15886 Mdot
.756 .15933 Mdot
.756 .16012 Mdot
.756 .1609 Mdot
.756 .16253 Mdot
.756 .16473 Mdot
.756 .16505 Mdot
.756 .16521 Mdot
.756 .16596 Mdot
.756 .16658 Mdot
.756 .16709 Mdot
.756 .16727 Mdot
.756 .16756 Mdot
.756 .16851 Mdot
.756 .16889 Mdot
.756 .16897 Mdot
.756 .16948 Mdot
.756 .17071 Mdot
.756 .172 Mdot
.756 .17206 Mdot
.756 .17222 Mdot
.756 .17293 Mdot
.756 .17389 Mdot
.756 .1753 Mdot
.756 .17555 Mdot
.756 .17595 Mdot
.756 .17606 Mdot
.756 .17617 Mdot
.756 .17624 Mdot
.756 .17629 Mdot
.756 .17677 Mdot
.756 .17748 Mdot
.756 .17755 Mdot
.756 .17793 Mdot
.756 .17861 Mdot
.756 .17915 Mdot
.756 .18003 Mdot
.756 .18142 Mdot
.756 .182 Mdot
.756 .18209 Mdot
.756 .18291 Mdot
.756 .183 Mdot
.756 .18317 Mdot
.756 .18338 Mdot
.756 .18549 Mdot
.756 .1857 Mdot
.756 .18594 Mdot
.756 .18639 Mdot
.756 .1865 Mdot
.756 .18685 Mdot
.756 .18698 Mdot
.756 .18802 Mdot
.756 .18831 Mdot
.756 .18847 Mdot
.756 .18942 Mdot
.756 .19147 Mdot
.756 .19264 Mdot
.756 .19434 Mdot
.756 .19522 Mdot
.756 .19524 Mdot
.756 .19534 Mdot
.756 .19679 Mdot
.756 .19868 Mdot
.756 .19986 Mdot
.756 .20035 Mdot
.756 .20117 Mdot
.756 .20191 Mdot
.756 .20307 Mdot
.756 .20347 Mdot
.756 .20511 Mdot
.756 .20697 Mdot
.756 .2072 Mdot
.756 .20756 Mdot
.756 .20885 Mdot
.756 .20961 Mdot
.756 .21026 Mdot
.756 .21043 Mdot
.756 .21076 Mdot
.756 .21385 Mdot
.756 .21395 Mdot
.756 .21735 Mdot
.756 .21767 Mdot
.756 .21799 Mdot
.756 .21868 Mdot
.756 .21993 Mdot
.756 .22028 Mdot
.756 .22143 Mdot
.756 .22324 Mdot
.756 .22546 Mdot
.756 .226 Mdot
.756 .22659 Mdot
.756 .22807 Mdot
.756 .22831 Mdot
.756 .22926 Mdot
.756 .23117 Mdot
.756 .23128 Mdot
.756 .23172 Mdot
.756 .23173 Mdot
.756 .23268 Mdot
.756 .23515 Mdot
.756 .23535 Mdot
.756 .23602 Mdot
.756 .23697 Mdot
.756 .23738 Mdot
.756 .23883 Mdot
.756 .23939 Mdot
.756 .23984 Mdot
.756 .24161 Mdot
.756 .24164 Mdot
.756 .24294 Mdot
.756 .24325 Mdot
.756 .2489 Mdot
.756 .24932 Mdot
.756 .25051 Mdot
.756 .25178 Mdot
.756 .25185 Mdot
.756 .25248 Mdot
.756 .25263 Mdot
.756 .25287 Mdot
.756 .25298 Mdot
.756 .25409 Mdot
.756 .25416 Mdot
.756 .25487 Mdot
.756 .25549 Mdot
.756 .25589 Mdot
.756 .25663 Mdot
.756 .25699 Mdot
.756 .25721 Mdot
.756 .25737 Mdot
.756 .25879 Mdot
.756 .26047 Mdot
.756 .26095 Mdot
.756 .26142 Mdot
.756 .26223 Mdot
.756 .26286 Mdot
.756 .264 Mdot
.756 .26529 Mdot
.756 .26628 Mdot
.756 .26726 Mdot
.756 .26735 Mdot
.756 .26747 Mdot
.756 .26865 Mdot
.756 .26889 Mdot
.756 .2711 Mdot
.756 .27302 Mdot
.756 .27494 Mdot
.756 .27608 Mdot
.756 .27643 Mdot
.756 .27669 Mdot
.756 .27689 Mdot
.756 .27781 Mdot
.756 .27975 Mdot
.756 .27986 Mdot
.756 .28076 Mdot
.756 .2818 Mdot
.756 .28323 Mdot
.756 .28401 Mdot
.756 .28506 Mdot
.756 .2861 Mdot
.756 .28727 Mdot
.756 .28814 Mdot
.756 .28889 Mdot
.756 .28942 Mdot
.756 .28958 Mdot
.756 .28997 Mdot
.756 .29173 Mdot
.756 .29226 Mdot
.756 .29359 Mdot
.756 .29469 Mdot
.756 .29705 Mdot
.756 .2972 Mdot
.756 .29753 Mdot
.756 .29971 Mdot
.756 .30053 Mdot
.756 .30236 Mdot
.756 .30243 Mdot
.756 .30324 Mdot
.756 .30391 Mdot
.756 .30498 Mdot
.756 .30775 Mdot
.756 .30886 Mdot
.756 .30943 Mdot
.756 .31153 Mdot
.756 .3116 Mdot
.756 .31416 Mdot
.756 .31539 Mdot
.756 .31649 Mdot
.756 .31697 Mdot
.756 .31849 Mdot
.756 .31971 Mdot
.756 .3205 Mdot
.756 .32092 Mdot
.756 .32207 Mdot
.756 .3268 Mdot
.756 .3276 Mdot
.756 .32762 Mdot
.756 .32765 Mdot
.756 .33239 Mdot
.756 .33239 Mdot
.756 .33317 Mdot
.756 .33369 Mdot
.756 .33376 Mdot
.756 .33459 Mdot
.756 .33774 Mdot
.756 .33786 Mdot
.756 .33869 Mdot
.756 .34027 Mdot
.756 .34039 Mdot
.756 .3404 Mdot
.756 .34048 Mdot
.756 .34073 Mdot
.756 .34075 Mdot
.756 .34128 Mdot
.756 .34181 Mdot
.756 .34183 Mdot
.756 .34221 Mdot
.756 .3426 Mdot
.756 .34272 Mdot
.756 .34275 Mdot
.756 .3428 Mdot
.756 .34308 Mdot
.756 .34343 Mdot
.756 .34382 Mdot
.756 .34391 Mdot
.756 .34409 Mdot
.756 .3443 Mdot
.756 .34476 Mdot
.756 .34508 Mdot
.756 .34526 Mdot
.756 .34644 Mdot
.756 .34658 Mdot
.756 .34752 Mdot
.756 .34753 Mdot
.756 .34794 Mdot
.756 .34805 Mdot
.756 .34813 Mdot
.756 .34848 Mdot
.756 .34882 Mdot
.756 .34931 Mdot
.756 .34959 Mdot
.756 .34995 Mdot
.756 .35083 Mdot
.756 .35122 Mdot
.756 .35143 Mdot
.756 .35174 Mdot
.756 .35206 Mdot
.756 .35232 Mdot
.756 .35317 Mdot
.756 .35534 Mdot
.756 .35542 Mdot
.756 .35612 Mdot
.756 .35637 Mdot
.756 .35647 Mdot
.756 .35727 Mdot
.756 .35731 Mdot
.756 .35817 Mdot
.756 .35879 Mdot
.756 .35882 Mdot
.756 .3589 Mdot
.756 .35969 Mdot
.756 .36036 Mdot
.756 .36048 Mdot
.756 .36072 Mdot
.756 .36077 Mdot
.756 .3608 Mdot
.756 .36137 Mdot
.756 .36158 Mdot
.756 .36189 Mdot
.756 .36342 Mdot
.756 .36346 Mdot
.756 .36383 Mdot
.756 .36403 Mdot
.756 .36496 Mdot
.756 .36535 Mdot
.756 .36561 Mdot
.756 .36606 Mdot
.756 .36666 Mdot
.756 .36801 Mdot
.756 .36908 Mdot
.756 .36909 Mdot
.756 .36972 Mdot
.756 .37049 Mdot
.756 .37096 Mdot
.756 .37116 Mdot
.756 .37149 Mdot
.756 .37178 Mdot
.756 .37224 Mdot
.756 .3724 Mdot
.756 .37304 Mdot
.756 .37377 Mdot
.756 .37386 Mdot
.756 .374 Mdot
.756 .37449 Mdot
.756 .37503 Mdot
.756 .37522 Mdot
.756 .3777 Mdot
.756 .37782 Mdot
.756 .37793 Mdot
.756 .37878 Mdot
.756 .37985 Mdot
.756 .38085 Mdot
.756 .38159 Mdot
.756 .38167 Mdot
.756 .38272 Mdot
.756 .38288 Mdot
.756 .38322 Mdot
.756 .38408 Mdot
.756 .38415 Mdot
.756 .38438 Mdot
.756 .38471 Mdot
.756 .38485 Mdot
.756 .38554 Mdot
.756 .3857 Mdot
.756 .38891 Mdot
.756 .3893 Mdot
.756 .38975 Mdot
.756 .39001 Mdot
.756 .39009 Mdot
.756 .39012 Mdot
.756 .39049 Mdot
.756 .39051 Mdot
.756 .39075 Mdot
.756 .39095 Mdot
.756 .39108 Mdot
.756 .39132 Mdot
.756 .39151 Mdot
.756 .39157 Mdot
.756 .39273 Mdot
.756 .39289 Mdot
.756 .39315 Mdot
.756 .39335 Mdot
.756 .39372 Mdot
.756 .39413 Mdot
.756 .39445 Mdot
.756 .39476 Mdot
.756 .39483 Mdot
.756 .39521 Mdot
.756 .39529 Mdot
.756 .39599 Mdot
.756 .3972 Mdot
.756 .39756 Mdot
.756 .39767 Mdot
.756 .39782 Mdot
.756 .39871 Mdot
.756 .39875 Mdot
.756 .39903 Mdot
.756 .3998 Mdot
.756 .40105 Mdot
.756 .40132 Mdot
.756 .40154 Mdot
.756 .40171 Mdot
.756 .40176 Mdot
.756 .40188 Mdot
.756 .40242 Mdot
.756 .40258 Mdot
.756 .40299 Mdot
.756 .40332 Mdot
.756 .40404 Mdot
.756 .40485 Mdot
.756 .40509 Mdot
.756 .40565 Mdot
.756 .40567 Mdot
.756 .40591 Mdot
.756 .40612 Mdot
.756 .40644 Mdot
.756 .4084 Mdot
.756 .40955 Mdot
.756 .40988 Mdot
.756 .41002 Mdot
.756 .41119 Mdot
.756 .41153 Mdot
.756 .41316 Mdot
.756 .41316 Mdot
.756 .41317 Mdot
.756 .41456 Mdot
.756 .41479 Mdot
.756 .41494 Mdot
.756 .41521 Mdot
.756 .41616 Mdot
.756 .4164 Mdot
.756 .41758 Mdot
.756 .41792 Mdot
.756 .41797 Mdot
.756 .41866 Mdot
.756 .41925 Mdot
.756 .41949 Mdot
.756 .41968 Mdot
.756 .41993 Mdot
.756 .42005 Mdot
.756 .4202 Mdot
.756 .42029 Mdot
.756 .42036 Mdot
.756 .42146 Mdot
.756 .42157 Mdot
.756 .42181 Mdot
.756 .42206 Mdot
.756 .42298 Mdot
.756 .42304 Mdot
.756 .42358 Mdot
.756 .42375 Mdot
.756 .42402 Mdot
.756 .42421 Mdot
.756 .42434 Mdot
.756 .42451 Mdot
.756 .42581 Mdot
.756 .42591 Mdot
.756 .42599 Mdot
.756 .42624 Mdot
.756 .42659 Mdot
.756 .42663 Mdot
.756 .42698 Mdot
.756 .4277 Mdot
.756 .42773 Mdot
.756 .42777 Mdot
.756 .42832 Mdot
.756 .42885 Mdot
.756 .42915 Mdot
.756 .42977 Mdot
.756 .43094 Mdot
.756 .43128 Mdot
.756 .43157 Mdot
.756 .43279 Mdot
.756 .43388 Mdot
.756 .43461 Mdot
.756 .43467 Mdot
.756 .4358 Mdot
.756 .43588 Mdot
.756 .43704 Mdot
.756 .43752 Mdot
.756 .43848 Mdot
.756 .4394 Mdot
.756 .43992 Mdot
.756 .44 Mdot
.756 .44003 Mdot
.756 .44012 Mdot
.756 .44063 Mdot
.756 .4409 Mdot
.756 .44092 Mdot
.756 .44113 Mdot
.756 .4423 Mdot
.756 .44327 Mdot
.756 .44346 Mdot
.756 .44437 Mdot
.756 .44438 Mdot
.756 .44473 Mdot
.756 .44524 Mdot
.756 .44553 Mdot
.756 .44599 Mdot
.756 .44626 Mdot
.756 .44633 Mdot
.756 .44698 Mdot
.756 .44767 Mdot
.756 .44781 Mdot
.756 .4479 Mdot
.756 .4484 Mdot
.756 .44874 Mdot
.756 .44902 Mdot
.756 .44992 Mdot
.756 .45007 Mdot
.756 .45032 Mdot
.756 .45096 Mdot
.756 .45155 Mdot
.756 .45271 Mdot
.756 .45283 Mdot
.756 .45325 Mdot
.756 .45332 Mdot
.756 .45336 Mdot
.756 .45363 Mdot
.756 .45413 Mdot
.756 .45464 Mdot
.756 .45489 Mdot
.756 .45555 Mdot
.756 .45614 Mdot
.756 .45618 Mdot
.756 .45656 Mdot
.756 .45776 Mdot
.756 .45809 Mdot
.756 .45902 Mdot
.756 .45944 Mdot
.756 .45976 Mdot
.756 .46013 Mdot
.756 .46033 Mdot
.756 .46051 Mdot
.756 .46064 Mdot
.756 .46073 Mdot
.756 .46155 Mdot
.756 .46178 Mdot
.756 .46213 Mdot
.756 .46216 Mdot
.756 .46263 Mdot
.756 .46276 Mdot
.756 .46288 Mdot
.756 .46348 Mdot
.756 .46352 Mdot
.756 .46364 Mdot
.756 .4637 Mdot
.756 .46383 Mdot
.756 .46467 Mdot
.756 .4647 Mdot
.756 .46557 Mdot
.756 .46625 Mdot
.756 .46705 Mdot
.756 .46785 Mdot
.756 .46865 Mdot
.756 .46936 Mdot
.756 .47031 Mdot
.756 .47046 Mdot
.756 .47056 Mdot
.756 .47068 Mdot
.756 .47179 Mdot
.756 .47195 Mdot
.756 .47222 Mdot
.756 .47253 Mdot
.756 .47256 Mdot
.756 .47264 Mdot
.756 .47382 Mdot
.756 .47557 Mdot
.756 .47595 Mdot
.756 .47629 Mdot
.756 .47668 Mdot
.756 .4774 Mdot
.756 .47751 Mdot
.756 .47757 Mdot
.756 .47796 Mdot
.756 .47812 Mdot
.756 .47832 Mdot
.756 .4785 Mdot
.756 .47996 Mdot
.756 .48034 Mdot
.756 .48041 Mdot
.756 .48066 Mdot
.756 .4813 Mdot
.756 .48177 Mdot
.756 .48214 Mdot
.756 .48259 Mdot
.756 .48344 Mdot
.756 .48349 Mdot
.756 .48355 Mdot
.756 .48464 Mdot
.756 .48518 Mdot
.756 .48524 Mdot
.756 .48528 Mdot
.756 .48615 Mdot
.756 .48628 Mdot
.756 .48642 Mdot
.756 .48704 Mdot
.756 .48837 Mdot
.756 .48863 Mdot
.756 .48882 Mdot
.756 .4891 Mdot
.756 .4895 Mdot
.756 .48959 Mdot
.756 .48976 Mdot
.756 .49055 Mdot
.756 .49064 Mdot
.756 .49089 Mdot
.756 .49092 Mdot
.756 .49107 Mdot
.756 .492 Mdot
.756 .49236 Mdot
.756 .49271 Mdot
.756 .49286 Mdot
.756 .49319 Mdot
.756 .49445 Mdot
.756 .49456 Mdot
.756 .49469 Mdot
.756 .49491 Mdot
.756 .49507 Mdot
.756 .49544 Mdot
.756 .4957 Mdot
.756 .4959 Mdot
.756 .49605 Mdot
.756 .49689 Mdot
.756 .49758 Mdot
.756 .49786 Mdot
.756 .49793 Mdot
.756 .49826 Mdot
.756 .49842 Mdot
.756 .49941 Mdot
.756 .50005 Mdot
.756 .50039 Mdot
.756 .50043 Mdot
.756 .5017 Mdot
.756 .50204 Mdot
.756 .50206 Mdot
.756 .50227 Mdot
.756 .50259 Mdot
.756 .50259 Mdot
.756 .50447 Mdot
.756 .50449 Mdot
.756 .50449 Mdot
.756 .50481 Mdot
.756 .50667 Mdot
.756 .50712 Mdot
.756 .50728 Mdot
.756 .50759 Mdot
.756 .50806 Mdot
.756 .50865 Mdot
.756 .50884 Mdot
.756 .50926 Mdot
.756 .50974 Mdot
.756 .51072 Mdot
.756 .51075 Mdot
.756 .51155 Mdot
.756 .51177 Mdot
.756 .51219 Mdot
.756 .51325 Mdot
.756 .51365 Mdot
.756 .51391 Mdot
.756 .51421 Mdot
.756 .51423 Mdot
.756 .51493 Mdot
.756 .51523 Mdot
.756 .51605 Mdot
.756 .51617 Mdot
.756 .51623 Mdot
.756 .51711 Mdot
.756 .51751 Mdot
.756 .51801 Mdot
.756 .51821 Mdot
.756 .51885 Mdot
.756 .519 Mdot
.756 .51906 Mdot
.756 .51925 Mdot
.756 .51953 Mdot
.756 .51985 Mdot
.756 .52027 Mdot
.756 .52066 Mdot
.756 .52104 Mdot
.756 .52132 Mdot
.756 .52185 Mdot
.756 .52222 Mdot
.756 .52255 Mdot
.756 .52259 Mdot
.756 .52329 Mdot
.756 .52362 Mdot
.756 .52369 Mdot
.756 .52379 Mdot
.756 .52391 Mdot
.756 .52432 Mdot
.756 .52501 Mdot
.756 .5257 Mdot
.756 .52648 Mdot
.756 .52657 Mdot
.756 .52699 Mdot
.756 .52703 Mdot
.756 .52707 Mdot
.756 .52741 Mdot
.756 .52776 Mdot
.756 .52822 Mdot
.756 .52862 Mdot
.756 .52884 Mdot
.756 .52913 Mdot
.756 .52929 Mdot
.756 .52946 Mdot
.756 .53005 Mdot
.756 .53055 Mdot
.756 .5306 Mdot
.756 .53068 Mdot
.756 .53081 Mdot
.756 .53106 Mdot
.756 .5312 Mdot
.756 .53142 Mdot
.756 .53166 Mdot
.756 .53169 Mdot
.756 .53207 Mdot
.756 .53211 Mdot
.756 .53219 Mdot
.756 .53225 Mdot
.756 .53246 Mdot
.756 .53249 Mdot
.756 .53293 Mdot
.756 .53334 Mdot
.756 .53348 Mdot
.756 .53542 Mdot
.756 .53553 Mdot
.756 .53597 Mdot
.756 .53598 Mdot
.756 .53658 Mdot
.756 .53674 Mdot
.756 .53693 Mdot
.756 .53742 Mdot
.756 .53756 Mdot
.756 .53788 Mdot
.756 .53811 Mdot
.756 .53817 Mdot
.756 .53901 Mdot
.756 .53932 Mdot
.756 .53933 Mdot
.756 .53948 Mdot
.756 .53951 Mdot
.756 .54015 Mdot
.756 .54047 Mdot
.756 .54055 Mdot
.756 .54104 Mdot
.756 .54124 Mdot
.756 .54142 Mdot
.756 .54216 Mdot
.756 .54276 Mdot
.756 .54314 Mdot
.756 .54325 Mdot
.756 .54367 Mdot
.756 .54389 Mdot
.756 .544 Mdot
.756 .54411 Mdot
.756 .54522 Mdot
.756 .54525 Mdot
.756 .54626 Mdot
.756 .54637 Mdot
.756 .54643 Mdot
.756 .54664 Mdot
.756 .54688 Mdot
.756 .5473 Mdot
.756 .54742 Mdot
.756 .54749 Mdot
.756 .5481 Mdot
.756 .54863 Mdot
.756 .54876 Mdot
.756 .54913 Mdot
.756 .54937 Mdot
.756 .54963 Mdot
.756 .54979 Mdot
.756 .55017 Mdot
.756 .55077 Mdot
.756 .55124 Mdot
.756 .55127 Mdot
.756 .55127 Mdot
.756 .55156 Mdot
.756 .5521 Mdot
.756 .55247 Mdot
.756 .55312 Mdot
.756 .55342 Mdot
.756 .55347 Mdot
.756 .55356 Mdot
.756 .55389 Mdot
.756 .55393 Mdot
.756 .55404 Mdot
.756 .55408 Mdot
.756 .55422 Mdot
.756 .5543 Mdot
.756 .55436 Mdot
.756 .55503 Mdot
.756 .55509 Mdot
.756 .55515 Mdot
.756 .55518 Mdot
.756 .55543 Mdot
.756 .55546 Mdot
.756 .55564 Mdot
.756 .55608 Mdot
.756 .55635 Mdot
.756 .55652 Mdot
.756 .55673 Mdot
.756 .55685 Mdot
.756 .55688 Mdot
.756 .5571 Mdot
.756 .55725 Mdot
.756 .55726 Mdot
.756 .55728 Mdot
.756 .55732 Mdot
.756 .55735 Mdot
.756 .55748 Mdot
.756 .55755 Mdot
.756 .55799 Mdot
.756 .55829 Mdot
.756 .55851 Mdot
.756 .55856 Mdot
.756 .55858 Mdot
.756 .55898 Mdot
.756 .55936 Mdot
.756 .55952 Mdot
.756 .55954 Mdot
.756 .55966 Mdot
.756 .55995 Mdot
.756 .56004 Mdot
.756 .5601 Mdot
.756 .56025 Mdot
.756 .56045 Mdot
.756 .56068 Mdot
.756 .56072 Mdot
.756 .56082 Mdot
.756 .5615 Mdot
.756 .562 Mdot
.756 .56224 Mdot
.756 .56248 Mdot
.756 .56262 Mdot
.756 .56279 Mdot
.756 .56279 Mdot
.756 .56297 Mdot
.756 .56308 Mdot
.756 .5633 Mdot
.756 .56332 Mdot
.756 .56337 Mdot
.756 .56344 Mdot
.756 .56376 Mdot
.756 .56396 Mdot
.756 .56406 Mdot
.756 .5641 Mdot
.756 .56419 Mdot
.756 .56435 Mdot
.756 .56453 Mdot
.756 .56471 Mdot
.756 .56475 Mdot
.756 .5648 Mdot
.756 .56501 Mdot
.756 .56501 Mdot
.756 .5653 Mdot
.756 .56547 Mdot
.756 .56554 Mdot
.756 .5661 Mdot
.756 .56619 Mdot
.756 .56622 Mdot
.756 .56634 Mdot
.756 .56655 Mdot
.756 .56665 Mdot
.756 .56673 Mdot
.756 .56676 Mdot
.756 .56694 Mdot
.756 .56709 Mdot
.756 .56709 Mdot
.756 .56722 Mdot
.756 .56724 Mdot
.756 .56725 Mdot
.756 .5673 Mdot
.756 .56747 Mdot
.756 .56758 Mdot
.756 .56763 Mdot
.756 .56764 Mdot
.756 .56773 Mdot
.756 .56784 Mdot
.756 .56787 Mdot
.756 .56793 Mdot
.756 .56809 Mdot
.756 .56809 Mdot
.756 .5682 Mdot
.756 .56823 Mdot
.756 .56823 Mdot
.756 .56828 Mdot
.756 .5683 Mdot
.756 .5689 Mdot
.756 .56906 Mdot
.756 .5691 Mdot
.756 .56922 Mdot
.756 .56926 Mdot
.756 .56943 Mdot
.756 .56981 Mdot
.756 .5703 Mdot
.756 .57037 Mdot
.756 .57055 Mdot
.756 .57064 Mdot
.756 .57066 Mdot
.756 .57082 Mdot
.756 .57088 Mdot
.756 .57106 Mdot
.756 .57107 Mdot
.756 .5712 Mdot
.756 .57154 Mdot
.756 .57178 Mdot
.756 .57198 Mdot
.756 .57211 Mdot
.756 .57215 Mdot
.756 .57225 Mdot
.756 .57235 Mdot
.756 .57236 Mdot
.756 .57236 Mdot
.756 .57255 Mdot
.756 .57266 Mdot
.756 .57278 Mdot
.756 .57306 Mdot
.756 .57327 Mdot
.756 .57349 Mdot
.756 .57367 Mdot
.756 .57368 Mdot
.756 .57369 Mdot
.756 .57374 Mdot
.756 .57374 Mdot
.756 .57386 Mdot
.756 .57401 Mdot
.756 .57404 Mdot
.756 .57413 Mdot
.756 .57419 Mdot
.756 .57423 Mdot
.756 .57431 Mdot
.756 .57431 Mdot
.756 .57433 Mdot
.756 .57438 Mdot
.756 .57442 Mdot
.756 .57443 Mdot
.756 .57449 Mdot
.756 .57455 Mdot
.756 .57455 Mdot
.756 .57459 Mdot
.756 .57459 Mdot
.756 .5746 Mdot
.758 .11791 Mdot
.758 .11792 Mdot
.758 .11792 Mdot
.758 .11792 Mdot
.758 .11802 Mdot
.758 .11812 Mdot
.758 .11816 Mdot
.758 .11819 Mdot
.758 .11831 Mdot
.758 .11833 Mdot
.758 .11843 Mdot
.758 .1185 Mdot
.758 .11874 Mdot
.758 .11889 Mdot
.758 .11917 Mdot
.758 .11922 Mdot
.758 .11923 Mdot
.758 .1193 Mdot
.758 .12106 Mdot
.758 .12207 Mdot
.758 .12259 Mdot
.758 .12317 Mdot
.758 .12335 Mdot
.758 .12505 Mdot
.758 .12515 Mdot
.758 .12643 Mdot
.758 .12661 Mdot
.758 .12674 Mdot
.758 .12785 Mdot
.758 .12819 Mdot
.758 .12833 Mdot
.758 .12855 Mdot
.758 .12943 Mdot
.758 .13001 Mdot
.758 .13036 Mdot
.758 .13041 Mdot
.758 .13049 Mdot
.758 .13096 Mdot
.758 .13114 Mdot
.758 .13145 Mdot
.758 .13215 Mdot
.758 .1335 Mdot
.758 .13452 Mdot
.758 .13459 Mdot
.758 .13508 Mdot
.758 .13638 Mdot
.758 .13651 Mdot
.758 .13657 Mdot
.758 .13724 Mdot
.758 .13725 Mdot
.758 .13725 Mdot
.758 .13727 Mdot
.758 .13741 Mdot
.758 .13759 Mdot
.758 .13764 Mdot
.758 .13781 Mdot
.758 .1379 Mdot
.758 .13801 Mdot
.758 .13811 Mdot
.758 .13814 Mdot
.758 .13852 Mdot
.758 .13858 Mdot
.758 .13892 Mdot
.758 .13913 Mdot
.758 .13917 Mdot
.758 .13996 Mdot
.758 .14021 Mdot
.758 .14045 Mdot
.758 .14143 Mdot
.758 .14161 Mdot
.758 .14164 Mdot
.758 .14187 Mdot
.758 .14224 Mdot
.758 .1426 Mdot
.758 .14265 Mdot
.758 .14289 Mdot
.758 .14322 Mdot
.758 .14337 Mdot
.758 .14343 Mdot
.758 .1439 Mdot
.758 .14475 Mdot
.758 .14518 Mdot
.758 .1462 Mdot
.758 .14657 Mdot
.758 .14817 Mdot
.758 .1484 Mdot
.758 .14917 Mdot
.758 .14943 Mdot
.758 .1505 Mdot
.758 .15087 Mdot
.758 .15144 Mdot
.758 .15247 Mdot
.758 .15423 Mdot
.758 .15464 Mdot
.758 .15495 Mdot
.758 .15507 Mdot
.758 .15566 Mdot
.758 .15568 Mdot
.758 .15575 Mdot
.758 .15711 Mdot
.758 .15787 Mdot
.758 .15832 Mdot
.758 .15838 Mdot
.758 .15961 Mdot
.758 .16026 Mdot
.758 .16028 Mdot
.758 .16061 Mdot
.758 .1631 Mdot
.758 .16311 Mdot
.758 .16348 Mdot
.758 .16366 Mdot
.758 .16429 Mdot
.758 .16562 Mdot
.758 .16586 Mdot
.758 .16594 Mdot
.758 .16597 Mdot
.758 .16608 Mdot
.758 .16672 Mdot
.758 .16805 Mdot
.758 .17015 Mdot
.758 .17149 Mdot
.758 .17227 Mdot
.758 .17316 Mdot
.758 .17318 Mdot
.758 .17382 Mdot
.758 .17432 Mdot
.758 .17463 Mdot
.758 .17467 Mdot
.758 .17559 Mdot
.758 .17592 Mdot
.758 .17619 Mdot
.758 .17703 Mdot
.758 .17713 Mdot
.758 .17731 Mdot
.758 .17783 Mdot
.758 .17948 Mdot
.758 .17971 Mdot
.758 .17981 Mdot
.758 .18087 Mdot
.758 .18122 Mdot
.758 .18199 Mdot
.758 .18313 Mdot
.758 .18329 Mdot
.758 .18493 Mdot
.758 .18622 Mdot
.758 .1867 Mdot
.758 .18709 Mdot
.758 .18717 Mdot
.758 .18786 Mdot
.758 .18894 Mdot
.758 .18983 Mdot
.758 .19005 Mdot
.758 .19106 Mdot
.758 .19238 Mdot
.758 .193 Mdot
.758 .19328 Mdot
.758 .19341 Mdot
.758 .19375 Mdot
.758 .19391 Mdot
.758 .19489 Mdot
.758 .19616 Mdot
.758 .19635 Mdot
.758 .1968 Mdot
.758 .19726 Mdot
.758 .19742 Mdot
.758 .19762 Mdot
.758 .19892 Mdot
.758 .19915 Mdot
.758 .1997 Mdot
.758 .19989 Mdot
.758 .20033 Mdot
.758 .20047 Mdot
.758 .20088 Mdot
.758 .20242 Mdot
.758 .20276 Mdot
.758 .20321 Mdot
.758 .20384 Mdot
.758 .20828 Mdot
.758 .20895 Mdot
.758 .20926 Mdot
.758 .20956 Mdot
.758 .21047 Mdot
.758 .21055 Mdot
.758 .21119 Mdot
.758 .21439 Mdot
.758 .21718 Mdot
.758 .21736 Mdot
.758 .21746 Mdot
.758 .21764 Mdot
.758 .21778 Mdot
.758 .21861 Mdot
.758 .21863 Mdot
.758 .21875 Mdot
.758 .21911 Mdot
.758 .21943 Mdot
.758 .21974 Mdot
.758 .22068 Mdot
.758 .22069 Mdot
.758 .22079 Mdot
.758 .22134 Mdot
.758 .22294 Mdot
.758 .22307 Mdot
.758 .22571 Mdot
.758 .22597 Mdot
.758 .22697 Mdot
.758 .22713 Mdot
.758 .22797 Mdot
.758 .22891 Mdot
.758 .22928 Mdot
.758 .22979 Mdot
.758 .23012 Mdot
.758 .23017 Mdot
.758 .23276 Mdot
.758 .23309 Mdot
.758 .23318 Mdot
.758 .23337 Mdot
.758 .23438 Mdot
.758 .23444 Mdot
.758 .23447 Mdot
.758 .23459 Mdot
.758 .2355 Mdot
.758 .23627 Mdot
.758 .23663 Mdot
.758 .23699 Mdot
.758 .23708 Mdot
.758 .23803 Mdot
.758 .23807 Mdot
.758 .23865 Mdot
.758 .23935 Mdot
.758 .24001 Mdot
.758 .24008 Mdot
.758 .24018 Mdot
.758 .24266 Mdot
.758 .24304 Mdot
.758 .24327 Mdot
.758 .24525 Mdot
.758 .24567 Mdot
.758 .24581 Mdot
.758 .24663 Mdot
.758 .24681 Mdot
.758 .24689 Mdot
.758 .2472 Mdot
.758 .24805 Mdot
.758 .24831 Mdot
.758 .24923 Mdot
.758 .24944 Mdot
.758 .25093 Mdot
.758 .25207 Mdot
.758 .2521 Mdot
.758 .25227 Mdot
.758 .25375 Mdot
.758 .25482 Mdot
.758 .2553 Mdot
.758 .25534 Mdot
.758 .25619 Mdot
.758 .25656 Mdot
.758 .25707 Mdot
.758 .25836 Mdot
.758 .25916 Mdot
.758 .26189 Mdot
.758 .26193 Mdot
.758 .26315 Mdot
.758 .26334 Mdot
.758 .26334 Mdot
.758 .26484 Mdot
.758 .26735 Mdot
.758 .26736 Mdot
.758 .26777 Mdot
.758 .26818 Mdot
.758 .26981 Mdot
.758 .27015 Mdot
.758 .27103 Mdot
.758 .27181 Mdot
.758 .27282 Mdot
.758 .274 Mdot
.758 .27457 Mdot
.758 .27489 Mdot
.758 .27493 Mdot
.758 .27503 Mdot
.758 .27546 Mdot
.758 .27791 Mdot
.758 .2787 Mdot
.758 .27893 Mdot
.758 .27993 Mdot
.758 .28004 Mdot
.758 .28109 Mdot
.758 .2815 Mdot
.758 .28155 Mdot
.758 .28424 Mdot
.758 .28452 Mdot
.758 .2847 Mdot
.758 .28526 Mdot
.758 .2856 Mdot
.758 .28618 Mdot
.758 .28745 Mdot
.758 .28918 Mdot
.758 .29093 Mdot
.758 .29447 Mdot
.758 .2953 Mdot
.758 .29709 Mdot
.758 .30386 Mdot
.758 .30414 Mdot
.758 .30473 Mdot
.758 .30588 Mdot
.758 .30804 Mdot
.758 .30818 Mdot
.758 .30831 Mdot
.758 .30981 Mdot
.758 .31135 Mdot
.758 .31238 Mdot
.758 .31263 Mdot
.758 .31339 Mdot
.758 .31516 Mdot
.758 .31567 Mdot
.758 .31657 Mdot
.758 .31673 Mdot
.758 .31675 Mdot
.758 .31693 Mdot
.758 .32443 Mdot
.758 .32469 Mdot
.758 .32698 Mdot
.758 .32865 Mdot
.758 .329 Mdot
.758 .33023 Mdot
.758 .33074 Mdot
.758 .33096 Mdot
.758 .33282 Mdot
.758 .3329 Mdot
.758 .33443 Mdot
.758 .33562 Mdot
.758 .33814 Mdot
.758 .33866 Mdot
.758 .33867 Mdot
.758 .33868 Mdot
.758 .33869 Mdot
.758 .33894 Mdot
.758 .33898 Mdot
.758 .33918 Mdot
.758 .33926 Mdot
.758 .33936 Mdot
.758 .33964 Mdot
.758 .33969 Mdot
.758 .33994 Mdot
.758 .3401 Mdot
.758 .34071 Mdot
.758 .34089 Mdot
.758 .34106 Mdot
.758 .34176 Mdot
.758 .34189 Mdot
.758 .34191 Mdot
.758 .34207 Mdot
.758 .34233 Mdot
.758 .34261 Mdot
.758 .34278 Mdot
.758 .34431 Mdot
.758 .34497 Mdot
.758 .34637 Mdot
.758 .34685 Mdot
.758 .34766 Mdot
.758 .34883 Mdot
.758 .35009 Mdot
.758 .35033 Mdot
.758 .35072 Mdot
.758 .35148 Mdot
.758 .3519 Mdot
.758 .35215 Mdot
.758 .35218 Mdot
.758 .35284 Mdot
.758 .3532 Mdot
.758 .35338 Mdot
.758 .35497 Mdot
.758 .3553 Mdot
.758 .35598 Mdot
.758 .35615 Mdot
.758 .35621 Mdot
.758 .35653 Mdot
.758 .3572 Mdot
.758 .35822 Mdot
.758 .35924 Mdot
.758 .35967 Mdot
.758 .35998 Mdot
.758 .36021 Mdot
.758 .36036 Mdot
.758 .36038 Mdot
.758 .36081 Mdot
.758 .36108 Mdot
.758 .36152 Mdot
.758 .3616 Mdot
.758 .36259 Mdot
.758 .36337 Mdot
.758 .36371 Mdot
.758 .36421 Mdot
.758 .365 Mdot
.758 .36556 Mdot
.758 .36626 Mdot
.758 .36672 Mdot
.758 .36719 Mdot
.758 .36762 Mdot
.758 .36817 Mdot
.758 .36842 Mdot
.758 .36854 Mdot
.758 .36873 Mdot
.758 .3692 Mdot
.758 .3698 Mdot
.758 .37017 Mdot
.758 .37023 Mdot
.758 .37031 Mdot
.758 .37093 Mdot
.758 .37145 Mdot
.758 .37162 Mdot
.758 .37254 Mdot
.758 .3745 Mdot
.758 .37488 Mdot
.758 .37534 Mdot
.758 .37562 Mdot
.758 .37682 Mdot
.758 .37792 Mdot
.758 .37807 Mdot
.758 .37838 Mdot
.758 .37839 Mdot
.758 .37843 Mdot
.758 .37856 Mdot
.758 .3788 Mdot
.758 .37914 Mdot
.758 .37914 Mdot
.758 .37918 Mdot
.758 .38146 Mdot
.758 .38209 Mdot
.758 .38222 Mdot
.758 .3824 Mdot
.758 .38252 Mdot
.758 .38401 Mdot
.758 .38403 Mdot
.758 .38404 Mdot
.758 .38408 Mdot
.758 .3844 Mdot
.758 .38479 Mdot
.758 .38491 Mdot
.758 .38528 Mdot
.758 .38548 Mdot
.758 .38572 Mdot
.758 .38595 Mdot
.758 .38597 Mdot
.758 .386 Mdot
.758 .38685 Mdot
.758 .38698 Mdot
.758 .38705 Mdot
.758 .38772 Mdot
.758 .38819 Mdot
.758 .38827 Mdot
.758 .38838 Mdot
.758 .38866 Mdot
.758 .38906 Mdot
.758 .38962 Mdot
.758 .39 Mdot
.758 .39001 Mdot
.758 .39055 Mdot
.758 .39107 Mdot
.758 .39135 Mdot
.758 .39147 Mdot
.758 .39164 Mdot
.758 .3932 Mdot
.758 .39322 Mdot
.758 .39361 Mdot
.758 .39367 Mdot
.758 .39367 Mdot
.758 .39415 Mdot
.758 .39496 Mdot
.758 .39522 Mdot
.758 .39574 Mdot
.758 .39585 Mdot
.758 .39612 Mdot
.758 .39637 Mdot
.758 .39706 Mdot
.758 .39739 Mdot
.758 .39752 Mdot
.758 .39853 Mdot
.758 .39895 Mdot
.758 .40034 Mdot
.758 .40125 Mdot
.758 .40178 Mdot
.758 .40231 Mdot
.758 .40339 Mdot
.758 .40419 Mdot
.758 .40623 Mdot
.758 .40632 Mdot
.758 .40649 Mdot
.758 .40752 Mdot
.758 .40801 Mdot
.758 .40885 Mdot
.758 .4096 Mdot
.758 .41002 Mdot
.758 .41007 Mdot
.758 .41007 Mdot
.758 .41013 Mdot
.758 .41234 Mdot
.758 .41242 Mdot
.758 .41309 Mdot
.758 .41358 Mdot
.758 .41368 Mdot
.758 .41404 Mdot
.758 .41426 Mdot
.758 .4148 Mdot
.758 .41635 Mdot
.758 .41659 Mdot
.758 .41765 Mdot
.758 .41989 Mdot
.758 .42 Mdot
.758 .42042 Mdot
.758 .42072 Mdot
.758 .42133 Mdot
.758 .42157 Mdot
.758 .42217 Mdot
.758 .42274 Mdot
.758 .42278 Mdot
.758 .42279 Mdot
.758 .42291 Mdot
.758 .42299 Mdot
.758 .42312 Mdot
.758 .42533 Mdot
.758 .42561 Mdot
.758 .42598 Mdot
.758 .42603 Mdot
.758 .42686 Mdot
.758 .4271 Mdot
.758 .42753 Mdot
.758 .42798 Mdot
.758 .428 Mdot
.758 .42803 Mdot
.758 .4281 Mdot
.758 .4282 Mdot
.758 .42887 Mdot
.758 .43048 Mdot
.758 .43106 Mdot
.758 .43122 Mdot
.758 .43173 Mdot
.758 .43176 Mdot
.758 .43226 Mdot
.758 .4324 Mdot
.758 .43284 Mdot
.758 .43393 Mdot
.758 .43607 Mdot
.758 .43612 Mdot
.758 .43715 Mdot
.758 .43716 Mdot
.758 .43785 Mdot
.758 .43819 Mdot
.758 .43908 Mdot
.758 .43939 Mdot
.758 .44008 Mdot
.758 .44096 Mdot
.758 .44165 Mdot
.758 .44186 Mdot
.758 .44231 Mdot
.758 .44246 Mdot
.758 .4425 Mdot
.758 .4427 Mdot
.758 .44389 Mdot
.758 .44607 Mdot
.758 .44633 Mdot
.758 .45013 Mdot
.758 .45252 Mdot
.758 .45289 Mdot
.758 .45337 Mdot
.758 .4539 Mdot
.758 .45547 Mdot
.758 .4555 Mdot
.758 .45663 Mdot
.758 .45719 Mdot
.758 .45749 Mdot
.758 .45804 Mdot
.758 .45812 Mdot
.758 .45925 Mdot
.758 .4596 Mdot
.758 .45968 Mdot
.758 .4597 Mdot
.758 .45994 Mdot
.758 .46028 Mdot
.758 .46071 Mdot
.758 .46073 Mdot
.758 .46106 Mdot
.758 .46218 Mdot
.758 .46225 Mdot
.758 .46235 Mdot
.758 .46266 Mdot
.758 .46354 Mdot
.758 .46375 Mdot
.758 .46492 Mdot
.758 .46544 Mdot
.758 .46633 Mdot
.758 .4667 Mdot
.758 .46688 Mdot
.758 .46693 Mdot
.758 .46749 Mdot
.758 .46863 Mdot
.758 .46864 Mdot
.758 .46866 Mdot
.758 .46922 Mdot
.758 .47036 Mdot
.758 .47044 Mdot
.758 .47048 Mdot
.758 .47235 Mdot
.758 .4726 Mdot
.758 .47393 Mdot
.758 .47525 Mdot
.758 .47567 Mdot
.758 .47639 Mdot
.758 .4766 Mdot
.758 .47733 Mdot
.758 .4774 Mdot
.758 .47746 Mdot
.758 .47808 Mdot
.758 .47825 Mdot
.758 .47851 Mdot
.758 .47869 Mdot
.758 .47882 Mdot
.758 .47942 Mdot
.758 .47991 Mdot
.758 .4816 Mdot
.758 .48194 Mdot
.758 .48297 Mdot
.758 .48297 Mdot
.758 .48313 Mdot
.758 .48323 Mdot
.758 .48329 Mdot
.758 .48331 Mdot
.758 .48331 Mdot
.758 .484 Mdot
.758 .48465 Mdot
.758 .48486 Mdot
.758 .48502 Mdot
.758 .48628 Mdot
.758 .48636 Mdot
.758 .48685 Mdot
.758 .48692 Mdot
.758 .48733 Mdot
.758 .48778 Mdot
.758 .4882 Mdot
.758 .48841 Mdot
.758 .48891 Mdot
.758 .48915 Mdot
.758 .4906 Mdot
.758 .49064 Mdot
.758 .49082 Mdot
.758 .49094 Mdot
.758 .49112 Mdot
.758 .49113 Mdot
.758 .49119 Mdot
.758 .49203 Mdot
.758 .49247 Mdot
.758 .49275 Mdot
.758 .49291 Mdot
.758 .49326 Mdot
.758 .4934 Mdot
.758 .49407 Mdot
.758 .49414 Mdot
.758 .49429 Mdot
.758 .49457 Mdot
.758 .49458 Mdot
.758 .49518 Mdot
.758 .49534 Mdot
.758 .49644 Mdot
.758 .49678 Mdot
.758 .49755 Mdot
.758 .49782 Mdot
.758 .49845 Mdot
.758 .49851 Mdot
.758 .49863 Mdot
.758 .49922 Mdot
.758 .49999 Mdot
.758 .50033 Mdot
.758 .50135 Mdot
.758 .50182 Mdot
.758 .50244 Mdot
.758 .50247 Mdot
.758 .50321 Mdot
.758 .5033 Mdot
.758 .5035 Mdot
.758 .50399 Mdot
.758 .50413 Mdot
.758 .50479 Mdot
.758 .50569 Mdot
.758 .50579 Mdot
.758 .50872 Mdot
.758 .50879 Mdot
.758 .5088 Mdot
.758 .50886 Mdot
.758 .50921 Mdot
.758 .5094 Mdot
.758 .51008 Mdot
.758 .51037 Mdot
.758 .51047 Mdot
.758 .51087 Mdot
.758 .51145 Mdot
.758 .51203 Mdot
.758 .51208 Mdot
.758 .51213 Mdot
.758 .51295 Mdot
.758 .51339 Mdot
.758 .51361 Mdot
.758 .51372 Mdot
.758 .51626 Mdot
.758 .51692 Mdot
.758 .51723 Mdot
.758 .51854 Mdot
.758 .51919 Mdot
.758 .51982 Mdot
.758 .52029 Mdot
.758 .5205 Mdot
.758 .52062 Mdot
.758 .52083 Mdot
.758 .52089 Mdot
.758 .521 Mdot
.758 .52197 Mdot
.758 .522 Mdot
.758 .52214 Mdot
.758 .52252 Mdot
.758 .52256 Mdot
.758 .52293 Mdot
.758 .52301 Mdot
.758 .52329 Mdot
.758 .52418 Mdot
.758 .52433 Mdot
.758 .52437 Mdot
.758 .52438 Mdot
.758 .5245 Mdot
.758 .5247 Mdot
.758 .52512 Mdot
.758 .52548 Mdot
.758 .52576 Mdot
.758 .52607 Mdot
.758 .5262 Mdot
.758 .52678 Mdot
.758 .52692 Mdot
.758 .52707 Mdot
.758 .52707 Mdot
.758 .52796 Mdot
.758 .52849 Mdot
.758 .52849 Mdot
.758 .52855 Mdot
.758 .52898 Mdot
.758 .529 Mdot
.758 .52995 Mdot
.758 .53024 Mdot
.758 .53069 Mdot
.758 .53086 Mdot
.758 .53099 Mdot
.758 .53129 Mdot
.758 .5313 Mdot
.758 .53147 Mdot
.758 .53184 Mdot
.758 .53235 Mdot
.758 .53241 Mdot
.758 .53242 Mdot
.758 .53282 Mdot
.758 .53333 Mdot
.758 .5334 Mdot
.758 .53372 Mdot
.758 .53381 Mdot
.758 .5341 Mdot
.758 .53421 Mdot
.758 .53424 Mdot
.758 .5343 Mdot
.758 .53458 Mdot
.758 .53463 Mdot
.758 .53477 Mdot
.758 .53545 Mdot
.758 .53553 Mdot
.758 .53566 Mdot
.758 .5365 Mdot
.758 .53654 Mdot
.758 .53656 Mdot
.758 .53678 Mdot
.758 .53702 Mdot
.758 .53721 Mdot
.758 .53723 Mdot
.758 .53755 Mdot
.758 .53758 Mdot
.758 .53764 Mdot
.758 .5377 Mdot
.758 .53782 Mdot
.758 .53809 Mdot
.758 .53839 Mdot
.758 .53843 Mdot
.758 .53844 Mdot
.758 .53846 Mdot
.758 .5388 Mdot
.758 .53887 Mdot
.758 .5389 Mdot
.758 .53901 Mdot
.758 .53988 Mdot
.758 .53989 Mdot
.758 .54001 Mdot
.758 .54017 Mdot
.758 .5403 Mdot
.758 .54061 Mdot
.758 .54089 Mdot
.758 .54095 Mdot
.758 .54128 Mdot
.758 .54137 Mdot
.758 .54224 Mdot
.758 .54229 Mdot
.758 .54282 Mdot
.758 .543 Mdot
.758 .54303 Mdot
.758 .54304 Mdot
.758 .54334 Mdot
.758 .54345 Mdot
.758 .54355 Mdot
.758 .54367 Mdot
.758 .54371 Mdot
.758 .54372 Mdot
.758 .54399 Mdot
.758 .54404 Mdot
.758 .5441 Mdot
.758 .54413 Mdot
.758 .54419 Mdot
.758 .5451 Mdot
.758 .54615 Mdot
.758 .54636 Mdot
.758 .54638 Mdot
.758 .54668 Mdot
.758 .54678 Mdot
.758 .54688 Mdot
.758 .5471 Mdot
.758 .54853 Mdot
.758 .54874 Mdot
.758 .54888 Mdot
.758 .54899 Mdot
.758 .54949 Mdot
.758 .54962 Mdot
.758 .54966 Mdot
.758 .54981 Mdot
.758 .54987 Mdot
.758 .55004 Mdot
.758 .55012 Mdot
.758 .55053 Mdot
.758 .5506 Mdot
.758 .55065 Mdot
.758 .55079 Mdot
.758 .55094 Mdot
.758 .551 Mdot
.758 .55141 Mdot
.758 .55172 Mdot
.758 .55177 Mdot
.758 .55188 Mdot
.758 .55192 Mdot
.758 .55201 Mdot
.758 .55221 Mdot
.758 .55262 Mdot
.758 .55294 Mdot
.758 .55301 Mdot
.758 .55329 Mdot
.758 .55364 Mdot
.758 .55386 Mdot
.758 .55388 Mdot
.758 .554 Mdot
.758 .55415 Mdot
.758 .55456 Mdot
.758 .55508 Mdot
.758 .55513 Mdot
.758 .55549 Mdot
.758 .55573 Mdot
.758 .55584 Mdot
.758 .55617 Mdot
.758 .5562 Mdot
.758 .55627 Mdot
.758 .55679 Mdot
.758 .55695 Mdot
.758 .55701 Mdot
.758 .55704 Mdot
.758 .5573 Mdot
.758 .55738 Mdot
.758 .55749 Mdot
.758 .55777 Mdot
.758 .55779 Mdot
.758 .55788 Mdot
.758 .55804 Mdot
.758 .55824 Mdot
.758 .55824 Mdot
.758 .55852 Mdot
.758 .55876 Mdot
.758 .55917 Mdot
.758 .55982 Mdot
.758 .56023 Mdot
.758 .56043 Mdot
.758 .56046 Mdot
.758 .56047 Mdot
.758 .56049 Mdot
.758 .56057 Mdot
.758 .56098 Mdot
.758 .56117 Mdot
.758 .56123 Mdot
.758 .56134 Mdot
.758 .56134 Mdot
.758 .56211 Mdot
.758 .56221 Mdot
.758 .56221 Mdot
.758 .56241 Mdot
.758 .56278 Mdot
.758 .5628 Mdot
.758 .56294 Mdot
.758 .56317 Mdot
.758 .56359 Mdot
.758 .5636 Mdot
.758 .56361 Mdot
.758 .56379 Mdot
.758 .56383 Mdot
.758 .56392 Mdot
.758 .56405 Mdot
.758 .56458 Mdot
.758 .56489 Mdot
.758 .56506 Mdot
.758 .56517 Mdot
.758 .5655 Mdot
.758 .56557 Mdot
.758 .56581 Mdot
.758 .56588 Mdot
.758 .56636 Mdot
.758 .56647 Mdot
.758 .56678 Mdot
.758 .5669 Mdot
.758 .56716 Mdot
.758 .5673 Mdot
.758 .56732 Mdot
.758 .56736 Mdot
.758 .56746 Mdot
.758 .56753 Mdot
.758 .56755 Mdot
.758 .56766 Mdot
.758 .56777 Mdot
.758 .56783 Mdot
.758 .56784 Mdot
.758 .5679 Mdot
.758 .56819 Mdot
.758 .56826 Mdot
.758 .56834 Mdot
.758 .56857 Mdot
.758 .56858 Mdot
.758 .56865 Mdot
.758 .56875 Mdot
.758 .56876 Mdot
.758 .56888 Mdot
.758 .56889 Mdot
.758 .56892 Mdot
.758 .56895 Mdot
.758 .56898 Mdot
.758 .56903 Mdot
.758 .56904 Mdot
.758 .56914 Mdot
.758 .56914 Mdot
.758 .56914 Mdot
.758 .56915 Mdot
.758 .56935 Mdot
.758 .56936 Mdot
.758 .5694 Mdot
.758 .56979 Mdot
.758 .56993 Mdot
.758 .56995 Mdot
.758 .57025 Mdot
.758 .57065 Mdot
.758 .57086 Mdot
.758 .57095 Mdot
.758 .57101 Mdot
.758 .57114 Mdot
.758 .57117 Mdot
.758 .57118 Mdot
.758 .57129 Mdot
.758 .57146 Mdot
.758 .57172 Mdot
.758 .57178 Mdot
.758 .57182 Mdot
.758 .57192 Mdot
.758 .57225 Mdot
.758 .57229 Mdot
.758 .57234 Mdot
.758 .57271 Mdot
.758 .57274 Mdot
.758 .57324 Mdot
.758 .57329 Mdot
.758 .57346 Mdot
.758 .57361 Mdot
.758 .57391 Mdot
.758 .57443 Mdot
.758 .57444 Mdot
.758 .57445 Mdot
.758 .57446 Mdot
.758 .57454 Mdot
.758 .57459 Mdot
.758 .57466 Mdot
.758 .57468 Mdot
.758 .57471 Mdot
.758 .57471 Mdot
.758 .57475 Mdot
.758 .57476 Mdot
.758 .57477 Mdot
.758 .5748 Mdot
.758 .57482 Mdot
.758 .57483 Mdot
.758 .57483 Mdot
.758 .57483 Mdot
.76 .11717 Mdot
.76 .11727 Mdot
.76 .11734 Mdot
.76 .11738 Mdot
.76 .11738 Mdot
.76 .11742 Mdot
.76 .11742 Mdot
.76 .11744 Mdot
.76 .11748 Mdot
.76 .11757 Mdot
.76 .1177 Mdot
.76 .11774 Mdot
.76 .11796 Mdot
.76 .11801 Mdot
.76 .11817 Mdot
.76 .11818 Mdot
.76 .11823 Mdot
.76 .11846 Mdot
.76 .11849 Mdot
.76 .11905 Mdot
.76 .11942 Mdot
.76 .11985 Mdot
.76 .12024 Mdot
.76 .12138 Mdot
.76 .12171 Mdot
.76 .12205 Mdot
.76 .12216 Mdot
.76 .12253 Mdot
.76 .12289 Mdot
.76 .12343 Mdot
.76 .12416 Mdot
.76 .12471 Mdot
.76 .12481 Mdot
.76 .12495 Mdot
.76 .1252 Mdot
.76 .12521 Mdot
.76 .12558 Mdot
.76 .12584 Mdot
.76 .12625 Mdot
.76 .1263 Mdot
.76 .12663 Mdot
.76 .127 Mdot
.76 .12852 Mdot
.76 .12985 Mdot
.76 .13022 Mdot
.76 .13023 Mdot
.76 .13062 Mdot
.76 .13135 Mdot
.76 .13141 Mdot
.76 .13231 Mdot
.76 .13244 Mdot
.76 .13352 Mdot
.76 .13361 Mdot
.76 .13394 Mdot
.76 .1341 Mdot
.76 .13433 Mdot
.76 .13434 Mdot
.76 .13437 Mdot
.76 .13462 Mdot
.76 .13467 Mdot
.76 .13489 Mdot
.76 .13499 Mdot
.76 .135 Mdot
.76 .13512 Mdot
.76 .13513 Mdot
.76 .13518 Mdot
.76 .13523 Mdot
.76 .1353 Mdot
.76 .13558 Mdot
.76 .13593 Mdot
.76 .13601 Mdot
.76 .13612 Mdot
.76 .13648 Mdot
.76 .13683 Mdot
.76 .13698 Mdot
.76 .1375 Mdot
.76 .13754 Mdot
.76 .13769 Mdot
.76 .13772 Mdot
.76 .13781 Mdot
.76 .13786 Mdot
.76 .13846 Mdot
.76 .13858 Mdot
.76 .14047 Mdot
.76 .14055 Mdot
.76 .14096 Mdot
.76 .14178 Mdot
.76 .14292 Mdot
.76 .14332 Mdot
.76 .14421 Mdot
.76 .14425 Mdot
.76 .14435 Mdot
.76 .14477 Mdot
.76 .14477 Mdot
.76 .14482 Mdot
.76 .1453 Mdot
.76 .14614 Mdot
.76 .14717 Mdot
.76 .14729 Mdot
.76 .14771 Mdot
.76 .1489 Mdot
.76 .14917 Mdot
.76 .14985 Mdot
.76 .15025 Mdot
.76 .1505 Mdot
.76 .15057 Mdot
.76 .15118 Mdot
.76 .1518 Mdot
.76 .1519 Mdot
.76 .15222 Mdot
.76 .15237 Mdot
.76 .15264 Mdot
.76 .15381 Mdot
.76 .15393 Mdot
.76 .15401 Mdot
.76 .15415 Mdot
.76 .15515 Mdot
.76 .15544 Mdot
.76 .15581 Mdot
.76 .15599 Mdot
.76 .15611 Mdot
.76 .15779 Mdot
.76 .15853 Mdot
.76 .15978 Mdot
.76 .15989 Mdot
.76 .16062 Mdot
.76 .16077 Mdot
.76 .16106 Mdot
.76 .16184 Mdot
.76 .16225 Mdot
.76 .16314 Mdot
.76 .16359 Mdot
.76 .16407 Mdot
.76 .16474 Mdot
.76 .16594 Mdot
.76 .16598 Mdot
.76 .16619 Mdot
.76 .16686 Mdot
.76 .16776 Mdot
.76 .16902 Mdot
.76 .171 Mdot
.76 .17106 Mdot
.76 .17123 Mdot
.76 .17166 Mdot
.76 .17248 Mdot
.76 .1729 Mdot
.76 .17369 Mdot
.76 .17475 Mdot
.76 .17646 Mdot
.76 .17673 Mdot
.76 .17681 Mdot
.76 .17755 Mdot
.76 .1788 Mdot
.76 .17918 Mdot
.76 .18112 Mdot
.76 .18155 Mdot
.76 .18172 Mdot
.76 .18211 Mdot
.76 .18269 Mdot
.76 .18306 Mdot
.76 .18343 Mdot
.76 .18401 Mdot
.76 .18756 Mdot
.76 .189 Mdot
.76 .18939 Mdot
.76 .18991 Mdot
.76 .19196 Mdot
.76 .19199 Mdot
.76 .19341 Mdot
.76 .19416 Mdot
.76 .19776 Mdot
.76 .19833 Mdot
.76 .19847 Mdot
.76 .19868 Mdot
.76 .19963 Mdot
.76 .19983 Mdot
.76 .20391 Mdot
.76 .20468 Mdot
.76 .20832 Mdot
.76 .20859 Mdot
.76 .20907 Mdot
.76 .20923 Mdot
.76 .21112 Mdot
.76 .2112 Mdot
.76 .21164 Mdot
.76 .21217 Mdot
.76 .21223 Mdot
.76 .21368 Mdot
.76 .21465 Mdot
.76 .2152 Mdot
.76 .21602 Mdot
.76 .21611 Mdot
.76 .21625 Mdot
.76 .21783 Mdot
.76 .21811 Mdot
.76 .2186 Mdot
.76 .21945 Mdot
.76 .22007 Mdot
.76 .22016 Mdot
.76 .22088 Mdot
.76 .22097 Mdot
.76 .22124 Mdot
.76 .22147 Mdot
.76 .22156 Mdot
.76 .22179 Mdot
.76 .22205 Mdot
.76 .22274 Mdot
.76 .22277 Mdot
.76 .22306 Mdot
.76 .2231 Mdot
.76 .22354 Mdot
.76 .22376 Mdot
.76 .22417 Mdot
.76 .22432 Mdot
.76 .22481 Mdot
.76 .22599 Mdot
.76 .22644 Mdot
.76 .22646 Mdot
.76 .22718 Mdot
.76 .22737 Mdot
.76 .22751 Mdot
.76 .22821 Mdot
.76 .22941 Mdot
.76 .23082 Mdot
.76 .23167 Mdot
.76 .23265 Mdot
.76 .23599 Mdot
.76 .23624 Mdot
.76 .23661 Mdot
.76 .23719 Mdot
.76 .23737 Mdot
.76 .23781 Mdot
.76 .23782 Mdot
.76 .23793 Mdot
.76 .23828 Mdot
.76 .24069 Mdot
.76 .24182 Mdot
.76 .24219 Mdot
.76 .24293 Mdot
.76 .24318 Mdot
.76 .24328 Mdot
.76 .24713 Mdot
.76 .24741 Mdot
.76 .24918 Mdot
.76 .25101 Mdot
.76 .25315 Mdot
.76 .2534 Mdot
.76 .25356 Mdot
.76 .25415 Mdot
.76 .25545 Mdot
.76 .25602 Mdot
.76 .25636 Mdot
.76 .25639 Mdot
.76 .2578 Mdot
.76 .25876 Mdot
.76 .26143 Mdot
.76 .26297 Mdot
.76 .26343 Mdot
.76 .2642 Mdot
.76 .26428 Mdot
.76 .26472 Mdot
.76 .2654 Mdot
.76 .26679 Mdot
.76 .26689 Mdot
.76 .26726 Mdot
.76 .26782 Mdot
.76 .2679 Mdot
.76 .2701 Mdot
.76 .27091 Mdot
.76 .27165 Mdot
.76 .27191 Mdot
.76 .27199 Mdot
.76 .27264 Mdot
.76 .27349 Mdot
.76 .27352 Mdot
.76 .2738 Mdot
.76 .27475 Mdot
.76 .27609 Mdot
.76 .27638 Mdot
.76 .27838 Mdot
.76 .27981 Mdot
.76 .28086 Mdot
.76 .28109 Mdot
.76 .2811 Mdot
.76 .28128 Mdot
.76 .2817 Mdot
.76 .28177 Mdot
.76 .28269 Mdot
.76 .2836 Mdot
.76 .28468 Mdot
.76 .28469 Mdot
.76 .28504 Mdot
.76 .28633 Mdot
.76 .28832 Mdot
.76 .28874 Mdot
.76 .2892 Mdot
.76 .28949 Mdot
.76 .28994 Mdot
.76 .29042 Mdot
.76 .29218 Mdot
.76 .29397 Mdot
.76 .29414 Mdot
.76 .29467 Mdot
.76 .2972 Mdot
.76 .29888 Mdot
.76 .30121 Mdot
.76 .30131 Mdot
.76 .30199 Mdot
.76 .30217 Mdot
.76 .30221 Mdot
.76 .30397 Mdot
.76 .3051 Mdot
.76 .30543 Mdot
.76 .3057 Mdot
.76 .30574 Mdot
.76 .30774 Mdot
.76 .31149 Mdot
.76 .31206 Mdot
.76 .31257 Mdot
.76 .31269 Mdot
.76 .31341 Mdot
.76 .31422 Mdot
.76 .3151 Mdot
.76 .31528 Mdot
.76 .31829 Mdot
.76 .32006 Mdot
.76 .32283 Mdot
.76 .32461 Mdot
.76 .32511 Mdot
.76 .32681 Mdot
.76 .32749 Mdot
.76 .32779 Mdot
.76 .3281 Mdot
.76 .32935 Mdot
.76 .33012 Mdot
.76 .33371 Mdot
.76 .33438 Mdot
.76 .33523 Mdot
.76 .33662 Mdot
.76 .33696 Mdot
.76 .33721 Mdot
.76 .33739 Mdot
.76 .33747 Mdot
.76 .33748 Mdot
.76 .33757 Mdot
.76 .33758 Mdot
.76 .33762 Mdot
.76 .33766 Mdot
.76 .33772 Mdot
.76 .33794 Mdot
.76 .33828 Mdot
.76 .33837 Mdot
.76 .33864 Mdot
.76 .33892 Mdot
.76 .33903 Mdot
.76 .33943 Mdot
.76 .33946 Mdot
.76 .33957 Mdot
.76 .33959 Mdot
.76 .3397 Mdot
.76 .34014 Mdot
.76 .34023 Mdot
.76 .3416 Mdot
.76 .34251 Mdot
.76 .34356 Mdot
.76 .34415 Mdot
.76 .34417 Mdot
.76 .34451 Mdot
.76 .34486 Mdot
.76 .34728 Mdot
.76 .3477 Mdot
.76 .34809 Mdot
.76 .34813 Mdot
.76 .34849 Mdot
.76 .34886 Mdot
.76 .34891 Mdot
.76 .3491 Mdot
.76 .34919 Mdot
.76 .34935 Mdot
.76 .35002 Mdot
.76 .35008 Mdot
.76 .35094 Mdot
.76 .35131 Mdot
.76 .35223 Mdot
.76 .35336 Mdot
.76 .35398 Mdot
.76 .35439 Mdot
.76 .35529 Mdot
.76 .35554 Mdot
.76 .35588 Mdot
.76 .35648 Mdot
.76 .35651 Mdot
.76 .35694 Mdot
.76 .35738 Mdot
.76 .358 Mdot
.76 .35896 Mdot
.76 .35899 Mdot
.76 .35907 Mdot
.76 .35966 Mdot
.76 .35986 Mdot
.76 .36073 Mdot
.76 .36152 Mdot
.76 .36275 Mdot
.76 .36361 Mdot
.76 .3638 Mdot
.76 .36405 Mdot
.76 .36431 Mdot
.76 .36641 Mdot
.76 .36718 Mdot
.76 .3674 Mdot
.76 .36826 Mdot
.76 .36827 Mdot
.76 .36916 Mdot
.76 .37085 Mdot
.76 .37099 Mdot
.76 .37137 Mdot
.76 .37145 Mdot
.76 .37305 Mdot
.76 .37335 Mdot
.76 .37504 Mdot
.76 .37581 Mdot
.76 .37601 Mdot
.76 .37623 Mdot
.76 .37677 Mdot
.76 .37714 Mdot
.76 .37764 Mdot
.76 .37768 Mdot
.76 .37773 Mdot
.76 .37831 Mdot
.76 .37841 Mdot
.76 .37859 Mdot
.76 .3789 Mdot
.76 .37913 Mdot
.76 .37916 Mdot
.76 .37942 Mdot
.76 .37945 Mdot
.76 .37955 Mdot
.76 .37964 Mdot
.76 .37967 Mdot
.76 .37984 Mdot
.76 .3801 Mdot
.76 .38038 Mdot
.76 .38046 Mdot
.76 .38061 Mdot
.76 .38126 Mdot
.76 .38142 Mdot
.76 .38168 Mdot
.76 .38175 Mdot
.76 .38247 Mdot
.76 .38296 Mdot
.76 .38326 Mdot
.76 .3836 Mdot
.76 .38476 Mdot
.76 .38484 Mdot
.76 .38497 Mdot
.76 .38517 Mdot
.76 .38523 Mdot
.76 .38538 Mdot
.76 .38542 Mdot
.76 .38554 Mdot
.76 .38675 Mdot
.76 .38687 Mdot
.76 .38713 Mdot
.76 .38724 Mdot
.76 .38853 Mdot
.76 .38921 Mdot
.76 .39061 Mdot
.76 .39128 Mdot
.76 .39147 Mdot
.76 .39236 Mdot
.76 .39411 Mdot
.76 .39414 Mdot
.76 .39509 Mdot
.76 .39658 Mdot
.76 .39705 Mdot
.76 .39745 Mdot
.76 .39903 Mdot
.76 .39936 Mdot
.76 .39943 Mdot
.76 .39949 Mdot
.76 .39962 Mdot
.76 .39964 Mdot
.76 .40054 Mdot
.76 .40054 Mdot
.76 .40065 Mdot
.76 .40105 Mdot
.76 .40165 Mdot
.76 .40215 Mdot
.76 .4023 Mdot
.76 .40343 Mdot
.76 .40359 Mdot
.76 .40486 Mdot
.76 .40557 Mdot
.76 .4056 Mdot
.76 .40585 Mdot
.76 .40673 Mdot
.76 .40692 Mdot
.76 .40752 Mdot
.76 .40864 Mdot
.76 .40899 Mdot
.76 .40921 Mdot
.76 .40976 Mdot
.76 .41065 Mdot
.76 .41117 Mdot
.76 .41199 Mdot
.76 .41251 Mdot
.76 .41266 Mdot
.76 .41344 Mdot
.76 .41353 Mdot
.76 .4139 Mdot
.76 .41517 Mdot
.76 .41536 Mdot
.76 .41561 Mdot
.76 .41601 Mdot
.76 .41632 Mdot
.76 .4166 Mdot
.76 .41687 Mdot
.76 .41691 Mdot
.76 .4182 Mdot
.76 .41923 Mdot
.76 .41946 Mdot
.76 .41963 Mdot
.76 .4199 Mdot
.76 .42086 Mdot
.76 .42116 Mdot
.76 .4219 Mdot
.76 .42248 Mdot
.76 .42268 Mdot
.76 .42321 Mdot
.76 .42357 Mdot
.76 .42382 Mdot
.76 .42394 Mdot
.76 .42484 Mdot
.76 .4271 Mdot
.76 .42745 Mdot
.76 .42843 Mdot
.76 .42856 Mdot
.76 .42871 Mdot
.76 .42938 Mdot
.76 .42996 Mdot
.76 .43008 Mdot
.76 .43062 Mdot
.76 .43099 Mdot
.76 .43118 Mdot
.76 .43159 Mdot
.76 .4326 Mdot
.76 .43288 Mdot
.76 .43345 Mdot
.76 .43415 Mdot
.76 .43419 Mdot
.76 .43493 Mdot
.76 .43571 Mdot
.76 .43681 Mdot
.76 .4374 Mdot
.76 .43821 Mdot
.76 .43824 Mdot
.76 .43914 Mdot
.76 .43961 Mdot
.76 .44039 Mdot
.76 .44093 Mdot
.76 .44234 Mdot
.76 .44263 Mdot
.76 .44271 Mdot
.76 .44291 Mdot
.76 .44309 Mdot
.76 .44312 Mdot
.76 .44357 Mdot
.76 .44434 Mdot
.76 .44597 Mdot
.76 .44717 Mdot
.76 .44827 Mdot
.76 .44962 Mdot
.76 .45158 Mdot
.76 .45183 Mdot
.76 .45194 Mdot
.76 .45225 Mdot
.76 .45301 Mdot
.76 .45371 Mdot
.76 .45446 Mdot
.76 .4552 Mdot
.76 .45658 Mdot
.76 .4566 Mdot
.76 .45794 Mdot
.76 .45844 Mdot
.76 .45872 Mdot
.76 .45878 Mdot
.76 .45908 Mdot
.76 .45943 Mdot
.76 .45957 Mdot
.76 .46007 Mdot
.76 .4614 Mdot
.76 .46185 Mdot
.76 .46249 Mdot
.76 .46326 Mdot
.76 .4634 Mdot
.76 .46473 Mdot
.76 .46537 Mdot
.76 .46552 Mdot
.76 .46601 Mdot
.76 .46703 Mdot
.76 .46708 Mdot
.76 .46843 Mdot
.76 .46923 Mdot
.76 .46941 Mdot
.76 .46994 Mdot
.76 .47023 Mdot
.76 .47088 Mdot
.76 .47121 Mdot
.76 .47182 Mdot
.76 .47243 Mdot
.76 .4725 Mdot
.76 .47302 Mdot
.76 .4737 Mdot
.76 .47376 Mdot
.76 .47397 Mdot
.76 .47489 Mdot
.76 .47581 Mdot
.76 .47626 Mdot
.76 .47787 Mdot
.76 .47851 Mdot
.76 .47882 Mdot
.76 .4794 Mdot
.76 .47963 Mdot
.76 .48025 Mdot
.76 .48043 Mdot
.76 .48133 Mdot
.76 .48188 Mdot
.76 .48239 Mdot
.76 .48249 Mdot
.76 .48262 Mdot
.76 .48282 Mdot
.76 .48328 Mdot
.76 .48433 Mdot
.76 .48485 Mdot
.76 .48642 Mdot
.76 .48646 Mdot
.76 .48827 Mdot
.76 .48861 Mdot
.76 .48962 Mdot
.76 .48972 Mdot
.76 .4898 Mdot
.76 .49017 Mdot
.76 .4907 Mdot
.76 .49149 Mdot
.76 .49177 Mdot
.76 .49263 Mdot
.76 .49371 Mdot
.76 .49414 Mdot
.76 .49499 Mdot
.76 .49553 Mdot
.76 .4958 Mdot
.76 .49591 Mdot
.76 .49601 Mdot
.76 .49616 Mdot
.76 .49631 Mdot
.76 .49649 Mdot
.76 .49765 Mdot
.76 .49793 Mdot
.76 .49794 Mdot
.76 .49976 Mdot
.76 .49981 Mdot
.76 .50018 Mdot
.76 .50058 Mdot
.76 .501 Mdot
.76 .50156 Mdot
.76 .5019 Mdot
.76 .50217 Mdot
.76 .5036 Mdot
.76 .5039 Mdot
.76 .5044 Mdot
.76 .50452 Mdot
.76 .50464 Mdot
.76 .50558 Mdot
.76 .50577 Mdot
.76 .50647 Mdot
.76 .50755 Mdot
.76 .50824 Mdot
.76 .50941 Mdot
.76 .50947 Mdot
.76 .50981 Mdot
.76 .51012 Mdot
.76 .5104 Mdot
.76 .51045 Mdot
.76 .51064 Mdot
.76 .51086 Mdot
.76 .51229 Mdot
.76 .51305 Mdot
.76 .51306 Mdot
.76 .51317 Mdot
.76 .51329 Mdot
.76 .51372 Mdot
.76 .51439 Mdot
.76 .5144 Mdot
.76 .51447 Mdot
.76 .51472 Mdot
.76 .51476 Mdot
.76 .51563 Mdot
.76 .51626 Mdot
.76 .5172 Mdot
.76 .5174 Mdot
.76 .51746 Mdot
.76 .51812 Mdot
.76 .51877 Mdot
.76 .51895 Mdot
.76 .51911 Mdot
.76 .51922 Mdot
.76 .51939 Mdot
.76 .51955 Mdot
.76 .52027 Mdot
.76 .52075 Mdot
.76 .52088 Mdot
.76 .52088 Mdot
.76 .52127 Mdot
.76 .5216 Mdot
.76 .52194 Mdot
.76 .52196 Mdot
.76 .52211 Mdot
.76 .52218 Mdot
.76 .52218 Mdot
.76 .52227 Mdot
.76 .52265 Mdot
.76 .52316 Mdot
.76 .52389 Mdot
.76 .52399 Mdot
.76 .52447 Mdot
.76 .52481 Mdot
.76 .52491 Mdot
.76 .52492 Mdot
.76 .52523 Mdot
.76 .52546 Mdot
.76 .52549 Mdot
.76 .52558 Mdot
.76 .52584 Mdot
.76 .52613 Mdot
.76 .52691 Mdot
.76 .52694 Mdot
.76 .52714 Mdot
.76 .52727 Mdot
.76 .52731 Mdot
.76 .5278 Mdot
.76 .52804 Mdot
.76 .52819 Mdot
.76 .52822 Mdot
.76 .52849 Mdot
.76 .52866 Mdot
.76 .5292 Mdot
.76 .53013 Mdot
.76 .53047 Mdot
.76 .53096 Mdot
.76 .53097 Mdot
.76 .53109 Mdot
.76 .53128 Mdot
.76 .53174 Mdot
.76 .53194 Mdot
.76 .532 Mdot
.76 .53208 Mdot
.76 .53282 Mdot
.76 .53346 Mdot
.76 .53406 Mdot
.76 .53416 Mdot
.76 .53548 Mdot
.76 .53551 Mdot
.76 .53559 Mdot
.76 .53585 Mdot
.76 .53597 Mdot
.76 .53636 Mdot
.76 .53718 Mdot
.76 .5373 Mdot
.76 .53733 Mdot
.76 .53734 Mdot
.76 .53748 Mdot
.76 .53754 Mdot
.76 .53774 Mdot
.76 .53787 Mdot
.76 .53795 Mdot
.76 .53908 Mdot
.76 .53941 Mdot
.76 .53969 Mdot
.76 .54016 Mdot
.76 .54056 Mdot
.76 .5408 Mdot
.76 .54084 Mdot
.76 .54091 Mdot
.76 .54115 Mdot
.76 .54115 Mdot
.76 .5413 Mdot
.76 .54169 Mdot
.76 .54186 Mdot
.76 .54191 Mdot
.76 .54205 Mdot
.76 .54212 Mdot
.76 .54226 Mdot
.76 .54227 Mdot
.76 .54237 Mdot
.76 .54238 Mdot
.76 .54261 Mdot
.76 .5427 Mdot
.76 .54277 Mdot
.76 .5428 Mdot
.76 .54288 Mdot
.76 .54297 Mdot
.76 .543 Mdot
.76 .54323 Mdot
.76 .54326 Mdot
.76 .54347 Mdot
.76 .54375 Mdot
.76 .54391 Mdot
.76 .544 Mdot
.76 .54452 Mdot
.76 .54457 Mdot
.76 .5446 Mdot
.76 .54487 Mdot
.76 .54504 Mdot
.76 .54536 Mdot
.76 .54584 Mdot
.76 .54586 Mdot
.76 .54603 Mdot
.76 .54617 Mdot
.76 .5462 Mdot
.76 .54682 Mdot
.76 .54686 Mdot
.76 .54702 Mdot
.76 .54711 Mdot
.76 .54829 Mdot
.76 .54854 Mdot
.76 .54985 Mdot
.76 .54991 Mdot
.76 .55022 Mdot
.76 .55029 Mdot
.76 .55033 Mdot
.76 .55051 Mdot
.76 .55166 Mdot
.76 .5519 Mdot
.76 .55235 Mdot
.76 .55236 Mdot
.76 .55301 Mdot
.76 .55318 Mdot
.76 .5533 Mdot
.76 .55376 Mdot
.76 .55487 Mdot
.76 .55506 Mdot
.76 .55517 Mdot
.76 .55529 Mdot
.76 .55547 Mdot
.76 .55559 Mdot
.76 .55565 Mdot
.76 .55578 Mdot
.76 .55639 Mdot
.76 .55651 Mdot
.76 .5569 Mdot
.76 .55713 Mdot
.76 .55715 Mdot
.76 .55723 Mdot
.76 .55777 Mdot
.76 .5581 Mdot
.76 .55834 Mdot
.76 .55847 Mdot
.76 .55873 Mdot
.76 .55886 Mdot
.76 .55891 Mdot
.76 .55893 Mdot
.76 .55954 Mdot
.76 .55993 Mdot
.76 .56021 Mdot
.76 .56041 Mdot
.76 .56048 Mdot
.76 .56049 Mdot
.76 .56086 Mdot
.76 .56106 Mdot
.76 .56121 Mdot
.76 .56135 Mdot
.76 .56162 Mdot
.76 .56175 Mdot
.76 .56198 Mdot
.76 .56207 Mdot
.76 .56212 Mdot
.76 .56234 Mdot
.76 .56237 Mdot
.76 .56276 Mdot
.76 .56298 Mdot
.76 .56349 Mdot
.76 .56353 Mdot
.76 .56358 Mdot
.76 .5637 Mdot
.76 .56379 Mdot
.76 .56409 Mdot
.76 .56413 Mdot
.76 .56416 Mdot
.76 .56419 Mdot
.76 .56454 Mdot
.76 .56463 Mdot
.76 .56467 Mdot
.76 .56477 Mdot
.76 .5648 Mdot
.76 .56499 Mdot
.76 .56517 Mdot
.76 .56519 Mdot
.76 .56527 Mdot
.76 .56539 Mdot
.76 .56559 Mdot
.76 .56567 Mdot
.76 .56603 Mdot
.76 .56616 Mdot
.76 .56619 Mdot
.76 .5665 Mdot
.76 .56676 Mdot
.76 .5669 Mdot
.76 .56691 Mdot
.76 .56691 Mdot
.76 .56704 Mdot
.76 .56707 Mdot
.76 .56708 Mdot
.76 .56735 Mdot
.76 .56747 Mdot
.76 .56781 Mdot
.76 .56805 Mdot
.76 .56817 Mdot
.76 .5682 Mdot
.76 .56876 Mdot
.76 .5688 Mdot
.76 .56898 Mdot
.76 .56899 Mdot
.76 .56902 Mdot
.76 .56903 Mdot
.76 .56907 Mdot
.76 .56908 Mdot
.76 .56924 Mdot
.76 .56928 Mdot
.76 .56939 Mdot
.76 .56949 Mdot
.76 .56953 Mdot
.76 .56955 Mdot
.76 .56965 Mdot
.76 .56974 Mdot
.76 .56976 Mdot
.76 .56977 Mdot
.76 .56979 Mdot
.76 .56979 Mdot
.76 .56983 Mdot
.76 .56983 Mdot
.76 .56986 Mdot
.76 .56992 Mdot
.76 .56994 Mdot
.76 .57001 Mdot
.76 .57002 Mdot
.76 .57002 Mdot
.76 .57009 Mdot
.76 .57014 Mdot
.76 .57024 Mdot
.76 .57026 Mdot
.76 .57058 Mdot
.76 .57062 Mdot
.76 .57089 Mdot
.76 .57091 Mdot
.76 .57112 Mdot
.76 .57124 Mdot
.76 .57124 Mdot
.76 .57135 Mdot
.76 .57174 Mdot
.76 .57219 Mdot
.76 .57229 Mdot
.76 .57239 Mdot
.76 .57241 Mdot
.76 .57252 Mdot
.76 .5726 Mdot
.76 .57271 Mdot
.76 .57271 Mdot
.76 .57279 Mdot
.76 .57283 Mdot
.76 .57286 Mdot
.76 .57302 Mdot
.76 .57323 Mdot
.76 .57339 Mdot
.76 .57349 Mdot
.76 .5736 Mdot
.76 .57364 Mdot
.76 .57374 Mdot
.76 .57383 Mdot
.76 .57416 Mdot
.76 .57428 Mdot
.76 .5744 Mdot
.76 .57451 Mdot
.76 .57467 Mdot
.76 .57468 Mdot
.76 .57475 Mdot
.76 .57476 Mdot
.76 .57477 Mdot
.76 .57481 Mdot
.76 .57483 Mdot
.76 .57489 Mdot
.76 .5749 Mdot
.76 .57494 Mdot
.76 .57497 Mdot
.76 .57498 Mdot
.76 .57498 Mdot
.76 .57498 Mdot
.76 .575 Mdot
.76 .575 Mdot
.76 .57501 Mdot
.76 .57503 Mdot
.76 .57506 Mdot
.762 .11637 Mdot
.762 .11637 Mdot
.762 .11638 Mdot
.762 .1164 Mdot
.762 .11641 Mdot
.762 .11647 Mdot
.762 .11651 Mdot
.762 .11651 Mdot
.762 .11654 Mdot
.762 .11667 Mdot
.762 .11673 Mdot
.762 .11691 Mdot
.762 .11697 Mdot
.762 .11727 Mdot
.762 .11748 Mdot
.762 .11758 Mdot
.762 .11765 Mdot
.762 .11776 Mdot
.762 .11816 Mdot
.762 .11831 Mdot
.762 .11837 Mdot
.762 .11851 Mdot
.762 .11897 Mdot
.762 .11919 Mdot
.762 .11935 Mdot
.762 .11938 Mdot
.762 .11966 Mdot
.762 .11972 Mdot
.762 .11994 Mdot
.762 .12048 Mdot
.762 .1207 Mdot
.762 .12086 Mdot
.762 .12124 Mdot
.762 .12128 Mdot
.762 .12149 Mdot
.762 .12168 Mdot
.762 .12172 Mdot
.762 .12325 Mdot
.762 .12376 Mdot
.762 .12411 Mdot
.762 .12609 Mdot
.762 .12633 Mdot
.762 .1267 Mdot
.762 .12693 Mdot
.762 .12745 Mdot
.762 .12858 Mdot
.762 .13003 Mdot
.762 .13016 Mdot
.762 .13142 Mdot
.762 .13143 Mdot
.762 .13145 Mdot
.762 .13152 Mdot
.762 .13152 Mdot
.762 .13168 Mdot
.762 .13172 Mdot
.762 .13183 Mdot
.762 .13183 Mdot
.762 .13191 Mdot
.762 .13229 Mdot
.762 .13232 Mdot
.762 .13247 Mdot
.762 .13289 Mdot
.762 .133 Mdot
.762 .13317 Mdot
.762 .13319 Mdot
.762 .13361 Mdot
.762 .1341 Mdot
.762 .13453 Mdot
.762 .13475 Mdot
.762 .13504 Mdot
.762 .13505 Mdot
.762 .13527 Mdot
.762 .13528 Mdot
.762 .13561 Mdot
.762 .13562 Mdot
.762 .13657 Mdot
.762 .13694 Mdot
.762 .13741 Mdot
.762 .13762 Mdot
.762 .13783 Mdot
.762 .13787 Mdot
.762 .13808 Mdot
.762 .13869 Mdot
.762 .13966 Mdot
.762 .14043 Mdot
.762 .14062 Mdot
.762 .14084 Mdot
.762 .141 Mdot
.762 .1411 Mdot
.762 .14118 Mdot
.762 .14144 Mdot
.762 .1417 Mdot
.762 .14212 Mdot
.762 .14213 Mdot
.762 .1422 Mdot
.762 .14234 Mdot
.762 .1429 Mdot
.762 .14315 Mdot
.762 .14332 Mdot
.762 .1439 Mdot
.762 .14429 Mdot
.762 .14505 Mdot
.762 .14516 Mdot
.762 .14603 Mdot
.762 .14659 Mdot
.762 .14664 Mdot
.762 .1469 Mdot
.762 .14692 Mdot
.762 .1472 Mdot
.762 .14816 Mdot
.762 .14832 Mdot
.762 .14844 Mdot
.762 .14861 Mdot
.762 .14916 Mdot
.762 .14938 Mdot
.762 .14953 Mdot
.762 .1499 Mdot
.762 .14999 Mdot
.762 .15 Mdot
.762 .15006 Mdot
.762 .15028 Mdot
.762 .15046 Mdot
.762 .15299 Mdot
.762 .15341 Mdot
.762 .15448 Mdot
.762 .15467 Mdot
.762 .15554 Mdot
.762 .15573 Mdot
.762 .15658 Mdot
.762 .15771 Mdot
.762 .15885 Mdot
.762 .16016 Mdot
.762 .16026 Mdot
.762 .16036 Mdot
.762 .16045 Mdot
.762 .16053 Mdot
.762 .16103 Mdot
.762 .16257 Mdot
.762 .16331 Mdot
.762 .16444 Mdot
.762 .16484 Mdot
.762 .16569 Mdot
.762 .16585 Mdot
.762 .16804 Mdot
.762 .16911 Mdot
.762 .16962 Mdot
.762 .16983 Mdot
.762 .17056 Mdot
.762 .17095 Mdot
.762 .17106 Mdot
.762 .1724 Mdot
.762 .17275 Mdot
.762 .17282 Mdot
.762 .17291 Mdot
.762 .17399 Mdot
.762 .17407 Mdot
.762 .17521 Mdot
.762 .17597 Mdot
.762 .17671 Mdot
.762 .17836 Mdot
.762 .17883 Mdot
.762 .17982 Mdot
.762 .18265 Mdot
.762 .18766 Mdot
.762 .18855 Mdot
.762 .19059 Mdot
.762 .19068 Mdot
.762 .19135 Mdot
.762 .19232 Mdot
.762 .19538 Mdot
.762 .19646 Mdot
.762 .19848 Mdot
.762 .19856 Mdot
.762 .19864 Mdot
.762 .19905 Mdot
.762 .1991 Mdot
.762 .19999 Mdot
.762 .20013 Mdot
.762 .20025 Mdot
.762 .20068 Mdot
.762 .20086 Mdot
.762 .20087 Mdot
.762 .20135 Mdot
.762 .20199 Mdot
.762 .20271 Mdot
.762 .20359 Mdot
.762 .20377 Mdot
.762 .20385 Mdot
.762 .20463 Mdot
.762 .20562 Mdot
.762 .206 Mdot
.762 .20681 Mdot
.762 .20711 Mdot
.762 .20776 Mdot
.762 .20791 Mdot
.762 .20881 Mdot
.762 .20891 Mdot
.762 .20936 Mdot
.762 .21 Mdot
.762 .21083 Mdot
.762 .21147 Mdot
.762 .21444 Mdot
.762 .21709 Mdot
.762 .21754 Mdot
.762 .21813 Mdot
.762 .21846 Mdot
.762 .21881 Mdot
.762 .22021 Mdot
.762 .22032 Mdot
.762 .22066 Mdot
.762 .22138 Mdot
.762 .22168 Mdot
.762 .22171 Mdot
.762 .22198 Mdot
.762 .22203 Mdot
.762 .2226 Mdot
.762 .22381 Mdot
.762 .22384 Mdot
.762 .22454 Mdot
.762 .22578 Mdot
.762 .22914 Mdot
.762 .22962 Mdot
.762 .22987 Mdot
.762 .23039 Mdot
.762 .23223 Mdot
.762 .23239 Mdot
.762 .23432 Mdot
.762 .23529 Mdot
.762 .23665 Mdot
.762 .23798 Mdot
.762 .238 Mdot
.762 .23822 Mdot
.762 .23848 Mdot
.762 .2394 Mdot
.762 .23961 Mdot
.762 .24362 Mdot
.762 .24394 Mdot
.762 .24549 Mdot
.762 .24622 Mdot
.762 .24768 Mdot
.762 .25004 Mdot
.762 .25131 Mdot
.762 .25515 Mdot
.762 .25535 Mdot
.762 .25644 Mdot
.762 .25735 Mdot
.762 .2579 Mdot
.762 .25793 Mdot
.762 .25896 Mdot
.762 .25941 Mdot
.762 .25966 Mdot
.762 .26018 Mdot
.762 .26125 Mdot
.762 .26176 Mdot
.762 .26196 Mdot
.762 .26291 Mdot
.762 .26371 Mdot
.762 .26397 Mdot
.762 .26405 Mdot
.762 .26416 Mdot
.762 .26654 Mdot
.762 .26665 Mdot
.762 .26713 Mdot
.762 .26724 Mdot
.762 .26784 Mdot
.762 .26808 Mdot
.762 .26966 Mdot
.762 .26982 Mdot
.762 .27065 Mdot
.762 .27076 Mdot
.762 .27171 Mdot
.762 .2719 Mdot
.762 .27336 Mdot
.762 .27361 Mdot
.762 .274 Mdot
.762 .27474 Mdot
.762 .27508 Mdot
.762 .27544 Mdot
.762 .27876 Mdot
.762 .27994 Mdot
.762 .28034 Mdot
.762 .28108 Mdot
.762 .28143 Mdot
.762 .28215 Mdot
.762 .28271 Mdot
.762 .28405 Mdot
.762 .28554 Mdot
.762 .28666 Mdot
.762 .28743 Mdot
.762 .29351 Mdot
.762 .29384 Mdot
.762 .29421 Mdot
.762 .29739 Mdot
.762 .29776 Mdot
.762 .29954 Mdot
.762 .29969 Mdot
.762 .30165 Mdot
.762 .30409 Mdot
.762 .30624 Mdot
.762 .30778 Mdot
.762 .30836 Mdot
.762 .30904 Mdot
.762 .30948 Mdot
.762 .31031 Mdot
.762 .3112 Mdot
.762 .31155 Mdot
.762 .31155 Mdot
.762 .3127 Mdot
.762 .31305 Mdot
.762 .3142 Mdot
.762 .31539 Mdot
.762 .31609 Mdot
.762 .31659 Mdot
.762 .31691 Mdot
.762 .31799 Mdot
.762 .31881 Mdot
.762 .31982 Mdot
.762 .32058 Mdot
.762 .32118 Mdot
.762 .32129 Mdot
.762 .32169 Mdot
.762 .3226 Mdot
.762 .32297 Mdot
.762 .32322 Mdot
.762 .32388 Mdot
.762 .32446 Mdot
.762 .32662 Mdot
.762 .32726 Mdot
.762 .32769 Mdot
.762 .32994 Mdot
.762 .33021 Mdot
.762 .33084 Mdot
.762 .33385 Mdot
.762 .3351 Mdot
.762 .33511 Mdot
.762 .33512 Mdot
.762 .33518 Mdot
.762 .33519 Mdot
.762 .33536 Mdot
.762 .33545 Mdot
.762 .33545 Mdot
.762 .33553 Mdot
.762 .33585 Mdot
.762 .336 Mdot
.762 .33635 Mdot
.762 .33644 Mdot
.762 .33659 Mdot
.762 .33735 Mdot
.762 .33787 Mdot
.762 .33811 Mdot
.762 .33828 Mdot
.762 .33828 Mdot
.762 .33854 Mdot
.762 .33855 Mdot
.762 .33955 Mdot
.762 .33991 Mdot
.762 .34006 Mdot
.762 .34022 Mdot
.762 .34024 Mdot
.762 .3404 Mdot
.762 .34085 Mdot
.762 .34154 Mdot
.762 .34208 Mdot
.762 .34221 Mdot
.762 .34236 Mdot
.762 .34247 Mdot
.762 .34254 Mdot
.762 .34278 Mdot
.762 .34323 Mdot
.762 .34324 Mdot
.762 .34339 Mdot
.762 .34376 Mdot
.762 .34393 Mdot
.762 .34516 Mdot
.762 .34523 Mdot
.762 .34578 Mdot
.762 .34617 Mdot
.762 .34634 Mdot
.762 .34651 Mdot
.762 .3471 Mdot
.762 .3472 Mdot
.762 .34771 Mdot
.762 .34784 Mdot
.762 .34793 Mdot
.762 .34815 Mdot
.762 .3482 Mdot
.762 .34825 Mdot
.762 .34848 Mdot
.762 .35196 Mdot
.762 .35257 Mdot
.762 .35318 Mdot
.762 .35393 Mdot
.762 .35403 Mdot
.762 .3555 Mdot
.762 .3567 Mdot
.762 .35872 Mdot
.762 .35926 Mdot
.762 .35931 Mdot
.762 .35994 Mdot
.762 .36018 Mdot
.762 .36072 Mdot
.762 .36125 Mdot
.762 .36193 Mdot
.762 .36333 Mdot
.762 .36458 Mdot
.762 .3671 Mdot
.762 .36795 Mdot
.762 .36827 Mdot
.762 .36867 Mdot
.762 .36991 Mdot
.762 .37116 Mdot
.762 .37119 Mdot
.762 .37122 Mdot
.762 .37138 Mdot
.762 .3714 Mdot
.762 .37176 Mdot
.762 .37186 Mdot
.762 .37203 Mdot
.762 .3721 Mdot
.762 .3721 Mdot
.762 .37229 Mdot
.762 .37283 Mdot
.762 .37317 Mdot
.762 .37324 Mdot
.762 .37327 Mdot
.762 .37357 Mdot
.762 .37395 Mdot
.762 .37452 Mdot
.762 .37477 Mdot
.762 .37483 Mdot
.762 .37517 Mdot
.762 .37521 Mdot
.762 .37538 Mdot
.762 .37562 Mdot
.762 .37593 Mdot
.762 .37617 Mdot
.762 .37728 Mdot
.762 .37825 Mdot
.762 .37876 Mdot
.762 .37888 Mdot
.762 .37939 Mdot
.762 .37943 Mdot
.762 .37992 Mdot
.762 .37993 Mdot
.762 .38025 Mdot
.762 .38069 Mdot
.762 .3807 Mdot
.762 .38095 Mdot
.762 .38257 Mdot
.762 .38283 Mdot
.762 .38301 Mdot
.762 .38365 Mdot
.762 .38438 Mdot
.762 .38471 Mdot
.762 .38518 Mdot
.762 .38563 Mdot
.762 .38571 Mdot
.762 .38611 Mdot
.762 .38619 Mdot
.762 .38754 Mdot
.762 .38968 Mdot
.762 .39009 Mdot
.762 .39135 Mdot
.762 .39142 Mdot
.762 .39177 Mdot
.762 .39207 Mdot
.762 .39225 Mdot
.762 .39259 Mdot
.762 .39273 Mdot
.762 .39281 Mdot
.762 .39298 Mdot
.762 .39333 Mdot
.762 .39355 Mdot
.762 .39386 Mdot
.762 .39411 Mdot
.762 .39426 Mdot
.762 .39502 Mdot
.762 .39505 Mdot
.762 .3952 Mdot
.762 .39524 Mdot
.762 .39551 Mdot
.762 .39671 Mdot
.762 .39717 Mdot
.762 .39725 Mdot
.762 .3976 Mdot
.762 .39885 Mdot
.762 .39934 Mdot
.762 .39968 Mdot
.762 .40007 Mdot
.762 .40129 Mdot
.762 .40152 Mdot
.762 .40338 Mdot
.762 .40347 Mdot
.762 .40455 Mdot
.762 .40466 Mdot
.762 .40519 Mdot
.762 .40524 Mdot
.762 .40583 Mdot
.762 .40766 Mdot
.762 .40783 Mdot
.762 .40817 Mdot
.762 .40841 Mdot
.762 .40878 Mdot
.762 .40878 Mdot
.762 .40956 Mdot
.762 .40991 Mdot
.762 .41036 Mdot
.762 .41068 Mdot
.762 .41144 Mdot
.762 .41162 Mdot
.762 .41165 Mdot
.762 .41177 Mdot
.762 .41214 Mdot
.762 .41222 Mdot
.762 .41258 Mdot
.762 .41321 Mdot
.762 .41352 Mdot
.762 .41661 Mdot
.762 .41774 Mdot
.762 .41819 Mdot
.762 .4186 Mdot
.762 .41937 Mdot
.762 .42073 Mdot
.762 .42112 Mdot
.762 .42192 Mdot
.762 .42285 Mdot
.762 .42323 Mdot
.762 .42383 Mdot
.762 .42491 Mdot
.762 .42536 Mdot
.762 .42633 Mdot
.762 .42655 Mdot
.762 .42688 Mdot
.762 .42713 Mdot
.762 .42729 Mdot
.762 .42829 Mdot
.762 .42869 Mdot
.762 .42889 Mdot
.762 .42935 Mdot
.762 .42987 Mdot
.762 .43152 Mdot
.762 .4319 Mdot
.762 .43208 Mdot
.762 .43228 Mdot
.762 .43245 Mdot
.762 .4326 Mdot
.762 .43272 Mdot
.762 .433 Mdot
.762 .43356 Mdot
.762 .43418 Mdot
.762 .4344 Mdot
.762 .4366 Mdot
.762 .43692 Mdot
.762 .43715 Mdot
.762 .4379 Mdot
.762 .4383 Mdot
.762 .44001 Mdot
.762 .44076 Mdot
.762 .44178 Mdot
.762 .44213 Mdot
.762 .44223 Mdot
.762 .44235 Mdot
.762 .44265 Mdot
.762 .44276 Mdot
.762 .44311 Mdot
.762 .4444 Mdot
.762 .44446 Mdot
.762 .44668 Mdot
.762 .44678 Mdot
.762 .44681 Mdot
.762 .44749 Mdot
.762 .44819 Mdot
.762 .44862 Mdot
.762 .44915 Mdot
.762 .44954 Mdot
.762 .44991 Mdot
.762 .44993 Mdot
.762 .4512 Mdot
.762 .45123 Mdot
.762 .45193 Mdot
.762 .45212 Mdot
.762 .45241 Mdot
.762 .45246 Mdot
.762 .45265 Mdot
.762 .4545 Mdot
.762 .45512 Mdot
.762 .45524 Mdot
.762 .45541 Mdot
.762 .45657 Mdot
.762 .45668 Mdot
.762 .4573 Mdot
.762 .45744 Mdot
.762 .45892 Mdot
.762 .45942 Mdot
.762 .45953 Mdot
.762 .45973 Mdot
.762 .46024 Mdot
.762 .46045 Mdot
.762 .46062 Mdot
.762 .46073 Mdot
.762 .46122 Mdot
.762 .462 Mdot
.762 .46296 Mdot
.762 .46423 Mdot
.762 .46482 Mdot
.762 .4656 Mdot
.762 .46712 Mdot
.762 .46727 Mdot
.762 .46779 Mdot
.762 .46904 Mdot
.762 .46942 Mdot
.762 .46996 Mdot
.762 .47195 Mdot
.762 .47356 Mdot
.762 .4739 Mdot
.762 .47492 Mdot
.762 .47581 Mdot
.762 .47627 Mdot
.762 .47645 Mdot
.762 .47669 Mdot
.762 .47697 Mdot
.762 .47727 Mdot
.762 .47757 Mdot
.762 .47818 Mdot
.762 .47999 Mdot
.762 .48077 Mdot
.762 .48138 Mdot
.762 .48158 Mdot
.762 .4823 Mdot
.762 .48261 Mdot
.762 .48322 Mdot
.762 .48453 Mdot
.762 .48466 Mdot
.762 .48477 Mdot
.762 .48501 Mdot
.762 .4854 Mdot
.762 .48569 Mdot
.762 .48589 Mdot
.762 .48623 Mdot
.762 .48716 Mdot
.762 .4877 Mdot
.762 .48837 Mdot
.762 .48999 Mdot
.762 .49088 Mdot
.762 .49143 Mdot
.762 .49172 Mdot
.762 .4928 Mdot
.762 .4933 Mdot
.762 .49396 Mdot
.762 .49453 Mdot
.762 .49622 Mdot
.762 .49633 Mdot
.762 .49645 Mdot
.762 .49648 Mdot
.762 .49703 Mdot
.762 .4971 Mdot
.762 .49759 Mdot
.762 .49816 Mdot
.762 .49837 Mdot
.762 .49856 Mdot
.762 .49873 Mdot
.762 .49879 Mdot
.762 .49934 Mdot
.762 .49959 Mdot
.762 .4996 Mdot
.762 .50028 Mdot
.762 .50038 Mdot
.762 .50116 Mdot
.762 .50216 Mdot
.762 .50336 Mdot
.762 .50361 Mdot
.762 .50372 Mdot
.762 .50461 Mdot
.762 .50478 Mdot
.762 .50504 Mdot
.762 .50588 Mdot
.762 .50611 Mdot
.762 .50637 Mdot
.762 .50647 Mdot
.762 .50661 Mdot
.762 .50697 Mdot
.762 .50712 Mdot
.762 .50717 Mdot
.762 .5074 Mdot
.762 .50769 Mdot
.762 .50809 Mdot
.762 .5084 Mdot
.762 .50883 Mdot
.762 .50895 Mdot
.762 .50914 Mdot
.762 .50941 Mdot
.762 .50987 Mdot
.762 .51031 Mdot
.762 .51044 Mdot
.762 .51089 Mdot
.762 .51089 Mdot
.762 .51102 Mdot
.762 .51136 Mdot
.762 .51168 Mdot
.762 .51184 Mdot
.762 .5121 Mdot
.762 .51233 Mdot
.762 .51291 Mdot
.762 .51372 Mdot
.762 .51464 Mdot
.762 .51538 Mdot
.762 .51543 Mdot
.762 .51609 Mdot
.762 .51623 Mdot
.762 .51741 Mdot
.762 .51755 Mdot
.762 .51767 Mdot
.762 .51991 Mdot
.762 .52019 Mdot
.762 .5206 Mdot
.762 .52115 Mdot
.762 .52164 Mdot
.762 .52184 Mdot
.762 .5221 Mdot
.762 .52223 Mdot
.762 .5225 Mdot
.762 .52264 Mdot
.762 .52307 Mdot
.762 .52426 Mdot
.762 .52439 Mdot
.762 .52451 Mdot
.762 .52478 Mdot
.762 .52492 Mdot
.762 .52501 Mdot
.762 .52553 Mdot
.762 .5256 Mdot
.762 .52593 Mdot
.762 .52597 Mdot
.762 .52627 Mdot
.762 .52633 Mdot
.762 .52689 Mdot
.762 .52697 Mdot
.762 .52718 Mdot
.762 .52722 Mdot
.762 .52739 Mdot
.762 .52743 Mdot
.762 .52827 Mdot
.762 .52831 Mdot
.762 .52834 Mdot
.762 .52843 Mdot
.762 .52871 Mdot
.762 .52905 Mdot
.762 .52912 Mdot
.762 .52929 Mdot
.762 .52967 Mdot
.762 .52985 Mdot
.762 .52994 Mdot
.762 .5301 Mdot
.762 .53046 Mdot
.762 .53047 Mdot
.762 .53066 Mdot
.762 .53098 Mdot
.762 .53135 Mdot
.762 .53143 Mdot
.762 .53276 Mdot
.762 .53319 Mdot
.762 .534 Mdot
.762 .5345 Mdot
.762 .53476 Mdot
.762 .53529 Mdot
.762 .53539 Mdot
.762 .53676 Mdot
.762 .53683 Mdot
.762 .53714 Mdot
.762 .53723 Mdot
.762 .5373 Mdot
.762 .53731 Mdot
.762 .53776 Mdot
.762 .53822 Mdot
.762 .53854 Mdot
.762 .53919 Mdot
.762 .53925 Mdot
.762 .53987 Mdot
.762 .54004 Mdot
.762 .54012 Mdot
.762 .54028 Mdot
.762 .5414 Mdot
.762 .54181 Mdot
.762 .54205 Mdot
.762 .54206 Mdot
.762 .54246 Mdot
.762 .54265 Mdot
.762 .54266 Mdot
.762 .54275 Mdot
.762 .54276 Mdot
.762 .54286 Mdot
.762 .5431 Mdot
.762 .54321 Mdot
.762 .54325 Mdot
.762 .54371 Mdot
.762 .54382 Mdot
.762 .54393 Mdot
.762 .54412 Mdot
.762 .54427 Mdot
.762 .54514 Mdot
.762 .54611 Mdot
.762 .54632 Mdot
.762 .54659 Mdot
.762 .5468 Mdot
.762 .54694 Mdot
.762 .54698 Mdot
.762 .54727 Mdot
.762 .54732 Mdot
.762 .54753 Mdot
.762 .54762 Mdot
.762 .54789 Mdot
.762 .54801 Mdot
.762 .54833 Mdot
.762 .54858 Mdot
.762 .54861 Mdot
.762 .54867 Mdot
.762 .54895 Mdot
.762 .54918 Mdot
.762 .54939 Mdot
.762 .54954 Mdot
.762 .54954 Mdot
.762 .5496 Mdot
.762 .54974 Mdot
.762 .54978 Mdot
.762 .54982 Mdot
.762 .55011 Mdot
.762 .55013 Mdot
.762 .55026 Mdot
.762 .55028 Mdot
.762 .55031 Mdot
.762 .55095 Mdot
.762 .5513 Mdot
.762 .55227 Mdot
.762 .55258 Mdot
.762 .55279 Mdot
.762 .55282 Mdot
.762 .55346 Mdot
.762 .55375 Mdot
.762 .55532 Mdot
.762 .55621 Mdot
.762 .55652 Mdot
.762 .55666 Mdot
.762 .55718 Mdot
.762 .55741 Mdot
.762 .55765 Mdot
.762 .558 Mdot
.762 .55803 Mdot
.762 .55836 Mdot
.762 .55839 Mdot
.762 .55841 Mdot
.762 .55852 Mdot
.762 .55893 Mdot
.762 .55897 Mdot
.762 .55909 Mdot
.762 .55931 Mdot
.762 .55938 Mdot
.762 .55953 Mdot
.762 .55986 Mdot
.762 .56054 Mdot
.762 .56059 Mdot
.762 .56085 Mdot
.762 .56097 Mdot
.762 .56131 Mdot
.762 .56154 Mdot
.762 .56201 Mdot
.762 .56217 Mdot
.762 .56219 Mdot
.762 .56222 Mdot
.762 .56225 Mdot
.762 .56228 Mdot
.762 .56268 Mdot
.762 .56303 Mdot
.762 .56337 Mdot
.762 .56363 Mdot
.762 .56368 Mdot
.762 .56395 Mdot
.762 .56401 Mdot
.762 .56433 Mdot
.762 .56446 Mdot
.762 .56522 Mdot
.762 .56527 Mdot
.762 .56534 Mdot
.762 .56536 Mdot
.762 .56536 Mdot
.762 .56539 Mdot
.762 .5655 Mdot
.762 .56555 Mdot
.762 .56561 Mdot
.762 .56578 Mdot
.762 .56583 Mdot
.762 .56587 Mdot
.762 .56591 Mdot
.762 .5662 Mdot
.762 .56629 Mdot
.762 .56629 Mdot
.762 .56637 Mdot
.762 .56638 Mdot
.762 .56655 Mdot
.762 .56681 Mdot
.762 .56685 Mdot
.762 .56707 Mdot
.762 .56719 Mdot
.762 .56736 Mdot
.762 .56741 Mdot
.762 .56749 Mdot
.762 .56766 Mdot
.762 .5677 Mdot
.762 .56772 Mdot
.762 .56772 Mdot
.762 .56785 Mdot
.762 .56793 Mdot
.762 .568 Mdot
.762 .56803 Mdot
.762 .56806 Mdot
.762 .56811 Mdot
.762 .56817 Mdot
.762 .56823 Mdot
.762 .56846 Mdot
.762 .56874 Mdot
.762 .56893 Mdot
.762 .56899 Mdot
.762 .569 Mdot
.762 .56906 Mdot
.762 .56912 Mdot
.762 .56927 Mdot
.762 .56938 Mdot
.762 .56966 Mdot
.762 .56966 Mdot
.762 .56976 Mdot
.762 .56976 Mdot
.762 .56982 Mdot
.762 .56983 Mdot
.762 .56991 Mdot
.762 .56998 Mdot
.762 .57011 Mdot
.762 .57025 Mdot
.762 .57038 Mdot
.762 .57038 Mdot
.762 .57043 Mdot
.762 .57047 Mdot
.762 .57059 Mdot
.762 .57063 Mdot
.762 .57064 Mdot
.762 .57075 Mdot
.762 .57078 Mdot
.762 .57078 Mdot
.762 .57081 Mdot
.762 .57082 Mdot
.762 .57087 Mdot
.762 .57087 Mdot
.762 .57089 Mdot
.762 .5709 Mdot
.762 .5709 Mdot
.762 .57127 Mdot
.762 .57131 Mdot
.762 .57174 Mdot
.762 .57207 Mdot
.762 .57222 Mdot
.762 .57229 Mdot
.762 .57239 Mdot
.762 .57247 Mdot
.762 .57304 Mdot
.762 .57315 Mdot
.762 .5733 Mdot
.762 .57375 Mdot
.762 .57376 Mdot
.762 .57381 Mdot
.762 .57387 Mdot
.762 .57388 Mdot
.762 .574 Mdot
.762 .57404 Mdot
.762 .57411 Mdot
.762 .57426 Mdot
.762 .57433 Mdot
.762 .57434 Mdot
.762 .57443 Mdot
.762 .57444 Mdot
.762 .57448 Mdot
.762 .57455 Mdot
.762 .57468 Mdot
.762 .57472 Mdot
.762 .57474 Mdot
.762 .57478 Mdot
.762 .5749 Mdot
.762 .57493 Mdot
.762 .57495 Mdot
.762 .57498 Mdot
.762 .57504 Mdot
.762 .57513 Mdot
.762 .57514 Mdot
.762 .5752 Mdot
.762 .57521 Mdot
.762 .57525 Mdot
.762 .57526 Mdot
.762 .57526 Mdot
.762 .57527 Mdot
.762 .57529 Mdot
.762 .57529 Mdot
.762 .5753 Mdot
.762 .5753 Mdot
.762 .5753 Mdot
.764 .1156 Mdot
.764 .1156 Mdot
.764 .1156 Mdot
.764 .11561 Mdot
.764 .1157 Mdot
.764 .11572 Mdot
.764 .11574 Mdot
.764 .11587 Mdot
.764 .11595 Mdot
.764 .11608 Mdot
.764 .11629 Mdot
.764 .11642 Mdot
.764 .11654 Mdot
.764 .11664 Mdot
.764 .1167 Mdot
.764 .11708 Mdot
.764 .11717 Mdot
.764 .11719 Mdot
.764 .11729 Mdot
.764 .11733 Mdot
.764 .11733 Mdot
.764 .11859 Mdot
.764 .11876 Mdot
.764 .11878 Mdot
.764 .11892 Mdot
.764 .1203 Mdot
.764 .12031 Mdot
.764 .12066 Mdot
.764 .12109 Mdot
.764 .12181 Mdot
.764 .12238 Mdot
.764 .12294 Mdot
.764 .12337 Mdot
.764 .12376 Mdot
.764 .12434 Mdot
.764 .12452 Mdot
.764 .12468 Mdot
.764 .12503 Mdot
.764 .12508 Mdot
.764 .12645 Mdot
.764 .12712 Mdot
.764 .12728 Mdot
.764 .12737 Mdot
.764 .12743 Mdot
.764 .1287 Mdot
.764 .1287 Mdot
.764 .1287 Mdot
.764 .12873 Mdot
.764 .12897 Mdot
.764 .12902 Mdot
.764 .12906 Mdot
.764 .12942 Mdot
.764 .12966 Mdot
.764 .13 Mdot
.764 .13038 Mdot
.764 .1306 Mdot
.764 .13099 Mdot
.764 .13115 Mdot
.764 .13125 Mdot
.764 .13133 Mdot
.764 .13162 Mdot
.764 .13165 Mdot
.764 .13168 Mdot
.764 .13179 Mdot
.764 .1318 Mdot
.764 .13206 Mdot
.764 .13295 Mdot
.764 .13296 Mdot
.764 .13316 Mdot
.764 .13321 Mdot
.764 .13328 Mdot
.764 .13337 Mdot
.764 .13358 Mdot
.764 .1337 Mdot
.764 .13372 Mdot
.764 .1338 Mdot
.764 .1341 Mdot
.764 .13469 Mdot
.764 .13471 Mdot
.764 .13495 Mdot
.764 .13506 Mdot
.764 .13768 Mdot
.764 .13782 Mdot
.764 .13784 Mdot
.764 .1379 Mdot
.764 .13818 Mdot
.764 .13839 Mdot
.764 .13848 Mdot
.764 .13849 Mdot
.764 .13888 Mdot
.764 .13896 Mdot
.764 .13911 Mdot
.764 .14124 Mdot
.764 .14173 Mdot
.764 .14212 Mdot
.764 .14248 Mdot
.764 .14305 Mdot
.764 .14368 Mdot
.764 .1437 Mdot
.764 .144 Mdot
.764 .14402 Mdot
.764 .14402 Mdot
.764 .1442 Mdot
.764 .14422 Mdot
.764 .14443 Mdot
.764 .14454 Mdot
.764 .14537 Mdot
.764 .1454 Mdot
.764 .14556 Mdot
.764 .14658 Mdot
.764 .14704 Mdot
.764 .14744 Mdot
.764 .1479 Mdot
.764 .14859 Mdot
.764 .14949 Mdot
.764 .14997 Mdot
.764 .15061 Mdot
.764 .15072 Mdot
.764 .15235 Mdot
.764 .1534 Mdot
.764 .15358 Mdot
.764 .15366 Mdot
.764 .15417 Mdot
.764 .15475 Mdot
.764 .15479 Mdot
.764 .15503 Mdot
.764 .15573 Mdot
.764 .15668 Mdot
.764 .15671 Mdot
.764 .15839 Mdot
.764 .15988 Mdot
.764 .15995 Mdot
.764 .16032 Mdot
.764 .16105 Mdot
.764 .16114 Mdot
.764 .16158 Mdot
.764 .16192 Mdot
.764 .16268 Mdot
.764 .16425 Mdot
.764 .16431 Mdot
.764 .16454 Mdot
.764 .1649 Mdot
.764 .16651 Mdot
.764 .16695 Mdot
.764 .16973 Mdot
.764 .16979 Mdot
.764 .17126 Mdot
.764 .1735 Mdot
.764 .17382 Mdot
.764 .17468 Mdot
.764 .17512 Mdot
.764 .17549 Mdot
.764 .17596 Mdot
.764 .17627 Mdot
.764 .17759 Mdot
.764 .17959 Mdot
.764 .18253 Mdot
.764 .18298 Mdot
.764 .18302 Mdot
.764 .18302 Mdot
.764 .18315 Mdot
.764 .18373 Mdot
.764 .18446 Mdot
.764 .18475 Mdot
.764 .18496 Mdot
.764 .18646 Mdot
.764 .18694 Mdot
.764 .18826 Mdot
.764 .18874 Mdot
.764 .18888 Mdot
.764 .18938 Mdot
.764 .18981 Mdot
.764 .19016 Mdot
.764 .19016 Mdot
.764 .19076 Mdot
.764 .19228 Mdot
.764 .19354 Mdot
.764 .19406 Mdot
.764 .19432 Mdot
.764 .19481 Mdot
.764 .19574 Mdot
.764 .1967 Mdot
.764 .19725 Mdot
.764 .19773 Mdot
.764 .19777 Mdot
.764 .19936 Mdot
.764 .19939 Mdot
.764 .19957 Mdot
.764 .19975 Mdot
.764 .20039 Mdot
.764 .20047 Mdot
.764 .2012 Mdot
.764 .2019 Mdot
.764 .20199 Mdot
.764 .20315 Mdot
.764 .20728 Mdot
.764 .20731 Mdot
.764 .2078 Mdot
.764 .20851 Mdot
.764 .20885 Mdot
.764 .20924 Mdot
.764 .20979 Mdot
.764 .21001 Mdot
.764 .21002 Mdot
.764 .21106 Mdot
.764 .21169 Mdot
.764 .21181 Mdot
.764 .21191 Mdot
.764 .21231 Mdot
.764 .21239 Mdot
.764 .21343 Mdot
.764 .21345 Mdot
.764 .21423 Mdot
.764 .21532 Mdot
.764 .21673 Mdot
.764 .21681 Mdot
.764 .21787 Mdot
.764 .218 Mdot
.764 .21844 Mdot
.764 .21949 Mdot
.764 .21957 Mdot
.764 .22023 Mdot
.764 .22049 Mdot
.764 .22074 Mdot
.764 .22088 Mdot
.764 .22156 Mdot
.764 .22186 Mdot
.764 .22439 Mdot
.764 .22582 Mdot
.764 .22714 Mdot
.764 .23198 Mdot
.764 .23693 Mdot
.764 .23784 Mdot
.764 .23794 Mdot
.764 .23833 Mdot
.764 .23866 Mdot
.764 .23907 Mdot
.764 .24021 Mdot
.764 .24155 Mdot
.764 .24218 Mdot
.764 .24218 Mdot
.764 .24479 Mdot
.764 .24528 Mdot
.764 .24555 Mdot
.764 .24628 Mdot
.764 .25014 Mdot
.764 .25058 Mdot
.764 .25154 Mdot
.764 .25322 Mdot
.764 .25727 Mdot
.764 .25904 Mdot
.764 .26059 Mdot
.764 .26171 Mdot
.764 .2639 Mdot
.764 .26394 Mdot
.764 .26654 Mdot
.764 .26668 Mdot
.764 .26898 Mdot
.764 .26905 Mdot
.764 .26971 Mdot
.764 .27024 Mdot
.764 .27065 Mdot
.764 .27219 Mdot
.764 .27281 Mdot
.764 .27294 Mdot
.764 .27328 Mdot
.764 .27407 Mdot
.764 .27457 Mdot
.764 .2749 Mdot
.764 .27637 Mdot
.764 .27703 Mdot
.764 .27723 Mdot
.764 .27728 Mdot
.764 .27739 Mdot
.764 .27944 Mdot
.764 .27962 Mdot
.764 .27964 Mdot
.764 .28034 Mdot
.764 .28068 Mdot
.764 .28085 Mdot
.764 .28101 Mdot
.764 .28198 Mdot
.764 .2821 Mdot
.764 .28244 Mdot
.764 .28252 Mdot
.764 .2832 Mdot
.764 .28593 Mdot
.764 .28599 Mdot
.764 .28624 Mdot
.764 .28692 Mdot
.764 .28837 Mdot
.764 .28842 Mdot
.764 .2888 Mdot
.764 .28898 Mdot
.764 .2892 Mdot
.764 .29033 Mdot
.764 .29086 Mdot
.764 .29332 Mdot
.764 .29395 Mdot
.764 .29448 Mdot
.764 .29449 Mdot
.764 .29707 Mdot
.764 .29712 Mdot
.764 .29744 Mdot
.764 .30057 Mdot
.764 .30063 Mdot
.764 .30086 Mdot
.764 .30219 Mdot
.764 .30252 Mdot
.764 .30294 Mdot
.764 .30346 Mdot
.764 .30503 Mdot
.764 .30667 Mdot
.764 .30855 Mdot
.764 .30857 Mdot
.764 .30933 Mdot
.764 .3098 Mdot
.764 .31117 Mdot
.764 .3115 Mdot
.764 .31249 Mdot
.764 .31364 Mdot
.764 .31605 Mdot
.764 .31772 Mdot
.764 .31782 Mdot
.764 .31783 Mdot
.764 .32122 Mdot
.764 .32571 Mdot
.764 .32646 Mdot
.764 .32816 Mdot
.764 .33195 Mdot
.764 .33331 Mdot
.764 .33332 Mdot
.764 .33332 Mdot
.764 .33334 Mdot
.764 .33357 Mdot
.764 .33362 Mdot
.764 .33365 Mdot
.764 .33398 Mdot
.764 .3342 Mdot
.764 .3345 Mdot
.764 .33503 Mdot
.764 .33537 Mdot
.764 .33566 Mdot
.764 .33591 Mdot
.764 .33596 Mdot
.764 .33606 Mdot
.764 .33628 Mdot
.764 .33701 Mdot
.764 .33723 Mdot
.764 .33728 Mdot
.764 .33752 Mdot
.764 .33762 Mdot
.764 .33763 Mdot
.764 .33793 Mdot
.764 .33869 Mdot
.764 .34074 Mdot
.764 .34115 Mdot
.764 .34122 Mdot
.764 .34122 Mdot
.764 .3415 Mdot
.764 .34155 Mdot
.764 .34372 Mdot
.764 .34433 Mdot
.764 .34474 Mdot
.764 .34495 Mdot
.764 .34496 Mdot
.764 .34496 Mdot
.764 .34508 Mdot
.764 .34529 Mdot
.764 .34582 Mdot
.764 .34594 Mdot
.764 .34657 Mdot
.764 .34685 Mdot
.764 .3471 Mdot
.764 .34861 Mdot
.764 .34999 Mdot
.764 .35058 Mdot
.764 .35069 Mdot
.764 .35073 Mdot
.764 .35101 Mdot
.764 .35134 Mdot
.764 .35187 Mdot
.764 .35239 Mdot
.764 .35241 Mdot
.764 .35331 Mdot
.764 .35432 Mdot
.764 .3547 Mdot
.764 .35474 Mdot
.764 .35497 Mdot
.764 .35515 Mdot
.764 .35553 Mdot
.764 .35635 Mdot
.764 .35646 Mdot
.764 .35664 Mdot
.764 .35766 Mdot
.764 .35903 Mdot
.764 .35972 Mdot
.764 .36091 Mdot
.764 .36131 Mdot
.764 .36151 Mdot
.764 .36168 Mdot
.764 .36189 Mdot
.764 .36203 Mdot
.764 .36263 Mdot
.764 .36352 Mdot
.764 .365 Mdot
.764 .36502 Mdot
.764 .36502 Mdot
.764 .36508 Mdot
.764 .36533 Mdot
.764 .36564 Mdot
.764 .36577 Mdot
.764 .36586 Mdot
.764 .36669 Mdot
.764 .36725 Mdot
.764 .36751 Mdot
.764 .36772 Mdot
.764 .36804 Mdot
.764 .36804 Mdot
.764 .36829 Mdot
.764 .36891 Mdot
.764 .36943 Mdot
.764 .36964 Mdot
.764 .36974 Mdot
.764 .36994 Mdot
.764 .37032 Mdot
.764 .3707 Mdot
.764 .37092 Mdot
.764 .37111 Mdot
.764 .37113 Mdot
.764 .37177 Mdot
.764 .37184 Mdot
.764 .37191 Mdot
.764 .37216 Mdot
.764 .37219 Mdot
.764 .37279 Mdot
.764 .37482 Mdot
.764 .37483 Mdot
.764 .37502 Mdot
.764 .37529 Mdot
.764 .37542 Mdot
.764 .37556 Mdot
.764 .37577 Mdot
.764 .37625 Mdot
.764 .37653 Mdot
.764 .37656 Mdot
.764 .37671 Mdot
.764 .37674 Mdot
.764 .37713 Mdot
.764 .37713 Mdot
.764 .37742 Mdot
.764 .37834 Mdot
.764 .37837 Mdot
.764 .37876 Mdot
.764 .3788 Mdot
.764 .37934 Mdot
.764 .37961 Mdot
.764 .37979 Mdot
.764 .37985 Mdot
.764 .38161 Mdot
.764 .38207 Mdot
.764 .38376 Mdot
.764 .38546 Mdot
.764 .38577 Mdot
.764 .38581 Mdot
.764 .38594 Mdot
.764 .38619 Mdot
.764 .38658 Mdot
.764 .38703 Mdot
.764 .38724 Mdot
.764 .38724 Mdot
.764 .38811 Mdot
.764 .38828 Mdot
.764 .38837 Mdot
.764 .38861 Mdot
.764 .38988 Mdot
.764 .39003 Mdot
.764 .39035 Mdot
.764 .39278 Mdot
.764 .39328 Mdot
.764 .39434 Mdot
.764 .39435 Mdot
.764 .39518 Mdot
.764 .39522 Mdot
.764 .39595 Mdot
.764 .39597 Mdot
.764 .39634 Mdot
.764 .39696 Mdot
.764 .39719 Mdot
.764 .3977 Mdot
.764 .39826 Mdot
.764 .39853 Mdot
.764 .39858 Mdot
.764 .39921 Mdot
.764 .39927 Mdot
.764 .39927 Mdot
.764 .39949 Mdot
.764 .39965 Mdot
.764 .3997 Mdot
.764 .4 Mdot
.764 .40014 Mdot
.764 .40037 Mdot
.764 .40121 Mdot
.764 .40151 Mdot
.764 .40195 Mdot
.764 .40197 Mdot
.764 .40208 Mdot
.764 .40214 Mdot
.764 .4022 Mdot
.764 .40255 Mdot
.764 .40346 Mdot
.764 .40364 Mdot
.764 .40381 Mdot
.764 .4047 Mdot
.764 .40565 Mdot
.764 .4065 Mdot
.764 .40746 Mdot
.764 .40839 Mdot
.764 .40889 Mdot
.764 .41075 Mdot
.764 .41175 Mdot
.764 .41306 Mdot
.764 .41328 Mdot
.764 .41378 Mdot
.764 .41661 Mdot
.764 .41858 Mdot
.764 .41874 Mdot
.764 .41892 Mdot
.764 .41911 Mdot
.764 .41926 Mdot
.764 .42029 Mdot
.764 .42038 Mdot
.764 .42063 Mdot
.764 .42146 Mdot
.764 .42152 Mdot
.764 .422 Mdot
.764 .42268 Mdot
.764 .4234 Mdot
.764 .42512 Mdot
.764 .42527 Mdot
.764 .42534 Mdot
.764 .42573 Mdot
.764 .42581 Mdot
.764 .42615 Mdot
.764 .42775 Mdot
.764 .42823 Mdot
.764 .42864 Mdot
.764 .429 Mdot
.764 .43047 Mdot
.764 .43153 Mdot
.764 .43167 Mdot
.764 .43237 Mdot
.764 .43282 Mdot
.764 .43339 Mdot
.764 .43378 Mdot
.764 .43394 Mdot
.764 .43445 Mdot
.764 .4348 Mdot
.764 .43545 Mdot
.764 .43555 Mdot
.764 .43687 Mdot
.764 .43984 Mdot
.764 .43995 Mdot
.764 .44037 Mdot
.764 .44105 Mdot
.764 .44194 Mdot
.764 .44197 Mdot
.764 .44268 Mdot
.764 .44405 Mdot
.764 .44486 Mdot
.764 .44678 Mdot
.764 .447 Mdot
.764 .44991 Mdot
.764 .45003 Mdot
.764 .45226 Mdot
.764 .45264 Mdot
.764 .45266 Mdot
.764 .45605 Mdot
.764 .45663 Mdot
.764 .45718 Mdot
.764 .45748 Mdot
.764 .4587 Mdot
.764 .45945 Mdot
.764 .45985 Mdot
.764 .46009 Mdot
.764 .46091 Mdot
.764 .46108 Mdot
.764 .46112 Mdot
.764 .46143 Mdot
.764 .46266 Mdot
.764 .46369 Mdot
.764 .46381 Mdot
.764 .46454 Mdot
.764 .46471 Mdot
.764 .46707 Mdot
.764 .46969 Mdot
.764 .47187 Mdot
.764 .47195 Mdot
.764 .47204 Mdot
.764 .47269 Mdot
.764 .47274 Mdot
.764 .47275 Mdot
.764 .47296 Mdot
.764 .4731 Mdot
.764 .47367 Mdot
.764 .47391 Mdot
.764 .47448 Mdot
.764 .47474 Mdot
.764 .47509 Mdot
.764 .47537 Mdot
.764 .47556 Mdot
.764 .47589 Mdot
.764 .4763 Mdot
.764 .47702 Mdot
.764 .47813 Mdot
.764 .47828 Mdot
.764 .47835 Mdot
.764 .47904 Mdot
.764 .48002 Mdot
.764 .48112 Mdot
.764 .48187 Mdot
.764 .48208 Mdot
.764 .48232 Mdot
.764 .48286 Mdot
.764 .48289 Mdot
.764 .48352 Mdot
.764 .48353 Mdot
.764 .48406 Mdot
.764 .48407 Mdot
.764 .48425 Mdot
.764 .48499 Mdot
.764 .48669 Mdot
.764 .48721 Mdot
.764 .4873 Mdot
.764 .48734 Mdot
.764 .48792 Mdot
.764 .48803 Mdot
.764 .48817 Mdot
.764 .48826 Mdot
.764 .4892 Mdot
.764 .48997 Mdot
.764 .49035 Mdot
.764 .49083 Mdot
.764 .49108 Mdot
.764 .49188 Mdot
.764 .49245 Mdot
.764 .49288 Mdot
.764 .49358 Mdot
.764 .49368 Mdot
.764 .49386 Mdot
.764 .49465 Mdot
.764 .49487 Mdot
.764 .49523 Mdot
.764 .49535 Mdot
.764 .49537 Mdot
.764 .49541 Mdot
.764 .49685 Mdot
.764 .49706 Mdot
.764 .49732 Mdot
.764 .49759 Mdot
.764 .49768 Mdot
.764 .49772 Mdot
.764 .49781 Mdot
.764 .49798 Mdot
.764 .49823 Mdot
.764 .49913 Mdot
.764 .49925 Mdot
.764 .50027 Mdot
.764 .50058 Mdot
.764 .50124 Mdot
.764 .50137 Mdot
.764 .50297 Mdot
.764 .50448 Mdot
.764 .50515 Mdot
.764 .50544 Mdot
.764 .5072 Mdot
.764 .50852 Mdot
.764 .50852 Mdot
.764 .50856 Mdot
.764 .50921 Mdot
.764 .51013 Mdot
.764 .51057 Mdot
.764 .51095 Mdot
.764 .51108 Mdot
.764 .5116 Mdot
.764 .51178 Mdot
.764 .51207 Mdot
.764 .51208 Mdot
.764 .51279 Mdot
.764 .51341 Mdot
.764 .514 Mdot
.764 .5142 Mdot
.764 .51436 Mdot
.764 .51448 Mdot
.764 .51498 Mdot
.764 .51507 Mdot
.764 .51509 Mdot
.764 .51626 Mdot
.764 .51638 Mdot
.764 .5164 Mdot
.764 .51736 Mdot
.764 .51736 Mdot
.764 .51756 Mdot
.764 .51779 Mdot
.764 .5187 Mdot
.764 .51889 Mdot
.764 .51931 Mdot
.764 .51939 Mdot
.764 .51945 Mdot
.764 .51959 Mdot
.764 .51961 Mdot
.764 .52014 Mdot
.764 .52039 Mdot
.764 .52048 Mdot
.764 .5205 Mdot
.764 .5215 Mdot
.764 .52175 Mdot
.764 .52178 Mdot
.764 .5219 Mdot
.764 .52194 Mdot
.764 .52229 Mdot
.764 .52235 Mdot
.764 .52241 Mdot
.764 .52254 Mdot
.764 .52279 Mdot
.764 .5228 Mdot
.764 .52286 Mdot
.764 .5236 Mdot
.764 .52364 Mdot
.764 .52366 Mdot
.764 .52373 Mdot
.764 .52397 Mdot
.764 .52449 Mdot
.764 .52461 Mdot
.764 .52479 Mdot
.764 .52507 Mdot
.764 .5252 Mdot
.764 .52524 Mdot
.764 .52546 Mdot
.764 .52601 Mdot
.764 .52616 Mdot
.764 .52635 Mdot
.764 .52658 Mdot
.764 .5266 Mdot
.764 .52742 Mdot
.764 .52747 Mdot
.764 .52839 Mdot
.764 .5284 Mdot
.764 .52917 Mdot
.764 .52956 Mdot
.764 .53011 Mdot
.764 .53072 Mdot
.764 .53213 Mdot
.764 .53271 Mdot
.764 .53304 Mdot
.764 .53319 Mdot
.764 .53452 Mdot
.764 .53477 Mdot
.764 .53486 Mdot
.764 .53503 Mdot
.764 .53592 Mdot
.764 .53592 Mdot
.764 .53613 Mdot
.764 .53659 Mdot
.764 .53697 Mdot
.764 .53711 Mdot
.764 .53722 Mdot
.764 .53735 Mdot
.764 .53739 Mdot
.764 .5377 Mdot
.764 .53936 Mdot
.764 .54098 Mdot
.764 .54142 Mdot
.764 .54189 Mdot
.764 .54273 Mdot
.764 .54283 Mdot
.764 .54305 Mdot
.764 .5431 Mdot
.764 .54318 Mdot
.764 .54327 Mdot
.764 .54349 Mdot
.764 .54351 Mdot
.764 .54386 Mdot
.764 .544 Mdot
.764 .54405 Mdot
.764 .54439 Mdot
.764 .54442 Mdot
.764 .54488 Mdot
.764 .54524 Mdot
.764 .54549 Mdot
.764 .5455 Mdot
.764 .54584 Mdot
.764 .54587 Mdot
.764 .54599 Mdot
.764 .54603 Mdot
.764 .54607 Mdot
.764 .54627 Mdot
.764 .54661 Mdot
.764 .54661 Mdot
.764 .54669 Mdot
.764 .54686 Mdot
.764 .54699 Mdot
.764 .5471 Mdot
.764 .54733 Mdot
.764 .54749 Mdot
.764 .5475 Mdot
.764 .54883 Mdot
.764 .54921 Mdot
.764 .54924 Mdot
.764 .54946 Mdot
.764 .54969 Mdot
.764 .54972 Mdot
.764 .54993 Mdot
.764 .54998 Mdot
.764 .55004 Mdot
.764 .55005 Mdot
.764 .55056 Mdot
.764 .55057 Mdot
.764 .55073 Mdot
.764 .5509 Mdot
.764 .55121 Mdot
.764 .5515 Mdot
.764 .55166 Mdot
.764 .55174 Mdot
.764 .55191 Mdot
.764 .55231 Mdot
.764 .55279 Mdot
.764 .55298 Mdot
.764 .55298 Mdot
.764 .55309 Mdot
.764 .55323 Mdot
.764 .55339 Mdot
.764 .55343 Mdot
.764 .55358 Mdot
.764 .554 Mdot
.764 .55415 Mdot
.764 .55462 Mdot
.764 .55468 Mdot
.764 .55478 Mdot
.764 .55501 Mdot
.764 .55519 Mdot
.764 .55523 Mdot
.764 .55523 Mdot
.764 .55524 Mdot
.764 .55538 Mdot
.764 .5563 Mdot
.764 .55693 Mdot
.764 .55734 Mdot
.764 .55743 Mdot
.764 .55758 Mdot
.764 .55769 Mdot
.764 .55783 Mdot
.764 .5581 Mdot
.764 .5582 Mdot
.764 .55889 Mdot
.764 .55934 Mdot
.764 .55936 Mdot
.764 .56022 Mdot
.764 .56035 Mdot
.764 .56085 Mdot
.764 .56096 Mdot
.764 .56103 Mdot
.764 .56105 Mdot
.764 .56153 Mdot
.764 .56176 Mdot
.764 .56186 Mdot
.764 .562 Mdot
.764 .56202 Mdot
.764 .56225 Mdot
.764 .56236 Mdot
.764 .56238 Mdot
.764 .56284 Mdot
.764 .56335 Mdot
.764 .56336 Mdot
.764 .56364 Mdot
.764 .56386 Mdot
.764 .56393 Mdot
.764 .56394 Mdot
.764 .56412 Mdot
.764 .56427 Mdot
.764 .56429 Mdot
.764 .56435 Mdot
.764 .56467 Mdot
.764 .56516 Mdot
.764 .56519 Mdot
.764 .56539 Mdot
.764 .56553 Mdot
.764 .5658 Mdot
.764 .56601 Mdot
.764 .56615 Mdot
.764 .56627 Mdot
.764 .5664 Mdot
.764 .56671 Mdot
.764 .56676 Mdot
.764 .56677 Mdot
.764 .56702 Mdot
.764 .56705 Mdot
.764 .56711 Mdot
.764 .56712 Mdot
.764 .56717 Mdot
.764 .56717 Mdot
.764 .56718 Mdot
.764 .56727 Mdot
.764 .56727 Mdot
.764 .56746 Mdot
.764 .56763 Mdot
.764 .56774 Mdot
.764 .56786 Mdot
.764 .568 Mdot
.764 .56864 Mdot
.764 .56868 Mdot
.764 .5687 Mdot
.764 .56882 Mdot
.764 .56882 Mdot
.764 .56885 Mdot
.764 .56891 Mdot
.764 .569 Mdot
.764 .56901 Mdot
.764 .56902 Mdot
.764 .56906 Mdot
.764 .56984 Mdot
.764 .56987 Mdot
.764 .56994 Mdot
.764 .56995 Mdot
.764 .57012 Mdot
.764 .57021 Mdot
.764 .57023 Mdot
.764 .57024 Mdot
.764 .57028 Mdot
.764 .57034 Mdot
.764 .57037 Mdot
.764 .57038 Mdot
.764 .5704 Mdot
.764 .57046 Mdot
.764 .57046 Mdot
.764 .57072 Mdot
.764 .5708 Mdot
.764 .5708 Mdot
.764 .57084 Mdot
.764 .57085 Mdot
.764 .57085 Mdot
.764 .57094 Mdot
.764 .57096 Mdot
.764 .57099 Mdot
.764 .57104 Mdot
.764 .57115 Mdot
.764 .57122 Mdot
.764 .57133 Mdot
.764 .57143 Mdot
.764 .5715 Mdot
.764 .57161 Mdot
.764 .57162 Mdot
.764 .57163 Mdot
.764 .57171 Mdot
.764 .57171 Mdot
.764 .57171 Mdot
.764 .57171 Mdot
.764 .57209 Mdot
.764 .5721 Mdot
.764 .57213 Mdot
.764 .57218 Mdot
.764 .57238 Mdot
.764 .57278 Mdot
.764 .57279 Mdot
.764 .57289 Mdot
.764 .57294 Mdot
.764 .57299 Mdot
.764 .57316 Mdot
.764 .57328 Mdot
.764 .5734 Mdot
.764 .57357 Mdot
.764 .57373 Mdot
.764 .57394 Mdot
.764 .57407 Mdot
.764 .57417 Mdot
.764 .57417 Mdot
.764 .57457 Mdot
.764 .57461 Mdot
.764 .57462 Mdot
.764 .57467 Mdot
.764 .57503 Mdot
.764 .57504 Mdot
.764 .57505 Mdot
.764 .57508 Mdot
.764 .57508 Mdot
.764 .57511 Mdot
.764 .57522 Mdot
.764 .57524 Mdot
.764 .57526 Mdot
.764 .5753 Mdot
.764 .57534 Mdot
.764 .5754 Mdot
.764 .57543 Mdot
.764 .57546 Mdot
.764 .5755 Mdot
.764 .5755 Mdot
.764 .57551 Mdot
.764 .57553 Mdot
.764 .57554 Mdot
.764 .57554 Mdot
.764 .57554 Mdot
.766 .11483 Mdot
.766 .11483 Mdot
.766 .11486 Mdot
.766 .11487 Mdot
.766 .11487 Mdot
.766 .11491 Mdot
.766 .11493 Mdot
.766 .11493 Mdot
.766 .11495 Mdot
.766 .11497 Mdot
.766 .11549 Mdot
.766 .11557 Mdot
.766 .11565 Mdot
.766 .11582 Mdot
.766 .11599 Mdot
.766 .11611 Mdot
.766 .11645 Mdot
.766 .11685 Mdot
.766 .117 Mdot
.766 .11767 Mdot
.766 .11824 Mdot
.766 .11849 Mdot
.766 .11861 Mdot
.766 .12022 Mdot
.766 .1205 Mdot
.766 .12104 Mdot
.766 .12123 Mdot
.766 .1213 Mdot
.766 .12141 Mdot
.766 .12283 Mdot
.766 .12301 Mdot
.766 .12318 Mdot
.766 .12361 Mdot
.766 .12426 Mdot
.766 .12459 Mdot
.766 .12504 Mdot
.766 .12542 Mdot
.766 .12607 Mdot
.766 .12607 Mdot
.766 .12608 Mdot
.766 .12608 Mdot
.766 .12617 Mdot
.766 .1262 Mdot
.766 .1262 Mdot
.766 .12628 Mdot
.766 .12634 Mdot
.766 .12634 Mdot
.766 .1264 Mdot
.766 .12644 Mdot
.766 .12708 Mdot
.766 .1278 Mdot
.766 .12801 Mdot
.766 .12823 Mdot
.766 .12868 Mdot
.766 .12868 Mdot
.766 .12897 Mdot
.766 .12909 Mdot
.766 .12917 Mdot
.766 .1295 Mdot
.766 .13001 Mdot
.766 .13046 Mdot
.766 .13108 Mdot
.766 .13166 Mdot
.766 .13166 Mdot
.766 .13197 Mdot
.766 .13212 Mdot
.766 .13216 Mdot
.766 .13329 Mdot
.766 .13369 Mdot
.766 .13381 Mdot
.766 .13422 Mdot
.766 .13481 Mdot
.766 .13534 Mdot
.766 .13608 Mdot
.766 .13627 Mdot
.766 .13658 Mdot
.766 .13694 Mdot
.766 .13733 Mdot
.766 .13776 Mdot
.766 .13949 Mdot
.766 .14161 Mdot
.766 .14235 Mdot
.766 .14265 Mdot
.766 .14265 Mdot
.766 .14288 Mdot
.766 .14316 Mdot
.766 .14425 Mdot
.766 .14435 Mdot
.766 .14539 Mdot
.766 .14636 Mdot
.766 .14681 Mdot
.766 .14686 Mdot
.766 .14714 Mdot
.766 .1474 Mdot
.766 .14786 Mdot
.766 .14791 Mdot
.766 .14801 Mdot
.766 .14822 Mdot
.766 .14916 Mdot
.766 .14924 Mdot
.766 .15155 Mdot
.766 .15267 Mdot
.766 .15296 Mdot
.766 .15375 Mdot
.766 .15383 Mdot
.766 .15412 Mdot
.766 .15436 Mdot
.766 .15453 Mdot
.766 .15462 Mdot
.766 .15536 Mdot
.766 .1557 Mdot
.766 .15571 Mdot
.766 .15582 Mdot
.766 .15732 Mdot
.766 .15788 Mdot
.766 .15912 Mdot
.766 .1597 Mdot
.766 .16027 Mdot
.766 .16092 Mdot
.766 .16182 Mdot
.766 .16316 Mdot
.766 .16353 Mdot
.766 .16386 Mdot
.766 .16397 Mdot
.766 .16578 Mdot
.766 .16595 Mdot
.766 .16752 Mdot
.766 .16898 Mdot
.766 .16901 Mdot
.766 .16905 Mdot
.766 .16905 Mdot
.766 .16947 Mdot
.766 .16952 Mdot
.766 .16962 Mdot
.766 .16963 Mdot
.766 .17004 Mdot
.766 .17009 Mdot
.766 .17034 Mdot
.766 .17035 Mdot
.766 .17065 Mdot
.766 .17084 Mdot
.766 .17272 Mdot
.766 .17413 Mdot
.766 .17458 Mdot
.766 .17468 Mdot
.766 .17644 Mdot
.766 .17675 Mdot
.766 .17789 Mdot
.766 .17848 Mdot
.766 .179 Mdot
.766 .17927 Mdot
.766 .18016 Mdot
.766 .18102 Mdot
.766 .18256 Mdot
.766 .18259 Mdot
.766 .18276 Mdot
.766 .18417 Mdot
.766 .18479 Mdot
.766 .18483 Mdot
.766 .18493 Mdot
.766 .18528 Mdot
.766 .18598 Mdot
.766 .18698 Mdot
.766 .1899 Mdot
.766 .19112 Mdot
.766 .19128 Mdot
.766 .19224 Mdot
.766 .19236 Mdot
.766 .19247 Mdot
.766 .19249 Mdot
.766 .19324 Mdot
.766 .19599 Mdot
.766 .19603 Mdot
.766 .19659 Mdot
.766 .19738 Mdot
.766 .19745 Mdot
.766 .19941 Mdot
.766 .19941 Mdot
.766 .20121 Mdot
.766 .20124 Mdot
.766 .20171 Mdot
.766 .20211 Mdot
.766 .20235 Mdot
.766 .20238 Mdot
.766 .20318 Mdot
.766 .20519 Mdot
.766 .20905 Mdot
.766 .20912 Mdot
.766 .2092 Mdot
.766 .21137 Mdot
.766 .21155 Mdot
.766 .21228 Mdot
.766 .21451 Mdot
.766 .21482 Mdot
.766 .2165 Mdot
.766 .21845 Mdot
.766 .21949 Mdot
.766 .22056 Mdot
.766 .22179 Mdot
.766 .2227 Mdot
.766 .22485 Mdot
.766 .22648 Mdot
.766 .22709 Mdot
.766 .22767 Mdot
.766 .22888 Mdot
.766 .22896 Mdot
.766 .22907 Mdot
.766 .22972 Mdot
.766 .23056 Mdot
.766 .23058 Mdot
.766 .23199 Mdot
.766 .23456 Mdot
.766 .23512 Mdot
.766 .23578 Mdot
.766 .23733 Mdot
.766 .23809 Mdot
.766 .23956 Mdot
.766 .24226 Mdot
.766 .24231 Mdot
.766 .24377 Mdot
.766 .24486 Mdot
.766 .24679 Mdot
.766 .24681 Mdot
.766 .24712 Mdot
.766 .24737 Mdot
.766 .24878 Mdot
.766 .24883 Mdot
.766 .25105 Mdot
.766 .25147 Mdot
.766 .25284 Mdot
.766 .25436 Mdot
.766 .25471 Mdot
.766 .25548 Mdot
.766 .25854 Mdot
.766 .25977 Mdot
.766 .26191 Mdot
.766 .26305 Mdot
.766 .26573 Mdot
.766 .26653 Mdot
.766 .26686 Mdot
.766 .2673 Mdot
.766 .2681 Mdot
.766 .26943 Mdot
.766 .27016 Mdot
.766 .27022 Mdot
.766 .27085 Mdot
.766 .27175 Mdot
.766 .2724 Mdot
.766 .27334 Mdot
.766 .27369 Mdot
.766 .27417 Mdot
.766 .27681 Mdot
.766 .28015 Mdot
.766 .28121 Mdot
.766 .28195 Mdot
.766 .28654 Mdot
.766 .2876 Mdot
.766 .28808 Mdot
.766 .28916 Mdot
.766 .28966 Mdot
.766 .29007 Mdot
.766 .29184 Mdot
.766 .29199 Mdot
.766 .29207 Mdot
.766 .29233 Mdot
.766 .29308 Mdot
.766 .29601 Mdot
.766 .29916 Mdot
.766 .29951 Mdot
.766 .30051 Mdot
.766 .30145 Mdot
.766 .30295 Mdot
.766 .30325 Mdot
.766 .30356 Mdot
.766 .3065 Mdot
.766 .30687 Mdot
.766 .30757 Mdot
.766 .30759 Mdot
.766 .30893 Mdot
.766 .30905 Mdot
.766 .31025 Mdot
.766 .31089 Mdot
.766 .31116 Mdot
.766 .3114 Mdot
.766 .31567 Mdot
.766 .31624 Mdot
.766 .3203 Mdot
.766 .32137 Mdot
.766 .32182 Mdot
.766 .32455 Mdot
.766 .32817 Mdot
.766 .32959 Mdot
.766 .33083 Mdot
.766 .33149 Mdot
.766 .33151 Mdot
.766 .33151 Mdot
.766 .33159 Mdot
.766 .33162 Mdot
.766 .33162 Mdot
.766 .3317 Mdot
.766 .33176 Mdot
.766 .33177 Mdot
.766 .33182 Mdot
.766 .33186 Mdot
.766 .33249 Mdot
.766 .33318 Mdot
.766 .33337 Mdot
.766 .33357 Mdot
.766 .33398 Mdot
.766 .33399 Mdot
.766 .33425 Mdot
.766 .33436 Mdot
.766 .33443 Mdot
.766 .33472 Mdot
.766 .33516 Mdot
.766 .33556 Mdot
.766 .33657 Mdot
.766 .33657 Mdot
.766 .33694 Mdot
.766 .33697 Mdot
.766 .33819 Mdot
.766 .33829 Mdot
.766 .33861 Mdot
.766 .33906 Mdot
.766 .33946 Mdot
.766 .34001 Mdot
.766 .34015 Mdot
.766 .34038 Mdot
.766 .34063 Mdot
.766 .34092 Mdot
.766 .34244 Mdot
.766 .34454 Mdot
.766 .34455 Mdot
.766 .34487 Mdot
.766 .34556 Mdot
.766 .34688 Mdot
.766 .34715 Mdot
.766 .34735 Mdot
.766 .34751 Mdot
.766 .34778 Mdot
.766 .348 Mdot
.766 .34855 Mdot
.766 .35057 Mdot
.766 .35122 Mdot
.766 .35137 Mdot
.766 .3516 Mdot
.766 .35165 Mdot
.766 .35205 Mdot
.766 .35224 Mdot
.766 .35224 Mdot
.766 .3531 Mdot
.766 .3534 Mdot
.766 .35405 Mdot
.766 .35435 Mdot
.766 .35465 Mdot
.766 .35545 Mdot
.766 .3563 Mdot
.766 .35647 Mdot
.766 .35652 Mdot
.766 .35742 Mdot
.766 .3575 Mdot
.766 .35896 Mdot
.766 .35898 Mdot
.766 .35899 Mdot
.766 .359 Mdot
.766 .3592 Mdot
.766 .35922 Mdot
.766 .35927 Mdot
.766 .35927 Mdot
.766 .35946 Mdot
.766 .35961 Mdot
.766 .35961 Mdot
.766 .35975 Mdot
.766 .35984 Mdot
.766 .36071 Mdot
.766 .36136 Mdot
.766 .36157 Mdot
.766 .36162 Mdot
.766 .36241 Mdot
.766 .36306 Mdot
.766 .36355 Mdot
.766 .36406 Mdot
.766 .36443 Mdot
.766 .3651 Mdot
.766 .36512 Mdot
.766 .36579 Mdot
.766 .36606 Mdot
.766 .36607 Mdot
.766 .36612 Mdot
.766 .36627 Mdot
.766 .36701 Mdot
.766 .3682 Mdot
.766 .3687 Mdot
.766 .36876 Mdot
.766 .36916 Mdot
.766 .36926 Mdot
.766 .36956 Mdot
.766 .37069 Mdot
.766 .37202 Mdot
.766 .37202 Mdot
.766 .37272 Mdot
.766 .37274 Mdot
.766 .37292 Mdot
.766 .37308 Mdot
.766 .37317 Mdot
.766 .37349 Mdot
.766 .37575 Mdot
.766 .37659 Mdot
.766 .37665 Mdot
.766 .37692 Mdot
.766 .37775 Mdot
.766 .37786 Mdot
.766 .37918 Mdot
.766 .37955 Mdot
.766 .38038 Mdot
.766 .38147 Mdot
.766 .38204 Mdot
.766 .38246 Mdot
.766 .38288 Mdot
.766 .38295 Mdot
.766 .38317 Mdot
.766 .38347 Mdot
.766 .38396 Mdot
.766 .38484 Mdot
.766 .38504 Mdot
.766 .38526 Mdot
.766 .38579 Mdot
.766 .38654 Mdot
.766 .38796 Mdot
.766 .38896 Mdot
.766 .38962 Mdot
.766 .38963 Mdot
.766 .3905 Mdot
.766 .39144 Mdot
.766 .3918 Mdot
.766 .39279 Mdot
.766 .39387 Mdot
.766 .39423 Mdot
.766 .39508 Mdot
.766 .39544 Mdot
.766 .39558 Mdot
.766 .39583 Mdot
.766 .39647 Mdot
.766 .39649 Mdot
.766 .39669 Mdot
.766 .39697 Mdot
.766 .39718 Mdot
.766 .39758 Mdot
.766 .39773 Mdot
.766 .39991 Mdot
.766 .40013 Mdot
.766 .40186 Mdot
.766 .40201 Mdot
.766 .40233 Mdot
.766 .40249 Mdot
.766 .40261 Mdot
.766 .40315 Mdot
.766 .40319 Mdot
.766 .40329 Mdot
.766 .4044 Mdot
.766 .40535 Mdot
.766 .40545 Mdot
.766 .40603 Mdot
.766 .40657 Mdot
.766 .40753 Mdot
.766 .40764 Mdot
.766 .40786 Mdot
.766 .40825 Mdot
.766 .40829 Mdot
.766 .40864 Mdot
.766 .41024 Mdot
.766 .41041 Mdot
.766 .4116 Mdot
.766 .41191 Mdot
.766 .41204 Mdot
.766 .41389 Mdot
.766 .4143 Mdot
.766 .41466 Mdot
.766 .41515 Mdot
.766 .41558 Mdot
.766 .41644 Mdot
.766 .41704 Mdot
.766 .41716 Mdot
.766 .41736 Mdot
.766 .41742 Mdot
.766 .41802 Mdot
.766 .41937 Mdot
.766 .41962 Mdot
.766 .41978 Mdot
.766 .42035 Mdot
.766 .42083 Mdot
.766 .42083 Mdot
.766 .42117 Mdot
.766 .42135 Mdot
.766 .42234 Mdot
.766 .42283 Mdot
.766 .42326 Mdot
.766 .42351 Mdot
.766 .42352 Mdot
.766 .42375 Mdot
.766 .42433 Mdot
.766 .42481 Mdot
.766 .4267 Mdot
.766 .4278 Mdot
.766 .42865 Mdot
.766 .4292 Mdot
.766 .4296 Mdot
.766 .42962 Mdot
.766 .42977 Mdot
.766 .43022 Mdot
.766 .43028 Mdot
.766 .43065 Mdot
.766 .43134 Mdot
.766 .43154 Mdot
.766 .43179 Mdot
.766 .43216 Mdot
.766 .43244 Mdot
.766 .43357 Mdot
.766 .43371 Mdot
.766 .43505 Mdot
.766 .4351 Mdot
.766 .43524 Mdot
.766 .43543 Mdot
.766 .4369 Mdot
.766 .43796 Mdot
.766 .438 Mdot
.766 .43854 Mdot
.766 .43866 Mdot
.766 .43928 Mdot
.766 .43946 Mdot
.766 .43949 Mdot
.766 .44057 Mdot
.766 .44101 Mdot
.766 .44173 Mdot
.766 .44287 Mdot
.766 .44303 Mdot
.766 .44315 Mdot
.766 .44315 Mdot
.766 .4432 Mdot
.766 .44372 Mdot
.766 .44379 Mdot
.766 .44432 Mdot
.766 .44476 Mdot
.766 .44478 Mdot
.766 .44482 Mdot
.766 .44564 Mdot
.766 .4458 Mdot
.766 .44608 Mdot
.766 .44641 Mdot
.766 .44654 Mdot
.766 .44676 Mdot
.766 .44715 Mdot
.766 .44719 Mdot
.766 .44736 Mdot
.766 .44754 Mdot
.766 .44768 Mdot
.766 .44817 Mdot
.766 .44821 Mdot
.766 .44828 Mdot
.766 .44846 Mdot
.766 .44871 Mdot
.766 .44872 Mdot
.766 .44874 Mdot
.766 .4488 Mdot
.766 .44887 Mdot
.766 .44888 Mdot
.766 .44907 Mdot
.766 .44907 Mdot
.766 .44921 Mdot
.766 .44931 Mdot
.766 .44934 Mdot
.766 .44937 Mdot
.766 .44964 Mdot
.766 .44971 Mdot
.766 .44981 Mdot
.766 .44991 Mdot
.766 .44993 Mdot
.766 .45014 Mdot
.766 .45026 Mdot
.766 .45033 Mdot
.766 .45066 Mdot
.766 .45075 Mdot
.766 .4512 Mdot
.766 .45122 Mdot
.766 .45123 Mdot
.766 .45147 Mdot
.766 .45176 Mdot
.766 .4518 Mdot
.766 .4521 Mdot
.766 .4521 Mdot
.766 .45217 Mdot
.766 .45287 Mdot
.766 .45325 Mdot
.766 .45349 Mdot
.766 .45408 Mdot
.766 .45457 Mdot
.766 .45485 Mdot
.766 .45543 Mdot
.766 .45631 Mdot
.766 .45638 Mdot
.766 .45641 Mdot
.766 .45718 Mdot
.766 .45791 Mdot
.766 .45811 Mdot
.766 .45824 Mdot
.766 .45869 Mdot
.766 .45888 Mdot
.766 .45915 Mdot
.766 .45922 Mdot
.766 .45923 Mdot
.766 .45944 Mdot
.766 .45972 Mdot
.766 .46168 Mdot
.766 .46192 Mdot
.766 .46246 Mdot
.766 .46292 Mdot
.766 .46367 Mdot
.766 .4644 Mdot
.766 .4654 Mdot
.766 .4655 Mdot
.766 .46555 Mdot
.766 .46585 Mdot
.766 .46628 Mdot
.766 .46672 Mdot
.766 .4669 Mdot
.766 .4671 Mdot
.766 .468 Mdot
.766 .46807 Mdot
.766 .46822 Mdot
.766 .46964 Mdot
.766 .46983 Mdot
.766 .47219 Mdot
.766 .47224 Mdot
.766 .47226 Mdot
.766 .47252 Mdot
.766 .47257 Mdot
.766 .4728 Mdot
.766 .47287 Mdot
.766 .4748 Mdot
.766 .47506 Mdot
.766 .47529 Mdot
.766 .4758 Mdot
.766 .47587 Mdot
.766 .47603 Mdot
.766 .47659 Mdot
.766 .47709 Mdot
.766 .47754 Mdot
.766 .47771 Mdot
.766 .47814 Mdot
.766 .47853 Mdot
.766 .47884 Mdot
.766 .47929 Mdot
.766 .47993 Mdot
.766 .48051 Mdot
.766 .48061 Mdot
.766 .48132 Mdot
.766 .48155 Mdot
.766 .48158 Mdot
.766 .48221 Mdot
.766 .48306 Mdot
.766 .48386 Mdot
.766 .48437 Mdot
.766 .48573 Mdot
.766 .48598 Mdot
.766 .48606 Mdot
.766 .48744 Mdot
.766 .48761 Mdot
.766 .48778 Mdot
.766 .48781 Mdot
.766 .48892 Mdot
.766 .48895 Mdot
.766 .48964 Mdot
.766 .4905 Mdot
.766 .49084 Mdot
.766 .49086 Mdot
.766 .49122 Mdot
.766 .49186 Mdot
.766 .49258 Mdot
.766 .49301 Mdot
.766 .49308 Mdot
.766 .4939 Mdot
.766 .49402 Mdot
.766 .4943 Mdot
.766 .49478 Mdot
.766 .49478 Mdot
.766 .49505 Mdot
.766 .49514 Mdot
.766 .49547 Mdot
.766 .49631 Mdot
.766 .49653 Mdot
.766 .49688 Mdot
.766 .49795 Mdot
.766 .49795 Mdot
.766 .49881 Mdot
.766 .49964 Mdot
.766 .49974 Mdot
.766 .50002 Mdot
.766 .50018 Mdot
.766 .50049 Mdot
.766 .50053 Mdot
.766 .50102 Mdot
.766 .50118 Mdot
.766 .50175 Mdot
.766 .50207 Mdot
.766 .50211 Mdot
.766 .50222 Mdot
.766 .50281 Mdot
.766 .50321 Mdot
.766 .50347 Mdot
.766 .50396 Mdot
.766 .50452 Mdot
.766 .50595 Mdot
.766 .50702 Mdot
.766 .50719 Mdot
.766 .50761 Mdot
.766 .50918 Mdot
.766 .5094 Mdot
.766 .51104 Mdot
.766 .51113 Mdot
.766 .51123 Mdot
.766 .51148 Mdot
.766 .51194 Mdot
.766 .51198 Mdot
.766 .51249 Mdot
.766 .51276 Mdot
.766 .5129 Mdot
.766 .51401 Mdot
.766 .51413 Mdot
.766 .51424 Mdot
.766 .5148 Mdot
.766 .51516 Mdot
.766 .51553 Mdot
.766 .51566 Mdot
.766 .51684 Mdot
.766 .51792 Mdot
.766 .5182 Mdot
.766 .51829 Mdot
.766 .51832 Mdot
.766 .51838 Mdot
.766 .51903 Mdot
.766 .51918 Mdot
.766 .51936 Mdot
.766 .51976 Mdot
.766 .51994 Mdot
.766 .52033 Mdot
.766 .52199 Mdot
.766 .52226 Mdot
.766 .52264 Mdot
.766 .52385 Mdot
.766 .52479 Mdot
.766 .52497 Mdot
.766 .52509 Mdot
.766 .52543 Mdot
.766 .52566 Mdot
.766 .52598 Mdot
.766 .5262 Mdot
.766 .52623 Mdot
.766 .52648 Mdot
.766 .52696 Mdot
.766 .52724 Mdot
.766 .52739 Mdot
.766 .52751 Mdot
.766 .52779 Mdot
.766 .52874 Mdot
.766 .52914 Mdot
.766 .52989 Mdot
.766 .53031 Mdot
.766 .53138 Mdot
.766 .53165 Mdot
.766 .53177 Mdot
.766 .53229 Mdot
.766 .53277 Mdot
.766 .53291 Mdot
.766 .53368 Mdot
.766 .53369 Mdot
.766 .53418 Mdot
.766 .53426 Mdot
.766 .53437 Mdot
.766 .53438 Mdot
.766 .53504 Mdot
.766 .53541 Mdot
.766 .5359 Mdot
.766 .53592 Mdot
.766 .53684 Mdot
.766 .53734 Mdot
.766 .53759 Mdot
.766 .53812 Mdot
.766 .53834 Mdot
.766 .53853 Mdot
.766 .53939 Mdot
.766 .53986 Mdot
.766 .53987 Mdot
.766 .54015 Mdot
.766 .54037 Mdot
.766 .5404 Mdot
.766 .54043 Mdot
.766 .54083 Mdot
.766 .54103 Mdot
.766 .54123 Mdot
.766 .54177 Mdot
.766 .54248 Mdot
.766 .54278 Mdot
.766 .54319 Mdot
.766 .54354 Mdot
.766 .54388 Mdot
.766 .54452 Mdot
.766 .54507 Mdot
.766 .54517 Mdot
.766 .5459 Mdot
.766 .54614 Mdot
.766 .5462 Mdot
.766 .5469 Mdot
.766 .54693 Mdot
.766 .54695 Mdot
.766 .5482 Mdot
.766 .54885 Mdot
.766 .54911 Mdot
.766 .54912 Mdot
.766 .54919 Mdot
.766 .54932 Mdot
.766 .54947 Mdot
.766 .54948 Mdot
.766 .55006 Mdot
.766 .55006 Mdot
.766 .55069 Mdot
.766 .55071 Mdot
.766 .55096 Mdot
.766 .55114 Mdot
.766 .55115 Mdot
.766 .55203 Mdot
.766 .55227 Mdot
.766 .55227 Mdot
.766 .55231 Mdot
.766 .55234 Mdot
.766 .55265 Mdot
.766 .5527 Mdot
.766 .55309 Mdot
.766 .55398 Mdot
.766 .55401 Mdot
.766 .55432 Mdot
.766 .55454 Mdot
.766 .55465 Mdot
.766 .55468 Mdot
.766 .5547 Mdot
.766 .55489 Mdot
.766 .55533 Mdot
.766 .55538 Mdot
.766 .55539 Mdot
.766 .55588 Mdot
.766 .55615 Mdot
.766 .55642 Mdot
.766 .55651 Mdot
.766 .55667 Mdot
.766 .55685 Mdot
.766 .55721 Mdot
.766 .55731 Mdot
.766 .55785 Mdot
.766 .55788 Mdot
.766 .55802 Mdot
.766 .55846 Mdot
.766 .55904 Mdot
.766 .5591 Mdot
.766 .55919 Mdot
.766 .55919 Mdot
.766 .55927 Mdot
.766 .55929 Mdot
.766 .55941 Mdot
.766 .55942 Mdot
.766 .55945 Mdot
.766 .55946 Mdot
.766 .55959 Mdot
.766 .55959 Mdot
.766 .5596 Mdot
.766 .55961 Mdot
.766 .56006 Mdot
.766 .56054 Mdot
.766 .5606 Mdot
.766 .56115 Mdot
.766 .56119 Mdot
.766 .56129 Mdot
.766 .5614 Mdot
.766 .56181 Mdot
.766 .56208 Mdot
.766 .56228 Mdot
.766 .56246 Mdot
.766 .56263 Mdot
.766 .56301 Mdot
.766 .56318 Mdot
.766 .56364 Mdot
.766 .56367 Mdot
.766 .56367 Mdot
.766 .56377 Mdot
.766 .564 Mdot
.766 .56403 Mdot
.766 .56408 Mdot
.766 .56415 Mdot
.766 .56424 Mdot
.766 .56426 Mdot
.766 .5645 Mdot
.766 .56459 Mdot
.766 .56493 Mdot
.766 .56562 Mdot
.766 .56565 Mdot
.766 .56593 Mdot
.766 .56599 Mdot
.766 .56602 Mdot
.766 .56604 Mdot
.766 .56618 Mdot
.766 .56625 Mdot
.766 .56634 Mdot
.766 .56635 Mdot
.766 .56649 Mdot
.766 .56678 Mdot
.766 .56709 Mdot
.766 .56712 Mdot
.766 .56745 Mdot
.766 .56753 Mdot
.766 .5676 Mdot
.766 .5676 Mdot
.766 .56769 Mdot
.766 .56791 Mdot
.766 .56854 Mdot
.766 .56905 Mdot
.766 .56918 Mdot
.766 .5693 Mdot
.766 .5694 Mdot
.766 .5695 Mdot
.766 .56955 Mdot
.766 .56977 Mdot
.766 .56993 Mdot
.766 .5701 Mdot
.766 .57022 Mdot
.766 .57026 Mdot
.766 .57038 Mdot
.766 .57071 Mdot
.766 .57072 Mdot
.766 .57077 Mdot
.766 .57086 Mdot
.766 .57086 Mdot
.766 .57103 Mdot
.766 .57121 Mdot
.766 .57134 Mdot
.766 .57149 Mdot
.766 .57159 Mdot
.766 .57161 Mdot
.766 .57165 Mdot
.766 .57173 Mdot
.766 .57173 Mdot
.766 .57187 Mdot
.766 .57193 Mdot
.766 .57199 Mdot
.766 .5722 Mdot
.766 .57239 Mdot
.766 .5724 Mdot
.766 .57242 Mdot
.766 .57242 Mdot
.766 .57244 Mdot
.766 .57246 Mdot
.766 .57246 Mdot
.766 .57247 Mdot
.766 .5725 Mdot
.766 .5725 Mdot
.766 .5725 Mdot
.766 .5725 Mdot
.766 .57269 Mdot
.766 .5728 Mdot
.766 .57293 Mdot
.766 .57303 Mdot
.766 .57322 Mdot
.766 .57335 Mdot
.766 .5734 Mdot
.766 .57345 Mdot
.766 .57386 Mdot
.766 .57389 Mdot
.766 .57391 Mdot
.766 .57397 Mdot
.766 .57413 Mdot
.766 .57421 Mdot
.766 .57468 Mdot
.766 .57471 Mdot
.766 .57478 Mdot
.766 .57495 Mdot
.766 .57514 Mdot
.766 .57519 Mdot
.766 .5753 Mdot
.766 .5754 Mdot
.766 .57543 Mdot
.766 .57549 Mdot
.766 .57553 Mdot
.766 .57556 Mdot
.766 .57558 Mdot
.766 .57573 Mdot
.766 .57574 Mdot
.766 .57574 Mdot
.766 .57574 Mdot
.766 .57575 Mdot
.766 .57576 Mdot
.766 .57576 Mdot
.766 .57576 Mdot
.766 .57577 Mdot
.766 .57577 Mdot
.768 .11406 Mdot
.768 .11421 Mdot
.768 .11422 Mdot
.768 .11427 Mdot
.768 .11429 Mdot
.768 .11437 Mdot
.768 .11442 Mdot
.768 .11442 Mdot
.768 .11443 Mdot
.768 .11459 Mdot
.768 .11487 Mdot
.768 .1149 Mdot
.768 .11493 Mdot
.768 .11493 Mdot
.768 .11525 Mdot
.768 .11602 Mdot
.768 .11604 Mdot
.768 .11629 Mdot
.768 .11659 Mdot
.768 .11696 Mdot
.768 .11702 Mdot
.768 .11712 Mdot
.768 .11726 Mdot
.768 .11729 Mdot
.768 .11736 Mdot
.768 .11745 Mdot
.768 .11755 Mdot
.768 .11801 Mdot
.768 .1183 Mdot
.768 .11833 Mdot
.768 .11852 Mdot
.768 .11957 Mdot
.768 .12003 Mdot
.768 .12008 Mdot
.768 .12023 Mdot
.768 .12043 Mdot
.768 .12288 Mdot
.768 .1236 Mdot
.768 .12396 Mdot
.768 .12398 Mdot
.768 .12409 Mdot
.768 .12415 Mdot
.768 .12434 Mdot
.768 .12445 Mdot
.768 .12445 Mdot
.768 .12449 Mdot
.768 .12449 Mdot
.768 .12451 Mdot
.768 .12486 Mdot
.768 .12494 Mdot
.768 .12517 Mdot
.768 .12523 Mdot
.768 .12556 Mdot
.768 .12565 Mdot
.768 .12571 Mdot
.768 .12572 Mdot
.768 .12656 Mdot
.768 .1273 Mdot
.768 .12851 Mdot
.768 .12864 Mdot
.768 .12871 Mdot
.768 .12879 Mdot
.768 .12943 Mdot
.768 .13019 Mdot
.768 .1303 Mdot
.768 .13143 Mdot
.768 .13152 Mdot
.768 .13162 Mdot
.768 .13192 Mdot
.768 .132 Mdot
.768 .13234 Mdot
.768 .13245 Mdot
.768 .13265 Mdot
.768 .13276 Mdot
.768 .13285 Mdot
.768 .13296 Mdot
.768 .13326 Mdot
.768 .13477 Mdot
.768 .13507 Mdot
.768 .13573 Mdot
.768 .13585 Mdot
.768 .13594 Mdot
.768 .13648 Mdot
.768 .13774 Mdot
.768 .13836 Mdot
.768 .13838 Mdot
.768 .13853 Mdot
.768 .13974 Mdot
.768 .14021 Mdot
.768 .14116 Mdot
.768 .14117 Mdot
.768 .14194 Mdot
.768 .14195 Mdot
.768 .14212 Mdot
.768 .1427 Mdot
.768 .1432 Mdot
.768 .14347 Mdot
.768 .14415 Mdot
.768 .14453 Mdot
.768 .14457 Mdot
.768 .14624 Mdot
.768 .14645 Mdot
.768 .14669 Mdot
.768 .14731 Mdot
.768 .14763 Mdot
.768 .14908 Mdot
.768 .15052 Mdot
.768 .15361 Mdot
.768 .15363 Mdot
.768 .15481 Mdot
.768 .155 Mdot
.768 .15521 Mdot
.768 .15571 Mdot
.768 .15583 Mdot
.768 .15626 Mdot
.768 .15681 Mdot
.768 .15772 Mdot
.768 .15848 Mdot
.768 .15855 Mdot
.768 .15909 Mdot
.768 .15934 Mdot
.768 .15934 Mdot
.768 .15937 Mdot
.768 .16025 Mdot
.768 .16074 Mdot
.768 .16078 Mdot
.768 .16094 Mdot
.768 .16097 Mdot
.768 .16105 Mdot
.768 .16155 Mdot
.768 .16255 Mdot
.768 .16268 Mdot
.768 .16311 Mdot
.768 .16419 Mdot
.768 .16423 Mdot
.768 .1645 Mdot
.768 .16534 Mdot
.768 .1655 Mdot
.768 .16609 Mdot
.768 .16629 Mdot
.768 .16631 Mdot
.768 .16653 Mdot
.768 .16685 Mdot
.768 .16688 Mdot
.768 .16719 Mdot
.768 .16807 Mdot
.768 .16887 Mdot
.768 .16911 Mdot
.768 .17107 Mdot
.768 .17207 Mdot
.768 .17256 Mdot
.768 .17287 Mdot
.768 .17344 Mdot
.768 .17471 Mdot
.768 .17493 Mdot
.768 .17661 Mdot
.768 .17664 Mdot
.768 .17822 Mdot
.768 .1804 Mdot
.768 .18136 Mdot
.768 .18204 Mdot
.768 .18245 Mdot
.768 .18289 Mdot
.768 .18335 Mdot
.768 .18529 Mdot
.768 .18641 Mdot
.768 .18764 Mdot
.768 .1879 Mdot
.768 .18854 Mdot
.768 .19046 Mdot
.768 .19064 Mdot
.768 .1913 Mdot
.768 .19262 Mdot
.768 .19273 Mdot
.768 .1951 Mdot
.768 .19644 Mdot
.768 .19644 Mdot
.768 .19669 Mdot
.768 .19713 Mdot
.768 .19781 Mdot
.768 .19835 Mdot
.768 .1989 Mdot
.768 .20012 Mdot
.768 .20067 Mdot
.768 .20117 Mdot
.768 .20317 Mdot
.768 .20382 Mdot
.768 .20503 Mdot
.768 .20558 Mdot
.768 .20573 Mdot
.768 .20597 Mdot
.768 .20619 Mdot
.768 .20625 Mdot
.768 .20688 Mdot
.768 .20782 Mdot
.768 .20842 Mdot
.768 .20852 Mdot
.768 .20867 Mdot
.768 .20872 Mdot
.768 .21107 Mdot
.768 .21141 Mdot
.768 .21301 Mdot
.768 .2145 Mdot
.768 .21466 Mdot
.768 .21805 Mdot
.768 .21838 Mdot
.768 .21992 Mdot
.768 .22277 Mdot
.768 .22299 Mdot
.768 .22401 Mdot
.768 .22445 Mdot
.768 .22487 Mdot
.768 .22547 Mdot
.768 .22637 Mdot
.768 .22736 Mdot
.768 .22867 Mdot
.768 .22888 Mdot
.768 .22894 Mdot
.768 .23007 Mdot
.768 .2316 Mdot
.768 .23286 Mdot
.768 .23495 Mdot
.768 .23502 Mdot
.768 .23548 Mdot
.768 .23709 Mdot
.768 .23866 Mdot
.768 .24001 Mdot
.768 .24007 Mdot
.768 .24062 Mdot
.768 .24121 Mdot
.768 .24134 Mdot
.768 .24228 Mdot
.768 .24232 Mdot
.768 .24325 Mdot
.768 .24666 Mdot
.768 .24684 Mdot
.768 .24747 Mdot
.768 .24842 Mdot
.768 .24934 Mdot
.768 .2504 Mdot
.768 .25149 Mdot
.768 .25358 Mdot
.768 .25454 Mdot
.768 .25524 Mdot
.768 .25708 Mdot
.768 .25731 Mdot
.768 .25869 Mdot
.768 .25918 Mdot
.768 .26002 Mdot
.768 .26004 Mdot
.768 .26042 Mdot
.768 .2605 Mdot
.768 .26187 Mdot
.768 .26512 Mdot
.768 .26534 Mdot
.768 .26541 Mdot
.768 .26579 Mdot
.768 .26654 Mdot
.768 .26911 Mdot
.768 .26996 Mdot
.768 .27052 Mdot
.768 .27184 Mdot
.768 .27348 Mdot
.768 .27398 Mdot
.768 .27399 Mdot
.768 .27493 Mdot
.768 .27576 Mdot
.768 .27587 Mdot
.768 .27759 Mdot
.768 .27992 Mdot
.768 .28059 Mdot
.768 .28097 Mdot
.768 .28208 Mdot
.768 .28328 Mdot
.768 .28352 Mdot
.768 .28662 Mdot
.768 .28736 Mdot
.768 .29213 Mdot
.768 .2924 Mdot
.768 .29266 Mdot
.768 .29489 Mdot
.768 .29525 Mdot
.768 .2967 Mdot
.768 .29699 Mdot
.768 .29706 Mdot
.768 .29762 Mdot
.768 .29838 Mdot
.768 .2996 Mdot
.768 .30277 Mdot
.768 .303 Mdot
.768 .30416 Mdot
.768 .30498 Mdot
.768 .305 Mdot
.768 .3087 Mdot
.768 .31167 Mdot
.768 .31173 Mdot
.768 .31211 Mdot
.768 .31228 Mdot
.768 .31278 Mdot
.768 .31313 Mdot
.768 .31516 Mdot
.768 .31526 Mdot
.768 .31632 Mdot
.768 .31837 Mdot
.768 .31901 Mdot
.768 .32053 Mdot
.768 .32072 Mdot
.768 .32116 Mdot
.768 .32151 Mdot
.768 .32231 Mdot
.768 .32284 Mdot
.768 .32472 Mdot
.768 .32543 Mdot
.768 .3289 Mdot
.768 .3297 Mdot
.768 .33009 Mdot
.768 .33011 Mdot
.768 .33023 Mdot
.768 .33029 Mdot
.768 .33049 Mdot
.768 .3306 Mdot
.768 .33061 Mdot
.768 .33065 Mdot
.768 .33065 Mdot
.768 .33103 Mdot
.768 .33112 Mdot
.768 .33135 Mdot
.768 .33174 Mdot
.768 .33182 Mdot
.768 .33189 Mdot
.768 .3319 Mdot
.768 .33271 Mdot
.768 .33341 Mdot
.768 .33462 Mdot
.768 .33469 Mdot
.768 .33531 Mdot
.768 .33605 Mdot
.768 .33699 Mdot
.768 .33714 Mdot
.768 .33738 Mdot
.768 .33771 Mdot
.768 .3378 Mdot
.768 .33796 Mdot
.768 .33805 Mdot
.768 .3382 Mdot
.768 .33843 Mdot
.768 .33958 Mdot
.768 .3398 Mdot
.768 .34029 Mdot
.768 .34038 Mdot
.768 .34084 Mdot
.768 .34173 Mdot
.768 .34217 Mdot
.768 .34342 Mdot
.768 .34456 Mdot
.768 .34467 Mdot
.768 .34504 Mdot
.768 .34536 Mdot
.768 .34553 Mdot
.768 .34596 Mdot
.768 .34622 Mdot
.768 .34724 Mdot
.768 .34737 Mdot
.768 .34788 Mdot
.768 .34975 Mdot
.768 .35148 Mdot
.768 .35214 Mdot
.768 .35235 Mdot
.768 .35321 Mdot
.768 .35369 Mdot
.768 .35408 Mdot
.768 .35412 Mdot
.768 .3544 Mdot
.768 .35453 Mdot
.768 .35453 Mdot
.768 .35454 Mdot
.768 .35499 Mdot
.768 .35525 Mdot
.768 .35527 Mdot
.768 .35535 Mdot
.768 .35536 Mdot
.768 .3554 Mdot
.768 .35566 Mdot
.768 .35623 Mdot
.768 .35644 Mdot
.768 .35697 Mdot
.768 .35699 Mdot
.768 .35713 Mdot
.768 .3579 Mdot
.768 .35811 Mdot
.768 .35827 Mdot
.768 .35828 Mdot
.768 .35843 Mdot
.768 .35923 Mdot
.768 .36026 Mdot
.768 .36109 Mdot
.768 .36136 Mdot
.768 .36193 Mdot
.768 .36203 Mdot
.768 .36279 Mdot
.768 .36487 Mdot
.768 .36516 Mdot
.768 .36534 Mdot
.768 .36552 Mdot
.768 .36572 Mdot
.768 .36701 Mdot
.768 .36753 Mdot
.768 .3679 Mdot
.768 .36876 Mdot
.768 .36903 Mdot
.768 .36957 Mdot
.768 .3711 Mdot
.768 .3711 Mdot
.768 .37164 Mdot
.768 .37185 Mdot
.768 .37207 Mdot
.768 .37254 Mdot
.768 .37276 Mdot
.768 .37295 Mdot
.768 .37372 Mdot
.768 .37397 Mdot
.768 .37443 Mdot
.768 .37464 Mdot
.768 .3747 Mdot
.768 .37487 Mdot
.768 .37489 Mdot
.768 .37513 Mdot
.768 .37549 Mdot
.768 .3758 Mdot
.768 .37582 Mdot
.768 .37925 Mdot
.768 .37992 Mdot
.768 .38101 Mdot
.768 .38138 Mdot
.768 .38153 Mdot
.768 .38168 Mdot
.768 .38189 Mdot
.768 .38221 Mdot
.768 .3831 Mdot
.768 .38349 Mdot
.768 .38402 Mdot
.768 .38446 Mdot
.768 .38519 Mdot
.768 .38535 Mdot
.768 .3859 Mdot
.768 .38688 Mdot
.768 .3869 Mdot
.768 .38708 Mdot
.768 .38728 Mdot
.768 .38732 Mdot
.768 .38764 Mdot
.768 .38765 Mdot
.768 .38967 Mdot
.768 .39032 Mdot
.768 .39136 Mdot
.768 .39189 Mdot
.768 .39248 Mdot
.768 .393 Mdot
.768 .39343 Mdot
.768 .39343 Mdot
.768 .39355 Mdot
.768 .39512 Mdot
.768 .39514 Mdot
.768 .39549 Mdot
.768 .3963 Mdot
.768 .39657 Mdot
.768 .39674 Mdot
.768 .39715 Mdot
.768 .39767 Mdot
.768 .39782 Mdot
.768 .39782 Mdot
.768 .39837 Mdot
.768 .39841 Mdot
.768 .39894 Mdot
.768 .39986 Mdot
.768 .40032 Mdot
.768 .40068 Mdot
.768 .40076 Mdot
.768 .4017 Mdot
.768 .40193 Mdot
.768 .40345 Mdot
.768 .4042 Mdot
.768 .40431 Mdot
.768 .40474 Mdot
.768 .40483 Mdot
.768 .40485 Mdot
.768 .40525 Mdot
.768 .40561 Mdot
.768 .40656 Mdot
.768 .40721 Mdot
.768 .40722 Mdot
.768 .40831 Mdot
.768 .40919 Mdot
.768 .4092 Mdot
.768 .41024 Mdot
.768 .41055 Mdot
.768 .41134 Mdot
.768 .41197 Mdot
.768 .41321 Mdot
.768 .41472 Mdot
.768 .41492 Mdot
.768 .41552 Mdot
.768 .41805 Mdot
.768 .41896 Mdot
.768 .41921 Mdot
.768 .4195 Mdot
.768 .41954 Mdot
.768 .42096 Mdot
.768 .42191 Mdot
.768 .42229 Mdot
.768 .4227 Mdot
.768 .42346 Mdot
.768 .42354 Mdot
.768 .4237 Mdot
.768 .42395 Mdot
.768 .42479 Mdot
.768 .42588 Mdot
.768 .42632 Mdot
.768 .42632 Mdot
.768 .42733 Mdot
.768 .42766 Mdot
.768 .42915 Mdot
.768 .42926 Mdot
.768 .4293 Mdot
.768 .42986 Mdot
.768 .43001 Mdot
.768 .43035 Mdot
.768 .43083 Mdot
.768 .43083 Mdot
.768 .43089 Mdot
.768 .43105 Mdot
.768 .43226 Mdot
.768 .43243 Mdot
.768 .43258 Mdot
.768 .43353 Mdot
.768 .4336 Mdot
.768 .43377 Mdot
.768 .43392 Mdot
.768 .43396 Mdot
.768 .43412 Mdot
.768 .43428 Mdot
.768 .43508 Mdot
.768 .4358 Mdot
.768 .43598 Mdot
.768 .43621 Mdot
.768 .43699 Mdot
.768 .43724 Mdot
.768 .43725 Mdot
.768 .43786 Mdot
.768 .43805 Mdot
.768 .43885 Mdot
.768 .4389 Mdot
.768 .43908 Mdot
.768 .44008 Mdot
.768 .44015 Mdot
.768 .44067 Mdot
.768 .44224 Mdot
.768 .44224 Mdot
.768 .44253 Mdot
.768 .44328 Mdot
.768 .44363 Mdot
.768 .44399 Mdot
.768 .44404 Mdot
.768 .44444 Mdot
.768 .44504 Mdot
.768 .44509 Mdot
.768 .44565 Mdot
.768 .44595 Mdot
.768 .44602 Mdot
.768 .44728 Mdot
.768 .44808 Mdot
.768 .4481 Mdot
.768 .44873 Mdot
.768 .44873 Mdot
.768 .44916 Mdot
.768 .44951 Mdot
.768 .44952 Mdot
.768 .45065 Mdot
.768 .45068 Mdot
.768 .45213 Mdot
.768 .45269 Mdot
.768 .45438 Mdot
.768 .45447 Mdot
.768 .4545 Mdot
.768 .45502 Mdot
.768 .45535 Mdot
.768 .45589 Mdot
.768 .45601 Mdot
.768 .45611 Mdot
.768 .4569 Mdot
.768 .45717 Mdot
.768 .45786 Mdot
.768 .45795 Mdot
.768 .45858 Mdot
.768 .45911 Mdot
.768 .45919 Mdot
.768 .4595 Mdot
.768 .46048 Mdot
.768 .461 Mdot
.768 .461 Mdot
.768 .4624 Mdot
.768 .46244 Mdot
.768 .46369 Mdot
.768 .46457 Mdot
.768 .46469 Mdot
.768 .46514 Mdot
.768 .46639 Mdot
.768 .46668 Mdot
.768 .46678 Mdot
.768 .46812 Mdot
.768 .46842 Mdot
.768 .4688 Mdot
.768 .46945 Mdot
.768 .46946 Mdot
.768 .46988 Mdot
.768 .47041 Mdot
.768 .47117 Mdot
.768 .47153 Mdot
.768 .47154 Mdot
.768 .47184 Mdot
.768 .4722 Mdot
.768 .47291 Mdot
.768 .47302 Mdot
.768 .47367 Mdot
.768 .47432 Mdot
.768 .47458 Mdot
.768 .47484 Mdot
.768 .47491 Mdot
.768 .47515 Mdot
.768 .47542 Mdot
.768 .47554 Mdot
.768 .47681 Mdot
.768 .47706 Mdot
.768 .4773 Mdot
.768 .47757 Mdot
.768 .47859 Mdot
.768 .47951 Mdot
.768 .47976 Mdot
.768 .47984 Mdot
.768 .47985 Mdot
.768 .48054 Mdot
.768 .48061 Mdot
.768 .48094 Mdot
.768 .48114 Mdot
.768 .48137 Mdot
.768 .48195 Mdot
.768 .48225 Mdot
.768 .48232 Mdot
.768 .48248 Mdot
.768 .48478 Mdot
.768 .48492 Mdot
.768 .48519 Mdot
.768 .48529 Mdot
.768 .48621 Mdot
.768 .48684 Mdot
.768 .48684 Mdot
.768 .4875 Mdot
.768 .48822 Mdot
.768 .48838 Mdot
.768 .48915 Mdot
.768 .49041 Mdot
.768 .49077 Mdot
.768 .49101 Mdot
.768 .49113 Mdot
.768 .49191 Mdot
.768 .49225 Mdot
.768 .49286 Mdot
.768 .49341 Mdot
.768 .49389 Mdot
.768 .49389 Mdot
.768 .49424 Mdot
.768 .49479 Mdot
.768 .49488 Mdot
.768 .49587 Mdot
.768 .49664 Mdot
.768 .49685 Mdot
.768 .4969 Mdot
.768 .49732 Mdot
.768 .49743 Mdot
.768 .49767 Mdot
.768 .49897 Mdot
.768 .49915 Mdot
.768 .49993 Mdot
.768 .50064 Mdot
.768 .5025 Mdot
.768 .50332 Mdot
.768 .50341 Mdot
.768 .5036 Mdot
.768 .50429 Mdot
.768 .50566 Mdot
.768 .50594 Mdot
.768 .50667 Mdot
.768 .50688 Mdot
.768 .50719 Mdot
.768 .50733 Mdot
.768 .5075 Mdot
.768 .50757 Mdot
.768 .50816 Mdot
.768 .50841 Mdot
.768 .5092 Mdot
.768 .50961 Mdot
.768 .50964 Mdot
.768 .51042 Mdot
.768 .51056 Mdot
.768 .51075 Mdot
.768 .51082 Mdot
.768 .51096 Mdot
.768 .51098 Mdot
.768 .51211 Mdot
.768 .51351 Mdot
.768 .51352 Mdot
.768 .51383 Mdot
.768 .51427 Mdot
.768 .51435 Mdot
.768 .51554 Mdot
.768 .516 Mdot
.768 .51628 Mdot
.768 .51649 Mdot
.768 .51651 Mdot
.768 .51662 Mdot
.768 .51716 Mdot
.768 .51729 Mdot
.768 .51812 Mdot
.768 .51822 Mdot
.768 .51831 Mdot
.768 .52006 Mdot
.768 .52034 Mdot
.768 .52146 Mdot
.768 .52155 Mdot
.768 .52199 Mdot
.768 .52239 Mdot
.768 .52253 Mdot
.768 .52277 Mdot
.768 .52361 Mdot
.768 .52422 Mdot
.768 .52427 Mdot
.768 .52456 Mdot
.768 .5249 Mdot
.768 .5249 Mdot
.768 .52508 Mdot
.768 .52567 Mdot
.768 .52613 Mdot
.768 .52633 Mdot
.768 .52664 Mdot
.768 .52754 Mdot
.768 .52781 Mdot
.768 .52794 Mdot
.768 .52797 Mdot
.768 .52805 Mdot
.768 .52919 Mdot
.768 .52967 Mdot
.768 .5297 Mdot
.768 .52983 Mdot
.768 .52983 Mdot
.768 .53013 Mdot
.768 .5303 Mdot
.768 .53078 Mdot
.768 .53086 Mdot
.768 .5315 Mdot
.768 .53174 Mdot
.768 .53207 Mdot
.768 .5328 Mdot
.768 .53317 Mdot
.768 .53385 Mdot
.768 .53418 Mdot
.768 .53439 Mdot
.768 .53445 Mdot
.768 .53562 Mdot
.768 .53593 Mdot
.768 .53595 Mdot
.768 .53627 Mdot
.768 .53631 Mdot
.768 .53651 Mdot
.768 .5367 Mdot
.768 .53672 Mdot
.768 .53717 Mdot
.768 .5377 Mdot
.768 .53825 Mdot
.768 .5384 Mdot
.768 .53843 Mdot
.768 .53913 Mdot
.768 .53955 Mdot
.768 .54006 Mdot
.768 .54044 Mdot
.768 .54046 Mdot
.768 .54053 Mdot
.768 .54097 Mdot
.768 .5413 Mdot
.768 .54159 Mdot
.768 .54179 Mdot
.768 .54193 Mdot
.768 .54208 Mdot
.768 .54242 Mdot
.768 .54249 Mdot
.768 .54343 Mdot
.768 .54393 Mdot
.768 .54404 Mdot
.768 .54515 Mdot
.768 .5452 Mdot
.768 .54569 Mdot
.768 .54621 Mdot
.768 .54632 Mdot
.768 .54709 Mdot
.768 .5471 Mdot
.768 .54715 Mdot
.768 .54718 Mdot
.768 .54738 Mdot
.768 .54768 Mdot
.768 .54788 Mdot
.768 .5479 Mdot
.768 .54798 Mdot
.768 .54805 Mdot
.768 .5481 Mdot
.768 .54828 Mdot
.768 .54867 Mdot
.768 .54888 Mdot
.768 .54952 Mdot
.768 .54968 Mdot
.768 .54986 Mdot
.768 .55025 Mdot
.768 .55042 Mdot
.768 .55059 Mdot
.768 .55081 Mdot
.768 .55095 Mdot
.768 .55103 Mdot
.768 .55103 Mdot
.768 .55146 Mdot
.768 .55221 Mdot
.768 .55225 Mdot
.768 .55267 Mdot
.768 .55288 Mdot
.768 .55293 Mdot
.768 .55354 Mdot
.768 .55374 Mdot
.768 .55382 Mdot
.768 .55421 Mdot
.768 .55456 Mdot
.768 .55517 Mdot
.768 .55532 Mdot
.768 .55545 Mdot
.768 .55558 Mdot
.768 .55579 Mdot
.768 .55609 Mdot
.768 .55677 Mdot
.768 .55727 Mdot
.768 .55727 Mdot
.768 .55779 Mdot
.768 .55786 Mdot
.768 .55826 Mdot
.768 .55843 Mdot
.768 .55853 Mdot
.768 .55868 Mdot
.768 .55899 Mdot
.768 .55959 Mdot
.768 .55967 Mdot
.768 .55991 Mdot
.768 .56018 Mdot
.768 .56028 Mdot
.768 .56029 Mdot
.768 .56039 Mdot
.768 .56045 Mdot
.768 .56046 Mdot
.768 .56052 Mdot
.768 .5607 Mdot
.768 .56075 Mdot
.768 .56101 Mdot
.768 .56109 Mdot
.768 .5611 Mdot
.768 .56144 Mdot
.768 .56156 Mdot
.768 .56161 Mdot
.768 .56191 Mdot
.768 .56206 Mdot
.768 .56209 Mdot
.768 .5621 Mdot
.768 .56215 Mdot
.768 .56216 Mdot
.768 .56231 Mdot
.768 .56258 Mdot
.768 .56258 Mdot
.768 .56258 Mdot
.768 .56266 Mdot
.768 .56282 Mdot
.768 .56285 Mdot
.768 .56308 Mdot
.768 .56335 Mdot
.768 .56352 Mdot
.768 .56365 Mdot
.768 .56369 Mdot
.768 .56384 Mdot
.768 .5639 Mdot
.768 .56396 Mdot
.768 .56432 Mdot
.768 .56432 Mdot
.768 .56525 Mdot
.768 .56569 Mdot
.768 .56612 Mdot
.768 .56622 Mdot
.768 .56641 Mdot
.768 .56648 Mdot
.768 .56654 Mdot
.768 .56704 Mdot
.768 .56705 Mdot
.768 .56717 Mdot
.768 .56737 Mdot
.768 .56745 Mdot
.768 .5676 Mdot
.768 .56777 Mdot
.768 .56782 Mdot
.768 .56782 Mdot
.768 .56806 Mdot
.768 .56806 Mdot
.768 .56834 Mdot
.768 .56848 Mdot
.768 .56884 Mdot
.768 .56888 Mdot
.768 .56889 Mdot
.768 .56907 Mdot
.768 .56945 Mdot
.768 .56961 Mdot
.768 .56963 Mdot
.768 .56967 Mdot
.768 .56987 Mdot
.768 .56995 Mdot
.768 .5704 Mdot
.768 .57049 Mdot
.768 .57052 Mdot
.768 .57055 Mdot
.768 .57058 Mdot
.768 .57064 Mdot
.768 .57067 Mdot
.768 .57077 Mdot
.768 .5708 Mdot
.768 .57088 Mdot
.768 .57091 Mdot
.768 .57094 Mdot
.768 .57127 Mdot
.768 .57131 Mdot
.768 .57153 Mdot
.768 .57171 Mdot
.768 .57174 Mdot
.768 .57176 Mdot
.768 .5718 Mdot
.768 .57215 Mdot
.768 .57237 Mdot
.768 .57262 Mdot
.768 .57262 Mdot
.768 .57264 Mdot
.768 .57266 Mdot
.768 .57276 Mdot
.768 .57278 Mdot
.768 .57284 Mdot
.768 .57287 Mdot
.768 .57297 Mdot
.768 .57297 Mdot
.768 .57298 Mdot
.768 .57299 Mdot
.768 .57299 Mdot
.768 .57302 Mdot
.768 .57307 Mdot
.768 .57309 Mdot
.768 .57313 Mdot
.768 .57313 Mdot
.768 .57324 Mdot
.768 .57345 Mdot
.768 .57416 Mdot
.768 .57422 Mdot
.768 .57426 Mdot
.768 .57428 Mdot
.768 .57441 Mdot
.768 .57472 Mdot
.768 .57477 Mdot
.768 .57478 Mdot
.768 .57486 Mdot
.768 .575 Mdot
.768 .57502 Mdot
.768 .57505 Mdot
.768 .57507 Mdot
.768 .57508 Mdot
.768 .57512 Mdot
.768 .57515 Mdot
.768 .57517 Mdot
.768 .57527 Mdot
.768 .57536 Mdot
.768 .57543 Mdot
.768 .57544 Mdot
.768 .57566 Mdot
.768 .57576 Mdot
.768 .57576 Mdot
.768 .57576 Mdot
.768 .57577 Mdot
.768 .57585 Mdot
.768 .5759 Mdot
.768 .5759 Mdot
.768 .5759 Mdot
.768 .57592 Mdot
.768 .57594 Mdot
.768 .57595 Mdot
.768 .57596 Mdot
.768 .57596 Mdot
.768 .57601 Mdot
.77 .11328 Mdot
.77 .11328 Mdot
.77 .1133 Mdot
.77 .1133 Mdot
.77 .11334 Mdot
.77 .11342 Mdot
.77 .11395 Mdot
.77 .11401 Mdot
.77 .11402 Mdot
.77 .11423 Mdot
.77 .11424 Mdot
.77 .11444 Mdot
.77 .11458 Mdot
.77 .11498 Mdot
.77 .11502 Mdot
.77 .11523 Mdot
.77 .11526 Mdot
.77 .11576 Mdot
.77 .11577 Mdot
.77 .11602 Mdot
.77 .11627 Mdot
.77 .11704 Mdot
.77 .11733 Mdot
.77 .11787 Mdot
.77 .11787 Mdot
.77 .11792 Mdot
.77 .11819 Mdot
.77 .11828 Mdot
.77 .1186 Mdot
.77 .11872 Mdot
.77 .11891 Mdot
.77 .11951 Mdot
.77 .11997 Mdot
.77 .1204 Mdot
.77 .12067 Mdot
.77 .12071 Mdot
.77 .12096 Mdot
.77 .12123 Mdot
.77 .12123 Mdot
.77 .12126 Mdot
.77 .12128 Mdot
.77 .12136 Mdot
.77 .12153 Mdot
.77 .12227 Mdot
.77 .12232 Mdot
.77 .12233 Mdot
.77 .1227 Mdot
.77 .12284 Mdot
.77 .12288 Mdot
.77 .12337 Mdot
.77 .12339 Mdot
.77 .12387 Mdot
.77 .1239 Mdot
.77 .12423 Mdot
.77 .12484 Mdot
.77 .12523 Mdot
.77 .12534 Mdot
.77 .12589 Mdot
.77 .12597 Mdot
.77 .12651 Mdot
.77 .12732 Mdot
.77 .12734 Mdot
.77 .12789 Mdot
.77 .12804 Mdot
.77 .12877 Mdot
.77 .12895 Mdot
.77 .13014 Mdot
.77 .13054 Mdot
.77 .13108 Mdot
.77 .13168 Mdot
.77 .13185 Mdot
.77 .13192 Mdot
.77 .132 Mdot
.77 .13233 Mdot
.77 .13259 Mdot
.77 .133 Mdot
.77 .133 Mdot
.77 .13346 Mdot
.77 .13373 Mdot
.77 .13373 Mdot
.77 .13393 Mdot
.77 .13416 Mdot
.77 .13465 Mdot
.77 .13476 Mdot
.77 .13483 Mdot
.77 .13492 Mdot
.77 .13513 Mdot
.77 .13586 Mdot
.77 .13621 Mdot
.77 .13622 Mdot
.77 .13664 Mdot
.77 .13698 Mdot
.77 .13714 Mdot
.77 .13732 Mdot
.77 .13913 Mdot
.77 .13916 Mdot
.77 .13949 Mdot
.77 .14067 Mdot
.77 .1408 Mdot
.77 .14095 Mdot
.77 .141 Mdot
.77 .14122 Mdot
.77 .14215 Mdot
.77 .14268 Mdot
.77 .14284 Mdot
.77 .1439 Mdot
.77 .14407 Mdot
.77 .14427 Mdot
.77 .14472 Mdot
.77 .14509 Mdot
.77 .14534 Mdot
.77 .14608 Mdot
.77 .14614 Mdot
.77 .14615 Mdot
.77 .14615 Mdot
.77 .14628 Mdot
.77 .14635 Mdot
.77 .14669 Mdot
.77 .14741 Mdot
.77 .14782 Mdot
.77 .15037 Mdot
.77 .15053 Mdot
.77 .15074 Mdot
.77 .15075 Mdot
.77 .15101 Mdot
.77 .15238 Mdot
.77 .15256 Mdot
.77 .15268 Mdot
.77 .15271 Mdot
.77 .153 Mdot
.77 .15314 Mdot
.77 .15437 Mdot
.77 .15537 Mdot
.77 .1554 Mdot
.77 .15543 Mdot
.77 .15601 Mdot
.77 .15766 Mdot
.77 .15775 Mdot
.77 .15919 Mdot
.77 .15929 Mdot
.77 .16013 Mdot
.77 .16218 Mdot
.77 .16227 Mdot
.77 .16409 Mdot
.77 .16441 Mdot
.77 .16463 Mdot
.77 .16485 Mdot
.77 .16736 Mdot
.77 .16774 Mdot
.77 .16804 Mdot
.77 .16811 Mdot
.77 .16879 Mdot
.77 .16903 Mdot
.77 .16941 Mdot
.77 .16996 Mdot
.77 .17036 Mdot
.77 .17048 Mdot
.77 .17089 Mdot
.77 .17255 Mdot
.77 .17284 Mdot
.77 .17293 Mdot
.77 .17346 Mdot
.77 .17443 Mdot
.77 .17465 Mdot
.77 .17479 Mdot
.77 .17736 Mdot
.77 .17767 Mdot
.77 .17849 Mdot
.77 .17935 Mdot
.77 .18013 Mdot
.77 .18244 Mdot
.77 .18341 Mdot
.77 .18349 Mdot
.77 .18419 Mdot
.77 .18492 Mdot
.77 .18846 Mdot
.77 .18899 Mdot
.77 .19008 Mdot
.77 .19159 Mdot
.77 .19241 Mdot
.77 .19552 Mdot
.77 .19613 Mdot
.77 .19699 Mdot
.77 .19752 Mdot
.77 .19903 Mdot
.77 .20002 Mdot
.77 .20044 Mdot
.77 .2006 Mdot
.77 .20094 Mdot
.77 .20288 Mdot
.77 .20445 Mdot
.77 .20487 Mdot
.77 .20675 Mdot
.77 .20692 Mdot
.77 .20695 Mdot
.77 .20782 Mdot
.77 .20955 Mdot
.77 .20974 Mdot
.77 .2098 Mdot
.77 .20999 Mdot
.77 .21142 Mdot
.77 .21143 Mdot
.77 .21262 Mdot
.77 .21408 Mdot
.77 .2155 Mdot
.77 .21716 Mdot
.77 .21785 Mdot
.77 .21828 Mdot
.77 .21885 Mdot
.77 .21937 Mdot
.77 .2198 Mdot
.77 .22017 Mdot
.77 .2205 Mdot
.77 .22101 Mdot
.77 .2229 Mdot
.77 .22482 Mdot
.77 .22561 Mdot
.77 .22575 Mdot
.77 .22703 Mdot
.77 .22712 Mdot
.77 .22722 Mdot
.77 .22983 Mdot
.77 .23044 Mdot
.77 .23166 Mdot
.77 .23203 Mdot
.77 .23307 Mdot
.77 .2338 Mdot
.77 .23533 Mdot
.77 .23684 Mdot
.77 .23751 Mdot
.77 .23794 Mdot
.77 .2381 Mdot
.77 .23949 Mdot
.77 .24158 Mdot
.77 .24343 Mdot
.77 .24506 Mdot
.77 .24626 Mdot
.77 .24647 Mdot
.77 .24862 Mdot
.77 .2499 Mdot
.77 .25137 Mdot
.77 .25168 Mdot
.77 .25197 Mdot
.77 .25341 Mdot
.77 .25593 Mdot
.77 .25637 Mdot
.77 .25661 Mdot
.77 .25678 Mdot
.77 .25754 Mdot
.77 .25841 Mdot
.77 .25852 Mdot
.77 .25884 Mdot
.77 .25887 Mdot
.77 .2604 Mdot
.77 .26322 Mdot
.77 .26488 Mdot
.77 .26674 Mdot
.77 .26796 Mdot
.77 .27046 Mdot
.77 .2709 Mdot
.77 .27128 Mdot
.77 .27155 Mdot
.77 .27254 Mdot
.77 .27362 Mdot
.77 .27365 Mdot
.77 .27483 Mdot
.77 .27621 Mdot
.77 .27791 Mdot
.77 .27888 Mdot
.77 .27923 Mdot
.77 .27975 Mdot
.77 .28007 Mdot
.77 .28012 Mdot
.77 .28116 Mdot
.77 .2815 Mdot
.77 .28342 Mdot
.77 .28466 Mdot
.77 .28722 Mdot
.77 .2889 Mdot
.77 .28896 Mdot
.77 .29119 Mdot
.77 .29361 Mdot
.77 .29408 Mdot
.77 .29421 Mdot
.77 .29462 Mdot
.77 .29471 Mdot
.77 .29471 Mdot
.77 .29558 Mdot
.77 .29607 Mdot
.77 .29748 Mdot
.77 .29849 Mdot
.77 .29851 Mdot
.77 .3014 Mdot
.77 .30249 Mdot
.77 .30251 Mdot
.77 .30333 Mdot
.77 .30358 Mdot
.77 .30649 Mdot
.77 .30735 Mdot
.77 .30801 Mdot
.77 .30821 Mdot
.77 .30884 Mdot
.77 .30884 Mdot
.77 .31475 Mdot
.77 .3162 Mdot
.77 .31772 Mdot
.77 .31782 Mdot
.77 .31834 Mdot
.77 .31841 Mdot
.77 .32006 Mdot
.77 .3246 Mdot
.77 .32487 Mdot
.77 .3257 Mdot
.77 .32631 Mdot
.77 .32718 Mdot
.77 .32723 Mdot
.77 .32755 Mdot
.77 .32786 Mdot
.77 .32786 Mdot
.77 .3279 Mdot
.77 .32792 Mdot
.77 .32802 Mdot
.77 .32823 Mdot
.77 .32913 Mdot
.77 .32955 Mdot
.77 .3297 Mdot
.77 .32974 Mdot
.77 .33027 Mdot
.77 .33028 Mdot
.77 .33079 Mdot
.77 .33115 Mdot
.77 .33177 Mdot
.77 .33215 Mdot
.77 .33226 Mdot
.77 .33279 Mdot
.77 .33286 Mdot
.77 .33411 Mdot
.77 .33413 Mdot
.77 .33475 Mdot
.77 .33539 Mdot
.77 .33554 Mdot
.77 .3373 Mdot
.77 .33778 Mdot
.77 .33803 Mdot
.77 .33849 Mdot
.77 .33881 Mdot
.77 .33936 Mdot
.77 .33936 Mdot
.77 .3395 Mdot
.77 .33968 Mdot
.77 .34004 Mdot
.77 .34017 Mdot
.77 .34024 Mdot
.77 .34039 Mdot
.77 .34092 Mdot
.77 .34116 Mdot
.77 .34117 Mdot
.77 .34147 Mdot
.77 .34171 Mdot
.77 .34194 Mdot
.77 .34318 Mdot
.77 .34342 Mdot
.77 .3442 Mdot
.77 .34429 Mdot
.77 .34456 Mdot
.77 .34515 Mdot
.77 .34559 Mdot
.77 .34625 Mdot
.77 .34635 Mdot
.77 .34698 Mdot
.77 .34761 Mdot
.77 .34762 Mdot
.77 .34762 Mdot
.77 .34769 Mdot
.77 .34774 Mdot
.77 .34794 Mdot
.77 .34836 Mdot
.77 .34861 Mdot
.77 .35016 Mdot
.77 .35028 Mdot
.77 .35028 Mdot
.77 .35043 Mdot
.77 .35119 Mdot
.77 .35136 Mdot
.77 .35138 Mdot
.77 .35153 Mdot
.77 .35161 Mdot
.77 .35228 Mdot
.77 .35281 Mdot
.77 .35283 Mdot
.77 .35285 Mdot
.77 .35402 Mdot
.77 .35407 Mdot
.77 .35486 Mdot
.77 .35529 Mdot
.77 .35632 Mdot
.77 .35636 Mdot
.77 .35726 Mdot
.77 .35742 Mdot
.77 .35752 Mdot
.77 .35884 Mdot
.77 .35902 Mdot
.77 .3598 Mdot
.77 .36006 Mdot
.77 .36025 Mdot
.77 .3603 Mdot
.77 .36139 Mdot
.77 .3622 Mdot
.77 .36227 Mdot
.77 .36341 Mdot
.77 .36355 Mdot
.77 .36391 Mdot
.77 .36428 Mdot
.77 .36561 Mdot
.77 .36602 Mdot
.77 .36835 Mdot
.77 .3688 Mdot
.77 .36974 Mdot
.77 .37098 Mdot
.77 .37122 Mdot
.77 .37236 Mdot
.77 .37274 Mdot
.77 .37291 Mdot
.77 .3731 Mdot
.77 .37384 Mdot
.77 .37445 Mdot
.77 .37531 Mdot
.77 .37538 Mdot
.77 .37539 Mdot
.77 .37571 Mdot
.77 .37636 Mdot
.77 .37643 Mdot
.77 .37652 Mdot
.77 .37705 Mdot
.77 .37705 Mdot
.77 .37749 Mdot
.77 .37803 Mdot
.77 .37914 Mdot
.77 .37939 Mdot
.77 .37955 Mdot
.77 .37975 Mdot
.77 .38022 Mdot
.77 .38034 Mdot
.77 .38186 Mdot
.77 .38214 Mdot
.77 .38219 Mdot
.77 .38264 Mdot
.77 .38267 Mdot
.77 .38361 Mdot
.77 .38382 Mdot
.77 .38436 Mdot
.77 .38472 Mdot
.77 .38549 Mdot
.77 .38623 Mdot
.77 .38642 Mdot
.77 .38689 Mdot
.77 .38874 Mdot
.77 .38914 Mdot
.77 .38921 Mdot
.77 .38991 Mdot
.77 .39033 Mdot
.77 .39147 Mdot
.77 .3925 Mdot
.77 .39255 Mdot
.77 .3928 Mdot
.77 .39308 Mdot
.77 .39311 Mdot
.77 .39323 Mdot
.77 .39371 Mdot
.77 .39461 Mdot
.77 .39572 Mdot
.77 .3961 Mdot
.77 .39688 Mdot
.77 .39713 Mdot
.77 .39722 Mdot
.77 .39787 Mdot
.77 .39948 Mdot
.77 .39959 Mdot
.77 .39985 Mdot
.77 .39986 Mdot
.77 .40029 Mdot
.77 .40125 Mdot
.77 .40203 Mdot
.77 .40255 Mdot
.77 .40322 Mdot
.77 .40409 Mdot
.77 .40413 Mdot
.77 .40426 Mdot
.77 .40428 Mdot
.77 .40428 Mdot
.77 .40454 Mdot
.77 .40469 Mdot
.77 .40511 Mdot
.77 .40542 Mdot
.77 .40628 Mdot
.77 .40685 Mdot
.77 .40692 Mdot
.77 .40779 Mdot
.77 .40848 Mdot
.77 .41064 Mdot
.77 .41126 Mdot
.77 .41176 Mdot
.77 .41308 Mdot
.77 .4134 Mdot
.77 .41383 Mdot
.77 .41385 Mdot
.77 .41394 Mdot
.77 .41439 Mdot
.77 .41624 Mdot
.77 .41689 Mdot
.77 .41718 Mdot
.77 .41754 Mdot
.77 .41779 Mdot
.77 .41786 Mdot
.77 .41844 Mdot
.77 .41873 Mdot
.77 .41876 Mdot
.77 .41971 Mdot
.77 .41999 Mdot
.77 .42078 Mdot
.77 .42078 Mdot
.77 .4212 Mdot
.77 .42221 Mdot
.77 .42319 Mdot
.77 .42326 Mdot
.77 .42332 Mdot
.77 .42364 Mdot
.77 .42422 Mdot
.77 .42447 Mdot
.77 .42761 Mdot
.77 .42772 Mdot
.77 .42791 Mdot
.77 .42955 Mdot
.77 .43003 Mdot
.77 .43051 Mdot
.77 .43072 Mdot
.77 .43078 Mdot
.77 .43091 Mdot
.77 .43189 Mdot
.77 .43222 Mdot
.77 .43253 Mdot
.77 .43268 Mdot
.77 .43354 Mdot
.77 .43405 Mdot
.77 .43584 Mdot
.77 .43613 Mdot
.77 .43647 Mdot
.77 .43663 Mdot
.77 .4371 Mdot
.77 .43773 Mdot
.77 .43805 Mdot
.77 .43935 Mdot
.77 .44008 Mdot
.77 .44044 Mdot
.77 .44067 Mdot
.77 .44109 Mdot
.77 .44151 Mdot
.77 .44168 Mdot
.77 .44267 Mdot
.77 .44353 Mdot
.77 .44393 Mdot
.77 .44403 Mdot
.77 .44417 Mdot
.77 .44442 Mdot
.77 .44566 Mdot
.77 .44576 Mdot
.77 .44615 Mdot
.77 .44647 Mdot
.77 .44684 Mdot
.77 .4474 Mdot
.77 .44752 Mdot
.77 .44759 Mdot
.77 .44804 Mdot
.77 .44829 Mdot
.77 .44876 Mdot
.77 .44883 Mdot
.77 .4492 Mdot
.77 .4495 Mdot
.77 .44964 Mdot
.77 .44989 Mdot
.77 .4505 Mdot
.77 .45088 Mdot
.77 .45094 Mdot
.77 .45161 Mdot
.77 .45175 Mdot
.77 .45182 Mdot
.77 .45187 Mdot
.77 .45209 Mdot
.77 .45255 Mdot
.77 .45309 Mdot
.77 .45375 Mdot
.77 .45433 Mdot
.77 .45501 Mdot
.77 .45519 Mdot
.77 .45552 Mdot
.77 .45603 Mdot
.77 .45618 Mdot
.77 .45711 Mdot
.77 .45738 Mdot
.77 .45783 Mdot
.77 .45806 Mdot
.77 .45823 Mdot
.77 .45881 Mdot
.77 .45895 Mdot
.77 .45919 Mdot
.77 .45944 Mdot
.77 .46043 Mdot
.77 .46215 Mdot
.77 .46244 Mdot
.77 .46316 Mdot
.77 .46387 Mdot
.77 .46387 Mdot
.77 .46426 Mdot
.77 .4644 Mdot
.77 .46488 Mdot
.77 .4658 Mdot
.77 .46611 Mdot
.77 .46724 Mdot
.77 .4683 Mdot
.77 .46854 Mdot
.77 .46884 Mdot
.77 .46988 Mdot
.77 .47066 Mdot
.77 .47093 Mdot
.77 .47149 Mdot
.77 .47197 Mdot
.77 .47238 Mdot
.77 .47396 Mdot
.77 .47409 Mdot
.77 .47489 Mdot
.77 .47523 Mdot
.77 .47571 Mdot
.77 .4764 Mdot
.77 .4771 Mdot
.77 .47734 Mdot
.77 .47784 Mdot
.77 .47836 Mdot
.77 .47908 Mdot
.77 .47992 Mdot
.77 .48013 Mdot
.77 .48022 Mdot
.77 .48055 Mdot
.77 .4813 Mdot
.77 .48203 Mdot
.77 .48205 Mdot
.77 .48285 Mdot
.77 .48453 Mdot
.77 .4846 Mdot
.77 .48489 Mdot
.77 .48506 Mdot
.77 .48685 Mdot
.77 .48809 Mdot
.77 .48983 Mdot
.77 .4902 Mdot
.77 .49106 Mdot
.77 .49154 Mdot
.77 .49162 Mdot
.77 .49173 Mdot
.77 .49274 Mdot
.77 .49318 Mdot
.77 .49363 Mdot
.77 .49465 Mdot
.77 .49488 Mdot
.77 .49525 Mdot
.77 .49526 Mdot
.77 .49565 Mdot
.77 .4964 Mdot
.77 .49681 Mdot
.77 .49782 Mdot
.77 .49817 Mdot
.77 .49821 Mdot
.77 .49862 Mdot
.77 .49922 Mdot
.77 .49944 Mdot
.77 .49954 Mdot
.77 .49981 Mdot
.77 .49989 Mdot
.77 .50004 Mdot
.77 .50039 Mdot
.77 .50052 Mdot
.77 .5008 Mdot
.77 .5017 Mdot
.77 .50321 Mdot
.77 .50425 Mdot
.77 .50487 Mdot
.77 .505 Mdot
.77 .50502 Mdot
.77 .50536 Mdot
.77 .5056 Mdot
.77 .50593 Mdot
.77 .50603 Mdot
.77 .5078 Mdot
.77 .50844 Mdot
.77 .50847 Mdot
.77 .50867 Mdot
.77 .50871 Mdot
.77 .50929 Mdot
.77 .50985 Mdot
.77 .51211 Mdot
.77 .51211 Mdot
.77 .51235 Mdot
.77 .51242 Mdot
.77 .51267 Mdot
.77 .513 Mdot
.77 .5141 Mdot
.77 .51419 Mdot
.77 .5145 Mdot
.77 .51451 Mdot
.77 .51491 Mdot
.77 .51599 Mdot
.77 .516 Mdot
.77 .51638 Mdot
.77 .5169 Mdot
.77 .51708 Mdot
.77 .5174 Mdot
.77 .5174 Mdot
.77 .51744 Mdot
.77 .51759 Mdot
.77 .51764 Mdot
.77 .51781 Mdot
.77 .5187 Mdot
.77 .51952 Mdot
.77 .51954 Mdot
.77 .52016 Mdot
.77 .52109 Mdot
.77 .52154 Mdot
.77 .52224 Mdot
.77 .52236 Mdot
.77 .52274 Mdot
.77 .52276 Mdot
.77 .52287 Mdot
.77 .52306 Mdot
.77 .52318 Mdot
.77 .52353 Mdot
.77 .52414 Mdot
.77 .52464 Mdot
.77 .52506 Mdot
.77 .52507 Mdot
.77 .52545 Mdot
.77 .52581 Mdot
.77 .5259 Mdot
.77 .52604 Mdot
.77 .5262 Mdot
.77 .52708 Mdot
.77 .52751 Mdot
.77 .52817 Mdot
.77 .52875 Mdot
.77 .52974 Mdot
.77 .53027 Mdot
.77 .53028 Mdot
.77 .53039 Mdot
.77 .53043 Mdot
.77 .53073 Mdot
.77 .531 Mdot
.77 .53106 Mdot
.77 .53114 Mdot
.77 .53129 Mdot
.77 .53217 Mdot
.77 .53266 Mdot
.77 .53276 Mdot
.77 .53287 Mdot
.77 .53338 Mdot
.77 .53381 Mdot
.77 .53455 Mdot
.77 .53462 Mdot
.77 .53503 Mdot
.77 .53559 Mdot
.77 .53622 Mdot
.77 .53693 Mdot
.77 .5374 Mdot
.77 .53745 Mdot
.77 .5376 Mdot
.77 .53782 Mdot
.77 .53833 Mdot
.77 .53885 Mdot
.77 .53909 Mdot
.77 .53944 Mdot
.77 .53956 Mdot
.77 .53997 Mdot
.77 .54017 Mdot
.77 .54104 Mdot
.77 .54107 Mdot
.77 .54111 Mdot
.77 .54153 Mdot
.77 .54158 Mdot
.77 .54184 Mdot
.77 .54247 Mdot
.77 .5431 Mdot
.77 .54326 Mdot
.77 .54337 Mdot
.77 .5435 Mdot
.77 .54364 Mdot
.77 .54381 Mdot
.77 .54399 Mdot
.77 .54414 Mdot
.77 .54436 Mdot
.77 .54491 Mdot
.77 .54537 Mdot
.77 .54584 Mdot
.77 .54623 Mdot
.77 .54623 Mdot
.77 .5467 Mdot
.77 .54676 Mdot
.77 .54678 Mdot
.77 .54684 Mdot
.77 .5474 Mdot
.77 .54768 Mdot
.77 .54769 Mdot
.77 .54775 Mdot
.77 .54836 Mdot
.77 .54849 Mdot
.77 .549 Mdot
.77 .54962 Mdot
.77 .54973 Mdot
.77 .54978 Mdot
.77 .54991 Mdot
.77 .55023 Mdot
.77 .55071 Mdot
.77 .55088 Mdot
.77 .55116 Mdot
.77 .55135 Mdot
.77 .55234 Mdot
.77 .5526 Mdot
.77 .55307 Mdot
.77 .55342 Mdot
.77 .55358 Mdot
.77 .5547 Mdot
.77 .55493 Mdot
.77 .55515 Mdot
.77 .55517 Mdot
.77 .55548 Mdot
.77 .5562 Mdot
.77 .55644 Mdot
.77 .55671 Mdot
.77 .55696 Mdot
.77 .55706 Mdot
.77 .55786 Mdot
.77 .5579 Mdot
.77 .55797 Mdot
.77 .55827 Mdot
.77 .55844 Mdot
.77 .55846 Mdot
.77 .55855 Mdot
.77 .55907 Mdot
.77 .55919 Mdot
.77 .55923 Mdot
.77 .55935 Mdot
.77 .55952 Mdot
.77 .55964 Mdot
.77 .55971 Mdot
.77 .55992 Mdot
.77 .55994 Mdot
.77 .56004 Mdot
.77 .56015 Mdot
.77 .56092 Mdot
.77 .56099 Mdot
.77 .56106 Mdot
.77 .56115 Mdot
.77 .56171 Mdot
.77 .56174 Mdot
.77 .56236 Mdot
.77 .56262 Mdot
.77 .56265 Mdot
.77 .56308 Mdot
.77 .56311 Mdot
.77 .56361 Mdot
.77 .56379 Mdot
.77 .5638 Mdot
.77 .56381 Mdot
.77 .56411 Mdot
.77 .56448 Mdot
.77 .56452 Mdot
.77 .56461 Mdot
.77 .56462 Mdot
.77 .56466 Mdot
.77 .56471 Mdot
.77 .56512 Mdot
.77 .5652 Mdot
.77 .56521 Mdot
.77 .56527 Mdot
.77 .56531 Mdot
.77 .56608 Mdot
.77 .56621 Mdot
.77 .56642 Mdot
.77 .56652 Mdot
.77 .56655 Mdot
.77 .56658 Mdot
.77 .56658 Mdot
.77 .56659 Mdot
.77 .5666 Mdot
.77 .56683 Mdot
.77 .5669 Mdot
.77 .56701 Mdot
.77 .56714 Mdot
.77 .56721 Mdot
.77 .56726 Mdot
.77 .56757 Mdot
.77 .56762 Mdot
.77 .56778 Mdot
.77 .56805 Mdot
.77 .56812 Mdot
.77 .56814 Mdot
.77 .56818 Mdot
.77 .56822 Mdot
.77 .56857 Mdot
.77 .56867 Mdot
.77 .56868 Mdot
.77 .56921 Mdot
.77 .56927 Mdot
.77 .56931 Mdot
.77 .56941 Mdot
.77 .56954 Mdot
.77 .56954 Mdot
.77 .56965 Mdot
.77 .56986 Mdot
.77 .56992 Mdot
.77 .56995 Mdot
.77 .56997 Mdot
.77 .57 Mdot
.77 .57015 Mdot
.77 .57022 Mdot
.77 .57027 Mdot
.77 .57027 Mdot
.77 .57036 Mdot
.77 .57049 Mdot
.77 .57049 Mdot
.77 .57061 Mdot
.77 .57069 Mdot
.77 .57079 Mdot
.77 .57081 Mdot
.77 .57083 Mdot
.77 .57088 Mdot
.77 .57106 Mdot
.77 .57121 Mdot
.77 .57133 Mdot
.77 .57168 Mdot
.77 .57174 Mdot
.77 .57195 Mdot
.77 .57199 Mdot
.77 .57215 Mdot
.77 .57216 Mdot
.77 .5724 Mdot
.77 .57256 Mdot
.77 .57258 Mdot
.77 .57274 Mdot
.77 .57277 Mdot
.77 .57289 Mdot
.77 .57307 Mdot
.77 .57316 Mdot
.77 .57317 Mdot
.77 .57331 Mdot
.77 .57332 Mdot
.77 .57346 Mdot
.77 .57347 Mdot
.77 .57351 Mdot
.77 .57362 Mdot
.77 .57362 Mdot
.77 .57364 Mdot
.77 .57385 Mdot
.77 .5739 Mdot
.77 .57393 Mdot
.77 .57393 Mdot
.77 .57394 Mdot
.77 .57394 Mdot
.77 .57402 Mdot
.77 .57409 Mdot
.77 .5741 Mdot
.77 .57418 Mdot
.77 .57431 Mdot
.77 .57444 Mdot
.77 .57461 Mdot
.77 .57467 Mdot
.77 .5747 Mdot
.77 .5748 Mdot
.77 .57482 Mdot
.77 .5749 Mdot
.77 .57492 Mdot
.77 .57492 Mdot
.77 .57507 Mdot
.77 .57516 Mdot
.77 .57538 Mdot
.77 .57545 Mdot
.77 .57553 Mdot
.77 .57553 Mdot
.77 .57567 Mdot
.77 .57568 Mdot
.77 .57574 Mdot
.77 .57575 Mdot
.77 .57587 Mdot
.77 .57591 Mdot
.77 .57597 Mdot
.77 .57597 Mdot
.77 .57603 Mdot
.77 .57603 Mdot
.77 .57605 Mdot
.77 .5762 Mdot
.77 .57623 Mdot
.77 .57624 Mdot
.77 .57624 Mdot
.77 .57624 Mdot
.77 .57624 Mdot
.772 .11251 Mdot
.772 .11251 Mdot
.772 .11254 Mdot
.772 .11255 Mdot
.772 .11258 Mdot
.772 .11267 Mdot
.772 .11281 Mdot
.772 .11282 Mdot
.772 .11285 Mdot
.772 .11286 Mdot
.772 .11346 Mdot
.772 .11365 Mdot
.772 .11367 Mdot
.772 .11424 Mdot
.772 .11444 Mdot
.772 .11454 Mdot
.772 .11458 Mdot
.772 .11511 Mdot
.772 .1152 Mdot
.772 .1152 Mdot
.772 .11551 Mdot
.772 .11556 Mdot
.772 .11589 Mdot
.772 .11643 Mdot
.772 .11659 Mdot
.772 .11737 Mdot
.772 .11899 Mdot
.772 .11899 Mdot
.772 .119 Mdot
.772 .11906 Mdot
.772 .11907 Mdot
.772 .11913 Mdot
.772 .11932 Mdot
.772 .1196 Mdot
.772 .11961 Mdot
.772 .11966 Mdot
.772 .11968 Mdot
.772 .11975 Mdot
.772 .12097 Mdot
.772 .12138 Mdot
.772 .12143 Mdot
.772 .12151 Mdot
.772 .12161 Mdot
.772 .12223 Mdot
.772 .12275 Mdot
.772 .12326 Mdot
.772 .12332 Mdot
.772 .12349 Mdot
.772 .1236 Mdot
.772 .12412 Mdot
.772 .12436 Mdot
.772 .12453 Mdot
.772 .12473 Mdot
.772 .12495 Mdot
.772 .12519 Mdot
.772 .12519 Mdot
.772 .12532 Mdot
.772 .12599 Mdot
.772 .12604 Mdot
.772 .12615 Mdot
.772 .12638 Mdot
.772 .12651 Mdot
.772 .12682 Mdot
.772 .12709 Mdot
.772 .12733 Mdot
.772 .12816 Mdot
.772 .12864 Mdot
.772 .12897 Mdot
.772 .12912 Mdot
.772 .12998 Mdot
.772 .13027 Mdot
.772 .13052 Mdot
.772 .13076 Mdot
.772 .13138 Mdot
.772 .13155 Mdot
.772 .13162 Mdot
.772 .1319 Mdot
.772 .13232 Mdot
.772 .13244 Mdot
.772 .13395 Mdot
.772 .13515 Mdot
.772 .13526 Mdot
.772 .13638 Mdot
.772 .13679 Mdot
.772 .13708 Mdot
.772 .13708 Mdot
.772 .13711 Mdot
.772 .13731 Mdot
.772 .13735 Mdot
.772 .1375 Mdot
.772 .13756 Mdot
.772 .13826 Mdot
.772 .13837 Mdot
.772 .13909 Mdot
.772 .13928 Mdot
.772 .13933 Mdot
.772 .1394 Mdot
.772 .13953 Mdot
.772 .13961 Mdot
.772 .13986 Mdot
.772 .14042 Mdot
.772 .14091 Mdot
.772 .1434 Mdot
.772 .14398 Mdot
.772 .14411 Mdot
.772 .14431 Mdot
.772 .14451 Mdot
.772 .14463 Mdot
.772 .14626 Mdot
.772 .1463 Mdot
.772 .14652 Mdot
.772 .14653 Mdot
.772 .14685 Mdot
.772 .14724 Mdot
.772 .14764 Mdot
.772 .14988 Mdot
.772 .15099 Mdot
.772 .15213 Mdot
.772 .15236 Mdot
.772 .15281 Mdot
.772 .15441 Mdot
.772 .15471 Mdot
.772 .15546 Mdot
.772 .15563 Mdot
.772 .15597 Mdot
.772 .15839 Mdot
.772 .15953 Mdot
.772 .15953 Mdot
.772 .15981 Mdot
.772 .16033 Mdot
.772 .16056 Mdot
.772 .16129 Mdot
.772 .16145 Mdot
.772 .16159 Mdot
.772 .16232 Mdot
.772 .1635 Mdot
.772 .16352 Mdot
.772 .16414 Mdot
.772 .16646 Mdot
.772 .16746 Mdot
.772 .1677 Mdot
.772 .1683 Mdot
.772 .16875 Mdot
.772 .16946 Mdot
.772 .17011 Mdot
.772 .17077 Mdot
.772 .17079 Mdot
.772 .17174 Mdot
.772 .17284 Mdot
.772 .17311 Mdot
.772 .1733 Mdot
.772 .17438 Mdot
.772 .17602 Mdot
.772 .17754 Mdot
.772 .17843 Mdot
.772 .17871 Mdot
.772 .17875 Mdot
.772 .1788 Mdot
.772 .17938 Mdot
.772 .18071 Mdot
.772 .18115 Mdot
.772 .18142 Mdot
.772 .18163 Mdot
.772 .18322 Mdot
.772 .18376 Mdot
.772 .18407 Mdot
.772 .18489 Mdot
.772 .18601 Mdot
.772 .18621 Mdot
.772 .18764 Mdot
.772 .18892 Mdot
.772 .18901 Mdot
.772 .19027 Mdot
.772 .19055 Mdot
.772 .1911 Mdot
.772 .19155 Mdot
.772 .192 Mdot
.772 .19257 Mdot
.772 .19317 Mdot
.772 .19339 Mdot
.772 .19347 Mdot
.772 .19351 Mdot
.772 .19362 Mdot
.772 .19448 Mdot
.772 .19505 Mdot
.772 .19702 Mdot
.772 .19785 Mdot
.772 .19804 Mdot
.772 .19845 Mdot
.772 .19911 Mdot
.772 .20011 Mdot
.772 .20038 Mdot
.772 .2007 Mdot
.772 .20264 Mdot
.772 .20298 Mdot
.772 .20332 Mdot
.772 .20414 Mdot
.772 .20681 Mdot
.772 .20858 Mdot
.772 .20933 Mdot
.772 .20943 Mdot
.772 .2099 Mdot
.772 .21052 Mdot
.772 .21148 Mdot
.772 .21218 Mdot
.772 .21256 Mdot
.772 .21261 Mdot
.772 .21261 Mdot
.772 .21895 Mdot
.772 .21984 Mdot
.772 .22015 Mdot
.772 .2208 Mdot
.772 .22201 Mdot
.772 .22373 Mdot
.772 .22545 Mdot
.772 .22669 Mdot
.772 .22802 Mdot
.772 .22827 Mdot
.772 .22828 Mdot
.772 .22949 Mdot
.772 .23018 Mdot
.772 .23028 Mdot
.772 .23035 Mdot
.772 .23068 Mdot
.772 .23255 Mdot
.772 .23255 Mdot
.772 .23278 Mdot
.772 .23279 Mdot
.772 .23405 Mdot
.772 .23408 Mdot
.772 .23411 Mdot
.772 .23435 Mdot
.772 .23476 Mdot
.772 .23477 Mdot
.772 .23531 Mdot
.772 .23575 Mdot
.772 .23634 Mdot
.772 .24032 Mdot
.772 .24034 Mdot
.772 .24109 Mdot
.772 .24132 Mdot
.772 .24153 Mdot
.772 .24181 Mdot
.772 .24391 Mdot
.772 .24478 Mdot
.772 .24491 Mdot
.772 .24589 Mdot
.772 .24721 Mdot
.772 .24755 Mdot
.772 .2476 Mdot
.772 .24761 Mdot
.772 .24773 Mdot
.772 .24797 Mdot
.772 .24838 Mdot
.772 .2489 Mdot
.772 .24941 Mdot
.772 .24997 Mdot
.772 .25065 Mdot
.772 .25111 Mdot
.772 .25249 Mdot
.772 .25492 Mdot
.772 .25634 Mdot
.772 .25822 Mdot
.772 .26167 Mdot
.772 .26173 Mdot
.772 .26218 Mdot
.772 .26646 Mdot
.772 .26721 Mdot
.772 .27109 Mdot
.772 .27129 Mdot
.772 .27321 Mdot
.772 .27419 Mdot
.772 .27439 Mdot
.772 .27487 Mdot
.772 .27546 Mdot
.772 .27623 Mdot
.772 .2771 Mdot
.772 .2795 Mdot
.772 .28039 Mdot
.772 .28102 Mdot
.772 .28185 Mdot
.772 .28253 Mdot
.772 .28325 Mdot
.772 .28369 Mdot
.772 .28409 Mdot
.772 .28599 Mdot
.772 .28896 Mdot
.772 .2943 Mdot
.772 .29554 Mdot
.772 .29581 Mdot
.772 .29737 Mdot
.772 .29745 Mdot
.772 .29807 Mdot
.772 .29807 Mdot
.772 .29826 Mdot
.772 .2994 Mdot
.772 .29951 Mdot
.772 .29973 Mdot
.772 .30182 Mdot
.772 .30189 Mdot
.772 .30249 Mdot
.772 .30508 Mdot
.772 .30514 Mdot
.772 .30529 Mdot
.772 .30533 Mdot
.772 .30725 Mdot
.772 .30768 Mdot
.772 .30885 Mdot
.772 .30918 Mdot
.772 .31026 Mdot
.772 .31174 Mdot
.772 .31778 Mdot
.772 .32129 Mdot
.772 .32602 Mdot
.772 .32602 Mdot
.772 .32604 Mdot
.772 .32611 Mdot
.772 .32612 Mdot
.772 .3262 Mdot
.772 .32645 Mdot
.772 .3268 Mdot
.772 .32682 Mdot
.772 .32688 Mdot
.772 .32691 Mdot
.772 .32699 Mdot
.772 .32846 Mdot
.772 .32892 Mdot
.772 .32898 Mdot
.772 .32918 Mdot
.772 .32986 Mdot
.772 .33041 Mdot
.772 .33094 Mdot
.772 .33101 Mdot
.772 .33117 Mdot
.772 .33129 Mdot
.772 .33181 Mdot
.772 .33221 Mdot
.772 .33241 Mdot
.772 .33261 Mdot
.772 .33284 Mdot
.772 .33284 Mdot
.772 .33296 Mdot
.772 .33358 Mdot
.772 .33363 Mdot
.772 .33373 Mdot
.772 .33406 Mdot
.772 .33457 Mdot
.772 .33591 Mdot
.772 .33631 Mdot
.772 .33725 Mdot
.772 .33745 Mdot
.772 .33813 Mdot
.772 .33826 Mdot
.772 .33832 Mdot
.772 .33885 Mdot
.772 .33894 Mdot
.772 .34007 Mdot
.772 .34101 Mdot
.772 .34209 Mdot
.772 .34228 Mdot
.772 .34228 Mdot
.772 .34231 Mdot
.772 .34245 Mdot
.772 .34247 Mdot
.772 .34262 Mdot
.772 .34309 Mdot
.772 .34377 Mdot
.772 .3438 Mdot
.772 .34393 Mdot
.772 .34398 Mdot
.772 .34415 Mdot
.772 .34451 Mdot
.772 .34639 Mdot
.772 .34682 Mdot
.772 .34707 Mdot
.772 .34714 Mdot
.772 .34811 Mdot
.772 .34813 Mdot
.772 .34826 Mdot
.772 .34827 Mdot
.772 .34846 Mdot
.772 .34868 Mdot
.772 .34892 Mdot
.772 .3502 Mdot
.772 .35144 Mdot
.772 .35182 Mdot
.772 .35267 Mdot
.772 .35284 Mdot
.772 .35324 Mdot
.772 .35332 Mdot
.772 .3535 Mdot
.772 .35476 Mdot
.772 .35534 Mdot
.772 .35548 Mdot
.772 .35574 Mdot
.772 .35622 Mdot
.772 .35673 Mdot
.772 .35731 Mdot
.772 .35732 Mdot
.772 .35762 Mdot
.772 .35874 Mdot
.772 .35921 Mdot
.772 .35932 Mdot
.772 .3596 Mdot
.772 .36014 Mdot
.772 .36044 Mdot
.772 .36075 Mdot
.772 .36075 Mdot
.772 .36119 Mdot
.772 .36181 Mdot
.772 .3619 Mdot
.772 .36238 Mdot
.772 .36378 Mdot
.772 .36417 Mdot
.772 .36429 Mdot
.772 .36431 Mdot
.772 .36433 Mdot
.772 .36458 Mdot
.772 .36515 Mdot
.772 .36534 Mdot
.772 .36546 Mdot
.772 .36622 Mdot
.772 .36645 Mdot
.772 .36658 Mdot
.772 .36747 Mdot
.772 .36858 Mdot
.772 .36925 Mdot
.772 .36947 Mdot
.772 .36983 Mdot
.772 .37039 Mdot
.772 .37105 Mdot
.772 .37182 Mdot
.772 .37222 Mdot
.772 .37238 Mdot
.772 .37263 Mdot
.772 .37302 Mdot
.772 .37399 Mdot
.772 .37425 Mdot
.772 .37456 Mdot
.772 .37557 Mdot
.772 .37654 Mdot
.772 .37729 Mdot
.772 .37755 Mdot
.772 .37771 Mdot
.772 .38 Mdot
.772 .38031 Mdot
.772 .38042 Mdot
.772 .38065 Mdot
.772 .38108 Mdot
.772 .38318 Mdot
.772 .38409 Mdot
.772 .38473 Mdot
.772 .38473 Mdot
.772 .38481 Mdot
.772 .38482 Mdot
.772 .38526 Mdot
.772 .38535 Mdot
.772 .38567 Mdot
.772 .38582 Mdot
.772 .38602 Mdot
.772 .38736 Mdot
.772 .38761 Mdot
.772 .38883 Mdot
.772 .38887 Mdot
.772 .38919 Mdot
.772 .38963 Mdot
.772 .38974 Mdot
.772 .3898 Mdot
.772 .38988 Mdot
.772 .39018 Mdot
.772 .39035 Mdot
.772 .39053 Mdot
.772 .39075 Mdot
.772 .3909 Mdot
.772 .39213 Mdot
.772 .39318 Mdot
.772 .39428 Mdot
.772 .39444 Mdot
.772 .39579 Mdot
.772 .39729 Mdot
.772 .39825 Mdot
.772 .3984 Mdot
.772 .39858 Mdot
.772 .39882 Mdot
.772 .39982 Mdot
.772 .40009 Mdot
.772 .40028 Mdot
.772 .40054 Mdot
.772 .40075 Mdot
.772 .40096 Mdot
.772 .4011 Mdot
.772 .40122 Mdot
.772 .40179 Mdot
.772 .40269 Mdot
.772 .4043 Mdot
.772 .40467 Mdot
.772 .40475 Mdot
.772 .40521 Mdot
.772 .40524 Mdot
.772 .40582 Mdot
.772 .40591 Mdot
.772 .40653 Mdot
.772 .40673 Mdot
.772 .4075 Mdot
.772 .40756 Mdot
.772 .40757 Mdot
.772 .40826 Mdot
.772 .40902 Mdot
.772 .41224 Mdot
.772 .41361 Mdot
.772 .41452 Mdot
.772 .41528 Mdot
.772 .41545 Mdot
.772 .41561 Mdot
.772 .41579 Mdot
.772 .41593 Mdot
.772 .41684 Mdot
.772 .4169 Mdot
.772 .41709 Mdot
.772 .41715 Mdot
.772 .4173 Mdot
.772 .41823 Mdot
.772 .41946 Mdot
.772 .41965 Mdot
.772 .41995 Mdot
.772 .42144 Mdot
.772 .42205 Mdot
.772 .42355 Mdot
.772 .42388 Mdot
.772 .42456 Mdot
.772 .4248 Mdot
.772 .42517 Mdot
.772 .42804 Mdot
.772 .42826 Mdot
.772 .42833 Mdot
.772 .42933 Mdot
.772 .43074 Mdot
.772 .43154 Mdot
.772 .43155 Mdot
.772 .43209 Mdot
.772 .4331 Mdot
.772 .43353 Mdot
.772 .43423 Mdot
.772 .4344 Mdot
.772 .43495 Mdot
.772 .43505 Mdot
.772 .43525 Mdot
.772 .43551 Mdot
.772 .43565 Mdot
.772 .43597 Mdot
.772 .43691 Mdot
.772 .43711 Mdot
.772 .43913 Mdot
.772 .43918 Mdot
.772 .43966 Mdot
.772 .43968 Mdot
.772 .44035 Mdot
.772 .4404 Mdot
.772 .44191 Mdot
.772 .44286 Mdot
.772 .44292 Mdot
.772 .44294 Mdot
.772 .44468 Mdot
.772 .4451 Mdot
.772 .44553 Mdot
.772 .44629 Mdot
.772 .44651 Mdot
.772 .44696 Mdot
.772 .44727 Mdot
.772 .44805 Mdot
.772 .44828 Mdot
.772 .44888 Mdot
.772 .44961 Mdot
.772 .45016 Mdot
.772 .45069 Mdot
.772 .45111 Mdot
.772 .45134 Mdot
.772 .45251 Mdot
.772 .45252 Mdot
.772 .45255 Mdot
.772 .45306 Mdot
.772 .45386 Mdot
.772 .45425 Mdot
.772 .45426 Mdot
.772 .45561 Mdot
.772 .4562 Mdot
.772 .45637 Mdot
.772 .45668 Mdot
.772 .45703 Mdot
.772 .45711 Mdot
.772 .45892 Mdot
.772 .46015 Mdot
.772 .46019 Mdot
.772 .4603 Mdot
.772 .46175 Mdot
.772 .46194 Mdot
.772 .46437 Mdot
.772 .46451 Mdot
.772 .46461 Mdot
.772 .46575 Mdot
.772 .46578 Mdot
.772 .46587 Mdot
.772 .46635 Mdot
.772 .46642 Mdot
.772 .46651 Mdot
.772 .46658 Mdot
.772 .46667 Mdot
.772 .46748 Mdot
.772 .4697 Mdot
.772 .47006 Mdot
.772 .4704 Mdot
.772 .47043 Mdot
.772 .47089 Mdot
.772 .47123 Mdot
.772 .47195 Mdot
.772 .47247 Mdot
.772 .47271 Mdot
.772 .47313 Mdot
.772 .47346 Mdot
.772 .47362 Mdot
.772 .47384 Mdot
.772 .47452 Mdot
.772 .47472 Mdot
.772 .47479 Mdot
.772 .47523 Mdot
.772 .47593 Mdot
.772 .47655 Mdot
.772 .47662 Mdot
.772 .47824 Mdot
.772 .47834 Mdot
.772 .47867 Mdot
.772 .47909 Mdot
.772 .47911 Mdot
.772 .48038 Mdot
.772 .48092 Mdot
.772 .48259 Mdot
.772 .48293 Mdot
.772 .48307 Mdot
.772 .48415 Mdot
.772 .48426 Mdot
.772 .48459 Mdot
.772 .48502 Mdot
.772 .48546 Mdot
.772 .4863 Mdot
.772 .48699 Mdot
.772 .48767 Mdot
.772 .48853 Mdot
.772 .48897 Mdot
.772 .48944 Mdot
.772 .48952 Mdot
.772 .48977 Mdot
.772 .48988 Mdot
.772 .48989 Mdot
.772 .48994 Mdot
.772 .49011 Mdot
.772 .49091 Mdot
.772 .49139 Mdot
.772 .4914 Mdot
.772 .49224 Mdot
.772 .49361 Mdot
.772 .49451 Mdot
.772 .49513 Mdot
.772 .49633 Mdot
.772 .4966 Mdot
.772 .49666 Mdot
.772 .49709 Mdot
.772 .49719 Mdot
.772 .49737 Mdot
.772 .49813 Mdot
.772 .49912 Mdot
.772 .49955 Mdot
.772 .49993 Mdot
.772 .50039 Mdot
.772 .50043 Mdot
.772 .50064 Mdot
.772 .50072 Mdot
.772 .50099 Mdot
.772 .50107 Mdot
.772 .50235 Mdot
.772 .50254 Mdot
.772 .50278 Mdot
.772 .50301 Mdot
.772 .50308 Mdot
.772 .50324 Mdot
.772 .50356 Mdot
.772 .50401 Mdot
.772 .50428 Mdot
.772 .50514 Mdot
.772 .50552 Mdot
.772 .50737 Mdot
.772 .50873 Mdot
.772 .51105 Mdot
.772 .51162 Mdot
.772 .51202 Mdot
.772 .51215 Mdot
.772 .51259 Mdot
.772 .51276 Mdot
.772 .51348 Mdot
.772 .5135 Mdot
.772 .51355 Mdot
.772 .51358 Mdot
.772 .51455 Mdot
.772 .51477 Mdot
.772 .5148 Mdot
.772 .51558 Mdot
.772 .51567 Mdot
.772 .5157 Mdot
.772 .51613 Mdot
.772 .5162 Mdot
.772 .5162 Mdot
.772 .51643 Mdot
.772 .51646 Mdot
.772 .51704 Mdot
.772 .51714 Mdot
.772 .5176 Mdot
.772 .51956 Mdot
.772 .52065 Mdot
.772 .52134 Mdot
.772 .52148 Mdot
.772 .52165 Mdot
.772 .52191 Mdot
.772 .52215 Mdot
.772 .52245 Mdot
.772 .52268 Mdot
.772 .523 Mdot
.772 .52386 Mdot
.772 .52417 Mdot
.772 .52445 Mdot
.772 .52466 Mdot
.772 .52483 Mdot
.772 .5249 Mdot
.772 .52525 Mdot
.772 .52594 Mdot
.772 .52601 Mdot
.772 .52738 Mdot
.772 .52765 Mdot
.772 .52915 Mdot
.772 .52931 Mdot
.772 .52933 Mdot
.772 .53053 Mdot
.772 .53119 Mdot
.772 .53168 Mdot
.772 .53252 Mdot
.772 .53299 Mdot
.772 .53315 Mdot
.772 .53339 Mdot
.772 .53358 Mdot
.772 .53375 Mdot
.772 .53393 Mdot
.772 .53407 Mdot
.772 .53415 Mdot
.772 .5342 Mdot
.772 .5342 Mdot
.772 .53421 Mdot
.772 .53433 Mdot
.772 .53478 Mdot
.772 .53512 Mdot
.772 .53516 Mdot
.772 .53546 Mdot
.772 .53617 Mdot
.772 .53627 Mdot
.772 .53634 Mdot
.772 .53642 Mdot
.772 .53667 Mdot
.772 .53668 Mdot
.772 .53802 Mdot
.772 .53822 Mdot
.772 .53837 Mdot
.772 .53855 Mdot
.772 .53855 Mdot
.772 .53869 Mdot
.772 .53877 Mdot
.772 .53878 Mdot
.772 .53879 Mdot
.772 .53921 Mdot
.772 .53922 Mdot
.772 .5393 Mdot
.772 .5393 Mdot
.772 .53992 Mdot
.772 .54003 Mdot
.772 .54005 Mdot
.772 .54008 Mdot
.772 .54032 Mdot
.772 .54072 Mdot
.772 .54072 Mdot
.772 .5408 Mdot
.772 .54125 Mdot
.772 .54166 Mdot
.772 .54223 Mdot
.772 .5428 Mdot
.772 .54319 Mdot
.772 .54341 Mdot
.772 .54351 Mdot
.772 .5438 Mdot
.772 .54587 Mdot
.772 .54587 Mdot
.772 .54589 Mdot
.772 .54601 Mdot
.772 .54624 Mdot
.772 .54655 Mdot
.772 .54676 Mdot
.772 .54691 Mdot
.772 .54694 Mdot
.772 .54718 Mdot
.772 .54775 Mdot
.772 .54862 Mdot
.772 .54888 Mdot
.772 .54899 Mdot
.772 .5491 Mdot
.772 .54972 Mdot
.772 .54982 Mdot
.772 .54991 Mdot
.772 .55023 Mdot
.772 .55044 Mdot
.772 .55057 Mdot
.772 .55063 Mdot
.772 .55089 Mdot
.772 .55152 Mdot
.772 .5517 Mdot
.772 .55198 Mdot
.772 .55201 Mdot
.772 .55202 Mdot
.772 .55205 Mdot
.772 .55212 Mdot
.772 .55231 Mdot
.772 .55249 Mdot
.772 .55263 Mdot
.772 .55278 Mdot
.772 .55295 Mdot
.772 .55304 Mdot
.772 .55344 Mdot
.772 .55347 Mdot
.772 .55387 Mdot
.772 .55432 Mdot
.772 .55438 Mdot
.772 .55473 Mdot
.772 .55499 Mdot
.772 .55509 Mdot
.772 .55526 Mdot
.772 .55575 Mdot
.772 .55582 Mdot
.772 .5559 Mdot
.772 .55604 Mdot
.772 .55645 Mdot
.772 .55663 Mdot
.772 .55665 Mdot
.772 .55666 Mdot
.772 .55675 Mdot
.772 .55703 Mdot
.772 .5575 Mdot
.772 .55801 Mdot
.772 .55834 Mdot
.772 .5584 Mdot
.772 .55848 Mdot
.772 .55882 Mdot
.772 .55912 Mdot
.772 .55912 Mdot
.772 .55932 Mdot
.772 .55953 Mdot
.772 .55974 Mdot
.772 .55988 Mdot
.772 .56007 Mdot
.772 .56014 Mdot
.772 .56045 Mdot
.772 .56116 Mdot
.772 .56135 Mdot
.772 .56135 Mdot
.772 .56171 Mdot
.772 .56194 Mdot
.772 .56198 Mdot
.772 .56203 Mdot
.772 .56225 Mdot
.772 .56232 Mdot
.772 .56248 Mdot
.772 .56256 Mdot
.772 .56291 Mdot
.772 .56364 Mdot
.772 .56375 Mdot
.772 .5638 Mdot
.772 .56402 Mdot
.772 .56412 Mdot
.772 .5646 Mdot
.772 .56473 Mdot
.772 .5648 Mdot
.772 .56515 Mdot
.772 .56548 Mdot
.772 .56615 Mdot
.772 .56627 Mdot
.772 .56639 Mdot
.772 .56649 Mdot
.772 .56649 Mdot
.772 .56656 Mdot
.772 .56657 Mdot
.772 .56705 Mdot
.772 .56709 Mdot
.772 .56715 Mdot
.772 .56721 Mdot
.772 .56725 Mdot
.772 .56742 Mdot
.772 .56816 Mdot
.772 .56831 Mdot
.772 .56847 Mdot
.772 .56855 Mdot
.772 .56857 Mdot
.772 .56861 Mdot
.772 .56863 Mdot
.772 .56865 Mdot
.772 .5687 Mdot
.772 .56892 Mdot
.772 .56895 Mdot
.772 .56916 Mdot
.772 .56918 Mdot
.772 .56922 Mdot
.772 .56923 Mdot
.772 .56929 Mdot
.772 .5693 Mdot
.772 .5693 Mdot
.772 .56939 Mdot
.772 .56951 Mdot
.772 .56984 Mdot
.772 .56987 Mdot
.772 .57022 Mdot
.772 .57067 Mdot
.772 .5707 Mdot
.772 .57083 Mdot
.772 .57091 Mdot
.772 .57093 Mdot
.772 .57098 Mdot
.772 .57117 Mdot
.772 .57124 Mdot
.772 .57131 Mdot
.772 .57139 Mdot
.772 .57165 Mdot
.772 .57169 Mdot
.772 .57179 Mdot
.772 .57193 Mdot
.772 .57217 Mdot
.772 .57224 Mdot
.772 .57232 Mdot
.772 .57241 Mdot
.772 .57245 Mdot
.772 .57252 Mdot
.772 .57255 Mdot
.772 .57256 Mdot
.772 .57276 Mdot
.772 .5728 Mdot
.772 .5728 Mdot
.772 .57287 Mdot
.772 .57293 Mdot
.772 .57299 Mdot
.772 .57304 Mdot
.772 .57311 Mdot
.772 .57326 Mdot
.772 .57329 Mdot
.772 .57334 Mdot
.772 .57336 Mdot
.772 .57351 Mdot
.772 .57366 Mdot
.772 .57384 Mdot
.772 .57387 Mdot
.772 .57389 Mdot
.772 .57391 Mdot
.772 .57403 Mdot
.772 .57438 Mdot
.772 .5744 Mdot
.772 .57441 Mdot
.772 .57442 Mdot
.772 .57443 Mdot
.772 .57451 Mdot
.772 .57456 Mdot
.772 .57458 Mdot
.772 .57458 Mdot
.772 .5746 Mdot
.772 .5746 Mdot
.772 .5746 Mdot
.772 .57507 Mdot
.772 .5753 Mdot
.772 .57535 Mdot
.772 .5755 Mdot
.772 .5756 Mdot
.772 .57561 Mdot
.772 .5757 Mdot
.772 .5757 Mdot
.772 .57573 Mdot
.772 .57588 Mdot
.772 .57589 Mdot
.772 .57592 Mdot
.772 .57598 Mdot
.772 .57614 Mdot
.772 .57615 Mdot
.772 .5762 Mdot
.772 .57638 Mdot
.772 .57638 Mdot
.772 .57639 Mdot
.772 .57639 Mdot
.772 .57643 Mdot
.772 .57646 Mdot
.772 .57647 Mdot
.772 .57647 Mdot
.772 .57648 Mdot
.772 .57648 Mdot
.774 .11173 Mdot
.774 .11174 Mdot
.774 .11174 Mdot
.774 .11174 Mdot
.774 .11175 Mdot
.774 .11179 Mdot
.774 .11183 Mdot
.774 .11186 Mdot
.774 .11191 Mdot
.774 .11194 Mdot
.774 .11195 Mdot
.774 .11242 Mdot
.774 .11245 Mdot
.774 .1125 Mdot
.774 .11258 Mdot
.774 .1128 Mdot
.774 .113 Mdot
.774 .11398 Mdot
.774 .11429 Mdot
.774 .11447 Mdot
.774 .11522 Mdot
.774 .11561 Mdot
.774 .11645 Mdot
.774 .11689 Mdot
.774 .1169 Mdot
.774 .1169 Mdot
.774 .11691 Mdot
.774 .11693 Mdot
.774 .11699 Mdot
.774 .11707 Mdot
.774 .11712 Mdot
.774 .11719 Mdot
.774 .11721 Mdot
.774 .11726 Mdot
.774 .11728 Mdot
.774 .11731 Mdot
.774 .11774 Mdot
.774 .11774 Mdot
.774 .11775 Mdot
.774 .11815 Mdot
.774 .11821 Mdot
.774 .11831 Mdot
.774 .11847 Mdot
.774 .1189 Mdot
.774 .11892 Mdot
.774 .11933 Mdot
.774 .11962 Mdot
.774 .12032 Mdot
.774 .1215 Mdot
.774 .12175 Mdot
.774 .12226 Mdot
.774 .12268 Mdot
.774 .12274 Mdot
.774 .1237 Mdot
.774 .12381 Mdot
.774 .12464 Mdot
.774 .12569 Mdot
.774 .12578 Mdot
.774 .12653 Mdot
.774 .12673 Mdot
.774 .12693 Mdot
.774 .12699 Mdot
.774 .12701 Mdot
.774 .12812 Mdot
.774 .12856 Mdot
.774 .12914 Mdot
.774 .12949 Mdot
.774 .12951 Mdot
.774 .12951 Mdot
.774 .12954 Mdot
.774 .12958 Mdot
.774 .12977 Mdot
.774 .13002 Mdot
.774 .13019 Mdot
.774 .13038 Mdot
.774 .1304 Mdot
.774 .13049 Mdot
.774 .13063 Mdot
.774 .13072 Mdot
.774 .13081 Mdot
.774 .13157 Mdot
.774 .1322 Mdot
.774 .13221 Mdot
.774 .13222 Mdot
.774 .13315 Mdot
.774 .13333 Mdot
.774 .13359 Mdot
.774 .1338 Mdot
.774 .13403 Mdot
.774 .13413 Mdot
.774 .13468 Mdot
.774 .13495 Mdot
.774 .13532 Mdot
.774 .13628 Mdot
.774 .13631 Mdot
.774 .13642 Mdot
.774 .13646 Mdot
.774 .13776 Mdot
.774 .13797 Mdot
.774 .13841 Mdot
.774 .13867 Mdot
.774 .13884 Mdot
.774 .13892 Mdot
.774 .13916 Mdot
.774 .14154 Mdot
.774 .14214 Mdot
.774 .14488 Mdot
.774 .14584 Mdot
.774 .14595 Mdot
.774 .14629 Mdot
.774 .14735 Mdot
.774 .14792 Mdot
.774 .14954 Mdot
.774 .15043 Mdot
.774 .15125 Mdot
.774 .1514 Mdot
.774 .15165 Mdot
.774 .15559 Mdot
.774 .15601 Mdot
.774 .15653 Mdot
.774 .15682 Mdot
.774 .15719 Mdot
.774 .15754 Mdot
.774 .1578 Mdot
.774 .15905 Mdot
.774 .16038 Mdot
.774 .16043 Mdot
.774 .16381 Mdot
.774 .16447 Mdot
.774 .1656 Mdot
.774 .16603 Mdot
.774 .16796 Mdot
.774 .16927 Mdot
.774 .16988 Mdot
.774 .17091 Mdot
.774 .17165 Mdot
.774 .17192 Mdot
.774 .17224 Mdot
.774 .17236 Mdot
.774 .17266 Mdot
.774 .17446 Mdot
.774 .1754 Mdot
.774 .17549 Mdot
.774 .17722 Mdot
.774 .17779 Mdot
.774 .17793 Mdot
.774 .17829 Mdot
.774 .17838 Mdot
.774 .17934 Mdot
.774 .18065 Mdot
.774 .18074 Mdot
.774 .18129 Mdot
.774 .18223 Mdot
.774 .1839 Mdot
.774 .18497 Mdot
.774 .1855 Mdot
.774 .18582 Mdot
.774 .18595 Mdot
.774 .18598 Mdot
.774 .18613 Mdot
.774 .18614 Mdot
.774 .1862 Mdot
.774 .18635 Mdot
.774 .18746 Mdot
.774 .18769 Mdot
.774 .18787 Mdot
.774 .18796 Mdot
.774 .18824 Mdot
.774 .18879 Mdot
.774 .18887 Mdot
.774 .18977 Mdot
.774 .18984 Mdot
.774 .19095 Mdot
.774 .19106 Mdot
.774 .19158 Mdot
.774 .19221 Mdot
.774 .1924 Mdot
.774 .19255 Mdot
.774 .19287 Mdot
.774 .19305 Mdot
.774 .19334 Mdot
.774 .1934 Mdot
.774 .19341 Mdot
.774 .19371 Mdot
.774 .19383 Mdot
.774 .19449 Mdot
.774 .19523 Mdot
.774 .1957 Mdot
.774 .19616 Mdot
.774 .19622 Mdot
.774 .19791 Mdot
.774 .19809 Mdot
.774 .19911 Mdot
.774 .19925 Mdot
.774 .19963 Mdot
.774 .19965 Mdot
.774 .19984 Mdot
.774 .20025 Mdot
.774 .20168 Mdot
.774 .20169 Mdot
.774 .20175 Mdot
.774 .2018 Mdot
.774 .20312 Mdot
.774 .20467 Mdot
.774 .20614 Mdot
.774 .20746 Mdot
.774 .20855 Mdot
.774 .20941 Mdot
.774 .20942 Mdot
.774 .20987 Mdot
.774 .21014 Mdot
.774 .21017 Mdot
.774 .21088 Mdot
.774 .21146 Mdot
.774 .21293 Mdot
.774 .21353 Mdot
.774 .21505 Mdot
.774 .21702 Mdot
.774 .21743 Mdot
.774 .21872 Mdot
.774 .21892 Mdot
.774 .21955 Mdot
.774 .21969 Mdot
.774 .22106 Mdot
.774 .22144 Mdot
.774 .22521 Mdot
.774 .22576 Mdot
.774 .22656 Mdot
.774 .22722 Mdot
.774 .22742 Mdot
.774 .22802 Mdot
.774 .22816 Mdot
.774 .22841 Mdot
.774 .22897 Mdot
.774 .23023 Mdot
.774 .23086 Mdot
.774 .23222 Mdot
.774 .23322 Mdot
.774 .23516 Mdot
.774 .23544 Mdot
.774 .23695 Mdot
.774 .23837 Mdot
.774 .23922 Mdot
.774 .24111 Mdot
.774 .24128 Mdot
.774 .24304 Mdot
.774 .24363 Mdot
.774 .24417 Mdot
.774 .24472 Mdot
.774 .24487 Mdot
.774 .24495 Mdot
.774 .2463 Mdot
.774 .24648 Mdot
.774 .24667 Mdot
.774 .24696 Mdot
.774 .24722 Mdot
.774 .24727 Mdot
.774 .24741 Mdot
.774 .24773 Mdot
.774 .24786 Mdot
.774 .24884 Mdot
.774 .24924 Mdot
.774 .24969 Mdot
.774 .25032 Mdot
.774 .25059 Mdot
.774 .25235 Mdot
.774 .2541 Mdot
.774 .25486 Mdot
.774 .25658 Mdot
.774 .25827 Mdot
.774 .25993 Mdot
.774 .26259 Mdot
.774 .26335 Mdot
.774 .26436 Mdot
.774 .26668 Mdot
.774 .26854 Mdot
.774 .26975 Mdot
.774 .27198 Mdot
.774 .27419 Mdot
.774 .27465 Mdot
.774 .27671 Mdot
.774 .27737 Mdot
.774 .28157 Mdot
.774 .28294 Mdot
.774 .2859 Mdot
.774 .28945 Mdot
.774 .29115 Mdot
.774 .29265 Mdot
.774 .29344 Mdot
.774 .29453 Mdot
.774 .29589 Mdot
.774 .29656 Mdot
.774 .29799 Mdot
.774 .30151 Mdot
.774 .30211 Mdot
.774 .30337 Mdot
.774 .30349 Mdot
.774 .30588 Mdot
.774 .30598 Mdot
.774 .30691 Mdot
.774 .30745 Mdot
.774 .30844 Mdot
.774 .30848 Mdot
.774 .3087 Mdot
.774 .30976 Mdot
.774 .30995 Mdot
.774 .31142 Mdot
.774 .31187 Mdot
.774 .31486 Mdot
.774 .31516 Mdot
.774 .319 Mdot
.774 .31969 Mdot
.774 .32417 Mdot
.774 .32418 Mdot
.774 .32419 Mdot
.774 .3242 Mdot
.774 .32422 Mdot
.774 .32431 Mdot
.774 .32442 Mdot
.774 .3245 Mdot
.774 .32464 Mdot
.774 .3247 Mdot
.774 .32474 Mdot
.774 .32478 Mdot
.774 .32537 Mdot
.774 .32538 Mdot
.774 .32593 Mdot
.774 .32601 Mdot
.774 .32613 Mdot
.774 .32634 Mdot
.774 .32691 Mdot
.774 .32741 Mdot
.774 .32776 Mdot
.774 .32989 Mdot
.774 .33015 Mdot
.774 .33069 Mdot
.774 .33113 Mdot
.774 .33118 Mdot
.774 .33225 Mdot
.774 .33303 Mdot
.774 .334 Mdot
.774 .33408 Mdot
.774 .33475 Mdot
.774 .33492 Mdot
.774 .33514 Mdot
.774 .33516 Mdot
.774 .33611 Mdot
.774 .33694 Mdot
.774 .33722 Mdot
.774 .33724 Mdot
.774 .33724 Mdot
.774 .33726 Mdot
.774 .33729 Mdot
.774 .33745 Mdot
.774 .33764 Mdot
.774 .33778 Mdot
.774 .33793 Mdot
.774 .33794 Mdot
.774 .33801 Mdot
.774 .33813 Mdot
.774 .33819 Mdot
.774 .33826 Mdot
.774 .33885 Mdot
.774 .33932 Mdot
.774 .33933 Mdot
.774 .33934 Mdot
.774 .34002 Mdot
.774 .34015 Mdot
.774 .34035 Mdot
.774 .3405 Mdot
.774 .34073 Mdot
.774 .34113 Mdot
.774 .34158 Mdot
.774 .34218 Mdot
.774 .34224 Mdot
.774 .34226 Mdot
.774 .34234 Mdot
.774 .34236 Mdot
.774 .34324 Mdot
.774 .34367 Mdot
.774 .34396 Mdot
.774 .34401 Mdot
.774 .34416 Mdot
.774 .34568 Mdot
.774 .34772 Mdot
.774 .34835 Mdot
.774 .34855 Mdot
.774 .34916 Mdot
.774 .3504 Mdot
.774 .3509 Mdot
.774 .35143 Mdot
.774 .35157 Mdot
.774 .35389 Mdot
.774 .35416 Mdot
.774 .35431 Mdot
.774 .3545 Mdot
.774 .35481 Mdot
.774 .35611 Mdot
.774 .35614 Mdot
.774 .35779 Mdot
.774 .35865 Mdot
.774 .35885 Mdot
.774 .36037 Mdot
.774 .36065 Mdot
.774 .36112 Mdot
.774 .36158 Mdot
.774 .36172 Mdot
.774 .36178 Mdot
.774 .36191 Mdot
.774 .36272 Mdot
.774 .36313 Mdot
.774 .36418 Mdot
.774 .36424 Mdot
.774 .3644 Mdot
.774 .36443 Mdot
.774 .36485 Mdot
.774 .36541 Mdot
.774 .36545 Mdot
.774 .36608 Mdot
.774 .36678 Mdot
.774 .36723 Mdot
.774 .36758 Mdot
.774 .36763 Mdot
.774 .36765 Mdot
.774 .36771 Mdot
.774 .36774 Mdot
.774 .3678 Mdot
.774 .36825 Mdot
.774 .36842 Mdot
.774 .36846 Mdot
.774 .36857 Mdot
.774 .36883 Mdot
.774 .36922 Mdot
.774 .36967 Mdot
.774 .36971 Mdot
.774 .36992 Mdot
.774 .37025 Mdot
.774 .37044 Mdot
.774 .37051 Mdot
.774 .37064 Mdot
.774 .37065 Mdot
.774 .37175 Mdot
.774 .37241 Mdot
.774 .37248 Mdot
.774 .37287 Mdot
.774 .37293 Mdot
.774 .37308 Mdot
.774 .37386 Mdot
.774 .37389 Mdot
.774 .37391 Mdot
.774 .37554 Mdot
.774 .37603 Mdot
.774 .37644 Mdot
.774 .37676 Mdot
.774 .37703 Mdot
.774 .37704 Mdot
.774 .37729 Mdot
.774 .37751 Mdot
.774 .37804 Mdot
.774 .37826 Mdot
.774 .37952 Mdot
.774 .38012 Mdot
.774 .38019 Mdot
.774 .38042 Mdot
.774 .38047 Mdot
.774 .38095 Mdot
.774 .3824 Mdot
.774 .3831 Mdot
.774 .38317 Mdot
.774 .38338 Mdot
.774 .38343 Mdot
.774 .38351 Mdot
.774 .3837 Mdot
.774 .38414 Mdot
.774 .38435 Mdot
.774 .38515 Mdot
.774 .3859 Mdot
.774 .38641 Mdot
.774 .38689 Mdot
.774 .38785 Mdot
.774 .38844 Mdot
.774 .38863 Mdot
.774 .38881 Mdot
.774 .38899 Mdot
.774 .38904 Mdot
.774 .38951 Mdot
.774 .38957 Mdot
.774 .38972 Mdot
.774 .38981 Mdot
.774 .38982 Mdot
.774 .38997 Mdot
.774 .39034 Mdot
.774 .39046 Mdot
.774 .3909 Mdot
.774 .39203 Mdot
.774 .39336 Mdot
.774 .39389 Mdot
.774 .39473 Mdot
.774 .39497 Mdot
.774 .39529 Mdot
.774 .39601 Mdot
.774 .39766 Mdot
.774 .40191 Mdot
.774 .40349 Mdot
.774 .40394 Mdot
.774 .40417 Mdot
.774 .4049 Mdot
.774 .40553 Mdot
.774 .40675 Mdot
.774 .40712 Mdot
.774 .40832 Mdot
.774 .40869 Mdot
.774 .409 Mdot
.774 .40905 Mdot
.774 .40962 Mdot
.774 .41049 Mdot
.774 .41169 Mdot
.774 .41354 Mdot
.774 .41354 Mdot
.774 .41422 Mdot
.774 .41521 Mdot
.774 .41551 Mdot
.774 .41604 Mdot
.774 .41686 Mdot
.774 .41714 Mdot
.774 .41741 Mdot
.774 .41774 Mdot
.774 .41841 Mdot
.774 .41888 Mdot
.774 .42085 Mdot
.774 .42196 Mdot
.774 .42398 Mdot
.774 .42481 Mdot
.774 .42583 Mdot
.774 .42587 Mdot
.774 .42641 Mdot
.774 .42677 Mdot
.774 .4271 Mdot
.774 .42714 Mdot
.774 .42784 Mdot
.774 .42834 Mdot
.774 .42923 Mdot
.774 .43028 Mdot
.774 .43079 Mdot
.774 .43156 Mdot
.774 .43187 Mdot
.774 .43194 Mdot
.774 .43291 Mdot
.774 .43337 Mdot
.774 .43346 Mdot
.774 .43639 Mdot
.774 .4374 Mdot
.774 .43756 Mdot
.774 .43782 Mdot
.774 .43889 Mdot
.774 .43981 Mdot
.774 .43991 Mdot
.774 .44114 Mdot
.774 .44228 Mdot
.774 .44326 Mdot
.774 .44395 Mdot
.774 .44404 Mdot
.774 .44406 Mdot
.774 .44434 Mdot
.774 .44572 Mdot
.774 .44762 Mdot
.774 .44774 Mdot
.774 .45 Mdot
.774 .4511 Mdot
.774 .45185 Mdot
.774 .45206 Mdot
.774 .45296 Mdot
.774 .45427 Mdot
.774 .45476 Mdot
.774 .45533 Mdot
.774 .45546 Mdot
.774 .45554 Mdot
.774 .45608 Mdot
.774 .45789 Mdot
.774 .45839 Mdot
.774 .45842 Mdot
.774 .45858 Mdot
.774 .45924 Mdot
.774 .45978 Mdot
.774 .46086 Mdot
.774 .46103 Mdot
.774 .46149 Mdot
.774 .46345 Mdot
.774 .46401 Mdot
.774 .46498 Mdot
.774 .46521 Mdot
.774 .46554 Mdot
.774 .46571 Mdot
.774 .46584 Mdot
.774 .46598 Mdot
.774 .46726 Mdot
.774 .4676 Mdot
.774 .46907 Mdot
.774 .46949 Mdot
.774 .46976 Mdot
.774 .46979 Mdot
.774 .46994 Mdot
.774 .47086 Mdot
.774 .47144 Mdot
.774 .47241 Mdot
.774 .47514 Mdot
.774 .47623 Mdot
.774 .47638 Mdot
.774 .47688 Mdot
.774 .47712 Mdot
.774 .47773 Mdot
.774 .47824 Mdot
.774 .47844 Mdot
.774 .4785 Mdot
.774 .47866 Mdot
.774 .47873 Mdot
.774 .47874 Mdot
.774 .47878 Mdot
.774 .47885 Mdot
.774 .47909 Mdot
.774 .47927 Mdot
.774 .4805 Mdot
.774 .48084 Mdot
.774 .4812 Mdot
.774 .48129 Mdot
.774 .48149 Mdot
.774 .48163 Mdot
.774 .48207 Mdot
.774 .48293 Mdot
.774 .48295 Mdot
.774 .48305 Mdot
.774 .48433 Mdot
.774 .48445 Mdot
.774 .48456 Mdot
.774 .4851 Mdot
.774 .48617 Mdot
.774 .48624 Mdot
.774 .48626 Mdot
.774 .48643 Mdot
.774 .48675 Mdot
.774 .48722 Mdot
.774 .48729 Mdot
.774 .48812 Mdot
.774 .48817 Mdot
.774 .48819 Mdot
.774 .48848 Mdot
.774 .4887 Mdot
.774 .48919 Mdot
.774 .48946 Mdot
.774 .48972 Mdot
.774 .48989 Mdot
.774 .48998 Mdot
.774 .49 Mdot
.774 .49045 Mdot
.774 .49062 Mdot
.774 .49096 Mdot
.774 .49162 Mdot
.774 .4927 Mdot
.774 .4934 Mdot
.774 .49395 Mdot
.774 .49408 Mdot
.774 .49416 Mdot
.774 .49557 Mdot
.774 .49662 Mdot
.774 .49688 Mdot
.774 .49833 Mdot
.774 .49839 Mdot
.774 .49853 Mdot
.774 .49906 Mdot
.774 .49907 Mdot
.774 .4991 Mdot
.774 .49938 Mdot
.774 .49996 Mdot
.774 .50001 Mdot
.774 .50048 Mdot
.774 .50085 Mdot
.774 .50125 Mdot
.774 .50196 Mdot
.774 .50197 Mdot
.774 .50206 Mdot
.774 .50213 Mdot
.774 .50239 Mdot
.774 .50312 Mdot
.774 .50354 Mdot
.774 .50395 Mdot
.774 .50489 Mdot
.774 .50583 Mdot
.774 .50583 Mdot
.774 .50606 Mdot
.774 .50804 Mdot
.774 .50831 Mdot
.774 .50979 Mdot
.774 .50991 Mdot
.774 .51105 Mdot
.774 .51122 Mdot
.774 .51178 Mdot
.774 .51185 Mdot
.774 .51226 Mdot
.774 .51234 Mdot
.774 .51235 Mdot
.774 .51273 Mdot
.774 .51293 Mdot
.774 .51328 Mdot
.774 .51332 Mdot
.774 .51422 Mdot
.774 .51427 Mdot
.774 .51474 Mdot
.774 .51496 Mdot
.774 .51628 Mdot
.774 .51681 Mdot
.774 .51706 Mdot
.774 .51756 Mdot
.774 .51796 Mdot
.774 .51825 Mdot
.774 .5188 Mdot
.774 .51943 Mdot
.774 .52072 Mdot
.774 .5218 Mdot
.774 .52229 Mdot
.774 .52381 Mdot
.774 .52404 Mdot
.774 .52478 Mdot
.774 .52494 Mdot
.774 .52573 Mdot
.774 .52652 Mdot
.774 .52695 Mdot
.774 .52761 Mdot
.774 .52842 Mdot
.774 .52878 Mdot
.774 .52904 Mdot
.774 .52998 Mdot
.774 .53055 Mdot
.774 .53114 Mdot
.774 .53173 Mdot
.774 .532 Mdot
.774 .5326 Mdot
.774 .53321 Mdot
.774 .5333 Mdot
.774 .53352 Mdot
.774 .53367 Mdot
.774 .53381 Mdot
.774 .53414 Mdot
.774 .53419 Mdot
.774 .5343 Mdot
.774 .53435 Mdot
.774 .53436 Mdot
.774 .53445 Mdot
.774 .53455 Mdot
.774 .53462 Mdot
.774 .53468 Mdot
.774 .53514 Mdot
.774 .53516 Mdot
.774 .53522 Mdot
.774 .5354 Mdot
.774 .53559 Mdot
.774 .53579 Mdot
.774 .53639 Mdot
.774 .53644 Mdot
.774 .53708 Mdot
.774 .53737 Mdot
.774 .53785 Mdot
.774 .53836 Mdot
.774 .53845 Mdot
.774 .5391 Mdot
.774 .53943 Mdot
.774 .53989 Mdot
.774 .5401 Mdot
.774 .54052 Mdot
.774 .54071 Mdot
.774 .54079 Mdot
.774 .54084 Mdot
.774 .54103 Mdot
.774 .5411 Mdot
.774 .54132 Mdot
.774 .54159 Mdot
.774 .54177 Mdot
.774 .54301 Mdot
.774 .54314 Mdot
.774 .54359 Mdot
.774 .54363 Mdot
.774 .54384 Mdot
.774 .54391 Mdot
.774 .54433 Mdot
.774 .54446 Mdot
.774 .54511 Mdot
.774 .5456 Mdot
.774 .5458 Mdot
.774 .54628 Mdot
.774 .54647 Mdot
.774 .54669 Mdot
.774 .5467 Mdot
.774 .54679 Mdot
.774 .54694 Mdot
.774 .54694 Mdot
.774 .54722 Mdot
.774 .54757 Mdot
.774 .548 Mdot
.774 .54847 Mdot
.774 .54897 Mdot
.774 .54939 Mdot
.774 .54941 Mdot
.774 .54943 Mdot
.774 .54943 Mdot
.774 .54989 Mdot
.774 .55002 Mdot
.774 .55008 Mdot
.774 .55009 Mdot
.774 .55021 Mdot
.774 .55025 Mdot
.774 .55058 Mdot
.774 .55064 Mdot
.774 .55118 Mdot
.774 .55119 Mdot
.774 .55134 Mdot
.774 .55149 Mdot
.774 .55172 Mdot
.774 .55194 Mdot
.774 .55197 Mdot
.774 .55207 Mdot
.774 .55207 Mdot
.774 .55209 Mdot
.774 .55218 Mdot
.774 .55224 Mdot
.774 .55234 Mdot
.774 .55239 Mdot
.774 .55245 Mdot
.774 .55265 Mdot
.774 .55281 Mdot
.774 .55285 Mdot
.774 .5532 Mdot
.774 .55322 Mdot
.774 .5535 Mdot
.774 .55353 Mdot
.774 .5537 Mdot
.774 .55379 Mdot
.774 .55382 Mdot
.774 .55388 Mdot
.774 .55395 Mdot
.774 .55429 Mdot
.774 .55434 Mdot
.774 .55436 Mdot
.774 .55436 Mdot
.774 .55441 Mdot
.774 .55442 Mdot
.774 .55446 Mdot
.774 .55456 Mdot
.774 .55473 Mdot
.774 .55507 Mdot
.774 .55559 Mdot
.774 .55588 Mdot
.774 .55605 Mdot
.774 .55608 Mdot
.774 .55649 Mdot
.774 .55679 Mdot
.774 .55681 Mdot
.774 .55693 Mdot
.774 .55697 Mdot
.774 .55715 Mdot
.774 .55768 Mdot
.774 .55771 Mdot
.774 .558 Mdot
.774 .55856 Mdot
.774 .55865 Mdot
.774 .55869 Mdot
.774 .55879 Mdot
.774 .55887 Mdot
.774 .5591 Mdot
.774 .55942 Mdot
.774 .5596 Mdot
.774 .56001 Mdot
.774 .5606 Mdot
.774 .56073 Mdot
.774 .56108 Mdot
.774 .56128 Mdot
.774 .56231 Mdot
.774 .56232 Mdot
.774 .56273 Mdot
.774 .56311 Mdot
.774 .56318 Mdot
.774 .56329 Mdot
.774 .5634 Mdot
.774 .56349 Mdot
.774 .56365 Mdot
.774 .56378 Mdot
.774 .56496 Mdot
.774 .56504 Mdot
.774 .56509 Mdot
.774 .56533 Mdot
.774 .5656 Mdot
.774 .56609 Mdot
.774 .56626 Mdot
.774 .56657 Mdot
.774 .56668 Mdot
.774 .56671 Mdot
.774 .567 Mdot
.774 .56781 Mdot
.774 .56799 Mdot
.774 .5687 Mdot
.774 .56877 Mdot
.774 .56879 Mdot
.774 .56884 Mdot
.774 .56892 Mdot
.774 .56905 Mdot
.774 .56911 Mdot
.774 .5695 Mdot
.774 .56951 Mdot
.774 .56954 Mdot
.774 .56955 Mdot
.774 .56984 Mdot
.774 .56994 Mdot
.774 .57002 Mdot
.774 .57019 Mdot
.774 .57022 Mdot
.774 .57028 Mdot
.774 .57035 Mdot
.774 .57042 Mdot
.774 .57048 Mdot
.774 .57075 Mdot
.774 .57075 Mdot
.774 .57076 Mdot
.774 .57094 Mdot
.774 .57117 Mdot
.774 .57119 Mdot
.774 .57122 Mdot
.774 .57126 Mdot
.774 .57128 Mdot
.774 .57129 Mdot
.774 .57135 Mdot
.774 .5714 Mdot
.774 .57147 Mdot
.774 .57153 Mdot
.774 .57154 Mdot
.774 .57155 Mdot
.774 .57155 Mdot
.774 .57155 Mdot
.774 .57165 Mdot
.774 .57183 Mdot
.774 .57195 Mdot
.774 .57228 Mdot
.774 .57229 Mdot
.774 .5723 Mdot
.774 .57236 Mdot
.774 .57242 Mdot
.774 .57264 Mdot
.774 .57266 Mdot
.774 .57297 Mdot
.774 .57321 Mdot
.774 .57325 Mdot
.774 .57353 Mdot
.774 .57354 Mdot
.774 .57367 Mdot
.774 .57382 Mdot
.774 .57389 Mdot
.774 .57423 Mdot
.774 .57443 Mdot
.774 .57452 Mdot
.774 .57464 Mdot
.774 .57464 Mdot
.774 .57477 Mdot
.774 .57481 Mdot
.774 .57484 Mdot
.774 .57486 Mdot
.774 .57498 Mdot
.774 .57498 Mdot
.774 .57498 Mdot
.774 .5751 Mdot
.774 .57511 Mdot
.774 .57512 Mdot
.774 .57513 Mdot
.774 .57514 Mdot
.774 .57516 Mdot
.774 .57517 Mdot
.774 .5752 Mdot
.774 .57521 Mdot
.774 .57522 Mdot
.774 .57522 Mdot
.774 .57522 Mdot
.774 .57522 Mdot
.774 .57535 Mdot
.774 .5756 Mdot
.774 .57571 Mdot
.774 .57593 Mdot
.774 .57598 Mdot
.774 .57607 Mdot
.774 .57635 Mdot
.774 .57641 Mdot
.774 .57647 Mdot
.774 .57649 Mdot
.774 .57651 Mdot
.774 .57652 Mdot
.774 .57665 Mdot
.774 .57665 Mdot
.774 .57666 Mdot
.774 .57668 Mdot
.774 .57669 Mdot
.774 .5767 Mdot
.774 .57671 Mdot
.774 .57671 Mdot
.774 .57671 Mdot
.774 .57671 Mdot
.774 .57671 Mdot
.776 .11096 Mdot
.776 .111 Mdot
.776 .11103 Mdot
.776 .11106 Mdot
.776 .1111 Mdot
.776 .11166 Mdot
.776 .11195 Mdot
.776 .11197 Mdot
.776 .11223 Mdot
.776 .11227 Mdot
.776 .11239 Mdot
.776 .11241 Mdot
.776 .11257 Mdot
.776 .11266 Mdot
.776 .11335 Mdot
.776 .11389 Mdot
.776 .11401 Mdot
.776 .11432 Mdot
.776 .11462 Mdot
.776 .11465 Mdot
.776 .11494 Mdot
.776 .11501 Mdot
.776 .11505 Mdot
.776 .1151 Mdot
.776 .11515 Mdot
.776 .11551 Mdot
.776 .1156 Mdot
.776 .11597 Mdot
.776 .11608 Mdot
.776 .11609 Mdot
.776 .11634 Mdot
.776 .1166 Mdot
.776 .11663 Mdot
.776 .11712 Mdot
.776 .11721 Mdot
.776 .11726 Mdot
.776 .11738 Mdot
.776 .11744 Mdot
.776 .11746 Mdot
.776 .1177 Mdot
.776 .11778 Mdot
.776 .11779 Mdot
.776 .11796 Mdot
.776 .11868 Mdot
.776 .11923 Mdot
.776 .11943 Mdot
.776 .12065 Mdot
.776 .12094 Mdot
.776 .1217 Mdot
.776 .12199 Mdot
.776 .1223 Mdot
.776 .12245 Mdot
.776 .12252 Mdot
.776 .12253 Mdot
.776 .12317 Mdot
.776 .12326 Mdot
.776 .12345 Mdot
.776 .12355 Mdot
.776 .12369 Mdot
.776 .12383 Mdot
.776 .1244 Mdot
.776 .12453 Mdot
.776 .12481 Mdot
.776 .12499 Mdot
.776 .12506 Mdot
.776 .12559 Mdot
.776 .12612 Mdot
.776 .12642 Mdot
.776 .12644 Mdot
.776 .12646 Mdot
.776 .12677 Mdot
.776 .1269 Mdot
.776 .12694 Mdot
.776 .12707 Mdot
.776 .1272 Mdot
.776 .12733 Mdot
.776 .12801 Mdot
.776 .12809 Mdot
.776 .12843 Mdot
.776 .12848 Mdot
.776 .12955 Mdot
.776 .12961 Mdot
.776 .12961 Mdot
.776 .12989 Mdot
.776 .13008 Mdot
.776 .13045 Mdot
.776 .13064 Mdot
.776 .13072 Mdot
.776 .13096 Mdot
.776 .13147 Mdot
.776 .13149 Mdot
.776 .13163 Mdot
.776 .13176 Mdot
.776 .13182 Mdot
.776 .13191 Mdot
.776 .13239 Mdot
.776 .13381 Mdot
.776 .13456 Mdot
.776 .13466 Mdot
.776 .13487 Mdot
.776 .1349 Mdot
.776 .13635 Mdot
.776 .13687 Mdot
.776 .13761 Mdot
.776 .13764 Mdot
.776 .13772 Mdot
.776 .1383 Mdot
.776 .13928 Mdot
.776 .13944 Mdot
.776 .1396 Mdot
.776 .14025 Mdot
.776 .14193 Mdot
.776 .14235 Mdot
.776 .14261 Mdot
.776 .14352 Mdot
.776 .14353 Mdot
.776 .14406 Mdot
.776 .14418 Mdot
.776 .14468 Mdot
.776 .14552 Mdot
.776 .14667 Mdot
.776 .14777 Mdot
.776 .14786 Mdot
.776 .14791 Mdot
.776 .14906 Mdot
.776 .14924 Mdot
.776 .14983 Mdot
.776 .14991 Mdot
.776 .15021 Mdot
.776 .15028 Mdot
.776 .1508 Mdot
.776 .15184 Mdot
.776 .15203 Mdot
.776 .15312 Mdot
.776 .15321 Mdot
.776 .15354 Mdot
.776 .1544 Mdot
.776 .15488 Mdot
.776 .15512 Mdot
.776 .15552 Mdot
.776 .1562 Mdot
.776 .15887 Mdot
.776 .1595 Mdot
.776 .16 Mdot
.776 .16086 Mdot
.776 .16174 Mdot
.776 .16178 Mdot
.776 .16184 Mdot
.776 .16205 Mdot
.776 .16314 Mdot
.776 .16341 Mdot
.776 .16469 Mdot
.776 .16531 Mdot
.776 .16543 Mdot
.776 .16738 Mdot
.776 .16891 Mdot
.776 .16905 Mdot
.776 .16916 Mdot
.776 .17016 Mdot
.776 .17076 Mdot
.776 .17112 Mdot
.776 .17142 Mdot
.776 .17159 Mdot
.776 .17165 Mdot
.776 .17231 Mdot
.776 .17259 Mdot
.776 .17298 Mdot
.776 .17368 Mdot
.776 .17411 Mdot
.776 .17448 Mdot
.776 .17733 Mdot
.776 .17747 Mdot
.776 .1778 Mdot
.776 .17965 Mdot
.776 .1799 Mdot
.776 .18249 Mdot
.776 .18273 Mdot
.776 .18591 Mdot
.776 .18625 Mdot
.776 .18627 Mdot
.776 .18682 Mdot
.776 .18787 Mdot
.776 .1882 Mdot
.776 .18891 Mdot
.776 .18946 Mdot
.776 .18966 Mdot
.776 .1899 Mdot
.776 .19055 Mdot
.776 .1909 Mdot
.776 .19105 Mdot
.776 .19217 Mdot
.776 .19265 Mdot
.776 .19365 Mdot
.776 .19408 Mdot
.776 .19509 Mdot
.776 .19676 Mdot
.776 .19707 Mdot
.776 .19719 Mdot
.776 .19801 Mdot
.776 .1981 Mdot
.776 .19838 Mdot
.776 .19882 Mdot
.776 .19914 Mdot
.776 .19968 Mdot
.776 .1999 Mdot
.776 .20038 Mdot
.776 .20138 Mdot
.776 .20262 Mdot
.776 .20423 Mdot
.776 .2075 Mdot
.776 .20977 Mdot
.776 .21108 Mdot
.776 .21133 Mdot
.776 .21137 Mdot
.776 .21168 Mdot
.776 .21424 Mdot
.776 .21605 Mdot
.776 .21643 Mdot
.776 .21672 Mdot
.776 .21706 Mdot
.776 .21707 Mdot
.776 .21805 Mdot
.776 .2182 Mdot
.776 .21961 Mdot
.776 .22191 Mdot
.776 .2234 Mdot
.776 .22388 Mdot
.776 .22421 Mdot
.776 .22757 Mdot
.776 .22759 Mdot
.776 .22762 Mdot
.776 .23099 Mdot
.776 .23222 Mdot
.776 .23461 Mdot
.776 .23589 Mdot
.776 .23605 Mdot
.776 .23658 Mdot
.776 .23738 Mdot
.776 .23829 Mdot
.776 .23851 Mdot
.776 .2393 Mdot
.776 .24044 Mdot
.776 .24443 Mdot
.776 .24462 Mdot
.776 .2452 Mdot
.776 .24704 Mdot
.776 .24813 Mdot
.776 .24827 Mdot
.776 .24853 Mdot
.776 .24863 Mdot
.776 .24871 Mdot
.776 .24922 Mdot
.776 .25371 Mdot
.776 .25517 Mdot
.776 .25585 Mdot
.776 .2592 Mdot
.776 .26023 Mdot
.776 .26176 Mdot
.776 .26525 Mdot
.776 .26587 Mdot
.776 .26654 Mdot
.776 .26817 Mdot
.776 .27001 Mdot
.776 .27395 Mdot
.776 .27439 Mdot
.776 .2764 Mdot
.776 .27647 Mdot
.776 .27838 Mdot
.776 .27858 Mdot
.776 .27908 Mdot
.776 .28017 Mdot
.776 .28102 Mdot
.776 .28197 Mdot
.776 .28229 Mdot
.776 .28233 Mdot
.776 .28346 Mdot
.776 .28399 Mdot
.776 .2844 Mdot
.776 .28452 Mdot
.776 .28568 Mdot
.776 .28684 Mdot
.776 .29047 Mdot
.776 .2917 Mdot
.776 .29391 Mdot
.776 .29479 Mdot
.776 .29625 Mdot
.776 .29737 Mdot
.776 .2987 Mdot
.776 .30032 Mdot
.776 .30103 Mdot
.776 .30136 Mdot
.776 .3015 Mdot
.776 .30237 Mdot
.776 .3065 Mdot
.776 .30682 Mdot
.776 .30719 Mdot
.776 .30753 Mdot
.776 .30859 Mdot
.776 .3146 Mdot
.776 .31572 Mdot
.776 .31704 Mdot
.776 .31747 Mdot
.776 .32043 Mdot
.776 .32125 Mdot
.776 .32182 Mdot
.776 .32231 Mdot
.776 .32243 Mdot
.776 .32249 Mdot
.776 .32258 Mdot
.776 .32267 Mdot
.776 .32394 Mdot
.776 .32411 Mdot
.776 .32448 Mdot
.776 .32486 Mdot
.776 .3249 Mdot
.776 .32557 Mdot
.776 .32569 Mdot
.776 .32576 Mdot
.776 .32591 Mdot
.776 .32599 Mdot
.776 .32603 Mdot
.776 .32643 Mdot
.776 .32645 Mdot
.776 .32667 Mdot
.776 .3282 Mdot
.776 .32844 Mdot
.776 .3298 Mdot
.776 .33011 Mdot
.776 .3309 Mdot
.776 .3315 Mdot
.776 .33165 Mdot
.776 .33172 Mdot
.776 .33173 Mdot
.776 .33244 Mdot
.776 .33262 Mdot
.776 .33272 Mdot
.776 .33285 Mdot
.776 .33299 Mdot
.776 .33388 Mdot
.776 .3341 Mdot
.776 .33504 Mdot
.776 .3353 Mdot
.776 .33532 Mdot
.776 .33534 Mdot
.776 .3356 Mdot
.776 .33585 Mdot
.776 .33596 Mdot
.776 .33663 Mdot
.776 .3367 Mdot
.776 .33697 Mdot
.776 .33791 Mdot
.776 .33791 Mdot
.776 .33813 Mdot
.776 .33827 Mdot
.776 .33856 Mdot
.776 .3387 Mdot
.776 .33877 Mdot
.776 .33933 Mdot
.776 .33935 Mdot
.776 .33955 Mdot
.776 .33959 Mdot
.776 .34001 Mdot
.776 .34104 Mdot
.776 .34178 Mdot
.776 .34179 Mdot
.776 .34279 Mdot
.776 .34314 Mdot
.776 .34363 Mdot
.776 .3437 Mdot
.776 .34471 Mdot
.776 .34481 Mdot
.776 .34491 Mdot
.776 .34533 Mdot
.776 .34637 Mdot
.776 .34663 Mdot
.776 .34679 Mdot
.776 .34734 Mdot
.776 .34735 Mdot
.776 .34766 Mdot
.776 .34773 Mdot
.776 .34852 Mdot
.776 .34919 Mdot
.776 .34981 Mdot
.776 .34989 Mdot
.776 .35053 Mdot
.776 .35064 Mdot
.776 .35096 Mdot
.776 .351 Mdot
.776 .35117 Mdot
.776 .35121 Mdot
.776 .35206 Mdot
.776 .35274 Mdot
.776 .35296 Mdot
.776 .35341 Mdot
.776 .35366 Mdot
.776 .35379 Mdot
.776 .354 Mdot
.776 .35435 Mdot
.776 .3557 Mdot
.776 .35602 Mdot
.776 .35669 Mdot
.776 .35712 Mdot
.776 .35714 Mdot
.776 .35717 Mdot
.776 .35728 Mdot
.776 .35793 Mdot
.776 .35854 Mdot
.776 .35889 Mdot
.776 .35981 Mdot
.776 .36052 Mdot
.776 .36058 Mdot
.776 .36063 Mdot
.776 .36108 Mdot
.776 .36136 Mdot
.776 .36152 Mdot
.776 .36166 Mdot
.776 .36173 Mdot
.776 .36176 Mdot
.776 .36206 Mdot
.776 .36236 Mdot
.776 .36267 Mdot
.776 .36302 Mdot
.776 .36427 Mdot
.776 .36447 Mdot
.776 .36526 Mdot
.776 .36537 Mdot
.776 .36646 Mdot
.776 .36657 Mdot
.776 .36788 Mdot
.776 .36802 Mdot
.776 .36803 Mdot
.776 .36826 Mdot
.776 .36868 Mdot
.776 .3691 Mdot
.776 .36996 Mdot
.776 .37041 Mdot
.776 .3706 Mdot
.776 .37116 Mdot
.776 .37156 Mdot
.776 .37221 Mdot
.776 .37233 Mdot
.776 .37238 Mdot
.776 .37269 Mdot
.776 .37273 Mdot
.776 .373 Mdot
.776 .37313 Mdot
.776 .37334 Mdot
.776 .37398 Mdot
.776 .37445 Mdot
.776 .37506 Mdot
.776 .37628 Mdot
.776 .37711 Mdot
.776 .37768 Mdot
.776 .3777 Mdot
.776 .37781 Mdot
.776 .37938 Mdot
.776 .37962 Mdot
.776 .37975 Mdot
.776 .38009 Mdot
.776 .38015 Mdot
.776 .38226 Mdot
.776 .38343 Mdot
.776 .38344 Mdot
.776 .38459 Mdot
.776 .38501 Mdot
.776 .38624 Mdot
.776 .3863 Mdot
.776 .38647 Mdot
.776 .38674 Mdot
.776 .38712 Mdot
.776 .38738 Mdot
.776 .38776 Mdot
.776 .38907 Mdot
.776 .38913 Mdot
.776 .38932 Mdot
.776 .38992 Mdot
.776 .39028 Mdot
.776 .39032 Mdot
.776 .39063 Mdot
.776 .39207 Mdot
.776 .39254 Mdot
.776 .39276 Mdot
.776 .39572 Mdot
.776 .39592 Mdot
.776 .39663 Mdot
.776 .3972 Mdot
.776 .39855 Mdot
.776 .39917 Mdot
.776 .39919 Mdot
.776 .39977 Mdot
.776 .40032 Mdot
.776 .40058 Mdot
.776 .40086 Mdot
.776 .40147 Mdot
.776 .40164 Mdot
.776 .40234 Mdot
.776 .40342 Mdot
.776 .40445 Mdot
.776 .40471 Mdot
.776 .40515 Mdot
.776 .40548 Mdot
.776 .40587 Mdot
.776 .40656 Mdot
.776 .40817 Mdot
.776 .40837 Mdot
.776 .40847 Mdot
.776 .40878 Mdot
.776 .41086 Mdot
.776 .41124 Mdot
.776 .41137 Mdot
.776 .41222 Mdot
.776 .41246 Mdot
.776 .41263 Mdot
.776 .41324 Mdot
.776 .41339 Mdot
.776 .41376 Mdot
.776 .41396 Mdot
.776 .41446 Mdot
.776 .41548 Mdot
.776 .4165 Mdot
.776 .41659 Mdot
.776 .41698 Mdot
.776 .41725 Mdot
.776 .41864 Mdot
.776 .41918 Mdot
.776 .41924 Mdot
.776 .41936 Mdot
.776 .41978 Mdot
.776 .42004 Mdot
.776 .42027 Mdot
.776 .42063 Mdot
.776 .42177 Mdot
.776 .42272 Mdot
.776 .42272 Mdot
.776 .42321 Mdot
.776 .42383 Mdot
.776 .42402 Mdot
.776 .42536 Mdot
.776 .4268 Mdot
.776 .42779 Mdot
.776 .42853 Mdot
.776 .43061 Mdot
.776 .4311 Mdot
.776 .43129 Mdot
.776 .43184 Mdot
.776 .43275 Mdot
.776 .43281 Mdot
.776 .43371 Mdot
.776 .43446 Mdot
.776 .43481 Mdot
.776 .43512 Mdot
.776 .43615 Mdot
.776 .43622 Mdot
.776 .43635 Mdot
.776 .43644 Mdot
.776 .43675 Mdot
.776 .43739 Mdot
.776 .43882 Mdot
.776 .43888 Mdot
.776 .43932 Mdot
.776 .43961 Mdot
.776 .43983 Mdot
.776 .44041 Mdot
.776 .44081 Mdot
.776 .44142 Mdot
.776 .44174 Mdot
.776 .44261 Mdot
.776 .4429 Mdot
.776 .44311 Mdot
.776 .44387 Mdot
.776 .44463 Mdot
.776 .44496 Mdot
.776 .44616 Mdot
.776 .44673 Mdot
.776 .44764 Mdot
.776 .44797 Mdot
.776 .44833 Mdot
.776 .44878 Mdot
.776 .44953 Mdot
.776 .44978 Mdot
.776 .44998 Mdot
.776 .45015 Mdot
.776 .45096 Mdot
.776 .45161 Mdot
.776 .45179 Mdot
.776 .4522 Mdot
.776 .45288 Mdot
.776 .45351 Mdot
.776 .45384 Mdot
.776 .45405 Mdot
.776 .45436 Mdot
.776 .45447 Mdot
.776 .45486 Mdot
.776 .45564 Mdot
.776 .45614 Mdot
.776 .45683 Mdot
.776 .45699 Mdot
.776 .45756 Mdot
.776 .45806 Mdot
.776 .45882 Mdot
.776 .45891 Mdot
.776 .46022 Mdot
.776 .4606 Mdot
.776 .4611 Mdot
.776 .4626 Mdot
.776 .46316 Mdot
.776 .4642 Mdot
.776 .46438 Mdot
.776 .46462 Mdot
.776 .46489 Mdot
.776 .46518 Mdot
.776 .46587 Mdot
.776 .46624 Mdot
.776 .46674 Mdot
.776 .46747 Mdot
.776 .46757 Mdot
.776 .46832 Mdot
.776 .46873 Mdot
.776 .46997 Mdot
.776 .47103 Mdot
.776 .47155 Mdot
.776 .4717 Mdot
.776 .47191 Mdot
.776 .47203 Mdot
.776 .47303 Mdot
.776 .47343 Mdot
.776 .47372 Mdot
.776 .47423 Mdot
.776 .4748 Mdot
.776 .47601 Mdot
.776 .47747 Mdot
.776 .47756 Mdot
.776 .47858 Mdot
.776 .47903 Mdot
.776 .47912 Mdot
.776 .47914 Mdot
.776 .47991 Mdot
.776 .48002 Mdot
.776 .48019 Mdot
.776 .48097 Mdot
.776 .48167 Mdot
.776 .4822 Mdot
.776 .48331 Mdot
.776 .48417 Mdot
.776 .48422 Mdot
.776 .48448 Mdot
.776 .48484 Mdot
.776 .48537 Mdot
.776 .48584 Mdot
.776 .48639 Mdot
.776 .48661 Mdot
.776 .4869 Mdot
.776 .48832 Mdot
.776 .48905 Mdot
.776 .48909 Mdot
.776 .49056 Mdot
.776 .4911 Mdot
.776 .49119 Mdot
.776 .49137 Mdot
.776 .4923 Mdot
.776 .4927 Mdot
.776 .49302 Mdot
.776 .49303 Mdot
.776 .49443 Mdot
.776 .49515 Mdot
.776 .4956 Mdot
.776 .49578 Mdot
.776 .49608 Mdot
.776 .49661 Mdot
.776 .49693 Mdot
.776 .49696 Mdot
.776 .49709 Mdot
.776 .49732 Mdot
.776 .49749 Mdot
.776 .49791 Mdot
.776 .49808 Mdot
.776 .49812 Mdot
.776 .49817 Mdot
.776 .49858 Mdot
.776 .49895 Mdot
.776 .49936 Mdot
.776 .49966 Mdot
.776 .50034 Mdot
.776 .50091 Mdot
.776 .50129 Mdot
.776 .50174 Mdot
.776 .50184 Mdot
.776 .50196 Mdot
.776 .50338 Mdot
.776 .50347 Mdot
.776 .50477 Mdot
.776 .50546 Mdot
.776 .50567 Mdot
.776 .50573 Mdot
.776 .50623 Mdot
.776 .50644 Mdot
.776 .50727 Mdot
.776 .50749 Mdot
.776 .50781 Mdot
.776 .50895 Mdot
.776 .50912 Mdot
.776 .50962 Mdot
.776 .51005 Mdot
.776 .51234 Mdot
.776 .51274 Mdot
.776 .51287 Mdot
.776 .51301 Mdot
.776 .51313 Mdot
.776 .51469 Mdot
.776 .51501 Mdot
.776 .51506 Mdot
.776 .51519 Mdot
.776 .51545 Mdot
.776 .51606 Mdot
.776 .51655 Mdot
.776 .51696 Mdot
.776 .5175 Mdot
.776 .51783 Mdot
.776 .51864 Mdot
.776 .51909 Mdot
.776 .52042 Mdot
.776 .52084 Mdot
.776 .52126 Mdot
.776 .52131 Mdot
.776 .52146 Mdot
.776 .52165 Mdot
.776 .52206 Mdot
.776 .52207 Mdot
.776 .52219 Mdot
.776 .52253 Mdot
.776 .52284 Mdot
.776 .52323 Mdot
.776 .52341 Mdot
.776 .52348 Mdot
.776 .52417 Mdot
.776 .52419 Mdot
.776 .52491 Mdot
.776 .52507 Mdot
.776 .52647 Mdot
.776 .52712 Mdot
.776 .52769 Mdot
.776 .52793 Mdot
.776 .52815 Mdot
.776 .52937 Mdot
.776 .5299 Mdot
.776 .53026 Mdot
.776 .53143 Mdot
.776 .53166 Mdot
.776 .53217 Mdot
.776 .53371 Mdot
.776 .53389 Mdot
.776 .53391 Mdot
.776 .53395 Mdot
.776 .53404 Mdot
.776 .53408 Mdot
.776 .53446 Mdot
.776 .53509 Mdot
.776 .53528 Mdot
.776 .53535 Mdot
.776 .5367 Mdot
.776 .53709 Mdot
.776 .53735 Mdot
.776 .53743 Mdot
.776 .53773 Mdot
.776 .538 Mdot
.776 .53818 Mdot
.776 .53824 Mdot
.776 .53866 Mdot
.776 .53947 Mdot
.776 .53988 Mdot
.776 .541 Mdot
.776 .54101 Mdot
.776 .54102 Mdot
.776 .54213 Mdot
.776 .54223 Mdot
.776 .54239 Mdot
.776 .54289 Mdot
.776 .54364 Mdot
.776 .54411 Mdot
.776 .54416 Mdot
.776 .54447 Mdot
.776 .54448 Mdot
.776 .54459 Mdot
.776 .54468 Mdot
.776 .54481 Mdot
.776 .5454 Mdot
.776 .54623 Mdot
.776 .54633 Mdot
.776 .54634 Mdot
.776 .54643 Mdot
.776 .54685 Mdot
.776 .54758 Mdot
.776 .54864 Mdot
.776 .54915 Mdot
.776 .54955 Mdot
.776 .54987 Mdot
.776 .55003 Mdot
.776 .5501 Mdot
.776 .55027 Mdot
.776 .55037 Mdot
.776 .55051 Mdot
.776 .5506 Mdot
.776 .55063 Mdot
.776 .55089 Mdot
.776 .55093 Mdot
.776 .55103 Mdot
.776 .55156 Mdot
.776 .55188 Mdot
.776 .55202 Mdot
.776 .55233 Mdot
.776 .55248 Mdot
.776 .55284 Mdot
.776 .55289 Mdot
.776 .553 Mdot
.776 .5532 Mdot
.776 .55328 Mdot
.776 .55334 Mdot
.776 .55351 Mdot
.776 .55374 Mdot
.776 .55384 Mdot
.776 .55417 Mdot
.776 .55434 Mdot
.776 .55435 Mdot
.776 .55446 Mdot
.776 .55545 Mdot
.776 .55553 Mdot
.776 .55634 Mdot
.776 .55641 Mdot
.776 .55699 Mdot
.776 .55709 Mdot
.776 .55714 Mdot
.776 .55802 Mdot
.776 .55813 Mdot
.776 .55826 Mdot
.776 .55848 Mdot
.776 .5586 Mdot
.776 .55869 Mdot
.776 .55889 Mdot
.776 .55891 Mdot
.776 .55896 Mdot
.776 .55906 Mdot
.776 .55916 Mdot
.776 .55935 Mdot
.776 .55966 Mdot
.776 .55969 Mdot
.776 .55973 Mdot
.776 .5602 Mdot
.776 .5608 Mdot
.776 .56084 Mdot
.776 .56103 Mdot
.776 .56142 Mdot
.776 .5615 Mdot
.776 .56183 Mdot
.776 .5619 Mdot
.776 .56192 Mdot
.776 .56193 Mdot
.776 .5622 Mdot
.776 .56246 Mdot
.776 .56261 Mdot
.776 .5628 Mdot
.776 .56361 Mdot
.776 .56381 Mdot
.776 .56394 Mdot
.776 .56401 Mdot
.776 .56415 Mdot
.776 .56441 Mdot
.776 .56451 Mdot
.776 .56454 Mdot
.776 .56487 Mdot
.776 .56493 Mdot
.776 .56524 Mdot
.776 .56539 Mdot
.776 .56542 Mdot
.776 .56551 Mdot
.776 .56553 Mdot
.776 .56571 Mdot
.776 .56576 Mdot
.776 .56611 Mdot
.776 .56612 Mdot
.776 .56615 Mdot
.776 .56648 Mdot
.776 .56682 Mdot
.776 .56707 Mdot
.776 .56722 Mdot
.776 .56726 Mdot
.776 .56741 Mdot
.776 .56742 Mdot
.776 .56769 Mdot
.776 .56777 Mdot
.776 .56789 Mdot
.776 .56839 Mdot
.776 .56858 Mdot
.776 .56863 Mdot
.776 .56868 Mdot
.776 .56897 Mdot
.776 .56914 Mdot
.776 .56916 Mdot
.776 .56917 Mdot
.776 .56939 Mdot
.776 .56955 Mdot
.776 .56998 Mdot
.776 .56998 Mdot
.776 .57004 Mdot
.776 .57008 Mdot
.776 .57029 Mdot
.776 .57071 Mdot
.776 .57086 Mdot
.776 .57088 Mdot
.776 .5709 Mdot
.776 .57094 Mdot
.776 .57098 Mdot
.776 .57098 Mdot
.776 .57113 Mdot
.776 .57121 Mdot
.776 .57123 Mdot
.776 .57129 Mdot
.776 .57139 Mdot
.776 .57145 Mdot
.776 .57153 Mdot
.776 .57153 Mdot
.776 .57155 Mdot
.776 .57186 Mdot
.776 .57188 Mdot
.776 .57198 Mdot
.776 .572 Mdot
.776 .5722 Mdot
.776 .57224 Mdot
.776 .57228 Mdot
.776 .57231 Mdot
.776 .57233 Mdot
.776 .57236 Mdot
.776 .57245 Mdot
.776 .57246 Mdot
.776 .57247 Mdot
.776 .57255 Mdot
.776 .57271 Mdot
.776 .57286 Mdot
.776 .57288 Mdot
.776 .57294 Mdot
.776 .57302 Mdot
.776 .57306 Mdot
.776 .57322 Mdot
.776 .57326 Mdot
.776 .5733 Mdot
.776 .57333 Mdot
.776 .57339 Mdot
.776 .57342 Mdot
.776 .5736 Mdot
.776 .5736 Mdot
.776 .57362 Mdot
.776 .57367 Mdot
.776 .57376 Mdot
.776 .57384 Mdot
.776 .57406 Mdot
.776 .57415 Mdot
.776 .5745 Mdot
.776 .57456 Mdot
.776 .57472 Mdot
.776 .57493 Mdot
.776 .57498 Mdot
.776 .57498 Mdot
.776 .575 Mdot
.776 .57507 Mdot
.776 .57508 Mdot
.776 .5751 Mdot
.776 .57513 Mdot
.776 .57515 Mdot
.776 .57517 Mdot
.776 .57531 Mdot
.776 .57532 Mdot
.776 .5754 Mdot
.776 .57547 Mdot
.776 .57547 Mdot
.776 .5755 Mdot
.776 .57561 Mdot
.776 .57564 Mdot
.776 .57574 Mdot
.776 .57576 Mdot
.776 .57577 Mdot
.776 .57578 Mdot
.776 .5758 Mdot
.776 .57589 Mdot
.776 .57589 Mdot
.776 .57598 Mdot
.776 .57607 Mdot
.776 .5761 Mdot
.776 .57626 Mdot
.776 .57646 Mdot
.776 .57649 Mdot
.776 .57653 Mdot
.776 .57654 Mdot
.776 .57657 Mdot
.776 .57658 Mdot
.776 .57666 Mdot
.776 .57666 Mdot
.776 .57675 Mdot
.776 .57691 Mdot
.776 .57692 Mdot
.776 .57693 Mdot
.776 .57694 Mdot
.776 .57695 Mdot
.778 .11019 Mdot
.778 .11019 Mdot
.778 .1102 Mdot
.778 .11026 Mdot
.778 .1103 Mdot
.778 .11031 Mdot
.778 .11031 Mdot
.778 .11043 Mdot
.778 .11062 Mdot
.778 .11065 Mdot
.778 .11067 Mdot
.778 .11079 Mdot
.778 .11082 Mdot
.778 .11085 Mdot
.778 .11089 Mdot
.778 .11099 Mdot
.778 .11121 Mdot
.778 .11144 Mdot
.778 .11162 Mdot
.778 .11176 Mdot
.778 .11185 Mdot
.778 .1119 Mdot
.778 .11209 Mdot
.778 .11211 Mdot
.778 .11217 Mdot
.778 .11225 Mdot
.778 .11229 Mdot
.778 .11314 Mdot
.778 .11314 Mdot
.778 .11314 Mdot
.778 .11322 Mdot
.778 .11328 Mdot
.778 .1133 Mdot
.778 .1133 Mdot
.778 .11333 Mdot
.778 .11347 Mdot
.778 .11374 Mdot
.778 .11378 Mdot
.778 .1138 Mdot
.778 .11399 Mdot
.778 .11403 Mdot
.778 .11407 Mdot
.778 .11413 Mdot
.778 .11429 Mdot
.778 .11446 Mdot
.778 .11464 Mdot
.778 .11471 Mdot
.778 .11502 Mdot
.778 .11533 Mdot
.778 .11558 Mdot
.778 .11568 Mdot
.778 .11574 Mdot
.778 .11583 Mdot
.778 .1162 Mdot
.778 .11622 Mdot
.778 .11634 Mdot
.778 .1165 Mdot
.778 .11656 Mdot
.778 .11692 Mdot
.778 .117 Mdot
.778 .11716 Mdot
.778 .11815 Mdot
.778 .1183 Mdot
.778 .11831 Mdot
.778 .11832 Mdot
.778 .11837 Mdot
.778 .1185 Mdot
.778 .11862 Mdot
.778 .11866 Mdot
.778 .11867 Mdot
.778 .11873 Mdot
.778 .11903 Mdot
.778 .11966 Mdot
.778 .11975 Mdot
.778 .1198 Mdot
.778 .11981 Mdot
.778 .1201 Mdot
.778 .12026 Mdot
.778 .12035 Mdot
.778 .12045 Mdot
.778 .12059 Mdot
.778 .12091 Mdot
.778 .12098 Mdot
.778 .12131 Mdot
.778 .1214 Mdot
.778 .12146 Mdot
.778 .12168 Mdot
.778 .12186 Mdot
.778 .12196 Mdot
.778 .12206 Mdot
.778 .12211 Mdot
.778 .12238 Mdot
.778 .12287 Mdot
.778 .12372 Mdot
.778 .1239 Mdot
.778 .12435 Mdot
.778 .12441 Mdot
.778 .12469 Mdot
.778 .12485 Mdot
.778 .12512 Mdot
.778 .12551 Mdot
.778 .12619 Mdot
.778 .12627 Mdot
.778 .12661 Mdot
.778 .12671 Mdot
.778 .12709 Mdot
.778 .12729 Mdot
.778 .12841 Mdot
.778 .12866 Mdot
.778 .12918 Mdot
.778 .13033 Mdot
.778 .13106 Mdot
.778 .13188 Mdot
.778 .132 Mdot
.778 .13248 Mdot
.778 .13301 Mdot
.778 .13303 Mdot
.778 .13307 Mdot
.778 .13325 Mdot
.778 .13342 Mdot
.778 .13368 Mdot
.778 .13372 Mdot
.778 .13411 Mdot
.778 .13428 Mdot
.778 .13429 Mdot
.778 .13451 Mdot
.778 .1349 Mdot
.778 .13562 Mdot
.778 .13562 Mdot
.778 .13718 Mdot
.778 .13796 Mdot
.778 .13803 Mdot
.778 .13829 Mdot
.778 .13851 Mdot
.778 .13853 Mdot
.778 .13853 Mdot
.778 .13858 Mdot
.778 .13929 Mdot
.778 .13967 Mdot
.778 .14029 Mdot
.778 .14055 Mdot
.778 .14065 Mdot
.778 .14103 Mdot
.778 .14162 Mdot
.778 .1429 Mdot
.778 .14321 Mdot
.778 .14342 Mdot
.778 .14357 Mdot
.778 .14458 Mdot
.778 .14493 Mdot
.778 .14504 Mdot
.778 .1452 Mdot
.778 .14612 Mdot
.778 .1469 Mdot
.778 .14732 Mdot
.778 .14775 Mdot
.778 .14795 Mdot
.778 .14914 Mdot
.778 .15129 Mdot
.778 .15131 Mdot
.778 .15155 Mdot
.778 .15522 Mdot
.778 .15577 Mdot
.778 .1558 Mdot
.778 .15609 Mdot
.778 .15664 Mdot
.778 .15771 Mdot
.778 .15823 Mdot
.778 .15852 Mdot
.778 .15987 Mdot
.778 .16064 Mdot
.778 .16196 Mdot
.778 .16393 Mdot
.778 .16496 Mdot
.778 .16683 Mdot
.778 .16736 Mdot
.778 .16752 Mdot
.778 .16755 Mdot
.778 .16779 Mdot
.778 .16786 Mdot
.778 .16957 Mdot
.778 .17009 Mdot
.778 .17066 Mdot
.778 .17209 Mdot
.778 .17227 Mdot
.778 .17312 Mdot
.778 .17483 Mdot
.778 .17547 Mdot
.778 .17562 Mdot
.778 .17598 Mdot
.778 .17627 Mdot
.778 .17628 Mdot
.778 .17723 Mdot
.778 .17894 Mdot
.778 .1792 Mdot
.778 .18013 Mdot
.778 .18058 Mdot
.778 .18071 Mdot
.778 .18352 Mdot
.778 .18616 Mdot
.778 .18623 Mdot
.778 .18641 Mdot
.778 .19012 Mdot
.778 .19017 Mdot
.778 .19054 Mdot
.778 .19293 Mdot
.778 .19436 Mdot
.778 .19569 Mdot
.778 .19789 Mdot
.778 .19929 Mdot
.778 .20001 Mdot
.778 .20003 Mdot
.778 .20036 Mdot
.778 .20228 Mdot
.778 .20293 Mdot
.778 .20349 Mdot
.778 .204 Mdot
.778 .20557 Mdot
.778 .2062 Mdot
.778 .20631 Mdot
.778 .20633 Mdot
.778 .20647 Mdot
.778 .20657 Mdot
.778 .20668 Mdot
.778 .20745 Mdot
.778 .20767 Mdot
.778 .20872 Mdot
.778 .20969 Mdot
.778 .21037 Mdot
.778 .2106 Mdot
.778 .21076 Mdot
.778 .21098 Mdot
.778 .21182 Mdot
.778 .21305 Mdot
.778 .21413 Mdot
.778 .21419 Mdot
.778 .21558 Mdot
.778 .21563 Mdot
.778 .21706 Mdot
.778 .21809 Mdot
.778 .2198 Mdot
.778 .22268 Mdot
.778 .22269 Mdot
.778 .22552 Mdot
.778 .22624 Mdot
.778 .23025 Mdot
.778 .23194 Mdot
.778 .23293 Mdot
.778 .23487 Mdot
.778 .23808 Mdot
.778 .23859 Mdot
.778 .23996 Mdot
.778 .24034 Mdot
.778 .24155 Mdot
.778 .24183 Mdot
.778 .24191 Mdot
.778 .24197 Mdot
.778 .24224 Mdot
.778 .24348 Mdot
.778 .2442 Mdot
.778 .24599 Mdot
.778 .24707 Mdot
.778 .24968 Mdot
.778 .25229 Mdot
.778 .25352 Mdot
.778 .25393 Mdot
.778 .25456 Mdot
.778 .25569 Mdot
.778 .25642 Mdot
.778 .25904 Mdot
.778 .2631 Mdot
.778 .26353 Mdot
.778 .26354 Mdot
.778 .26575 Mdot
.778 .27024 Mdot
.778 .27206 Mdot
.778 .27285 Mdot
.778 .27333 Mdot
.778 .27365 Mdot
.778 .2742 Mdot
.778 .27573 Mdot
.778 .27675 Mdot
.778 .27846 Mdot
.778 .28185 Mdot
.778 .28388 Mdot
.778 .28639 Mdot
.778 .28661 Mdot
.778 .28676 Mdot
.778 .28717 Mdot
.778 .28833 Mdot
.778 .2914 Mdot
.778 .29161 Mdot
.778 .29483 Mdot
.778 .29524 Mdot
.778 .29942 Mdot
.778 .29961 Mdot
.778 .30041 Mdot
.778 .30226 Mdot
.778 .30301 Mdot
.778 .3034 Mdot
.778 .30356 Mdot
.778 .30434 Mdot
.778 .30651 Mdot
.778 .30652 Mdot
.778 .30667 Mdot
.778 .30708 Mdot
.778 .30795 Mdot
.778 .30809 Mdot
.778 .30999 Mdot
.778 .31241 Mdot
.778 .31348 Mdot
.778 .3136 Mdot
.778 .31426 Mdot
.778 .31437 Mdot
.778 .31649 Mdot
.778 .31701 Mdot
.778 .3174 Mdot
.778 .31775 Mdot
.778 .31824 Mdot
.778 .31827 Mdot
.778 .31869 Mdot
.778 .32047 Mdot
.778 .32048 Mdot
.778 .32049 Mdot
.778 .32064 Mdot
.778 .32074 Mdot
.778 .32079 Mdot
.778 .32079 Mdot
.778 .32084 Mdot
.778 .32109 Mdot
.778 .32158 Mdot
.778 .32165 Mdot
.778 .3217 Mdot
.778 .32202 Mdot
.778 .32209 Mdot
.778 .32216 Mdot
.778 .32226 Mdot
.778 .32252 Mdot
.778 .32308 Mdot
.778 .32367 Mdot
.778 .32414 Mdot
.778 .3245 Mdot
.778 .32465 Mdot
.778 .32472 Mdot
.778 .32486 Mdot
.778 .32536 Mdot
.778 .3254 Mdot
.778 .32555 Mdot
.778 .32577 Mdot
.778 .32585 Mdot
.778 .32632 Mdot
.778 .32784 Mdot
.778 .32802 Mdot
.778 .32802 Mdot
.778 .32804 Mdot
.778 .3281 Mdot
.778 .32824 Mdot
.778 .32838 Mdot
.778 .32844 Mdot
.778 .32844 Mdot
.778 .32851 Mdot
.778 .32885 Mdot
.778 .32955 Mdot
.778 .32964 Mdot
.778 .32971 Mdot
.778 .33002 Mdot
.778 .33019 Mdot
.778 .33029 Mdot
.778 .33039 Mdot
.778 .33054 Mdot
.778 .33094 Mdot
.778 .33136 Mdot
.778 .33182 Mdot
.778 .33192 Mdot
.778 .33201 Mdot
.778 .33206 Mdot
.778 .33232 Mdot
.778 .33279 Mdot
.778 .33358 Mdot
.778 .33374 Mdot
.778 .3342 Mdot
.778 .33445 Mdot
.778 .33459 Mdot
.778 .33482 Mdot
.778 .33517 Mdot
.778 .33574 Mdot
.778 .33581 Mdot
.778 .3361 Mdot
.778 .33649 Mdot
.778 .33665 Mdot
.778 .33755 Mdot
.778 .33775 Mdot
.778 .33816 Mdot
.778 .33903 Mdot
.778 .34018 Mdot
.778 .34027 Mdot
.778 .34061 Mdot
.778 .34099 Mdot
.778 .34101 Mdot
.778 .34103 Mdot
.778 .34116 Mdot
.778 .34146 Mdot
.778 .34176 Mdot
.778 .34188 Mdot
.778 .34189 Mdot
.778 .34204 Mdot
.778 .34279 Mdot
.778 .34279 Mdot
.778 .34433 Mdot
.778 .34455 Mdot
.778 .34469 Mdot
.778 .3447 Mdot
.778 .34473 Mdot
.778 .34542 Mdot
.778 .34581 Mdot
.778 .34603 Mdot
.778 .34627 Mdot
.778 .34663 Mdot
.778 .3474 Mdot
.778 .34758 Mdot
.778 .34771 Mdot
.778 .34839 Mdot
.778 .34859 Mdot
.778 .34866 Mdot
.778 .34875 Mdot
.778 .34928 Mdot
.778 .34972 Mdot
.778 .34996 Mdot
.778 .3502 Mdot
.778 .35031 Mdot
.778 .35097 Mdot
.778 .35214 Mdot
.778 .35215 Mdot
.778 .35421 Mdot
.778 .35465 Mdot
.778 .35547 Mdot
.778 .35573 Mdot
.778 .35588 Mdot
.778 .35654 Mdot
.778 .35692 Mdot
.778 .35756 Mdot
.778 .35851 Mdot
.778 .35987 Mdot
.778 .36011 Mdot
.778 .36018 Mdot
.778 .3602 Mdot
.778 .36031 Mdot
.778 .36034 Mdot
.778 .36112 Mdot
.778 .36136 Mdot
.778 .36226 Mdot
.778 .36272 Mdot
.778 .36375 Mdot
.778 .36381 Mdot
.778 .36397 Mdot
.778 .36409 Mdot
.778 .36524 Mdot
.778 .36535 Mdot
.778 .36594 Mdot
.778 .36599 Mdot
.778 .36716 Mdot
.778 .36825 Mdot
.778 .36828 Mdot
.778 .36985 Mdot
.778 .36987 Mdot
.778 .37001 Mdot
.778 .37152 Mdot
.778 .37289 Mdot
.778 .37342 Mdot
.778 .3737 Mdot
.778 .37371 Mdot
.778 .3748 Mdot
.778 .37501 Mdot
.778 .3752 Mdot
.778 .37602 Mdot
.778 .37606 Mdot
.778 .37616 Mdot
.778 .37656 Mdot
.778 .37695 Mdot
.778 .3773 Mdot
.778 .37755 Mdot
.778 .37763 Mdot
.778 .37777 Mdot
.778 .37852 Mdot
.778 .37891 Mdot
.778 .37893 Mdot
.778 .37943 Mdot
.778 .38032 Mdot
.778 .38092 Mdot
.778 .38193 Mdot
.778 .38193 Mdot
.778 .38291 Mdot
.778 .38453 Mdot
.778 .38544 Mdot
.778 .38716 Mdot
.778 .38733 Mdot
.778 .38791 Mdot
.778 .38831 Mdot
.778 .3884 Mdot
.778 .38843 Mdot
.778 .38844 Mdot
.778 .38853 Mdot
.778 .38894 Mdot
.778 .38918 Mdot
.778 .38976 Mdot
.778 .39011 Mdot
.778 .39095 Mdot
.778 .39219 Mdot
.778 .39232 Mdot
.778 .39288 Mdot
.778 .39311 Mdot
.778 .39394 Mdot
.778 .39521 Mdot
.778 .39604 Mdot
.778 .39743 Mdot
.778 .39799 Mdot
.778 .39838 Mdot
.778 .39848 Mdot
.778 .39865 Mdot
.778 .39911 Mdot
.778 .39943 Mdot
.778 .40159 Mdot
.778 .40234 Mdot
.778 .40257 Mdot
.778 .40292 Mdot
.778 .40486 Mdot
.778 .40627 Mdot
.778 .40651 Mdot
.778 .40739 Mdot
.778 .4083 Mdot
.778 .4083 Mdot
.778 .40846 Mdot
.778 .40872 Mdot
.778 .40876 Mdot
.778 .41002 Mdot
.778 .41033 Mdot
.778 .41056 Mdot
.778 .4112 Mdot
.778 .41355 Mdot
.778 .41447 Mdot
.778 .41564 Mdot
.778 .41568 Mdot
.778 .41616 Mdot
.778 .41657 Mdot
.778 .41929 Mdot
.778 .42041 Mdot
.778 .4214 Mdot
.778 .42358 Mdot
.778 .42367 Mdot
.778 .42372 Mdot
.778 .42468 Mdot
.778 .4247 Mdot
.778 .42474 Mdot
.778 .42478 Mdot
.778 .42531 Mdot
.778 .42595 Mdot
.778 .42596 Mdot
.778 .42641 Mdot
.778 .42645 Mdot
.778 .42726 Mdot
.778 .42851 Mdot
.778 .42864 Mdot
.778 .42954 Mdot
.778 .4301 Mdot
.778 .43056 Mdot
.778 .43204 Mdot
.778 .43273 Mdot
.778 .43382 Mdot
.778 .43422 Mdot
.778 .43449 Mdot
.778 .43674 Mdot
.778 .43737 Mdot
.778 .43781 Mdot
.778 .43797 Mdot
.778 .4397 Mdot
.778 .44048 Mdot
.778 .44109 Mdot
.778 .44207 Mdot
.778 .44228 Mdot
.778 .44242 Mdot
.778 .4428 Mdot
.778 .44376 Mdot
.778 .44419 Mdot
.778 .44472 Mdot
.778 .4459 Mdot
.778 .44645 Mdot
.778 .44687 Mdot
.778 .44716 Mdot
.778 .44722 Mdot
.778 .44766 Mdot
.778 .44779 Mdot
.778 .4509 Mdot
.778 .45184 Mdot
.778 .45212 Mdot
.778 .45235 Mdot
.778 .45287 Mdot
.778 .45315 Mdot
.778 .45326 Mdot
.778 .45378 Mdot
.778 .45452 Mdot
.778 .45543 Mdot
.778 .45551 Mdot
.778 .45575 Mdot
.778 .45725 Mdot
.778 .4576 Mdot
.778 .45852 Mdot
.778 .45928 Mdot
.778 .46026 Mdot
.778 .46096 Mdot
.778 .46137 Mdot
.778 .46162 Mdot
.778 .46162 Mdot
.778 .46221 Mdot
.778 .46225 Mdot
.778 .46274 Mdot
.778 .46277 Mdot
.778 .4639 Mdot
.778 .46439 Mdot
.778 .46494 Mdot
.778 .46628 Mdot
.778 .46731 Mdot
.778 .46775 Mdot
.778 .4692 Mdot
.778 .46931 Mdot
.778 .46946 Mdot
.778 .47006 Mdot
.778 .4702 Mdot
.778 .47028 Mdot
.778 .47125 Mdot
.778 .4749 Mdot
.778 .47495 Mdot
.778 .47539 Mdot
.778 .47603 Mdot
.778 .4778 Mdot
.778 .4789 Mdot
.778 .47917 Mdot
.778 .47927 Mdot
.778 .47956 Mdot
.778 .48126 Mdot
.778 .48198 Mdot
.778 .48286 Mdot
.778 .48425 Mdot
.778 .48446 Mdot
.778 .48538 Mdot
.778 .48546 Mdot
.778 .48603 Mdot
.778 .48638 Mdot
.778 .48763 Mdot
.778 .48769 Mdot
.778 .48837 Mdot
.778 .48839 Mdot
.778 .48935 Mdot
.778 .48967 Mdot
.778 .49016 Mdot
.778 .49021 Mdot
.778 .49028 Mdot
.778 .49031 Mdot
.778 .49175 Mdot
.778 .49181 Mdot
.778 .49182 Mdot
.778 .49195 Mdot
.778 .49379 Mdot
.778 .49517 Mdot
.778 .49661 Mdot
.778 .497 Mdot
.778 .49821 Mdot
.778 .499 Mdot
.778 .50002 Mdot
.778 .50006 Mdot
.778 .50052 Mdot
.778 .50207 Mdot
.778 .50263 Mdot
.778 .5032 Mdot
.778 .5033 Mdot
.778 .50336 Mdot
.778 .50411 Mdot
.778 .50486 Mdot
.778 .50497 Mdot
.778 .50556 Mdot
.778 .50622 Mdot
.778 .5077 Mdot
.778 .50853 Mdot
.778 .50869 Mdot
.778 .5087 Mdot
.778 .50889 Mdot
.778 .50903 Mdot
.778 .50917 Mdot
.778 .50938 Mdot
.778 .51019 Mdot
.778 .51023 Mdot
.778 .51048 Mdot
.778 .51053 Mdot
.778 .51094 Mdot
.778 .51186 Mdot
.778 .51258 Mdot
.778 .51263 Mdot
.778 .51296 Mdot
.778 .51312 Mdot
.778 .51317 Mdot
.778 .51317 Mdot
.778 .51399 Mdot
.778 .51428 Mdot
.778 .51434 Mdot
.778 .51449 Mdot
.778 .51477 Mdot
.778 .51546 Mdot
.778 .51576 Mdot
.778 .51583 Mdot
.778 .51738 Mdot
.778 .51753 Mdot
.778 .51872 Mdot
.778 .51879 Mdot
.778 .51992 Mdot
.778 .52034 Mdot
.778 .52049 Mdot
.778 .52055 Mdot
.778 .52063 Mdot
.778 .52154 Mdot
.778 .52227 Mdot
.778 .52349 Mdot
.778 .5241 Mdot
.778 .52447 Mdot
.778 .52502 Mdot
.778 .52521 Mdot
.778 .52533 Mdot
.778 .5255 Mdot
.778 .52578 Mdot
.778 .52643 Mdot
.778 .52801 Mdot
.778 .52878 Mdot
.778 .52879 Mdot
.778 .52894 Mdot
.778 .53036 Mdot
.778 .53127 Mdot
.778 .53152 Mdot
.778 .53191 Mdot
.778 .53212 Mdot
.778 .53227 Mdot
.778 .53269 Mdot
.778 .53359 Mdot
.778 .53448 Mdot
.778 .53485 Mdot
.778 .53546 Mdot
.778 .5357 Mdot
.778 .53612 Mdot
.778 .53622 Mdot
.778 .53623 Mdot
.778 .53626 Mdot
.778 .53636 Mdot
.778 .53677 Mdot
.778 .5369 Mdot
.778 .53736 Mdot
.778 .53753 Mdot
.778 .53861 Mdot
.778 .53926 Mdot
.778 .53959 Mdot
.778 .54015 Mdot
.778 .54148 Mdot
.778 .54172 Mdot
.778 .54266 Mdot
.778 .54266 Mdot
.778 .54361 Mdot
.778 .54417 Mdot
.778 .54451 Mdot
.778 .54497 Mdot
.778 .54499 Mdot
.778 .54544 Mdot
.778 .54546 Mdot
.778 .54581 Mdot
.778 .54621 Mdot
.778 .54648 Mdot
.778 .54656 Mdot
.778 .54661 Mdot
.778 .54668 Mdot
.778 .5469 Mdot
.778 .54722 Mdot
.778 .54756 Mdot
.778 .54763 Mdot
.778 .54788 Mdot
.778 .54791 Mdot
.778 .54794 Mdot
.778 .54799 Mdot
.778 .54799 Mdot
.778 .54803 Mdot
.778 .54823 Mdot
.778 .54874 Mdot
.778 .5489 Mdot
.778 .54908 Mdot
.778 .54929 Mdot
.778 .5499 Mdot
.778 .55001 Mdot
.778 .55002 Mdot
.778 .55025 Mdot
.778 .55069 Mdot
.778 .55139 Mdot
.778 .55182 Mdot
.778 .55227 Mdot
.778 .55302 Mdot
.778 .55314 Mdot
.778 .55316 Mdot
.778 .55432 Mdot
.778 .55438 Mdot
.778 .5544 Mdot
.778 .55523 Mdot
.778 .5561 Mdot
.778 .55614 Mdot
.778 .55629 Mdot
.778 .55657 Mdot
.778 .55666 Mdot
.778 .55719 Mdot
.778 .55748 Mdot
.778 .55749 Mdot
.778 .55757 Mdot
.778 .55769 Mdot
.778 .55773 Mdot
.778 .55793 Mdot
.778 .55846 Mdot
.778 .55872 Mdot
.778 .55878 Mdot
.778 .55922 Mdot
.778 .55939 Mdot
.778 .55955 Mdot
.778 .56008 Mdot
.778 .5601 Mdot
.778 .56017 Mdot
.778 .56018 Mdot
.778 .56023 Mdot
.778 .56039 Mdot
.778 .56097 Mdot
.778 .56128 Mdot
.778 .56188 Mdot
.778 .56228 Mdot
.778 .56252 Mdot
.778 .56293 Mdot
.778 .56301 Mdot
.778 .56317 Mdot
.778 .56349 Mdot
.778 .56366 Mdot
.778 .56375 Mdot
.778 .56376 Mdot
.778 .56392 Mdot
.778 .56503 Mdot
.778 .5651 Mdot
.778 .56511 Mdot
.778 .56575 Mdot
.778 .56611 Mdot
.778 .56617 Mdot
.778 .5663 Mdot
.778 .56643 Mdot
.778 .56666 Mdot
.778 .56693 Mdot
.778 .56698 Mdot
.778 .56701 Mdot
.778 .56712 Mdot
.778 .56742 Mdot
.778 .56746 Mdot
.778 .56753 Mdot
.778 .56762 Mdot
.778 .568 Mdot
.778 .56817 Mdot
.778 .56829 Mdot
.778 .56832 Mdot
.778 .56839 Mdot
.778 .56858 Mdot
.778 .56869 Mdot
.778 .5689 Mdot
.778 .56891 Mdot
.778 .56892 Mdot
.778 .56892 Mdot
.778 .56899 Mdot
.778 .56906 Mdot
.778 .56909 Mdot
.778 .56932 Mdot
.778 .56978 Mdot
.778 .56978 Mdot
.778 .56999 Mdot
.778 .5701 Mdot
.778 .57017 Mdot
.778 .57017 Mdot
.778 .57022 Mdot
.778 .57035 Mdot
.778 .57043 Mdot
.778 .57048 Mdot
.778 .57053 Mdot
.778 .57054 Mdot
.778 .57055 Mdot
.778 .5707 Mdot
.778 .57084 Mdot
.778 .57088 Mdot
.778 .57112 Mdot
.778 .57133 Mdot
.778 .57167 Mdot
.778 .57182 Mdot
.778 .5719 Mdot
.778 .57223 Mdot
.778 .57228 Mdot
.778 .57239 Mdot
.778 .57242 Mdot
.778 .57252 Mdot
.778 .57255 Mdot
.778 .57274 Mdot
.778 .57286 Mdot
.778 .57294 Mdot
.778 .57298 Mdot
.778 .57307 Mdot
.778 .57308 Mdot
.778 .57321 Mdot
.778 .57327 Mdot
.778 .57352 Mdot
.778 .57366 Mdot
.778 .57374 Mdot
.778 .57375 Mdot
.778 .57378 Mdot
.778 .57381 Mdot
.778 .57386 Mdot
.778 .57392 Mdot
.778 .57394 Mdot
.778 .57397 Mdot
.778 .57406 Mdot
.778 .57408 Mdot
.778 .57418 Mdot
.778 .57422 Mdot
.778 .57425 Mdot
.778 .57427 Mdot
.778 .57432 Mdot
.778 .5744 Mdot
.778 .57441 Mdot
.778 .57442 Mdot
.778 .57445 Mdot
.778 .57463 Mdot
.778 .57472 Mdot
.778 .57474 Mdot
.778 .57474 Mdot
.778 .57475 Mdot
.778 .57479 Mdot
.778 .57482 Mdot
.778 .57484 Mdot
.778 .57484 Mdot
.778 .57484 Mdot
.778 .57488 Mdot
.778 .57517 Mdot
.778 .57522 Mdot
.778 .57524 Mdot
.778 .57535 Mdot
.778 .57536 Mdot
.778 .57541 Mdot
.778 .57544 Mdot
.778 .57545 Mdot
.778 .57556 Mdot
.778 .57558 Mdot
.778 .5756 Mdot
.778 .57563 Mdot
.778 .5757 Mdot
.778 .57579 Mdot
.778 .57588 Mdot
.778 .5759 Mdot
.778 .57595 Mdot
.778 .576 Mdot
.778 .57605 Mdot
.778 .57606 Mdot
.778 .57608 Mdot
.778 .57609 Mdot
.778 .57614 Mdot
.778 .57615 Mdot
.778 .57616 Mdot
.778 .57624 Mdot
.778 .57628 Mdot
.778 .57629 Mdot
.778 .57629 Mdot
.778 .57629 Mdot
.778 .57631 Mdot
.778 .57633 Mdot
.778 .57633 Mdot
.778 .57633 Mdot
.778 .57658 Mdot
.778 .57659 Mdot
.778 .57661 Mdot
.778 .57663 Mdot
.778 .57663 Mdot
.778 .57669 Mdot
.778 .5767 Mdot
.778 .57673 Mdot
.778 .57677 Mdot
.778 .57682 Mdot
.778 .57689 Mdot
.778 .57695 Mdot
.778 .57698 Mdot
.778 .57699 Mdot
.778 .577 Mdot
.778 .57701 Mdot
.778 .57704 Mdot
.778 .57705 Mdot
.778 .57706 Mdot
.778 .57711 Mdot
.778 .57714 Mdot
.778 .57714 Mdot
.778 .57715 Mdot
.778 .57716 Mdot
.778 .57718 Mdot
.778 .57718 Mdot
.778 .57718 Mdot
.78 .10943 Mdot
.78 .10954 Mdot
.78 .10971 Mdot
.78 .10976 Mdot
.78 .10977 Mdot
.78 .10999 Mdot
.78 .1106 Mdot
.78 .1107 Mdot
.78 .11071 Mdot
.78 .11101 Mdot
.78 .11115 Mdot
.78 .11146 Mdot
.78 .11148 Mdot
.78 .11161 Mdot
.78 .11168 Mdot
.78 .11176 Mdot
.78 .11181 Mdot
.78 .11187 Mdot
.78 .11188 Mdot
.78 .11188 Mdot
.78 .11216 Mdot
.78 .11216 Mdot
.78 .11216 Mdot
.78 .11217 Mdot
.78 .11232 Mdot
.78 .11253 Mdot
.78 .11277 Mdot
.78 .11285 Mdot
.78 .113 Mdot
.78 .11315 Mdot
.78 .11317 Mdot
.78 .11339 Mdot
.78 .11363 Mdot
.78 .11385 Mdot
.78 .11432 Mdot
.78 .11437 Mdot
.78 .11441 Mdot
.78 .11463 Mdot
.78 .11476 Mdot
.78 .11476 Mdot
.78 .1149 Mdot
.78 .11499 Mdot
.78 .1151 Mdot
.78 .11512 Mdot
.78 .11513 Mdot
.78 .11564 Mdot
.78 .11565 Mdot
.78 .11565 Mdot
.78 .11566 Mdot
.78 .11571 Mdot
.78 .11596 Mdot
.78 .11637 Mdot
.78 .11686 Mdot
.78 .11704 Mdot
.78 .11736 Mdot
.78 .11736 Mdot
.78 .11767 Mdot
.78 .11773 Mdot
.78 .1178 Mdot
.78 .11822 Mdot
.78 .11876 Mdot
.78 .11881 Mdot
.78 .11894 Mdot
.78 .11927 Mdot
.78 .11929 Mdot
.78 .11933 Mdot
.78 .11963 Mdot
.78 .11975 Mdot
.78 .12009 Mdot
.78 .1203 Mdot
.78 .12044 Mdot
.78 .12044 Mdot
.78 .12055 Mdot
.78 .12066 Mdot
.78 .12121 Mdot
.78 .12155 Mdot
.78 .12155 Mdot
.78 .12192 Mdot
.78 .12216 Mdot
.78 .12247 Mdot
.78 .12251 Mdot
.78 .12254 Mdot
.78 .12396 Mdot
.78 .12399 Mdot
.78 .124 Mdot
.78 .12402 Mdot
.78 .12418 Mdot
.78 .1249 Mdot
.78 .12571 Mdot
.78 .12613 Mdot
.78 .12661 Mdot
.78 .12707 Mdot
.78 .12765 Mdot
.78 .12821 Mdot
.78 .12926 Mdot
.78 .12927 Mdot
.78 .13004 Mdot
.78 .13029 Mdot
.78 .13047 Mdot
.78 .13074 Mdot
.78 .13099 Mdot
.78 .13109 Mdot
.78 .13141 Mdot
.78 .1316 Mdot
.78 .13217 Mdot
.78 .13279 Mdot
.78 .1341 Mdot
.78 .13426 Mdot
.78 .13474 Mdot
.78 .13493 Mdot
.78 .13598 Mdot
.78 .13603 Mdot
.78 .1362 Mdot
.78 .13668 Mdot
.78 .13705 Mdot
.78 .13734 Mdot
.78 .13744 Mdot
.78 .13751 Mdot
.78 .1378 Mdot
.78 .13782 Mdot
.78 .13911 Mdot
.78 .13916 Mdot
.78 .13973 Mdot
.78 .13994 Mdot
.78 .1405 Mdot
.78 .1405 Mdot
.78 .14085 Mdot
.78 .14094 Mdot
.78 .14141 Mdot
.78 .14261 Mdot
.78 .1431 Mdot
.78 .14315 Mdot
.78 .14367 Mdot
.78 .14372 Mdot
.78 .14499 Mdot
.78 .14509 Mdot
.78 .1451 Mdot
.78 .14539 Mdot
.78 .14649 Mdot
.78 .14654 Mdot
.78 .14668 Mdot
.78 .14773 Mdot
.78 .1491 Mdot
.78 .14926 Mdot
.78 .14941 Mdot
.78 .14962 Mdot
.78 .1507 Mdot
.78 .15092 Mdot
.78 .15258 Mdot
.78 .15439 Mdot
.78 .1546 Mdot
.78 .15596 Mdot
.78 .15609 Mdot
.78 .15615 Mdot
.78 .15622 Mdot
.78 .15699 Mdot
.78 .157 Mdot
.78 .15759 Mdot
.78 .15881 Mdot
.78 .16051 Mdot
.78 .16194 Mdot
.78 .16353 Mdot
.78 .16407 Mdot
.78 .16457 Mdot
.78 .16563 Mdot
.78 .16666 Mdot
.78 .16671 Mdot
.78 .16701 Mdot
.78 .16749 Mdot
.78 .169 Mdot
.78 .16918 Mdot
.78 .16931 Mdot
.78 .17095 Mdot
.78 .17128 Mdot
.78 .17164 Mdot
.78 .1724 Mdot
.78 .17244 Mdot
.78 .17298 Mdot
.78 .17327 Mdot
.78 .1734 Mdot
.78 .17473 Mdot
.78 .17781 Mdot
.78 .1786 Mdot
.78 .18071 Mdot
.78 .18126 Mdot
.78 .18142 Mdot
.78 .18169 Mdot
.78 .18225 Mdot
.78 .18297 Mdot
.78 .18343 Mdot
.78 .1836 Mdot
.78 .18369 Mdot
.78 .18371 Mdot
.78 .18504 Mdot
.78 .18816 Mdot
.78 .18958 Mdot
.78 .19064 Mdot
.78 .19104 Mdot
.78 .19221 Mdot
.78 .1937 Mdot
.78 .19395 Mdot
.78 .19429 Mdot
.78 .1947 Mdot
.78 .1956 Mdot
.78 .19624 Mdot
.78 .19652 Mdot
.78 .19669 Mdot
.78 .19735 Mdot
.78 .19762 Mdot
.78 .1983 Mdot
.78 .20081 Mdot
.78 .20461 Mdot
.78 .20668 Mdot
.78 .20769 Mdot
.78 .20771 Mdot
.78 .21111 Mdot
.78 .21211 Mdot
.78 .21233 Mdot
.78 .21278 Mdot
.78 .21379 Mdot
.78 .21685 Mdot
.78 .21809 Mdot
.78 .21928 Mdot
.78 .21977 Mdot
.78 .2211 Mdot
.78 .22185 Mdot
.78 .2249 Mdot
.78 .22522 Mdot
.78 .22524 Mdot
.78 .22631 Mdot
.78 .2266 Mdot
.78 .22681 Mdot
.78 .22759 Mdot
.78 .2285 Mdot
.78 .22953 Mdot
.78 .23018 Mdot
.78 .23189 Mdot
.78 .23197 Mdot
.78 .2339 Mdot
.78 .23421 Mdot
.78 .23448 Mdot
.78 .23455 Mdot
.78 .23502 Mdot
.78 .23692 Mdot
.78 .23708 Mdot
.78 .23963 Mdot
.78 .24161 Mdot
.78 .24475 Mdot
.78 .24578 Mdot
.78 .24613 Mdot
.78 .24756 Mdot
.78 .24997 Mdot
.78 .25001 Mdot
.78 .25063 Mdot
.78 .25147 Mdot
.78 .25154 Mdot
.78 .2549 Mdot
.78 .25495 Mdot
.78 .25508 Mdot
.78 .25532 Mdot
.78 .25534 Mdot
.78 .25598 Mdot
.78 .25777 Mdot
.78 .2584 Mdot
.78 .25913 Mdot
.78 .26167 Mdot
.78 .26389 Mdot
.78 .26571 Mdot
.78 .26811 Mdot
.78 .26813 Mdot
.78 .27006 Mdot
.78 .27008 Mdot
.78 .27037 Mdot
.78 .27143 Mdot
.78 .27247 Mdot
.78 .27332 Mdot
.78 .27352 Mdot
.78 .27381 Mdot
.78 .27405 Mdot
.78 .27521 Mdot
.78 .27752 Mdot
.78 .27789 Mdot
.78 .27796 Mdot
.78 .27866 Mdot
.78 .28206 Mdot
.78 .28687 Mdot
.78 .28701 Mdot
.78 .28757 Mdot
.78 .2877 Mdot
.78 .28808 Mdot
.78 .2897 Mdot
.78 .29228 Mdot
.78 .2936 Mdot
.78 .29571 Mdot
.78 .29665 Mdot
.78 .2968 Mdot
.78 .29724 Mdot
.78 .29763 Mdot
.78 .29795 Mdot
.78 .29796 Mdot
.78 .29854 Mdot
.78 .29879 Mdot
.78 .29896 Mdot
.78 .30021 Mdot
.78 .30138 Mdot
.78 .30386 Mdot
.78 .30528 Mdot
.78 .30648 Mdot
.78 .30771 Mdot
.78 .31304 Mdot
.78 .31311 Mdot
.78 .31632 Mdot
.78 .31661 Mdot
.78 .31747 Mdot
.78 .31857 Mdot
.78 .31863 Mdot
.78 .31891 Mdot
.78 .31935 Mdot
.78 .31948 Mdot
.78 .31951 Mdot
.78 .32008 Mdot
.78 .32009 Mdot
.78 .32166 Mdot
.78 .3219 Mdot
.78 .32194 Mdot
.78 .32271 Mdot
.78 .32306 Mdot
.78 .32379 Mdot
.78 .32386 Mdot
.78 .32392 Mdot
.78 .32424 Mdot
.78 .32443 Mdot
.78 .32463 Mdot
.78 .32475 Mdot
.78 .32492 Mdot
.78 .32493 Mdot
.78 .32495 Mdot
.78 .32565 Mdot
.78 .32566 Mdot
.78 .32567 Mdot
.78 .32567 Mdot
.78 .32608 Mdot
.78 .3266 Mdot
.78 .32721 Mdot
.78 .32743 Mdot
.78 .32781 Mdot
.78 .32781 Mdot
.78 .32817 Mdot
.78 .32824 Mdot
.78 .3288 Mdot
.78 .3294 Mdot
.78 .32945 Mdot
.78 .32959 Mdot
.78 .32997 Mdot
.78 .33002 Mdot
.78 .33081 Mdot
.78 .33116 Mdot
.78 .33127 Mdot
.78 .33139 Mdot
.78 .33193 Mdot
.78 .33226 Mdot
.78 .33226 Mdot
.78 .33261 Mdot
.78 .33284 Mdot
.78 .33313 Mdot
.78 .33316 Mdot
.78 .33319 Mdot
.78 .33448 Mdot
.78 .3345 Mdot
.78 .33451 Mdot
.78 .33452 Mdot
.78 .33467 Mdot
.78 .33529 Mdot
.78 .33632 Mdot
.78 .33671 Mdot
.78 .33709 Mdot
.78 .33754 Mdot
.78 .33799 Mdot
.78 .33879 Mdot
.78 .33879 Mdot
.78 .33956 Mdot
.78 .33969 Mdot
.78 .33989 Mdot
.78 .34038 Mdot
.78 .34092 Mdot
.78 .34136 Mdot
.78 .34226 Mdot
.78 .34237 Mdot
.78 .34269 Mdot
.78 .34352 Mdot
.78 .34356 Mdot
.78 .34366 Mdot
.78 .34441 Mdot
.78 .34447 Mdot
.78 .3447 Mdot
.78 .34553 Mdot
.78 .34591 Mdot
.78 .34604 Mdot
.78 .34639 Mdot
.78 .34639 Mdot
.78 .34666 Mdot
.78 .34694 Mdot
.78 .34828 Mdot
.78 .34831 Mdot
.78 .34904 Mdot
.78 .3491 Mdot
.78 .34911 Mdot
.78 .34927 Mdot
.78 .35 Mdot
.78 .35059 Mdot
.78 .35134 Mdot
.78 .35143 Mdot
.78 .35151 Mdot
.78 .35162 Mdot
.78 .3522 Mdot
.78 .3532 Mdot
.78 .35425 Mdot
.78 .35494 Mdot
.78 .35501 Mdot
.78 .35504 Mdot
.78 .35507 Mdot
.78 .35546 Mdot
.78 .35547 Mdot
.78 .35576 Mdot
.78 .3572 Mdot
.78 .35789 Mdot
.78 .35865 Mdot
.78 .35913 Mdot
.78 .36011 Mdot
.78 .36013 Mdot
.78 .36049 Mdot
.78 .36117 Mdot
.78 .36126 Mdot
.78 .36131 Mdot
.78 .3622 Mdot
.78 .36236 Mdot
.78 .36372 Mdot
.78 .36504 Mdot
.78 .36538 Mdot
.78 .36627 Mdot
.78 .36668 Mdot
.78 .36691 Mdot
.78 .36721 Mdot
.78 .36747 Mdot
.78 .3675 Mdot
.78 .36751 Mdot
.78 .36932 Mdot
.78 .36989 Mdot
.78 .37031 Mdot
.78 .37093 Mdot
.78 .37151 Mdot
.78 .37161 Mdot
.78 .37174 Mdot
.78 .3725 Mdot
.78 .3726 Mdot
.78 .37267 Mdot
.78 .37292 Mdot
.78 .37303 Mdot
.78 .37424 Mdot
.78 .37566 Mdot
.78 .37679 Mdot
.78 .3768 Mdot
.78 .37804 Mdot
.78 .37848 Mdot
.78 .37864 Mdot
.78 .379 Mdot
.78 .38009 Mdot
.78 .38053 Mdot
.78 .38158 Mdot
.78 .38184 Mdot
.78 .3829 Mdot
.78 .38302 Mdot
.78 .38338 Mdot
.78 .38448 Mdot
.78 .3847 Mdot
.78 .38528 Mdot
.78 .38531 Mdot
.78 .38595 Mdot
.78 .38617 Mdot
.78 .38633 Mdot
.78 .38696 Mdot
.78 .38701 Mdot
.78 .38987 Mdot
.78 .38998 Mdot
.78 .39123 Mdot
.78 .3917 Mdot
.78 .39285 Mdot
.78 .39292 Mdot
.78 .39293 Mdot
.78 .3937 Mdot
.78 .3939 Mdot
.78 .39413 Mdot
.78 .39492 Mdot
.78 .39562 Mdot
.78 .39692 Mdot
.78 .39753 Mdot
.78 .39753 Mdot
.78 .39762 Mdot
.78 .39795 Mdot
.78 .39853 Mdot
.78 .39859 Mdot
.78 .39868 Mdot
.78 .3991 Mdot
.78 .39981 Mdot
.78 .39992 Mdot
.78 .40015 Mdot
.78 .40262 Mdot
.78 .40267 Mdot
.78 .40283 Mdot
.78 .40287 Mdot
.78 .40299 Mdot
.78 .40347 Mdot
.78 .40463 Mdot
.78 .40553 Mdot
.78 .40557 Mdot
.78 .40582 Mdot
.78 .40591 Mdot
.78 .40609 Mdot
.78 .40616 Mdot
.78 .40621 Mdot
.78 .40658 Mdot
.78 .40765 Mdot
.78 .40807 Mdot
.78 .40841 Mdot
.78 .40877 Mdot
.78 .41127 Mdot
.78 .4116 Mdot
.78 .41192 Mdot
.78 .41236 Mdot
.78 .41458 Mdot
.78 .41505 Mdot
.78 .41509 Mdot
.78 .41521 Mdot
.78 .41543 Mdot
.78 .41712 Mdot
.78 .41816 Mdot
.78 .41844 Mdot
.78 .41932 Mdot
.78 .42062 Mdot
.78 .42209 Mdot
.78 .42252 Mdot
.78 .42312 Mdot
.78 .42385 Mdot
.78 .42404 Mdot
.78 .42523 Mdot
.78 .42548 Mdot
.78 .4256 Mdot
.78 .42566 Mdot
.78 .42575 Mdot
.78 .42727 Mdot
.78 .42729 Mdot
.78 .42845 Mdot
.78 .4288 Mdot
.78 .42893 Mdot
.78 .43068 Mdot
.78 .43085 Mdot
.78 .43335 Mdot
.78 .43378 Mdot
.78 .43415 Mdot
.78 .43477 Mdot
.78 .43587 Mdot
.78 .4366 Mdot
.78 .43676 Mdot
.78 .4369 Mdot
.78 .4372 Mdot
.78 .43752 Mdot
.78 .43933 Mdot
.78 .43937 Mdot
.78 .43992 Mdot
.78 .44055 Mdot
.78 .44093 Mdot
.78 .44165 Mdot
.78 .44186 Mdot
.78 .44192 Mdot
.78 .44239 Mdot
.78 .44334 Mdot
.78 .44385 Mdot
.78 .44537 Mdot
.78 .44577 Mdot
.78 .44586 Mdot
.78 .44641 Mdot
.78 .44716 Mdot
.78 .4473 Mdot
.78 .44758 Mdot
.78 .44819 Mdot
.78 .45005 Mdot
.78 .45038 Mdot
.78 .45061 Mdot
.78 .45158 Mdot
.78 .45268 Mdot
.78 .45318 Mdot
.78 .45344 Mdot
.78 .45358 Mdot
.78 .45416 Mdot
.78 .45479 Mdot
.78 .45481 Mdot
.78 .45576 Mdot
.78 .45593 Mdot
.78 .45616 Mdot
.78 .45625 Mdot
.78 .45662 Mdot
.78 .4572 Mdot
.78 .45771 Mdot
.78 .45793 Mdot
.78 .4593 Mdot
.78 .4602 Mdot
.78 .46026 Mdot
.78 .46185 Mdot
.78 .46267 Mdot
.78 .46276 Mdot
.78 .46313 Mdot
.78 .46437 Mdot
.78 .46501 Mdot
.78 .46559 Mdot
.78 .4661 Mdot
.78 .46692 Mdot
.78 .46703 Mdot
.78 .46709 Mdot
.78 .47013 Mdot
.78 .47047 Mdot
.78 .47067 Mdot
.78 .47118 Mdot
.78 .47138 Mdot
.78 .47141 Mdot
.78 .47166 Mdot
.78 .47168 Mdot
.78 .4721 Mdot
.78 .47288 Mdot
.78 .47303 Mdot
.78 .4742 Mdot
.78 .47469 Mdot
.78 .47496 Mdot
.78 .47522 Mdot
.78 .47538 Mdot
.78 .47542 Mdot
.78 .4757 Mdot
.78 .4763 Mdot
.78 .47698 Mdot
.78 .47757 Mdot
.78 .48099 Mdot
.78 .48125 Mdot
.78 .48252 Mdot
.78 .48401 Mdot
.78 .4842 Mdot
.78 .48474 Mdot
.78 .48475 Mdot
.78 .48639 Mdot
.78 .48655 Mdot
.78 .48657 Mdot
.78 .487 Mdot
.78 .48879 Mdot
.78 .4889 Mdot
.78 .48902 Mdot
.78 .48912 Mdot
.78 .4893 Mdot
.78 .48968 Mdot
.78 .49103 Mdot
.78 .4914 Mdot
.78 .49146 Mdot
.78 .49175 Mdot
.78 .49191 Mdot
.78 .49252 Mdot
.78 .49284 Mdot
.78 .49373 Mdot
.78 .49385 Mdot
.78 .49436 Mdot
.78 .49479 Mdot
.78 .49521 Mdot
.78 .49544 Mdot
.78 .49641 Mdot
.78 .49651 Mdot
.78 .49681 Mdot
.78 .49779 Mdot
.78 .49837 Mdot
.78 .49964 Mdot
.78 .50003 Mdot
.78 .50135 Mdot
.78 .5015 Mdot
.78 .50385 Mdot
.78 .50416 Mdot
.78 .50433 Mdot
.78 .50438 Mdot
.78 .50503 Mdot
.78 .5066 Mdot
.78 .50804 Mdot
.78 .50863 Mdot
.78 .50905 Mdot
.78 .50938 Mdot
.78 .50949 Mdot
.78 .51072 Mdot
.78 .51074 Mdot
.78 .51277 Mdot
.78 .51323 Mdot
.78 .51368 Mdot
.78 .51422 Mdot
.78 .51515 Mdot
.78 .51558 Mdot
.78 .51605 Mdot
.78 .51611 Mdot
.78 .5162 Mdot
.78 .51642 Mdot
.78 .51642 Mdot
.78 .51654 Mdot
.78 .51669 Mdot
.78 .51685 Mdot
.78 .51691 Mdot
.78 .51725 Mdot
.78 .51803 Mdot
.78 .51851 Mdot
.78 .51946 Mdot
.78 .52005 Mdot
.78 .52019 Mdot
.78 .52024 Mdot
.78 .52044 Mdot
.78 .52049 Mdot
.78 .52224 Mdot
.78 .52346 Mdot
.78 .52371 Mdot
.78 .52374 Mdot
.78 .52387 Mdot
.78 .5247 Mdot
.78 .52511 Mdot
.78 .52519 Mdot
.78 .5253 Mdot
.78 .52537 Mdot
.78 .52567 Mdot
.78 .52604 Mdot
.78 .52641 Mdot
.78 .52652 Mdot
.78 .52653 Mdot
.78 .52721 Mdot
.78 .52721 Mdot
.78 .52806 Mdot
.78 .5287 Mdot
.78 .52948 Mdot
.78 .53036 Mdot
.78 .53061 Mdot
.78 .53083 Mdot
.78 .53145 Mdot
.78 .53167 Mdot
.78 .53168 Mdot
.78 .53176 Mdot
.78 .53181 Mdot
.78 .53183 Mdot
.78 .53298 Mdot
.78 .53301 Mdot
.78 .53329 Mdot
.78 .53351 Mdot
.78 .53352 Mdot
.78 .53434 Mdot
.78 .53483 Mdot
.78 .53495 Mdot
.78 .53531 Mdot
.78 .53637 Mdot
.78 .53704 Mdot
.78 .5379 Mdot
.78 .53795 Mdot
.78 .53859 Mdot
.78 .53875 Mdot
.78 .53877 Mdot
.78 .53886 Mdot
.78 .53896 Mdot
.78 .53961 Mdot
.78 .53964 Mdot
.78 .54021 Mdot
.78 .54042 Mdot
.78 .54076 Mdot
.78 .54107 Mdot
.78 .54132 Mdot
.78 .54139 Mdot
.78 .54149 Mdot
.78 .54184 Mdot
.78 .54185 Mdot
.78 .54196 Mdot
.78 .54296 Mdot
.78 .54321 Mdot
.78 .54365 Mdot
.78 .54381 Mdot
.78 .5442 Mdot
.78 .5446 Mdot
.78 .5456 Mdot
.78 .54593 Mdot
.78 .54607 Mdot
.78 .54614 Mdot
.78 .54647 Mdot
.78 .54757 Mdot
.78 .54758 Mdot
.78 .5479 Mdot
.78 .54857 Mdot
.78 .54978 Mdot
.78 .55058 Mdot
.78 .5508 Mdot
.78 .55089 Mdot
.78 .5511 Mdot
.78 .55115 Mdot
.78 .55124 Mdot
.78 .55144 Mdot
.78 .55173 Mdot
.78 .55186 Mdot
.78 .55197 Mdot
.78 .55205 Mdot
.78 .55252 Mdot
.78 .55289 Mdot
.78 .55301 Mdot
.78 .55335 Mdot
.78 .5538 Mdot
.78 .55477 Mdot
.78 .5548 Mdot
.78 .55519 Mdot
.78 .5552 Mdot
.78 .55523 Mdot
.78 .55528 Mdot
.78 .55542 Mdot
.78 .55565 Mdot
.78 .55582 Mdot
.78 .5559 Mdot
.78 .55596 Mdot
.78 .55613 Mdot
.78 .55678 Mdot
.78 .55703 Mdot
.78 .55798 Mdot
.78 .55839 Mdot
.78 .55843 Mdot
.78 .55852 Mdot
.78 .55869 Mdot
.78 .5587 Mdot
.78 .55894 Mdot
.78 .55905 Mdot
.78 .55915 Mdot
.78 .55965 Mdot
.78 .55969 Mdot
.78 .55975 Mdot
.78 .56021 Mdot
.78 .56036 Mdot
.78 .56045 Mdot
.78 .56046 Mdot
.78 .56078 Mdot
.78 .5611 Mdot
.78 .56126 Mdot
.78 .56142 Mdot
.78 .5619 Mdot
.78 .56234 Mdot
.78 .56285 Mdot
.78 .56322 Mdot
.78 .5634 Mdot
.78 .56341 Mdot
.78 .56364 Mdot
.78 .56366 Mdot
.78 .56368 Mdot
.78 .56372 Mdot
.78 .56413 Mdot
.78 .56419 Mdot
.78 .56474 Mdot
.78 .56524 Mdot
.78 .5653 Mdot
.78 .56563 Mdot
.78 .56569 Mdot
.78 .56574 Mdot
.78 .56578 Mdot
.78 .56619 Mdot
.78 .56651 Mdot
.78 .56655 Mdot
.78 .56656 Mdot
.78 .56689 Mdot
.78 .56698 Mdot
.78 .56698 Mdot
.78 .56701 Mdot
.78 .56739 Mdot
.78 .5674 Mdot
.78 .56756 Mdot
.78 .56757 Mdot
.78 .56772 Mdot
.78 .56808 Mdot
.78 .56822 Mdot
.78 .56824 Mdot
.78 .56835 Mdot
.78 .56835 Mdot
.78 .56851 Mdot
.78 .56858 Mdot
.78 .56875 Mdot
.78 .56876 Mdot
.78 .56914 Mdot
.78 .56915 Mdot
.78 .56923 Mdot
.78 .56925 Mdot
.78 .56928 Mdot
.78 .56937 Mdot
.78 .56948 Mdot
.78 .56962 Mdot
.78 .56967 Mdot
.78 .56969 Mdot
.78 .57 Mdot
.78 .57005 Mdot
.78 .57019 Mdot
.78 .57024 Mdot
.78 .57063 Mdot
.78 .57081 Mdot
.78 .57098 Mdot
.78 .57103 Mdot
.78 .57113 Mdot
.78 .57116 Mdot
.78 .57123 Mdot
.78 .57131 Mdot
.78 .57136 Mdot
.78 .57143 Mdot
.78 .57166 Mdot
.78 .57166 Mdot
.78 .57197 Mdot
.78 .57213 Mdot
.78 .5723 Mdot
.78 .57244 Mdot
.78 .57258 Mdot
.78 .5727 Mdot
.78 .57294 Mdot
.78 .57315 Mdot
.78 .57319 Mdot
.78 .5732 Mdot
.78 .5732 Mdot
.78 .57321 Mdot
.78 .57362 Mdot
.78 .57363 Mdot
.78 .57364 Mdot
.78 .57373 Mdot
.78 .5738 Mdot
.78 .57391 Mdot
.78 .57391 Mdot
.78 .57401 Mdot
.78 .57417 Mdot
.78 .5742 Mdot
.78 .57423 Mdot
.78 .57423 Mdot
.78 .57428 Mdot
.78 .57434 Mdot
.78 .57443 Mdot
.78 .57447 Mdot
.78 .57456 Mdot
.78 .57457 Mdot
.78 .57457 Mdot
.78 .57467 Mdot
.78 .57471 Mdot
.78 .57472 Mdot
.78 .57488 Mdot
.78 .575 Mdot
.78 .57502 Mdot
.78 .57504 Mdot
.78 .57512 Mdot
.78 .57513 Mdot
.78 .57522 Mdot
.78 .57527 Mdot
.78 .57541 Mdot
.78 .57553 Mdot
.78 .5756 Mdot
.78 .57562 Mdot
.78 .57562 Mdot
.78 .57562 Mdot
.78 .57562 Mdot
.78 .57577 Mdot
.78 .57577 Mdot
.78 .57578 Mdot
.78 .57581 Mdot
.78 .57584 Mdot
.78 .57588 Mdot
.78 .57588 Mdot
.78 .57592 Mdot
.78 .57598 Mdot
.78 .57599 Mdot
.78 .576 Mdot
.78 .57614 Mdot
.78 .5762 Mdot
.78 .57627 Mdot
.78 .57633 Mdot
.78 .57634 Mdot
.78 .57638 Mdot
.78 .57643 Mdot
.78 .57645 Mdot
.78 .57652 Mdot
.78 .57658 Mdot
.78 .57662 Mdot
.78 .57662 Mdot
.78 .57663 Mdot
.78 .57663 Mdot
.78 .57671 Mdot
.78 .57671 Mdot
.78 .57671 Mdot
.78 .57673 Mdot
.78 .57674 Mdot
.78 .57676 Mdot
.78 .57679 Mdot
.78 .57682 Mdot
.78 .57683 Mdot
.78 .57692 Mdot
.78 .57696 Mdot
.78 .57704 Mdot
.78 .57705 Mdot
.78 .57707 Mdot
.78 .57725 Mdot
.78 .57731 Mdot
.78 .57732 Mdot
.78 .57733 Mdot
.78 .57738 Mdot
.78 .57741 Mdot
.782 .10861 Mdot
.782 .10862 Mdot
.782 .10866 Mdot
.782 .10866 Mdot
.782 .10872 Mdot
.782 .10872 Mdot
.782 .10884 Mdot
.782 .10894 Mdot
.782 .10898 Mdot
.782 .10898 Mdot
.782 .10904 Mdot
.782 .10913 Mdot
.782 .10958 Mdot
.782 .10969 Mdot
.782 .10976 Mdot
.782 .10982 Mdot
.782 .10982 Mdot
.782 .10989 Mdot
.782 .10992 Mdot
.782 .10993 Mdot
.782 .10993 Mdot
.782 .10993 Mdot
.782 .10996 Mdot
.782 .10997 Mdot
.782 .10999 Mdot
.782 .11001 Mdot
.782 .11002 Mdot
.782 .11002 Mdot
.782 .11014 Mdot
.782 .11023 Mdot
.782 .11027 Mdot
.782 .11027 Mdot
.782 .11034 Mdot
.782 .11035 Mdot
.782 .11043 Mdot
.782 .1108 Mdot
.782 .11093 Mdot
.782 .11107 Mdot
.782 .11116 Mdot
.782 .11122 Mdot
.782 .11123 Mdot
.782 .11132 Mdot
.782 .11136 Mdot
.782 .11136 Mdot
.782 .11136 Mdot
.782 .11137 Mdot
.782 .11141 Mdot
.782 .11142 Mdot
.782 .11145 Mdot
.782 .11147 Mdot
.782 .11149 Mdot
.782 .11149 Mdot
.782 .11164 Mdot
.782 .11177 Mdot
.782 .11183 Mdot
.782 .11183 Mdot
.782 .11192 Mdot
.782 .11193 Mdot
.782 .11205 Mdot
.782 .11216 Mdot
.782 .11261 Mdot
.782 .11281 Mdot
.782 .11304 Mdot
.782 .11317 Mdot
.782 .11329 Mdot
.782 .11329 Mdot
.782 .11345 Mdot
.782 .11351 Mdot
.782 .11352 Mdot
.782 .11352 Mdot
.782 .11353 Mdot
.782 .1136 Mdot
.782 .1136 Mdot
.782 .11362 Mdot
.782 .11363 Mdot
.782 .11367 Mdot
.782 .1137 Mdot
.782 .11374 Mdot
.782 .11374 Mdot
.782 .11398 Mdot
.782 .11401 Mdot
.782 .11424 Mdot
.782 .11426 Mdot
.782 .11434 Mdot
.782 .11435 Mdot
.782 .11452 Mdot
.782 .11454 Mdot
.782 .11477 Mdot
.782 .11497 Mdot
.782 .11511 Mdot
.782 .11536 Mdot
.782 .11586 Mdot
.782 .11623 Mdot
.782 .1163 Mdot
.782 .11677 Mdot
.782 .11681 Mdot
.782 .11707 Mdot
.782 .11733 Mdot
.782 .11734 Mdot
.782 .11769 Mdot
.782 .11784 Mdot
.782 .11786 Mdot
.782 .11786 Mdot
.782 .11788 Mdot
.782 .11804 Mdot
.782 .11806 Mdot
.782 .1181 Mdot
.782 .11813 Mdot
.782 .11821 Mdot
.782 .11829 Mdot
.782 .11836 Mdot
.782 .11837 Mdot
.782 .11896 Mdot
.782 .11901 Mdot
.782 .11916 Mdot
.782 .11961 Mdot
.782 .11964 Mdot
.782 .11969 Mdot
.782 .11985 Mdot
.782 .11987 Mdot
.782 .12032 Mdot
.782 .12037 Mdot
.782 .12095 Mdot
.782 .12149 Mdot
.782 .12151 Mdot
.782 .12187 Mdot
.782 .12258 Mdot
.782 .12389 Mdot
.782 .12401 Mdot
.782 .12455 Mdot
.782 .1251 Mdot
.782 .1253 Mdot
.782 .12569 Mdot
.782 .12621 Mdot
.782 .1263 Mdot
.782 .12678 Mdot
.782 .1269 Mdot
.782 .1277 Mdot
.782 .1279 Mdot
.782 .12809 Mdot
.782 .12857 Mdot
.782 .1286 Mdot
.782 .12981 Mdot
.782 .13031 Mdot
.782 .13037 Mdot
.782 .13038 Mdot
.782 .13043 Mdot
.782 .13098 Mdot
.782 .13105 Mdot
.782 .1312 Mdot
.782 .1313 Mdot
.782 .1316 Mdot
.782 .13187 Mdot
.782 .13213 Mdot
.782 .13214 Mdot
.782 .13315 Mdot
.782 .13342 Mdot
.782 .13427 Mdot
.782 .13449 Mdot
.782 .13504 Mdot
.782 .13603 Mdot
.782 .13672 Mdot
.782 .13684 Mdot
.782 .13703 Mdot
.782 .13766 Mdot
.782 .13776 Mdot
.782 .13952 Mdot
.782 .13972 Mdot
.782 .14064 Mdot
.782 .14128 Mdot
.782 .14209 Mdot
.782 .14276 Mdot
.782 .14435 Mdot
.782 .14443 Mdot
.782 .14541 Mdot
.782 .14599 Mdot
.782 .14632 Mdot
.782 .14705 Mdot
.782 .1485 Mdot
.782 .14897 Mdot
.782 .1491 Mdot
.782 .14914 Mdot
.782 .15266 Mdot
.782 .15519 Mdot
.782 .15577 Mdot
.782 .15673 Mdot
.782 .15763 Mdot
.782 .15839 Mdot
.782 .1601 Mdot
.782 .16108 Mdot
.782 .16212 Mdot
.782 .1622 Mdot
.782 .16222 Mdot
.782 .1626 Mdot
.782 .16263 Mdot
.782 .16407 Mdot
.782 .16572 Mdot
.782 .16615 Mdot
.782 .16677 Mdot
.782 .16722 Mdot
.782 .16885 Mdot
.782 .16963 Mdot
.782 .16975 Mdot
.782 .17039 Mdot
.782 .17227 Mdot
.782 .17265 Mdot
.782 .17279 Mdot
.782 .17466 Mdot
.782 .1754 Mdot
.782 .17576 Mdot
.782 .17587 Mdot
.782 .1768 Mdot
.782 .17949 Mdot
.782 .17967 Mdot
.782 .1839 Mdot
.782 .18453 Mdot
.782 .18466 Mdot
.782 .1862 Mdot
.782 .18651 Mdot
.782 .18793 Mdot
.782 .18945 Mdot
.782 .1898 Mdot
.782 .18984 Mdot
.782 .19016 Mdot
.782 .19193 Mdot
.782 .1934 Mdot
.782 .19383 Mdot
.782 .19469 Mdot
.782 .19532 Mdot
.782 .19713 Mdot
.782 .19873 Mdot
.782 .20035 Mdot
.782 .2004 Mdot
.782 .20073 Mdot
.782 .20378 Mdot
.782 .2042 Mdot
.782 .20664 Mdot
.782 .20759 Mdot
.782 .20765 Mdot
.782 .20834 Mdot
.782 .20858 Mdot
.782 .20873 Mdot
.782 .21003 Mdot
.782 .21015 Mdot
.782 .2131 Mdot
.782 .21372 Mdot
.782 .21511 Mdot
.782 .21527 Mdot
.782 .21704 Mdot
.782 .21862 Mdot
.782 .22015 Mdot
.782 .22209 Mdot
.782 .22274 Mdot
.782 .22363 Mdot
.782 .22508 Mdot
.782 .22658 Mdot
.782 .22965 Mdot
.782 .23044 Mdot
.782 .23174 Mdot
.782 .23436 Mdot
.782 .2359 Mdot
.782 .23658 Mdot
.782 .23766 Mdot
.782 .23829 Mdot
.782 .23906 Mdot
.782 .24069 Mdot
.782 .24103 Mdot
.782 .24855 Mdot
.782 .24992 Mdot
.782 .25018 Mdot
.782 .25487 Mdot
.782 .25627 Mdot
.782 .25805 Mdot
.782 .25949 Mdot
.782 .2595 Mdot
.782 .25968 Mdot
.782 .2607 Mdot
.782 .26235 Mdot
.782 .26442 Mdot
.782 .26638 Mdot
.782 .26663 Mdot
.782 .26986 Mdot
.782 .27074 Mdot
.782 .27112 Mdot
.782 .27573 Mdot
.782 .27957 Mdot
.782 .28096 Mdot
.782 .28146 Mdot
.782 .2824 Mdot
.782 .28296 Mdot
.782 .28511 Mdot
.782 .28686 Mdot
.782 .28739 Mdot
.782 .28997 Mdot
.782 .29066 Mdot
.782 .29207 Mdot
.782 .29412 Mdot
.782 .29418 Mdot
.782 .2965 Mdot
.782 .30026 Mdot
.782 .30172 Mdot
.782 .30422 Mdot
.782 .30464 Mdot
.782 .305 Mdot
.782 .30682 Mdot
.782 .30683 Mdot
.782 .30746 Mdot
.782 .30911 Mdot
.782 .30961 Mdot
.782 .31044 Mdot
.782 .31219 Mdot
.782 .31282 Mdot
.782 .31305 Mdot
.782 .31555 Mdot
.782 .31593 Mdot
.782 .31614 Mdot
.782 .31632 Mdot
.782 .31654 Mdot
.782 .31662 Mdot
.782 .31663 Mdot
.782 .31663 Mdot
.782 .31664 Mdot
.782 .31674 Mdot
.782 .31676 Mdot
.782 .31683 Mdot
.782 .31687 Mdot
.782 .3169 Mdot
.782 .31691 Mdot
.782 .31722 Mdot
.782 .31747 Mdot
.782 .31757 Mdot
.782 .31758 Mdot
.782 .31775 Mdot
.782 .31798 Mdot
.782 .31885 Mdot
.782 .31914 Mdot
.782 .31944 Mdot
.782 .31961 Mdot
.782 .31976 Mdot
.782 .31976 Mdot
.782 .31995 Mdot
.782 .32003 Mdot
.782 .32004 Mdot
.782 .32004 Mdot
.782 .32005 Mdot
.782 .32014 Mdot
.782 .32016 Mdot
.782 .32021 Mdot
.782 .32025 Mdot
.782 .32028 Mdot
.782 .32029 Mdot
.782 .32058 Mdot
.782 .32083 Mdot
.782 .32093 Mdot
.782 .32094 Mdot
.782 .32111 Mdot
.782 .32113 Mdot
.782 .32134 Mdot
.782 .3223 Mdot
.782 .32264 Mdot
.782 .323 Mdot
.782 .32321 Mdot
.782 .32339 Mdot
.782 .32339 Mdot
.782 .32363 Mdot
.782 .32373 Mdot
.782 .32374 Mdot
.782 .32374 Mdot
.782 .32376 Mdot
.782 .32387 Mdot
.782 .3239 Mdot
.782 .32397 Mdot
.782 .32402 Mdot
.782 .32406 Mdot
.782 .32407 Mdot
.782 .32442 Mdot
.782 .32446 Mdot
.782 .3248 Mdot
.782 .32481 Mdot
.782 .32493 Mdot
.782 .32494 Mdot
.782 .32518 Mdot
.782 .32521 Mdot
.782 .32551 Mdot
.782 .32579 Mdot
.782 .3263 Mdot
.782 .32693 Mdot
.782 .32746 Mdot
.782 .32802 Mdot
.782 .32837 Mdot
.782 .32866 Mdot
.782 .32867 Mdot
.782 .32907 Mdot
.782 .32924 Mdot
.782 .32925 Mdot
.782 .32926 Mdot
.782 .32927 Mdot
.782 .32945 Mdot
.782 .32947 Mdot
.782 .32952 Mdot
.782 .32955 Mdot
.782 .32964 Mdot
.782 .32972 Mdot
.782 .3298 Mdot
.782 .3298 Mdot
.782 .33043 Mdot
.782 .33049 Mdot
.782 .33109 Mdot
.782 .33112 Mdot
.782 .33134 Mdot
.782 .33136 Mdot
.782 .3318 Mdot
.782 .33185 Mdot
.782 .33241 Mdot
.782 .33294 Mdot
.782 .33327 Mdot
.782 .33392 Mdot
.782 .33517 Mdot
.782 .33609 Mdot
.782 .33626 Mdot
.782 .337 Mdot
.782 .33745 Mdot
.782 .33755 Mdot
.782 .33817 Mdot
.782 .3382 Mdot
.782 .33832 Mdot
.782 .33883 Mdot
.782 .33886 Mdot
.782 .33975 Mdot
.782 .34012 Mdot
.782 .34016 Mdot
.782 .34017 Mdot
.782 .34021 Mdot
.782 .3406 Mdot
.782 .34065 Mdot
.782 .34076 Mdot
.782 .34083 Mdot
.782 .34104 Mdot
.782 .34123 Mdot
.782 .34142 Mdot
.782 .34142 Mdot
.782 .34212 Mdot
.782 .34288 Mdot
.782 .34302 Mdot
.782 .34339 Mdot
.782 .34403 Mdot
.782 .34448 Mdot
.782 .34456 Mdot
.782 .34468 Mdot
.782 .34508 Mdot
.782 .34514 Mdot
.782 .34623 Mdot
.782 .34636 Mdot
.782 .34778 Mdot
.782 .34909 Mdot
.782 .34914 Mdot
.782 .34969 Mdot
.782 .35002 Mdot
.782 .3502 Mdot
.782 .35061 Mdot
.782 .35173 Mdot
.782 .35175 Mdot
.782 .35491 Mdot
.782 .3552 Mdot
.782 .35613 Mdot
.782 .3565 Mdot
.782 .35781 Mdot
.782 .3583 Mdot
.782 .35834 Mdot
.782 .35922 Mdot
.782 .36018 Mdot
.782 .36047 Mdot
.782 .36068 Mdot
.782 .36141 Mdot
.782 .36182 Mdot
.782 .3621 Mdot
.782 .36294 Mdot
.782 .3631 Mdot
.782 .36398 Mdot
.782 .3643 Mdot
.782 .36445 Mdot
.782 .3645 Mdot
.782 .36489 Mdot
.782 .36603 Mdot
.782 .36611 Mdot
.782 .36817 Mdot
.782 .36879 Mdot
.782 .36892 Mdot
.782 .37009 Mdot
.782 .37023 Mdot
.782 .37025 Mdot
.782 .37037 Mdot
.782 .37107 Mdot
.782 .37164 Mdot
.782 .37181 Mdot
.782 .37214 Mdot
.782 .37238 Mdot
.782 .37308 Mdot
.782 .37369 Mdot
.782 .3743 Mdot
.782 .37432 Mdot
.782 .37444 Mdot
.782 .37558 Mdot
.782 .37574 Mdot
.782 .37663 Mdot
.782 .37698 Mdot
.782 .37725 Mdot
.782 .3774 Mdot
.782 .37787 Mdot
.782 .37791 Mdot
.782 .37919 Mdot
.782 .37969 Mdot
.782 .38092 Mdot
.782 .38235 Mdot
.782 .38266 Mdot
.782 .38316 Mdot
.782 .38471 Mdot
.782 .38498 Mdot
.782 .38542 Mdot
.782 .38681 Mdot
.782 .38703 Mdot
.782 .38739 Mdot
.782 .38785 Mdot
.782 .3885 Mdot
.782 .39093 Mdot
.782 .39137 Mdot
.782 .39339 Mdot
.782 .39395 Mdot
.782 .39441 Mdot
.782 .39446 Mdot
.782 .39478 Mdot
.782 .39655 Mdot
.782 .39662 Mdot
.782 .39762 Mdot
.782 .398 Mdot
.782 .40057 Mdot
.782 .40114 Mdot
.782 .40142 Mdot
.782 .40159 Mdot
.782 .40224 Mdot
.782 .40369 Mdot
.782 .40389 Mdot
.782 .40492 Mdot
.782 .40562 Mdot
.782 .40672 Mdot
.782 .40715 Mdot
.782 .40811 Mdot
.782 .40864 Mdot
.782 .40864 Mdot
.782 .40883 Mdot
.782 .4102 Mdot
.782 .41117 Mdot
.782 .41128 Mdot
.782 .41134 Mdot
.782 .41145 Mdot
.782 .41148 Mdot
.782 .41154 Mdot
.782 .41155 Mdot
.782 .41212 Mdot
.782 .41372 Mdot
.782 .41876 Mdot
.782 .42104 Mdot
.782 .42116 Mdot
.782 .42147 Mdot
.782 .42386 Mdot
.782 .42468 Mdot
.782 .42502 Mdot
.782 .42507 Mdot
.782 .42628 Mdot
.782 .42692 Mdot
.782 .4287 Mdot
.782 .42884 Mdot
.782 .42885 Mdot
.782 .43019 Mdot
.782 .43165 Mdot
.782 .43352 Mdot
.782 .43442 Mdot
.782 .43525 Mdot
.782 .43542 Mdot
.782 .43573 Mdot
.782 .4362 Mdot
.782 .43701 Mdot
.782 .4374 Mdot
.782 .43755 Mdot
.782 .43755 Mdot
.782 .43761 Mdot
.782 .43831 Mdot
.782 .43832 Mdot
.782 .43838 Mdot
.782 .439 Mdot
.782 .44111 Mdot
.782 .44114 Mdot
.782 .44337 Mdot
.782 .44419 Mdot
.782 .445 Mdot
.782 .44552 Mdot
.782 .44592 Mdot
.782 .44614 Mdot
.782 .44635 Mdot
.782 .44698 Mdot
.782 .44853 Mdot
.782 .44997 Mdot
.782 .45115 Mdot
.782 .45138 Mdot
.782 .4516 Mdot
.782 .45276 Mdot
.782 .45394 Mdot
.782 .45507 Mdot
.782 .45544 Mdot
.782 .45584 Mdot
.782 .45612 Mdot
.782 .45654 Mdot
.782 .45679 Mdot
.782 .45704 Mdot
.782 .45747 Mdot
.782 .4589 Mdot
.782 .46033 Mdot
.782 .46033 Mdot
.782 .46163 Mdot
.782 .46224 Mdot
.782 .46243 Mdot
.782 .46403 Mdot
.782 .46419 Mdot
.782 .46425 Mdot
.782 .46784 Mdot
.782 .46861 Mdot
.782 .46888 Mdot
.782 .46892 Mdot
.782 .46898 Mdot
.782 .46901 Mdot
.782 .47019 Mdot
.782 .47028 Mdot
.782 .47028 Mdot
.782 .47053 Mdot
.782 .47119 Mdot
.782 .47253 Mdot
.782 .4733 Mdot
.782 .47381 Mdot
.782 .47408 Mdot
.782 .47545 Mdot
.782 .47591 Mdot
.782 .4769 Mdot
.782 .47693 Mdot
.782 .47714 Mdot
.782 .47962 Mdot
.782 .47991 Mdot
.782 .48011 Mdot
.782 .48223 Mdot
.782 .48236 Mdot
.782 .48432 Mdot
.782 .48434 Mdot
.782 .48455 Mdot
.782 .48473 Mdot
.782 .48528 Mdot
.782 .48534 Mdot
.782 .48584 Mdot
.782 .4873 Mdot
.782 .48828 Mdot
.782 .48855 Mdot
.782 .49011 Mdot
.782 .4902 Mdot
.782 .49071 Mdot
.782 .49078 Mdot
.782 .49142 Mdot
.782 .49194 Mdot
.782 .49271 Mdot
.782 .49364 Mdot
.782 .49546 Mdot
.782 .49592 Mdot
.782 .49609 Mdot
.782 .4963 Mdot
.782 .49861 Mdot
.782 .49938 Mdot
.782 .50091 Mdot
.782 .50097 Mdot
.782 .50144 Mdot
.782 .50567 Mdot
.782 .50625 Mdot
.782 .50641 Mdot
.782 .50857 Mdot
.782 .50933 Mdot
.782 .50934 Mdot
.782 .50942 Mdot
.782 .50946 Mdot
.782 .50954 Mdot
.782 .50961 Mdot
.782 .50969 Mdot
.782 .50983 Mdot
.782 .51079 Mdot
.782 .51088 Mdot
.782 .51112 Mdot
.782 .51178 Mdot
.782 .5121 Mdot
.782 .51229 Mdot
.782 .51291 Mdot
.782 .51315 Mdot
.782 .51315 Mdot
.782 .51383 Mdot
.782 .51397 Mdot
.782 .51413 Mdot
.782 .51506 Mdot
.782 .51561 Mdot
.782 .517 Mdot
.782 .51786 Mdot
.782 .51788 Mdot
.782 .51864 Mdot
.782 .51915 Mdot
.782 .51941 Mdot
.782 .52034 Mdot
.782 .52054 Mdot
.782 .52117 Mdot
.782 .52195 Mdot
.782 .52216 Mdot
.782 .5225 Mdot
.782 .52267 Mdot
.782 .52317 Mdot
.782 .52455 Mdot
.782 .52619 Mdot
.782 .52632 Mdot
.782 .52663 Mdot
.782 .52777 Mdot
.782 .52786 Mdot
.782 .52855 Mdot
.782 .52927 Mdot
.782 .52985 Mdot
.782 .5302 Mdot
.782 .53026 Mdot
.782 .53027 Mdot
.782 .53077 Mdot
.782 .53139 Mdot
.782 .53187 Mdot
.782 .53348 Mdot
.782 .53357 Mdot
.782 .53404 Mdot
.782 .5366 Mdot
.782 .53671 Mdot
.782 .53726 Mdot
.782 .53752 Mdot
.782 .53773 Mdot
.782 .5381 Mdot
.782 .53832 Mdot
.782 .53884 Mdot
.782 .53972 Mdot
.782 .54015 Mdot
.782 .54041 Mdot
.782 .54143 Mdot
.782 .54193 Mdot
.782 .54241 Mdot
.782 .5427 Mdot
.782 .54291 Mdot
.782 .54355 Mdot
.782 .54405 Mdot
.782 .54457 Mdot
.782 .54514 Mdot
.782 .5452 Mdot
.782 .54565 Mdot
.782 .54585 Mdot
.782 .54681 Mdot
.782 .54685 Mdot
.782 .54727 Mdot
.782 .54731 Mdot
.782 .54739 Mdot
.782 .54761 Mdot
.782 .54764 Mdot
.782 .54794 Mdot
.782 .54872 Mdot
.782 .54886 Mdot
.782 .54984 Mdot
.782 .54994 Mdot
.782 .54996 Mdot
.782 .55047 Mdot
.782 .55098 Mdot
.782 .55156 Mdot
.782 .55176 Mdot
.782 .55203 Mdot
.782 .55217 Mdot
.782 .55263 Mdot
.782 .55319 Mdot
.782 .55329 Mdot
.782 .5533 Mdot
.782 .55341 Mdot
.782 .55389 Mdot
.782 .55434 Mdot
.782 .55443 Mdot
.782 .55492 Mdot
.782 .55496 Mdot
.782 .55515 Mdot
.782 .55647 Mdot
.782 .55653 Mdot
.782 .55736 Mdot
.782 .55765 Mdot
.782 .55769 Mdot
.782 .55779 Mdot
.782 .55802 Mdot
.782 .5586 Mdot
.782 .55865 Mdot
.782 .55876 Mdot
.782 .55934 Mdot
.782 .55954 Mdot
.782 .55957 Mdot
.782 .55981 Mdot
.782 .56031 Mdot
.782 .56045 Mdot
.782 .56064 Mdot
.782 .56077 Mdot
.782 .56127 Mdot
.782 .56171 Mdot
.782 .56172 Mdot
.782 .56184 Mdot
.782 .56185 Mdot
.782 .56187 Mdot
.782 .56218 Mdot
.782 .56248 Mdot
.782 .563 Mdot
.782 .56323 Mdot
.782 .5635 Mdot
.782 .56379 Mdot
.782 .56397 Mdot
.782 .56473 Mdot
.782 .56579 Mdot
.782 .5658 Mdot
.782 .56584 Mdot
.782 .56598 Mdot
.782 .56641 Mdot
.782 .56663 Mdot
.782 .56673 Mdot
.782 .5669 Mdot
.782 .56719 Mdot
.782 .56722 Mdot
.782 .56769 Mdot
.782 .56789 Mdot
.782 .56813 Mdot
.782 .56832 Mdot
.782 .56859 Mdot
.782 .56865 Mdot
.782 .56918 Mdot
.782 .5692 Mdot
.782 .56939 Mdot
.782 .56945 Mdot
.782 .56948 Mdot
.782 .56969 Mdot
.782 .56998 Mdot
.782 .57014 Mdot
.782 .5702 Mdot
.782 .57045 Mdot
.782 .57053 Mdot
.782 .57083 Mdot
.782 .57083 Mdot
.782 .57091 Mdot
.782 .57099 Mdot
.782 .57108 Mdot
.782 .57111 Mdot
.782 .57115 Mdot
.782 .57117 Mdot
.782 .57133 Mdot
.782 .57135 Mdot
.782 .57135 Mdot
.782 .57137 Mdot
.782 .57152 Mdot
.782 .57187 Mdot
.782 .57188 Mdot
.782 .57202 Mdot
.782 .57207 Mdot
.782 .57213 Mdot
.782 .57237 Mdot
.782 .5724 Mdot
.782 .57254 Mdot
.782 .57257 Mdot
.782 .57272 Mdot
.782 .57283 Mdot
.782 .57289 Mdot
.782 .57305 Mdot
.782 .57321 Mdot
.782 .57324 Mdot
.782 .57362 Mdot
.782 .57383 Mdot
.782 .57394 Mdot
.782 .57394 Mdot
.782 .5741 Mdot
.782 .57427 Mdot
.782 .57428 Mdot
.782 .57441 Mdot
.782 .57442 Mdot
.782 .57447 Mdot
.782 .57448 Mdot
.782 .57449 Mdot
.782 .57462 Mdot
.782 .57466 Mdot
.782 .57468 Mdot
.782 .57485 Mdot
.782 .57485 Mdot
.782 .57487 Mdot
.782 .57489 Mdot
.782 .57492 Mdot
.782 .57492 Mdot
.782 .57494 Mdot
.782 .57494 Mdot
.782 .57499 Mdot
.782 .57499 Mdot
.782 .57499 Mdot
.782 .575 Mdot
.782 .57504 Mdot
.782 .57515 Mdot
.782 .57515 Mdot
.782 .57522 Mdot
.782 .5753 Mdot
.782 .57531 Mdot
.782 .57545 Mdot
.782 .57547 Mdot
.782 .57557 Mdot
.782 .57571 Mdot
.782 .57579 Mdot
.782 .57583 Mdot
.782 .57589 Mdot
.782 .57595 Mdot
.782 .57596 Mdot
.782 .57601 Mdot
.782 .57601 Mdot
.782 .57603 Mdot
.782 .57604 Mdot
.782 .57611 Mdot
.782 .57611 Mdot
.782 .57618 Mdot
.782 .57618 Mdot
.782 .57619 Mdot
.782 .5762 Mdot
.782 .57621 Mdot
.782 .57622 Mdot
.782 .57622 Mdot
.782 .57622 Mdot
.782 .57624 Mdot
.782 .57625 Mdot
.782 .57625 Mdot
.782 .57625 Mdot
.782 .57627 Mdot
.782 .57631 Mdot
.782 .57631 Mdot
.782 .57635 Mdot
.782 .57639 Mdot
.782 .57645 Mdot
.782 .57651 Mdot
.782 .57664 Mdot
.782 .57667 Mdot
.782 .5767 Mdot
.782 .57671 Mdot
.782 .57673 Mdot
.782 .57673 Mdot
.782 .57675 Mdot
.782 .57679 Mdot
.782 .57683 Mdot
.782 .57683 Mdot
.782 .57684 Mdot
.782 .57684 Mdot
.782 .57685 Mdot
.782 .57685 Mdot
.782 .57687 Mdot
.782 .57687 Mdot
.782 .57687 Mdot
.782 .57687 Mdot
.782 .57688 Mdot
.782 .57691 Mdot
.782 .57691 Mdot
.782 .57693 Mdot
.782 .57695 Mdot
.782 .57699 Mdot
.782 .57703 Mdot
.782 .57713 Mdot
.782 .57716 Mdot
.782 .57716 Mdot
.782 .57718 Mdot
.782 .57718 Mdot
.782 .57719 Mdot
.782 .57722 Mdot
.782 .57725 Mdot
.782 .57725 Mdot
.782 .57726 Mdot
.782 .57726 Mdot
.782 .57727 Mdot
.782 .57727 Mdot
.782 .57728 Mdot
.782 .57728 Mdot
.782 .57728 Mdot
.782 .57728 Mdot
.782 .57729 Mdot
.782 .57731 Mdot
.782 .57731 Mdot
.782 .57733 Mdot
.782 .57735 Mdot
.782 .57738 Mdot
.782 .57751 Mdot
.782 .57753 Mdot
.782 .57755 Mdot
.782 .57755 Mdot
.782 .57756 Mdot
.782 .57759 Mdot
.782 .57762 Mdot
.782 .57763 Mdot
.782 .57764 Mdot
.782 .57764 Mdot
.782 .57765 Mdot
.782 .57766 Mdot
.784 .10783 Mdot
.784 .10783 Mdot
.784 .10783 Mdot
.784 .10783 Mdot
.784 .10803 Mdot
.784 .10808 Mdot
.784 .1081 Mdot
.784 .10828 Mdot
.784 .10856 Mdot
.784 .10856 Mdot
.784 .10856 Mdot
.784 .10857 Mdot
.784 .10871 Mdot
.784 .10874 Mdot
.784 .10876 Mdot
.784 .10876 Mdot
.784 .1089 Mdot
.784 .10905 Mdot
.784 .10914 Mdot
.784 .10914 Mdot
.784 .10914 Mdot
.784 .10914 Mdot
.784 .10928 Mdot
.784 .10931 Mdot
.784 .10932 Mdot
.784 .10932 Mdot
.784 .10946 Mdot
.784 .10961 Mdot
.784 .10968 Mdot
.784 .10971 Mdot
.784 .10971 Mdot
.784 .10971 Mdot
.784 .10972 Mdot
.784 .10974 Mdot
.784 .10986 Mdot
.784 .1099 Mdot
.784 .10991 Mdot
.784 .10991 Mdot
.784 .11007 Mdot
.784 .11025 Mdot
.784 .11034 Mdot
.784 .11038 Mdot
.784 .11038 Mdot
.784 .11038 Mdot
.784 .11038 Mdot
.784 .11039 Mdot
.784 .11042 Mdot
.784 .11056 Mdot
.784 .11061 Mdot
.784 .11063 Mdot
.784 .11063 Mdot
.784 .11065 Mdot
.784 .11079 Mdot
.784 .11084 Mdot
.784 .11109 Mdot
.784 .11121 Mdot
.784 .11127 Mdot
.784 .11127 Mdot
.784 .11127 Mdot
.784 .11127 Mdot
.784 .11128 Mdot
.784 .11132 Mdot
.784 .11154 Mdot
.784 .11162 Mdot
.784 .11164 Mdot
.784 .11165 Mdot
.784 .11168 Mdot
.784 .11189 Mdot
.784 .11189 Mdot
.784 .11196 Mdot
.784 .11228 Mdot
.784 .11237 Mdot
.784 .11257 Mdot
.784 .11267 Mdot
.784 .11267 Mdot
.784 .11267 Mdot
.784 .11268 Mdot
.784 .11269 Mdot
.784 .11277 Mdot
.784 .11277 Mdot
.784 .11315 Mdot
.784 .11328 Mdot
.784 .11333 Mdot
.784 .11333 Mdot
.784 .11339 Mdot
.784 .11345 Mdot
.784 .11347 Mdot
.784 .11361 Mdot
.784 .11368 Mdot
.784 .11379 Mdot
.784 .11379 Mdot
.784 .11388 Mdot
.784 .11392 Mdot
.784 .11397 Mdot
.784 .11411 Mdot
.784 .11453 Mdot
.784 .11458 Mdot
.784 .11472 Mdot
.784 .11479 Mdot
.784 .11484 Mdot
.784 .11513 Mdot
.784 .11532 Mdot
.784 .11533 Mdot
.784 .11534 Mdot
.784 .11535 Mdot
.784 .11538 Mdot
.784 .11543 Mdot
.784 .11553 Mdot
.784 .11553 Mdot
.784 .11553 Mdot
.784 .11594 Mdot
.784 .1163 Mdot
.784 .11637 Mdot
.784 .11658 Mdot
.784 .11665 Mdot
.784 .11677 Mdot
.784 .11679 Mdot
.784 .11691 Mdot
.784 .11704 Mdot
.784 .1171 Mdot
.784 .11727 Mdot
.784 .11742 Mdot
.784 .1176 Mdot
.784 .11766 Mdot
.784 .11785 Mdot
.784 .11785 Mdot
.784 .11808 Mdot
.784 .11817 Mdot
.784 .1183 Mdot
.784 .11857 Mdot
.784 .11864 Mdot
.784 .11902 Mdot
.784 .11972 Mdot
.784 .11984 Mdot
.784 .12022 Mdot
.784 .12041 Mdot
.784 .12052 Mdot
.784 .1213 Mdot
.784 .12158 Mdot
.784 .12186 Mdot
.784 .12186 Mdot
.784 .1219 Mdot
.784 .12192 Mdot
.784 .12193 Mdot
.784 .12202 Mdot
.784 .12216 Mdot
.784 .12234 Mdot
.784 .12243 Mdot
.784 .12245 Mdot
.784 .12245 Mdot
.784 .12363 Mdot
.784 .12437 Mdot
.784 .12441 Mdot
.784 .12474 Mdot
.784 .12493 Mdot
.784 .12558 Mdot
.784 .12582 Mdot
.784 .1262 Mdot
.784 .12625 Mdot
.784 .12666 Mdot
.784 .12707 Mdot
.784 .12725 Mdot
.784 .12781 Mdot
.784 .128 Mdot
.784 .1283 Mdot
.784 .12864 Mdot
.784 .12892 Mdot
.784 .12912 Mdot
.784 .12937 Mdot
.784 .12976 Mdot
.784 .12977 Mdot
.784 .13057 Mdot
.784 .13091 Mdot
.784 .13233 Mdot
.784 .13259 Mdot
.784 .13297 Mdot
.784 .13399 Mdot
.784 .13605 Mdot
.784 .13664 Mdot
.784 .13665 Mdot
.784 .13681 Mdot
.784 .13712 Mdot
.784 .13861 Mdot
.784 .13937 Mdot
.784 .13984 Mdot
.784 .14303 Mdot
.784 .14309 Mdot
.784 .14427 Mdot
.784 .14548 Mdot
.784 .1455 Mdot
.784 .14561 Mdot
.784 .14565 Mdot
.784 .14576 Mdot
.784 .14577 Mdot
.784 .14585 Mdot
.784 .14619 Mdot
.784 .14679 Mdot
.784 .14762 Mdot
.784 .14801 Mdot
.784 .1481 Mdot
.784 .14811 Mdot
.784 .14893 Mdot
.784 .15025 Mdot
.784 .15355 Mdot
.784 .154 Mdot
.784 .15711 Mdot
.784 .1572 Mdot
.784 .15728 Mdot
.784 .15891 Mdot
.784 .15984 Mdot
.784 .16141 Mdot
.784 .16315 Mdot
.784 .16437 Mdot
.784 .16634 Mdot
.784 .16644 Mdot
.784 .16658 Mdot
.784 .16695 Mdot
.784 .16872 Mdot
.784 .17048 Mdot
.784 .17092 Mdot
.784 .17189 Mdot
.784 .17244 Mdot
.784 .17336 Mdot
.784 .17464 Mdot
.784 .17496 Mdot
.784 .17599 Mdot
.784 .17634 Mdot
.784 .17766 Mdot
.784 .17959 Mdot
.784 .18021 Mdot
.784 .18112 Mdot
.784 .1819 Mdot
.784 .18229 Mdot
.784 .18275 Mdot
.784 .18369 Mdot
.784 .18597 Mdot
.784 .18603 Mdot
.784 .19008 Mdot
.784 .19074 Mdot
.784 .19198 Mdot
.784 .19273 Mdot
.784 .19389 Mdot
.784 .19689 Mdot
.784 .19906 Mdot
.784 .20006 Mdot
.784 .20087 Mdot
.784 .20136 Mdot
.784 .20225 Mdot
.784 .20298 Mdot
.784 .20357 Mdot
.784 .20401 Mdot
.784 .2041 Mdot
.784 .20438 Mdot
.784 .20534 Mdot
.784 .20598 Mdot
.784 .20735 Mdot
.784 .21172 Mdot
.784 .2135 Mdot
.784 .22469 Mdot
.784 .22509 Mdot
.784 .22601 Mdot
.784 .229 Mdot
.784 .22904 Mdot
.784 .23012 Mdot
.784 .23155 Mdot
.784 .23217 Mdot
.784 .23249 Mdot
.784 .23436 Mdot
.784 .23481 Mdot
.784 .23871 Mdot
.784 .24142 Mdot
.784 .242 Mdot
.784 .24211 Mdot
.784 .24214 Mdot
.784 .2423 Mdot
.784 .24744 Mdot
.784 .25073 Mdot
.784 .25142 Mdot
.784 .25378 Mdot
.784 .25433 Mdot
.784 .25473 Mdot
.784 .25559 Mdot
.784 .26769 Mdot
.784 .27303 Mdot
.784 .27313 Mdot
.784 .27351 Mdot
.784 .27858 Mdot
.784 .28189 Mdot
.784 .28402 Mdot
.784 .28721 Mdot
.784 .28859 Mdot
.784 .28966 Mdot
.784 .29009 Mdot
.784 .29057 Mdot
.784 .29069 Mdot
.784 .29148 Mdot
.784 .29175 Mdot
.784 .29236 Mdot
.784 .29255 Mdot
.784 .29267 Mdot
.784 .29324 Mdot
.784 .295 Mdot
.784 .29563 Mdot
.784 .29786 Mdot
.784 .2984 Mdot
.784 .29998 Mdot
.784 .30567 Mdot
.784 .30599 Mdot
.784 .30882 Mdot
.784 .30886 Mdot
.784 .30942 Mdot
.784 .30954 Mdot
.784 .31248 Mdot
.784 .31346 Mdot
.784 .3147 Mdot
.784 .3147 Mdot
.784 .31471 Mdot
.784 .31472 Mdot
.784 .31525 Mdot
.784 .31537 Mdot
.784 .31542 Mdot
.784 .31542 Mdot
.784 .31588 Mdot
.784 .31634 Mdot
.784 .31662 Mdot
.784 .31662 Mdot
.784 .31663 Mdot
.784 .31663 Mdot
.784 .317 Mdot
.784 .31709 Mdot
.784 .31713 Mdot
.784 .31713 Mdot
.784 .31749 Mdot
.784 .31788 Mdot
.784 .31813 Mdot
.784 .31813 Mdot
.784 .31813 Mdot
.784 .31814 Mdot
.784 .31821 Mdot
.784 .31848 Mdot
.784 .31857 Mdot
.784 .3186 Mdot
.784 .3186 Mdot
.784 .31895 Mdot
.784 .31935 Mdot
.784 .31953 Mdot
.784 .31961 Mdot
.784 .31961 Mdot
.784 .31962 Mdot
.784 .31962 Mdot
.784 .3197 Mdot
.784 .32 Mdot
.784 .32009 Mdot
.784 .32013 Mdot
.784 .32014 Mdot
.784 .32045 Mdot
.784 .32054 Mdot
.784 .32101 Mdot
.784 .32123 Mdot
.784 .32133 Mdot
.784 .32133 Mdot
.784 .32134 Mdot
.784 .32134 Mdot
.784 .32136 Mdot
.784 .32143 Mdot
.784 .32182 Mdot
.784 .32194 Mdot
.784 .32199 Mdot
.784 .32199 Mdot
.784 .32205 Mdot
.784 .3224 Mdot
.784 .32252 Mdot
.784 .32318 Mdot
.784 .32348 Mdot
.784 .32363 Mdot
.784 .32363 Mdot
.784 .32364 Mdot
.784 .32364 Mdot
.784 .32367 Mdot
.784 .32377 Mdot
.784 .32378 Mdot
.784 .32434 Mdot
.784 .32452 Mdot
.784 .3246 Mdot
.784 .32461 Mdot
.784 .32468 Mdot
.784 .32476 Mdot
.784 .32499 Mdot
.784 .32509 Mdot
.784 .32523 Mdot
.784 .32524 Mdot
.784 .32542 Mdot
.784 .32622 Mdot
.784 .32647 Mdot
.784 .32661 Mdot
.784 .32697 Mdot
.784 .32721 Mdot
.784 .32722 Mdot
.784 .32723 Mdot
.784 .32724 Mdot
.784 .32728 Mdot
.784 .32747 Mdot
.784 .32747 Mdot
.784 .32844 Mdot
.784 .32868 Mdot
.784 .32877 Mdot
.784 .3289 Mdot
.784 .32892 Mdot
.784 .32906 Mdot
.784 .3292 Mdot
.784 .32926 Mdot
.784 .32961 Mdot
.784 .3298 Mdot
.784 .32987 Mdot
.784 .33007 Mdot
.784 .33007 Mdot
.784 .33031 Mdot
.784 .33041 Mdot
.784 .33054 Mdot
.784 .33089 Mdot
.784 .33127 Mdot
.784 .33196 Mdot
.784 .33208 Mdot
.784 .33244 Mdot
.784 .33262 Mdot
.784 .33273 Mdot
.784 .33345 Mdot
.784 .3337 Mdot
.784 .33395 Mdot
.784 .33396 Mdot
.784 .33399 Mdot
.784 .33401 Mdot
.784 .3341 Mdot
.784 .33422 Mdot
.784 .33438 Mdot
.784 .33446 Mdot
.784 .33448 Mdot
.784 .33448 Mdot
.784 .3355 Mdot
.784 .33612 Mdot
.784 .33642 Mdot
.784 .33657 Mdot
.784 .3371 Mdot
.784 .33729 Mdot
.784 .33759 Mdot
.784 .33762 Mdot
.784 .33794 Mdot
.784 .33826 Mdot
.784 .3384 Mdot
.784 .33883 Mdot
.784 .33897 Mdot
.784 .33919 Mdot
.784 .33965 Mdot
.784 .3398 Mdot
.784 .33998 Mdot
.784 .34026 Mdot
.784 .34027 Mdot
.784 .34084 Mdot
.784 .34108 Mdot
.784 .34138 Mdot
.784 .34207 Mdot
.784 .34225 Mdot
.784 .3425 Mdot
.784 .34318 Mdot
.784 .3449 Mdot
.784 .3452 Mdot
.784 .34613 Mdot
.784 .34658 Mdot
.784 .34687 Mdot
.784 .34874 Mdot
.784 .34878 Mdot
.784 .34946 Mdot
.784 .35014 Mdot
.784 .35015 Mdot
.784 .35021 Mdot
.784 .35023 Mdot
.784 .35029 Mdot
.784 .3503 Mdot
.784 .35053 Mdot
.784 .35086 Mdot
.784 .35131 Mdot
.784 .35153 Mdot
.784 .35157 Mdot
.784 .35158 Mdot
.784 .35202 Mdot
.784 .35272 Mdot
.784 .35443 Mdot
.784 .35466 Mdot
.784 .35621 Mdot
.784 .35626 Mdot
.784 .3563 Mdot
.784 .35709 Mdot
.784 .35755 Mdot
.784 .35829 Mdot
.784 .35911 Mdot
.784 .35968 Mdot
.784 .36058 Mdot
.784 .36063 Mdot
.784 .36069 Mdot
.784 .36086 Mdot
.784 .36166 Mdot
.784 .36264 Mdot
.784 .36306 Mdot
.784 .36439 Mdot
.784 .36483 Mdot
.784 .36498 Mdot
.784 .36554 Mdot
.784 .36635 Mdot
.784 .36699 Mdot
.784 .36747 Mdot
.784 .36765 Mdot
.784 .36804 Mdot
.784 .36896 Mdot
.784 .36899 Mdot
.784 .37085 Mdot
.784 .37134 Mdot
.784 .37163 Mdot
.784 .37208 Mdot
.784 .37323 Mdot
.784 .37405 Mdot
.784 .37443 Mdot
.784 .37473 Mdot
.784 .37491 Mdot
.784 .37524 Mdot
.784 .37551 Mdot
.784 .37638 Mdot
.784 .37711 Mdot
.784 .37869 Mdot
.784 .38336 Mdot
.784 .38469 Mdot
.784 .3847 Mdot
.784 .38506 Mdot
.784 .38575 Mdot
.784 .38663 Mdot
.784 .3888 Mdot
.784 .38904 Mdot
.784 .38909 Mdot
.784 .39075 Mdot
.784 .3918 Mdot
.784 .39277 Mdot
.784 .39307 Mdot
.784 .39711 Mdot
.784 .39874 Mdot
.784 .39889 Mdot
.784 .40042 Mdot
.784 .40141 Mdot
.784 .40205 Mdot
.784 .40301 Mdot
.784 .40341 Mdot
.784 .40373 Mdot
.784 .40386 Mdot
.784 .404 Mdot
.784 .40404 Mdot
.784 .40427 Mdot
.784 .40435 Mdot
.784 .40459 Mdot
.784 .40462 Mdot
.784 .40479 Mdot
.784 .40531 Mdot
.784 .40549 Mdot
.784 .40615 Mdot
.784 .40677 Mdot
.784 .40843 Mdot
.784 .40852 Mdot
.784 .40934 Mdot
.784 .40936 Mdot
.784 .40952 Mdot
.784 .40955 Mdot
.784 .4104 Mdot
.784 .41125 Mdot
.784 .41152 Mdot
.784 .41399 Mdot
.784 .41539 Mdot
.784 .41648 Mdot
.784 .41825 Mdot
.784 .42073 Mdot
.784 .42165 Mdot
.784 .42185 Mdot
.784 .4224 Mdot
.784 .42285 Mdot
.784 .42342 Mdot
.784 .42408 Mdot
.784 .42709 Mdot
.784 .42762 Mdot
.784 .42785 Mdot
.784 .42804 Mdot
.784 .42818 Mdot
.784 .42871 Mdot
.784 .43139 Mdot
.784 .43312 Mdot
.784 .4332 Mdot
.784 .43602 Mdot
.784 .43622 Mdot
.784 .43626 Mdot
.784 .43667 Mdot
.784 .43756 Mdot
.784 .43812 Mdot
.784 .43955 Mdot
.784 .43986 Mdot
.784 .4414 Mdot
.784 .44156 Mdot
.784 .44186 Mdot
.784 .44292 Mdot
.784 .44552 Mdot
.784 .44571 Mdot
.784 .44598 Mdot
.784 .44665 Mdot
.784 .44716 Mdot
.784 .44882 Mdot
.784 .44991 Mdot
.784 .45081 Mdot
.784 .45309 Mdot
.784 .45382 Mdot
.784 .4539 Mdot
.784 .45472 Mdot
.784 .45563 Mdot
.784 .45593 Mdot
.784 .45639 Mdot
.784 .45661 Mdot
.784 .45673 Mdot
.784 .45823 Mdot
.784 .46049 Mdot
.784 .46104 Mdot
.784 .46131 Mdot
.784 .46282 Mdot
.784 .46315 Mdot
.784 .46343 Mdot
.784 .46366 Mdot
.784 .46393 Mdot
.784 .46571 Mdot
.784 .46658 Mdot
.784 .46711 Mdot
.784 .46898 Mdot
.784 .46951 Mdot
.784 .47001 Mdot
.784 .47045 Mdot
.784 .47154 Mdot
.784 .47193 Mdot
.784 .47262 Mdot
.784 .47268 Mdot
.784 .47283 Mdot
.784 .47302 Mdot
.784 .47346 Mdot
.784 .47423 Mdot
.784 .47576 Mdot
.784 .47761 Mdot
.784 .47775 Mdot
.784 .47944 Mdot
.784 .47955 Mdot
.784 .48052 Mdot
.784 .48474 Mdot
.784 .48556 Mdot
.784 .48578 Mdot
.784 .48591 Mdot
.784 .48608 Mdot
.784 .48643 Mdot
.784 .48693 Mdot
.784 .48725 Mdot
.784 .48883 Mdot
.784 .48997 Mdot
.784 .49171 Mdot
.784 .49181 Mdot
.784 .49279 Mdot
.784 .49364 Mdot
.784 .4943 Mdot
.784 .49511 Mdot
.784 .4954 Mdot
.784 .49614 Mdot
.784 .49674 Mdot
.784 .49928 Mdot
.784 .5003 Mdot
.784 .50071 Mdot
.784 .50185 Mdot
.784 .50254 Mdot
.784 .50281 Mdot
.784 .50377 Mdot
.784 .50432 Mdot
.784 .50479 Mdot
.784 .5056 Mdot
.784 .50619 Mdot
.784 .50624 Mdot
.784 .50632 Mdot
.784 .50671 Mdot
.784 .508 Mdot
.784 .50886 Mdot
.784 .50958 Mdot
.784 .50993 Mdot
.784 .51068 Mdot
.784 .51105 Mdot
.784 .51217 Mdot
.784 .51221 Mdot
.784 .51243 Mdot
.784 .51244 Mdot
.784 .51351 Mdot
.784 .51363 Mdot
.784 .51576 Mdot
.784 .51634 Mdot
.784 .51654 Mdot
.784 .51737 Mdot
.784 .5176 Mdot
.784 .51825 Mdot
.784 .51846 Mdot
.784 .5185 Mdot
.784 .51857 Mdot
.784 .5188 Mdot
.784 .5189 Mdot
.784 .51918 Mdot
.784 .51923 Mdot
.784 .5194 Mdot
.784 .51956 Mdot
.784 .51995 Mdot
.784 .52045 Mdot
.784 .52161 Mdot
.784 .52238 Mdot
.784 .52357 Mdot
.784 .52538 Mdot
.784 .52551 Mdot
.784 .52555 Mdot
.784 .52744 Mdot
.784 .53166 Mdot
.784 .53195 Mdot
.784 .53209 Mdot
.784 .53228 Mdot
.784 .53309 Mdot
.784 .53333 Mdot
.784 .53445 Mdot
.784 .5362 Mdot
.784 .53625 Mdot
.784 .53627 Mdot
.784 .5363 Mdot
.784 .5365 Mdot
.784 .53741 Mdot
.784 .53872 Mdot
.784 .53887 Mdot
.784 .5395 Mdot
.784 .5396 Mdot
.784 .53981 Mdot
.784 .54029 Mdot
.784 .54065 Mdot
.784 .54066 Mdot
.784 .54165 Mdot
.784 .54195 Mdot
.784 .54208 Mdot
.784 .54575 Mdot
.784 .54632 Mdot
.784 .54774 Mdot
.784 .54818 Mdot
.784 .54838 Mdot
.784 .54869 Mdot
.784 .54878 Mdot
.784 .54881 Mdot
.784 .54895 Mdot
.784 .54914 Mdot
.784 .54938 Mdot
.784 .54966 Mdot
.784 .54981 Mdot
.784 .55007 Mdot
.784 .55039 Mdot
.784 .55108 Mdot
.784 .55203 Mdot
.784 .5524 Mdot
.784 .55264 Mdot
.784 .55303 Mdot
.784 .55324 Mdot
.784 .55451 Mdot
.784 .55453 Mdot
.784 .55524 Mdot
.784 .55553 Mdot
.784 .55568 Mdot
.784 .5558 Mdot
.784 .55604 Mdot
.784 .55633 Mdot
.784 .55652 Mdot
.784 .55712 Mdot
.784 .55753 Mdot
.784 .55764 Mdot
.784 .55795 Mdot
.784 .55805 Mdot
.784 .55845 Mdot
.784 .55873 Mdot
.784 .5589 Mdot
.784 .5592 Mdot
.784 .55933 Mdot
.784 .55987 Mdot
.784 .56042 Mdot
.784 .56053 Mdot
.784 .56057 Mdot
.784 .5606 Mdot
.784 .5612 Mdot
.784 .56157 Mdot
.784 .5621 Mdot
.784 .56258 Mdot
.784 .56286 Mdot
.784 .56336 Mdot
.784 .56338 Mdot
.784 .56341 Mdot
.784 .56434 Mdot
.784 .56448 Mdot
.784 .56547 Mdot
.784 .56587 Mdot
.784 .56611 Mdot
.784 .56612 Mdot
.784 .56614 Mdot
.784 .56626 Mdot
.784 .56651 Mdot
.784 .56669 Mdot
.784 .56679 Mdot
.784 .56681 Mdot
.784 .56682 Mdot
.784 .56685 Mdot
.784 .56686 Mdot
.784 .56689 Mdot
.784 .5669 Mdot
.784 .56726 Mdot
.784 .56761 Mdot
.784 .56763 Mdot
.784 .56857 Mdot
.784 .56871 Mdot
.784 .56894 Mdot
.784 .56938 Mdot
.784 .56947 Mdot
.784 .56952 Mdot
.784 .56952 Mdot
.784 .5697 Mdot
.784 .5703 Mdot
.784 .5706 Mdot
.784 .57071 Mdot
.784 .57079 Mdot
.784 .57121 Mdot
.784 .57131 Mdot
.784 .57154 Mdot
.784 .57154 Mdot
.784 .57166 Mdot
.784 .57173 Mdot
.784 .57179 Mdot
.784 .57187 Mdot
.784 .57197 Mdot
.784 .57206 Mdot
.784 .57211 Mdot
.784 .57228 Mdot
.784 .57233 Mdot
.784 .57245 Mdot
.784 .57257 Mdot
.784 .57258 Mdot
.784 .57269 Mdot
.784 .57276 Mdot
.784 .57296 Mdot
.784 .57301 Mdot
.784 .57311 Mdot
.784 .57312 Mdot
.784 .57333 Mdot
.784 .57368 Mdot
.784 .57368 Mdot
.784 .57368 Mdot
.784 .57371 Mdot
.784 .57376 Mdot
.784 .5738 Mdot
.784 .57383 Mdot
.784 .57383 Mdot
.784 .57384 Mdot
.784 .57385 Mdot
.784 .57385 Mdot
.784 .57393 Mdot
.784 .57401 Mdot
.784 .57424 Mdot
.784 .57427 Mdot
.784 .57432 Mdot
.784 .57443 Mdot
.784 .57447 Mdot
.784 .57467 Mdot
.784 .57478 Mdot
.784 .5748 Mdot
.784 .57488 Mdot
.784 .57492 Mdot
.784 .57494 Mdot
.784 .57501 Mdot
.784 .57501 Mdot
.784 .57506 Mdot
.784 .57508 Mdot
.784 .57514 Mdot
.784 .57518 Mdot
.784 .57523 Mdot
.784 .57524 Mdot
.784 .57528 Mdot
.784 .57532 Mdot
.784 .57532 Mdot
.784 .57536 Mdot
.784 .57538 Mdot
.784 .57544 Mdot
.784 .57546 Mdot
.784 .57556 Mdot
.784 .57568 Mdot
.784 .57568 Mdot
.784 .57568 Mdot
.784 .57571 Mdot
.784 .57572 Mdot
.784 .57573 Mdot
.784 .57573 Mdot
.784 .57574 Mdot
.784 .57574 Mdot
.784 .5758 Mdot
.784 .57588 Mdot
.784 .57589 Mdot
.784 .57591 Mdot
.784 .57595 Mdot
.784 .57597 Mdot
.784 .57609 Mdot
.784 .57613 Mdot
.784 .57614 Mdot
.784 .57615 Mdot
.784 .57618 Mdot
.784 .57618 Mdot
.784 .57621 Mdot
.784 .57623 Mdot
.784 .57627 Mdot
.784 .57628 Mdot
.784 .5763 Mdot
.784 .57631 Mdot
.784 .57631 Mdot
.784 .57633 Mdot
.784 .57637 Mdot
.784 .57648 Mdot
.784 .57648 Mdot
.784 .5765 Mdot
.784 .5765 Mdot
.784 .5765 Mdot
.784 .5765 Mdot
.784 .5765 Mdot
.784 .57653 Mdot
.784 .57659 Mdot
.784 .57661 Mdot
.784 .57671 Mdot
.784 .57673 Mdot
.784 .57673 Mdot
.784 .57679 Mdot
.784 .5768 Mdot
.784 .5768 Mdot
.784 .57681 Mdot
.784 .57683 Mdot
.784 .57689 Mdot
.784 .5769 Mdot
.784 .5769 Mdot
.784 .5769 Mdot
.784 .57691 Mdot
.784 .57691 Mdot
.784 .57692 Mdot
.784 .57696 Mdot
.784 .57703 Mdot
.784 .57704 Mdot
.784 .57708 Mdot
.784 .57709 Mdot
.784 .57709 Mdot
.784 .57709 Mdot
.784 .57711 Mdot
.784 .57715 Mdot
.784 .57716 Mdot
.784 .57716 Mdot
.784 .57716 Mdot
.784 .57716 Mdot
.784 .57716 Mdot
.784 .57717 Mdot
.784 .5772 Mdot
.784 .57725 Mdot
.784 .57729 Mdot
.784 .57729 Mdot
.784 .5773 Mdot
.784 .57731 Mdot
.784 .57734 Mdot
.784 .57735 Mdot
.784 .57735 Mdot
.784 .57735 Mdot
.784 .57735 Mdot
.784 .57736 Mdot
.784 .57738 Mdot
.784 .57742 Mdot
.784 .57746 Mdot
.784 .57746 Mdot
.784 .57747 Mdot
.784 .57748 Mdot
.784 .57751 Mdot
.784 .57751 Mdot
.784 .57752 Mdot
.784 .57752 Mdot
.784 .57754 Mdot
.784 .57759 Mdot
.784 .57762 Mdot
.784 .57763 Mdot
.784 .57763 Mdot
.784 .57764 Mdot
.784 .57768 Mdot
.784 .57768 Mdot
.784 .57768 Mdot
.784 .57768 Mdot
.784 .57776 Mdot
.784 .57781 Mdot
.784 .57782 Mdot
.784 .57783 Mdot
.784 .57789 Mdot
.784 .57789 Mdot
.784 .57789 Mdot
.784 .57789 Mdot
.786 .10777 Mdot
.786 .31469 Mdot
.786 .57792 Mdot
.788 .10635 Mdot
.788 .31108 Mdot
.788 .57833 Mdot
.79 .10547 Mdot
.79 .30886 Mdot
.79 .5786 Mdot
.792 .10476 Mdot
.792 .30711 Mdot
.792 .57881 Mdot
.794 .10415 Mdot
.794 .30561 Mdot
.794 .57899 Mdot
.796 .10361 Mdot
.796 .30428 Mdot
.796 .57916 Mdot
.798 .10311 Mdot
.798 .30307 Mdot
.798 .57931 Mdot
.8 .10266 Mdot
.8 .30196 Mdot
.8 .57945 Mdot
.802 .10171 Mdot
.802 .10279 Mdot
.802 .29952 Mdot
.802 .30243 Mdot
.802 .57942 Mdot
.802 .57973 Mdot
.804 .10001 Mdot
.804 .10443 Mdot
.804 .29502 Mdot
.804 .30696 Mdot
.804 .57897 Mdot
.804 .58022 Mdot
.806 .09912 Mdot
.806 .10527 Mdot
.806 .29269 Mdot
.806 .30931 Mdot
.806 .57874 Mdot
.806 .58048 Mdot
.808 .09842 Mdot
.808 .10591 Mdot
.808 .29089 Mdot
.808 .31114 Mdot
.808 .57857 Mdot
.808 .58069 Mdot
.81 .09753 Mdot
.81 .09825 Mdot
.81 .10541 Mdot
.81 .10719 Mdot
.81 .28855 Mdot
.81 .29055 Mdot
.81 .30993 Mdot
.81 .31467 Mdot
.81 .57822 Mdot
.81 .57872 Mdot
.81 .58074 Mdot
.81 .58095 Mdot
.812 .09671 Mdot
.812 .09671 Mdot
.812 .09671 Mdot
.812 .09671 Mdot
.812 .09671 Mdot
.812 .09671 Mdot
.812 .09672 Mdot
.812 .09672 Mdot
.812 .09672 Mdot
.812 .09672 Mdot
.812 .09672 Mdot
.812 .09673 Mdot
.812 .09673 Mdot
.812 .09673 Mdot
.812 .09673 Mdot
.812 .09673 Mdot
.812 .09673 Mdot
.812 .09674 Mdot
.812 .09675 Mdot
.812 .09675 Mdot
.812 .09676 Mdot
.812 .09676 Mdot
.812 .09676 Mdot
.812 .09677 Mdot
.812 .09677 Mdot
.812 .09678 Mdot
.812 .09678 Mdot
.812 .09679 Mdot
.812 .09679 Mdot
.812 .09679 Mdot
.812 .0968 Mdot
.812 .0968 Mdot
.812 .0968 Mdot
.812 .09681 Mdot
.812 .09681 Mdot
.812 .09682 Mdot
.812 .09682 Mdot
.812 .09682 Mdot
.812 .09682 Mdot
.812 .09683 Mdot
.812 .09683 Mdot
.812 .09683 Mdot
.812 .09684 Mdot
.812 .09685 Mdot
.812 .09685 Mdot
.812 .09685 Mdot
.812 .09686 Mdot
.812 .09687 Mdot
.812 .09687 Mdot
.812 .09688 Mdot
.812 .09688 Mdot
.812 .09689 Mdot
.812 .09689 Mdot
.812 .09689 Mdot
.812 .0969 Mdot
.812 .0969 Mdot
.812 .09691 Mdot
.812 .09691 Mdot
.812 .09691 Mdot
.812 .09693 Mdot
.812 .09693 Mdot
.812 .09696 Mdot
.812 .09697 Mdot
.812 .09697 Mdot
.812 .097 Mdot
.812 .09701 Mdot
.812 .09704 Mdot
.812 .09704 Mdot
.812 .09705 Mdot
.812 .09706 Mdot
.812 .09706 Mdot
.812 .09706 Mdot
.812 .09707 Mdot
.812 .09708 Mdot
.812 .09709 Mdot
.812 .09709 Mdot
.812 .0971 Mdot
.812 .0971 Mdot
.812 .09711 Mdot
.812 .09712 Mdot
.812 .09713 Mdot
.812 .09713 Mdot
.812 .09713 Mdot
.812 .09714 Mdot
.812 .0976 Mdot
.812 .0976 Mdot
.812 .09761 Mdot
.812 .09762 Mdot
.812 .09763 Mdot
.812 .09765 Mdot
.812 .09767 Mdot
.812 .09768 Mdot
.812 .0977 Mdot
.812 .0977 Mdot
.812 .09771 Mdot
.812 .09775 Mdot
.812 .09776 Mdot
.812 .09776 Mdot
.812 .09777 Mdot
.812 .09778 Mdot
.812 .09781 Mdot
.812 .09782 Mdot
.812 .09789 Mdot
.812 .0979 Mdot
.812 .09797 Mdot
.812 .09798 Mdot
.812 .09802 Mdot
.812 .09808 Mdot
.812 .09808 Mdot
.812 .09813 Mdot
.812 .09814 Mdot
.812 .09815 Mdot
.812 .09816 Mdot
.812 .09816 Mdot
.812 .09818 Mdot
.812 .09819 Mdot
.812 .09819 Mdot
.812 .09821 Mdot
.812 .09822 Mdot
.812 .09824 Mdot
.812 .09824 Mdot
.812 .09827 Mdot
.812 .0983 Mdot
.812 .0983 Mdot
.812 .09834 Mdot
.812 .09835 Mdot
.812 .09837 Mdot
.812 .09837 Mdot
.812 .09838 Mdot
.812 .09839 Mdot
.812 .0984 Mdot
.812 .09841 Mdot
.812 .09841 Mdot
.812 .09843 Mdot
.812 .09844 Mdot
.812 .09847 Mdot
.812 .09847 Mdot
.812 .09848 Mdot
.812 .09849 Mdot
.812 .09849 Mdot
.812 .0985 Mdot
.812 .09852 Mdot
.812 .09854 Mdot
.812 .09854 Mdot
.812 .09857 Mdot
.812 .09858 Mdot
.812 .09859 Mdot
.812 .09862 Mdot
.812 .09862 Mdot
.812 .09865 Mdot
.812 .09866 Mdot
.812 .09867 Mdot
.812 .09867 Mdot
.812 .09868 Mdot
.812 .09868 Mdot
.812 .09868 Mdot
.812 .09869 Mdot
.812 .0987 Mdot
.812 .0987 Mdot
.812 .09871 Mdot
.812 .09871 Mdot
.812 .09872 Mdot
.812 .09873 Mdot
.812 .09873 Mdot
.812 .09874 Mdot
.812 .09874 Mdot
.812 .09874 Mdot
.812 .10342 Mdot
.812 .10342 Mdot
.812 .10342 Mdot
.812 .10344 Mdot
.812 .10344 Mdot
.812 .10346 Mdot
.812 .10348 Mdot
.812 .10349 Mdot
.812 .10351 Mdot
.812 .10351 Mdot
.812 .10352 Mdot
.812 .10355 Mdot
.812 .10356 Mdot
.812 .10356 Mdot
.812 .10357 Mdot
.812 .10358 Mdot
.812 .1036 Mdot
.812 .10361 Mdot
.812 .10368 Mdot
.812 .10368 Mdot
.812 .10376 Mdot
.812 .10377 Mdot
.812 .1038 Mdot
.812 .10386 Mdot
.812 .10386 Mdot
.812 .10391 Mdot
.812 .10394 Mdot
.812 .10396 Mdot
.812 .10397 Mdot
.812 .10399 Mdot
.812 .10402 Mdot
.812 .10403 Mdot
.812 .10409 Mdot
.812 .1041 Mdot
.812 .10414 Mdot
.812 .10416 Mdot
.812 .10417 Mdot
.812 .10421 Mdot
.812 .10422 Mdot
.812 .10425 Mdot
.812 .10425 Mdot
.812 .10429 Mdot
.812 .10431 Mdot
.812 .1044 Mdot
.812 .1044 Mdot
.812 .10448 Mdot
.812 .10454 Mdot
.812 .10454 Mdot
.812 .10461 Mdot
.812 .10461 Mdot
.812 .10465 Mdot
.812 .10466 Mdot
.812 .10468 Mdot
.812 .10471 Mdot
.812 .10473 Mdot
.812 .10473 Mdot
.812 .10476 Mdot
.812 .10478 Mdot
.812 .10481 Mdot
.812 .10492 Mdot
.812 .10493 Mdot
.812 .10508 Mdot
.812 .10516 Mdot
.812 .10518 Mdot
.812 .10537 Mdot
.812 .10539 Mdot
.812 .10557 Mdot
.812 .10559 Mdot
.812 .10567 Mdot
.812 .10569 Mdot
.812 .10571 Mdot
.812 .10571 Mdot
.812 .10575 Mdot
.812 .10583 Mdot
.812 .10585 Mdot
.812 .10586 Mdot
.812 .10591 Mdot
.812 .10595 Mdot
.812 .10599 Mdot
.812 .10605 Mdot
.812 .10607 Mdot
.812 .1061 Mdot
.812 .10611 Mdot
.812 .10612 Mdot
.812 .10735 Mdot
.812 .10736 Mdot
.812 .10736 Mdot
.812 .10738 Mdot
.812 .10739 Mdot
.812 .10742 Mdot
.812 .10744 Mdot
.812 .10746 Mdot
.812 .10748 Mdot
.812 .10749 Mdot
.812 .1075 Mdot
.812 .10754 Mdot
.812 .10755 Mdot
.812 .10756 Mdot
.812 .10756 Mdot
.812 .10757 Mdot
.812 .10761 Mdot
.812 .10762 Mdot
.812 .10771 Mdot
.812 .10771 Mdot
.812 .1078 Mdot
.812 .10781 Mdot
.812 .10785 Mdot
.812 .10791 Mdot
.812 .10792 Mdot
.812 .10797 Mdot
.812 .10798 Mdot
.812 .10799 Mdot
.812 .108 Mdot
.812 .10801 Mdot
.812 .10803 Mdot
.812 .10803 Mdot
.812 .10804 Mdot
.812 .10805 Mdot
.812 .10806 Mdot
.812 .10809 Mdot
.812 .10809 Mdot
.812 .10811 Mdot
.812 .10815 Mdot
.812 .10815 Mdot
.812 .10818 Mdot
.812 .10819 Mdot
.812 .10821 Mdot
.812 .10821 Mdot
.812 .10822 Mdot
.812 .10823 Mdot
.812 .10824 Mdot
.812 .10825 Mdot
.812 .10825 Mdot
.812 .10827 Mdot
.812 .10828 Mdot
.812 .1083 Mdot
.812 .1083 Mdot
.812 .10832 Mdot
.812 .10833 Mdot
.812 .10833 Mdot
.812 .10834 Mdot
.812 .10835 Mdot
.812 .10837 Mdot
.812 .10837 Mdot
.812 .1084 Mdot
.812 .10841 Mdot
.812 .10841 Mdot
.812 .10844 Mdot
.812 .10845 Mdot
.812 .10847 Mdot
.812 .10848 Mdot
.812 .10849 Mdot
.812 .10849 Mdot
.812 .10849 Mdot
.812 .1085 Mdot
.812 .1085 Mdot
.812 .10851 Mdot
.812 .10852 Mdot
.812 .10852 Mdot
.812 .10852 Mdot
.812 .10853 Mdot
.812 .10853 Mdot
.812 .10854 Mdot
.812 .10855 Mdot
.812 .10855 Mdot
.812 .10855 Mdot
.812 .10855 Mdot
.812 .28639 Mdot
.812 .28639 Mdot
.812 .28639 Mdot
.812 .2864 Mdot
.812 .2864 Mdot
.812 .28641 Mdot
.812 .28641 Mdot
.812 .28642 Mdot
.812 .28643 Mdot
.812 .28643 Mdot
.812 .28643 Mdot
.812 .28644 Mdot
.812 .28645 Mdot
.812 .28645 Mdot
.812 .28645 Mdot
.812 .28645 Mdot
.812 .28646 Mdot
.812 .28647 Mdot
.812 .28649 Mdot
.812 .2865 Mdot
.812 .28652 Mdot
.812 .28653 Mdot
.812 .28654 Mdot
.812 .28656 Mdot
.812 .28657 Mdot
.812 .28658 Mdot
.812 .2866 Mdot
.812 .28661 Mdot
.812 .28661 Mdot
.812 .28662 Mdot
.812 .28663 Mdot
.812 .28663 Mdot
.812 .28666 Mdot
.812 .28666 Mdot
.812 .28668 Mdot
.812 .28669 Mdot
.812 .28669 Mdot
.812 .28671 Mdot
.812 .28671 Mdot
.812 .28672 Mdot
.812 .28673 Mdot
.812 .28674 Mdot
.812 .28675 Mdot
.812 .28677 Mdot
.812 .28678 Mdot
.812 .28679 Mdot
.812 .28682 Mdot
.812 .28684 Mdot
.812 .28685 Mdot
.812 .28687 Mdot
.812 .28688 Mdot
.812 .28689 Mdot
.812 .2869 Mdot
.812 .2869 Mdot
.812 .28692 Mdot
.812 .28693 Mdot
.812 .28694 Mdot
.812 .28695 Mdot
.812 .28696 Mdot
.812 .28701 Mdot
.812 .28701 Mdot
.812 .28708 Mdot
.812 .28711 Mdot
.812 .28712 Mdot
.812 .28721 Mdot
.812 .28722 Mdot
.812 .2873 Mdot
.812 .28731 Mdot
.812 .28735 Mdot
.812 .28736 Mdot
.812 .28737 Mdot
.812 .28737 Mdot
.812 .28739 Mdot
.812 .28743 Mdot
.812 .28744 Mdot
.812 .28744 Mdot
.812 .28747 Mdot
.812 .28749 Mdot
.812 .28751 Mdot
.812 .28754 Mdot
.812 .28755 Mdot
.812 .28757 Mdot
.812 .28757 Mdot
.812 .28758 Mdot
.812 .28886 Mdot
.812 .28887 Mdot
.812 .28888 Mdot
.812 .28891 Mdot
.812 .28894 Mdot
.812 .28901 Mdot
.812 .28905 Mdot
.812 .28909 Mdot
.812 .28914 Mdot
.812 .28915 Mdot
.812 .28918 Mdot
.812 .28927 Mdot
.812 .2893 Mdot
.812 .28931 Mdot
.812 .28932 Mdot
.812 .28935 Mdot
.812 .28944 Mdot
.812 .28946 Mdot
.812 .28966 Mdot
.812 .28968 Mdot
.812 .2899 Mdot
.812 .28992 Mdot
.812 .29001 Mdot
.812 .29018 Mdot
.812 .2902 Mdot
.812 .29033 Mdot
.812 .29036 Mdot
.812 .29038 Mdot
.812 .29041 Mdot
.812 .29042 Mdot
.812 .29048 Mdot
.812 .2905 Mdot
.812 .2905 Mdot
.812 .29055 Mdot
.812 .29056 Mdot
.812 .29064 Mdot
.812 .29064 Mdot
.812 .29071 Mdot
.812 .2908 Mdot
.812 .29081 Mdot
.812 .29091 Mdot
.812 .29093 Mdot
.812 .29098 Mdot
.812 .29099 Mdot
.812 .29101 Mdot
.812 .29103 Mdot
.812 .29108 Mdot
.812 .29109 Mdot
.812 .29111 Mdot
.812 .29116 Mdot
.812 .29118 Mdot
.812 .29125 Mdot
.812 .29126 Mdot
.812 .2913 Mdot
.812 .29132 Mdot
.812 .29133 Mdot
.812 .29136 Mdot
.812 .2914 Mdot
.812 .29145 Mdot
.812 .29146 Mdot
.812 .29153 Mdot
.812 .29157 Mdot
.812 .29158 Mdot
.812 .29167 Mdot
.812 .29168 Mdot
.812 .29176 Mdot
.812 .29177 Mdot
.812 .29181 Mdot
.812 .29182 Mdot
.812 .29183 Mdot
.812 .29183 Mdot
.812 .29184 Mdot
.812 .29188 Mdot
.812 .29189 Mdot
.812 .29189 Mdot
.812 .29192 Mdot
.812 .29193 Mdot
.812 .29195 Mdot
.812 .29198 Mdot
.812 .29199 Mdot
.812 .292 Mdot
.812 .29201 Mdot
.812 .29201 Mdot
.812 .30473 Mdot
.812 .30474 Mdot
.812 .30475 Mdot
.812 .30478 Mdot
.812 .3048 Mdot
.812 .30485 Mdot
.812 .30489 Mdot
.812 .30493 Mdot
.812 .30497 Mdot
.812 .30498 Mdot
.812 .30501 Mdot
.812 .30508 Mdot
.812 .30511 Mdot
.812 .30512 Mdot
.812 .30513 Mdot
.812 .30515 Mdot
.812 .30523 Mdot
.812 .30525 Mdot
.812 .30543 Mdot
.812 .30545 Mdot
.812 .30564 Mdot
.812 .30567 Mdot
.812 .30575 Mdot
.812 .30591 Mdot
.812 .30593 Mdot
.812 .30605 Mdot
.812 .30614 Mdot
.812 .3062 Mdot
.812 .30622 Mdot
.812 .30627 Mdot
.812 .30636 Mdot
.812 .30637 Mdot
.812 .30653 Mdot
.812 .30657 Mdot
.812 .30668 Mdot
.812 .30673 Mdot
.812 .30674 Mdot
.812 .30686 Mdot
.812 .30689 Mdot
.812 .30695 Mdot
.812 .30697 Mdot
.812 .30708 Mdot
.812 .30713 Mdot
.812 .30736 Mdot
.812 .30737 Mdot
.812 .30757 Mdot
.812 .30773 Mdot
.812 .30774 Mdot
.812 .30791 Mdot
.812 .30794 Mdot
.812 .30804 Mdot
.812 .30806 Mdot
.812 .30811 Mdot
.812 .30821 Mdot
.812 .30824 Mdot
.812 .30825 Mdot
.812 .30832 Mdot
.812 .30838 Mdot
.812 .30845 Mdot
.812 .30874 Mdot
.812 .30879 Mdot
.812 .30918 Mdot
.812 .30939 Mdot
.812 .30945 Mdot
.812 .30996 Mdot
.812 .31001 Mdot
.812 .31049 Mdot
.812 .31055 Mdot
.812 .31076 Mdot
.812 .31082 Mdot
.812 .31086 Mdot
.812 .31087 Mdot
.812 .31096 Mdot
.812 .31117 Mdot
.812 .31124 Mdot
.812 .31126 Mdot
.812 .31138 Mdot
.812 .31149 Mdot
.812 .31159 Mdot
.812 .31175 Mdot
.812 .31182 Mdot
.812 .3119 Mdot
.812 .31193 Mdot
.812 .31196 Mdot
.812 .3152 Mdot
.812 .31522 Mdot
.812 .31523 Mdot
.812 .31527 Mdot
.812 .31531 Mdot
.812 .31539 Mdot
.812 .31544 Mdot
.812 .31549 Mdot
.812 .31555 Mdot
.812 .31556 Mdot
.812 .31559 Mdot
.812 .3157 Mdot
.812 .31574 Mdot
.812 .31575 Mdot
.812 .31576 Mdot
.812 .31579 Mdot
.812 .31589 Mdot
.812 .31592 Mdot
.812 .31614 Mdot
.812 .31616 Mdot
.812 .31639 Mdot
.812 .31642 Mdot
.812 .31652 Mdot
.812 .31669 Mdot
.812 .31671 Mdot
.812 .31684 Mdot
.812 .31687 Mdot
.812 .31689 Mdot
.812 .31692 Mdot
.812 .31693 Mdot
.812 .31698 Mdot
.812 .317 Mdot
.812 .31701 Mdot
.812 .31706 Mdot
.812 .31707 Mdot
.812 .31714 Mdot
.812 .31715 Mdot
.812 .31721 Mdot
.812 .3173 Mdot
.812 .3173 Mdot
.812 .3174 Mdot
.812 .31742 Mdot
.812 .31746 Mdot
.812 .31747 Mdot
.812 .3175 Mdot
.812 .31751 Mdot
.812 .31756 Mdot
.812 .31756 Mdot
.812 .31758 Mdot
.812 .31763 Mdot
.812 .31764 Mdot
.812 .31771 Mdot
.812 .31771 Mdot
.812 .31775 Mdot
.812 .31777 Mdot
.812 .31778 Mdot
.812 .3178 Mdot
.812 .31784 Mdot
.812 .31789 Mdot
.812 .3179 Mdot
.812 .31796 Mdot
.812 .31799 Mdot
.812 .318 Mdot
.812 .31808 Mdot
.812 .31809 Mdot
.812 .31816 Mdot
.812 .31817 Mdot
.812 .3182 Mdot
.812 .31821 Mdot
.812 .31821 Mdot
.812 .31822 Mdot
.812 .31823 Mdot
.812 .31826 Mdot
.812 .31827 Mdot
.812 .31827 Mdot
.812 .31829 Mdot
.812 .3183 Mdot
.812 .31832 Mdot
.812 .31834 Mdot
.812 .31835 Mdot
.812 .31836 Mdot
.812 .31837 Mdot
.812 .31837 Mdot
.812 .57784 Mdot
.812 .57784 Mdot
.812 .57784 Mdot
.812 .57784 Mdot
.812 .57784 Mdot
.812 .57785 Mdot
.812 .57785 Mdot
.812 .57785 Mdot
.812 .57785 Mdot
.812 .57785 Mdot
.812 .57785 Mdot
.812 .57785 Mdot
.812 .57786 Mdot
.812 .57786 Mdot
.812 .57786 Mdot
.812 .57786 Mdot
.812 .57786 Mdot
.812 .57786 Mdot
.812 .57787 Mdot
.812 .57787 Mdot
.812 .57788 Mdot
.812 .57788 Mdot
.812 .57788 Mdot
.812 .57789 Mdot
.812 .57789 Mdot
.812 .5779 Mdot
.812 .5779 Mdot
.812 .5779 Mdot
.812 .5779 Mdot
.812 .57791 Mdot
.812 .57791 Mdot
.812 .57791 Mdot
.812 .57792 Mdot
.812 .57792 Mdot
.812 .57792 Mdot
.812 .57793 Mdot
.812 .57793 Mdot
.812 .57793 Mdot
.812 .57793 Mdot
.812 .57794 Mdot
.812 .57794 Mdot
.812 .57794 Mdot
.812 .57795 Mdot
.812 .57796 Mdot
.812 .57796 Mdot
.812 .57796 Mdot
.812 .57797 Mdot
.812 .57797 Mdot
.812 .57798 Mdot
.812 .57798 Mdot
.812 .57799 Mdot
.812 .57799 Mdot
.812 .57799 Mdot
.812 .578 Mdot
.812 .578 Mdot
.812 .578 Mdot
.812 .578 Mdot
.812 .57801 Mdot
.812 .57802 Mdot
.812 .57802 Mdot
.812 .57804 Mdot
.812 .57805 Mdot
.812 .57805 Mdot
.812 .57808 Mdot
.812 .57808 Mdot
.812 .5781 Mdot
.812 .57811 Mdot
.812 .57812 Mdot
.812 .57812 Mdot
.812 .57812 Mdot
.812 .57812 Mdot
.812 .57813 Mdot
.812 .57814 Mdot
.812 .57814 Mdot
.812 .57814 Mdot
.812 .57815 Mdot
.812 .57816 Mdot
.812 .57816 Mdot
.812 .57817 Mdot
.812 .57817 Mdot
.812 .57818 Mdot
.812 .57818 Mdot
.812 .57818 Mdot
.812 .57853 Mdot
.812 .57853 Mdot
.812 .57854 Mdot
.812 .57854 Mdot
.812 .57855 Mdot
.812 .57857 Mdot
.812 .57858 Mdot
.812 .57859 Mdot
.812 .5786 Mdot
.812 .57861 Mdot
.812 .57861 Mdot
.812 .57864 Mdot
.812 .57865 Mdot
.812 .57865 Mdot
.812 .57865 Mdot
.812 .57866 Mdot
.812 .57868 Mdot
.812 .57869 Mdot
.812 .57874 Mdot
.812 .57874 Mdot
.812 .5788 Mdot
.812 .5788 Mdot
.812 .57883 Mdot
.812 .57887 Mdot
.812 .57887 Mdot
.812 .5789 Mdot
.812 .57891 Mdot
.812 .57892 Mdot
.812 .57892 Mdot
.812 .57893 Mdot
.812 .57894 Mdot
.812 .57894 Mdot
.812 .57895 Mdot
.812 .57896 Mdot
.812 .57896 Mdot
.812 .57898 Mdot
.812 .57898 Mdot
.812 .579 Mdot
.812 .57902 Mdot
.812 .57902 Mdot
.812 .57904 Mdot
.812 .57905 Mdot
.812 .57906 Mdot
.812 .57906 Mdot
.812 .57907 Mdot
.812 .57907 Mdot
.812 .57908 Mdot
.812 .57909 Mdot
.812 .57909 Mdot
.812 .5791 Mdot
.812 .57911 Mdot
.812 .57912 Mdot
.812 .57912 Mdot
.812 .57913 Mdot
.812 .57914 Mdot
.812 .57914 Mdot
.812 .57915 Mdot
.812 .57916 Mdot
.812 .57917 Mdot
.812 .57917 Mdot
.812 .57919 Mdot
.812 .5792 Mdot
.812 .5792 Mdot
.812 .57922 Mdot
.812 .57922 Mdot
.812 .57924 Mdot
.812 .57924 Mdot
.812 .57925 Mdot
.812 .57925 Mdot
.812 .57926 Mdot
.812 .57926 Mdot
.812 .57926 Mdot
.812 .57927 Mdot
.812 .57927 Mdot
.812 .57927 Mdot
.812 .57928 Mdot
.812 .57928 Mdot
.812 .57928 Mdot
.812 .57929 Mdot
.812 .57929 Mdot
.812 .57929 Mdot
.812 .5793 Mdot
.812 .5793 Mdot
.812 .58062 Mdot
.812 .58062 Mdot
.812 .58062 Mdot
.812 .58062 Mdot
.812 .58062 Mdot
.812 .58062 Mdot
.812 .58062 Mdot
.812 .58063 Mdot
.812 .58063 Mdot
.812 .58063 Mdot
.812 .58063 Mdot
.812 .58063 Mdot
.812 .58063 Mdot
.812 .58063 Mdot
.812 .58064 Mdot
.812 .58064 Mdot
.812 .58064 Mdot
.812 .58064 Mdot
.812 .58065 Mdot
.812 .58065 Mdot
.812 .58066 Mdot
.812 .58066 Mdot
.812 .58066 Mdot
.812 .58067 Mdot
.812 .58067 Mdot
.812 .58068 Mdot
.812 .58068 Mdot
.812 .58069 Mdot
.812 .58069 Mdot
.812 .58069 Mdot
.812 .58069 Mdot
.812 .58069 Mdot
.812 .5807 Mdot
.812 .5807 Mdot
.812 .58071 Mdot
.812 .58071 Mdot
.812 .58071 Mdot
.812 .58072 Mdot
.812 .58072 Mdot
.812 .58072 Mdot
.812 .58072 Mdot
.812 .58073 Mdot
.812 .58073 Mdot
.812 .58074 Mdot
.812 .58074 Mdot
.812 .58075 Mdot
.812 .58076 Mdot
.812 .58076 Mdot
.812 .58076 Mdot
.812 .58076 Mdot
.812 .58077 Mdot
.812 .58077 Mdot
.812 .58077 Mdot
.812 .58078 Mdot
.812 .58078 Mdot
.812 .58078 Mdot
.812 .58078 Mdot
.812 .58079 Mdot
.812 .5808 Mdot
.812 .5808 Mdot
.812 .58082 Mdot
.812 .58083 Mdot
.812 .58083 Mdot
.812 .58085 Mdot
.812 .58086 Mdot
.812 .58088 Mdot
.812 .58088 Mdot
.812 .58089 Mdot
.812 .58089 Mdot
.812 .58089 Mdot
.812 .58089 Mdot
.812 .5809 Mdot
.812 .5809 Mdot
.812 .58091 Mdot
.812 .58091 Mdot
.812 .58091 Mdot
.812 .58092 Mdot
.812 .58092 Mdot
.812 .58093 Mdot
.812 .58093 Mdot
.812 .58094 Mdot
.812 .58094 Mdot
.812 .58094 Mdot
.812 .58107 Mdot
.812 .58107 Mdot
.812 .58107 Mdot
.812 .58107 Mdot
.812 .58107 Mdot
.812 .58107 Mdot
.812 .58108 Mdot
.812 .58108 Mdot
.812 .58108 Mdot
.812 .58108 Mdot
.812 .58108 Mdot
.812 .58109 Mdot
.812 .58109 Mdot
.812 .58109 Mdot
.812 .58109 Mdot
.812 .58109 Mdot
.812 .58109 Mdot
.812 .5811 Mdot
.812 .5811 Mdot
.812 .5811 Mdot
.812 .58111 Mdot
.812 .58111 Mdot
.812 .58112 Mdot
.812 .58112 Mdot
.812 .58113 Mdot
.812 .58113 Mdot
.812 .58113 Mdot
.812 .58113 Mdot
.812 .58113 Mdot
.812 .58113 Mdot
.812 .58114 Mdot
.812 .58114 Mdot
.812 .58114 Mdot
.812 .58114 Mdot
.812 .58114 Mdot
.812 .58114 Mdot
.812 .58114 Mdot
.812 .58114 Mdot
.812 .58115 Mdot
.812 .58115 Mdot
.812 .58115 Mdot
.812 .58115 Mdot
.812 .58115 Mdot
.812 .58115 Mdot
.812 .58115 Mdot
.812 .58115 Mdot
.812 .58116 Mdot
.812 .58116 Mdot
.812 .58116 Mdot
.812 .58116 Mdot
.812 .58116 Mdot
.812 .58116 Mdot
.812 .58116 Mdot
.812 .58116 Mdot
.812 .58116 Mdot
.812 .58117 Mdot
.812 .58117 Mdot
.812 .58117 Mdot
.812 .58117 Mdot
.812 .58117 Mdot
.812 .58117 Mdot
.812 .58117 Mdot
.812 .58117 Mdot
.812 .58117 Mdot
.812 .58118 Mdot
.812 .58118 Mdot
.812 .58118 Mdot
.812 .58118 Mdot
.812 .58118 Mdot
.812 .58118 Mdot
.812 .58118 Mdot
.812 .58118 Mdot
.812 .58118 Mdot
.812 .58118 Mdot
.812 .58118 Mdot
.812 .58118 Mdot
.812 .58118 Mdot
.812 .58119 Mdot
.812 .58119 Mdot
.812 .58119 Mdot
.812 .58119 Mdot
.812 .58119 Mdot
.812 .58119 Mdot
.812 .58119 Mdot
.814 .09591 Mdot
.814 .09591 Mdot
.814 .09591 Mdot
.814 .09591 Mdot
.814 .09592 Mdot
.814 .09592 Mdot
.814 .09593 Mdot
.814 .09594 Mdot
.814 .09595 Mdot
.814 .09596 Mdot
.814 .09596 Mdot
.814 .09597 Mdot
.814 .09597 Mdot
.814 .09598 Mdot
.814 .09599 Mdot
.814 .09603 Mdot
.814 .09603 Mdot
.814 .09605 Mdot
.814 .0961 Mdot
.814 .0961 Mdot
.814 .09612 Mdot
.814 .09615 Mdot
.814 .09616 Mdot
.814 .09616 Mdot
.814 .09622 Mdot
.814 .09622 Mdot
.814 .09623 Mdot
.814 .09623 Mdot
.814 .09624 Mdot
.814 .09627 Mdot
.814 .09627 Mdot
.814 .09628 Mdot
.814 .09631 Mdot
.814 .09632 Mdot
.814 .09634 Mdot
.814 .09636 Mdot
.814 .09639 Mdot
.814 .09642 Mdot
.814 .09642 Mdot
.814 .09643 Mdot
.814 .09651 Mdot
.814 .09651 Mdot
.814 .09656 Mdot
.814 .0966 Mdot
.814 .09667 Mdot
.814 .09668 Mdot
.814 .0967 Mdot
.814 .0967 Mdot
.814 .09671 Mdot
.814 .09673 Mdot
.814 .09673 Mdot
.814 .09676 Mdot
.814 .09676 Mdot
.814 .09681 Mdot
.814 .09683 Mdot
.814 .09685 Mdot
.814 .09695 Mdot
.814 .09696 Mdot
.814 .09702 Mdot
.814 .09703 Mdot
.814 .09708 Mdot
.814 .09709 Mdot
.814 .0971 Mdot
.814 .09716 Mdot
.814 .09716 Mdot
.814 .09717 Mdot
.814 .09717 Mdot
.814 .09722 Mdot
.814 .09726 Mdot
.814 .09728 Mdot
.814 .09733 Mdot
.814 .09736 Mdot
.814 .09743 Mdot
.814 .09749 Mdot
.814 .09754 Mdot
.814 .09759 Mdot
.814 .09764 Mdot
.814 .09765 Mdot
.814 .0978 Mdot
.814 .09782 Mdot
.814 .09783 Mdot
.814 .09789 Mdot
.814 .09793 Mdot
.814 .09793 Mdot
.814 .09795 Mdot
.814 .09795 Mdot
.814 .098 Mdot
.814 .09805 Mdot
.814 .09814 Mdot
.814 .0982 Mdot
.814 .09821 Mdot
.814 .09828 Mdot
.814 .09831 Mdot
.814 .09831 Mdot
.814 .09832 Mdot
.814 .09839 Mdot
.814 .09841 Mdot
.814 .09843 Mdot
.814 .09849 Mdot
.814 .0985 Mdot
.814 .09856 Mdot
.814 .09861 Mdot
.814 .09861 Mdot
.814 .09862 Mdot
.814 .09862 Mdot
.814 .09863 Mdot
.814 .09864 Mdot
.814 .09864 Mdot
.814 .09866 Mdot
.814 .0987 Mdot
.814 .09888 Mdot
.814 .09889 Mdot
.814 .09891 Mdot
.814 .09893 Mdot
.814 .09894 Mdot
.814 .09896 Mdot
.814 .09902 Mdot
.814 .09906 Mdot
.814 .09909 Mdot
.814 .09918 Mdot
.814 .09919 Mdot
.814 .0992 Mdot
.814 .09924 Mdot
.814 .09925 Mdot
.814 .09927 Mdot
.814 .09935 Mdot
.814 .0994 Mdot
.814 .0994 Mdot
.814 .09943 Mdot
.814 .09944 Mdot
.814 .0995 Mdot
.814 .09951 Mdot
.814 .09952 Mdot
.814 .09952 Mdot
.814 .09952 Mdot
.814 .09962 Mdot
.814 .09962 Mdot
.814 .09964 Mdot
.814 .09967 Mdot
.814 .09969 Mdot
.814 .09974 Mdot
.814 .09975 Mdot
.814 .09976 Mdot
.814 .09976 Mdot
.814 .09979 Mdot
.814 .09981 Mdot
.814 .09982 Mdot
.814 .09982 Mdot
.814 .09985 Mdot
.814 .09985 Mdot
.814 .09986 Mdot
.814 .09989 Mdot
.814 .09989 Mdot
.814 .0999 Mdot
.814 .09991 Mdot
.814 .09994 Mdot
.814 .09994 Mdot
.814 .09995 Mdot
.814 .09996 Mdot
.814 .09997 Mdot
.814 .09999 Mdot
.814 .10001 Mdot
.814 .10001 Mdot
.814 .10003 Mdot
.814 .10004 Mdot
.814 .10006 Mdot
.814 .10006 Mdot
.814 .10008 Mdot
.814 .10009 Mdot
.814 .10009 Mdot
.814 .1001 Mdot
.814 .10012 Mdot
.814 .10012 Mdot
.814 .10013 Mdot
.814 .10015 Mdot
.814 .10017 Mdot
.814 .10019 Mdot
.814 .1002 Mdot
.814 .10021 Mdot
.814 .10026 Mdot
.814 .10028 Mdot
.814 .10029 Mdot
.814 .10029 Mdot
.814 .10035 Mdot
.814 .10036 Mdot
.814 .10037 Mdot
.814 .10041 Mdot
.814 .10042 Mdot
.814 .10043 Mdot
.814 .10046 Mdot
.814 .10052 Mdot
.814 .10053 Mdot
.814 .10054 Mdot
.814 .10057 Mdot
.814 .10065 Mdot
.814 .10069 Mdot
.814 .10075 Mdot
.814 .10078 Mdot
.814 .10078 Mdot
.814 .10096 Mdot
.814 .10096 Mdot
.814 .10096 Mdot
.814 .10098 Mdot
.814 .10101 Mdot
.814 .10113 Mdot
.814 .10114 Mdot
.814 .10119 Mdot
.814 .1012 Mdot
.814 .10129 Mdot
.814 .10145 Mdot
.814 .1015 Mdot
.814 .10151 Mdot
.814 .10159 Mdot
.814 .1016 Mdot
.814 .10162 Mdot
.814 .10181 Mdot
.814 .10186 Mdot
.814 .10196 Mdot
.814 .10206 Mdot
.814 .10212 Mdot
.814 .10214 Mdot
.814 .10217 Mdot
.814 .10222 Mdot
.814 .10224 Mdot
.814 .10263 Mdot
.814 .10271 Mdot
.814 .10275 Mdot
.814 .10276 Mdot
.814 .10278 Mdot
.814 .10279 Mdot
.814 .10279 Mdot
.814 .10283 Mdot
.814 .10283 Mdot
.814 .10293 Mdot
.814 .10307 Mdot
.814 .10308 Mdot
.814 .10322 Mdot
.814 .10328 Mdot
.814 .10332 Mdot
.814 .10347 Mdot
.814 .1035 Mdot
.814 .1035 Mdot
.814 .10358 Mdot
.814 .10372 Mdot
.814 .10375 Mdot
.814 .10389 Mdot
.814 .10411 Mdot
.814 .10424 Mdot
.814 .10436 Mdot
.814 .10436 Mdot
.814 .10439 Mdot
.814 .10439 Mdot
.814 .10449 Mdot
.814 .10464 Mdot
.814 .10466 Mdot
.814 .10473 Mdot
.814 .1051 Mdot
.814 .10511 Mdot
.814 .10524 Mdot
.814 .10539 Mdot
.814 .10552 Mdot
.814 .10565 Mdot
.814 .10584 Mdot
.814 .10593 Mdot
.814 .10607 Mdot
.814 .10613 Mdot
.814 .10621 Mdot
.814 .10635 Mdot
.814 .10637 Mdot
.814 .10638 Mdot
.814 .1064 Mdot
.814 .10655 Mdot
.814 .10657 Mdot
.814 .1066 Mdot
.814 .10674 Mdot
.814 .10676 Mdot
.814 .10694 Mdot
.814 .10697 Mdot
.814 .10725 Mdot
.814 .10732 Mdot
.814 .10737 Mdot
.814 .1075 Mdot
.814 .10751 Mdot
.814 .10759 Mdot
.814 .10759 Mdot
.814 .10765 Mdot
.814 .10767 Mdot
.814 .10767 Mdot
.814 .10775 Mdot
.814 .10775 Mdot
.814 .10796 Mdot
.814 .10808 Mdot
.814 .10824 Mdot
.814 .10824 Mdot
.814 .10847 Mdot
.814 .1085 Mdot
.814 .10851 Mdot
.814 .1086 Mdot
.814 .10868 Mdot
.814 .10874 Mdot
.814 .10879 Mdot
.814 .10881 Mdot
.814 .10891 Mdot
.814 .10896 Mdot
.814 .10896 Mdot
.814 .10905 Mdot
.814 .10907 Mdot
.814 .10907 Mdot
.814 .10909 Mdot
.814 .10912 Mdot
.814 .10928 Mdot
.814 .10929 Mdot
.814 .10931 Mdot
.814 .1094 Mdot
.814 .10947 Mdot
.814 .10947 Mdot
.814 .10961 Mdot
.814 .1097 Mdot
.814 .1097 Mdot
.814 .10981 Mdot
.814 .10985 Mdot
.814 .10989 Mdot
.814 .10989 Mdot
.814 .10991 Mdot
.814 .10991 Mdot
.814 .10994 Mdot
.814 .10997 Mdot
.814 .11 Mdot
.814 .11003 Mdot
.814 .11004 Mdot
.814 .11005 Mdot
.814 .11006 Mdot
.814 .11008 Mdot
.814 .11008 Mdot
.814 .28427 Mdot
.814 .28427 Mdot
.814 .28429 Mdot
.814 .28429 Mdot
.814 .28431 Mdot
.814 .28431 Mdot
.814 .28434 Mdot
.814 .28437 Mdot
.814 .2844 Mdot
.814 .28442 Mdot
.814 .28442 Mdot
.814 .28443 Mdot
.814 .28444 Mdot
.814 .28448 Mdot
.814 .28451 Mdot
.814 .28461 Mdot
.814 .28461 Mdot
.814 .28468 Mdot
.814 .28481 Mdot
.814 .28482 Mdot
.814 .28487 Mdot
.814 .28495 Mdot
.814 .28497 Mdot
.814 .28499 Mdot
.814 .28513 Mdot
.814 .28516 Mdot
.814 .28517 Mdot
.814 .28517 Mdot
.814 .28519 Mdot
.814 .28527 Mdot
.814 .28527 Mdot
.814 .28532 Mdot
.814 .28541 Mdot
.814 .28543 Mdot
.814 .28548 Mdot
.814 .28553 Mdot
.814 .28561 Mdot
.814 .28569 Mdot
.814 .2857 Mdot
.814 .28573 Mdot
.814 .28594 Mdot
.814 .28595 Mdot
.814 .28609 Mdot
.814 .28621 Mdot
.814 .28641 Mdot
.814 .28641 Mdot
.814 .28648 Mdot
.814 .28649 Mdot
.814 .2865 Mdot
.814 .28656 Mdot
.814 .28657 Mdot
.814 .28664 Mdot
.814 .28665 Mdot
.814 .28678 Mdot
.814 .28683 Mdot
.814 .28689 Mdot
.814 .28717 Mdot
.814 .2872 Mdot
.814 .28738 Mdot
.814 .2874 Mdot
.814 .28754 Mdot
.814 .28757 Mdot
.814 .28759 Mdot
.814 .28775 Mdot
.814 .28776 Mdot
.814 .28778 Mdot
.814 .2878 Mdot
.814 .28793 Mdot
.814 .28802 Mdot
.814 .28808 Mdot
.814 .28823 Mdot
.814 .28832 Mdot
.814 .28852 Mdot
.814 .28866 Mdot
.814 .2888 Mdot
.814 .28896 Mdot
.814 .2891 Mdot
.814 .28912 Mdot
.814 .28952 Mdot
.814 .28959 Mdot
.814 .28962 Mdot
.814 .28979 Mdot
.814 .28989 Mdot
.814 .2899 Mdot
.814 .28993 Mdot
.814 .28993 Mdot
.814 .29007 Mdot
.814 .29022 Mdot
.814 .29048 Mdot
.814 .29063 Mdot
.814 .29067 Mdot
.814 .29084 Mdot
.814 .29093 Mdot
.814 .29093 Mdot
.814 .29097 Mdot
.814 .29115 Mdot
.814 .2912 Mdot
.814 .29127 Mdot
.814 .29145 Mdot
.814 .29145 Mdot
.814 .29163 Mdot
.814 .29175 Mdot
.814 .29176 Mdot
.814 .2918 Mdot
.814 .2918 Mdot
.814 .29181 Mdot
.814 .29184 Mdot
.814 .29185 Mdot
.814 .2919 Mdot
.814 .292 Mdot
.814 .2925 Mdot
.814 .29253 Mdot
.814 .29259 Mdot
.814 .29264 Mdot
.814 .29267 Mdot
.814 .29274 Mdot
.814 .29288 Mdot
.814 .29301 Mdot
.814 .29308 Mdot
.814 .29333 Mdot
.814 .29336 Mdot
.814 .29338 Mdot
.814 .2935 Mdot
.814 .29351 Mdot
.814 .29357 Mdot
.814 .2938 Mdot
.814 .29392 Mdot
.814 .29394 Mdot
.814 .29401 Mdot
.814 .29403 Mdot
.814 .2942 Mdot
.814 .29425 Mdot
.814 .29426 Mdot
.814 .29427 Mdot
.814 .29427 Mdot
.814 .29453 Mdot
.814 .29454 Mdot
.814 .29459 Mdot
.814 .29468 Mdot
.814 .29472 Mdot
.814 .29486 Mdot
.814 .2949 Mdot
.814 .29491 Mdot
.814 .29493 Mdot
.814 .29502 Mdot
.814 .29507 Mdot
.814 .29509 Mdot
.814 .2951 Mdot
.814 .29516 Mdot
.814 .29518 Mdot
.814 .29518 Mdot
.814 .29528 Mdot
.814 .29528 Mdot
.814 .2953 Mdot
.814 .29533 Mdot
.814 .29541 Mdot
.814 .29542 Mdot
.814 .29545 Mdot
.814 .29547 Mdot
.814 .2955 Mdot
.814 .29556 Mdot
.814 .29559 Mdot
.814 .29561 Mdot
.814 .29566 Mdot
.814 .2957 Mdot
.814 .29573 Mdot
.814 .29574 Mdot
.814 .29579 Mdot
.814 .29581 Mdot
.814 .29582 Mdot
.814 .29584 Mdot
.814 .2959 Mdot
.814 .29592 Mdot
.814 .29593 Mdot
.814 .296 Mdot
.814 .29606 Mdot
.814 .29609 Mdot
.814 .29614 Mdot
.814 .29615 Mdot
.814 .29629 Mdot
.814 .29635 Mdot
.814 .29638 Mdot
.814 .29638 Mdot
.814 .29655 Mdot
.814 .29656 Mdot
.814 .29659 Mdot
.814 .2967 Mdot
.814 .29671 Mdot
.814 .29676 Mdot
.814 .29685 Mdot
.814 .297 Mdot
.814 .29703 Mdot
.814 .29704 Mdot
.814 .29712 Mdot
.814 .29737 Mdot
.814 .29745 Mdot
.814 .29762 Mdot
.814 .2977 Mdot
.814 .29771 Mdot
.814 .2982 Mdot
.814 .29821 Mdot
.814 .29821 Mdot
.814 .29824 Mdot
.814 .29834 Mdot
.814 .29865 Mdot
.814 .29869 Mdot
.814 .29882 Mdot
.814 .29885 Mdot
.814 .29909 Mdot
.814 .29954 Mdot
.814 .29965 Mdot
.814 .29968 Mdot
.814 .29991 Mdot
.814 .29994 Mdot
.814 .3 Mdot
.814 .3005 Mdot
.814 .30064 Mdot
.814 .30091 Mdot
.814 .30119 Mdot
.814 .30134 Mdot
.814 .30139 Mdot
.814 .30149 Mdot
.814 .30163 Mdot
.814 .30168 Mdot
.814 .30273 Mdot
.814 .30294 Mdot
.814 .30305 Mdot
.814 .30306 Mdot
.814 .30314 Mdot
.814 .30316 Mdot
.814 .30317 Mdot
.814 .30326 Mdot
.814 .30326 Mdot
.814 .30354 Mdot
.814 .30392 Mdot
.814 .30393 Mdot
.814 .30433 Mdot
.814 .30447 Mdot
.814 .30459 Mdot
.814 .30498 Mdot
.814 .30507 Mdot
.814 .30507 Mdot
.814 .30528 Mdot
.814 .30567 Mdot
.814 .30575 Mdot
.814 .30611 Mdot
.814 .3067 Mdot
.814 .30705 Mdot
.814 .30737 Mdot
.814 .30738 Mdot
.814 .30746 Mdot
.814 .30747 Mdot
.814 .30772 Mdot
.814 .30812 Mdot
.814 .30819 Mdot
.814 .30837 Mdot
.814 .30934 Mdot
.814 .30939 Mdot
.814 .30973 Mdot
.814 .31012 Mdot
.814 .31046 Mdot
.814 .31083 Mdot
.814 .31133 Mdot
.814 .31157 Mdot
.814 .31194 Mdot
.814 .31209 Mdot
.814 .31232 Mdot
.814 .31268 Mdot
.814 .31273 Mdot
.814 .31276 Mdot
.814 .31281 Mdot
.814 .31322 Mdot
.814 .31326 Mdot
.814 .31335 Mdot
.814 .31372 Mdot
.814 .31378 Mdot
.814 .31425 Mdot
.814 .31432 Mdot
.814 .31507 Mdot
.814 .31524 Mdot
.814 .31538 Mdot
.814 .31571 Mdot
.814 .31575 Mdot
.814 .31595 Mdot
.814 .31597 Mdot
.814 .31613 Mdot
.814 .31616 Mdot
.814 .31618 Mdot
.814 .31637 Mdot
.814 .31638 Mdot
.814 .31693 Mdot
.814 .31726 Mdot
.814 .31766 Mdot
.814 .31768 Mdot
.814 .31826 Mdot
.814 .31835 Mdot
.814 .31838 Mdot
.814 .31862 Mdot
.814 .31882 Mdot
.814 .31897 Mdot
.814 .31911 Mdot
.814 .31918 Mdot
.814 .31943 Mdot
.814 .31957 Mdot
.814 .31957 Mdot
.814 .31979 Mdot
.814 .31986 Mdot
.814 .31986 Mdot
.814 .3199 Mdot
.814 .31997 Mdot
.814 .32038 Mdot
.814 .32043 Mdot
.814 .32048 Mdot
.814 .32072 Mdot
.814 .32088 Mdot
.814 .3209 Mdot
.814 .32127 Mdot
.814 .32148 Mdot
.814 .32148 Mdot
.814 .32177 Mdot
.814 .32188 Mdot
.814 .32199 Mdot
.814 .322 Mdot
.814 .32204 Mdot
.814 .32205 Mdot
.814 .32211 Mdot
.814 .32219 Mdot
.814 .32227 Mdot
.814 .32236 Mdot
.814 .32238 Mdot
.814 .32241 Mdot
.814 .32243 Mdot
.814 .32248 Mdot
.814 .32249 Mdot
.814 .57742 Mdot
.814 .57742 Mdot
.814 .57742 Mdot
.814 .57742 Mdot
.814 .57743 Mdot
.814 .57743 Mdot
.814 .57744 Mdot
.814 .57745 Mdot
.814 .57746 Mdot
.814 .57746 Mdot
.814 .57746 Mdot
.814 .57747 Mdot
.814 .57747 Mdot
.814 .57748 Mdot
.814 .57749 Mdot
.814 .57753 Mdot
.814 .57753 Mdot
.814 .57755 Mdot
.814 .57759 Mdot
.814 .57759 Mdot
.814 .57761 Mdot
.814 .57763 Mdot
.814 .57764 Mdot
.814 .57765 Mdot
.814 .57769 Mdot
.814 .5777 Mdot
.814 .5777 Mdot
.814 .5777 Mdot
.814 .57771 Mdot
.814 .57773 Mdot
.814 .57773 Mdot
.814 .57775 Mdot
.814 .57778 Mdot
.814 .57778 Mdot
.814 .5778 Mdot
.814 .57782 Mdot
.814 .57784 Mdot
.814 .57786 Mdot
.814 .57787 Mdot
.814 .57788 Mdot
.814 .57794 Mdot
.814 .57794 Mdot
.814 .57798 Mdot
.814 .57802 Mdot
.814 .57808 Mdot
.814 .57808 Mdot
.814 .5781 Mdot
.814 .5781 Mdot
.814 .57811 Mdot
.814 .57812 Mdot
.814 .57813 Mdot
.814 .57815 Mdot
.814 .57815 Mdot
.814 .57819 Mdot
.814 .5782 Mdot
.814 .57822 Mdot
.814 .5783 Mdot
.814 .57831 Mdot
.814 .57836 Mdot
.814 .57836 Mdot
.814 .57841 Mdot
.814 .57841 Mdot
.814 .57842 Mdot
.814 .57846 Mdot
.814 .57847 Mdot
.814 .57847 Mdot
.814 .57848 Mdot
.814 .57852 Mdot
.814 .57854 Mdot
.814 .57856 Mdot
.814 .5786 Mdot
.814 .57862 Mdot
.814 .57867 Mdot
.814 .57871 Mdot
.814 .57875 Mdot
.814 .57879 Mdot
.814 .57883 Mdot
.814 .57883 Mdot
.814 .57894 Mdot
.814 .57895 Mdot
.814 .57896 Mdot
.814 .579 Mdot
.814 .57903 Mdot
.814 .57903 Mdot
.814 .57904 Mdot
.814 .57904 Mdot
.814 .57908 Mdot
.814 .57911 Mdot
.814 .57917 Mdot
.814 .57921 Mdot
.814 .57922 Mdot
.814 .57926 Mdot
.814 .57928 Mdot
.814 .57928 Mdot
.814 .57929 Mdot
.814 .57933 Mdot
.814 .57935 Mdot
.814 .57936 Mdot
.814 .5794 Mdot
.814 .5794 Mdot
.814 .57944 Mdot
.814 .57947 Mdot
.814 .57947 Mdot
.814 .57948 Mdot
.814 .57948 Mdot
.814 .57949 Mdot
.814 .57949 Mdot
.814 .5795 Mdot
.814 .57951 Mdot
.814 .57953 Mdot
.814 .57964 Mdot
.814 .57964 Mdot
.814 .57966 Mdot
.814 .57967 Mdot
.814 .57967 Mdot
.814 .57969 Mdot
.814 .57972 Mdot
.814 .57975 Mdot
.814 .57976 Mdot
.814 .57981 Mdot
.814 .57982 Mdot
.814 .57982 Mdot
.814 .57985 Mdot
.814 .57985 Mdot
.814 .57986 Mdot
.814 .57991 Mdot
.814 .57993 Mdot
.814 .57994 Mdot
.814 .57995 Mdot
.814 .57995 Mdot
.814 .57999 Mdot
.814 .58 Mdot
.814 .58 Mdot
.814 .58 Mdot
.814 .58 Mdot
.814 .58005 Mdot
.814 .58005 Mdot
.814 .58006 Mdot
.814 .58008 Mdot
.814 .58009 Mdot
.814 .58011 Mdot
.814 .58012 Mdot
.814 .58012 Mdot
.814 .58013 Mdot
.814 .58014 Mdot
.814 .58015 Mdot
.814 .58015 Mdot
.814 .58016 Mdot
.814 .58017 Mdot
.814 .58017 Mdot
.814 .58017 Mdot
.814 .58019 Mdot
.814 .58019 Mdot
.814 .58019 Mdot
.814 .5802 Mdot
.814 .58021 Mdot
.814 .58021 Mdot
.814 .58022 Mdot
.814 .58022 Mdot
.814 .58023 Mdot
.814 .58024 Mdot
.814 .58024 Mdot
.814 .58024 Mdot
.814 .58024 Mdot
.814 .58025 Mdot
.814 .58025 Mdot
.814 .58025 Mdot
.814 .58025 Mdot
.814 .58026 Mdot
.814 .58026 Mdot
.814 .58026 Mdot
.814 .58027 Mdot
.814 .58027 Mdot
.814 .58027 Mdot
.814 .58028 Mdot
.814 .58028 Mdot
.814 .58028 Mdot
.814 .58029 Mdot
.814 .58029 Mdot
.814 .5803 Mdot
.814 .5803 Mdot
.814 .5803 Mdot
.814 .5803 Mdot
.814 .58031 Mdot
.814 .58031 Mdot
.814 .58031 Mdot
.814 .58032 Mdot
.814 .58032 Mdot
.814 .58032 Mdot
.814 .58033 Mdot
.814 .58034 Mdot
.814 .58034 Mdot
.814 .58034 Mdot
.814 .58036 Mdot
.814 .58036 Mdot
.814 .58037 Mdot
.814 .58038 Mdot
.814 .58038 Mdot
.814 .58041 Mdot
.814 .58041 Mdot
.814 .58041 Mdot
.814 .58041 Mdot
.814 .58041 Mdot
.814 .58043 Mdot
.814 .58043 Mdot
.814 .58044 Mdot
.814 .58044 Mdot
.814 .58045 Mdot
.814 .58048 Mdot
.814 .58048 Mdot
.814 .58049 Mdot
.814 .5805 Mdot
.814 .5805 Mdot
.814 .5805 Mdot
.814 .58053 Mdot
.814 .58054 Mdot
.814 .58055 Mdot
.814 .58056 Mdot
.814 .58057 Mdot
.814 .58057 Mdot
.814 .58058 Mdot
.814 .58058 Mdot
.814 .58059 Mdot
.814 .58064 Mdot
.814 .58065 Mdot
.814 .58065 Mdot
.814 .58065 Mdot
.814 .58066 Mdot
.814 .58066 Mdot
.814 .58066 Mdot
.814 .58066 Mdot
.814 .58066 Mdot
.814 .58068 Mdot
.814 .58069 Mdot
.814 .5807 Mdot
.814 .58071 Mdot
.814 .58072 Mdot
.814 .58073 Mdot
.814 .58074 Mdot
.814 .58075 Mdot
.814 .58075 Mdot
.814 .58076 Mdot
.814 .58077 Mdot
.814 .58078 Mdot
.814 .58079 Mdot
.814 .58082 Mdot
.814 .58084 Mdot
.814 .58085 Mdot
.814 .58085 Mdot
.814 .58085 Mdot
.814 .58085 Mdot
.814 .58086 Mdot
.814 .58088 Mdot
.814 .58088 Mdot
.814 .58089 Mdot
.814 .58093 Mdot
.814 .58093 Mdot
.814 .58095 Mdot
.814 .58096 Mdot
.814 .58098 Mdot
.814 .58099 Mdot
.814 .58101 Mdot
.814 .58102 Mdot
.814 .58104 Mdot
.814 .58104 Mdot
.814 .58105 Mdot
.814 .58107 Mdot
.814 .58107 Mdot
.814 .58107 Mdot
.814 .58107 Mdot
.814 .58109 Mdot
.814 .58109 Mdot
.814 .58109 Mdot
.814 .58111 Mdot
.814 .58111 Mdot
.814 .58113 Mdot
.814 .58113 Mdot
.814 .58116 Mdot
.814 .58116 Mdot
.814 .58117 Mdot
.814 .58118 Mdot
.814 .58118 Mdot
.814 .58119 Mdot
.814 .58119 Mdot
.814 .5812 Mdot
.814 .5812 Mdot
.814 .5812 Mdot
.814 .58121 Mdot
.814 .58121 Mdot
.814 .58123 Mdot
.814 .58124 Mdot
.814 .58125 Mdot
.814 .58125 Mdot
.814 .58128 Mdot
.814 .58128 Mdot
.814 .58128 Mdot
.814 .58129 Mdot
.814 .5813 Mdot
.814 .5813 Mdot
.814 .58131 Mdot
.814 .58131 Mdot
.814 .58132 Mdot
.814 .58132 Mdot
.814 .58132 Mdot
.814 .58133 Mdot
.814 .58133 Mdot
.814 .58133 Mdot
.814 .58133 Mdot
.814 .58134 Mdot
.814 .58135 Mdot
.814 .58135 Mdot
.814 .58135 Mdot
.814 .58136 Mdot
.814 .58137 Mdot
.814 .58137 Mdot
.814 .58138 Mdot
.814 .58139 Mdot
.814 .58139 Mdot
.814 .5814 Mdot
.814 .5814 Mdot
.814 .58141 Mdot
.814 .58141 Mdot
.814 .58141 Mdot
.814 .58141 Mdot
.814 .58141 Mdot
.814 .58141 Mdot
.814 .58142 Mdot
.814 .58142 Mdot
.814 .58142 Mdot
.814 .58142 Mdot
.814 .58142 Mdot
.814 .58142 Mdot
.814 .58142 Mdot
.816 .0951 Mdot
.816 .0951 Mdot
.816 .0951 Mdot
.816 .0951 Mdot
.816 .09511 Mdot
.816 .09512 Mdot
.816 .09512 Mdot
.816 .09512 Mdot
.816 .09513 Mdot
.816 .09513 Mdot
.816 .09514 Mdot
.816 .09515 Mdot
.816 .09515 Mdot
.816 .09516 Mdot
.816 .09519 Mdot
.816 .09519 Mdot
.816 .0952 Mdot
.816 .0952 Mdot
.816 .09521 Mdot
.816 .09524 Mdot
.816 .09525 Mdot
.816 .09526 Mdot
.816 .09527 Mdot
.816 .09528 Mdot
.816 .09531 Mdot
.816 .09532 Mdot
.816 .09534 Mdot
.816 .09538 Mdot
.816 .09539 Mdot
.816 .09544 Mdot
.816 .09544 Mdot
.816 .09546 Mdot
.816 .09547 Mdot
.816 .09548 Mdot
.816 .09551 Mdot
.816 .09553 Mdot
.816 .09554 Mdot
.816 .09556 Mdot
.816 .09565 Mdot
.816 .09568 Mdot
.816 .09575 Mdot
.816 .09583 Mdot
.816 .09583 Mdot
.816 .09585 Mdot
.816 .09585 Mdot
.816 .09586 Mdot
.816 .09586 Mdot
.816 .09587 Mdot
.816 .09587 Mdot
.816 .09589 Mdot
.816 .09592 Mdot
.816 .09592 Mdot
.816 .09597 Mdot
.816 .09597 Mdot
.816 .09599 Mdot
.816 .09599 Mdot
.816 .096 Mdot
.816 .09603 Mdot
.816 .09603 Mdot
.816 .09603 Mdot
.816 .09607 Mdot
.816 .09608 Mdot
.816 .09611 Mdot
.816 .09612 Mdot
.816 .09612 Mdot
.816 .09617 Mdot
.816 .09619 Mdot
.816 .09619 Mdot
.816 .09622 Mdot
.816 .09626 Mdot
.816 .09627 Mdot
.816 .09628 Mdot
.816 .09633 Mdot
.816 .09636 Mdot
.816 .09638 Mdot
.816 .09642 Mdot
.816 .09644 Mdot
.816 .09645 Mdot
.816 .0965 Mdot
.816 .09651 Mdot
.816 .09653 Mdot
.816 .09659 Mdot
.816 .09665 Mdot
.816 .09669 Mdot
.816 .09678 Mdot
.816 .09682 Mdot
.816 .09684 Mdot
.816 .09685 Mdot
.816 .09689 Mdot
.816 .09692 Mdot
.816 .09694 Mdot
.816 .09695 Mdot
.816 .09698 Mdot
.816 .09702 Mdot
.816 .09702 Mdot
.816 .09706 Mdot
.816 .09709 Mdot
.816 .09713 Mdot
.816 .09716 Mdot
.816 .09718 Mdot
.816 .09719 Mdot
.816 .09724 Mdot
.816 .09735 Mdot
.816 .09737 Mdot
.816 .09738 Mdot
.816 .09744 Mdot
.816 .09746 Mdot
.816 .09751 Mdot
.816 .09751 Mdot
.816 .09753 Mdot
.816 .09759 Mdot
.816 .09766 Mdot
.816 .09767 Mdot
.816 .09768 Mdot
.816 .09775 Mdot
.816 .09777 Mdot
.816 .09789 Mdot
.816 .09796 Mdot
.816 .09796 Mdot
.816 .09799 Mdot
.816 .098 Mdot
.816 .09803 Mdot
.816 .09809 Mdot
.816 .09821 Mdot
.816 .09821 Mdot
.816 .09822 Mdot
.816 .09822 Mdot
.816 .09826 Mdot
.816 .09829 Mdot
.816 .09832 Mdot
.816 .09837 Mdot
.816 .09837 Mdot
.816 .09846 Mdot
.816 .09848 Mdot
.816 .0985 Mdot
.816 .09873 Mdot
.816 .09877 Mdot
.816 .0988 Mdot
.816 .09881 Mdot
.816 .09884 Mdot
.816 .09896 Mdot
.816 .09912 Mdot
.816 .09916 Mdot
.816 .09927 Mdot
.816 .09933 Mdot
.816 .09943 Mdot
.816 .09948 Mdot
.816 .09965 Mdot
.816 .09976 Mdot
.816 .09986 Mdot
.816 .09989 Mdot
.816 .09994 Mdot
.816 .10005 Mdot
.816 .10017 Mdot
.816 .10024 Mdot
.816 .10025 Mdot
.816 .10026 Mdot
.816 .10031 Mdot
.816 .10045 Mdot
.816 .10047 Mdot
.816 .10048 Mdot
.816 .10057 Mdot
.816 .10077 Mdot
.816 .10079 Mdot
.816 .10082 Mdot
.816 .10087 Mdot
.816 .10109 Mdot
.816 .10119 Mdot
.816 .10121 Mdot
.816 .10126 Mdot
.816 .10144 Mdot
.816 .10146 Mdot
.816 .1015 Mdot
.816 .10152 Mdot
.816 .10156 Mdot
.816 .10159 Mdot
.816 .10164 Mdot
.816 .10167 Mdot
.816 .10171 Mdot
.816 .10173 Mdot
.816 .10195 Mdot
.816 .10201 Mdot
.816 .10205 Mdot
.816 .1021 Mdot
.816 .10211 Mdot
.816 .10217 Mdot
.816 .10223 Mdot
.816 .10228 Mdot
.816 .10229 Mdot
.816 .10238 Mdot
.816 .10241 Mdot
.816 .10246 Mdot
.816 .10247 Mdot
.816 .10248 Mdot
.816 .10252 Mdot
.816 .10257 Mdot
.816 .10258 Mdot
.816 .10262 Mdot
.816 .10262 Mdot
.816 .10265 Mdot
.816 .10265 Mdot
.816 .10271 Mdot
.816 .10272 Mdot
.816 .10275 Mdot
.816 .10279 Mdot
.816 .10279 Mdot
.816 .10279 Mdot
.816 .10281 Mdot
.816 .10282 Mdot
.816 .10284 Mdot
.816 .10284 Mdot
.816 .10311 Mdot
.816 .10327 Mdot
.816 .10333 Mdot
.816 .10336 Mdot
.816 .10342 Mdot
.816 .10343 Mdot
.816 .10361 Mdot
.816 .10391 Mdot
.816 .10395 Mdot
.816 .10413 Mdot
.816 .10415 Mdot
.816 .10417 Mdot
.816 .10435 Mdot
.816 .1045 Mdot
.816 .10455 Mdot
.816 .10456 Mdot
.816 .10469 Mdot
.816 .10475 Mdot
.816 .1049 Mdot
.816 .10493 Mdot
.816 .10499 Mdot
.816 .10527 Mdot
.816 .10539 Mdot
.816 .10543 Mdot
.816 .10549 Mdot
.816 .10557 Mdot
.816 .10568 Mdot
.816 .10576 Mdot
.816 .10587 Mdot
.816 .10588 Mdot
.816 .10599 Mdot
.816 .10607 Mdot
.816 .10609 Mdot
.816 .10614 Mdot
.816 .10624 Mdot
.816 .10636 Mdot
.816 .10636 Mdot
.816 .10642 Mdot
.816 .10656 Mdot
.816 .1068 Mdot
.816 .10691 Mdot
.816 .10709 Mdot
.816 .10726 Mdot
.816 .10731 Mdot
.816 .10737 Mdot
.816 .1075 Mdot
.816 .10754 Mdot
.816 .10759 Mdot
.816 .1077 Mdot
.816 .10777 Mdot
.816 .10787 Mdot
.816 .108 Mdot
.816 .10804 Mdot
.816 .10813 Mdot
.816 .10819 Mdot
.816 .10828 Mdot
.816 .10829 Mdot
.816 .10835 Mdot
.816 .1085 Mdot
.816 .10851 Mdot
.816 .10855 Mdot
.816 .10864 Mdot
.816 .10866 Mdot
.816 .10877 Mdot
.816 .10877 Mdot
.816 .10879 Mdot
.816 .10889 Mdot
.816 .1089 Mdot
.816 .1089 Mdot
.816 .10896 Mdot
.816 .10897 Mdot
.816 .10912 Mdot
.816 .10914 Mdot
.816 .10921 Mdot
.816 .1093 Mdot
.816 .1093 Mdot
.816 .1093 Mdot
.816 .10931 Mdot
.816 .10934 Mdot
.816 .10936 Mdot
.816 .10941 Mdot
.816 .10941 Mdot
.816 .10968 Mdot
.816 .1099 Mdot
.816 .11 Mdot
.816 .11029 Mdot
.816 .11037 Mdot
.816 .1104 Mdot
.816 .11046 Mdot
.816 .11056 Mdot
.816 .11057 Mdot
.816 .1106 Mdot
.816 .11069 Mdot
.816 .1107 Mdot
.816 .11086 Mdot
.816 .11088 Mdot
.816 .11102 Mdot
.816 .11108 Mdot
.816 .11111 Mdot
.816 .11121 Mdot
.816 .11126 Mdot
.816 .1113 Mdot
.816 .11134 Mdot
.816 .11135 Mdot
.816 .11145 Mdot
.816 .11148 Mdot
.816 .1115 Mdot
.816 .11152 Mdot
.816 .11153 Mdot
.816 .11162 Mdot
.816 .11166 Mdot
.816 .11167 Mdot
.816 .11171 Mdot
.816 .11173 Mdot
.816 .11175 Mdot
.816 .11177 Mdot
.816 .11177 Mdot
.816 .11179 Mdot
.816 .11182 Mdot
.816 .11183 Mdot
.816 .11185 Mdot
.816 .11185 Mdot
.816 .11185 Mdot
.816 .28212 Mdot
.816 .28212 Mdot
.816 .28212 Mdot
.816 .28213 Mdot
.816 .28215 Mdot
.816 .28217 Mdot
.816 .28218 Mdot
.816 .28219 Mdot
.816 .2822 Mdot
.816 .28222 Mdot
.816 .28224 Mdot
.816 .28227 Mdot
.816 .28228 Mdot
.816 .28231 Mdot
.816 .28238 Mdot
.816 .28239 Mdot
.816 .2824 Mdot
.816 .28242 Mdot
.816 .28244 Mdot
.816 .28253 Mdot
.816 .28254 Mdot
.816 .28257 Mdot
.816 .2826 Mdot
.816 .28264 Mdot
.816 .28273 Mdot
.816 .28275 Mdot
.816 .2828 Mdot
.816 .28292 Mdot
.816 .28294 Mdot
.816 .28307 Mdot
.816 .28308 Mdot
.816 .28315 Mdot
.816 .28317 Mdot
.816 .28318 Mdot
.816 .28327 Mdot
.816 .28332 Mdot
.816 .28335 Mdot
.816 .28341 Mdot
.816 .28366 Mdot
.816 .28375 Mdot
.816 .28394 Mdot
.816 .28417 Mdot
.816 .28417 Mdot
.816 .28422 Mdot
.816 .28424 Mdot
.816 .28426 Mdot
.816 .28426 Mdot
.816 .28427 Mdot
.816 .28427 Mdot
.816 .28434 Mdot
.816 .28441 Mdot
.816 .28443 Mdot
.816 .28456 Mdot
.816 .28457 Mdot
.816 .28462 Mdot
.816 .28462 Mdot
.816 .28463 Mdot
.816 .28472 Mdot
.816 .28474 Mdot
.816 .28474 Mdot
.816 .28484 Mdot
.816 .28486 Mdot
.816 .28494 Mdot
.816 .28497 Mdot
.816 .28498 Mdot
.816 .28512 Mdot
.816 .28517 Mdot
.816 .28518 Mdot
.816 .28526 Mdot
.816 .28537 Mdot
.816 .2854 Mdot
.816 .28543 Mdot
.816 .28556 Mdot
.816 .28565 Mdot
.816 .28571 Mdot
.816 .28582 Mdot
.816 .28586 Mdot
.816 .2859 Mdot
.816 .28603 Mdot
.816 .28608 Mdot
.816 .28613 Mdot
.816 .28629 Mdot
.816 .28646 Mdot
.816 .28656 Mdot
.816 .2868 Mdot
.816 .28694 Mdot
.816 .28699 Mdot
.816 .287 Mdot
.816 .28711 Mdot
.816 .28722 Mdot
.816 .28726 Mdot
.816 .28728 Mdot
.816 .28736 Mdot
.816 .28748 Mdot
.816 .28748 Mdot
.816 .28759 Mdot
.816 .28768 Mdot
.816 .28779 Mdot
.816 .28787 Mdot
.816 .28793 Mdot
.816 .28797 Mdot
.816 .2881 Mdot
.816 .28839 Mdot
.816 .28845 Mdot
.816 .28848 Mdot
.816 .28864 Mdot
.816 .28871 Mdot
.816 .28884 Mdot
.816 .28885 Mdot
.816 .2889 Mdot
.816 .28907 Mdot
.816 .28926 Mdot
.816 .28929 Mdot
.816 .28931 Mdot
.816 .28951 Mdot
.816 .28955 Mdot
.816 .28989 Mdot
.816 .29009 Mdot
.816 .2901 Mdot
.816 .29017 Mdot
.816 .29021 Mdot
.816 .29027 Mdot
.816 .29045 Mdot
.816 .29077 Mdot
.816 .29077 Mdot
.816 .2908 Mdot
.816 .29081 Mdot
.816 .29092 Mdot
.816 .291 Mdot
.816 .29109 Mdot
.816 .29122 Mdot
.816 .29123 Mdot
.816 .29145 Mdot
.816 .29152 Mdot
.816 .29159 Mdot
.816 .29221 Mdot
.816 .29231 Mdot
.816 .2924 Mdot
.816 .29244 Mdot
.816 .29251 Mdot
.816 .29284 Mdot
.816 .29327 Mdot
.816 .29338 Mdot
.816 .29369 Mdot
.816 .29386 Mdot
.816 .29413 Mdot
.816 .29427 Mdot
.816 .29472 Mdot
.816 .29505 Mdot
.816 .2953 Mdot
.816 .29539 Mdot
.816 .29554 Mdot
.816 .29582 Mdot
.816 .29615 Mdot
.816 .29634 Mdot
.816 .29639 Mdot
.816 .29641 Mdot
.816 .29653 Mdot
.816 .29693 Mdot
.816 .29697 Mdot
.816 .29701 Mdot
.816 .29725 Mdot
.816 .29781 Mdot
.816 .29785 Mdot
.816 .29793 Mdot
.816 .29808 Mdot
.816 .29867 Mdot
.816 .29895 Mdot
.816 .299 Mdot
.816 .29912 Mdot
.816 .29961 Mdot
.816 .29968 Mdot
.816 .29977 Mdot
.816 .29984 Mdot
.816 .29994 Mdot
.816 .30004 Mdot
.816 .30017 Mdot
.816 .30026 Mdot
.816 .30036 Mdot
.816 .30041 Mdot
.816 .30101 Mdot
.816 .30117 Mdot
.816 .30127 Mdot
.816 .3014 Mdot
.816 .30144 Mdot
.816 .30159 Mdot
.816 .30175 Mdot
.816 .30189 Mdot
.816 .30193 Mdot
.816 .30217 Mdot
.816 .30224 Mdot
.816 .30239 Mdot
.816 .3024 Mdot
.816 .30244 Mdot
.816 .30256 Mdot
.816 .30268 Mdot
.816 .3027 Mdot
.816 .30281 Mdot
.816 .30283 Mdot
.816 .30289 Mdot
.816 .3029 Mdot
.816 .30307 Mdot
.816 .30309 Mdot
.816 .30318 Mdot
.816 .30328 Mdot
.816 .30328 Mdot
.816 .30329 Mdot
.816 .30332 Mdot
.816 .30335 Mdot
.816 .30341 Mdot
.816 .30341 Mdot
.816 .30415 Mdot
.816 .30457 Mdot
.816 .30473 Mdot
.816 .30481 Mdot
.816 .30498 Mdot
.816 .305 Mdot
.816 .30548 Mdot
.816 .3063 Mdot
.816 .3064 Mdot
.816 .30687 Mdot
.816 .30693 Mdot
.816 .307 Mdot
.816 .30747 Mdot
.816 .30788 Mdot
.816 .30801 Mdot
.816 .30803 Mdot
.816 .30837 Mdot
.816 .30854 Mdot
.816 .30893 Mdot
.816 .30901 Mdot
.816 .30918 Mdot
.816 .30992 Mdot
.816 .31026 Mdot
.816 .31036 Mdot
.816 .31051 Mdot
.816 .31073 Mdot
.816 .31102 Mdot
.816 .31124 Mdot
.816 .31153 Mdot
.816 .31155 Mdot
.816 .31184 Mdot
.816 .31207 Mdot
.816 .31212 Mdot
.816 .31224 Mdot
.816 .31251 Mdot
.816 .31283 Mdot
.816 .31284 Mdot
.816 .31299 Mdot
.816 .31336 Mdot
.816 .31401 Mdot
.816 .31429 Mdot
.816 .31476 Mdot
.816 .31521 Mdot
.816 .31535 Mdot
.816 .3155 Mdot
.816 .31586 Mdot
.816 .31596 Mdot
.816 .31607 Mdot
.816 .31638 Mdot
.816 .31655 Mdot
.816 .31681 Mdot
.816 .31718 Mdot
.816 .31728 Mdot
.816 .3175 Mdot
.816 .31767 Mdot
.816 .31791 Mdot
.816 .31792 Mdot
.816 .31809 Mdot
.816 .31847 Mdot
.816 .3185 Mdot
.816 .31861 Mdot
.816 .31884 Mdot
.816 .31889 Mdot
.816 .31919 Mdot
.816 .31919 Mdot
.816 .31923 Mdot
.816 .3195 Mdot
.816 .31952 Mdot
.816 .31954 Mdot
.816 .31968 Mdot
.816 .31971 Mdot
.816 .3201 Mdot
.816 .32015 Mdot
.816 .32035 Mdot
.816 .32057 Mdot
.816 .32057 Mdot
.816 .32059 Mdot
.816 .3206 Mdot
.816 .32067 Mdot
.816 .32072 Mdot
.816 .32087 Mdot
.816 .32087 Mdot
.816 .32156 Mdot
.816 .32215 Mdot
.816 .32239 Mdot
.816 .32317 Mdot
.816 .32335 Mdot
.816 .32344 Mdot
.816 .32359 Mdot
.816 .32387 Mdot
.816 .32389 Mdot
.816 .32397 Mdot
.816 .3242 Mdot
.816 .32422 Mdot
.816 .32463 Mdot
.816 .32469 Mdot
.816 .32506 Mdot
.816 .32522 Mdot
.816 .32528 Mdot
.816 .32555 Mdot
.816 .32567 Mdot
.816 .32578 Mdot
.816 .32587 Mdot
.816 .3259 Mdot
.816 .32618 Mdot
.816 .32625 Mdot
.816 .3263 Mdot
.816 .32636 Mdot
.816 .32637 Mdot
.816 .3266 Mdot
.816 .32671 Mdot
.816 .32674 Mdot
.816 .32683 Mdot
.816 .32688 Mdot
.816 .32694 Mdot
.816 .32699 Mdot
.816 .327 Mdot
.816 .32703 Mdot
.816 .32712 Mdot
.816 .32716 Mdot
.816 .3272 Mdot
.816 .3272 Mdot
.816 .3272 Mdot
.816 .57692 Mdot
.816 .57692 Mdot
.816 .57692 Mdot
.816 .57693 Mdot
.816 .57693 Mdot
.816 .57694 Mdot
.816 .57695 Mdot
.816 .57695 Mdot
.816 .57695 Mdot
.816 .57696 Mdot
.816 .57696 Mdot
.816 .57697 Mdot
.816 .57698 Mdot
.816 .57699 Mdot
.816 .57701 Mdot
.816 .57702 Mdot
.816 .57702 Mdot
.816 .57703 Mdot
.816 .57704 Mdot
.816 .57707 Mdot
.816 .57707 Mdot
.816 .57708 Mdot
.816 .57709 Mdot
.816 .57711 Mdot
.816 .57714 Mdot
.816 .57714 Mdot
.816 .57716 Mdot
.816 .5772 Mdot
.816 .57721 Mdot
.816 .57725 Mdot
.816 .57725 Mdot
.816 .57728 Mdot
.816 .57729 Mdot
.816 .57729 Mdot
.816 .57732 Mdot
.816 .57734 Mdot
.816 .57735 Mdot
.816 .57737 Mdot
.816 .57745 Mdot
.816 .57748 Mdot
.816 .57754 Mdot
.816 .57762 Mdot
.816 .57762 Mdot
.816 .57763 Mdot
.816 .57764 Mdot
.816 .57765 Mdot
.816 .57765 Mdot
.816 .57765 Mdot
.816 .57765 Mdot
.816 .57767 Mdot
.816 .5777 Mdot
.816 .5777 Mdot
.816 .57774 Mdot
.816 .57775 Mdot
.816 .57776 Mdot
.816 .57776 Mdot
.816 .57777 Mdot
.816 .5778 Mdot
.816 .5778 Mdot
.816 .5778 Mdot
.816 .57783 Mdot
.816 .57784 Mdot
.816 .57786 Mdot
.816 .57788 Mdot
.816 .57788 Mdot
.816 .57792 Mdot
.816 .57794 Mdot
.816 .57794 Mdot
.816 .57796 Mdot
.816 .57801 Mdot
.816 .57802 Mdot
.816 .57806 Mdot
.816 .57809 Mdot
.816 .5781 Mdot
.816 .57814 Mdot
.816 .57815 Mdot
.816 .57816 Mdot
.816 .5782 Mdot
.816 .57821 Mdot
.816 .57823 Mdot
.816 .57828 Mdot
.816 .57833 Mdot
.816 .57836 Mdot
.816 .57843 Mdot
.816 .57847 Mdot
.816 .57848 Mdot
.816 .57849 Mdot
.816 .57852 Mdot
.816 .57855 Mdot
.816 .57856 Mdot
.816 .57857 Mdot
.816 .57859 Mdot
.816 .57862 Mdot
.816 .57862 Mdot
.816 .57865 Mdot
.816 .57868 Mdot
.816 .57871 Mdot
.816 .57873 Mdot
.816 .57875 Mdot
.816 .57876 Mdot
.816 .57879 Mdot
.816 .57887 Mdot
.816 .57889 Mdot
.816 .5789 Mdot
.816 .57894 Mdot
.816 .57896 Mdot
.816 .57899 Mdot
.816 .579 Mdot
.816 .57901 Mdot
.816 .57905 Mdot
.816 .5791 Mdot
.816 .57911 Mdot
.816 .57912 Mdot
.816 .57917 Mdot
.816 .57918 Mdot
.816 .57926 Mdot
.816 .57931 Mdot
.816 .57932 Mdot
.816 .57933 Mdot
.816 .57934 Mdot
.816 .57936 Mdot
.816 .5794 Mdot
.816 .57948 Mdot
.816 .57948 Mdot
.816 .57949 Mdot
.816 .57949 Mdot
.816 .57949 Mdot
.816 .57949 Mdot
.816 .57949 Mdot
.816 .5795 Mdot
.816 .57951 Mdot
.816 .57952 Mdot
.816 .57953 Mdot
.816 .57954 Mdot
.816 .57954 Mdot
.816 .57954 Mdot
.816 .57955 Mdot
.816 .57956 Mdot
.816 .57957 Mdot
.816 .57958 Mdot
.816 .57959 Mdot
.816 .57959 Mdot
.816 .5796 Mdot
.816 .57961 Mdot
.816 .57964 Mdot
.816 .57964 Mdot
.816 .57965 Mdot
.816 .57967 Mdot
.816 .57969 Mdot
.816 .57969 Mdot
.816 .5797 Mdot
.816 .57971 Mdot
.816 .57973 Mdot
.816 .57979 Mdot
.816 .5798 Mdot
.816 .57981 Mdot
.816 .57982 Mdot
.816 .57983 Mdot
.816 .57984 Mdot
.816 .57985 Mdot
.816 .57986 Mdot
.816 .57987 Mdot
.816 .57988 Mdot
.816 .57993 Mdot
.816 .57994 Mdot
.816 .57995 Mdot
.816 .57997 Mdot
.816 .58004 Mdot
.816 .58005 Mdot
.816 .58006 Mdot
.816 .58006 Mdot
.816 .58012 Mdot
.816 .58015 Mdot
.816 .58015 Mdot
.816 .58015 Mdot
.816 .58019 Mdot
.816 .58021 Mdot
.816 .58021 Mdot
.816 .58021 Mdot
.816 .58023 Mdot
.816 .58027 Mdot
.816 .5803 Mdot
.816 .58031 Mdot
.816 .58032 Mdot
.816 .58035 Mdot
.816 .58038 Mdot
.816 .58043 Mdot
.816 .58044 Mdot
.816 .58047 Mdot
.816 .58049 Mdot
.816 .58052 Mdot
.816 .58053 Mdot
.816 .58057 Mdot
.816 .58061 Mdot
.816 .58062 Mdot
.816 .58062 Mdot
.816 .58063 Mdot
.816 .58064 Mdot
.816 .5807 Mdot
.816 .58071 Mdot
.816 .58072 Mdot
.816 .58074 Mdot
.816 .58074 Mdot
.816 .58075 Mdot
.816 .58076 Mdot
.816 .58077 Mdot
.816 .58078 Mdot
.816 .58078 Mdot
.816 .58078 Mdot
.816 .58079 Mdot
.816 .58082 Mdot
.816 .58084 Mdot
.816 .58084 Mdot
.816 .58085 Mdot
.816 .58085 Mdot
.816 .58085 Mdot
.816 .58088 Mdot
.816 .58091 Mdot
.816 .58091 Mdot
.816 .58093 Mdot
.816 .58094 Mdot
.816 .58094 Mdot
.816 .58096 Mdot
.816 .58098 Mdot
.816 .58098 Mdot
.816 .58098 Mdot
.816 .581 Mdot
.816 .581 Mdot
.816 .58102 Mdot
.816 .58102 Mdot
.816 .58103 Mdot
.816 .58106 Mdot
.816 .58107 Mdot
.816 .58107 Mdot
.816 .58108 Mdot
.816 .58109 Mdot
.816 .5811 Mdot
.816 .58111 Mdot
.816 .58112 Mdot
.816 .58112 Mdot
.816 .58113 Mdot
.816 .58114 Mdot
.816 .58114 Mdot
.816 .58115 Mdot
.816 .58116 Mdot
.816 .58117 Mdot
.816 .58117 Mdot
.816 .58117 Mdot
.816 .58119 Mdot
.816 .58121 Mdot
.816 .58122 Mdot
.816 .58124 Mdot
.816 .58126 Mdot
.816 .58126 Mdot
.816 .58127 Mdot
.816 .58128 Mdot
.816 .58128 Mdot
.816 .58129 Mdot
.816 .5813 Mdot
.816 .5813 Mdot
.816 .58131 Mdot
.816 .58133 Mdot
.816 .58133 Mdot
.816 .58133 Mdot
.816 .58134 Mdot
.816 .58135 Mdot
.816 .58135 Mdot
.816 .58136 Mdot
.816 .58137 Mdot
.816 .58137 Mdot
.816 .58138 Mdot
.816 .58138 Mdot
.816 .58139 Mdot
.816 .5814 Mdot
.816 .5814 Mdot
.816 .5814 Mdot
.816 .58141 Mdot
.816 .58141 Mdot
.816 .58141 Mdot
.816 .58141 Mdot
.816 .58141 Mdot
.816 .58143 Mdot
.816 .58143 Mdot
.816 .58144 Mdot
.816 .58144 Mdot
.816 .58144 Mdot
.816 .58144 Mdot
.816 .58144 Mdot
.816 .58145 Mdot
.816 .58145 Mdot
.816 .58145 Mdot
.816 .58145 Mdot
.816 .58148 Mdot
.816 .5815 Mdot
.816 .5815 Mdot
.816 .58153 Mdot
.816 .58154 Mdot
.816 .58154 Mdot
.816 .58154 Mdot
.816 .58155 Mdot
.816 .58155 Mdot
.816 .58156 Mdot
.816 .58156 Mdot
.816 .58156 Mdot
.816 .58158 Mdot
.816 .58158 Mdot
.816 .58159 Mdot
.816 .5816 Mdot
.816 .5816 Mdot
.816 .58161 Mdot
.816 .58161 Mdot
.816 .58161 Mdot
.816 .58162 Mdot
.816 .58162 Mdot
.816 .58163 Mdot
.816 .58163 Mdot
.816 .58163 Mdot
.816 .58163 Mdot
.816 .58163 Mdot
.816 .58164 Mdot
.816 .58164 Mdot
.816 .58164 Mdot
.816 .58165 Mdot
.816 .58165 Mdot
.816 .58165 Mdot
.816 .58165 Mdot
.816 .58165 Mdot
.816 .58165 Mdot
.816 .58166 Mdot
.816 .58166 Mdot
.816 .58166 Mdot
.816 .58166 Mdot
.816 .58166 Mdot
.818 .09429 Mdot
.818 .09429 Mdot
.818 .09429 Mdot
.818 .09429 Mdot
.818 .09429 Mdot
.818 .09429 Mdot
.818 .0943 Mdot
.818 .0943 Mdot
.818 .0943 Mdot
.818 .0943 Mdot
.818 .09431 Mdot
.818 .09431 Mdot
.818 .09432 Mdot
.818 .09432 Mdot
.818 .09434 Mdot
.818 .09435 Mdot
.818 .09437 Mdot
.818 .09438 Mdot
.818 .09438 Mdot
.818 .09439 Mdot
.818 .09439 Mdot
.818 .0944 Mdot
.818 .09443 Mdot
.818 .09447 Mdot
.818 .09448 Mdot
.818 .09449 Mdot
.818 .0945 Mdot
.818 .0945 Mdot
.818 .0945 Mdot
.818 .09451 Mdot
.818 .09454 Mdot
.818 .09454 Mdot
.818 .09454 Mdot
.818 .09456 Mdot
.818 .0946 Mdot
.818 .0946 Mdot
.818 .09461 Mdot
.818 .09463 Mdot
.818 .09463 Mdot
.818 .09464 Mdot
.818 .09465 Mdot
.818 .09466 Mdot
.818 .09467 Mdot
.818 .09468 Mdot
.818 .09469 Mdot
.818 .09469 Mdot
.818 .0947 Mdot
.818 .0947 Mdot
.818 .09472 Mdot
.818 .09473 Mdot
.818 .09476 Mdot
.818 .09478 Mdot
.818 .09478 Mdot
.818 .09483 Mdot
.818 .09484 Mdot
.818 .09486 Mdot
.818 .09488 Mdot
.818 .09491 Mdot
.818 .09491 Mdot
.818 .09495 Mdot
.818 .09496 Mdot
.818 .09498 Mdot
.818 .09498 Mdot
.818 .09501 Mdot
.818 .09503 Mdot
.818 .09505 Mdot
.818 .09506 Mdot
.818 .09506 Mdot
.818 .09506 Mdot
.818 .09506 Mdot
.818 .09507 Mdot
.818 .09508 Mdot
.818 .09509 Mdot
.818 .0952 Mdot
.818 .09523 Mdot
.818 .09523 Mdot
.818 .09531 Mdot
.818 .09531 Mdot
.818 .09531 Mdot
.818 .0954 Mdot
.818 .09543 Mdot
.818 .09555 Mdot
.818 .09562 Mdot
.818 .09575 Mdot
.818 .09584 Mdot
.818 .09591 Mdot
.818 .09596 Mdot
.818 .09597 Mdot
.818 .09598 Mdot
.818 .09615 Mdot
.818 .09616 Mdot
.818 .09619 Mdot
.818 .09619 Mdot
.818 .09623 Mdot
.818 .0964 Mdot
.818 .09651 Mdot
.818 .09666 Mdot
.818 .09677 Mdot
.818 .0968 Mdot
.818 .09684 Mdot
.818 .09709 Mdot
.818 .09722 Mdot
.818 .09726 Mdot
.818 .09733 Mdot
.818 .09751 Mdot
.818 .09758 Mdot
.818 .09759 Mdot
.818 .09759 Mdot
.818 .0976 Mdot
.818 .0976 Mdot
.818 .09761 Mdot
.818 .09763 Mdot
.818 .09765 Mdot
.818 .0977 Mdot
.818 .09786 Mdot
.818 .09789 Mdot
.818 .09801 Mdot
.818 .09825 Mdot
.818 .09837 Mdot
.818 .0984 Mdot
.818 .09875 Mdot
.818 .09887 Mdot
.818 .09888 Mdot
.818 .09888 Mdot
.818 .09901 Mdot
.818 .09911 Mdot
.818 .09923 Mdot
.818 .0993 Mdot
.818 .09936 Mdot
.818 .09938 Mdot
.818 .09947 Mdot
.818 .09951 Mdot
.818 .09957 Mdot
.818 .09963 Mdot
.818 .09977 Mdot
.818 .09999 Mdot
.818 .10021 Mdot
.818 .10029 Mdot
.818 .10031 Mdot
.818 .10041 Mdot
.818 .10044 Mdot
.818 .10047 Mdot
.818 .10047 Mdot
.818 .10048 Mdot
.818 .10048 Mdot
.818 .10048 Mdot
.818 .10049 Mdot
.818 .10053 Mdot
.818 .1007 Mdot
.818 .10073 Mdot
.818 .10083 Mdot
.818 .10101 Mdot
.818 .10104 Mdot
.818 .10114 Mdot
.818 .10127 Mdot
.818 .1015 Mdot
.818 .10153 Mdot
.818 .10153 Mdot
.818 .10157 Mdot
.818 .10174 Mdot
.818 .10186 Mdot
.818 .10195 Mdot
.818 .10208 Mdot
.818 .10215 Mdot
.818 .10242 Mdot
.818 .10252 Mdot
.818 .10256 Mdot
.818 .10271 Mdot
.818 .10271 Mdot
.818 .10279 Mdot
.818 .10296 Mdot
.818 .103 Mdot
.818 .10317 Mdot
.818 .10318 Mdot
.818 .10321 Mdot
.818 .10327 Mdot
.818 .10331 Mdot
.818 .10332 Mdot
.818 .10336 Mdot
.818 .10337 Mdot
.818 .10339 Mdot
.818 .10342 Mdot
.818 .10344 Mdot
.818 .10345 Mdot
.818 .10347 Mdot
.818 .10349 Mdot
.818 .10353 Mdot
.818 .10365 Mdot
.818 .10366 Mdot
.818 .10373 Mdot
.818 .10376 Mdot
.818 .10384 Mdot
.818 .10395 Mdot
.818 .10407 Mdot
.818 .10409 Mdot
.818 .10414 Mdot
.818 .10431 Mdot
.818 .10442 Mdot
.818 .10443 Mdot
.818 .10456 Mdot
.818 .10461 Mdot
.818 .10461 Mdot
.818 .10478 Mdot
.818 .10485 Mdot
.818 .10495 Mdot
.818 .10497 Mdot
.818 .10498 Mdot
.818 .10501 Mdot
.818 .10511 Mdot
.818 .10518 Mdot
.818 .10525 Mdot
.818 .10548 Mdot
.818 .10557 Mdot
.818 .10561 Mdot
.818 .10567 Mdot
.818 .10595 Mdot
.818 .10597 Mdot
.818 .106 Mdot
.818 .10601 Mdot
.818 .10611 Mdot
.818 .10616 Mdot
.818 .10625 Mdot
.818 .10643 Mdot
.818 .10644 Mdot
.818 .1065 Mdot
.818 .10669 Mdot
.818 .1067 Mdot
.818 .10673 Mdot
.818 .10682 Mdot
.818 .10687 Mdot
.818 .1069 Mdot
.818 .10692 Mdot
.818 .10693 Mdot
.818 .10697 Mdot
.818 .10703 Mdot
.818 .10703 Mdot
.818 .10704 Mdot
.818 .10704 Mdot
.818 .10704 Mdot
.818 .10705 Mdot
.818 .10727 Mdot
.818 .10737 Mdot
.818 .10737 Mdot
.818 .10747 Mdot
.818 .10751 Mdot
.818 .10802 Mdot
.818 .10807 Mdot
.818 .10809 Mdot
.818 .10825 Mdot
.818 .10847 Mdot
.818 .10877 Mdot
.818 .10919 Mdot
.818 .1094 Mdot
.818 .10981 Mdot
.818 .10991 Mdot
.818 .11019 Mdot
.818 .11019 Mdot
.818 .11019 Mdot
.818 .11047 Mdot
.818 .11048 Mdot
.818 .11059 Mdot
.818 .11097 Mdot
.818 .11098 Mdot
.818 .11103 Mdot
.818 .11105 Mdot
.818 .11106 Mdot
.818 .11107 Mdot
.818 .11107 Mdot
.818 .1111 Mdot
.818 .11118 Mdot
.818 .11124 Mdot
.818 .11133 Mdot
.818 .11135 Mdot
.818 .1114 Mdot
.818 .11146 Mdot
.818 .11158 Mdot
.818 .11158 Mdot
.818 .11168 Mdot
.818 .11178 Mdot
.818 .11184 Mdot
.818 .11187 Mdot
.818 .11204 Mdot
.818 .11206 Mdot
.818 .11212 Mdot
.818 .11223 Mdot
.818 .11225 Mdot
.818 .11232 Mdot
.818 .11234 Mdot
.818 .11236 Mdot
.818 .11238 Mdot
.818 .1124 Mdot
.818 .11243 Mdot
.818 .11247 Mdot
.818 .11252 Mdot
.818 .11255 Mdot
.818 .11257 Mdot
.818 .1126 Mdot
.818 .11265 Mdot
.818 .1127 Mdot
.818 .11271 Mdot
.818 .11284 Mdot
.818 .11289 Mdot
.818 .11291 Mdot
.818 .11292 Mdot
.818 .11301 Mdot
.818 .11306 Mdot
.818 .11306 Mdot
.818 .11307 Mdot
.818 .11311 Mdot
.818 .11314 Mdot
.818 .11317 Mdot
.818 .11331 Mdot
.818 .11343 Mdot
.818 .11345 Mdot
.818 .11346 Mdot
.818 .11349 Mdot
.818 .11351 Mdot
.818 .11355 Mdot
.818 .11362 Mdot
.818 .11364 Mdot
.818 .11371 Mdot
.818 .11371 Mdot
.818 .11376 Mdot
.818 .11378 Mdot
.818 .11379 Mdot
.818 .11379 Mdot
.818 .1138 Mdot
.818 .11381 Mdot
.818 .11383 Mdot
.818 .11384 Mdot
.818 .11384 Mdot
.818 .11384 Mdot
.818 .11384 Mdot
.818 .11384 Mdot
.818 .27996 Mdot
.818 .27997 Mdot
.818 .27997 Mdot
.818 .27997 Mdot
.818 .27997 Mdot
.818 .27997 Mdot
.818 .27999 Mdot
.818 .28 Mdot
.818 .28 Mdot
.818 .28001 Mdot
.818 .28001 Mdot
.818 .28003 Mdot
.818 .28006 Mdot
.818 .28006 Mdot
.818 .28012 Mdot
.818 .28013 Mdot
.818 .28019 Mdot
.818 .28021 Mdot
.818 .28023 Mdot
.818 .28025 Mdot
.818 .28026 Mdot
.818 .28027 Mdot
.818 .28037 Mdot
.818 .28047 Mdot
.818 .2805 Mdot
.818 .28052 Mdot
.818 .28055 Mdot
.818 .28056 Mdot
.818 .28056 Mdot
.818 .28059 Mdot
.818 .28067 Mdot
.818 .28067 Mdot
.818 .28068 Mdot
.818 .28073 Mdot
.818 .28083 Mdot
.818 .28083 Mdot
.818 .28087 Mdot
.818 .28091 Mdot
.818 .28093 Mdot
.818 .28095 Mdot
.818 .28097 Mdot
.818 .28101 Mdot
.818 .28104 Mdot
.818 .28106 Mdot
.818 .28108 Mdot
.818 .2811 Mdot
.818 .28111 Mdot
.818 .28113 Mdot
.818 .28118 Mdot
.818 .2812 Mdot
.818 .28129 Mdot
.818 .28134 Mdot
.818 .28135 Mdot
.818 .28148 Mdot
.818 .28151 Mdot
.818 .28155 Mdot
.818 .28163 Mdot
.818 .28171 Mdot
.818 .28171 Mdot
.818 .28181 Mdot
.818 .28186 Mdot
.818 .2819 Mdot
.818 .28191 Mdot
.818 .28198 Mdot
.818 .28203 Mdot
.818 .2821 Mdot
.818 .28212 Mdot
.818 .28212 Mdot
.818 .28213 Mdot
.818 .28214 Mdot
.818 .28215 Mdot
.818 .28219 Mdot
.818 .2822 Mdot
.818 .28251 Mdot
.818 .2826 Mdot
.818 .28261 Mdot
.818 .28284 Mdot
.818 .28284 Mdot
.818 .28284 Mdot
.818 .28308 Mdot
.818 .28316 Mdot
.818 .2835 Mdot
.818 .28368 Mdot
.818 .28405 Mdot
.818 .28431 Mdot
.818 .2845 Mdot
.818 .28464 Mdot
.818 .28466 Mdot
.818 .28471 Mdot
.818 .28517 Mdot
.818 .2852 Mdot
.818 .28529 Mdot
.818 .28529 Mdot
.818 .28539 Mdot
.818 .28589 Mdot
.818 .28617 Mdot
.818 .28661 Mdot
.818 .2869 Mdot
.818 .287 Mdot
.818 .28708 Mdot
.818 .28779 Mdot
.818 .28815 Mdot
.818 .28827 Mdot
.818 .28845 Mdot
.818 .28896 Mdot
.818 .28914 Mdot
.818 .28916 Mdot
.818 .28919 Mdot
.818 .28919 Mdot
.818 .28921 Mdot
.818 .28924 Mdot
.818 .28928 Mdot
.818 .28933 Mdot
.818 .28948 Mdot
.818 .28991 Mdot
.818 .29 Mdot
.818 .29034 Mdot
.818 .291 Mdot
.818 .29134 Mdot
.818 .29142 Mdot
.818 .29239 Mdot
.818 .29272 Mdot
.818 .29273 Mdot
.818 .29273 Mdot
.818 .29308 Mdot
.818 .29338 Mdot
.818 .29369 Mdot
.818 .29389 Mdot
.818 .29406 Mdot
.818 .29411 Mdot
.818 .29437 Mdot
.818 .29447 Mdot
.818 .29464 Mdot
.818 .2948 Mdot
.818 .29519 Mdot
.818 .29579 Mdot
.818 .29639 Mdot
.818 .2966 Mdot
.818 .29666 Mdot
.818 .29693 Mdot
.818 .29703 Mdot
.818 .29708 Mdot
.818 .2971 Mdot
.818 .29712 Mdot
.818 .29712 Mdot
.818 .29714 Mdot
.818 .29716 Mdot
.818 .29727 Mdot
.818 .29774 Mdot
.818 .29782 Mdot
.818 .29807 Mdot
.818 .29858 Mdot
.818 .29864 Mdot
.818 .29893 Mdot
.818 .29927 Mdot
.818 .29991 Mdot
.818 .29999 Mdot
.818 .29999 Mdot
.818 .3001 Mdot
.818 .30054 Mdot
.818 .30087 Mdot
.818 .30112 Mdot
.818 .30148 Mdot
.818 .30167 Mdot
.818 .3024 Mdot
.818 .30268 Mdot
.818 .30278 Mdot
.818 .30318 Mdot
.818 .30319 Mdot
.818 .30341 Mdot
.818 .30386 Mdot
.818 .30398 Mdot
.818 .30442 Mdot
.818 .30445 Mdot
.818 .30453 Mdot
.818 .30468 Mdot
.818 .30481 Mdot
.818 .30483 Mdot
.818 .30493 Mdot
.818 .30496 Mdot
.818 .30503 Mdot
.818 .3051 Mdot
.818 .30515 Mdot
.818 .30517 Mdot
.818 .30523 Mdot
.818 .3053 Mdot
.818 .30539 Mdot
.818 .30571 Mdot
.818 .30574 Mdot
.818 .30592 Mdot
.818 .30601 Mdot
.818 .30623 Mdot
.818 .30653 Mdot
.818 .30685 Mdot
.818 .3069 Mdot
.818 .30702 Mdot
.818 .3075 Mdot
.818 .30778 Mdot
.818 .30781 Mdot
.818 .30815 Mdot
.818 .30828 Mdot
.818 .30829 Mdot
.818 .30874 Mdot
.818 .30894 Mdot
.818 .30921 Mdot
.818 .30925 Mdot
.818 .30927 Mdot
.818 .30935 Mdot
.818 .30962 Mdot
.818 .30981 Mdot
.818 .31 Mdot
.818 .31062 Mdot
.818 .31086 Mdot
.818 .31096 Mdot
.818 .31112 Mdot
.818 .31186 Mdot
.818 .31192 Mdot
.818 .31199 Mdot
.818 .31202 Mdot
.818 .31229 Mdot
.818 .31242 Mdot
.818 .31266 Mdot
.818 .31313 Mdot
.818 .31317 Mdot
.818 .31333 Mdot
.818 .31382 Mdot
.818 .31386 Mdot
.818 .31394 Mdot
.818 .31417 Mdot
.818 .31432 Mdot
.818 .31439 Mdot
.818 .31444 Mdot
.818 .31446 Mdot
.818 .31456 Mdot
.818 .31472 Mdot
.818 .31474 Mdot
.818 .31475 Mdot
.818 .31476 Mdot
.818 .31477 Mdot
.818 .31479 Mdot
.818 .31537 Mdot
.818 .31563 Mdot
.818 .31564 Mdot
.818 .31591 Mdot
.818 .31599 Mdot
.818 .31734 Mdot
.818 .31747 Mdot
.818 .31753 Mdot
.818 .31796 Mdot
.818 .31853 Mdot
.818 .31932 Mdot
.818 .32042 Mdot
.818 .32097 Mdot
.818 .32204 Mdot
.818 .32229 Mdot
.818 .32303 Mdot
.818 .32303 Mdot
.818 .32304 Mdot
.818 .32376 Mdot
.818 .32379 Mdot
.818 .32406 Mdot
.818 .32505 Mdot
.818 .32508 Mdot
.818 .32521 Mdot
.818 .32526 Mdot
.818 .32529 Mdot
.818 .32531 Mdot
.818 .32532 Mdot
.818 .32538 Mdot
.818 .3256 Mdot
.818 .32576 Mdot
.818 .326 Mdot
.818 .32603 Mdot
.818 .32616 Mdot
.818 .32632 Mdot
.818 .32664 Mdot
.818 .32664 Mdot
.818 .32689 Mdot
.818 .32715 Mdot
.818 .3273 Mdot
.818 .32738 Mdot
.818 .32781 Mdot
.818 .32786 Mdot
.818 .32803 Mdot
.818 .32831 Mdot
.818 .32836 Mdot
.818 .32854 Mdot
.818 .32859 Mdot
.818 .32865 Mdot
.818 .32871 Mdot
.818 .32876 Mdot
.818 .32882 Mdot
.818 .32893 Mdot
.818 .32906 Mdot
.818 .32915 Mdot
.818 .32918 Mdot
.818 .32927 Mdot
.818 .32939 Mdot
.818 .32952 Mdot
.818 .32954 Mdot
.818 .32988 Mdot
.818 .33002 Mdot
.818 .33007 Mdot
.818 .33007 Mdot
.818 .33032 Mdot
.818 .33044 Mdot
.818 .33045 Mdot
.818 .33048 Mdot
.818 .33058 Mdot
.818 .33065 Mdot
.818 .33072 Mdot
.818 .33107 Mdot
.818 .3314 Mdot
.818 .33145 Mdot
.818 .33146 Mdot
.818 .33156 Mdot
.818 .33161 Mdot
.818 .33169 Mdot
.818 .33187 Mdot
.818 .33193 Mdot
.818 .33211 Mdot
.818 .33212 Mdot
.818 .33223 Mdot
.818 .33228 Mdot
.818 .33231 Mdot
.818 .33233 Mdot
.818 .33233 Mdot
.818 .33237 Mdot
.818 .33242 Mdot
.818 .33243 Mdot
.818 .33243 Mdot
.818 .33244 Mdot
.818 .33244 Mdot
.818 .33245 Mdot
.818 .57637 Mdot
.818 .57637 Mdot
.818 .57637 Mdot
.818 .57637 Mdot
.818 .57637 Mdot
.818 .57637 Mdot
.818 .57638 Mdot
.818 .57638 Mdot
.818 .57638 Mdot
.818 .57638 Mdot
.818 .57639 Mdot
.818 .57639 Mdot
.818 .5764 Mdot
.818 .5764 Mdot
.818 .57642 Mdot
.818 .57643 Mdot
.818 .57645 Mdot
.818 .57646 Mdot
.818 .57647 Mdot
.818 .57648 Mdot
.818 .57648 Mdot
.818 .57648 Mdot
.818 .57652 Mdot
.818 .57656 Mdot
.818 .57657 Mdot
.818 .57658 Mdot
.818 .57659 Mdot
.818 .57659 Mdot
.818 .57659 Mdot
.818 .5766 Mdot
.818 .57663 Mdot
.818 .57663 Mdot
.818 .57664 Mdot
.818 .57665 Mdot
.818 .57669 Mdot
.818 .57669 Mdot
.818 .57671 Mdot
.818 .57672 Mdot
.818 .57673 Mdot
.818 .57673 Mdot
.818 .57674 Mdot
.818 .57676 Mdot
.818 .57677 Mdot
.818 .57678 Mdot
.818 .57678 Mdot
.818 .57679 Mdot
.818 .5768 Mdot
.818 .5768 Mdot
.818 .57682 Mdot
.818 .57683 Mdot
.818 .57686 Mdot
.818 .57688 Mdot
.818 .57688 Mdot
.818 .57693 Mdot
.818 .57694 Mdot
.818 .57696 Mdot
.818 .57698 Mdot
.818 .57701 Mdot
.818 .57701 Mdot
.818 .57705 Mdot
.818 .57706 Mdot
.818 .57708 Mdot
.818 .57708 Mdot
.818 .57711 Mdot
.818 .57713 Mdot
.818 .57715 Mdot
.818 .57716 Mdot
.818 .57716 Mdot
.818 .57716 Mdot
.818 .57716 Mdot
.818 .57717 Mdot
.818 .57718 Mdot
.818 .57719 Mdot
.818 .57729 Mdot
.818 .57732 Mdot
.818 .57733 Mdot
.818 .57741 Mdot
.818 .57741 Mdot
.818 .57741 Mdot
.818 .57749 Mdot
.818 .57752 Mdot
.818 .57763 Mdot
.818 .57769 Mdot
.818 .57781 Mdot
.818 .5779 Mdot
.818 .57796 Mdot
.818 .578 Mdot
.818 .57801 Mdot
.818 .57803 Mdot
.818 .57817 Mdot
.818 .57818 Mdot
.818 .57821 Mdot
.818 .57821 Mdot
.818 .57824 Mdot
.818 .5783 Mdot
.818 .5783 Mdot
.818 .5783 Mdot
.818 .5783 Mdot
.818 .5783 Mdot
.818 .57831 Mdot
.818 .57832 Mdot
.818 .57833 Mdot
.818 .57834 Mdot
.818 .57834 Mdot
.818 .57835 Mdot
.818 .57837 Mdot
.818 .57839 Mdot
.818 .5784 Mdot
.818 .5784 Mdot
.818 .57846 Mdot
.818 .57847 Mdot
.818 .57848 Mdot
.818 .57853 Mdot
.818 .57855 Mdot
.818 .57857 Mdot
.818 .5786 Mdot
.818 .5786 Mdot
.818 .57861 Mdot
.818 .57861 Mdot
.818 .57869 Mdot
.818 .57871 Mdot
.818 .57872 Mdot
.818 .57874 Mdot
.818 .57881 Mdot
.818 .57883 Mdot
.818 .57885 Mdot
.818 .57888 Mdot
.818 .57889 Mdot
.818 .57889 Mdot
.818 .57892 Mdot
.818 .57894 Mdot
.818 .57899 Mdot
.818 .57899 Mdot
.818 .57901 Mdot
.818 .57904 Mdot
.818 .57904 Mdot
.818 .57907 Mdot
.818 .57912 Mdot
.818 .57914 Mdot
.818 .57914 Mdot
.818 .57918 Mdot
.818 .57921 Mdot
.818 .57923 Mdot
.818 .57924 Mdot
.818 .57926 Mdot
.818 .57926 Mdot
.818 .5793 Mdot
.818 .57931 Mdot
.818 .57931 Mdot
.818 .57932 Mdot
.818 .57932 Mdot
.818 .57933 Mdot
.818 .57933 Mdot
.818 .57934 Mdot
.818 .57934 Mdot
.818 .57935 Mdot
.818 .57936 Mdot
.818 .57937 Mdot
.818 .57939 Mdot
.818 .5794 Mdot
.818 .5794 Mdot
.818 .57944 Mdot
.818 .57946 Mdot
.818 .5795 Mdot
.818 .57953 Mdot
.818 .57953 Mdot
.818 .57957 Mdot
.818 .57958 Mdot
.818 .57961 Mdot
.818 .57969 Mdot
.818 .5797 Mdot
.818 .57974 Mdot
.818 .57977 Mdot
.818 .5798 Mdot
.818 .57985 Mdot
.818 .57986 Mdot
.818 .57986 Mdot
.818 .57987 Mdot
.818 .57993 Mdot
.818 .57997 Mdot
.818 .58 Mdot
.818 .58001 Mdot
.818 .58006 Mdot
.818 .58008 Mdot
.818 .58009 Mdot
.818 .58014 Mdot
.818 .58015 Mdot
.818 .58015 Mdot
.818 .58016 Mdot
.818 .58016 Mdot
.818 .58016 Mdot
.818 .58016 Mdot
.818 .58017 Mdot
.818 .58018 Mdot
.818 .5802 Mdot
.818 .58021 Mdot
.818 .58023 Mdot
.818 .58029 Mdot
.818 .58036 Mdot
.818 .58039 Mdot
.818 .58041 Mdot
.818 .58043 Mdot
.818 .58044 Mdot
.818 .58047 Mdot
.818 .58047 Mdot
.818 .58049 Mdot
.818 .58051 Mdot
.818 .58054 Mdot
.818 .58057 Mdot
.818 .58061 Mdot
.818 .58061 Mdot
.818 .58061 Mdot
.818 .58064 Mdot
.818 .58074 Mdot
.818 .58075 Mdot
.818 .58078 Mdot
.818 .58085 Mdot
.818 .58088 Mdot
.818 .58089 Mdot
.818 .58094 Mdot
.818 .58095 Mdot
.818 .58096 Mdot
.818 .58096 Mdot
.818 .58097 Mdot
.818 .58097 Mdot
.818 .58097 Mdot
.818 .58097 Mdot
.818 .58097 Mdot
.818 .58099 Mdot
.818 .58104 Mdot
.818 .58106 Mdot
.818 .58107 Mdot
.818 .58111 Mdot
.818 .58118 Mdot
.818 .58119 Mdot
.818 .5812 Mdot
.818 .58123 Mdot
.818 .58127 Mdot
.818 .5813 Mdot
.818 .58135 Mdot
.818 .58136 Mdot
.818 .58136 Mdot
.818 .58137 Mdot
.818 .58137 Mdot
.818 .58142 Mdot
.818 .58142 Mdot
.818 .58143 Mdot
.818 .58144 Mdot
.818 .58146 Mdot
.818 .58149 Mdot
.818 .58152 Mdot
.818 .58154 Mdot
.818 .58158 Mdot
.818 .58158 Mdot
.818 .58161 Mdot
.818 .58161 Mdot
.818 .58161 Mdot
.818 .58163 Mdot
.818 .58163 Mdot
.818 .58164 Mdot
.818 .58167 Mdot
.818 .58167 Mdot
.818 .58168 Mdot
.818 .58168 Mdot
.818 .58168 Mdot
.818 .58168 Mdot
.818 .58168 Mdot
.818 .58168 Mdot
.818 .58169 Mdot
.818 .58169 Mdot
.818 .5817 Mdot
.818 .5817 Mdot
.818 .58171 Mdot
.818 .58171 Mdot
.818 .58172 Mdot
.818 .58172 Mdot
.818 .58173 Mdot
.818 .58174 Mdot
.818 .58174 Mdot
.818 .58174 Mdot
.818 .58176 Mdot
.818 .58176 Mdot
.818 .58176 Mdot
.818 .58177 Mdot
.818 .58177 Mdot
.818 .58178 Mdot
.818 .58178 Mdot
.818 .58178 Mdot
.818 .58178 Mdot
.818 .58178 Mdot
.818 .58179 Mdot
.818 .58179 Mdot
.818 .58179 Mdot
.818 .5818 Mdot
.818 .5818 Mdot
.818 .5818 Mdot
.818 .5818 Mdot
.818 .58181 Mdot
.818 .58181 Mdot
.818 .58182 Mdot
.818 .58182 Mdot
.818 .58182 Mdot
.818 .58182 Mdot
.818 .58183 Mdot
.818 .58183 Mdot
.818 .58184 Mdot
.818 .58184 Mdot
.818 .58184 Mdot
.818 .58184 Mdot
.818 .58184 Mdot
.818 .58185 Mdot
.818 .58186 Mdot
.818 .58186 Mdot
.818 .58187 Mdot
.818 .58187 Mdot
.818 .58187 Mdot
.818 .58187 Mdot
.818 .58188 Mdot
.818 .58188 Mdot
.818 .58188 Mdot
.818 .58188 Mdot
.818 .58189 Mdot
.818 .58189 Mdot
.818 .58189 Mdot
.818 .58189 Mdot
.818 .58189 Mdot
.818 .58189 Mdot
.818 .58189 Mdot
.818 .58189 Mdot
.818 .58189 Mdot
.818 .58189 Mdot
.818 .58189 Mdot
.818 .58189 Mdot
.82 .09348 Mdot
.82 .10489 Mdot
.82 .11328 Mdot
.82 .11606 Mdot
.82 .27779 Mdot
.82 .30916 Mdot
.82 .33114 Mdot
.82 .33823 Mdot
.82 .57574 Mdot
.82 .57654 Mdot
.82 .57892 Mdot
.82 .58213 Mdot
.822 .09267 Mdot
.822 .09267 Mdot
.822 .09267 Mdot
.822 .09267 Mdot
.822 .09267 Mdot
.822 .09268 Mdot
.822 .0927 Mdot
.822 .09273 Mdot
.822 .09274 Mdot
.822 .09274 Mdot
.822 .09276 Mdot
.822 .09277 Mdot
.822 .09278 Mdot
.822 .0928 Mdot
.822 .09281 Mdot
.822 .09283 Mdot
.822 .09285 Mdot
.822 .09294 Mdot
.822 .09296 Mdot
.822 .09297 Mdot
.822 .09298 Mdot
.822 .09312 Mdot
.822 .09313 Mdot
.822 .09316 Mdot
.822 .09322 Mdot
.822 .09322 Mdot
.822 .09327 Mdot
.822 .0933 Mdot
.822 .09339 Mdot
.822 .09343 Mdot
.822 .09362 Mdot
.822 .09363 Mdot
.822 .09382 Mdot
.822 .09383 Mdot
.822 .09384 Mdot
.822 .09397 Mdot
.822 .09403 Mdot
.822 .09409 Mdot
.822 .09409 Mdot
.822 .09414 Mdot
.822 .09418 Mdot
.822 .09432 Mdot
.822 .09433 Mdot
.822 .09436 Mdot
.822 .09445 Mdot
.822 .09451 Mdot
.822 .09456 Mdot
.822 .09459 Mdot
.822 .09479 Mdot
.822 .09483 Mdot
.822 .09516 Mdot
.822 .09519 Mdot
.822 .0953 Mdot
.822 .09538 Mdot
.822 .0954 Mdot
.822 .09544 Mdot
.822 .09548 Mdot
.822 .09555 Mdot
.822 .0959 Mdot
.822 .09616 Mdot
.822 .09639 Mdot
.822 .09639 Mdot
.822 .09643 Mdot
.822 .09702 Mdot
.822 .09709 Mdot
.822 .09718 Mdot
.822 .0972 Mdot
.822 .0973 Mdot
.822 .09739 Mdot
.822 .0976 Mdot
.822 .09768 Mdot
.822 .09775 Mdot
.822 .09787 Mdot
.822 .09823 Mdot
.822 .09839 Mdot
.822 .09843 Mdot
.822 .09855 Mdot
.822 .09857 Mdot
.822 .09872 Mdot
.822 .09894 Mdot
.822 .09903 Mdot
.822 .09929 Mdot
.822 .09936 Mdot
.822 .0994 Mdot
.822 .0996 Mdot
.822 .09966 Mdot
.822 .09972 Mdot
.822 .09976 Mdot
.822 .10011 Mdot
.822 .10014 Mdot
.822 .10045 Mdot
.822 .10069 Mdot
.822 .1008 Mdot
.822 .10081 Mdot
.822 .10095 Mdot
.822 .10098 Mdot
.822 .10127 Mdot
.822 .10144 Mdot
.822 .10164 Mdot
.822 .10196 Mdot
.822 .10202 Mdot
.822 .10217 Mdot
.822 .10218 Mdot
.822 .10218 Mdot
.822 .10241 Mdot
.822 .10243 Mdot
.822 .10267 Mdot
.822 .10273 Mdot
.822 .10286 Mdot
.822 .1029 Mdot
.822 .10298 Mdot
.822 .10317 Mdot
.822 .10344 Mdot
.822 .10376 Mdot
.822 .1038 Mdot
.822 .10399 Mdot
.822 .10457 Mdot
.822 .10461 Mdot
.822 .10484 Mdot
.822 .10496 Mdot
.822 .10496 Mdot
.822 .10538 Mdot
.822 .10546 Mdot
.822 .10552 Mdot
.822 .10556 Mdot
.822 .10566 Mdot
.822 .1061 Mdot
.822 .10613 Mdot
.822 .10644 Mdot
.822 .10771 Mdot
.822 .10776 Mdot
.822 .10781 Mdot
.822 .10795 Mdot
.822 .10796 Mdot
.822 .10807 Mdot
.822 .10813 Mdot
.822 .10817 Mdot
.822 .1084 Mdot
.822 .10879 Mdot
.822 .10889 Mdot
.822 .1094 Mdot
.822 .10955 Mdot
.822 .11004 Mdot
.822 .11016 Mdot
.822 .11028 Mdot
.822 .1108 Mdot
.822 .11089 Mdot
.822 .111 Mdot
.822 .11117 Mdot
.822 .11133 Mdot
.822 .11138 Mdot
.822 .11172 Mdot
.822 .11183 Mdot
.822 .11188 Mdot
.822 .11196 Mdot
.822 .11238 Mdot
.822 .11241 Mdot
.822 .11247 Mdot
.822 .11247 Mdot
.822 .11257 Mdot
.822 .11275 Mdot
.822 .11276 Mdot
.822 .11298 Mdot
.822 .1131 Mdot
.822 .11312 Mdot
.822 .11319 Mdot
.822 .1137 Mdot
.822 .11373 Mdot
.822 .11375 Mdot
.822 .11377 Mdot
.822 .11397 Mdot
.822 .11451 Mdot
.822 .11453 Mdot
.822 .1146 Mdot
.822 .11466 Mdot
.822 .11511 Mdot
.822 .11534 Mdot
.822 .1155 Mdot
.822 .11566 Mdot
.822 .11585 Mdot
.822 .11597 Mdot
.822 .116 Mdot
.822 .11619 Mdot
.822 .11619 Mdot
.822 .11637 Mdot
.822 .11644 Mdot
.822 .11659 Mdot
.822 .11663 Mdot
.822 .11676 Mdot
.822 .11691 Mdot
.822 .1171 Mdot
.822 .11721 Mdot
.822 .11725 Mdot
.822 .1173 Mdot
.822 .11738 Mdot
.822 .1174 Mdot
.822 .11749 Mdot
.822 .11775 Mdot
.822 .11781 Mdot
.822 .11782 Mdot
.822 .11793 Mdot
.822 .11798 Mdot
.822 .11806 Mdot
.822 .1181 Mdot
.822 .11814 Mdot
.822 .1182 Mdot
.822 .11824 Mdot
.822 .11827 Mdot
.822 .1184 Mdot
.822 .11849 Mdot
.822 .1185 Mdot
.822 .11851 Mdot
.822 .11851 Mdot
.822 .11851 Mdot
.822 .11852 Mdot
.822 .11882 Mdot
.822 .11904 Mdot
.822 .11906 Mdot
.822 .11952 Mdot
.822 .1197 Mdot
.822 .12 Mdot
.822 .12017 Mdot
.822 .12034 Mdot
.822 .12058 Mdot
.822 .12072 Mdot
.822 .12086 Mdot
.822 .12137 Mdot
.822 .12174 Mdot
.822 .12178 Mdot
.822 .12179 Mdot
.822 .12179 Mdot
.822 .12182 Mdot
.822 .12187 Mdot
.822 .12206 Mdot
.822 .12307 Mdot
.822 .124 Mdot
.822 .12407 Mdot
.822 .12599 Mdot
.822 .12621 Mdot
.822 .1268 Mdot
.822 .12809 Mdot
.822 .12859 Mdot
.822 .12882 Mdot
.822 .12959 Mdot
.822 .13068 Mdot
.822 .1313 Mdot
.822 .13195 Mdot
.822 .13268 Mdot
.822 .1343 Mdot
.822 .13606 Mdot
.822 .13626 Mdot
.822 .1363 Mdot
.822 .13631 Mdot
.822 .13646 Mdot
.822 .13663 Mdot
.822 .13669 Mdot
.822 .13764 Mdot
.822 .14262 Mdot
.822 .14563 Mdot
.822 .14743 Mdot
.822 .1478 Mdot
.822 .15062 Mdot
.822 .15827 Mdot
.822 .15955 Mdot
.822 .16193 Mdot
.822 .1629 Mdot
.822 .16718 Mdot
.822 .16767 Mdot
.822 .17051 Mdot
.822 .17193 Mdot
.822 .17354 Mdot
.822 .17498 Mdot
.822 .17804 Mdot
.822 .17968 Mdot
.822 .17974 Mdot
.822 .18056 Mdot
.822 .18266 Mdot
.822 .18318 Mdot
.822 .18662 Mdot
.822 .18775 Mdot
.822 .19063 Mdot
.822 .19253 Mdot
.822 .1949 Mdot
.822 .1955 Mdot
.822 .19972 Mdot
.822 .20417 Mdot
.822 .20622 Mdot
.822 .20759 Mdot
.822 .20767 Mdot
.822 .2107 Mdot
.822 .21527 Mdot
.822 .2229 Mdot
.822 .22431 Mdot
.822 .22464 Mdot
.822 .2247 Mdot
.822 .22574 Mdot
.822 .22699 Mdot
.822 .2272 Mdot
.822 .22736 Mdot
.822 .23035 Mdot
.822 .23421 Mdot
.822 .23674 Mdot
.822 .23723 Mdot
.822 .23792 Mdot
.822 .24197 Mdot
.822 .24369 Mdot
.822 .24537 Mdot
.822 .24556 Mdot
.822 .24668 Mdot
.822 .24729 Mdot
.822 .24965 Mdot
.822 .25134 Mdot
.822 .25368 Mdot
.822 .26085 Mdot
.822 .27089 Mdot
.822 .27561 Mdot
.822 .27562 Mdot
.822 .27562 Mdot
.822 .27562 Mdot
.822 .27562 Mdot
.822 .27563 Mdot
.822 .27569 Mdot
.822 .27577 Mdot
.822 .2758 Mdot
.822 .27582 Mdot
.822 .27586 Mdot
.822 .27589 Mdot
.822 .27592 Mdot
.822 .27597 Mdot
.822 .276 Mdot
.822 .27608 Mdot
.822 .27612 Mdot
.822 .27637 Mdot
.822 .27642 Mdot
.822 .27646 Mdot
.822 .27648 Mdot
.822 .27687 Mdot
.822 .2769 Mdot
.822 .27701 Mdot
.822 .27717 Mdot
.822 .27718 Mdot
.822 .2773 Mdot
.822 .27732 Mdot
.822 .27741 Mdot
.822 .27765 Mdot
.822 .27776 Mdot
.822 .27828 Mdot
.822 .27833 Mdot
.822 .27888 Mdot
.822 .27889 Mdot
.822 .27892 Mdot
.822 .2793 Mdot
.822 .27945 Mdot
.822 .27961 Mdot
.822 .27962 Mdot
.822 .27975 Mdot
.822 .27983 Mdot
.822 .27988 Mdot
.822 .28027 Mdot
.822 .28031 Mdot
.822 .28039 Mdot
.822 .28065 Mdot
.822 .28081 Mdot
.822 .28094 Mdot
.822 .28103 Mdot
.822 .2816 Mdot
.822 .2817 Mdot
.822 .28262 Mdot
.822 .28271 Mdot
.822 .28302 Mdot
.822 .28326 Mdot
.822 .2833 Mdot
.822 .28341 Mdot
.822 .28352 Mdot
.822 .28372 Mdot
.822 .28471 Mdot
.822 .28542 Mdot
.822 .28606 Mdot
.822 .28606 Mdot
.822 .28617 Mdot
.822 .28781 Mdot
.822 .288 Mdot
.822 .28826 Mdot
.822 .28832 Mdot
.822 .2886 Mdot
.822 .28886 Mdot
.822 .28943 Mdot
.822 .28965 Mdot
.822 .28984 Mdot
.822 .29019 Mdot
.822 .29037 Mdot
.822 .29115 Mdot
.822 .29118 Mdot
.822 .2916 Mdot
.822 .29173 Mdot
.822 .29206 Mdot
.822 .29211 Mdot
.822 .29253 Mdot
.822 .29314 Mdot
.822 .29333 Mdot
.822 .29339 Mdot
.822 .2936 Mdot
.822 .29411 Mdot
.822 .29429 Mdot
.822 .29439 Mdot
.822 .29496 Mdot
.822 .29511 Mdot
.822 .29529 Mdot
.822 .29539 Mdot
.822 .29635 Mdot
.822 .29642 Mdot
.822 .29727 Mdot
.822 .29793 Mdot
.822 .29823 Mdot
.822 .29826 Mdot
.822 .29865 Mdot
.822 .29872 Mdot
.822 .2995 Mdot
.822 .29997 Mdot
.822 .30052 Mdot
.822 .3014 Mdot
.822 .30156 Mdot
.822 .30195 Mdot
.822 .30199 Mdot
.822 .302 Mdot
.822 .30261 Mdot
.822 .30267 Mdot
.822 .30332 Mdot
.822 .30347 Mdot
.822 .30381 Mdot
.822 .30394 Mdot
.822 .30416 Mdot
.822 .30416 Mdot
.822 .30443 Mdot
.822 .30466 Mdot
.822 .30539 Mdot
.822 .30625 Mdot
.822 .30636 Mdot
.822 .30659 Mdot
.822 .30686 Mdot
.822 .30733 Mdot
.822 .30843 Mdot
.822 .30853 Mdot
.822 .30916 Mdot
.822 .30939 Mdot
.822 .30948 Mdot
.822 .30948 Mdot
.822 .31013 Mdot
.822 .3106 Mdot
.822 .3108 Mdot
.822 .31096 Mdot
.822 .31107 Mdot
.822 .31134 Mdot
.822 .31239 Mdot
.822 .31251 Mdot
.822 .31259 Mdot
.822 .31343 Mdot
.822 .31678 Mdot
.822 .3168 Mdot
.822 .31692 Mdot
.822 .31704 Mdot
.822 .3174 Mdot
.822 .31744 Mdot
.822 .31774 Mdot
.822 .31788 Mdot
.822 .31799 Mdot
.822 .31861 Mdot
.822 .31961 Mdot
.822 .31988 Mdot
.822 .31996 Mdot
.822 .32121 Mdot
.822 .32161 Mdot
.822 .32289 Mdot
.822 .32322 Mdot
.822 .32352 Mdot
.822 .32487 Mdot
.822 .32509 Mdot
.822 .32539 Mdot
.822 .32584 Mdot
.822 .32623 Mdot
.822 .32638 Mdot
.822 .32725 Mdot
.822 .32754 Mdot
.822 .32767 Mdot
.822 .32787 Mdot
.822 .32896 Mdot
.822 .32902 Mdot
.822 .32919 Mdot
.822 .3292 Mdot
.822 .32946 Mdot
.822 .3299 Mdot
.822 .32995 Mdot
.822 .33049 Mdot
.822 .33081 Mdot
.822 .33085 Mdot
.822 .33103 Mdot
.822 .3316 Mdot
.822 .33163 Mdot
.822 .33236 Mdot
.822 .33243 Mdot
.822 .33249 Mdot
.822 .33252 Mdot
.822 .33302 Mdot
.822 .33304 Mdot
.822 .33443 Mdot
.822 .33447 Mdot
.822 .33464 Mdot
.822 .33481 Mdot
.822 .33582 Mdot
.822 .33595 Mdot
.822 .33653 Mdot
.822 .33693 Mdot
.822 .33734 Mdot
.822 .33782 Mdot
.822 .33814 Mdot
.822 .33821 Mdot
.822 .33867 Mdot
.822 .33868 Mdot
.822 .33913 Mdot
.822 .3393 Mdot
.822 .33969 Mdot
.822 .3398 Mdot
.822 .34011 Mdot
.822 .34049 Mdot
.822 .34098 Mdot
.822 .34125 Mdot
.822 .34135 Mdot
.822 .34148 Mdot
.822 .34168 Mdot
.822 .34174 Mdot
.822 .34195 Mdot
.822 .34262 Mdot
.822 .34276 Mdot
.822 .34277 Mdot
.822 .34307 Mdot
.822 .34319 Mdot
.822 .34338 Mdot
.822 .34348 Mdot
.822 .34359 Mdot
.822 .34375 Mdot
.822 .34383 Mdot
.822 .34392 Mdot
.822 .34424 Mdot
.822 .34447 Mdot
.822 .34449 Mdot
.822 .3445 Mdot
.822 .3445 Mdot
.822 .34452 Mdot
.822 .34455 Mdot
.822 .34467 Mdot
.822 .34528 Mdot
.822 .34584 Mdot
.822 .34589 Mdot
.822 .34701 Mdot
.822 .34748 Mdot
.822 .34822 Mdot
.822 .3485 Mdot
.822 .34863 Mdot
.822 .34906 Mdot
.822 .34965 Mdot
.822 .34999 Mdot
.822 .35034 Mdot
.822 .35073 Mdot
.822 .35159 Mdot
.822 .3525 Mdot
.822 .3526 Mdot
.822 .35262 Mdot
.822 .35263 Mdot
.822 .3527 Mdot
.822 .35279 Mdot
.822 .35282 Mdot
.822 .3533 Mdot
.822 .35576 Mdot
.822 .35802 Mdot
.822 .35819 Mdot
.822 .35947 Mdot
.822 .36281 Mdot
.822 .36336 Mdot
.822 .36475 Mdot
.822 .3665 Mdot
.822 .36782 Mdot
.822 .36901 Mdot
.822 .36957 Mdot
.822 .37138 Mdot
.822 .37169 Mdot
.822 .37393 Mdot
.822 .37538 Mdot
.822 .3769 Mdot
.822 .37711 Mdot
.822 .37858 Mdot
.822 .38127 Mdot
.822 .38232 Mdot
.822 .38631 Mdot
.822 .38676 Mdot
.822 .38687 Mdot
.822 .38689 Mdot
.822 .38722 Mdot
.822 .38761 Mdot
.822 .38773 Mdot
.822 .38868 Mdot
.822 .38989 Mdot
.822 .39282 Mdot
.822 .39391 Mdot
.822 .39463 Mdot
.822 .39584 Mdot
.822 .39797 Mdot
.822 .40091 Mdot
.822 .40349 Mdot
.822 .40649 Mdot
.822 .40671 Mdot
.822 .40741 Mdot
.822 .41104 Mdot
.822 .41125 Mdot
.822 .41202 Mdot
.822 .41265 Mdot
.822 .41474 Mdot
.822 .41793 Mdot
.822 .41908 Mdot
.822 .42149 Mdot
.822 .42369 Mdot
.822 .42881 Mdot
.822 .43343 Mdot
.822 .43455 Mdot
.822 .43505 Mdot
.822 .43596 Mdot
.822 .43955 Mdot
.822 .44057 Mdot
.822 .44177 Mdot
.822 .44244 Mdot
.822 .44625 Mdot
.822 .44816 Mdot
.822 .44944 Mdot
.822 .44999 Mdot
.822 .45052 Mdot
.822 .45114 Mdot
.822 .45143 Mdot
.822 .45212 Mdot
.822 .45313 Mdot
.822 .45548 Mdot
.822 .45664 Mdot
.822 .45894 Mdot
.822 .45919 Mdot
.822 .46208 Mdot
.822 .46461 Mdot
.822 .46569 Mdot
.822 .46686 Mdot
.822 .46894 Mdot
.822 .46994 Mdot
.822 .4707 Mdot
.822 .47273 Mdot
.822 .47283 Mdot
.822 .47422 Mdot
.822 .47675 Mdot
.822 .47772 Mdot
.822 .47827 Mdot
.822 .47859 Mdot
.822 .47908 Mdot
.822 .48093 Mdot
.822 .48418 Mdot
.822 .48599 Mdot
.822 .48831 Mdot
.822 .4905 Mdot
.822 .49344 Mdot
.822 .49618 Mdot
.822 .49701 Mdot
.822 .49792 Mdot
.822 .49946 Mdot
.822 .50297 Mdot
.822 .50407 Mdot
.822 .50461 Mdot
.822 .50462 Mdot
.822 .50911 Mdot
.822 .51031 Mdot
.822 .51198 Mdot
.822 .51283 Mdot
.822 .5131 Mdot
.822 .51387 Mdot
.822 .51415 Mdot
.822 .51495 Mdot
.822 .51505 Mdot
.822 .51892 Mdot
.822 .51902 Mdot
.822 .51981 Mdot
.822 .52009 Mdot
.822 .52387 Mdot
.822 .52476 Mdot
.822 .52702 Mdot
.822 .53051 Mdot
.822 .53296 Mdot
.822 .53376 Mdot
.822 .53433 Mdot
.822 .53513 Mdot
.822 .53534 Mdot
.822 .53571 Mdot
.822 .53578 Mdot
.822 .53634 Mdot
.822 .53692 Mdot
.822 .53827 Mdot
.822 .5385 Mdot
.822 .53866 Mdot
.822 .5395 Mdot
.822 .54077 Mdot
.822 .54176 Mdot
.822 .54181 Mdot
.822 .54188 Mdot
.822 .54229 Mdot
.822 .54263 Mdot
.822 .54264 Mdot
.822 .54276 Mdot
.822 .54321 Mdot
.822 .54569 Mdot
.822 .54715 Mdot
.822 .54812 Mdot
.822 .54815 Mdot
.822 .54859 Mdot
.822 .54924 Mdot
.822 .55065 Mdot
.822 .55197 Mdot
.822 .55216 Mdot
.822 .55291 Mdot
.822 .5535 Mdot
.822 .5544 Mdot
.822 .55475 Mdot
.822 .55581 Mdot
.822 .55598 Mdot
.822 .55662 Mdot
.822 .55688 Mdot
.822 .55689 Mdot
.822 .5574 Mdot
.822 .55834 Mdot
.822 .55878 Mdot
.822 .55927 Mdot
.822 .5597 Mdot
.822 .56056 Mdot
.822 .56071 Mdot
.822 .56201 Mdot
.822 .5623 Mdot
.822 .56301 Mdot
.822 .5634 Mdot
.822 .56568 Mdot
.822 .56652 Mdot
.822 .56663 Mdot
.822 .56716 Mdot
.822 .56805 Mdot
.822 .56951 Mdot
.822 .56979 Mdot
.822 .56981 Mdot
.822 .56986 Mdot
.822 .5699 Mdot
.822 .5699 Mdot
.822 .56992 Mdot
.822 .56997 Mdot
.822 .57049 Mdot
.822 .57096 Mdot
.822 .57117 Mdot
.822 .57136 Mdot
.822 .57154 Mdot
.822 .57186 Mdot
.822 .57208 Mdot
.822 .57215 Mdot
.822 .57229 Mdot
.822 .57267 Mdot
.822 .57284 Mdot
.822 .5729 Mdot
.822 .57346 Mdot
.822 .57348 Mdot
.822 .57374 Mdot
.822 .57403 Mdot
.822 .57409 Mdot
.822 .5741 Mdot
.822 .57411 Mdot
.822 .57411 Mdot
.822 .57412 Mdot
.822 .57413 Mdot
.822 .57423 Mdot
.822 .57438 Mdot
.822 .57442 Mdot
.822 .57446 Mdot
.822 .57453 Mdot
.822 .57458 Mdot
.822 .57463 Mdot
.822 .57471 Mdot
.822 .57477 Mdot
.822 .5749 Mdot
.822 .5749 Mdot
.822 .57497 Mdot
.822 .57505 Mdot
.822 .57505 Mdot
.822 .57506 Mdot
.822 .57506 Mdot
.822 .57506 Mdot
.822 .57506 Mdot
.822 .57509 Mdot
.822 .57512 Mdot
.822 .57513 Mdot
.822 .57514 Mdot
.822 .57516 Mdot
.822 .57517 Mdot
.822 .57519 Mdot
.822 .57521 Mdot
.822 .57522 Mdot
.822 .57525 Mdot
.822 .57526 Mdot
.822 .57527 Mdot
.822 .57535 Mdot
.822 .57537 Mdot
.822 .57538 Mdot
.822 .5754 Mdot
.822 .57542 Mdot
.822 .57543 Mdot
.822 .57546 Mdot
.822 .57551 Mdot
.822 .57556 Mdot
.822 .57559 Mdot
.822 .57561 Mdot
.822 .57565 Mdot
.822 .57567 Mdot
.822 .57572 Mdot
.822 .57572 Mdot
.822 .57577 Mdot
.822 .57578 Mdot
.822 .57582 Mdot
.822 .57587 Mdot
.822 .57592 Mdot
.822 .57596 Mdot
.822 .57603 Mdot
.822 .57616 Mdot
.822 .57618 Mdot
.822 .57619 Mdot
.822 .5762 Mdot
.822 .57635 Mdot
.822 .57641 Mdot
.822 .57642 Mdot
.822 .57642 Mdot
.822 .57643 Mdot
.822 .57658 Mdot
.822 .5766 Mdot
.822 .5766 Mdot
.822 .57664 Mdot
.822 .5767 Mdot
.822 .5767 Mdot
.822 .57675 Mdot
.822 .57678 Mdot
.822 .57678 Mdot
.822 .5768 Mdot
.822 .57681 Mdot
.822 .57693 Mdot
.822 .57695 Mdot
.822 .57696 Mdot
.822 .577 Mdot
.822 .57709 Mdot
.822 .57711 Mdot
.822 .57715 Mdot
.822 .5772 Mdot
.822 .57723 Mdot
.822 .57726 Mdot
.822 .5774 Mdot
.822 .57744 Mdot
.822 .57747 Mdot
.822 .57761 Mdot
.822 .57766 Mdot
.822 .5778 Mdot
.822 .57783 Mdot
.822 .57794 Mdot
.822 .578 Mdot
.822 .57802 Mdot
.822 .57803 Mdot
.822 .57806 Mdot
.822 .57807 Mdot
.822 .57811 Mdot
.822 .57812 Mdot
.822 .57813 Mdot
.822 .57849 Mdot
.822 .57858 Mdot
.822 .57859 Mdot
.822 .57871 Mdot
.822 .57874 Mdot
.822 .57875 Mdot
.822 .57877 Mdot
.822 .57879 Mdot
.822 .57891 Mdot
.822 .57891 Mdot
.822 .57895 Mdot
.822 .57901 Mdot
.822 .57902 Mdot
.822 .57919 Mdot
.822 .57924 Mdot
.822 .57925 Mdot
.822 .57934 Mdot
.822 .57942 Mdot
.822 .57947 Mdot
.822 .57949 Mdot
.822 .57951 Mdot
.822 .57954 Mdot
.822 .57956 Mdot
.822 .57963 Mdot
.822 .57963 Mdot
.822 .5797 Mdot
.822 .5797 Mdot
.822 .5797 Mdot
.822 .57974 Mdot
.822 .57976 Mdot
.822 .57985 Mdot
.822 .57991 Mdot
.822 .57995 Mdot
.822 .58004 Mdot
.822 .58004 Mdot
.822 .58008 Mdot
.822 .58009 Mdot
.822 .58012 Mdot
.822 .58019 Mdot
.822 .58027 Mdot
.822 .58028 Mdot
.822 .58038 Mdot
.822 .58039 Mdot
.822 .58041 Mdot
.822 .58042 Mdot
.822 .58048 Mdot
.822 .58049 Mdot
.822 .58051 Mdot
.822 .58058 Mdot
.822 .58061 Mdot
.822 .58067 Mdot
.822 .58071 Mdot
.822 .58072 Mdot
.822 .58075 Mdot
.822 .58076 Mdot
.822 .58081 Mdot
.822 .58091 Mdot
.822 .58094 Mdot
.822 .58096 Mdot
.822 .58099 Mdot
.822 .58104 Mdot
.822 .58107 Mdot
.822 .5811 Mdot
.822 .5811 Mdot
.822 .58113 Mdot
.822 .58115 Mdot
.822 .58131 Mdot
.822 .58132 Mdot
.822 .58133 Mdot
.822 .58139 Mdot
.822 .58146 Mdot
.822 .58156 Mdot
.822 .58158 Mdot
.822 .58159 Mdot
.822 .5816 Mdot
.822 .58161 Mdot
.822 .58163 Mdot
.822 .58166 Mdot
.822 .58167 Mdot
.822 .58176 Mdot
.822 .58177 Mdot
.822 .58183 Mdot
.822 .58184 Mdot
.822 .58185 Mdot
.822 .58187 Mdot
.822 .58189 Mdot
.822 .5819 Mdot
.822 .5819 Mdot
.822 .58194 Mdot
.822 .58196 Mdot
.822 .58197 Mdot
.822 .58197 Mdot
.822 .58199 Mdot
.822 .582 Mdot
.822 .58204 Mdot
.822 .58204 Mdot
.822 .58204 Mdot
.822 .5821 Mdot
.822 .5821 Mdot
.822 .58215 Mdot
.822 .58216 Mdot
.822 .58219 Mdot
.822 .5822 Mdot
.822 .58221 Mdot
.822 .58221 Mdot
.822 .58223 Mdot
.822 .58224 Mdot
.822 .58224 Mdot
.822 .58228 Mdot
.822 .58228 Mdot
.822 .58228 Mdot
.822 .58229 Mdot
.822 .58231 Mdot
.822 .58232 Mdot
.822 .58233 Mdot
.822 .58233 Mdot
.822 .58233 Mdot
.822 .58234 Mdot
.822 .58234 Mdot
.822 .58234 Mdot
.822 .58235 Mdot
.822 .58235 Mdot
.822 .58236 Mdot
.822 .58236 Mdot
.822 .58236 Mdot
.822 .58236 Mdot
.822 .58236 Mdot
.822 .58236 Mdot
.822 .58236 Mdot
.824 .09186 Mdot
.824 .09187 Mdot
.824 .09187 Mdot
.824 .09189 Mdot
.824 .09189 Mdot
.824 .09192 Mdot
.824 .09193 Mdot
.824 .09194 Mdot
.824 .09194 Mdot
.824 .09195 Mdot
.824 .09195 Mdot
.824 .09196 Mdot
.824 .09201 Mdot
.824 .09201 Mdot
.824 .09202 Mdot
.824 .09204 Mdot
.824 .09206 Mdot
.824 .09237 Mdot
.824 .0924 Mdot
.824 .09246 Mdot
.824 .09248 Mdot
.824 .09265 Mdot
.824 .09268 Mdot
.824 .09274 Mdot
.824 .0928 Mdot
.824 .09283 Mdot
.824 .09284 Mdot
.824 .093 Mdot
.824 .093 Mdot
.824 .09306 Mdot
.824 .09318 Mdot
.824 .09325 Mdot
.824 .09327 Mdot
.824 .09333 Mdot
.824 .0934 Mdot
.824 .09345 Mdot
.824 .09351 Mdot
.824 .09354 Mdot
.824 .09361 Mdot
.824 .09363 Mdot
.824 .09369 Mdot
.824 .09369 Mdot
.824 .09385 Mdot
.824 .09404 Mdot
.824 .09405 Mdot
.824 .09437 Mdot
.824 .09449 Mdot
.824 .09452 Mdot
.824 .09458 Mdot
.824 .0948 Mdot
.824 .09496 Mdot
.824 .09504 Mdot
.824 .09513 Mdot
.824 .09513 Mdot
.824 .09523 Mdot
.824 .09526 Mdot
.824 .0954 Mdot
.824 .09543 Mdot
.824 .09547 Mdot
.824 .09555 Mdot
.824 .09592 Mdot
.824 .09596 Mdot
.824 .09631 Mdot
.824 .0964 Mdot
.824 .09641 Mdot
.824 .09642 Mdot
.824 .09675 Mdot
.824 .09692 Mdot
.824 .09697 Mdot
.824 .09726 Mdot
.824 .09765 Mdot
.824 .09781 Mdot
.824 .09804 Mdot
.824 .09933 Mdot
.824 .09961 Mdot
.824 .09966 Mdot
.824 .09989 Mdot
.824 .10019 Mdot
.824 .10021 Mdot
.824 .1003 Mdot
.824 .10032 Mdot
.824 .10038 Mdot
.824 .10045 Mdot
.824 .1006 Mdot
.824 .10154 Mdot
.824 .10161 Mdot
.824 .10174 Mdot
.824 .10197 Mdot
.824 .10216 Mdot
.824 .10216 Mdot
.824 .1024 Mdot
.824 .10254 Mdot
.824 .10301 Mdot
.824 .10372 Mdot
.824 .10377 Mdot
.824 .10379 Mdot
.824 .10396 Mdot
.824 .104 Mdot
.824 .10403 Mdot
.824 .10428 Mdot
.824 .10446 Mdot
.824 .10467 Mdot
.824 .10506 Mdot
.824 .10518 Mdot
.824 .10537 Mdot
.824 .10546 Mdot
.824 .10548 Mdot
.824 .10585 Mdot
.824 .10654 Mdot
.824 .10665 Mdot
.824 .10692 Mdot
.824 .10705 Mdot
.824 .10716 Mdot
.824 .10717 Mdot
.824 .10763 Mdot
.824 .10766 Mdot
.824 .10772 Mdot
.824 .10784 Mdot
.824 .10801 Mdot
.824 .10807 Mdot
.824 .10807 Mdot
.824 .10821 Mdot
.824 .10838 Mdot
.824 .10839 Mdot
.824 .10864 Mdot
.824 .10873 Mdot
.824 .10876 Mdot
.824 .1088 Mdot
.824 .10908 Mdot
.824 .1092 Mdot
.824 .10943 Mdot
.824 .11 Mdot
.824 .11002 Mdot
.824 .11021 Mdot
.824 .11033 Mdot
.824 .11049 Mdot
.824 .11078 Mdot
.824 .1109 Mdot
.824 .11165 Mdot
.824 .11196 Mdot
.824 .11197 Mdot
.824 .112 Mdot
.824 .11249 Mdot
.824 .11257 Mdot
.824 .11266 Mdot
.824 .11273 Mdot
.824 .11333 Mdot
.824 .11335 Mdot
.824 .11336 Mdot
.824 .11361 Mdot
.824 .11368 Mdot
.824 .11396 Mdot
.824 .1141 Mdot
.824 .11433 Mdot
.824 .11454 Mdot
.824 .1147 Mdot
.824 .11476 Mdot
.824 .11482 Mdot
.824 .11493 Mdot
.824 .11505 Mdot
.824 .11506 Mdot
.824 .11516 Mdot
.824 .11527 Mdot
.824 .11544 Mdot
.824 .11559 Mdot
.824 .11571 Mdot
.824 .11594 Mdot
.824 .11618 Mdot
.824 .1162 Mdot
.824 .11642 Mdot
.824 .11687 Mdot
.824 .1169 Mdot
.824 .11696 Mdot
.824 .11705 Mdot
.824 .11708 Mdot
.824 .11727 Mdot
.824 .11741 Mdot
.824 .11753 Mdot
.824 .1177 Mdot
.824 .11804 Mdot
.824 .1184 Mdot
.824 .1185 Mdot
.824 .11879 Mdot
.824 .11892 Mdot
.824 .11906 Mdot
.824 .11929 Mdot
.824 .11939 Mdot
.824 .12029 Mdot
.824 .12041 Mdot
.824 .12049 Mdot
.824 .12051 Mdot
.824 .12052 Mdot
.824 .12075 Mdot
.824 .12079 Mdot
.824 .12081 Mdot
.824 .12082 Mdot
.824 .12082 Mdot
.824 .12083 Mdot
.824 .12088 Mdot
.824 .12093 Mdot
.824 .12096 Mdot
.824 .12106 Mdot
.824 .12108 Mdot
.824 .12115 Mdot
.824 .12117 Mdot
.824 .12122 Mdot
.824 .12122 Mdot
.824 .12242 Mdot
.824 .12294 Mdot
.824 .12325 Mdot
.824 .12352 Mdot
.824 .12394 Mdot
.824 .1245 Mdot
.824 .12495 Mdot
.824 .12854 Mdot
.824 .12888 Mdot
.824 .12889 Mdot
.824 .1294 Mdot
.824 .12976 Mdot
.824 .12989 Mdot
.824 .12993 Mdot
.824 .13052 Mdot
.824 .13098 Mdot
.824 .13115 Mdot
.824 .13124 Mdot
.824 .13129 Mdot
.824 .1313 Mdot
.824 .13134 Mdot
.824 .13155 Mdot
.824 .13178 Mdot
.824 .13195 Mdot
.824 .13223 Mdot
.824 .13239 Mdot
.824 .13248 Mdot
.824 .13282 Mdot
.824 .13289 Mdot
.824 .13292 Mdot
.824 .13313 Mdot
.824 .13316 Mdot
.824 .13477 Mdot
.824 .13495 Mdot
.824 .13892 Mdot
.824 .13912 Mdot
.824 .14107 Mdot
.824 .1413 Mdot
.824 .14152 Mdot
.824 .14311 Mdot
.824 .1445 Mdot
.824 .14451 Mdot
.824 .14669 Mdot
.824 .14787 Mdot
.824 .14831 Mdot
.824 .14969 Mdot
.824 .15212 Mdot
.824 .15252 Mdot
.824 .15331 Mdot
.824 .16546 Mdot
.824 .16756 Mdot
.824 .16863 Mdot
.824 .17138 Mdot
.824 .17294 Mdot
.824 .17503 Mdot
.824 .1751 Mdot
.824 .17685 Mdot
.824 .18051 Mdot
.824 .18131 Mdot
.824 .18157 Mdot
.824 .18377 Mdot
.824 .18535 Mdot
.824 .18655 Mdot
.824 .18793 Mdot
.824 .18828 Mdot
.824 .18847 Mdot
.824 .18945 Mdot
.824 .19001 Mdot
.824 .19031 Mdot
.824 .19042 Mdot
.824 .19065 Mdot
.824 .19203 Mdot
.824 .19212 Mdot
.824 .19352 Mdot
.824 .19466 Mdot
.824 .1965 Mdot
.824 .1976 Mdot
.824 .19814 Mdot
.824 .19894 Mdot
.824 .20043 Mdot
.824 .20093 Mdot
.824 .20101 Mdot
.824 .20111 Mdot
.824 .20256 Mdot
.824 .20274 Mdot
.824 .20691 Mdot
.824 .21377 Mdot
.824 .21502 Mdot
.824 .21748 Mdot
.824 .22031 Mdot
.824 .23329 Mdot
.824 .23879 Mdot
.824 .24339 Mdot
.824 .24491 Mdot
.824 .25929 Mdot
.824 .25949 Mdot
.824 .26104 Mdot
.824 .26268 Mdot
.824 .26363 Mdot
.824 .26573 Mdot
.824 .26896 Mdot
.824 .26914 Mdot
.824 .27218 Mdot
.824 .27341 Mdot
.824 .27345 Mdot
.824 .27346 Mdot
.824 .2735 Mdot
.824 .27351 Mdot
.824 .27359 Mdot
.824 .27362 Mdot
.824 .27365 Mdot
.824 .27366 Mdot
.824 .27367 Mdot
.824 .27368 Mdot
.824 .2737 Mdot
.824 .27384 Mdot
.824 .27385 Mdot
.824 .27387 Mdot
.824 .27392 Mdot
.824 .27399 Mdot
.824 .27462 Mdot
.824 .27486 Mdot
.824 .27494 Mdot
.824 .27513 Mdot
.824 .27519 Mdot
.824 .27565 Mdot
.824 .27576 Mdot
.824 .27593 Mdot
.824 .27605 Mdot
.824 .27608 Mdot
.824 .27617 Mdot
.824 .2762 Mdot
.824 .27664 Mdot
.824 .27666 Mdot
.824 .27682 Mdot
.824 .27716 Mdot
.824 .27735 Mdot
.824 .27743 Mdot
.824 .27759 Mdot
.824 .27767 Mdot
.824 .27778 Mdot
.824 .27793 Mdot
.824 .27809 Mdot
.824 .27819 Mdot
.824 .27838 Mdot
.824 .27844 Mdot
.824 .27861 Mdot
.824 .27862 Mdot
.824 .27906 Mdot
.824 .27912 Mdot
.824 .2796 Mdot
.824 .27963 Mdot
.824 .28051 Mdot
.824 .28086 Mdot
.824 .28095 Mdot
.824 .2811 Mdot
.824 .28174 Mdot
.824 .28206 Mdot
.824 .28219 Mdot
.824 .28239 Mdot
.824 .28265 Mdot
.824 .28265 Mdot
.824 .28294 Mdot
.824 .28301 Mdot
.824 .28341 Mdot
.824 .2835 Mdot
.824 .28361 Mdot
.824 .28385 Mdot
.824 .28487 Mdot
.824 .28497 Mdot
.824 .28513 Mdot
.824 .28524 Mdot
.824 .28596 Mdot
.824 .2862 Mdot
.824 .28623 Mdot
.824 .28626 Mdot
.824 .28718 Mdot
.824 .28764 Mdot
.824 .28779 Mdot
.824 .2886 Mdot
.824 .28969 Mdot
.824 .29013 Mdot
.824 .29076 Mdot
.824 .29433 Mdot
.824 .29509 Mdot
.824 .29524 Mdot
.824 .29586 Mdot
.824 .29668 Mdot
.824 .29674 Mdot
.824 .29698 Mdot
.824 .29703 Mdot
.824 .29722 Mdot
.824 .29738 Mdot
.824 .29782 Mdot
.824 .30038 Mdot
.824 .30055 Mdot
.824 .30064 Mdot
.824 .30092 Mdot
.824 .30152 Mdot
.824 .30187 Mdot
.824 .30204 Mdot
.824 .30206 Mdot
.824 .3027 Mdot
.824 .30309 Mdot
.824 .30436 Mdot
.824 .30626 Mdot
.824 .3064 Mdot
.824 .30645 Mdot
.824 .30646 Mdot
.824 .30692 Mdot
.824 .30701 Mdot
.824 .30709 Mdot
.824 .30777 Mdot
.824 .30827 Mdot
.824 .30882 Mdot
.824 .30986 Mdot
.824 .31019 Mdot
.824 .31068 Mdot
.824 .31081 Mdot
.824 .31093 Mdot
.824 .31098 Mdot
.824 .31196 Mdot
.824 .3138 Mdot
.824 .31409 Mdot
.824 .31418 Mdot
.824 .31481 Mdot
.824 .31516 Mdot
.824 .31545 Mdot
.824 .31548 Mdot
.824 .3167 Mdot
.824 .31678 Mdot
.824 .31693 Mdot
.824 .31725 Mdot
.824 .3177 Mdot
.824 .31785 Mdot
.824 .31786 Mdot
.824 .31823 Mdot
.824 .31866 Mdot
.824 .31868 Mdot
.824 .31935 Mdot
.824 .3196 Mdot
.824 .31967 Mdot
.824 .31977 Mdot
.824 .32052 Mdot
.824 .32082 Mdot
.824 .32142 Mdot
.824 .32156 Mdot
.824 .32223 Mdot
.824 .32292 Mdot
.824 .32296 Mdot
.824 .32345 Mdot
.824 .32378 Mdot
.824 .32419 Mdot
.824 .32474 Mdot
.824 .32495 Mdot
.824 .32525 Mdot
.824 .32688 Mdot
.824 .32721 Mdot
.824 .32753 Mdot
.824 .32788 Mdot
.824 .328 Mdot
.824 .32802 Mdot
.824 .3281 Mdot
.824 .32817 Mdot
.824 .32936 Mdot
.824 .32957 Mdot
.824 .3298 Mdot
.824 .33 Mdot
.824 .33 Mdot
.824 .33154 Mdot
.824 .33159 Mdot
.824 .33161 Mdot
.824 .33224 Mdot
.824 .33243 Mdot
.824 .33315 Mdot
.824 .33349 Mdot
.824 .33409 Mdot
.824 .33463 Mdot
.824 .33504 Mdot
.824 .33519 Mdot
.824 .33533 Mdot
.824 .3355 Mdot
.824 .33563 Mdot
.824 .33592 Mdot
.824 .33594 Mdot
.824 .3362 Mdot
.824 .33647 Mdot
.824 .33692 Mdot
.824 .3373 Mdot
.824 .33761 Mdot
.824 .33818 Mdot
.824 .33841 Mdot
.824 .33879 Mdot
.824 .33885 Mdot
.824 .3394 Mdot
.824 .34041 Mdot
.824 .34053 Mdot
.824 .34061 Mdot
.824 .34076 Mdot
.824 .34098 Mdot
.824 .34106 Mdot
.824 .34154 Mdot
.824 .3419 Mdot
.824 .3422 Mdot
.824 .34261 Mdot
.824 .34326 Mdot
.824 .34348 Mdot
.824 .34437 Mdot
.824 .34446 Mdot
.824 .34462 Mdot
.824 .34535 Mdot
.824 .34566 Mdot
.824 .34601 Mdot
.824 .34626 Mdot
.824 .34659 Mdot
.824 .34685 Mdot
.824 .34908 Mdot
.824 .34936 Mdot
.824 .34956 Mdot
.824 .34963 Mdot
.824 .34965 Mdot
.824 .34997 Mdot
.824 .35022 Mdot
.824 .35031 Mdot
.824 .35036 Mdot
.824 .35039 Mdot
.824 .3504 Mdot
.824 .35041 Mdot
.824 .35053 Mdot
.824 .35065 Mdot
.824 .35074 Mdot
.824 .35089 Mdot
.824 .35097 Mdot
.824 .35102 Mdot
.824 .3512 Mdot
.824 .35124 Mdot
.824 .35125 Mdot
.824 .35136 Mdot
.824 .35138 Mdot
.824 .35221 Mdot
.824 .35431 Mdot
.824 .35547 Mdot
.824 .35558 Mdot
.824 .35634 Mdot
.824 .35699 Mdot
.824 .35801 Mdot
.824 .35937 Mdot
.824 .36046 Mdot
.824 .36063 Mdot
.824 .36098 Mdot
.824 .36608 Mdot
.824 .36692 Mdot
.824 .36735 Mdot
.824 .36843 Mdot
.824 .36904 Mdot
.824 .36985 Mdot
.824 .36987 Mdot
.824 .37054 Mdot
.824 .37192 Mdot
.824 .37222 Mdot
.824 .37231 Mdot
.824 .3737 Mdot
.824 .37414 Mdot
.824 .37477 Mdot
.824 .37484 Mdot
.824 .37519 Mdot
.824 .37539 Mdot
.824 .3755 Mdot
.824 .37554 Mdot
.824 .37562 Mdot
.824 .37611 Mdot
.824 .37614 Mdot
.824 .37664 Mdot
.824 .37704 Mdot
.824 .37768 Mdot
.824 .37807 Mdot
.824 .37826 Mdot
.824 .37853 Mdot
.824 .37905 Mdot
.824 .37922 Mdot
.824 .37928 Mdot
.824 .37977 Mdot
.824 .37984 Mdot
.824 .38125 Mdot
.824 .38353 Mdot
.824 .38394 Mdot
.824 .38566 Mdot
.824 .38978 Mdot
.824 .39148 Mdot
.824 .39289 Mdot
.824 .39336 Mdot
.824 .39766 Mdot
.824 .39818 Mdot
.824 .39866 Mdot
.824 .39894 Mdot
.824 .39955 Mdot
.824 .40049 Mdot
.824 .40143 Mdot
.824 .40213 Mdot
.824 .40343 Mdot
.824 .40514 Mdot
.824 .40517 Mdot
.824 .4095 Mdot
.824 .40985 Mdot
.824 .41233 Mdot
.824 .41326 Mdot
.824 .41616 Mdot
.824 .41675 Mdot
.824 .42121 Mdot
.824 .42202 Mdot
.824 .42303 Mdot
.824 .42327 Mdot
.824 .42363 Mdot
.824 .43075 Mdot
.824 .4338 Mdot
.824 .4363 Mdot
.824 .43698 Mdot
.824 .43919 Mdot
.824 .44595 Mdot
.824 .44684 Mdot
.824 .44747 Mdot
.824 .44966 Mdot
.824 .45141 Mdot
.824 .45291 Mdot
.824 .45338 Mdot
.824 .45691 Mdot
.824 .45805 Mdot
.824 .4584 Mdot
.824 .45966 Mdot
.824 .4612 Mdot
.824 .4649 Mdot
.824 .46502 Mdot
.824 .46806 Mdot
.824 .4715 Mdot
.824 .47433 Mdot
.824 .47525 Mdot
.824 .47567 Mdot
.824 .4761 Mdot
.824 .47638 Mdot
.824 .47975 Mdot
.824 .48051 Mdot
.824 .48233 Mdot
.824 .48426 Mdot
.824 .48544 Mdot
.824 .48647 Mdot
.824 .48703 Mdot
.824 .48733 Mdot
.824 .48886 Mdot
.824 .48975 Mdot
.824 .49021 Mdot
.824 .49039 Mdot
.824 .49074 Mdot
.824 .49287 Mdot
.824 .49301 Mdot
.824 .49514 Mdot
.824 .49647 Mdot
.824 .49686 Mdot
.824 .49701 Mdot
.824 .49738 Mdot
.824 .49888 Mdot
.824 .4996 Mdot
.824 .50008 Mdot
.824 .50121 Mdot
.824 .502 Mdot
.824 .50315 Mdot
.824 .5053 Mdot
.824 .50601 Mdot
.824 .50612 Mdot
.824 .50625 Mdot
.824 .50651 Mdot
.824 .50733 Mdot
.824 .50829 Mdot
.824 .50855 Mdot
.824 .51135 Mdot
.824 .51262 Mdot
.824 .51425 Mdot
.824 .51594 Mdot
.824 .51639 Mdot
.824 .52198 Mdot
.824 .52202 Mdot
.824 .52312 Mdot
.824 .52416 Mdot
.824 .52468 Mdot
.824 .52575 Mdot
.824 .5266 Mdot
.824 .52767 Mdot
.824 .52773 Mdot
.824 .52886 Mdot
.824 .52958 Mdot
.824 .52991 Mdot
.824 .53048 Mdot
.824 .53101 Mdot
.824 .53108 Mdot
.824 .53596 Mdot
.824 .53647 Mdot
.824 .53801 Mdot
.824 .53984 Mdot
.824 .54408 Mdot
.824 .545 Mdot
.824 .54579 Mdot
.824 .5462 Mdot
.824 .54839 Mdot
.824 .54972 Mdot
.824 .54977 Mdot
.824 .55023 Mdot
.824 .55026 Mdot
.824 .55029 Mdot
.824 .55045 Mdot
.824 .55092 Mdot
.824 .55117 Mdot
.824 .55134 Mdot
.824 .55168 Mdot
.824 .55226 Mdot
.824 .55262 Mdot
.824 .55306 Mdot
.824 .55309 Mdot
.824 .55352 Mdot
.824 .55359 Mdot
.824 .55362 Mdot
.824 .55371 Mdot
.824 .55389 Mdot
.824 .5542 Mdot
.824 .55425 Mdot
.824 .55436 Mdot
.824 .55479 Mdot
.824 .55516 Mdot
.824 .55565 Mdot
.824 .55633 Mdot
.824 .55641 Mdot
.824 .55666 Mdot
.824 .55778 Mdot
.824 .55832 Mdot
.824 .55834 Mdot
.824 .55898 Mdot
.824 .55945 Mdot
.824 .56029 Mdot
.824 .56061 Mdot
.824 .56125 Mdot
.824 .5649 Mdot
.824 .56513 Mdot
.824 .56525 Mdot
.824 .56598 Mdot
.824 .56639 Mdot
.824 .56652 Mdot
.824 .56686 Mdot
.824 .56751 Mdot
.824 .56751 Mdot
.824 .56792 Mdot
.824 .56839 Mdot
.824 .56845 Mdot
.824 .56852 Mdot
.824 .56909 Mdot
.824 .56915 Mdot
.824 .57031 Mdot
.824 .57037 Mdot
.824 .57083 Mdot
.824 .57084 Mdot
.824 .57091 Mdot
.824 .57091 Mdot
.824 .57093 Mdot
.824 .57103 Mdot
.824 .57106 Mdot
.824 .57111 Mdot
.824 .57119 Mdot
.824 .57124 Mdot
.824 .5713 Mdot
.824 .57136 Mdot
.824 .57137 Mdot
.824 .57138 Mdot
.824 .57139 Mdot
.824 .57142 Mdot
.824 .57147 Mdot
.824 .5716 Mdot
.824 .57177 Mdot
.824 .57179 Mdot
.824 .57182 Mdot
.824 .57193 Mdot
.824 .57208 Mdot
.824 .57208 Mdot
.824 .57218 Mdot
.824 .57322 Mdot
.824 .57335 Mdot
.824 .57351 Mdot
.824 .57363 Mdot
.824 .57371 Mdot
.824 .5738 Mdot
.824 .57395 Mdot
.824 .57429 Mdot
.824 .57429 Mdot
.824 .5743 Mdot
.824 .57431 Mdot
.824 .57433 Mdot
.824 .57434 Mdot
.824 .57436 Mdot
.824 .57437 Mdot
.824 .57439 Mdot
.824 .5744 Mdot
.824 .5744 Mdot
.824 .5744 Mdot
.824 .57441 Mdot
.824 .57441 Mdot
.824 .57442 Mdot
.824 .57449 Mdot
.824 .57449 Mdot
.824 .5745 Mdot
.824 .57452 Mdot
.824 .57456 Mdot
.824 .57481 Mdot
.824 .57484 Mdot
.824 .57491 Mdot
.824 .57495 Mdot
.824 .57499 Mdot
.824 .57507 Mdot
.824 .5751 Mdot
.824 .5752 Mdot
.824 .5753 Mdot
.824 .57535 Mdot
.824 .57538 Mdot
.824 .57542 Mdot
.824 .57548 Mdot
.824 .57549 Mdot
.824 .57551 Mdot
.824 .57553 Mdot
.824 .57554 Mdot
.824 .57567 Mdot
.824 .57573 Mdot
.824 .57573 Mdot
.824 .5758 Mdot
.824 .57587 Mdot
.824 .5759 Mdot
.824 .57595 Mdot
.824 .576 Mdot
.824 .57603 Mdot
.824 .57606 Mdot
.824 .57606 Mdot
.824 .57609 Mdot
.824 .57612 Mdot
.824 .57614 Mdot
.824 .57616 Mdot
.824 .5762 Mdot
.824 .57626 Mdot
.824 .57633 Mdot
.824 .57637 Mdot
.824 .57645 Mdot
.824 .57647 Mdot
.824 .57654 Mdot
.824 .57654 Mdot
.824 .57655 Mdot
.824 .57672 Mdot
.824 .57674 Mdot
.824 .57677 Mdot
.824 .57679 Mdot
.824 .57693 Mdot
.824 .57694 Mdot
.824 .57694 Mdot
.824 .57703 Mdot
.824 .57724 Mdot
.824 .57727 Mdot
.824 .57736 Mdot
.824 .5774 Mdot
.824 .57744 Mdot
.824 .57749 Mdot
.824 .57749 Mdot
.824 .57766 Mdot
.824 .57772 Mdot
.824 .57776 Mdot
.824 .57784 Mdot
.824 .57785 Mdot
.824 .57785 Mdot
.824 .57788 Mdot
.824 .57795 Mdot
.824 .57796 Mdot
.824 .578 Mdot
.824 .57804 Mdot
.824 .57804 Mdot
.824 .57806 Mdot
.824 .57811 Mdot
.824 .57814 Mdot
.824 .57816 Mdot
.824 .57817 Mdot
.824 .5783 Mdot
.824 .5783 Mdot
.824 .57833 Mdot
.824 .57837 Mdot
.824 .57845 Mdot
.824 .57848 Mdot
.824 .57867 Mdot
.824 .57878 Mdot
.824 .57878 Mdot
.824 .57881 Mdot
.824 .57886 Mdot
.824 .5789 Mdot
.824 .57901 Mdot
.824 .57906 Mdot
.824 .57912 Mdot
.824 .57919 Mdot
.824 .5792 Mdot
.824 .5792 Mdot
.824 .57925 Mdot
.824 .57926 Mdot
.824 .57927 Mdot
.824 .57947 Mdot
.824 .57961 Mdot
.824 .57965 Mdot
.824 .57971 Mdot
.824 .57971 Mdot
.824 .57977 Mdot
.824 .57983 Mdot
.824 .57987 Mdot
.824 .57989 Mdot
.824 .58015 Mdot
.824 .5802 Mdot
.824 .58021 Mdot
.824 .58023 Mdot
.824 .58024 Mdot
.824 .58026 Mdot
.824 .58027 Mdot
.824 .58035 Mdot
.824 .58042 Mdot
.824 .58043 Mdot
.824 .58051 Mdot
.824 .58087 Mdot
.824 .58094 Mdot
.824 .58098 Mdot
.824 .58109 Mdot
.824 .58117 Mdot
.824 .58119 Mdot
.824 .58123 Mdot
.824 .58133 Mdot
.824 .58133 Mdot
.824 .58133 Mdot
.824 .58136 Mdot
.824 .58146 Mdot
.824 .58147 Mdot
.824 .58157 Mdot
.824 .58159 Mdot
.824 .5816 Mdot
.824 .58161 Mdot
.824 .58165 Mdot
.824 .58166 Mdot
.824 .58169 Mdot
.824 .58169 Mdot
.824 .58171 Mdot
.824 .58173 Mdot
.824 .58178 Mdot
.824 .58184 Mdot
.824 .58186 Mdot
.824 .58187 Mdot
.824 .5819 Mdot
.824 .58199 Mdot
.824 .58199 Mdot
.824 .58204 Mdot
.824 .58209 Mdot
.824 .58209 Mdot
.824 .58211 Mdot
.824 .58211 Mdot
.824 .58213 Mdot
.824 .58214 Mdot
.824 .58216 Mdot
.824 .58217 Mdot
.824 .58219 Mdot
.824 .58221 Mdot
.824 .58221 Mdot
.824 .58223 Mdot
.824 .58227 Mdot
.824 .58228 Mdot
.824 .58228 Mdot
.824 .58233 Mdot
.824 .58233 Mdot
.824 .58234 Mdot
.824 .58235 Mdot
.824 .58237 Mdot
.824 .58238 Mdot
.824 .58243 Mdot
.824 .58243 Mdot
.824 .58245 Mdot
.824 .58246 Mdot
.824 .58254 Mdot
.824 .58255 Mdot
.824 .58256 Mdot
.824 .58256 Mdot
.824 .58256 Mdot
.824 .58257 Mdot
.824 .58257 Mdot
.824 .58258 Mdot
.824 .58258 Mdot
.824 .58258 Mdot
.824 .58258 Mdot
.824 .58258 Mdot
.824 .58259 Mdot
.824 .58259 Mdot
.824 .5826 Mdot
.824 .5826 Mdot
.824 .5826 Mdot
.826 .09104 Mdot
.826 .09105 Mdot
.826 .09105 Mdot
.826 .09109 Mdot
.826 .09112 Mdot
.826 .09115 Mdot
.826 .09117 Mdot
.826 .0912 Mdot
.826 .09121 Mdot
.826 .09133 Mdot
.826 .09136 Mdot
.826 .09138 Mdot
.826 .09141 Mdot
.826 .09142 Mdot
.826 .09144 Mdot
.826 .09149 Mdot
.826 .09156 Mdot
.826 .09156 Mdot
.826 .09159 Mdot
.826 .09166 Mdot
.826 .09172 Mdot
.826 .09178 Mdot
.826 .0918 Mdot
.826 .09181 Mdot
.826 .09196 Mdot
.826 .09208 Mdot
.826 .09209 Mdot
.826 .09213 Mdot
.826 .09216 Mdot
.826 .09218 Mdot
.826 .09238 Mdot
.826 .0924 Mdot
.826 .09246 Mdot
.826 .0925 Mdot
.826 .09259 Mdot
.826 .09259 Mdot
.826 .0926 Mdot
.826 .09261 Mdot
.826 .09266 Mdot
.826 .09269 Mdot
.826 .09277 Mdot
.826 .09285 Mdot
.826 .09307 Mdot
.826 .09315 Mdot
.826 .0932 Mdot
.826 .09325 Mdot
.826 .09346 Mdot
.826 .0936 Mdot
.826 .0936 Mdot
.826 .09405 Mdot
.826 .09415 Mdot
.826 .09444 Mdot
.826 .09445 Mdot
.826 .09453 Mdot
.826 .0947 Mdot
.826 .09483 Mdot
.826 .0949 Mdot
.826 .09496 Mdot
.826 .09516 Mdot
.826 .09523 Mdot
.826 .09541 Mdot
.826 .09545 Mdot
.826 .09587 Mdot
.826 .09636 Mdot
.826 .09641 Mdot
.826 .09682 Mdot
.826 .09686 Mdot
.826 .0969 Mdot
.826 .09721 Mdot
.826 .09736 Mdot
.826 .09753 Mdot
.826 .09762 Mdot
.826 .09777 Mdot
.826 .09797 Mdot
.826 .09798 Mdot
.826 .09805 Mdot
.826 .09839 Mdot
.826 .09848 Mdot
.826 .09859 Mdot
.826 .09874 Mdot
.826 .09891 Mdot
.826 .09893 Mdot
.826 .09942 Mdot
.826 .09968 Mdot
.826 .09978 Mdot
.826 .10002 Mdot
.826 .10046 Mdot
.826 .10085 Mdot
.826 .10096 Mdot
.826 .1012 Mdot
.826 .10146 Mdot
.826 .10163 Mdot
.826 .10168 Mdot
.826 .10168 Mdot
.826 .10179 Mdot
.826 .1019 Mdot
.826 .10222 Mdot
.826 .10279 Mdot
.826 .10296 Mdot
.826 .10296 Mdot
.826 .10308 Mdot
.826 .10317 Mdot
.826 .10324 Mdot
.826 .10341 Mdot
.826 .10418 Mdot
.826 .10473 Mdot
.826 .10551 Mdot
.826 .10565 Mdot
.826 .10607 Mdot
.826 .10611 Mdot
.826 .1062 Mdot
.826 .1065 Mdot
.826 .1067 Mdot
.826 .1068 Mdot
.826 .10682 Mdot
.826 .10684 Mdot
.826 .10703 Mdot
.826 .10731 Mdot
.826 .10755 Mdot
.826 .10761 Mdot
.826 .10774 Mdot
.826 .10784 Mdot
.826 .10792 Mdot
.826 .10819 Mdot
.826 .10835 Mdot
.826 .10863 Mdot
.826 .10924 Mdot
.826 .10924 Mdot
.826 .10954 Mdot
.826 .10957 Mdot
.826 .10987 Mdot
.826 .11068 Mdot
.826 .11091 Mdot
.826 .11104 Mdot
.826 .1115 Mdot
.826 .11199 Mdot
.826 .11252 Mdot
.826 .11262 Mdot
.826 .11272 Mdot
.826 .11279 Mdot
.826 .11281 Mdot
.826 .11302 Mdot
.826 .11329 Mdot
.826 .11337 Mdot
.826 .11346 Mdot
.826 .11374 Mdot
.826 .1142 Mdot
.826 .1144 Mdot
.826 .11453 Mdot
.826 .1146 Mdot
.826 .11463 Mdot
.826 .11464 Mdot
.826 .11479 Mdot
.826 .11487 Mdot
.826 .11489 Mdot
.826 .11496 Mdot
.826 .11589 Mdot
.826 .11621 Mdot
.826 .11636 Mdot
.826 .11639 Mdot
.826 .11641 Mdot
.826 .11658 Mdot
.826 .1167 Mdot
.826 .11691 Mdot
.826 .11694 Mdot
.826 .11699 Mdot
.826 .11701 Mdot
.826 .11701 Mdot
.826 .1174 Mdot
.826 .11757 Mdot
.826 .11785 Mdot
.826 .11791 Mdot
.826 .1181 Mdot
.826 .11831 Mdot
.826 .11882 Mdot
.826 .11891 Mdot
.826 .11904 Mdot
.826 .11907 Mdot
.826 .11921 Mdot
.826 .11925 Mdot
.826 .11984 Mdot
.826 .11991 Mdot
.826 .12049 Mdot
.826 .12057 Mdot
.826 .12064 Mdot
.826 .12094 Mdot
.826 .1212 Mdot
.826 .12154 Mdot
.826 .12167 Mdot
.826 .1217 Mdot
.826 .122 Mdot
.826 .122 Mdot
.826 .12224 Mdot
.826 .12233 Mdot
.826 .12237 Mdot
.826 .1224 Mdot
.826 .12255 Mdot
.826 .12264 Mdot
.826 .12279 Mdot
.826 .1229 Mdot
.826 .12306 Mdot
.826 .12336 Mdot
.826 .12342 Mdot
.826 .12357 Mdot
.826 .12363 Mdot
.826 .12363 Mdot
.826 .12381 Mdot
.826 .12382 Mdot
.826 .12395 Mdot
.826 .12413 Mdot
.826 .12414 Mdot
.826 .12417 Mdot
.826 .12531 Mdot
.826 .12636 Mdot
.826 .12668 Mdot
.826 .12927 Mdot
.826 .12965 Mdot
.826 .12997 Mdot
.826 .13136 Mdot
.826 .13255 Mdot
.826 .13341 Mdot
.826 .13418 Mdot
.826 .13483 Mdot
.826 .13493 Mdot
.826 .13641 Mdot
.826 .13642 Mdot
.826 .13693 Mdot
.826 .13711 Mdot
.826 .1376 Mdot
.826 .13803 Mdot
.826 .13825 Mdot
.826 .13841 Mdot
.826 .13895 Mdot
.826 .13914 Mdot
.826 .1396 Mdot
.826 .14034 Mdot
.826 .14093 Mdot
.826 .14101 Mdot
.826 .14173 Mdot
.826 .14328 Mdot
.826 .14359 Mdot
.826 .14434 Mdot
.826 .14466 Mdot
.826 .14468 Mdot
.826 .14564 Mdot
.826 .14565 Mdot
.826 .14636 Mdot
.826 .14672 Mdot
.826 .14731 Mdot
.826 .14738 Mdot
.826 .14753 Mdot
.826 .14851 Mdot
.826 .14986 Mdot
.826 .15373 Mdot
.826 .15971 Mdot
.826 .16015 Mdot
.826 .16152 Mdot
.826 .16248 Mdot
.826 .1638 Mdot
.826 .16497 Mdot
.826 .17006 Mdot
.826 .17388 Mdot
.826 .17439 Mdot
.826 .1768 Mdot
.826 .1771 Mdot
.826 .17718 Mdot
.826 .17959 Mdot
.826 .18157 Mdot
.826 .18295 Mdot
.826 .18669 Mdot
.826 .18927 Mdot
.826 .19 Mdot
.826 .19054 Mdot
.826 .19067 Mdot
.826 .19798 Mdot
.826 .19844 Mdot
.826 .20119 Mdot
.826 .20122 Mdot
.826 .20385 Mdot
.826 .20425 Mdot
.826 .20594 Mdot
.826 .20955 Mdot
.826 .21404 Mdot
.826 .21479 Mdot
.826 .21536 Mdot
.826 .22519 Mdot
.826 .22527 Mdot
.826 .22534 Mdot
.826 .22647 Mdot
.826 .22892 Mdot
.826 .23022 Mdot
.826 .23057 Mdot
.826 .23378 Mdot
.826 .2369 Mdot
.826 .2385 Mdot
.826 .23851 Mdot
.826 .23962 Mdot
.826 .24218 Mdot
.826 .24242 Mdot
.826 .24268 Mdot
.826 .2436 Mdot
.826 .24497 Mdot
.826 .24726 Mdot
.826 .24837 Mdot
.826 .25384 Mdot
.826 .25826 Mdot
.826 .25887 Mdot
.826 .26335 Mdot
.826 .26426 Mdot
.826 .26435 Mdot
.826 .26614 Mdot
.826 .27119 Mdot
.826 .27121 Mdot
.826 .27122 Mdot
.826 .27132 Mdot
.826 .2714 Mdot
.826 .27151 Mdot
.826 .27155 Mdot
.826 .27163 Mdot
.826 .27167 Mdot
.826 .27201 Mdot
.826 .27209 Mdot
.826 .27215 Mdot
.826 .27223 Mdot
.826 .27228 Mdot
.826 .27233 Mdot
.826 .27248 Mdot
.826 .27266 Mdot
.826 .27267 Mdot
.826 .27275 Mdot
.826 .27296 Mdot
.826 .27312 Mdot
.826 .2733 Mdot
.826 .27334 Mdot
.826 .27339 Mdot
.826 .27379 Mdot
.826 .27416 Mdot
.826 .27419 Mdot
.826 .2743 Mdot
.826 .27438 Mdot
.826 .27443 Mdot
.826 .27501 Mdot
.826 .27505 Mdot
.826 .27523 Mdot
.826 .27534 Mdot
.826 .27559 Mdot
.826 .2756 Mdot
.826 .27564 Mdot
.826 .27566 Mdot
.826 .2758 Mdot
.826 .27588 Mdot
.826 .27599 Mdot
.826 .276 Mdot
.826 .27612 Mdot
.826 .27633 Mdot
.826 .27696 Mdot
.826 .27718 Mdot
.826 .27721 Mdot
.826 .27734 Mdot
.826 .27748 Mdot
.826 .27799 Mdot
.826 .27805 Mdot
.826 .2783 Mdot
.826 .27845 Mdot
.826 .27847 Mdot
.826 .27973 Mdot
.826 .28 Mdot
.826 .28061 Mdot
.826 .28084 Mdot
.826 .28087 Mdot
.826 .28109 Mdot
.826 .28157 Mdot
.826 .28192 Mdot
.826 .28213 Mdot
.826 .28228 Mdot
.826 .28286 Mdot
.826 .28304 Mdot
.826 .28355 Mdot
.826 .28367 Mdot
.826 .28402 Mdot
.826 .28483 Mdot
.826 .2862 Mdot
.826 .28635 Mdot
.826 .28645 Mdot
.826 .28662 Mdot
.826 .28749 Mdot
.826 .2876 Mdot
.826 .28771 Mdot
.826 .28857 Mdot
.826 .28898 Mdot
.826 .28945 Mdot
.826 .28956 Mdot
.826 .28971 Mdot
.826 .29012 Mdot
.826 .29068 Mdot
.826 .29071 Mdot
.826 .2909 Mdot
.826 .29184 Mdot
.826 .2921 Mdot
.826 .2924 Mdot
.826 .29282 Mdot
.826 .29328 Mdot
.826 .29334 Mdot
.826 .29391 Mdot
.826 .29398 Mdot
.826 .29469 Mdot
.826 .29539 Mdot
.826 .29568 Mdot
.826 .29633 Mdot
.826 .29654 Mdot
.826 .29753 Mdot
.826 .2986 Mdot
.826 .29889 Mdot
.826 .29944 Mdot
.826 .29957 Mdot
.826 .30026 Mdot
.826 .30073 Mdot
.826 .30086 Mdot
.826 .30088 Mdot
.826 .30116 Mdot
.826 .30147 Mdot
.826 .30222 Mdot
.826 .30234 Mdot
.826 .30389 Mdot
.826 .30433 Mdot
.826 .30435 Mdot
.826 .30465 Mdot
.826 .30491 Mdot
.826 .30508 Mdot
.826 .30554 Mdot
.826 .30673 Mdot
.826 .30726 Mdot
.826 .30763 Mdot
.826 .30841 Mdot
.826 .3091 Mdot
.826 .30952 Mdot
.826 .31118 Mdot
.826 .31157 Mdot
.826 .31166 Mdot
.826 .31267 Mdot
.826 .31278 Mdot
.826 .31303 Mdot
.826 .31383 Mdot
.826 .31436 Mdot
.826 .31461 Mdot
.826 .31467 Mdot
.826 .31474 Mdot
.826 .31524 Mdot
.826 .31566 Mdot
.826 .3159 Mdot
.826 .31596 Mdot
.826 .31659 Mdot
.826 .31677 Mdot
.826 .31711 Mdot
.826 .31712 Mdot
.826 .31737 Mdot
.826 .31759 Mdot
.826 .31829 Mdot
.826 .31871 Mdot
.826 .31944 Mdot
.826 .32032 Mdot
.826 .32104 Mdot
.826 .32106 Mdot
.826 .3212 Mdot
.826 .32183 Mdot
.826 .32191 Mdot
.826 .32225 Mdot
.826 .32271 Mdot
.826 .3248 Mdot
.826 .32541 Mdot
.826 .32575 Mdot
.826 .3262 Mdot
.826 .32629 Mdot
.826 .3267 Mdot
.826 .32682 Mdot
.826 .32695 Mdot
.826 .3282 Mdot
.826 .32958 Mdot
.826 .32984 Mdot
.826 .3301 Mdot
.826 .33027 Mdot
.826 .33032 Mdot
.826 .33086 Mdot
.826 .33157 Mdot
.826 .33177 Mdot
.826 .332 Mdot
.826 .33271 Mdot
.826 .33388 Mdot
.826 .3344 Mdot
.826 .33473 Mdot
.826 .3349 Mdot
.826 .33498 Mdot
.826 .33502 Mdot
.826 .3354 Mdot
.826 .33559 Mdot
.826 .33565 Mdot
.826 .33583 Mdot
.826 .33624 Mdot
.826 .33693 Mdot
.826 .3382 Mdot
.826 .33864 Mdot
.826 .33899 Mdot
.826 .33938 Mdot
.826 .33945 Mdot
.826 .33952 Mdot
.826 .33992 Mdot
.826 .34024 Mdot
.826 .34078 Mdot
.826 .34085 Mdot
.826 .34096 Mdot
.826 .34101 Mdot
.826 .34103 Mdot
.826 .34201 Mdot
.826 .34242 Mdot
.826 .34314 Mdot
.826 .34328 Mdot
.826 .34376 Mdot
.826 .34428 Mdot
.826 .34556 Mdot
.826 .34578 Mdot
.826 .3461 Mdot
.826 .34619 Mdot
.826 .34652 Mdot
.826 .34663 Mdot
.826 .34809 Mdot
.826 .34827 Mdot
.826 .3497 Mdot
.826 .34991 Mdot
.826 .35008 Mdot
.826 .35082 Mdot
.826 .35145 Mdot
.826 .35229 Mdot
.826 .35262 Mdot
.826 .35268 Mdot
.826 .35342 Mdot
.826 .35343 Mdot
.826 .35402 Mdot
.826 .35423 Mdot
.826 .35434 Mdot
.826 .35441 Mdot
.826 .35477 Mdot
.826 .355 Mdot
.826 .35535 Mdot
.826 .35564 Mdot
.826 .35568 Mdot
.826 .35602 Mdot
.826 .35676 Mdot
.826 .3569 Mdot
.826 .35725 Mdot
.826 .3574 Mdot
.826 .35741 Mdot
.826 .35785 Mdot
.826 .35786 Mdot
.826 .35819 Mdot
.826 .35835 Mdot
.826 .35862 Mdot
.826 .35865 Mdot
.826 .35872 Mdot
.826 .36147 Mdot
.826 .364 Mdot
.826 .36475 Mdot
.826 .36515 Mdot
.826 .36569 Mdot
.826 .36616 Mdot
.826 .36818 Mdot
.826 .36986 Mdot
.826 .37089 Mdot
.826 .37092 Mdot
.826 .37182 Mdot
.826 .37256 Mdot
.826 .37581 Mdot
.826 .37858 Mdot
.826 .38042 Mdot
.826 .38056 Mdot
.826 .38234 Mdot
.826 .38382 Mdot
.826 .38406 Mdot
.826 .38741 Mdot
.826 .38744 Mdot
.826 .38859 Mdot
.826 .389 Mdot
.826 .39011 Mdot
.826 .39108 Mdot
.826 .39157 Mdot
.826 .39191 Mdot
.826 .39313 Mdot
.826 .39354 Mdot
.826 .39423 Mdot
.826 .39457 Mdot
.826 .3962 Mdot
.826 .39751 Mdot
.826 .39769 Mdot
.826 .39901 Mdot
.826 .39927 Mdot
.826 .3993 Mdot
.826 .39982 Mdot
.826 .40267 Mdot
.826 .40302 Mdot
.826 .40333 Mdot
.826 .40496 Mdot
.826 .40565 Mdot
.826 .4057 Mdot
.826 .40653 Mdot
.826 .40775 Mdot
.826 .40777 Mdot
.826 .40929 Mdot
.826 .41007 Mdot
.826 .41132 Mdot
.826 .41147 Mdot
.826 .41179 Mdot
.826 .41268 Mdot
.826 .41385 Mdot
.826 .41506 Mdot
.826 .4153 Mdot
.826 .41559 Mdot
.826 .41667 Mdot
.826 .41669 Mdot
.826 .4194 Mdot
.826 .42466 Mdot
.826 .42538 Mdot
.826 .42722 Mdot
.826 .42849 Mdot
.826 .43639 Mdot
.826 .43661 Mdot
.826 .43748 Mdot
.826 .44013 Mdot
.826 .44079 Mdot
.826 .44198 Mdot
.826 .44451 Mdot
.826 .44673 Mdot
.826 .45618 Mdot
.826 .45844 Mdot
.826 .46242 Mdot
.826 .46305 Mdot
.826 .46395 Mdot
.826 .46687 Mdot
.826 .46818 Mdot
.826 .4687 Mdot
.826 .46883 Mdot
.826 .46895 Mdot
.826 .47008 Mdot
.826 .47297 Mdot
.826 .47459 Mdot
.826 .47605 Mdot
.826 .47629 Mdot
.826 .47643 Mdot
.826 .47859 Mdot
.826 .48468 Mdot
.826 .48877 Mdot
.826 .48921 Mdot
.826 .48992 Mdot
.826 .49077 Mdot
.826 .49097 Mdot
.826 .49119 Mdot
.826 .49401 Mdot
.826 .49511 Mdot
.826 .50197 Mdot
.826 .50264 Mdot
.826 .50291 Mdot
.826 .50658 Mdot
.826 .50662 Mdot
.826 .50678 Mdot
.826 .50682 Mdot
.826 .50834 Mdot
.826 .50874 Mdot
.826 .50907 Mdot
.826 .51029 Mdot
.826 .51075 Mdot
.826 .51084 Mdot
.826 .51234 Mdot
.826 .51315 Mdot
.826 .51356 Mdot
.826 .51399 Mdot
.826 .51419 Mdot
.826 .51585 Mdot
.826 .51688 Mdot
.826 .51794 Mdot
.826 .51887 Mdot
.826 .5189 Mdot
.826 .52047 Mdot
.826 .52153 Mdot
.826 .52159 Mdot
.826 .52246 Mdot
.826 .52367 Mdot
.826 .52449 Mdot
.826 .5246 Mdot
.826 .52488 Mdot
.826 .5253 Mdot
.826 .52531 Mdot
.826 .52875 Mdot
.826 .52937 Mdot
.826 .5294 Mdot
.826 .52971 Mdot
.826 .53126 Mdot
.826 .53147 Mdot
.826 .53297 Mdot
.826 .53483 Mdot
.826 .5352 Mdot
.826 .53598 Mdot
.826 .53643 Mdot
.826 .53674 Mdot
.826 .53683 Mdot
.826 .53691 Mdot
.826 .53777 Mdot
.826 .53813 Mdot
.826 .53814 Mdot
.826 .53867 Mdot
.826 .5397 Mdot
.826 .54076 Mdot
.826 .54088 Mdot
.826 .5413 Mdot
.826 .54211 Mdot
.826 .54247 Mdot
.826 .5425 Mdot
.826 .54252 Mdot
.826 .54571 Mdot
.826 .54589 Mdot
.826 .54613 Mdot
.826 .54758 Mdot
.826 .54873 Mdot
.826 .54926 Mdot
.826 .54939 Mdot
.826 .55022 Mdot
.826 .55023 Mdot
.826 .5511 Mdot
.826 .55124 Mdot
.826 .55353 Mdot
.826 .55357 Mdot
.826 .55374 Mdot
.826 .55397 Mdot
.826 .55477 Mdot
.826 .55593 Mdot
.826 .55635 Mdot
.826 .55696 Mdot
.826 .5577 Mdot
.826 .55773 Mdot
.826 .55782 Mdot
.826 .55856 Mdot
.826 .55871 Mdot
.826 .55988 Mdot
.826 .56142 Mdot
.826 .56177 Mdot
.826 .56217 Mdot
.826 .56246 Mdot
.826 .56287 Mdot
.826 .563 Mdot
.826 .56479 Mdot
.826 .56594 Mdot
.826 .56634 Mdot
.826 .56663 Mdot
.826 .56668 Mdot
.826 .5667 Mdot
.826 .56687 Mdot
.826 .56698 Mdot
.826 .56719 Mdot
.826 .56719 Mdot
.826 .56747 Mdot
.826 .56748 Mdot
.826 .56757 Mdot
.826 .5678 Mdot
.826 .56789 Mdot
.826 .56834 Mdot
.826 .56855 Mdot
.826 .56858 Mdot
.826 .56875 Mdot
.826 .56897 Mdot
.826 .5691 Mdot
.826 .56916 Mdot
.826 .56932 Mdot
.826 .56936 Mdot
.826 .56943 Mdot
.826 .56955 Mdot
.826 .5697 Mdot
.826 .56975 Mdot
.826 .5699 Mdot
.826 .5699 Mdot
.826 .57033 Mdot
.826 .57036 Mdot
.826 .57055 Mdot
.826 .57078 Mdot
.826 .57103 Mdot
.826 .57137 Mdot
.826 .57178 Mdot
.826 .57187 Mdot
.826 .57198 Mdot
.826 .57273 Mdot
.826 .57282 Mdot
.826 .57313 Mdot
.826 .57345 Mdot
.826 .57346 Mdot
.826 .57346 Mdot
.826 .57352 Mdot
.826 .57356 Mdot
.826 .57356 Mdot
.826 .57361 Mdot
.826 .57361 Mdot
.826 .57363 Mdot
.826 .57367 Mdot
.826 .57369 Mdot
.826 .57377 Mdot
.826 .57382 Mdot
.826 .57385 Mdot
.826 .57389 Mdot
.826 .57392 Mdot
.826 .57396 Mdot
.826 .57397 Mdot
.826 .57398 Mdot
.826 .57401 Mdot
.826 .57408 Mdot
.826 .57408 Mdot
.826 .57417 Mdot
.826 .57417 Mdot
.826 .57421 Mdot
.826 .57431 Mdot
.826 .57438 Mdot
.826 .57447 Mdot
.826 .57449 Mdot
.826 .57451 Mdot
.826 .57468 Mdot
.826 .5747 Mdot
.826 .57487 Mdot
.826 .57488 Mdot
.826 .57492 Mdot
.826 .57493 Mdot
.826 .57497 Mdot
.826 .57499 Mdot
.826 .57514 Mdot
.826 .5752 Mdot
.826 .57525 Mdot
.826 .57527 Mdot
.826 .57535 Mdot
.826 .5754 Mdot
.826 .57551 Mdot
.826 .57551 Mdot
.826 .57552 Mdot
.826 .57553 Mdot
.826 .57554 Mdot
.826 .5756 Mdot
.826 .57563 Mdot
.826 .57568 Mdot
.826 .57569 Mdot
.826 .5757 Mdot
.826 .57574 Mdot
.826 .57583 Mdot
.826 .57609 Mdot
.826 .57612 Mdot
.826 .57612 Mdot
.826 .57614 Mdot
.826 .57619 Mdot
.826 .57619 Mdot
.826 .5762 Mdot
.826 .57622 Mdot
.826 .57625 Mdot
.826 .57631 Mdot
.826 .57644 Mdot
.826 .57652 Mdot
.826 .57655 Mdot
.826 .57657 Mdot
.826 .57665 Mdot
.826 .57671 Mdot
.826 .57671 Mdot
.826 .57673 Mdot
.826 .57676 Mdot
.826 .57679 Mdot
.826 .57694 Mdot
.826 .57708 Mdot
.826 .57721 Mdot
.826 .57725 Mdot
.826 .57731 Mdot
.826 .57754 Mdot
.826 .57763 Mdot
.826 .57764 Mdot
.826 .57772 Mdot
.826 .57772 Mdot
.826 .5779 Mdot
.826 .57798 Mdot
.826 .57802 Mdot
.826 .5781 Mdot
.826 .57812 Mdot
.826 .57815 Mdot
.826 .57818 Mdot
.826 .5782 Mdot
.826 .57827 Mdot
.826 .57835 Mdot
.826 .5784 Mdot
.826 .57841 Mdot
.826 .57841 Mdot
.826 .57844 Mdot
.826 .5785 Mdot
.826 .57858 Mdot
.826 .57861 Mdot
.826 .57862 Mdot
.826 .57874 Mdot
.826 .57878 Mdot
.826 .579 Mdot
.826 .57915 Mdot
.826 .57937 Mdot
.826 .57942 Mdot
.826 .57944 Mdot
.826 .57947 Mdot
.826 .5795 Mdot
.826 .5795 Mdot
.826 .57954 Mdot
.826 .57971 Mdot
.826 .5798 Mdot
.826 .57983 Mdot
.826 .57986 Mdot
.826 .57986 Mdot
.826 .57987 Mdot
.826 .57992 Mdot
.826 .57999 Mdot
.826 .58006 Mdot
.826 .58009 Mdot
.826 .5802 Mdot
.826 .58033 Mdot
.826 .58035 Mdot
.826 .58039 Mdot
.826 .58042 Mdot
.826 .58049 Mdot
.826 .58063 Mdot
.826 .58064 Mdot
.826 .58068 Mdot
.826 .58073 Mdot
.826 .58076 Mdot
.826 .58078 Mdot
.826 .58088 Mdot
.826 .5809 Mdot
.826 .5809 Mdot
.826 .58096 Mdot
.826 .581 Mdot
.826 .58103 Mdot
.826 .58107 Mdot
.826 .58111 Mdot
.826 .5812 Mdot
.826 .58121 Mdot
.826 .58122 Mdot
.826 .58134 Mdot
.826 .58135 Mdot
.826 .58149 Mdot
.826 .58161 Mdot
.826 .58162 Mdot
.826 .58167 Mdot
.826 .58169 Mdot
.826 .58174 Mdot
.826 .58176 Mdot
.826 .58178 Mdot
.826 .58181 Mdot
.826 .58186 Mdot
.826 .58189 Mdot
.826 .58189 Mdot
.826 .58197 Mdot
.826 .582 Mdot
.826 .58212 Mdot
.826 .58212 Mdot
.826 .58216 Mdot
.826 .58222 Mdot
.826 .58223 Mdot
.826 .58225 Mdot
.826 .58227 Mdot
.826 .58233 Mdot
.826 .58235 Mdot
.826 .58238 Mdot
.826 .58239 Mdot
.826 .5824 Mdot
.826 .5824 Mdot
.826 .58241 Mdot
.826 .58241 Mdot
.826 .58243 Mdot
.826 .58244 Mdot
.826 .58246 Mdot
.826 .58246 Mdot
.826 .58252 Mdot
.826 .58253 Mdot
.826 .58253 Mdot
.826 .58254 Mdot
.826 .58255 Mdot
.826 .58258 Mdot
.826 .58262 Mdot
.826 .58263 Mdot
.826 .58263 Mdot
.826 .58265 Mdot
.826 .58266 Mdot
.826 .58268 Mdot
.826 .58269 Mdot
.826 .58269 Mdot
.826 .58271 Mdot
.826 .58273 Mdot
.826 .58273 Mdot
.826 .58273 Mdot
.826 .58274 Mdot
.826 .58275 Mdot
.826 .58276 Mdot
.826 .58279 Mdot
.826 .58279 Mdot
.826 .5828 Mdot
.826 .58281 Mdot
.826 .58282 Mdot
.826 .58282 Mdot
.826 .58283 Mdot
.826 .58283 Mdot
.826 .58284 Mdot
.828 .09024 Mdot
.828 .09028 Mdot
.828 .0903 Mdot
.828 .09031 Mdot
.828 .09034 Mdot
.828 .09044 Mdot
.828 .09044 Mdot
.828 .09044 Mdot
.828 .09049 Mdot
.828 .09051 Mdot
.828 .0906 Mdot
.828 .09061 Mdot
.828 .09064 Mdot
.828 .09071 Mdot
.828 .09077 Mdot
.828 .09081 Mdot
.828 .09085 Mdot
.828 .09086 Mdot
.828 .0909 Mdot
.828 .09091 Mdot
.828 .09103 Mdot
.828 .09104 Mdot
.828 .09109 Mdot
.828 .09118 Mdot
.828 .09152 Mdot
.828 .09157 Mdot
.828 .0917 Mdot
.828 .09171 Mdot
.828 .09175 Mdot
.828 .09188 Mdot
.828 .0919 Mdot
.828 .09199 Mdot
.828 .09201 Mdot
.828 .09208 Mdot
.828 .09234 Mdot
.828 .09245 Mdot
.828 .09248 Mdot
.828 .09255 Mdot
.828 .09273 Mdot
.828 .09283 Mdot
.828 .09287 Mdot
.828 .09293 Mdot
.828 .09296 Mdot
.828 .09311 Mdot
.828 .09329 Mdot
.828 .09332 Mdot
.828 .09336 Mdot
.828 .09336 Mdot
.828 .09339 Mdot
.828 .09353 Mdot
.828 .09363 Mdot
.828 .09396 Mdot
.828 .09432 Mdot
.828 .09447 Mdot
.828 .09456 Mdot
.828 .09513 Mdot
.828 .09515 Mdot
.828 .09526 Mdot
.828 .09539 Mdot
.828 .09578 Mdot
.828 .09662 Mdot
.828 .09703 Mdot
.828 .09704 Mdot
.828 .09779 Mdot
.828 .09781 Mdot
.828 .09841 Mdot
.828 .09841 Mdot
.828 .09933 Mdot
.828 .09934 Mdot
.828 .1004 Mdot
.828 .1004 Mdot
.828 .10043 Mdot
.828 .10074 Mdot
.828 .10104 Mdot
.828 .10107 Mdot
.828 .10144 Mdot
.828 .10154 Mdot
.828 .10156 Mdot
.828 .10173 Mdot
.828 .10186 Mdot
.828 .10242 Mdot
.828 .10384 Mdot
.828 .1041 Mdot
.828 .10534 Mdot
.828 .10576 Mdot
.828 .10577 Mdot
.828 .10577 Mdot
.828 .10614 Mdot
.828 .10616 Mdot
.828 .10621 Mdot
.828 .10645 Mdot
.828 .10651 Mdot
.828 .10685 Mdot
.828 .10703 Mdot
.828 .10744 Mdot
.828 .1079 Mdot
.828 .10821 Mdot
.828 .10853 Mdot
.828 .10861 Mdot
.828 .10882 Mdot
.828 .10894 Mdot
.828 .10912 Mdot
.828 .10978 Mdot
.828 .11046 Mdot
.828 .11145 Mdot
.828 .11173 Mdot
.828 .11213 Mdot
.828 .11258 Mdot
.828 .1127 Mdot
.828 .11282 Mdot
.828 .11283 Mdot
.828 .11297 Mdot
.828 .11301 Mdot
.828 .11308 Mdot
.828 .11313 Mdot
.828 .11385 Mdot
.828 .11449 Mdot
.828 .11449 Mdot
.828 .11462 Mdot
.828 .11484 Mdot
.828 .1149 Mdot
.828 .11503 Mdot
.828 .11545 Mdot
.828 .11549 Mdot
.828 .11574 Mdot
.828 .11622 Mdot
.828 .11654 Mdot
.828 .11668 Mdot
.828 .11717 Mdot
.828 .11834 Mdot
.828 .11866 Mdot
.828 .11876 Mdot
.828 .11916 Mdot
.828 .11926 Mdot
.828 .11948 Mdot
.828 .11985 Mdot
.828 .12005 Mdot
.828 .12007 Mdot
.828 .12038 Mdot
.828 .12068 Mdot
.828 .1208 Mdot
.828 .12091 Mdot
.828 .12121 Mdot
.828 .12203 Mdot
.828 .12256 Mdot
.828 .1229 Mdot
.828 .12302 Mdot
.828 .12327 Mdot
.828 .12329 Mdot
.828 .12332 Mdot
.828 .12346 Mdot
.828 .1239 Mdot
.828 .12393 Mdot
.828 .12406 Mdot
.828 .12413 Mdot
.828 .12413 Mdot
.828 .12417 Mdot
.828 .1243 Mdot
.828 .12438 Mdot
.828 .12457 Mdot
.828 .12489 Mdot
.828 .12527 Mdot
.828 .12539 Mdot
.828 .12544 Mdot
.828 .12562 Mdot
.828 .1259 Mdot
.828 .12593 Mdot
.828 .126 Mdot
.828 .12626 Mdot
.828 .12628 Mdot
.828 .12629 Mdot
.828 .12678 Mdot
.828 .12681 Mdot
.828 .1269 Mdot
.828 .12695 Mdot
.828 .12701 Mdot
.828 .12708 Mdot
.828 .12722 Mdot
.828 .12733 Mdot
.828 .12828 Mdot
.828 .12966 Mdot
.828 .13005 Mdot
.828 .1302 Mdot
.828 .13072 Mdot
.828 .13146 Mdot
.828 .13192 Mdot
.828 .13215 Mdot
.828 .13366 Mdot
.828 .13419 Mdot
.828 .1346 Mdot
.828 .13611 Mdot
.828 .13868 Mdot
.828 .13876 Mdot
.828 .14047 Mdot
.828 .14107 Mdot
.828 .14206 Mdot
.828 .14236 Mdot
.828 .14248 Mdot
.828 .14264 Mdot
.828 .14337 Mdot
.828 .14568 Mdot
.828 .14584 Mdot
.828 .14602 Mdot
.828 .14643 Mdot
.828 .14654 Mdot
.828 .14683 Mdot
.828 .14689 Mdot
.828 .14689 Mdot
.828 .147 Mdot
.828 .14714 Mdot
.828 .14781 Mdot
.828 .14826 Mdot
.828 .14826 Mdot
.828 .1493 Mdot
.828 .15102 Mdot
.828 .15257 Mdot
.828 .15314 Mdot
.828 .1538 Mdot
.828 .1541 Mdot
.828 .1551 Mdot
.828 .15673 Mdot
.828 .15687 Mdot
.828 .15699 Mdot
.828 .15724 Mdot
.828 .15877 Mdot
.828 .15886 Mdot
.828 .15891 Mdot
.828 .15965 Mdot
.828 .16179 Mdot
.828 .16195 Mdot
.828 .16246 Mdot
.828 .16277 Mdot
.828 .16299 Mdot
.828 .16316 Mdot
.828 .16358 Mdot
.828 .16439 Mdot
.828 .16467 Mdot
.828 .16502 Mdot
.828 .16881 Mdot
.828 .17029 Mdot
.828 .17079 Mdot
.828 .17553 Mdot
.828 .17594 Mdot
.828 .17889 Mdot
.828 .17937 Mdot
.828 .18183 Mdot
.828 .18184 Mdot
.828 .18282 Mdot
.828 .18357 Mdot
.828 .18475 Mdot
.828 .18616 Mdot
.828 .18746 Mdot
.828 .18847 Mdot
.828 .18997 Mdot
.828 .19096 Mdot
.828 .19177 Mdot
.828 .19403 Mdot
.828 .19409 Mdot
.828 .19555 Mdot
.828 .19744 Mdot
.828 .20057 Mdot
.828 .20145 Mdot
.828 .20302 Mdot
.828 .20582 Mdot
.828 .20815 Mdot
.828 .20871 Mdot
.828 .20945 Mdot
.828 .21231 Mdot
.828 .22025 Mdot
.828 .22297 Mdot
.828 .22428 Mdot
.828 .23821 Mdot
.828 .24156 Mdot
.828 .2422 Mdot
.828 .24309 Mdot
.828 .24407 Mdot
.828 .24513 Mdot
.828 .24623 Mdot
.828 .24733 Mdot
.828 .24749 Mdot
.828 .2495 Mdot
.828 .25487 Mdot
.828 .25866 Mdot
.828 .2593 Mdot
.828 .25948 Mdot
.828 .25967 Mdot
.828 .26563 Mdot
.828 .26677 Mdot
.828 .26898 Mdot
.828 .26904 Mdot
.828 .26912 Mdot
.828 .26916 Mdot
.828 .26919 Mdot
.828 .26929 Mdot
.828 .26956 Mdot
.828 .26957 Mdot
.828 .26957 Mdot
.828 .26972 Mdot
.828 .26976 Mdot
.828 .26993 Mdot
.828 .27003 Mdot
.828 .27006 Mdot
.828 .27013 Mdot
.828 .27035 Mdot
.828 .27053 Mdot
.828 .27064 Mdot
.828 .27076 Mdot
.828 .27078 Mdot
.828 .2709 Mdot
.828 .27091 Mdot
.828 .27117 Mdot
.828 .27127 Mdot
.828 .27128 Mdot
.828 .27142 Mdot
.828 .27169 Mdot
.828 .272 Mdot
.828 .27267 Mdot
.828 .27281 Mdot
.828 .27318 Mdot
.828 .27319 Mdot
.828 .27332 Mdot
.828 .27368 Mdot
.828 .27374 Mdot
.828 .27399 Mdot
.828 .27405 Mdot
.828 .27425 Mdot
.828 .27499 Mdot
.828 .27531 Mdot
.828 .2754 Mdot
.828 .27561 Mdot
.828 .27611 Mdot
.828 .27639 Mdot
.828 .27652 Mdot
.828 .27667 Mdot
.828 .27675 Mdot
.828 .27675 Mdot
.828 .27719 Mdot
.828 .27768 Mdot
.828 .27776 Mdot
.828 .27789 Mdot
.828 .2779 Mdot
.828 .27798 Mdot
.828 .27838 Mdot
.828 .27867 Mdot
.828 .27959 Mdot
.828 .28059 Mdot
.828 .28104 Mdot
.828 .28129 Mdot
.828 .28264 Mdot
.828 .28289 Mdot
.828 .28293 Mdot
.828 .28325 Mdot
.828 .28362 Mdot
.828 .28469 Mdot
.828 .28622 Mdot
.828 .28704 Mdot
.828 .2882 Mdot
.828 .28821 Mdot
.828 .2903 Mdot
.828 .29036 Mdot
.828 .29106 Mdot
.828 .292 Mdot
.828 .29201 Mdot
.828 .2944 Mdot
.828 .29456 Mdot
.828 .29458 Mdot
.828 .29559 Mdot
.828 .29643 Mdot
.828 .29699 Mdot
.828 .29743 Mdot
.828 .29748 Mdot
.828 .29749 Mdot
.828 .29757 Mdot
.828 .29842 Mdot
.828 .29909 Mdot
.828 .29924 Mdot
.828 .29931 Mdot
.828 .30016 Mdot
.828 .30033 Mdot
.828 .3006 Mdot
.828 .30066 Mdot
.828 .30099 Mdot
.828 .3011 Mdot
.828 .30111 Mdot
.828 .30147 Mdot
.828 .30298 Mdot
.828 .30318 Mdot
.828 .30365 Mdot
.828 .30367 Mdot
.828 .3045 Mdot
.828 .30559 Mdot
.828 .30567 Mdot
.828 .30684 Mdot
.828 .30752 Mdot
.828 .30954 Mdot
.828 .3107 Mdot
.828 .31085 Mdot
.828 .31198 Mdot
.828 .31199 Mdot
.828 .31202 Mdot
.828 .31299 Mdot
.828 .31305 Mdot
.828 .31317 Mdot
.828 .31382 Mdot
.828 .31399 Mdot
.828 .31416 Mdot
.828 .3142 Mdot
.828 .31487 Mdot
.828 .31537 Mdot
.828 .31643 Mdot
.828 .31765 Mdot
.828 .31848 Mdot
.828 .31932 Mdot
.828 .31952 Mdot
.828 .31972 Mdot
.828 .31978 Mdot
.828 .32008 Mdot
.828 .32041 Mdot
.828 .32086 Mdot
.828 .32219 Mdot
.828 .32258 Mdot
.828 .32383 Mdot
.828 .32437 Mdot
.828 .3255 Mdot
.828 .32695 Mdot
.828 .32767 Mdot
.828 .3287 Mdot
.828 .32871 Mdot
.828 .32986 Mdot
.828 .33018 Mdot
.828 .33048 Mdot
.828 .3305 Mdot
.828 .33087 Mdot
.828 .33097 Mdot
.828 .33115 Mdot
.828 .33128 Mdot
.828 .33312 Mdot
.828 .33477 Mdot
.828 .33478 Mdot
.828 .33509 Mdot
.828 .33534 Mdot
.828 .33566 Mdot
.828 .33582 Mdot
.828 .33614 Mdot
.828 .3365 Mdot
.828 .33706 Mdot
.828 .33722 Mdot
.828 .33731 Mdot
.828 .33794 Mdot
.828 .33917 Mdot
.828 .33997 Mdot
.828 .34024 Mdot
.828 .34032 Mdot
.828 .34156 Mdot
.828 .34195 Mdot
.828 .34449 Mdot
.828 .34504 Mdot
.828 .34529 Mdot
.828 .34554 Mdot
.828 .34654 Mdot
.828 .34679 Mdot
.828 .34721 Mdot
.828 .34725 Mdot
.828 .34735 Mdot
.828 .34826 Mdot
.828 .34876 Mdot
.828 .34881 Mdot
.828 .34957 Mdot
.828 .35032 Mdot
.828 .35052 Mdot
.828 .3506 Mdot
.828 .35088 Mdot
.828 .35151 Mdot
.828 .35163 Mdot
.828 .35267 Mdot
.828 .35288 Mdot
.828 .35364 Mdot
.828 .35491 Mdot
.828 .35495 Mdot
.828 .35577 Mdot
.828 .35605 Mdot
.828 .35652 Mdot
.828 .35667 Mdot
.828 .35672 Mdot
.828 .3568 Mdot
.828 .35714 Mdot
.828 .35821 Mdot
.828 .35828 Mdot
.828 .3586 Mdot
.828 .35876 Mdot
.828 .35876 Mdot
.828 .35881 Mdot
.828 .35887 Mdot
.828 .35917 Mdot
.828 .35937 Mdot
.828 .35984 Mdot
.828 .3606 Mdot
.828 .36127 Mdot
.828 .36152 Mdot
.828 .3618 Mdot
.828 .36193 Mdot
.828 .36236 Mdot
.828 .36305 Mdot
.828 .36311 Mdot
.828 .36327 Mdot
.828 .36391 Mdot
.828 .36394 Mdot
.828 .36396 Mdot
.828 .36427 Mdot
.828 .36515 Mdot
.828 .36521 Mdot
.828 .36542 Mdot
.828 .36555 Mdot
.828 .36564 Mdot
.828 .36571 Mdot
.828 .36588 Mdot
.828 .3662 Mdot
.828 .36632 Mdot
.828 .36645 Mdot
.828 .36796 Mdot
.828 .36873 Mdot
.828 .37199 Mdot
.828 .37289 Mdot
.828 .37326 Mdot
.828 .37353 Mdot
.828 .37447 Mdot
.828 .3753 Mdot
.828 .37619 Mdot
.828 .37727 Mdot
.828 .37728 Mdot
.828 .37779 Mdot
.828 .37845 Mdot
.828 .37952 Mdot
.828 .38036 Mdot
.828 .3813 Mdot
.828 .38207 Mdot
.828 .38226 Mdot
.828 .38251 Mdot
.828 .38345 Mdot
.828 .38602 Mdot
.828 .38689 Mdot
.828 .38731 Mdot
.828 .39165 Mdot
.828 .39267 Mdot
.828 .39287 Mdot
.828 .39314 Mdot
.828 .39343 Mdot
.828 .39409 Mdot
.828 .39442 Mdot
.828 .39446 Mdot
.828 .39667 Mdot
.828 .39797 Mdot
.828 .39803 Mdot
.828 .39808 Mdot
.828 .39982 Mdot
.828 .40015 Mdot
.828 .40081 Mdot
.828 .40107 Mdot
.828 .40143 Mdot
.828 .40167 Mdot
.828 .40303 Mdot
.828 .4047 Mdot
.828 .40708 Mdot
.828 .40801 Mdot
.828 .40835 Mdot
.828 .40874 Mdot
.828 .40886 Mdot
.828 .40962 Mdot
.828 .40985 Mdot
.828 .41046 Mdot
.828 .41059 Mdot
.828 .4106 Mdot
.828 .41082 Mdot
.828 .41113 Mdot
.828 .41115 Mdot
.828 .41254 Mdot
.828 .41349 Mdot
.828 .4135 Mdot
.828 .41503 Mdot
.828 .41569 Mdot
.828 .41613 Mdot
.828 .41926 Mdot
.828 .41958 Mdot
.828 .41973 Mdot
.828 .42105 Mdot
.828 .42189 Mdot
.828 .42247 Mdot
.828 .42337 Mdot
.828 .42363 Mdot
.828 .42455 Mdot
.828 .42498 Mdot
.828 .4256 Mdot
.828 .42744 Mdot
.828 .42762 Mdot
.828 .43004 Mdot
.828 .43089 Mdot
.828 .43118 Mdot
.828 .43141 Mdot
.828 .43192 Mdot
.828 .43294 Mdot
.828 .43486 Mdot
.828 .43494 Mdot
.828 .43512 Mdot
.828 .43522 Mdot
.828 .43668 Mdot
.828 .43718 Mdot
.828 .43801 Mdot
.828 .43977 Mdot
.828 .44084 Mdot
.828 .44114 Mdot
.828 .44213 Mdot
.828 .44273 Mdot
.828 .44314 Mdot
.828 .44347 Mdot
.828 .44427 Mdot
.828 .445 Mdot
.828 .44581 Mdot
.828 .44635 Mdot
.828 .44701 Mdot
.828 .45407 Mdot
.828 .45679 Mdot
.828 .4577 Mdot
.828 .45812 Mdot
.828 .4593 Mdot
.828 .46028 Mdot
.828 .46173 Mdot
.828 .46302 Mdot
.828 .46444 Mdot
.828 .46502 Mdot
.828 .46574 Mdot
.828 .46615 Mdot
.828 .46679 Mdot
.828 .46686 Mdot
.828 .46852 Mdot
.828 .46904 Mdot
.828 .47088 Mdot
.828 .47195 Mdot
.828 .47278 Mdot
.828 .47389 Mdot
.828 .47528 Mdot
.828 .47613 Mdot
.828 .47692 Mdot
.828 .47694 Mdot
.828 .47855 Mdot
.828 .47857 Mdot
.828 .47872 Mdot
.828 .47901 Mdot
.828 .47915 Mdot
.828 .47981 Mdot
.828 .48174 Mdot
.828 .48231 Mdot
.828 .48395 Mdot
.828 .48403 Mdot
.828 .48478 Mdot
.828 .48514 Mdot
.828 .4856 Mdot
.828 .48611 Mdot
.828 .48696 Mdot
.828 .48771 Mdot
.828 .49008 Mdot
.828 .49076 Mdot
.828 .49105 Mdot
.828 .49162 Mdot
.828 .49287 Mdot
.828 .49389 Mdot
.828 .49482 Mdot
.828 .49549 Mdot
.828 .49631 Mdot
.828 .4964 Mdot
.828 .49687 Mdot
.828 .49727 Mdot
.828 .49859 Mdot
.828 .4986 Mdot
.828 .49948 Mdot
.828 .50071 Mdot
.828 .50139 Mdot
.828 .50264 Mdot
.828 .50286 Mdot
.828 .50332 Mdot
.828 .5059 Mdot
.828 .50714 Mdot
.828 .50778 Mdot
.828 .50841 Mdot
.828 .50933 Mdot
.828 .50935 Mdot
.828 .51144 Mdot
.828 .51145 Mdot
.828 .51275 Mdot
.828 .51318 Mdot
.828 .51462 Mdot
.828 .51465 Mdot
.828 .51506 Mdot
.828 .51536 Mdot
.828 .51537 Mdot
.828 .51554 Mdot
.828 .51631 Mdot
.828 .51635 Mdot
.828 .51666 Mdot
.828 .51705 Mdot
.828 .51765 Mdot
.828 .51781 Mdot
.828 .51802 Mdot
.828 .51833 Mdot
.828 .51876 Mdot
.828 .51997 Mdot
.828 .52171 Mdot
.828 .52299 Mdot
.828 .52508 Mdot
.828 .52674 Mdot
.828 .52704 Mdot
.828 .52747 Mdot
.828 .52778 Mdot
.828 .52857 Mdot
.828 .52896 Mdot
.828 .53102 Mdot
.828 .53108 Mdot
.828 .53114 Mdot
.828 .53136 Mdot
.828 .53266 Mdot
.828 .53448 Mdot
.828 .53516 Mdot
.828 .53521 Mdot
.828 .53558 Mdot
.828 .53595 Mdot
.828 .53631 Mdot
.828 .53664 Mdot
.828 .53694 Mdot
.828 .53715 Mdot
.828 .53826 Mdot
.828 .54285 Mdot
.828 .54328 Mdot
.828 .54416 Mdot
.828 .54672 Mdot
.828 .54763 Mdot
.828 .54787 Mdot
.828 .54805 Mdot
.828 .54879 Mdot
.828 .54968 Mdot
.828 .55017 Mdot
.828 .55045 Mdot
.828 .55144 Mdot
.828 .55203 Mdot
.828 .55249 Mdot
.828 .55251 Mdot
.828 .55321 Mdot
.828 .55346 Mdot
.828 .55377 Mdot
.828 .55424 Mdot
.828 .55456 Mdot
.828 .55496 Mdot
.828 .55539 Mdot
.828 .55576 Mdot
.828 .55599 Mdot
.828 .55629 Mdot
.828 .5563 Mdot
.828 .55705 Mdot
.828 .5572 Mdot
.828 .5581 Mdot
.828 .55823 Mdot
.828 .55967 Mdot
.828 .55982 Mdot
.828 .56028 Mdot
.828 .56142 Mdot
.828 .56153 Mdot
.828 .56161 Mdot
.828 .56186 Mdot
.828 .56198 Mdot
.828 .56203 Mdot
.828 .5621 Mdot
.828 .56219 Mdot
.828 .56235 Mdot
.828 .56239 Mdot
.828 .56304 Mdot
.828 .56326 Mdot
.828 .56327 Mdot
.828 .5633 Mdot
.828 .56376 Mdot
.828 .56384 Mdot
.828 .56387 Mdot
.828 .56391 Mdot
.828 .5644 Mdot
.828 .5647 Mdot
.828 .56479 Mdot
.828 .56498 Mdot
.828 .56515 Mdot
.828 .56561 Mdot
.828 .56612 Mdot
.828 .56643 Mdot
.828 .56643 Mdot
.828 .56657 Mdot
.828 .56676 Mdot
.828 .5668 Mdot
.828 .56684 Mdot
.828 .56684 Mdot
.828 .56685 Mdot
.828 .56694 Mdot
.828 .56697 Mdot
.828 .56709 Mdot
.828 .56715 Mdot
.828 .56719 Mdot
.828 .56787 Mdot
.828 .56809 Mdot
.828 .56814 Mdot
.828 .56817 Mdot
.828 .56826 Mdot
.828 .56855 Mdot
.828 .56873 Mdot
.828 .56923 Mdot
.828 .56925 Mdot
.828 .57 Mdot
.828 .57044 Mdot
.828 .57056 Mdot
.828 .57072 Mdot
.828 .57116 Mdot
.828 .57122 Mdot
.828 .57136 Mdot
.828 .57157 Mdot
.828 .57172 Mdot
.828 .57177 Mdot
.828 .57188 Mdot
.828 .57228 Mdot
.828 .57256 Mdot
.828 .57259 Mdot
.828 .57263 Mdot
.828 .57265 Mdot
.828 .57266 Mdot
.828 .57268 Mdot
.828 .57271 Mdot
.828 .57271 Mdot
.828 .57286 Mdot
.828 .57286 Mdot
.828 .57286 Mdot
.828 .57294 Mdot
.828 .57296 Mdot
.828 .57297 Mdot
.828 .57305 Mdot
.828 .5731 Mdot
.828 .57312 Mdot
.828 .57315 Mdot
.828 .57326 Mdot
.828 .57335 Mdot
.828 .57341 Mdot
.828 .57343 Mdot
.828 .57347 Mdot
.828 .57348 Mdot
.828 .57348 Mdot
.828 .5735 Mdot
.828 .57354 Mdot
.828 .57354 Mdot
.828 .57367 Mdot
.828 .57371 Mdot
.828 .57372 Mdot
.828 .57373 Mdot
.828 .5738 Mdot
.828 .57383 Mdot
.828 .57393 Mdot
.828 .57408 Mdot
.828 .57432 Mdot
.828 .5744 Mdot
.828 .57444 Mdot
.828 .57447 Mdot
.828 .57456 Mdot
.828 .57464 Mdot
.828 .57465 Mdot
.828 .57471 Mdot
.828 .57481 Mdot
.828 .57488 Mdot
.828 .57491 Mdot
.828 .57502 Mdot
.828 .57505 Mdot
.828 .57514 Mdot
.828 .57548 Mdot
.828 .57562 Mdot
.828 .57566 Mdot
.828 .57575 Mdot
.828 .57588 Mdot
.828 .57596 Mdot
.828 .57597 Mdot
.828 .57609 Mdot
.828 .57612 Mdot
.828 .57614 Mdot
.828 .5762 Mdot
.828 .57624 Mdot
.828 .57624 Mdot
.828 .57642 Mdot
.828 .57663 Mdot
.828 .57664 Mdot
.828 .57666 Mdot
.828 .57667 Mdot
.828 .57671 Mdot
.828 .57672 Mdot
.828 .57675 Mdot
.828 .57679 Mdot
.828 .57691 Mdot
.828 .57703 Mdot
.828 .57711 Mdot
.828 .57739 Mdot
.828 .57758 Mdot
.828 .57777 Mdot
.828 .57782 Mdot
.828 .57785 Mdot
.828 .57791 Mdot
.828 .57793 Mdot
.828 .57803 Mdot
.828 .57811 Mdot
.828 .57824 Mdot
.828 .57836 Mdot
.828 .57841 Mdot
.828 .57851 Mdot
.828 .57852 Mdot
.828 .57859 Mdot
.828 .57861 Mdot
.828 .57861 Mdot
.828 .57871 Mdot
.828 .57872 Mdot
.828 .57872 Mdot
.828 .57884 Mdot
.828 .57919 Mdot
.828 .57926 Mdot
.828 .57966 Mdot
.828 .57982 Mdot
.828 .57986 Mdot
.828 .5799 Mdot
.828 .57991 Mdot
.828 .57994 Mdot
.828 .58004 Mdot
.828 .58005 Mdot
.828 .58013 Mdot
.828 .58022 Mdot
.828 .58023 Mdot
.828 .58023 Mdot
.828 .58053 Mdot
.828 .58053 Mdot
.828 .58077 Mdot
.828 .58079 Mdot
.828 .58079 Mdot
.828 .58095 Mdot
.828 .58096 Mdot
.828 .58117 Mdot
.828 .58117 Mdot
.828 .58129 Mdot
.828 .58152 Mdot
.828 .58163 Mdot
.828 .58167 Mdot
.828 .5817 Mdot
.828 .5817 Mdot
.828 .58186 Mdot
.828 .58189 Mdot
.828 .58193 Mdot
.828 .58203 Mdot
.828 .58212 Mdot
.828 .58215 Mdot
.828 .58219 Mdot
.828 .5822 Mdot
.828 .5822 Mdot
.828 .58221 Mdot
.828 .58222 Mdot
.828 .58227 Mdot
.828 .58231 Mdot
.828 .58232 Mdot
.828 .58233 Mdot
.828 .58235 Mdot
.828 .58237 Mdot
.828 .58242 Mdot
.828 .58244 Mdot
.828 .58245 Mdot
.828 .58248 Mdot
.828 .58256 Mdot
.828 .58258 Mdot
.828 .58258 Mdot
.828 .58261 Mdot
.828 .58261 Mdot
.828 .58265 Mdot
.828 .58266 Mdot
.828 .58266 Mdot
.828 .5827 Mdot
.828 .58271 Mdot
.828 .58281 Mdot
.828 .58283 Mdot
.828 .58285 Mdot
.828 .58285 Mdot
.828 .58288 Mdot
.828 .58288 Mdot
.828 .5829 Mdot
.828 .5829 Mdot
.828 .58291 Mdot
.828 .58292 Mdot
.828 .58294 Mdot
.828 .58296 Mdot
.828 .58296 Mdot
.828 .58297 Mdot
.828 .58299 Mdot
.828 .583 Mdot
.828 .58301 Mdot
.828 .58301 Mdot
.828 .58301 Mdot
.828 .58304 Mdot
.828 .58305 Mdot
.828 .58305 Mdot
.828 .58306 Mdot
.828 .58307 Mdot
.83 .08941 Mdot
.83 .08942 Mdot
.83 .08943 Mdot
.83 .08943 Mdot
.83 .08946 Mdot
.83 .08948 Mdot
.83 .08948 Mdot
.83 .08952 Mdot
.83 .08952 Mdot
.83 .08955 Mdot
.83 .08956 Mdot
.83 .08956 Mdot
.83 .0896 Mdot
.83 .08961 Mdot
.83 .08963 Mdot
.83 .08971 Mdot
.83 .08983 Mdot
.83 .08985 Mdot
.83 .08995 Mdot
.83 .08995 Mdot
.83 .08996 Mdot
.83 .09034 Mdot
.83 .09038 Mdot
.83 .09046 Mdot
.83 .09073 Mdot
.83 .09098 Mdot
.83 .09105 Mdot
.83 .09126 Mdot
.83 .09134 Mdot
.83 .0915 Mdot
.83 .09155 Mdot
.83 .09167 Mdot
.83 .0917 Mdot
.83 .09203 Mdot
.83 .0922 Mdot
.83 .09253 Mdot
.83 .09264 Mdot
.83 .09272 Mdot
.83 .09313 Mdot
.83 .09324 Mdot
.83 .09351 Mdot
.83 .09351 Mdot
.83 .09372 Mdot
.83 .09374 Mdot
.83 .09378 Mdot
.83 .09388 Mdot
.83 .09389 Mdot
.83 .09389 Mdot
.83 .09391 Mdot
.83 .09395 Mdot
.83 .09433 Mdot
.83 .09444 Mdot
.83 .09465 Mdot
.83 .09481 Mdot
.83 .09495 Mdot
.83 .09502 Mdot
.83 .09514 Mdot
.83 .09514 Mdot
.83 .09538 Mdot
.83 .09558 Mdot
.83 .09562 Mdot
.83 .09582 Mdot
.83 .09583 Mdot
.83 .09646 Mdot
.83 .09674 Mdot
.83 .09676 Mdot
.83 .09698 Mdot
.83 .0972 Mdot
.83 .09735 Mdot
.83 .09788 Mdot
.83 .09803 Mdot
.83 .09826 Mdot
.83 .09855 Mdot
.83 .09867 Mdot
.83 .09904 Mdot
.83 .09924 Mdot
.83 .0993 Mdot
.83 .09953 Mdot
.83 .09954 Mdot
.83 .09963 Mdot
.83 .09998 Mdot
.83 .10025 Mdot
.83 .10029 Mdot
.83 .10037 Mdot
.83 .10109 Mdot
.83 .10127 Mdot
.83 .10214 Mdot
.83 .10224 Mdot
.83 .10285 Mdot
.83 .10301 Mdot
.83 .10304 Mdot
.83 .10347 Mdot
.83 .10367 Mdot
.83 .10369 Mdot
.83 .10381 Mdot
.83 .10428 Mdot
.83 .10444 Mdot
.83 .10464 Mdot
.83 .10525 Mdot
.83 .10526 Mdot
.83 .10541 Mdot
.83 .10567 Mdot
.83 .10593 Mdot
.83 .10638 Mdot
.83 .10641 Mdot
.83 .10695 Mdot
.83 .10773 Mdot
.83 .10793 Mdot
.83 .10804 Mdot
.83 .10814 Mdot
.83 .1087 Mdot
.83 .10941 Mdot
.83 .10958 Mdot
.83 .10958 Mdot
.83 .10972 Mdot
.83 .10974 Mdot
.83 .1098 Mdot
.83 .10981 Mdot
.83 .10984 Mdot
.83 .11024 Mdot
.83 .1104 Mdot
.83 .11044 Mdot
.83 .1105 Mdot
.83 .11075 Mdot
.83 .11129 Mdot
.83 .1113 Mdot
.83 .11209 Mdot
.83 .11239 Mdot
.83 .11282 Mdot
.83 .11316 Mdot
.83 .11347 Mdot
.83 .11401 Mdot
.83 .11458 Mdot
.83 .1149 Mdot
.83 .1154 Mdot
.83 .11586 Mdot
.83 .11612 Mdot
.83 .11686 Mdot
.83 .11763 Mdot
.83 .11915 Mdot
.83 .1193 Mdot
.83 .11984 Mdot
.83 .12008 Mdot
.83 .12085 Mdot
.83 .12123 Mdot
.83 .12142 Mdot
.83 .12226 Mdot
.83 .12233 Mdot
.83 .12261 Mdot
.83 .12297 Mdot
.83 .12387 Mdot
.83 .12482 Mdot
.83 .1252 Mdot
.83 .12534 Mdot
.83 .12564 Mdot
.83 .12584 Mdot
.83 .12643 Mdot
.83 .12784 Mdot
.83 .12791 Mdot
.83 .12791 Mdot
.83 .12841 Mdot
.83 .12851 Mdot
.83 .12918 Mdot
.83 .1295 Mdot
.83 .12959 Mdot
.83 .1296 Mdot
.83 .12971 Mdot
.83 .12975 Mdot
.83 .12998 Mdot
.83 .12999 Mdot
.83 .13001 Mdot
.83 .13007 Mdot
.83 .1302 Mdot
.83 .1302 Mdot
.83 .1304 Mdot
.83 .13041 Mdot
.83 .13054 Mdot
.83 .13069 Mdot
.83 .1307 Mdot
.83 .13077 Mdot
.83 .1308 Mdot
.83 .13085 Mdot
.83 .13111 Mdot
.83 .13178 Mdot
.83 .13192 Mdot
.83 .13267 Mdot
.83 .13268 Mdot
.83 .13296 Mdot
.83 .1333 Mdot
.83 .13401 Mdot
.83 .13435 Mdot
.83 .13484 Mdot
.83 .13681 Mdot
.83 .13716 Mdot
.83 .13854 Mdot
.83 .1404 Mdot
.83 .14183 Mdot
.83 .1451 Mdot
.83 .1455 Mdot
.83 .14554 Mdot
.83 .15026 Mdot
.83 .15174 Mdot
.83 .1524 Mdot
.83 .15315 Mdot
.83 .15485 Mdot
.83 .15601 Mdot
.83 .1575 Mdot
.83 .15938 Mdot
.83 .16011 Mdot
.83 .16015 Mdot
.83 .16018 Mdot
.83 .16759 Mdot
.83 .16776 Mdot
.83 .1682 Mdot
.83 .1682 Mdot
.83 .17021 Mdot
.83 .17059 Mdot
.83 .17128 Mdot
.83 .17187 Mdot
.83 .17192 Mdot
.83 .1748 Mdot
.83 .17607 Mdot
.83 .17612 Mdot
.83 .17809 Mdot
.83 .17865 Mdot
.83 .17871 Mdot
.83 .17938 Mdot
.83 .17969 Mdot
.83 .18111 Mdot
.83 .18117 Mdot
.83 .1813 Mdot
.83 .18172 Mdot
.83 .18223 Mdot
.83 .18255 Mdot
.83 .18256 Mdot
.83 .18273 Mdot
.83 .18385 Mdot
.83 .18389 Mdot
.83 .18473 Mdot
.83 .18551 Mdot
.83 .18573 Mdot
.83 .18576 Mdot
.83 .18626 Mdot
.83 .18642 Mdot
.83 .18676 Mdot
.83 .18845 Mdot
.83 .19289 Mdot
.83 .1938 Mdot
.83 .19406 Mdot
.83 .1989 Mdot
.83 .19898 Mdot
.83 .20005 Mdot
.83 .20087 Mdot
.83 .20316 Mdot
.83 .2038 Mdot
.83 .20559 Mdot
.83 .20809 Mdot
.83 .21041 Mdot
.83 .21115 Mdot
.83 .21152 Mdot
.83 .21385 Mdot
.83 .214 Mdot
.83 .21492 Mdot
.83 .21527 Mdot
.83 .21681 Mdot
.83 .21775 Mdot
.83 .22257 Mdot
.83 .22306 Mdot
.83 .2234 Mdot
.83 .22459 Mdot
.83 .22793 Mdot
.83 .22849 Mdot
.83 .22922 Mdot
.83 .23044 Mdot
.83 .23082 Mdot
.83 .23108 Mdot
.83 .23262 Mdot
.83 .23292 Mdot
.83 .23342 Mdot
.83 .24054 Mdot
.83 .24356 Mdot
.83 .24701 Mdot
.83 .24751 Mdot
.83 .24862 Mdot
.83 .24912 Mdot
.83 .24927 Mdot
.83 .25028 Mdot
.83 .25326 Mdot
.83 .25436 Mdot
.83 .25681 Mdot
.83 .25956 Mdot
.83 .25958 Mdot
.83 .2649 Mdot
.83 .26507 Mdot
.83 .26543 Mdot
.83 .26575 Mdot
.83 .26656 Mdot
.83 .26669 Mdot
.83 .26672 Mdot
.83 .26673 Mdot
.83 .26677 Mdot
.83 .26678 Mdot
.83 .26686 Mdot
.83 .26693 Mdot
.83 .26693 Mdot
.83 .26703 Mdot
.83 .26703 Mdot
.83 .2671 Mdot
.83 .26714 Mdot
.83 .26715 Mdot
.83 .26727 Mdot
.83 .2673 Mdot
.83 .26735 Mdot
.83 .26736 Mdot
.83 .26757 Mdot
.83 .26793 Mdot
.83 .26799 Mdot
.83 .26826 Mdot
.83 .26826 Mdot
.83 .2683 Mdot
.83 .26939 Mdot
.83 .2695 Mdot
.83 .26974 Mdot
.83 .26996 Mdot
.83 .2705 Mdot
.83 .27122 Mdot
.83 .27142 Mdot
.83 .27202 Mdot
.83 .27225 Mdot
.83 .27271 Mdot
.83 .27286 Mdot
.83 .27319 Mdot
.83 .27328 Mdot
.83 .27421 Mdot
.83 .2747 Mdot
.83 .27534 Mdot
.83 .27564 Mdot
.83 .27596 Mdot
.83 .27617 Mdot
.83 .27655 Mdot
.83 .27736 Mdot
.83 .27765 Mdot
.83 .27787 Mdot
.83 .27842 Mdot
.83 .27842 Mdot
.83 .27881 Mdot
.83 .27903 Mdot
.83 .27906 Mdot
.83 .27917 Mdot
.83 .27947 Mdot
.83 .27949 Mdot
.83 .2795 Mdot
.83 .27954 Mdot
.83 .27956 Mdot
.83 .27966 Mdot
.83 .27978 Mdot
.83 .28031 Mdot
.83 .28073 Mdot
.83 .28105 Mdot
.83 .28165 Mdot
.83 .28211 Mdot
.83 .28247 Mdot
.83 .28268 Mdot
.83 .28302 Mdot
.83 .28303 Mdot
.83 .2837 Mdot
.83 .28425 Mdot
.83 .28437 Mdot
.83 .28492 Mdot
.83 .28495 Mdot
.83 .28565 Mdot
.83 .28672 Mdot
.83 .2875 Mdot
.83 .28755 Mdot
.83 .28817 Mdot
.83 .28827 Mdot
.83 .28858 Mdot
.83 .28878 Mdot
.83 .28918 Mdot
.83 .28963 Mdot
.83 .28988 Mdot
.83 .29005 Mdot
.83 .29066 Mdot
.83 .29109 Mdot
.83 .29172 Mdot
.83 .29251 Mdot
.83 .29253 Mdot
.83 .29284 Mdot
.83 .2931 Mdot
.83 .29343 Mdot
.83 .29388 Mdot
.83 .29442 Mdot
.83 .29458 Mdot
.83 .29521 Mdot
.83 .29524 Mdot
.83 .2955 Mdot
.83 .29646 Mdot
.83 .29719 Mdot
.83 .29732 Mdot
.83 .29753 Mdot
.83 .29849 Mdot
.83 .29918 Mdot
.83 .2995 Mdot
.83 .29999 Mdot
.83 .30087 Mdot
.83 .30235 Mdot
.83 .30262 Mdot
.83 .30427 Mdot
.83 .30471 Mdot
.83 .3048 Mdot
.83 .30596 Mdot
.83 .30611 Mdot
.83 .3065 Mdot
.83 .30655 Mdot
.83 .30665 Mdot
.83 .30687 Mdot
.83 .30813 Mdot
.83 .30857 Mdot
.83 .30909 Mdot
.83 .30992 Mdot
.83 .31075 Mdot
.83 .31076 Mdot
.83 .31116 Mdot
.83 .31186 Mdot
.83 .31255 Mdot
.83 .31376 Mdot
.83 .31383 Mdot
.83 .31528 Mdot
.83 .31647 Mdot
.83 .31734 Mdot
.83 .31786 Mdot
.83 .31816 Mdot
.83 .31842 Mdot
.83 .31879 Mdot
.83 .31988 Mdot
.83 .32175 Mdot
.83 .32219 Mdot
.83 .32219 Mdot
.83 .32255 Mdot
.83 .32262 Mdot
.83 .32278 Mdot
.83 .32279 Mdot
.83 .32288 Mdot
.83 .32393 Mdot
.83 .32434 Mdot
.83 .32444 Mdot
.83 .32461 Mdot
.83 .32525 Mdot
.83 .32666 Mdot
.83 .32668 Mdot
.83 .3272 Mdot
.83 .32872 Mdot
.83 .32952 Mdot
.83 .32975 Mdot
.83 .33022 Mdot
.83 .33061 Mdot
.83 .33148 Mdot
.83 .33229 Mdot
.83 .33294 Mdot
.83 .33349 Mdot
.83 .33368 Mdot
.83 .33419 Mdot
.83 .33449 Mdot
.83 .33513 Mdot
.83 .33595 Mdot
.83 .33714 Mdot
.83 .33722 Mdot
.83 .33837 Mdot
.83 .33905 Mdot
.83 .3409 Mdot
.83 .34112 Mdot
.83 .34286 Mdot
.83 .34612 Mdot
.83 .34665 Mdot
.83 .34702 Mdot
.83 .34836 Mdot
.83 .34897 Mdot
.83 .35063 Mdot
.83 .35088 Mdot
.83 .35182 Mdot
.83 .35189 Mdot
.83 .35228 Mdot
.83 .35243 Mdot
.83 .35338 Mdot
.83 .35436 Mdot
.83 .35453 Mdot
.83 .3552 Mdot
.83 .35609 Mdot
.83 .35676 Mdot
.83 .35827 Mdot
.83 .36058 Mdot
.83 .3615 Mdot
.83 .36183 Mdot
.83 .36256 Mdot
.83 .36305 Mdot
.83 .36445 Mdot
.83 .36475 Mdot
.83 .36476 Mdot
.83 .36781 Mdot
.83 .36799 Mdot
.83 .36799 Mdot
.83 .36918 Mdot
.83 .36942 Mdot
.83 .371 Mdot
.83 .37176 Mdot
.83 .37197 Mdot
.83 .37199 Mdot
.83 .37224 Mdot
.83 .37235 Mdot
.83 .37287 Mdot
.83 .3729 Mdot
.83 .37294 Mdot
.83 .3731 Mdot
.83 .37328 Mdot
.83 .3734 Mdot
.83 .3734 Mdot
.83 .37347 Mdot
.83 .37387 Mdot
.83 .37389 Mdot
.83 .37419 Mdot
.83 .37455 Mdot
.83 .37456 Mdot
.83 .37474 Mdot
.83 .3748 Mdot
.83 .37492 Mdot
.83 .37552 Mdot
.83 .37709 Mdot
.83 .37741 Mdot
.83 .37917 Mdot
.83 .37919 Mdot
.83 .37956 Mdot
.83 .37984 Mdot
.83 .38061 Mdot
.83 .38083 Mdot
.83 .38143 Mdot
.83 .38226 Mdot
.83 .38302 Mdot
.83 .38327 Mdot
.83 .38339 Mdot
.83 .38415 Mdot
.83 .3842 Mdot
.83 .3845 Mdot
.83 .38711 Mdot
.83 .38864 Mdot
.83 .38904 Mdot
.83 .38943 Mdot
.83 .38962 Mdot
.83 .3902 Mdot
.83 .39035 Mdot
.83 .39253 Mdot
.83 .39449 Mdot
.83 .39512 Mdot
.83 .39516 Mdot
.83 .39635 Mdot
.83 .39667 Mdot
.83 .3974 Mdot
.83 .3982 Mdot
.83 .39821 Mdot
.83 .39976 Mdot
.83 .39981 Mdot
.83 .39991 Mdot
.83 .40001 Mdot
.83 .40024 Mdot
.83 .40047 Mdot
.83 .40349 Mdot
.83 .40375 Mdot
.83 .40396 Mdot
.83 .40569 Mdot
.83 .40643 Mdot
.83 .40681 Mdot
.83 .40693 Mdot
.83 .40778 Mdot
.83 .40787 Mdot
.83 .40928 Mdot
.83 .40947 Mdot
.83 .41139 Mdot
.83 .41154 Mdot
.83 .41785 Mdot
.83 .41871 Mdot
.83 .41887 Mdot
.83 .41985 Mdot
.83 .42093 Mdot
.83 .42228 Mdot
.83 .42349 Mdot
.83 .42383 Mdot
.83 .42729 Mdot
.83 .42729 Mdot
.83 .42963 Mdot
.83 .4326 Mdot
.83 .43383 Mdot
.83 .43399 Mdot
.83 .43609 Mdot
.83 .43631 Mdot
.83 .43677 Mdot
.83 .4368 Mdot
.83 .43775 Mdot
.83 .43782 Mdot
.83 .43788 Mdot
.83 .43855 Mdot
.83 .4399 Mdot
.83 .44223 Mdot
.83 .44429 Mdot
.83 .44694 Mdot
.83 .44695 Mdot
.83 .44849 Mdot
.83 .44907 Mdot
.83 .45201 Mdot
.83 .45232 Mdot
.83 .45314 Mdot
.83 .45314 Mdot
.83 .45454 Mdot
.83 .45561 Mdot
.83 .45682 Mdot
.83 .45751 Mdot
.83 .45841 Mdot
.83 .45842 Mdot
.83 .45877 Mdot
.83 .45983 Mdot
.83 .45991 Mdot
.83 .46318 Mdot
.83 .46505 Mdot
.83 .46681 Mdot
.83 .46729 Mdot
.83 .46736 Mdot
.83 .47077 Mdot
.83 .47084 Mdot
.83 .47174 Mdot
.83 .47183 Mdot
.83 .47299 Mdot
.83 .47316 Mdot
.83 .4735 Mdot
.83 .4743 Mdot
.83 .4744 Mdot
.83 .47452 Mdot
.83 .4759 Mdot
.83 .47601 Mdot
.83 .47612 Mdot
.83 .47616 Mdot
.83 .47623 Mdot
.83 .47693 Mdot
.83 .47694 Mdot
.83 .4773 Mdot
.83 .47778 Mdot
.83 .47831 Mdot
.83 .47833 Mdot
.83 .47861 Mdot
.83 .48046 Mdot
.83 .48053 Mdot
.83 .48078 Mdot
.83 .48104 Mdot
.83 .48189 Mdot
.83 .48304 Mdot
.83 .48317 Mdot
.83 .48353 Mdot
.83 .48358 Mdot
.83 .48438 Mdot
.83 .48464 Mdot
.83 .48519 Mdot
.83 .4878 Mdot
.83 .48788 Mdot
.83 .49147 Mdot
.83 .49148 Mdot
.83 .49479 Mdot
.83 .49617 Mdot
.83 .49655 Mdot
.83 .49677 Mdot
.83 .49728 Mdot
.83 .4991 Mdot
.83 .50109 Mdot
.83 .50266 Mdot
.83 .5037 Mdot
.83 .50382 Mdot
.83 .50409 Mdot
.83 .50431 Mdot
.83 .50537 Mdot
.83 .50555 Mdot
.83 .50653 Mdot
.83 .50975 Mdot
.83 .51063 Mdot
.83 .51309 Mdot
.83 .5143 Mdot
.83 .5145 Mdot
.83 .51644 Mdot
.83 .51706 Mdot
.83 .51731 Mdot
.83 .51915 Mdot
.83 .51927 Mdot
.83 .51948 Mdot
.83 .52037 Mdot
.83 .52044 Mdot
.83 .52053 Mdot
.83 .5209 Mdot
.83 .52102 Mdot
.83 .52195 Mdot
.83 .52385 Mdot
.83 .52404 Mdot
.83 .52413 Mdot
.83 .52439 Mdot
.83 .52472 Mdot
.83 .52518 Mdot
.83 .52561 Mdot
.83 .52749 Mdot
.83 .5284 Mdot
.83 .52863 Mdot
.83 .52868 Mdot
.83 .52896 Mdot
.83 .52907 Mdot
.83 .52919 Mdot
.83 .52925 Mdot
.83 .53108 Mdot
.83 .53109 Mdot
.83 .53203 Mdot
.83 .53286 Mdot
.83 .53324 Mdot
.83 .53425 Mdot
.83 .53459 Mdot
.83 .53464 Mdot
.83 .53481 Mdot
.83 .53518 Mdot
.83 .53535 Mdot
.83 .53651 Mdot
.83 .53752 Mdot
.83 .53988 Mdot
.83 .54004 Mdot
.83 .54014 Mdot
.83 .54065 Mdot
.83 .54074 Mdot
.83 .54086 Mdot
.83 .54126 Mdot
.83 .5415 Mdot
.83 .54169 Mdot
.83 .54278 Mdot
.83 .54316 Mdot
.83 .54327 Mdot
.83 .54343 Mdot
.83 .54499 Mdot
.83 .5453 Mdot
.83 .54579 Mdot
.83 .54591 Mdot
.83 .5462 Mdot
.83 .54625 Mdot
.83 .547 Mdot
.83 .54711 Mdot
.83 .54735 Mdot
.83 .54809 Mdot
.83 .54889 Mdot
.83 .54946 Mdot
.83 .54966 Mdot
.83 .55038 Mdot
.83 .55064 Mdot
.83 .55098 Mdot
.83 .551 Mdot
.83 .55252 Mdot
.83 .5526 Mdot
.83 .55288 Mdot
.83 .55427 Mdot
.83 .55479 Mdot
.83 .5549 Mdot
.83 .55495 Mdot
.83 .5551 Mdot
.83 .55511 Mdot
.83 .55518 Mdot
.83 .55542 Mdot
.83 .55568 Mdot
.83 .55569 Mdot
.83 .55604 Mdot
.83 .55609 Mdot
.83 .55609 Mdot
.83 .55619 Mdot
.83 .55635 Mdot
.83 .55648 Mdot
.83 .55652 Mdot
.83 .55654 Mdot
.83 .55698 Mdot
.83 .55707 Mdot
.83 .55728 Mdot
.83 .55729 Mdot
.83 .55747 Mdot
.83 .55807 Mdot
.83 .55808 Mdot
.83 .55847 Mdot
.83 .55935 Mdot
.83 .55936 Mdot
.83 .55954 Mdot
.83 .55975 Mdot
.83 .55987 Mdot
.83 .56048 Mdot
.83 .56048 Mdot
.83 .56061 Mdot
.83 .56066 Mdot
.83 .5629 Mdot
.83 .56291 Mdot
.83 .56292 Mdot
.83 .56314 Mdot
.83 .5637 Mdot
.83 .56414 Mdot
.83 .56449 Mdot
.83 .565 Mdot
.83 .56522 Mdot
.83 .56542 Mdot
.83 .56586 Mdot
.83 .56725 Mdot
.83 .56726 Mdot
.83 .56738 Mdot
.83 .56834 Mdot
.83 .56876 Mdot
.83 .56931 Mdot
.83 .56971 Mdot
.83 .56981 Mdot
.83 .57039 Mdot
.83 .57053 Mdot
.83 .57063 Mdot
.83 .57084 Mdot
.83 .57093 Mdot
.83 .57102 Mdot
.83 .57102 Mdot
.83 .57124 Mdot
.83 .57128 Mdot
.83 .57147 Mdot
.83 .57155 Mdot
.83 .57156 Mdot
.83 .57157 Mdot
.83 .57159 Mdot
.83 .57159 Mdot
.83 .57164 Mdot
.83 .57168 Mdot
.83 .57168 Mdot
.83 .57174 Mdot
.83 .57174 Mdot
.83 .57177 Mdot
.83 .57179 Mdot
.83 .5718 Mdot
.83 .5718 Mdot
.83 .57187 Mdot
.83 .57188 Mdot
.83 .57191 Mdot
.83 .57191 Mdot
.83 .57194 Mdot
.83 .57203 Mdot
.83 .57223 Mdot
.83 .57225 Mdot
.83 .5724 Mdot
.83 .5724 Mdot
.83 .57242 Mdot
.83 .57283 Mdot
.83 .573 Mdot
.83 .57306 Mdot
.83 .57314 Mdot
.83 .57318 Mdot
.83 .57329 Mdot
.83 .57357 Mdot
.83 .57382 Mdot
.83 .57393 Mdot
.83 .57401 Mdot
.83 .57403 Mdot
.83 .57427 Mdot
.83 .57432 Mdot
.83 .57443 Mdot
.83 .57465 Mdot
.83 .57472 Mdot
.83 .57488 Mdot
.83 .57492 Mdot
.83 .57536 Mdot
.83 .57558 Mdot
.83 .57579 Mdot
.83 .57586 Mdot
.83 .57599 Mdot
.83 .57614 Mdot
.83 .57623 Mdot
.83 .57639 Mdot
.83 .57654 Mdot
.83 .57663 Mdot
.83 .57673 Mdot
.83 .57685 Mdot
.83 .57694 Mdot
.83 .57716 Mdot
.83 .57716 Mdot
.83 .57732 Mdot
.83 .57739 Mdot
.83 .5774 Mdot
.83 .57742 Mdot
.83 .57746 Mdot
.83 .57757 Mdot
.83 .57758 Mdot
.83 .57759 Mdot
.83 .5776 Mdot
.83 .57761 Mdot
.83 .57765 Mdot
.83 .57765 Mdot
.83 .5777 Mdot
.83 .5779 Mdot
.83 .57806 Mdot
.83 .57808 Mdot
.83 .57812 Mdot
.83 .57817 Mdot
.83 .57839 Mdot
.83 .57855 Mdot
.83 .57855 Mdot
.83 .57868 Mdot
.83 .57876 Mdot
.83 .57883 Mdot
.83 .57887 Mdot
.83 .57887 Mdot
.83 .57905 Mdot
.83 .5791 Mdot
.83 .57915 Mdot
.83 .57928 Mdot
.83 .57931 Mdot
.83 .57932 Mdot
.83 .57937 Mdot
.83 .5795 Mdot
.83 .57951 Mdot
.83 .57955 Mdot
.83 .57972 Mdot
.83 .57975 Mdot
.83 .57999 Mdot
.83 .58004 Mdot
.83 .58025 Mdot
.83 .58027 Mdot
.83 .58028 Mdot
.83 .58036 Mdot
.83 .58045 Mdot
.83 .58048 Mdot
.83 .58048 Mdot
.83 .58055 Mdot
.83 .58056 Mdot
.83 .58062 Mdot
.83 .58072 Mdot
.83 .58076 Mdot
.83 .58084 Mdot
.83 .5809 Mdot
.83 .58095 Mdot
.83 .58109 Mdot
.83 .58113 Mdot
.83 .5812 Mdot
.83 .58126 Mdot
.83 .58126 Mdot
.83 .58134 Mdot
.83 .58152 Mdot
.83 .58152 Mdot
.83 .58158 Mdot
.83 .58159 Mdot
.83 .58164 Mdot
.83 .58171 Mdot
.83 .58171 Mdot
.83 .58175 Mdot
.83 .58177 Mdot
.83 .5818 Mdot
.83 .58185 Mdot
.83 .58191 Mdot
.83 .58194 Mdot
.83 .58204 Mdot
.83 .58205 Mdot
.83 .58206 Mdot
.83 .58206 Mdot
.83 .58206 Mdot
.83 .58209 Mdot
.83 .5821 Mdot
.83 .58211 Mdot
.83 .58217 Mdot
.83 .58217 Mdot
.83 .58224 Mdot
.83 .58227 Mdot
.83 .58239 Mdot
.83 .58241 Mdot
.83 .58244 Mdot
.83 .58253 Mdot
.83 .58258 Mdot
.83 .58267 Mdot
.83 .58268 Mdot
.83 .58271 Mdot
.83 .58273 Mdot
.83 .58276 Mdot
.83 .58277 Mdot
.83 .58279 Mdot
.83 .58285 Mdot
.83 .58287 Mdot
.83 .58294 Mdot
.83 .58301 Mdot
.83 .58304 Mdot
.83 .58305 Mdot
.83 .58315 Mdot
.83 .58316 Mdot
.83 .58316 Mdot
.83 .58318 Mdot
.83 .58319 Mdot
.83 .58322 Mdot
.83 .58325 Mdot
.83 .58325 Mdot
.83 .58325 Mdot
.83 .58327 Mdot
.83 .58327 Mdot
.83 .58327 Mdot
.83 .58328 Mdot
.83 .58328 Mdot
.83 .58329 Mdot
.83 .58329 Mdot
.83 .5833 Mdot
.83 .5833 Mdot
.83 .58331 Mdot
.83 .58331 Mdot
.832 .0886 Mdot
.832 .08862 Mdot
.832 .08864 Mdot
.832 .08865 Mdot
.832 .08865 Mdot
.832 .08875 Mdot
.832 .08875 Mdot
.832 .0888 Mdot
.832 .08881 Mdot
.832 .08884 Mdot
.832 .08886 Mdot
.832 .08888 Mdot
.832 .08892 Mdot
.832 .08898 Mdot
.832 .08904 Mdot
.832 .08917 Mdot
.832 .08917 Mdot
.832 .08922 Mdot
.832 .08924 Mdot
.832 .08925 Mdot
.832 .08932 Mdot
.832 .08935 Mdot
.832 .08938 Mdot
.832 .08968 Mdot
.832 .08972 Mdot
.832 .08982 Mdot
.832 .08985 Mdot
.832 .08999 Mdot
.832 .09001 Mdot
.832 .0901 Mdot
.832 .09025 Mdot
.832 .09042 Mdot
.832 .09044 Mdot
.832 .09066 Mdot
.832 .09072 Mdot
.832 .09072 Mdot
.832 .0909 Mdot
.832 .09092 Mdot
.832 .09099 Mdot
.832 .09128 Mdot
.832 .0913 Mdot
.832 .09134 Mdot
.832 .09174 Mdot
.832 .09178 Mdot
.832 .09192 Mdot
.832 .09211 Mdot
.832 .09212 Mdot
.832 .09243 Mdot
.832 .09265 Mdot
.832 .09271 Mdot
.832 .09274 Mdot
.832 .09291 Mdot
.832 .09321 Mdot
.832 .09329 Mdot
.832 .09345 Mdot
.832 .09345 Mdot
.832 .09363 Mdot
.832 .09364 Mdot
.832 .0941 Mdot
.832 .09415 Mdot
.832 .09431 Mdot
.832 .09455 Mdot
.832 .09461 Mdot
.832 .09464 Mdot
.832 .09523 Mdot
.832 .09524 Mdot
.832 .09524 Mdot
.832 .09566 Mdot
.832 .09567 Mdot
.832 .0959 Mdot
.832 .09598 Mdot
.832 .09632 Mdot
.832 .09667 Mdot
.832 .09677 Mdot
.832 .09681 Mdot
.832 .09694 Mdot
.832 .0971 Mdot
.832 .09793 Mdot
.832 .09841 Mdot
.832 .09885 Mdot
.832 .09919 Mdot
.832 .09929 Mdot
.832 .09959 Mdot
.832 .0997 Mdot
.832 .09974 Mdot
.832 .10029 Mdot
.832 .10059 Mdot
.832 .10062 Mdot
.832 .10092 Mdot
.832 .10106 Mdot
.832 .10161 Mdot
.832 .10172 Mdot
.832 .10187 Mdot
.832 .10201 Mdot
.832 .10261 Mdot
.832 .10262 Mdot
.832 .10265 Mdot
.832 .10274 Mdot
.832 .10361 Mdot
.832 .10399 Mdot
.832 .10401 Mdot
.832 .10405 Mdot
.832 .10492 Mdot
.832 .10576 Mdot
.832 .10595 Mdot
.832 .10608 Mdot
.832 .10619 Mdot
.832 .10641 Mdot
.832 .10663 Mdot
.832 .10668 Mdot
.832 .10671 Mdot
.832 .1071 Mdot
.832 .10726 Mdot
.832 .10746 Mdot
.832 .1077 Mdot
.832 .10787 Mdot
.832 .10807 Mdot
.832 .10812 Mdot
.832 .10936 Mdot
.832 .10983 Mdot
.832 .10988 Mdot
.832 .11036 Mdot
.832 .11056 Mdot
.832 .11059 Mdot
.832 .11061 Mdot
.832 .11091 Mdot
.832 .11111 Mdot
.832 .11111 Mdot
.832 .11126 Mdot
.832 .11157 Mdot
.832 .11164 Mdot
.832 .11283 Mdot
.832 .11316 Mdot
.832 .11356 Mdot
.832 .11366 Mdot
.832 .11388 Mdot
.832 .11391 Mdot
.832 .11489 Mdot
.832 .11625 Mdot
.832 .11631 Mdot
.832 .1164 Mdot
.832 .11701 Mdot
.832 .1172 Mdot
.832 .11785 Mdot
.832 .118 Mdot
.832 .11936 Mdot
.832 .11943 Mdot
.832 .11989 Mdot
.832 .12009 Mdot
.832 .12018 Mdot
.832 .12161 Mdot
.832 .12195 Mdot
.832 .12204 Mdot
.832 .12273 Mdot
.832 .12296 Mdot
.832 .12297 Mdot
.832 .12303 Mdot
.832 .12327 Mdot
.832 .12352 Mdot
.832 .12439 Mdot
.832 .12447 Mdot
.832 .12505 Mdot
.832 .12535 Mdot
.832 .12595 Mdot
.832 .12615 Mdot
.832 .1264 Mdot
.832 .12662 Mdot
.832 .12673 Mdot
.832 .12739 Mdot
.832 .12747 Mdot
.832 .12761 Mdot
.832 .12817 Mdot
.832 .12837 Mdot
.832 .13006 Mdot
.832 .13019 Mdot
.832 .13038 Mdot
.832 .13073 Mdot
.832 .1308 Mdot
.832 .1309 Mdot
.832 .1312 Mdot
.832 .13122 Mdot
.832 .13192 Mdot
.832 .13225 Mdot
.832 .13259 Mdot
.832 .13283 Mdot
.832 .13294 Mdot
.832 .13309 Mdot
.832 .13312 Mdot
.832 .13324 Mdot
.832 .1333 Mdot
.832 .13358 Mdot
.832 .13359 Mdot
.832 .13417 Mdot
.832 .13418 Mdot
.832 .13422 Mdot
.832 .13436 Mdot
.832 .13449 Mdot
.832 .13461 Mdot
.832 .13478 Mdot
.832 .13524 Mdot
.832 .13767 Mdot
.832 .13869 Mdot
.832 .13874 Mdot
.832 .13989 Mdot
.832 .13997 Mdot
.832 .14026 Mdot
.832 .14108 Mdot
.832 .14154 Mdot
.832 .14282 Mdot
.832 .14511 Mdot
.832 .14513 Mdot
.832 .14754 Mdot
.832 .14798 Mdot
.832 .15051 Mdot
.832 .15115 Mdot
.832 .15286 Mdot
.832 .15504 Mdot
.832 .1563 Mdot
.832 .15742 Mdot
.832 .15889 Mdot
.832 .15934 Mdot
.832 .16018 Mdot
.832 .16082 Mdot
.832 .1617 Mdot
.832 .1624 Mdot
.832 .16375 Mdot
.832 .16474 Mdot
.832 .16479 Mdot
.832 .16522 Mdot
.832 .1661 Mdot
.832 .16642 Mdot
.832 .16947 Mdot
.832 .17074 Mdot
.832 .17219 Mdot
.832 .17242 Mdot
.832 .1755 Mdot
.832 .1765 Mdot
.832 .17715 Mdot
.832 .1795 Mdot
.832 .18139 Mdot
.832 .18221 Mdot
.832 .18343 Mdot
.832 .18576 Mdot
.832 .18619 Mdot
.832 .18688 Mdot
.832 .1888 Mdot
.832 .18887 Mdot
.832 .18897 Mdot
.832 .18928 Mdot
.832 .19041 Mdot
.832 .19114 Mdot
.832 .19364 Mdot
.832 .19587 Mdot
.832 .1973 Mdot
.832 .19817 Mdot
.832 .19855 Mdot
.832 .19981 Mdot
.832 .20055 Mdot
.832 .20156 Mdot
.832 .20174 Mdot
.832 .20257 Mdot
.832 .20301 Mdot
.832 .20477 Mdot
.832 .20489 Mdot
.832 .20492 Mdot
.832 .20502 Mdot
.832 .20899 Mdot
.832 .20909 Mdot
.832 .20938 Mdot
.832 .20968 Mdot
.832 .21036 Mdot
.832 .21124 Mdot
.832 .21211 Mdot
.832 .21275 Mdot
.832 .21329 Mdot
.832 .21354 Mdot
.832 .21402 Mdot
.832 .21658 Mdot
.832 .23405 Mdot
.832 .24159 Mdot
.832 .24198 Mdot
.832 .24824 Mdot
.832 .25048 Mdot
.832 .25112 Mdot
.832 .25207 Mdot
.832 .25332 Mdot
.832 .25704 Mdot
.832 .25942 Mdot
.832 .25943 Mdot
.832 .26128 Mdot
.832 .26241 Mdot
.832 .26291 Mdot
.832 .26446 Mdot
.832 .26453 Mdot
.832 .2646 Mdot
.832 .26462 Mdot
.832 .26462 Mdot
.832 .26491 Mdot
.832 .26492 Mdot
.832 .26506 Mdot
.832 .26509 Mdot
.832 .26516 Mdot
.832 .26524 Mdot
.832 .26529 Mdot
.832 .26541 Mdot
.832 .26559 Mdot
.832 .26576 Mdot
.832 .26612 Mdot
.832 .26613 Mdot
.832 .26628 Mdot
.832 .26633 Mdot
.832 .26637 Mdot
.832 .26655 Mdot
.832 .26665 Mdot
.832 .26672 Mdot
.832 .26761 Mdot
.832 .26772 Mdot
.832 .26801 Mdot
.832 .26809 Mdot
.832 .26849 Mdot
.832 .26855 Mdot
.832 .2688 Mdot
.832 .26924 Mdot
.832 .26973 Mdot
.832 .26977 Mdot
.832 .27027 Mdot
.832 .2704 Mdot
.832 .27057 Mdot
.832 .27058 Mdot
.832 .27111 Mdot
.832 .27116 Mdot
.832 .27136 Mdot
.832 .27219 Mdot
.832 .27225 Mdot
.832 .27237 Mdot
.832 .27264 Mdot
.832 .27351 Mdot
.832 .2736 Mdot
.832 .274 Mdot
.832 .27456 Mdot
.832 .2746 Mdot
.832 .27547 Mdot
.832 .27611 Mdot
.832 .27627 Mdot
.832 .27634 Mdot
.832 .27683 Mdot
.832 .27764 Mdot
.832 .27768 Mdot
.832 .2779 Mdot
.832 .27835 Mdot
.832 .27836 Mdot
.832 .27887 Mdot
.832 .2789 Mdot
.832 .27925 Mdot
.832 .2802 Mdot
.832 .28034 Mdot
.832 .28047 Mdot
.832 .2808 Mdot
.832 .28093 Mdot
.832 .28129 Mdot
.832 .28147 Mdot
.832 .28164 Mdot
.832 .28172 Mdot
.832 .28182 Mdot
.832 .28337 Mdot
.832 .2834 Mdot
.832 .28342 Mdot
.832 .28374 Mdot
.832 .28459 Mdot
.832 .2846 Mdot
.832 .28526 Mdot
.832 .28549 Mdot
.832 .286 Mdot
.832 .28644 Mdot
.832 .28673 Mdot
.832 .28741 Mdot
.832 .2877 Mdot
.832 .28781 Mdot
.832 .28816 Mdot
.832 .28861 Mdot
.832 .28912 Mdot
.832 .29021 Mdot
.832 .29039 Mdot
.832 .29092 Mdot
.832 .29223 Mdot
.832 .29225 Mdot
.832 .29345 Mdot
.832 .2944 Mdot
.832 .29468 Mdot
.832 .29469 Mdot
.832 .29551 Mdot
.832 .29578 Mdot
.832 .29582 Mdot
.832 .29591 Mdot
.832 .2968 Mdot
.832 .29682 Mdot
.832 .29717 Mdot
.832 .29742 Mdot
.832 .29824 Mdot
.832 .29832 Mdot
.832 .29895 Mdot
.832 .29914 Mdot
.832 .29954 Mdot
.832 .30104 Mdot
.832 .30134 Mdot
.832 .30173 Mdot
.832 .30212 Mdot
.832 .30374 Mdot
.832 .30379 Mdot
.832 .30386 Mdot
.832 .3041 Mdot
.832 .30646 Mdot
.832 .30749 Mdot
.832 .30752 Mdot
.832 .30763 Mdot
.832 .30899 Mdot
.832 .30997 Mdot
.832 .31159 Mdot
.832 .31196 Mdot
.832 .31204 Mdot
.832 .31221 Mdot
.832 .31238 Mdot
.832 .31249 Mdot
.832 .31274 Mdot
.832 .31307 Mdot
.832 .31336 Mdot
.832 .31395 Mdot
.832 .31454 Mdot
.832 .31467 Mdot
.832 .31476 Mdot
.832 .3158 Mdot
.832 .31622 Mdot
.832 .31675 Mdot
.832 .31738 Mdot
.832 .3178 Mdot
.832 .31784 Mdot
.832 .31835 Mdot
.832 .31849 Mdot
.832 .31893 Mdot
.832 .31967 Mdot
.832 .32055 Mdot
.832 .32175 Mdot
.832 .32299 Mdot
.832 .32311 Mdot
.832 .32362 Mdot
.832 .32428 Mdot
.832 .32435 Mdot
.832 .3249 Mdot
.832 .32498 Mdot
.832 .32502 Mdot
.832 .32579 Mdot
.832 .32632 Mdot
.832 .32633 Mdot
.832 .32661 Mdot
.832 .32671 Mdot
.832 .32752 Mdot
.832 .32768 Mdot
.832 .32801 Mdot
.832 .33074 Mdot
.832 .33077 Mdot
.832 .33162 Mdot
.832 .3319 Mdot
.832 .33264 Mdot
.832 .3329 Mdot
.832 .33347 Mdot
.832 .33355 Mdot
.832 .33538 Mdot
.832 .33605 Mdot
.832 .33678 Mdot
.832 .3368 Mdot
.832 .33738 Mdot
.832 .33787 Mdot
.832 .3395 Mdot
.832 .33965 Mdot
.832 .33989 Mdot
.832 .34003 Mdot
.832 .34003 Mdot
.832 .34143 Mdot
.832 .34191 Mdot
.832 .34353 Mdot
.832 .34391 Mdot
.832 .34535 Mdot
.832 .34732 Mdot
.832 .34749 Mdot
.832 .34862 Mdot
.832 .34912 Mdot
.832 .34937 Mdot
.832 .3499 Mdot
.832 .35288 Mdot
.832 .35363 Mdot
.832 .35371 Mdot
.832 .35395 Mdot
.832 .35565 Mdot
.832 .35619 Mdot
.832 .35623 Mdot
.832 .35637 Mdot
.832 .35696 Mdot
.832 .35756 Mdot
.832 .35969 Mdot
.832 .35989 Mdot
.832 .36127 Mdot
.832 .36201 Mdot
.832 .36293 Mdot
.832 .36346 Mdot
.832 .36393 Mdot
.832 .36453 Mdot
.832 .36506 Mdot
.832 .36532 Mdot
.832 .36568 Mdot
.832 .3665 Mdot
.832 .36689 Mdot
.832 .36708 Mdot
.832 .36743 Mdot
.832 .36874 Mdot
.832 .36923 Mdot
.832 .36988 Mdot
.832 .37104 Mdot
.832 .37141 Mdot
.832 .37166 Mdot
.832 .37252 Mdot
.832 .37322 Mdot
.832 .37351 Mdot
.832 .37396 Mdot
.832 .3748 Mdot
.832 .37495 Mdot
.832 .3752 Mdot
.832 .37588 Mdot
.832 .3759 Mdot
.832 .37594 Mdot
.832 .3767 Mdot
.832 .37757 Mdot
.832 .37834 Mdot
.832 .37883 Mdot
.832 .37913 Mdot
.832 .37969 Mdot
.832 .37994 Mdot
.832 .38028 Mdot
.832 .38034 Mdot
.832 .38062 Mdot
.832 .38077 Mdot
.832 .38136 Mdot
.832 .3814 Mdot
.832 .38141 Mdot
.832 .38144 Mdot
.832 .38276 Mdot
.832 .38279 Mdot
.832 .38288 Mdot
.832 .38298 Mdot
.832 .38321 Mdot
.832 .38349 Mdot
.832 .38378 Mdot
.832 .38416 Mdot
.832 .38424 Mdot
.832 .3844 Mdot
.832 .38523 Mdot
.832 .39072 Mdot
.832 .39302 Mdot
.832 .39314 Mdot
.832 .39502 Mdot
.832 .39568 Mdot
.832 .39587 Mdot
.832 .39615 Mdot
.832 .39652 Mdot
.832 .39762 Mdot
.832 .39831 Mdot
.832 .39832 Mdot
.832 .39886 Mdot
.832 .39919 Mdot
.832 .39933 Mdot
.832 .40214 Mdot
.832 .40356 Mdot
.832 .40436 Mdot
.832 .4046 Mdot
.832 .40613 Mdot
.832 .4071 Mdot
.832 .40715 Mdot
.832 .40894 Mdot
.832 .40954 Mdot
.832 .4123 Mdot
.832 .41323 Mdot
.832 .41471 Mdot
.832 .41522 Mdot
.832 .41711 Mdot
.832 .41854 Mdot
.832 .41986 Mdot
.832 .42002 Mdot
.832 .42015 Mdot
.832 .42073 Mdot
.832 .42339 Mdot
.832 .42784 Mdot
.832 .42946 Mdot
.832 .43037 Mdot
.832 .43058 Mdot
.832 .43184 Mdot
.832 .43261 Mdot
.832 .43265 Mdot
.832 .43552 Mdot
.832 .43622 Mdot
.832 .43641 Mdot
.832 .43656 Mdot
.832 .43783 Mdot
.832 .43805 Mdot
.832 .43812 Mdot
.832 .4393 Mdot
.832 .43946 Mdot
.832 .44102 Mdot
.832 .44234 Mdot
.832 .44237 Mdot
.832 .44495 Mdot
.832 .44526 Mdot
.832 .44684 Mdot
.832 .44694 Mdot
.832 .44737 Mdot
.832 .44775 Mdot
.832 .4494 Mdot
.832 .45 Mdot
.832 .45301 Mdot
.832 .45412 Mdot
.832 .45565 Mdot
.832 .45713 Mdot
.832 .45782 Mdot
.832 .45797 Mdot
.832 .45862 Mdot
.832 .45879 Mdot
.832 .46059 Mdot
.832 .461 Mdot
.832 .46163 Mdot
.832 .46219 Mdot
.832 .46647 Mdot
.832 .46675 Mdot
.832 .46681 Mdot
.832 .46821 Mdot
.832 .46911 Mdot
.832 .46935 Mdot
.832 .47179 Mdot
.832 .47207 Mdot
.832 .47338 Mdot
.832 .47409 Mdot
.832 .47419 Mdot
.832 .47456 Mdot
.832 .47656 Mdot
.832 .47671 Mdot
.832 .47696 Mdot
.832 .47727 Mdot
.832 .47793 Mdot
.832 .47845 Mdot
.832 .47997 Mdot
.832 .48315 Mdot
.832 .48322 Mdot
.832 .48377 Mdot
.832 .48446 Mdot
.832 .48448 Mdot
.832 .48557 Mdot
.832 .48648 Mdot
.832 .48683 Mdot
.832 .48827 Mdot
.832 .48864 Mdot
.832 .48874 Mdot
.832 .4889 Mdot
.832 .48939 Mdot
.832 .49081 Mdot
.832 .49115 Mdot
.832 .4923 Mdot
.832 .49612 Mdot
.832 .49763 Mdot
.832 .49946 Mdot
.832 .50157 Mdot
.832 .50158 Mdot
.832 .50243 Mdot
.832 .50262 Mdot
.832 .50285 Mdot
.832 .50286 Mdot
.832 .50341 Mdot
.832 .50476 Mdot
.832 .50522 Mdot
.832 .50627 Mdot
.832 .50681 Mdot
.832 .5077 Mdot
.832 .50796 Mdot
.832 .50913 Mdot
.832 .50946 Mdot
.832 .50974 Mdot
.832 .51017 Mdot
.832 .51217 Mdot
.832 .51221 Mdot
.832 .51234 Mdot
.832 .51237 Mdot
.832 .51251 Mdot
.832 .51348 Mdot
.832 .51718 Mdot
.832 .51784 Mdot
.832 .51796 Mdot
.832 .51797 Mdot
.832 .51834 Mdot
.832 .51874 Mdot
.832 .51962 Mdot
.832 .52029 Mdot
.832 .52036 Mdot
.832 .52075 Mdot
.832 .52161 Mdot
.832 .52187 Mdot
.832 .52268 Mdot
.832 .52336 Mdot
.832 .52355 Mdot
.832 .52368 Mdot
.832 .52384 Mdot
.832 .52427 Mdot
.832 .52484 Mdot
.832 .52659 Mdot
.832 .52742 Mdot
.832 .52997 Mdot
.832 .53014 Mdot
.832 .53053 Mdot
.832 .53117 Mdot
.832 .53117 Mdot
.832 .53199 Mdot
.832 .53325 Mdot
.832 .53368 Mdot
.832 .534 Mdot
.832 .53422 Mdot
.832 .53497 Mdot
.832 .53707 Mdot
.832 .5372 Mdot
.832 .5397 Mdot
.832 .5454 Mdot
.832 .54622 Mdot
.832 .54638 Mdot
.832 .54646 Mdot
.832 .54663 Mdot
.832 .54683 Mdot
.832 .54711 Mdot
.832 .54739 Mdot
.832 .54761 Mdot
.832 .54771 Mdot
.832 .5478 Mdot
.832 .54783 Mdot
.832 .54909 Mdot
.832 .54913 Mdot
.832 .54913 Mdot
.832 .54917 Mdot
.832 .54973 Mdot
.832 .54987 Mdot
.832 .55013 Mdot
.832 .55019 Mdot
.832 .55051 Mdot
.832 .55074 Mdot
.832 .55125 Mdot
.832 .55153 Mdot
.832 .55198 Mdot
.832 .55267 Mdot
.832 .55345 Mdot
.832 .55368 Mdot
.832 .55403 Mdot
.832 .55413 Mdot
.832 .55416 Mdot
.832 .55418 Mdot
.832 .55478 Mdot
.832 .55499 Mdot
.832 .55512 Mdot
.832 .55584 Mdot
.832 .55622 Mdot
.832 .55647 Mdot
.832 .55705 Mdot
.832 .55777 Mdot
.832 .55797 Mdot
.832 .55828 Mdot
.832 .55922 Mdot
.832 .55929 Mdot
.832 .55973 Mdot
.832 .56011 Mdot
.832 .56104 Mdot
.832 .56113 Mdot
.832 .5614 Mdot
.832 .56153 Mdot
.832 .56154 Mdot
.832 .56184 Mdot
.832 .56225 Mdot
.832 .56246 Mdot
.832 .56272 Mdot
.832 .56292 Mdot
.832 .56317 Mdot
.832 .5633 Mdot
.832 .56374 Mdot
.832 .56408 Mdot
.832 .56445 Mdot
.832 .5651 Mdot
.832 .56561 Mdot
.832 .5658 Mdot
.832 .56655 Mdot
.832 .56668 Mdot
.832 .56739 Mdot
.832 .56739 Mdot
.832 .56807 Mdot
.832 .56844 Mdot
.832 .56858 Mdot
.832 .56882 Mdot
.832 .5689 Mdot
.832 .56893 Mdot
.832 .56926 Mdot
.832 .56928 Mdot
.832 .56958 Mdot
.832 .57029 Mdot
.832 .57042 Mdot
.832 .57047 Mdot
.832 .57051 Mdot
.832 .57054 Mdot
.832 .57058 Mdot
.832 .5706 Mdot
.832 .5706 Mdot
.832 .57077 Mdot
.832 .57077 Mdot
.832 .57085 Mdot
.832 .57087 Mdot
.832 .5709 Mdot
.832 .57091 Mdot
.832 .57095 Mdot
.832 .57099 Mdot
.832 .57106 Mdot
.832 .57116 Mdot
.832 .57125 Mdot
.832 .57145 Mdot
.832 .57146 Mdot
.832 .57155 Mdot
.832 .57158 Mdot
.832 .5716 Mdot
.832 .5717 Mdot
.832 .57175 Mdot
.832 .57179 Mdot
.832 .57228 Mdot
.832 .57234 Mdot
.832 .5725 Mdot
.832 .57254 Mdot
.832 .57256 Mdot
.832 .57275 Mdot
.832 .57279 Mdot
.832 .57285 Mdot
.832 .57292 Mdot
.832 .57298 Mdot
.832 .57315 Mdot
.832 .57324 Mdot
.832 .5734 Mdot
.832 .57343 Mdot
.832 .57368 Mdot
.832 .57375 Mdot
.832 .57382 Mdot
.832 .57384 Mdot
.832 .57384 Mdot
.832 .57391 Mdot
.832 .5741 Mdot
.832 .57413 Mdot
.832 .57423 Mdot
.832 .57464 Mdot
.832 .57467 Mdot
.832 .57472 Mdot
.832 .57485 Mdot
.832 .57487 Mdot
.832 .57526 Mdot
.832 .57531 Mdot
.832 .57549 Mdot
.832 .57555 Mdot
.832 .57572 Mdot
.832 .57575 Mdot
.832 .57576 Mdot
.832 .57615 Mdot
.832 .57643 Mdot
.832 .57644 Mdot
.832 .5765 Mdot
.832 .57653 Mdot
.832 .57664 Mdot
.832 .57674 Mdot
.832 .57708 Mdot
.832 .57709 Mdot
.832 .57718 Mdot
.832 .57722 Mdot
.832 .57723 Mdot
.832 .57728 Mdot
.832 .57737 Mdot
.832 .57737 Mdot
.832 .57738 Mdot
.832 .57744 Mdot
.832 .57757 Mdot
.832 .57759 Mdot
.832 .57772 Mdot
.832 .57807 Mdot
.832 .57809 Mdot
.832 .57814 Mdot
.832 .57819 Mdot
.832 .57826 Mdot
.832 .57832 Mdot
.832 .57836 Mdot
.832 .57847 Mdot
.832 .57848 Mdot
.832 .57849 Mdot
.832 .57856 Mdot
.832 .57862 Mdot
.832 .57865 Mdot
.832 .57869 Mdot
.832 .57874 Mdot
.832 .57898 Mdot
.832 .57922 Mdot
.832 .57923 Mdot
.832 .57924 Mdot
.832 .57934 Mdot
.832 .57959 Mdot
.832 .57962 Mdot
.832 .57962 Mdot
.832 .57963 Mdot
.832 .5798 Mdot
.832 .57984 Mdot
.832 .57988 Mdot
.832 .57991 Mdot
.832 .58006 Mdot
.832 .5801 Mdot
.832 .58019 Mdot
.832 .5802 Mdot
.832 .58028 Mdot
.832 .58043 Mdot
.832 .58044 Mdot
.832 .58048 Mdot
.832 .58056 Mdot
.832 .58059 Mdot
.832 .58068 Mdot
.832 .58081 Mdot
.832 .58094 Mdot
.832 .58117 Mdot
.832 .58122 Mdot
.832 .58125 Mdot
.832 .58126 Mdot
.832 .58129 Mdot
.832 .58139 Mdot
.832 .58149 Mdot
.832 .58151 Mdot
.832 .58157 Mdot
.832 .58158 Mdot
.832 .58169 Mdot
.832 .58169 Mdot
.832 .5817 Mdot
.832 .58186 Mdot
.832 .58187 Mdot
.832 .58189 Mdot
.832 .58195 Mdot
.832 .582 Mdot
.832 .58201 Mdot
.832 .58214 Mdot
.832 .58214 Mdot
.832 .58219 Mdot
.832 .58219 Mdot
.832 .58224 Mdot
.832 .58226 Mdot
.832 .58234 Mdot
.832 .58239 Mdot
.832 .5824 Mdot
.832 .58241 Mdot
.832 .58248 Mdot
.832 .58256 Mdot
.832 .58257 Mdot
.832 .58262 Mdot
.832 .58266 Mdot
.832 .58267 Mdot
.832 .58278 Mdot
.832 .58279 Mdot
.832 .5828 Mdot
.832 .58288 Mdot
.832 .5829 Mdot
.832 .5829 Mdot
.832 .58295 Mdot
.832 .58295 Mdot
.832 .58297 Mdot
.832 .58303 Mdot
.832 .58304 Mdot
.832 .58308 Mdot
.832 .58312 Mdot
.832 .58315 Mdot
.832 .58316 Mdot
.832 .58319 Mdot
.832 .5832 Mdot
.832 .58323 Mdot
.832 .58324 Mdot
.832 .58333 Mdot
.832 .58333 Mdot
.832 .58334 Mdot
.832 .58336 Mdot
.832 .58336 Mdot
.832 .58337 Mdot
.832 .58338 Mdot
.832 .58338 Mdot
.832 .58342 Mdot
.832 .58343 Mdot
.832 .58345 Mdot
.832 .58346 Mdot
.832 .58347 Mdot
.832 .58348 Mdot
.832 .58348 Mdot
.832 .58349 Mdot
.832 .5835 Mdot
.832 .5835 Mdot
.832 .58353 Mdot
.832 .58353 Mdot
.832 .58353 Mdot
.832 .58354 Mdot
.832 .58354 Mdot
.834 .08778 Mdot
.834 .08778 Mdot
.834 .08783 Mdot
.834 .088 Mdot
.834 .08802 Mdot
.834 .08805 Mdot
.834 .08813 Mdot
.834 .08821 Mdot
.834 .08829 Mdot
.834 .08843 Mdot
.834 .08865 Mdot
.834 .08865 Mdot
.834 .08881 Mdot
.834 .08899 Mdot
.834 .0891 Mdot
.834 .08923 Mdot
.834 .08925 Mdot
.834 .08962 Mdot
.834 .08988 Mdot
.834 .08989 Mdot
.834 .09014 Mdot
.834 .0904 Mdot
.834 .09048 Mdot
.834 .0905 Mdot
.834 .09066 Mdot
.834 .09067 Mdot
.834 .0907 Mdot
.834 .09074 Mdot
.834 .09096 Mdot
.834 .09116 Mdot
.834 .09124 Mdot
.834 .09139 Mdot
.834 .0914 Mdot
.834 .09144 Mdot
.834 .09146 Mdot
.834 .09147 Mdot
.834 .09159 Mdot
.834 .0921 Mdot
.834 .09234 Mdot
.834 .09261 Mdot
.834 .09271 Mdot
.834 .0928 Mdot
.834 .09318 Mdot
.834 .09329 Mdot
.834 .09331 Mdot
.834 .09337 Mdot
.834 .09343 Mdot
.834 .09357 Mdot
.834 .09404 Mdot
.834 .09419 Mdot
.834 .09446 Mdot
.834 .09533 Mdot
.834 .09569 Mdot
.834 .0958 Mdot
.834 .09613 Mdot
.834 .0965 Mdot
.834 .09777 Mdot
.834 .09782 Mdot
.834 .09835 Mdot
.834 .09884 Mdot
.834 .09916 Mdot
.834 .09954 Mdot
.834 .09992 Mdot
.834 .10024 Mdot
.834 .10058 Mdot
.834 .10104 Mdot
.834 .10126 Mdot
.834 .10161 Mdot
.834 .10207 Mdot
.834 .10279 Mdot
.834 .10309 Mdot
.834 .10332 Mdot
.834 .10336 Mdot
.834 .10449 Mdot
.834 .1047 Mdot
.834 .10578 Mdot
.834 .10648 Mdot
.834 .10679 Mdot
.834 .10679 Mdot
.834 .1072 Mdot
.834 .10732 Mdot
.834 .10855 Mdot
.834 .10866 Mdot
.834 .10918 Mdot
.834 .10975 Mdot
.834 .10996 Mdot
.834 .11022 Mdot
.834 .11028 Mdot
.834 .11029 Mdot
.834 .11043 Mdot
.834 .11074 Mdot
.834 .11164 Mdot
.834 .11234 Mdot
.834 .11255 Mdot
.834 .11274 Mdot
.834 .11315 Mdot
.834 .11355 Mdot
.834 .11424 Mdot
.834 .11433 Mdot
.834 .11469 Mdot
.834 .1153 Mdot
.834 .11539 Mdot
.834 .11551 Mdot
.834 .11555 Mdot
.834 .11594 Mdot
.834 .11639 Mdot
.834 .11643 Mdot
.834 .11676 Mdot
.834 .117 Mdot
.834 .11756 Mdot
.834 .11771 Mdot
.834 .11777 Mdot
.834 .11787 Mdot
.834 .11799 Mdot
.834 .11813 Mdot
.834 .11834 Mdot
.834 .11837 Mdot
.834 .11841 Mdot
.834 .11846 Mdot
.834 .11865 Mdot
.834 .11874 Mdot
.834 .11915 Mdot
.834 .11943 Mdot
.834 .11952 Mdot
.834 .1198 Mdot
.834 .12014 Mdot
.834 .12014 Mdot
.834 .12038 Mdot
.834 .12079 Mdot
.834 .12129 Mdot
.834 .12152 Mdot
.834 .12191 Mdot
.834 .12212 Mdot
.834 .12228 Mdot
.834 .12231 Mdot
.834 .1225 Mdot
.834 .1229 Mdot
.834 .12312 Mdot
.834 .12321 Mdot
.834 .12323 Mdot
.834 .12334 Mdot
.834 .12362 Mdot
.834 .12393 Mdot
.834 .12417 Mdot
.834 .12465 Mdot
.834 .12501 Mdot
.834 .1257 Mdot
.834 .12571 Mdot
.834 .12598 Mdot
.834 .12634 Mdot
.834 .12638 Mdot
.834 .12678 Mdot
.834 .1272 Mdot
.834 .12774 Mdot
.834 .1287 Mdot
.834 .12948 Mdot
.834 .12982 Mdot
.834 .12994 Mdot
.834 .13062 Mdot
.834 .13108 Mdot
.834 .13126 Mdot
.834 .13223 Mdot
.834 .13229 Mdot
.834 .13321 Mdot
.834 .13323 Mdot
.834 .13414 Mdot
.834 .13451 Mdot
.834 .13518 Mdot
.834 .13531 Mdot
.834 .13581 Mdot
.834 .13601 Mdot
.834 .13617 Mdot
.834 .13631 Mdot
.834 .13678 Mdot
.834 .13693 Mdot
.834 .13704 Mdot
.834 .13713 Mdot
.834 .13812 Mdot
.834 .13814 Mdot
.834 .13839 Mdot
.834 .13843 Mdot
.834 .13918 Mdot
.834 .13997 Mdot
.834 .14032 Mdot
.834 .14077 Mdot
.834 .1409 Mdot
.834 .14134 Mdot
.834 .14146 Mdot
.834 .14236 Mdot
.834 .14296 Mdot
.834 .14463 Mdot
.834 .14593 Mdot
.834 .14734 Mdot
.834 .14853 Mdot
.834 .14962 Mdot
.834 .15053 Mdot
.834 .15099 Mdot
.834 .15182 Mdot
.834 .15187 Mdot
.834 .15258 Mdot
.834 .15286 Mdot
.834 .15378 Mdot
.834 .15434 Mdot
.834 .1545 Mdot
.834 .15453 Mdot
.834 .15454 Mdot
.834 .15606 Mdot
.834 .15626 Mdot
.834 .15753 Mdot
.834 .15816 Mdot
.834 .1584 Mdot
.834 .16077 Mdot
.834 .16328 Mdot
.834 .16362 Mdot
.834 .1641 Mdot
.834 .16518 Mdot
.834 .16658 Mdot
.834 .16667 Mdot
.834 .17251 Mdot
.834 .17339 Mdot
.834 .17365 Mdot
.834 .17376 Mdot
.834 .17693 Mdot
.834 .1774 Mdot
.834 .17906 Mdot
.834 .17958 Mdot
.834 .17966 Mdot
.834 .18037 Mdot
.834 .18256 Mdot
.834 .18421 Mdot
.834 .18479 Mdot
.834 .18552 Mdot
.834 .18744 Mdot
.834 .18784 Mdot
.834 .18846 Mdot
.834 .189 Mdot
.834 .18972 Mdot
.834 .19531 Mdot
.834 .19552 Mdot
.834 .19552 Mdot
.834 .19594 Mdot
.834 .19628 Mdot
.834 .19754 Mdot
.834 .20171 Mdot
.834 .20214 Mdot
.834 .20221 Mdot
.834 .20234 Mdot
.834 .20259 Mdot
.834 .20288 Mdot
.834 .20866 Mdot
.834 .20868 Mdot
.834 .20893 Mdot
.834 .20985 Mdot
.834 .21091 Mdot
.834 .21129 Mdot
.834 .21559 Mdot
.834 .21604 Mdot
.834 .21653 Mdot
.834 .21694 Mdot
.834 .21929 Mdot
.834 .22052 Mdot
.834 .22061 Mdot
.834 .22195 Mdot
.834 .22307 Mdot
.834 .22408 Mdot
.834 .2246 Mdot
.834 .22618 Mdot
.834 .22679 Mdot
.834 .22691 Mdot
.834 .22748 Mdot
.834 .22859 Mdot
.834 .22935 Mdot
.834 .22938 Mdot
.834 .23007 Mdot
.834 .23133 Mdot
.834 .23293 Mdot
.834 .23479 Mdot
.834 .23518 Mdot
.834 .2371 Mdot
.834 .23719 Mdot
.834 .23734 Mdot
.834 .23749 Mdot
.834 .23933 Mdot
.834 .23959 Mdot
.834 .24241 Mdot
.834 .24415 Mdot
.834 .24521 Mdot
.834 .24621 Mdot
.834 .24753 Mdot
.834 .25112 Mdot
.834 .25131 Mdot
.834 .25377 Mdot
.834 .25584 Mdot
.834 .25617 Mdot
.834 .25711 Mdot
.834 .25811 Mdot
.834 .26035 Mdot
.834 .26146 Mdot
.834 .26219 Mdot
.834 .26221 Mdot
.834 .26232 Mdot
.834 .26233 Mdot
.834 .26285 Mdot
.834 .26291 Mdot
.834 .26298 Mdot
.834 .26321 Mdot
.834 .26345 Mdot
.834 .26369 Mdot
.834 .26408 Mdot
.834 .26472 Mdot
.834 .26473 Mdot
.834 .26519 Mdot
.834 .26571 Mdot
.834 .26604 Mdot
.834 .26639 Mdot
.834 .26645 Mdot
.834 .26754 Mdot
.834 .26827 Mdot
.834 .26829 Mdot
.834 .26849 Mdot
.834 .26901 Mdot
.834 .26921 Mdot
.834 .26978 Mdot
.834 .26994 Mdot
.834 .27001 Mdot
.834 .27006 Mdot
.834 .27052 Mdot
.834 .27053 Mdot
.834 .27063 Mdot
.834 .27075 Mdot
.834 .27139 Mdot
.834 .27163 Mdot
.834 .27197 Mdot
.834 .27219 Mdot
.834 .2726 Mdot
.834 .27265 Mdot
.834 .27276 Mdot
.834 .2728 Mdot
.834 .27284 Mdot
.834 .27318 Mdot
.834 .27322 Mdot
.834 .2738 Mdot
.834 .27403 Mdot
.834 .27465 Mdot
.834 .27533 Mdot
.834 .2761 Mdot
.834 .27636 Mdot
.834 .27663 Mdot
.834 .27772 Mdot
.834 .27803 Mdot
.834 .27808 Mdot
.834 .27826 Mdot
.834 .27841 Mdot
.834 .27881 Mdot
.834 .28015 Mdot
.834 .28057 Mdot
.834 .28134 Mdot
.834 .28332 Mdot
.834 .28376 Mdot
.834 .28438 Mdot
.834 .28479 Mdot
.834 .2851 Mdot
.834 .28602 Mdot
.834 .28668 Mdot
.834 .28704 Mdot
.834 .28844 Mdot
.834 .2898 Mdot
.834 .29059 Mdot
.834 .29071 Mdot
.834 .29114 Mdot
.834 .2922 Mdot
.834 .29356 Mdot
.834 .29363 Mdot
.834 .29444 Mdot
.834 .29549 Mdot
.834 .29653 Mdot
.834 .29655 Mdot
.834 .29667 Mdot
.834 .29692 Mdot
.834 .29741 Mdot
.834 .29783 Mdot
.834 .29791 Mdot
.834 .29833 Mdot
.834 .29958 Mdot
.834 .2996 Mdot
.834 .30019 Mdot
.834 .30114 Mdot
.834 .30241 Mdot
.834 .30435 Mdot
.834 .30517 Mdot
.834 .30579 Mdot
.834 .30591 Mdot
.834 .30757 Mdot
.834 .30895 Mdot
.834 .30951 Mdot
.834 .3124 Mdot
.834 .31329 Mdot
.834 .31426 Mdot
.834 .31508 Mdot
.834 .31509 Mdot
.834 .31618 Mdot
.834 .3165 Mdot
.834 .31684 Mdot
.834 .319 Mdot
.834 .31955 Mdot
.834 .31974 Mdot
.834 .32005 Mdot
.834 .32006 Mdot
.834 .32098 Mdot
.834 .3214 Mdot
.834 .32146 Mdot
.834 .32171 Mdot
.834 .32291 Mdot
.834 .32331 Mdot
.834 .32345 Mdot
.834 .32414 Mdot
.834 .32429 Mdot
.834 .32431 Mdot
.834 .32467 Mdot
.834 .32529 Mdot
.834 .32549 Mdot
.834 .32782 Mdot
.834 .32964 Mdot
.834 .33019 Mdot
.834 .33068 Mdot
.834 .33171 Mdot
.834 .33232 Mdot
.834 .33274 Mdot
.834 .33453 Mdot
.834 .33475 Mdot
.834 .33568 Mdot
.834 .33584 Mdot
.834 .33723 Mdot
.834 .33747 Mdot
.834 .33777 Mdot
.834 .33787 Mdot
.834 .33877 Mdot
.834 .33885 Mdot
.834 .34 Mdot
.834 .3401 Mdot
.834 .34093 Mdot
.834 .34154 Mdot
.834 .3422 Mdot
.834 .34265 Mdot
.834 .34294 Mdot
.834 .34332 Mdot
.834 .34346 Mdot
.834 .34348 Mdot
.834 .34372 Mdot
.834 .34403 Mdot
.834 .34438 Mdot
.834 .34472 Mdot
.834 .34491 Mdot
.834 .34499 Mdot
.834 .34507 Mdot
.834 .34522 Mdot
.834 .34568 Mdot
.834 .3459 Mdot
.834 .34627 Mdot
.834 .34627 Mdot
.834 .34693 Mdot
.834 .34706 Mdot
.834 .34762 Mdot
.834 .34785 Mdot
.834 .34803 Mdot
.834 .34856 Mdot
.834 .3494 Mdot
.834 .3494 Mdot
.834 .34998 Mdot
.834 .3502 Mdot
.834 .351 Mdot
.834 .3514 Mdot
.834 .35223 Mdot
.834 .35281 Mdot
.834 .35377 Mdot
.834 .35428 Mdot
.834 .35468 Mdot
.834 .35476 Mdot
.834 .35522 Mdot
.834 .3562 Mdot
.834 .35674 Mdot
.834 .35694 Mdot
.834 .35701 Mdot
.834 .35721 Mdot
.834 .35726 Mdot
.834 .35795 Mdot
.834 .35871 Mdot
.834 .3593 Mdot
.834 .36045 Mdot
.834 .36131 Mdot
.834 .36151 Mdot
.834 .36189 Mdot
.834 .36231 Mdot
.834 .3627 Mdot
.834 .36294 Mdot
.834 .363 Mdot
.834 .36301 Mdot
.834 .36302 Mdot
.834 .36365 Mdot
.834 .36374 Mdot
.834 .36452 Mdot
.834 .36462 Mdot
.834 .36558 Mdot
.834 .36659 Mdot
.834 .36734 Mdot
.834 .36789 Mdot
.834 .36792 Mdot
.834 .37017 Mdot
.834 .3706 Mdot
.834 .37064 Mdot
.834 .37199 Mdot
.834 .37261 Mdot
.834 .3728 Mdot
.834 .37309 Mdot
.834 .37448 Mdot
.834 .37468 Mdot
.834 .37494 Mdot
.834 .37577 Mdot
.834 .37599 Mdot
.834 .37618 Mdot
.834 .37643 Mdot
.834 .37837 Mdot
.834 .37844 Mdot
.834 .37858 Mdot
.834 .37913 Mdot
.834 .38071 Mdot
.834 .38076 Mdot
.834 .38285 Mdot
.834 .38294 Mdot
.834 .38359 Mdot
.834 .38371 Mdot
.834 .38525 Mdot
.834 .3854 Mdot
.834 .38554 Mdot
.834 .38629 Mdot
.834 .38667 Mdot
.834 .38713 Mdot
.834 .38748 Mdot
.834 .3878 Mdot
.834 .38846 Mdot
.834 .38886 Mdot
.834 .38921 Mdot
.834 .38945 Mdot
.834 .38967 Mdot
.834 .39006 Mdot
.834 .39182 Mdot
.834 .3919 Mdot
.834 .39194 Mdot
.834 .3925 Mdot
.834 .39258 Mdot
.834 .39427 Mdot
.834 .39457 Mdot
.834 .39603 Mdot
.834 .39681 Mdot
.834 .39779 Mdot
.834 .39809 Mdot
.834 .39906 Mdot
.834 .39931 Mdot
.834 .4013 Mdot
.834 .40261 Mdot
.834 .40267 Mdot
.834 .4053 Mdot
.834 .4056 Mdot
.834 .40625 Mdot
.834 .40749 Mdot
.834 .409 Mdot
.834 .40903 Mdot
.834 .40983 Mdot
.834 .41203 Mdot
.834 .4136 Mdot
.834 .41456 Mdot
.834 .4153 Mdot
.834 .41686 Mdot
.834 .41876 Mdot
.834 .41971 Mdot
.834 .42142 Mdot
.834 .42154 Mdot
.834 .42298 Mdot
.834 .42357 Mdot
.834 .42389 Mdot
.834 .42544 Mdot
.834 .4266 Mdot
.834 .4267 Mdot
.834 .42681 Mdot
.834 .42691 Mdot
.834 .42698 Mdot
.834 .427 Mdot
.834 .42719 Mdot
.834 .42816 Mdot
.834 .42904 Mdot
.834 .43007 Mdot
.834 .43047 Mdot
.834 .43111 Mdot
.834 .43132 Mdot
.834 .43234 Mdot
.834 .433 Mdot
.834 .43425 Mdot
.834 .43473 Mdot
.834 .43938 Mdot
.834 .43961 Mdot
.834 .44346 Mdot
.834 .44424 Mdot
.834 .44489 Mdot
.834 .44547 Mdot
.834 .44581 Mdot
.834 .44785 Mdot
.834 .44893 Mdot
.834 .4495 Mdot
.834 .45049 Mdot
.834 .45065 Mdot
.834 .45198 Mdot
.834 .45228 Mdot
.834 .45411 Mdot
.834 .45515 Mdot
.834 .45715 Mdot
.834 .46084 Mdot
.834 .46135 Mdot
.834 .46145 Mdot
.834 .46248 Mdot
.834 .46292 Mdot
.834 .4634 Mdot
.834 .46358 Mdot
.834 .46364 Mdot
.834 .46502 Mdot
.834 .46915 Mdot
.834 .46996 Mdot
.834 .47173 Mdot
.834 .47212 Mdot
.834 .47282 Mdot
.834 .4737 Mdot
.834 .47383 Mdot
.834 .47504 Mdot
.834 .47872 Mdot
.834 .47994 Mdot
.834 .48073 Mdot
.834 .48144 Mdot
.834 .48239 Mdot
.834 .48278 Mdot
.834 .48357 Mdot
.834 .48385 Mdot
.834 .4855 Mdot
.834 .48583 Mdot
.834 .48667 Mdot
.834 .48685 Mdot
.834 .4873 Mdot
.834 .4875 Mdot
.834 .4883 Mdot
.834 .48913 Mdot
.834 .48915 Mdot
.834 .49027 Mdot
.834 .49052 Mdot
.834 .49202 Mdot
.834 .49232 Mdot
.834 .49236 Mdot
.834 .49245 Mdot
.834 .49261 Mdot
.834 .49279 Mdot
.834 .49295 Mdot
.834 .49472 Mdot
.834 .49708 Mdot
.834 .49757 Mdot
.834 .49844 Mdot
.834 .49883 Mdot
.834 .49915 Mdot
.834 .49915 Mdot
.834 .49977 Mdot
.834 .50027 Mdot
.834 .50059 Mdot
.834 .50077 Mdot
.834 .50213 Mdot
.834 .50328 Mdot
.834 .50465 Mdot
.834 .50737 Mdot
.834 .50812 Mdot
.834 .50874 Mdot
.834 .50883 Mdot
.834 .50901 Mdot
.834 .50936 Mdot
.834 .50956 Mdot
.834 .50977 Mdot
.834 .51058 Mdot
.834 .51192 Mdot
.834 .51405 Mdot
.834 .517 Mdot
.834 .51761 Mdot
.834 .51764 Mdot
.834 .51797 Mdot
.834 .51806 Mdot
.834 .5181 Mdot
.834 .51916 Mdot
.834 .52006 Mdot
.834 .52055 Mdot
.834 .52104 Mdot
.834 .52167 Mdot
.834 .52249 Mdot
.834 .52287 Mdot
.834 .52615 Mdot
.834 .52623 Mdot
.834 .52643 Mdot
.834 .52698 Mdot
.834 .52757 Mdot
.834 .52783 Mdot
.834 .52808 Mdot
.834 .53021 Mdot
.834 .53051 Mdot
.834 .53089 Mdot
.834 .53165 Mdot
.834 .532 Mdot
.834 .53232 Mdot
.834 .53243 Mdot
.834 .53313 Mdot
.834 .53397 Mdot
.834 .53403 Mdot
.834 .53524 Mdot
.834 .53569 Mdot
.834 .53602 Mdot
.834 .53638 Mdot
.834 .53696 Mdot
.834 .5379 Mdot
.834 .53798 Mdot
.834 .5386 Mdot
.834 .53864 Mdot
.834 .53869 Mdot
.834 .53873 Mdot
.834 .53936 Mdot
.834 .53949 Mdot
.834 .5401 Mdot
.834 .54063 Mdot
.834 .54104 Mdot
.834 .54127 Mdot
.834 .54128 Mdot
.834 .54153 Mdot
.834 .54189 Mdot
.834 .54208 Mdot
.834 .54211 Mdot
.834 .54231 Mdot
.834 .54283 Mdot
.834 .543 Mdot
.834 .54333 Mdot
.834 .54369 Mdot
.834 .54412 Mdot
.834 .54415 Mdot
.834 .54455 Mdot
.834 .54531 Mdot
.834 .54544 Mdot
.834 .5456 Mdot
.834 .54574 Mdot
.834 .54712 Mdot
.834 .54724 Mdot
.834 .54758 Mdot
.834 .54787 Mdot
.834 .54795 Mdot
.834 .54796 Mdot
.834 .54979 Mdot
.834 .54989 Mdot
.834 .54996 Mdot
.834 .55001 Mdot
.834 .55003 Mdot
.834 .55016 Mdot
.834 .55148 Mdot
.834 .55187 Mdot
.834 .55198 Mdot
.834 .55211 Mdot
.834 .55211 Mdot
.834 .55218 Mdot
.834 .55392 Mdot
.834 .55414 Mdot
.834 .55431 Mdot
.834 .5545 Mdot
.834 .55463 Mdot
.834 .55522 Mdot
.834 .55545 Mdot
.834 .55563 Mdot
.834 .55613 Mdot
.834 .55681 Mdot
.834 .55703 Mdot
.834 .55705 Mdot
.834 .55721 Mdot
.834 .55772 Mdot
.834 .55786 Mdot
.834 .55883 Mdot
.834 .55886 Mdot
.834 .55894 Mdot
.834 .55921 Mdot
.834 .56098 Mdot
.834 .56101 Mdot
.834 .56143 Mdot
.834 .56175 Mdot
.834 .5619 Mdot
.834 .562 Mdot
.834 .56276 Mdot
.834 .56347 Mdot
.834 .56354 Mdot
.834 .56373 Mdot
.834 .5641 Mdot
.834 .56416 Mdot
.834 .56462 Mdot
.834 .56462 Mdot
.834 .56463 Mdot
.834 .56468 Mdot
.834 .56484 Mdot
.834 .56512 Mdot
.834 .5652 Mdot
.834 .56541 Mdot
.834 .56543 Mdot
.834 .56567 Mdot
.834 .56581 Mdot
.834 .56608 Mdot
.834 .5664 Mdot
.834 .56675 Mdot
.834 .56717 Mdot
.834 .56755 Mdot
.834 .56804 Mdot
.834 .56822 Mdot
.834 .56848 Mdot
.834 .56852 Mdot
.834 .56865 Mdot
.834 .56869 Mdot
.834 .56882 Mdot
.834 .56892 Mdot
.834 .56915 Mdot
.834 .56937 Mdot
.834 .56938 Mdot
.834 .56945 Mdot
.834 .56946 Mdot
.834 .56975 Mdot
.834 .56978 Mdot
.834 .56981 Mdot
.834 .56985 Mdot
.834 .56999 Mdot
.834 .57003 Mdot
.834 .57008 Mdot
.834 .57013 Mdot
.834 .57028 Mdot
.834 .57032 Mdot
.834 .57051 Mdot
.834 .57062 Mdot
.834 .57089 Mdot
.834 .57089 Mdot
.834 .57116 Mdot
.834 .57118 Mdot
.834 .57146 Mdot
.834 .57151 Mdot
.834 .57164 Mdot
.834 .57184 Mdot
.834 .57188 Mdot
.834 .57197 Mdot
.834 .5722 Mdot
.834 .57247 Mdot
.834 .57263 Mdot
.834 .57275 Mdot
.834 .57287 Mdot
.834 .57288 Mdot
.834 .57299 Mdot
.834 .57306 Mdot
.834 .57306 Mdot
.834 .57326 Mdot
.834 .57337 Mdot
.834 .5735 Mdot
.834 .57366 Mdot
.834 .57374 Mdot
.834 .57378 Mdot
.834 .57378 Mdot
.834 .57381 Mdot
.834 .57387 Mdot
.834 .57398 Mdot
.834 .57404 Mdot
.834 .57405 Mdot
.834 .57409 Mdot
.834 .57415 Mdot
.834 .57427 Mdot
.834 .57433 Mdot
.834 .57448 Mdot
.834 .57459 Mdot
.834 .57466 Mdot
.834 .57466 Mdot
.834 .57476 Mdot
.834 .57484 Mdot
.834 .57487 Mdot
.834 .57495 Mdot
.834 .57506 Mdot
.834 .57509 Mdot
.834 .57514 Mdot
.834 .57516 Mdot
.834 .57517 Mdot
.834 .57518 Mdot
.834 .57524 Mdot
.834 .57528 Mdot
.834 .57531 Mdot
.834 .57534 Mdot
.834 .57536 Mdot
.834 .5754 Mdot
.834 .57556 Mdot
.834 .57563 Mdot
.834 .57572 Mdot
.834 .57573 Mdot
.834 .57586 Mdot
.834 .57597 Mdot
.834 .57598 Mdot
.834 .57602 Mdot
.834 .57605 Mdot
.834 .57622 Mdot
.834 .57632 Mdot
.834 .57635 Mdot
.834 .57654 Mdot
.834 .57666 Mdot
.834 .57677 Mdot
.834 .57683 Mdot
.834 .57689 Mdot
.834 .57709 Mdot
.834 .57734 Mdot
.834 .57743 Mdot
.834 .57747 Mdot
.834 .57747 Mdot
.834 .57749 Mdot
.834 .57756 Mdot
.834 .57762 Mdot
.834 .57778 Mdot
.834 .57793 Mdot
.834 .57796 Mdot
.834 .57831 Mdot
.834 .57834 Mdot
.834 .57846 Mdot
.834 .57846 Mdot
.834 .57855 Mdot
.834 .57874 Mdot
.834 .57905 Mdot
.834 .57911 Mdot
.834 .57943 Mdot
.834 .57944 Mdot
.834 .5795 Mdot
.834 .57959 Mdot
.834 .57979 Mdot
.834 .57992 Mdot
.834 .58002 Mdot
.834 .58008 Mdot
.834 .58021 Mdot
.834 .5803 Mdot
.834 .58039 Mdot
.834 .5805 Mdot
.834 .58061 Mdot
.834 .58069 Mdot
.834 .58083 Mdot
.834 .58098 Mdot
.834 .581 Mdot
.834 .58135 Mdot
.834 .58145 Mdot
.834 .58155 Mdot
.834 .58158 Mdot
.834 .58168 Mdot
.834 .58192 Mdot
.834 .58199 Mdot
.834 .58204 Mdot
.834 .58217 Mdot
.834 .58221 Mdot
.834 .58222 Mdot
.834 .58224 Mdot
.834 .58225 Mdot
.834 .58228 Mdot
.834 .58238 Mdot
.834 .58241 Mdot
.834 .58243 Mdot
.834 .58251 Mdot
.834 .58258 Mdot
.834 .58272 Mdot
.834 .58275 Mdot
.834 .58276 Mdot
.834 .58276 Mdot
.834 .58277 Mdot
.834 .58278 Mdot
.834 .58282 Mdot
.834 .58284 Mdot
.834 .58289 Mdot
.834 .58296 Mdot
.834 .58297 Mdot
.834 .58298 Mdot
.834 .58298 Mdot
.834 .58302 Mdot
.834 .58303 Mdot
.834 .58305 Mdot
.834 .58312 Mdot
.834 .58319 Mdot
.834 .58319 Mdot
.834 .58327 Mdot
.834 .58337 Mdot
.834 .58338 Mdot
.834 .58341 Mdot
.834 .58344 Mdot
.834 .58349 Mdot
.834 .58354 Mdot
.834 .58354 Mdot
.834 .5836 Mdot
.834 .58363 Mdot
.834 .58366 Mdot
.834 .58368 Mdot
.834 .5837 Mdot
.834 .58371 Mdot
.834 .58371 Mdot
.834 .58376 Mdot
.834 .58378 Mdot
.834 .58378 Mdot
.836 .08696 Mdot
.836 .08698 Mdot
.836 .08698 Mdot
.836 .08699 Mdot
.836 .08705 Mdot
.836 .08707 Mdot
.836 .08707 Mdot
.836 .08725 Mdot
.836 .08726 Mdot
.836 .08726 Mdot
.836 .08727 Mdot
.836 .08734 Mdot
.836 .08753 Mdot
.836 .08792 Mdot
.836 .08809 Mdot
.836 .08813 Mdot
.836 .0882 Mdot
.836 .08824 Mdot
.836 .08824 Mdot
.836 .0884 Mdot
.836 .08847 Mdot
.836 .08857 Mdot
.836 .0888 Mdot
.836 .08898 Mdot
.836 .0891 Mdot
.836 .08924 Mdot
.836 .08928 Mdot
.836 .08947 Mdot
.836 .08968 Mdot
.836 .0897 Mdot
.836 .08976 Mdot
.836 .09025 Mdot
.836 .09053 Mdot
.836 .09064 Mdot
.836 .09083 Mdot
.836 .09087 Mdot
.836 .09107 Mdot
.836 .09112 Mdot
.836 .09113 Mdot
.836 .09189 Mdot
.836 .09207 Mdot
.836 .0921 Mdot
.836 .0924 Mdot
.836 .09245 Mdot
.836 .09292 Mdot
.836 .09334 Mdot
.836 .09383 Mdot
.836 .09436 Mdot
.836 .09468 Mdot
.836 .09495 Mdot
.836 .09499 Mdot
.836 .09525 Mdot
.836 .09574 Mdot
.836 .09786 Mdot
.836 .098 Mdot
.836 .09865 Mdot
.836 .09917 Mdot
.836 .09975 Mdot
.836 .09996 Mdot
.836 .10053 Mdot
.836 .10082 Mdot
.836 .10143 Mdot
.836 .10152 Mdot
.836 .10159 Mdot
.836 .10192 Mdot
.836 .10212 Mdot
.836 .10298 Mdot
.836 .10312 Mdot
.836 .10314 Mdot
.836 .10365 Mdot
.836 .10406 Mdot
.836 .10482 Mdot
.836 .10522 Mdot
.836 .10529 Mdot
.836 .10631 Mdot
.836 .10719 Mdot
.836 .10722 Mdot
.836 .10722 Mdot
.836 .10777 Mdot
.836 .10804 Mdot
.836 .10856 Mdot
.836 .10916 Mdot
.836 .10946 Mdot
.836 .11067 Mdot
.836 .11091 Mdot
.836 .11262 Mdot
.836 .11292 Mdot
.836 .11311 Mdot
.836 .11446 Mdot
.836 .11462 Mdot
.836 .11543 Mdot
.836 .1157 Mdot
.836 .11904 Mdot
.836 .11906 Mdot
.836 .11917 Mdot
.836 .11934 Mdot
.836 .11988 Mdot
.836 .12007 Mdot
.836 .12028 Mdot
.836 .12032 Mdot
.836 .12037 Mdot
.836 .12052 Mdot
.836 .1207 Mdot
.836 .12086 Mdot
.836 .12145 Mdot
.836 .12155 Mdot
.836 .12158 Mdot
.836 .12202 Mdot
.836 .12203 Mdot
.836 .12269 Mdot
.836 .12272 Mdot
.836 .12293 Mdot
.836 .12346 Mdot
.836 .12402 Mdot
.836 .12461 Mdot
.836 .12487 Mdot
.836 .12584 Mdot
.836 .12604 Mdot
.836 .12605 Mdot
.836 .12609 Mdot
.836 .12628 Mdot
.836 .1264 Mdot
.836 .1265 Mdot
.836 .12695 Mdot
.836 .12766 Mdot
.836 .12775 Mdot
.836 .12779 Mdot
.836 .12838 Mdot
.836 .12856 Mdot
.836 .12866 Mdot
.836 .1289 Mdot
.836 .12894 Mdot
.836 .12971 Mdot
.836 .12988 Mdot
.836 .13036 Mdot
.836 .13059 Mdot
.836 .13091 Mdot
.836 .13142 Mdot
.836 .13143 Mdot
.836 .1319 Mdot
.836 .13205 Mdot
.836 .13276 Mdot
.836 .13332 Mdot
.836 .13375 Mdot
.836 .13411 Mdot
.836 .13423 Mdot
.836 .1343 Mdot
.836 .13468 Mdot
.836 .13469 Mdot
.836 .13489 Mdot
.836 .13533 Mdot
.836 .1356 Mdot
.836 .13581 Mdot
.836 .13645 Mdot
.836 .13662 Mdot
.836 .13767 Mdot
.836 .13781 Mdot
.836 .1389 Mdot
.836 .13899 Mdot
.836 .13961 Mdot
.836 .14018 Mdot
.836 .1406 Mdot
.836 .14066 Mdot
.836 .14071 Mdot
.836 .14077 Mdot
.836 .14166 Mdot
.836 .14187 Mdot
.836 .14189 Mdot
.836 .14194 Mdot
.836 .142 Mdot
.836 .14242 Mdot
.836 .14244 Mdot
.836 .14244 Mdot
.836 .14249 Mdot
.836 .14259 Mdot
.836 .14351 Mdot
.836 .14471 Mdot
.836 .14796 Mdot
.836 .14888 Mdot
.836 .14939 Mdot
.836 .14987 Mdot
.836 .14991 Mdot
.836 .15053 Mdot
.836 .15075 Mdot
.836 .15134 Mdot
.836 .15141 Mdot
.836 .15177 Mdot
.836 .15437 Mdot
.836 .1549 Mdot
.836 .1559 Mdot
.836 .15609 Mdot
.836 .15613 Mdot
.836 .15635 Mdot
.836 .15748 Mdot
.836 .15819 Mdot
.836 .15879 Mdot
.836 .15931 Mdot
.836 .15958 Mdot
.836 .16119 Mdot
.836 .16148 Mdot
.836 .16156 Mdot
.836 .16264 Mdot
.836 .16329 Mdot
.836 .16411 Mdot
.836 .16577 Mdot
.836 .16633 Mdot
.836 .16656 Mdot
.836 .17018 Mdot
.836 .17053 Mdot
.836 .17134 Mdot
.836 .17194 Mdot
.836 .17339 Mdot
.836 .17346 Mdot
.836 .17373 Mdot
.836 .17652 Mdot
.836 .1786 Mdot
.836 .17972 Mdot
.836 .18113 Mdot
.836 .18284 Mdot
.836 .18303 Mdot
.836 .18432 Mdot
.836 .18493 Mdot
.836 .18501 Mdot
.836 .18623 Mdot
.836 .18646 Mdot
.836 .18983 Mdot
.836 .18992 Mdot
.836 .18998 Mdot
.836 .19071 Mdot
.836 .19214 Mdot
.836 .1931 Mdot
.836 .1941 Mdot
.836 .19689 Mdot
.836 .19877 Mdot
.836 .19892 Mdot
.836 .20136 Mdot
.836 .20281 Mdot
.836 .20453 Mdot
.836 .2058 Mdot
.836 .20831 Mdot
.836 .20872 Mdot
.836 .20913 Mdot
.836 .20967 Mdot
.836 .21192 Mdot
.836 .21236 Mdot
.836 .21237 Mdot
.836 .21311 Mdot
.836 .21379 Mdot
.836 .21523 Mdot
.836 .21583 Mdot
.836 .21598 Mdot
.836 .21622 Mdot
.836 .2167 Mdot
.836 .21693 Mdot
.836 .21887 Mdot
.836 .22039 Mdot
.836 .22333 Mdot
.836 .225 Mdot
.836 .22627 Mdot
.836 .23262 Mdot
.836 .23392 Mdot
.836 .23496 Mdot
.836 .23634 Mdot
.836 .23891 Mdot
.836 .24053 Mdot
.836 .24128 Mdot
.836 .2426 Mdot
.836 .24307 Mdot
.836 .24374 Mdot
.836 .24611 Mdot
.836 .24728 Mdot
.836 .24836 Mdot
.836 .25265 Mdot
.836 .25588 Mdot
.836 .25607 Mdot
.836 .25632 Mdot
.836 .2567 Mdot
.836 .25712 Mdot
.836 .25992 Mdot
.836 .25996 Mdot
.836 .25998 Mdot
.836 .25999 Mdot
.836 .26018 Mdot
.836 .26021 Mdot
.836 .26023 Mdot
.836 .26024 Mdot
.836 .26075 Mdot
.836 .26078 Mdot
.836 .2608 Mdot
.836 .26083 Mdot
.836 .26102 Mdot
.836 .26129 Mdot
.836 .26158 Mdot
.836 .2627 Mdot
.836 .26278 Mdot
.836 .26319 Mdot
.836 .26332 Mdot
.836 .26354 Mdot
.836 .26363 Mdot
.836 .26364 Mdot
.836 .26392 Mdot
.836 .26409 Mdot
.836 .2643 Mdot
.836 .26458 Mdot
.836 .26526 Mdot
.836 .26551 Mdot
.836 .26568 Mdot
.836 .26579 Mdot
.836 .26604 Mdot
.836 .26612 Mdot
.836 .26652 Mdot
.836 .26654 Mdot
.836 .26667 Mdot
.836 .26714 Mdot
.836 .26719 Mdot
.836 .2678 Mdot
.836 .26785 Mdot
.836 .26802 Mdot
.836 .26804 Mdot
.836 .26882 Mdot
.836 .26945 Mdot
.836 .26974 Mdot
.836 .26986 Mdot
.836 .26987 Mdot
.836 .27024 Mdot
.836 .27025 Mdot
.836 .27052 Mdot
.836 .27057 Mdot
.836 .271 Mdot
.836 .27111 Mdot
.836 .27122 Mdot
.836 .27136 Mdot
.836 .27179 Mdot
.836 .27189 Mdot
.836 .27195 Mdot
.836 .27197 Mdot
.836 .27398 Mdot
.836 .27414 Mdot
.836 .27465 Mdot
.836 .27475 Mdot
.836 .27561 Mdot
.836 .27574 Mdot
.836 .27707 Mdot
.836 .27806 Mdot
.836 .27827 Mdot
.836 .27907 Mdot
.836 .27966 Mdot
.836 .27969 Mdot
.836 .28111 Mdot
.836 .28116 Mdot
.836 .28147 Mdot
.836 .28207 Mdot
.836 .28283 Mdot
.836 .28294 Mdot
.836 .28366 Mdot
.836 .2841 Mdot
.836 .28416 Mdot
.836 .28504 Mdot
.836 .28574 Mdot
.836 .2874 Mdot
.836 .28975 Mdot
.836 .29059 Mdot
.836 .29095 Mdot
.836 .29133 Mdot
.836 .29315 Mdot
.836 .29379 Mdot
.836 .29459 Mdot
.836 .29575 Mdot
.836 .29585 Mdot
.836 .29617 Mdot
.836 .29624 Mdot
.836 .29674 Mdot
.836 .29723 Mdot
.836 .2983 Mdot
.836 .29873 Mdot
.836 .29911 Mdot
.836 .30078 Mdot
.836 .30103 Mdot
.836 .30123 Mdot
.836 .30212 Mdot
.836 .30266 Mdot
.836 .30499 Mdot
.836 .30536 Mdot
.836 .30541 Mdot
.836 .30679 Mdot
.836 .30787 Mdot
.836 .30792 Mdot
.836 .30854 Mdot
.836 .30995 Mdot
.836 .31104 Mdot
.836 .31121 Mdot
.836 .31252 Mdot
.836 .31257 Mdot
.836 .31394 Mdot
.836 .31605 Mdot
.836 .31627 Mdot
.836 .31637 Mdot
.836 .31637 Mdot
.836 .31783 Mdot
.836 .31826 Mdot
.836 .31852 Mdot
.836 .31883 Mdot
.836 .31976 Mdot
.836 .31989 Mdot
.836 .32148 Mdot
.836 .32227 Mdot
.836 .3237 Mdot
.836 .32375 Mdot
.836 .32418 Mdot
.836 .32544 Mdot
.836 .32606 Mdot
.836 .3274 Mdot
.836 .32774 Mdot
.836 .3305 Mdot
.836 .33127 Mdot
.836 .33176 Mdot
.836 .33249 Mdot
.836 .33326 Mdot
.836 .33379 Mdot
.836 .33421 Mdot
.836 .33522 Mdot
.836 .33563 Mdot
.836 .3377 Mdot
.836 .33837 Mdot
.836 .33877 Mdot
.836 .33933 Mdot
.836 .3408 Mdot
.836 .3421 Mdot
.836 .34656 Mdot
.836 .34679 Mdot
.836 .34684 Mdot
.836 .34712 Mdot
.836 .34753 Mdot
.836 .34889 Mdot
.836 .34936 Mdot
.836 .34988 Mdot
.836 .34999 Mdot
.836 .35011 Mdot
.836 .35047 Mdot
.836 .35091 Mdot
.836 .35122 Mdot
.836 .35132 Mdot
.836 .35278 Mdot
.836 .35302 Mdot
.836 .3531 Mdot
.836 .35417 Mdot
.836 .35421 Mdot
.836 .35494 Mdot
.836 .35583 Mdot
.836 .3559 Mdot
.836 .35641 Mdot
.836 .35769 Mdot
.836 .35805 Mdot
.836 .35853 Mdot
.836 .35908 Mdot
.836 .36051 Mdot
.836 .36113 Mdot
.836 .36135 Mdot
.836 .36162 Mdot
.836 .362 Mdot
.836 .36324 Mdot
.836 .36346 Mdot
.836 .36388 Mdot
.836 .36396 Mdot
.836 .36397 Mdot
.836 .36407 Mdot
.836 .36453 Mdot
.836 .36482 Mdot
.836 .36506 Mdot
.836 .36527 Mdot
.836 .36603 Mdot
.836 .36614 Mdot
.836 .36618 Mdot
.836 .36661 Mdot
.836 .36686 Mdot
.836 .36719 Mdot
.836 .36784 Mdot
.836 .36806 Mdot
.836 .36814 Mdot
.836 .36954 Mdot
.836 .36998 Mdot
.836 .37021 Mdot
.836 .37078 Mdot
.836 .37088 Mdot
.836 .37268 Mdot
.836 .37309 Mdot
.836 .3736 Mdot
.836 .37422 Mdot
.836 .37475 Mdot
.836 .375 Mdot
.836 .37551 Mdot
.836 .37669 Mdot
.836 .37672 Mdot
.836 .377 Mdot
.836 .37783 Mdot
.836 .37817 Mdot
.836 .37977 Mdot
.836 .37981 Mdot
.836 .38064 Mdot
.836 .38112 Mdot
.836 .38211 Mdot
.836 .38294 Mdot
.836 .3832 Mdot
.836 .38338 Mdot
.836 .38425 Mdot
.836 .38426 Mdot
.836 .3845 Mdot
.836 .38472 Mdot
.836 .38518 Mdot
.836 .38537 Mdot
.836 .38549 Mdot
.836 .38565 Mdot
.836 .38572 Mdot
.836 .38634 Mdot
.836 .38682 Mdot
.836 .38775 Mdot
.836 .38827 Mdot
.836 .38867 Mdot
.836 .39063 Mdot
.836 .39103 Mdot
.836 .39135 Mdot
.836 .39254 Mdot
.836 .39326 Mdot
.836 .39366 Mdot
.836 .3938 Mdot
.836 .394 Mdot
.836 .39505 Mdot
.836 .39537 Mdot
.836 .39664 Mdot
.836 .39759 Mdot
.836 .39772 Mdot
.836 .39783 Mdot
.836 .39795 Mdot
.836 .39885 Mdot
.836 .39959 Mdot
.836 .39992 Mdot
.836 .40038 Mdot
.836 .40043 Mdot
.836 .40053 Mdot
.836 .40067 Mdot
.836 .40085 Mdot
.836 .40159 Mdot
.836 .40163 Mdot
.836 .40163 Mdot
.836 .40174 Mdot
.836 .40195 Mdot
.836 .40396 Mdot
.836 .40442 Mdot
.836 .40482 Mdot
.836 .40658 Mdot
.836 .40723 Mdot
.836 .40893 Mdot
.836 .40904 Mdot
.836 .41242 Mdot
.836 .41352 Mdot
.836 .41446 Mdot
.836 .41506 Mdot
.836 .41547 Mdot
.836 .41654 Mdot
.836 .41655 Mdot
.836 .41754 Mdot
.836 .41763 Mdot
.836 .41891 Mdot
.836 .41937 Mdot
.836 .4206 Mdot
.836 .42075 Mdot
.836 .42149 Mdot
.836 .42269 Mdot
.836 .42576 Mdot
.836 .42664 Mdot
.836 .42671 Mdot
.836 .42682 Mdot
.836 .42715 Mdot
.836 .42769 Mdot
.836 .42789 Mdot
.836 .42793 Mdot
.836 .42992 Mdot
.836 .43029 Mdot
.836 .43038 Mdot
.836 .43083 Mdot
.836 .43284 Mdot
.836 .43307 Mdot
.836 .43315 Mdot
.836 .43448 Mdot
.836 .4353 Mdot
.836 .43567 Mdot
.836 .4367 Mdot
.836 .43724 Mdot
.836 .4382 Mdot
.836 .43897 Mdot
.836 .43946 Mdot
.836 .44038 Mdot
.836 .44094 Mdot
.836 .4411 Mdot
.836 .44319 Mdot
.836 .44404 Mdot
.836 .44428 Mdot
.836 .44442 Mdot
.836 .446 Mdot
.836 .44772 Mdot
.836 .44915 Mdot
.836 .44921 Mdot
.836 .45019 Mdot
.836 .45062 Mdot
.836 .45222 Mdot
.836 .45302 Mdot
.836 .45482 Mdot
.836 .45495 Mdot
.836 .45732 Mdot
.836 .45757 Mdot
.836 .45796 Mdot
.836 .45944 Mdot
.836 .46052 Mdot
.836 .46067 Mdot
.836 .46311 Mdot
.836 .46323 Mdot
.836 .4635 Mdot
.836 .46372 Mdot
.836 .46375 Mdot
.836 .46418 Mdot
.836 .46568 Mdot
.836 .46863 Mdot
.836 .46934 Mdot
.836 .46963 Mdot
.836 .47059 Mdot
.836 .47218 Mdot
.836 .47223 Mdot
.836 .47301 Mdot
.836 .47413 Mdot
.836 .47432 Mdot
.836 .47595 Mdot
.836 .47652 Mdot
.836 .47686 Mdot
.836 .47857 Mdot
.836 .4792 Mdot
.836 .47937 Mdot
.836 .47969 Mdot
.836 .48054 Mdot
.836 .48182 Mdot
.836 .48274 Mdot
.836 .48281 Mdot
.836 .48286 Mdot
.836 .48294 Mdot
.836 .48324 Mdot
.836 .48492 Mdot
.836 .4853 Mdot
.836 .48648 Mdot
.836 .48719 Mdot
.836 .48734 Mdot
.836 .48794 Mdot
.836 .49064 Mdot
.836 .49078 Mdot
.836 .49089 Mdot
.836 .49107 Mdot
.836 .49113 Mdot
.836 .49144 Mdot
.836 .49202 Mdot
.836 .49229 Mdot
.836 .4928 Mdot
.836 .49296 Mdot
.836 .49307 Mdot
.836 .49423 Mdot
.836 .49443 Mdot
.836 .4957 Mdot
.836 .49721 Mdot
.836 .49909 Mdot
.836 .50086 Mdot
.836 .50138 Mdot
.836 .50196 Mdot
.836 .50218 Mdot
.836 .50397 Mdot
.836 .50413 Mdot
.836 .50434 Mdot
.836 .50464 Mdot
.836 .50648 Mdot
.836 .50661 Mdot
.836 .50784 Mdot
.836 .508 Mdot
.836 .50802 Mdot
.836 .50952 Mdot
.836 .50988 Mdot
.836 .51009 Mdot
.836 .51093 Mdot
.836 .51223 Mdot
.836 .51225 Mdot
.836 .51374 Mdot
.836 .51399 Mdot
.836 .51735 Mdot
.836 .5179 Mdot
.836 .51826 Mdot
.836 .5184 Mdot
.836 .51844 Mdot
.836 .51915 Mdot
.836 .52061 Mdot
.836 .52145 Mdot
.836 .52204 Mdot
.836 .5226 Mdot
.836 .52263 Mdot
.836 .52356 Mdot
.836 .52369 Mdot
.836 .52419 Mdot
.836 .52441 Mdot
.836 .52477 Mdot
.836 .5262 Mdot
.836 .52693 Mdot
.836 .52711 Mdot
.836 .52724 Mdot
.836 .52741 Mdot
.836 .5275 Mdot
.836 .52763 Mdot
.836 .52764 Mdot
.836 .52768 Mdot
.836 .528 Mdot
.836 .52828 Mdot
.836 .52858 Mdot
.836 .5288 Mdot
.836 .52897 Mdot
.836 .52909 Mdot
.836 .52915 Mdot
.836 .5297 Mdot
.836 .53009 Mdot
.836 .5306 Mdot
.836 .53097 Mdot
.836 .53203 Mdot
.836 .53217 Mdot
.836 .5323 Mdot
.836 .53239 Mdot
.836 .53245 Mdot
.836 .53355 Mdot
.836 .535 Mdot
.836 .53536 Mdot
.836 .53575 Mdot
.836 .53654 Mdot
.836 .53677 Mdot
.836 .53693 Mdot
.836 .53737 Mdot
.836 .53762 Mdot
.836 .53816 Mdot
.836 .53901 Mdot
.836 .53946 Mdot
.836 .53981 Mdot
.836 .54024 Mdot
.836 .54231 Mdot
.836 .54273 Mdot
.836 .54327 Mdot
.836 .54422 Mdot
.836 .54471 Mdot
.836 .54534 Mdot
.836 .54541 Mdot
.836 .54557 Mdot
.836 .54565 Mdot
.836 .54569 Mdot
.836 .54589 Mdot
.836 .54635 Mdot
.836 .54656 Mdot
.836 .5468 Mdot
.836 .54681 Mdot
.836 .54695 Mdot
.836 .54766 Mdot
.836 .54784 Mdot
.836 .54797 Mdot
.836 .5481 Mdot
.836 .5489 Mdot
.836 .5493 Mdot
.836 .54984 Mdot
.836 .5503 Mdot
.836 .55107 Mdot
.836 .55111 Mdot
.836 .5517 Mdot
.836 .55258 Mdot
.836 .55289 Mdot
.836 .55319 Mdot
.836 .55363 Mdot
.836 .55386 Mdot
.836 .55388 Mdot
.836 .55391 Mdot
.836 .55495 Mdot
.836 .55502 Mdot
.836 .5554 Mdot
.836 .55543 Mdot
.836 .55561 Mdot
.836 .55601 Mdot
.836 .55607 Mdot
.836 .55659 Mdot
.836 .55703 Mdot
.836 .55737 Mdot
.836 .55801 Mdot
.836 .55886 Mdot
.836 .55894 Mdot
.836 .55896 Mdot
.836 .5594 Mdot
.836 .55958 Mdot
.836 .55983 Mdot
.836 .55994 Mdot
.836 .56103 Mdot
.836 .5611 Mdot
.836 .56127 Mdot
.836 .56177 Mdot
.836 .56202 Mdot
.836 .56221 Mdot
.836 .56254 Mdot
.836 .56256 Mdot
.836 .56265 Mdot
.836 .56313 Mdot
.836 .56321 Mdot
.836 .56337 Mdot
.836 .56355 Mdot
.836 .56376 Mdot
.836 .56409 Mdot
.836 .56416 Mdot
.836 .56417 Mdot
.836 .56423 Mdot
.836 .56453 Mdot
.836 .56469 Mdot
.836 .56546 Mdot
.836 .56556 Mdot
.836 .56559 Mdot
.836 .56576 Mdot
.836 .56583 Mdot
.836 .56601 Mdot
.836 .56602 Mdot
.836 .56616 Mdot
.836 .56631 Mdot
.836 .56659 Mdot
.836 .56754 Mdot
.836 .5679 Mdot
.836 .56817 Mdot
.836 .5682 Mdot
.836 .56821 Mdot
.836 .56821 Mdot
.836 .56822 Mdot
.836 .56834 Mdot
.836 .56836 Mdot
.836 .56837 Mdot
.836 .56838 Mdot
.836 .56844 Mdot
.836 .5687 Mdot
.836 .56872 Mdot
.836 .56873 Mdot
.836 .56875 Mdot
.836 .56887 Mdot
.836 .56904 Mdot
.836 .56922 Mdot
.836 .56925 Mdot
.836 .56957 Mdot
.836 .56961 Mdot
.836 .56991 Mdot
.836 .56996 Mdot
.836 .57015 Mdot
.836 .57021 Mdot
.836 .57029 Mdot
.836 .57042 Mdot
.836 .57048 Mdot
.836 .57048 Mdot
.836 .57059 Mdot
.836 .57061 Mdot
.836 .57064 Mdot
.836 .57075 Mdot
.836 .57087 Mdot
.836 .57104 Mdot
.836 .57124 Mdot
.836 .57128 Mdot
.836 .57142 Mdot
.836 .57143 Mdot
.836 .57157 Mdot
.836 .57167 Mdot
.836 .57173 Mdot
.836 .57187 Mdot
.836 .57192 Mdot
.836 .57214 Mdot
.836 .57215 Mdot
.836 .57222 Mdot
.836 .57225 Mdot
.836 .57231 Mdot
.836 .57247 Mdot
.836 .57249 Mdot
.836 .57251 Mdot
.836 .57272 Mdot
.836 .57285 Mdot
.836 .57288 Mdot
.836 .57291 Mdot
.836 .57297 Mdot
.836 .57298 Mdot
.836 .57298 Mdot
.836 .57304 Mdot
.836 .57332 Mdot
.836 .57339 Mdot
.836 .57356 Mdot
.836 .57372 Mdot
.836 .57387 Mdot
.836 .57393 Mdot
.836 .57394 Mdot
.836 .57413 Mdot
.836 .57414 Mdot
.836 .57426 Mdot
.836 .57427 Mdot
.836 .5743 Mdot
.836 .57447 Mdot
.836 .57452 Mdot
.836 .57457 Mdot
.836 .57461 Mdot
.836 .57462 Mdot
.836 .57464 Mdot
.836 .5747 Mdot
.836 .57475 Mdot
.836 .5749 Mdot
.836 .57495 Mdot
.836 .57498 Mdot
.836 .57499 Mdot
.836 .57594 Mdot
.836 .57602 Mdot
.836 .57625 Mdot
.836 .5763 Mdot
.836 .57668 Mdot
.836 .57673 Mdot
.836 .57682 Mdot
.836 .5773 Mdot
.836 .57737 Mdot
.836 .57771 Mdot
.836 .5778 Mdot
.836 .57797 Mdot
.836 .57812 Mdot
.836 .57819 Mdot
.836 .57835 Mdot
.836 .57835 Mdot
.836 .57836 Mdot
.836 .57861 Mdot
.836 .57889 Mdot
.836 .57891 Mdot
.836 .57903 Mdot
.836 .57924 Mdot
.836 .57936 Mdot
.836 .5795 Mdot
.836 .57951 Mdot
.836 .57954 Mdot
.836 .57979 Mdot
.836 .57984 Mdot
.836 .57993 Mdot
.836 .57995 Mdot
.836 .57998 Mdot
.836 .58015 Mdot
.836 .58023 Mdot
.836 .58039 Mdot
.836 .58045 Mdot
.836 .58061 Mdot
.836 .58076 Mdot
.836 .58094 Mdot
.836 .58098 Mdot
.836 .58157 Mdot
.836 .58171 Mdot
.836 .58178 Mdot
.836 .58179 Mdot
.836 .58187 Mdot
.836 .58196 Mdot
.836 .5821 Mdot
.836 .58224 Mdot
.836 .58236 Mdot
.836 .58249 Mdot
.836 .5825 Mdot
.836 .58259 Mdot
.836 .5826 Mdot
.836 .58264 Mdot
.836 .58286 Mdot
.836 .58286 Mdot
.836 .58287 Mdot
.836 .58293 Mdot
.836 .58294 Mdot
.836 .58299 Mdot
.836 .58302 Mdot
.836 .5831 Mdot
.836 .58324 Mdot
.836 .58325 Mdot
.836 .58326 Mdot
.836 .58332 Mdot
.836 .58337 Mdot
.836 .58338 Mdot
.836 .58342 Mdot
.836 .58345 Mdot
.836 .5835 Mdot
.836 .58357 Mdot
.836 .58359 Mdot
.836 .58361 Mdot
.836 .58366 Mdot
.836 .58366 Mdot
.836 .58367 Mdot
.836 .58369 Mdot
.836 .5837 Mdot
.836 .58375 Mdot
.836 .58385 Mdot
.836 .58391 Mdot
.836 .58393 Mdot
.836 .58393 Mdot
.836 .58393 Mdot
.836 .58393 Mdot
.836 .58398 Mdot
.836 .58398 Mdot
.836 .58399 Mdot
.836 .584 Mdot
.836 .58401 Mdot
.836 .58401 Mdot
.836 .58401 Mdot
.838 .08613 Mdot
.838 .08614 Mdot
.838 .08637 Mdot
.838 .08637 Mdot
.838 .08639 Mdot
.838 .08648 Mdot
.838 .08664 Mdot
.838 .08679 Mdot
.838 .08684 Mdot
.838 .08692 Mdot
.838 .08694 Mdot
.838 .08695 Mdot
.838 .08697 Mdot
.838 .087 Mdot
.838 .08739 Mdot
.838 .08741 Mdot
.838 .08742 Mdot
.838 .08746 Mdot
.838 .08761 Mdot
.838 .08775 Mdot
.838 .08789 Mdot
.838 .08824 Mdot
.838 .0883 Mdot
.838 .08831 Mdot
.838 .08832 Mdot
.838 .08849 Mdot
.838 .08854 Mdot
.838 .08859 Mdot
.838 .08867 Mdot
.838 .08884 Mdot
.838 .08892 Mdot
.838 .08897 Mdot
.838 .08898 Mdot
.838 .08925 Mdot
.838 .08951 Mdot
.838 .08957 Mdot
.838 .09022 Mdot
.838 .09061 Mdot
.838 .0907 Mdot
.838 .09079 Mdot
.838 .09107 Mdot
.838 .09107 Mdot
.838 .09131 Mdot
.838 .09138 Mdot
.838 .09184 Mdot
.838 .0919 Mdot
.838 .09195 Mdot
.838 .09228 Mdot
.838 .09241 Mdot
.838 .09249 Mdot
.838 .09251 Mdot
.838 .09268 Mdot
.838 .09279 Mdot
.838 .09299 Mdot
.838 .09317 Mdot
.838 .09327 Mdot
.838 .09329 Mdot
.838 .09355 Mdot
.838 .09489 Mdot
.838 .09495 Mdot
.838 .09509 Mdot
.838 .09538 Mdot
.838 .09549 Mdot
.838 .09589 Mdot
.838 .09594 Mdot
.838 .09602 Mdot
.838 .0962 Mdot
.838 .09654 Mdot
.838 .09721 Mdot
.838 .0974 Mdot
.838 .0982 Mdot
.838 .09834 Mdot
.838 .09874 Mdot
.838 .09897 Mdot
.838 .09913 Mdot
.838 .09914 Mdot
.838 .10021 Mdot
.838 .10041 Mdot
.838 .10062 Mdot
.838 .10076 Mdot
.838 .10171 Mdot
.838 .10172 Mdot
.838 .10219 Mdot
.838 .10224 Mdot
.838 .10241 Mdot
.838 .10248 Mdot
.838 .10325 Mdot
.838 .10441 Mdot
.838 .1066 Mdot
.838 .10662 Mdot
.838 .10715 Mdot
.838 .10723 Mdot
.838 .10738 Mdot
.838 .10824 Mdot
.838 .10843 Mdot
.838 .10849 Mdot
.838 .1089 Mdot
.838 .10936 Mdot
.838 .10965 Mdot
.838 .1105 Mdot
.838 .11075 Mdot
.838 .11093 Mdot
.838 .11098 Mdot
.838 .11099 Mdot
.838 .11111 Mdot
.838 .11173 Mdot
.838 .11178 Mdot
.838 .11214 Mdot
.838 .11217 Mdot
.838 .1127 Mdot
.838 .11385 Mdot
.838 .11421 Mdot
.838 .11438 Mdot
.838 .11445 Mdot
.838 .11469 Mdot
.838 .11505 Mdot
.838 .1157 Mdot
.838 .11585 Mdot
.838 .11683 Mdot
.838 .11688 Mdot
.838 .11693 Mdot
.838 .11719 Mdot
.838 .11808 Mdot
.838 .11812 Mdot
.838 .11835 Mdot
.838 .11838 Mdot
.838 .11902 Mdot
.838 .11967 Mdot
.838 .11977 Mdot
.838 .1198 Mdot
.838 .1202 Mdot
.838 .1204 Mdot
.838 .12068 Mdot
.838 .12193 Mdot
.838 .12256 Mdot
.838 .12267 Mdot
.838 .12299 Mdot
.838 .12313 Mdot
.838 .12362 Mdot
.838 .12497 Mdot
.838 .12507 Mdot
.838 .12593 Mdot
.838 .12608 Mdot
.838 .12612 Mdot
.838 .12636 Mdot
.838 .12649 Mdot
.838 .12724 Mdot
.838 .1279 Mdot
.838 .1285 Mdot
.838 .12942 Mdot
.838 .12947 Mdot
.838 .12948 Mdot
.838 .12975 Mdot
.838 .13022 Mdot
.838 .13118 Mdot
.838 .13167 Mdot
.838 .13168 Mdot
.838 .13193 Mdot
.838 .13225 Mdot
.838 .13234 Mdot
.838 .1329 Mdot
.838 .13324 Mdot
.838 .13329 Mdot
.838 .13335 Mdot
.838 .13338 Mdot
.838 .13372 Mdot
.838 .13425 Mdot
.838 .13467 Mdot
.838 .13583 Mdot
.838 .13652 Mdot
.838 .13669 Mdot
.838 .13709 Mdot
.838 .13754 Mdot
.838 .13799 Mdot
.838 .13806 Mdot
.838 .13845 Mdot
.838 .13872 Mdot
.838 .13879 Mdot
.838 .1388 Mdot
.838 .13892 Mdot
.838 .1395 Mdot
.838 .14137 Mdot
.838 .1416 Mdot
.838 .14169 Mdot
.838 .14176 Mdot
.838 .14191 Mdot
.838 .14212 Mdot
.838 .14243 Mdot
.838 .14259 Mdot
.838 .14272 Mdot
.838 .14305 Mdot
.838 .14369 Mdot
.838 .14476 Mdot
.838 .14538 Mdot
.838 .14547 Mdot
.838 .14548 Mdot
.838 .14706 Mdot
.838 .14707 Mdot
.838 .14822 Mdot
.838 .14871 Mdot
.838 .14957 Mdot
.838 .15013 Mdot
.838 .1504 Mdot
.838 .15241 Mdot
.838 .15389 Mdot
.838 .15431 Mdot
.838 .15506 Mdot
.838 .15596 Mdot
.838 .1562 Mdot
.838 .1576 Mdot
.838 .15838 Mdot
.838 .16287 Mdot
.838 .16446 Mdot
.838 .1657 Mdot
.838 .16693 Mdot
.838 .17068 Mdot
.838 .17192 Mdot
.838 .17602 Mdot
.838 .17649 Mdot
.838 .17681 Mdot
.838 .17691 Mdot
.838 .17781 Mdot
.838 .17862 Mdot
.838 .18013 Mdot
.838 .18061 Mdot
.838 .18167 Mdot
.838 .18239 Mdot
.838 .18253 Mdot
.838 .18302 Mdot
.838 .18386 Mdot
.838 .18393 Mdot
.838 .1865 Mdot
.838 .18663 Mdot
.838 .18771 Mdot
.838 .18802 Mdot
.838 .18806 Mdot
.838 .19077 Mdot
.838 .19135 Mdot
.838 .19141 Mdot
.838 .19306 Mdot
.838 .19388 Mdot
.838 .19526 Mdot
.838 .1954 Mdot
.838 .1959 Mdot
.838 .19689 Mdot
.838 .19729 Mdot
.838 .19903 Mdot
.838 .19969 Mdot
.838 .19999 Mdot
.838 .2021 Mdot
.838 .20239 Mdot
.838 .20263 Mdot
.838 .20281 Mdot
.838 .20303 Mdot
.838 .20411 Mdot
.838 .20544 Mdot
.838 .20798 Mdot
.838 .20913 Mdot
.838 .20987 Mdot
.838 .2121 Mdot
.838 .21385 Mdot
.838 .21438 Mdot
.838 .2169 Mdot
.838 .21921 Mdot
.838 .22046 Mdot
.838 .22475 Mdot
.838 .22543 Mdot
.838 .2265 Mdot
.838 .22669 Mdot
.838 .22738 Mdot
.838 .22966 Mdot
.838 .23213 Mdot
.838 .23293 Mdot
.838 .23439 Mdot
.838 .235 Mdot
.838 .23628 Mdot
.838 .23677 Mdot
.838 .23765 Mdot
.838 .23797 Mdot
.838 .23856 Mdot
.838 .23972 Mdot
.838 .24079 Mdot
.838 .24173 Mdot
.838 .24223 Mdot
.838 .24228 Mdot
.838 .24319 Mdot
.838 .24374 Mdot
.838 .2454 Mdot
.838 .24605 Mdot
.838 .24758 Mdot
.838 .25452 Mdot
.838 .25531 Mdot
.838 .2576 Mdot
.838 .2576 Mdot
.838 .2583 Mdot
.838 .2583 Mdot
.838 .25834 Mdot
.838 .25862 Mdot
.838 .25909 Mdot
.838 .25953 Mdot
.838 .25959 Mdot
.838 .25966 Mdot
.838 .25989 Mdot
.838 .25996 Mdot
.838 .26 Mdot
.838 .26003 Mdot
.838 .26014 Mdot
.838 .26127 Mdot
.838 .26132 Mdot
.838 .26136 Mdot
.838 .26148 Mdot
.838 .2617 Mdot
.838 .26191 Mdot
.838 .26232 Mdot
.838 .26272 Mdot
.838 .26349 Mdot
.838 .26374 Mdot
.838 .26391 Mdot
.838 .26396 Mdot
.838 .26398 Mdot
.838 .26415 Mdot
.838 .26447 Mdot
.838 .26463 Mdot
.838 .26475 Mdot
.838 .26475 Mdot
.838 .265 Mdot
.838 .26548 Mdot
.838 .26572 Mdot
.838 .26586 Mdot
.838 .26586 Mdot
.838 .26589 Mdot
.838 .26667 Mdot
.838 .26741 Mdot
.838 .26748 Mdot
.838 .2676 Mdot
.838 .26762 Mdot
.838 .26816 Mdot
.838 .26894 Mdot
.838 .26947 Mdot
.838 .26987 Mdot
.838 .27058 Mdot
.838 .27085 Mdot
.838 .27108 Mdot
.838 .2711 Mdot
.838 .2719 Mdot
.838 .27192 Mdot
.838 .27208 Mdot
.838 .2726 Mdot
.838 .27279 Mdot
.838 .27412 Mdot
.838 .27427 Mdot
.838 .27432 Mdot
.838 .27442 Mdot
.838 .27465 Mdot
.838 .27538 Mdot
.838 .27572 Mdot
.838 .27597 Mdot
.838 .27601 Mdot
.838 .2765 Mdot
.838 .2765 Mdot
.838 .27682 Mdot
.838 .27739 Mdot
.838 .27791 Mdot
.838 .27819 Mdot
.838 .27823 Mdot
.838 .27837 Mdot
.838 .27898 Mdot
.838 .27954 Mdot
.838 .28275 Mdot
.838 .28294 Mdot
.838 .28332 Mdot
.838 .28413 Mdot
.838 .28444 Mdot
.838 .28461 Mdot
.838 .28557 Mdot
.838 .28571 Mdot
.838 .28593 Mdot
.838 .28643 Mdot
.838 .28738 Mdot
.838 .28926 Mdot
.838 .2898 Mdot
.838 .29201 Mdot
.838 .29241 Mdot
.838 .29263 Mdot
.838 .29264 Mdot
.838 .29336 Mdot
.838 .29343 Mdot
.838 .2935 Mdot
.838 .29415 Mdot
.838 .29424 Mdot
.838 .29459 Mdot
.838 .2946 Mdot
.838 .29529 Mdot
.838 .29756 Mdot
.838 .29809 Mdot
.838 .29868 Mdot
.838 .29906 Mdot
.838 .29947 Mdot
.838 .30166 Mdot
.838 .30169 Mdot
.838 .30297 Mdot
.838 .3031 Mdot
.838 .30358 Mdot
.838 .30375 Mdot
.838 .30519 Mdot
.838 .30575 Mdot
.838 .30584 Mdot
.838 .30585 Mdot
.838 .30873 Mdot
.838 .30898 Mdot
.838 .31365 Mdot
.838 .31476 Mdot
.838 .31484 Mdot
.838 .31489 Mdot
.838 .31628 Mdot
.838 .31649 Mdot
.838 .3169 Mdot
.838 .31726 Mdot
.838 .31761 Mdot
.838 .31843 Mdot
.838 .31859 Mdot
.838 .31861 Mdot
.838 .31909 Mdot
.838 .31918 Mdot
.838 .31969 Mdot
.838 .31985 Mdot
.838 .31996 Mdot
.838 .32093 Mdot
.838 .32105 Mdot
.838 .32213 Mdot
.838 .32289 Mdot
.838 .32302 Mdot
.838 .32512 Mdot
.838 .32528 Mdot
.838 .32577 Mdot
.838 .32624 Mdot
.838 .32637 Mdot
.838 .32639 Mdot
.838 .3267 Mdot
.838 .32831 Mdot
.838 .32846 Mdot
.838 .32889 Mdot
.838 .32931 Mdot
.838 .32937 Mdot
.838 .32945 Mdot
.838 .32963 Mdot
.838 .32998 Mdot
.838 .33084 Mdot
.838 .33174 Mdot
.838 .33246 Mdot
.838 .33378 Mdot
.838 .3347 Mdot
.838 .33514 Mdot
.838 .33533 Mdot
.838 .33595 Mdot
.838 .33686 Mdot
.838 .33851 Mdot
.838 .33889 Mdot
.838 .33895 Mdot
.838 .34044 Mdot
.838 .34138 Mdot
.838 .3415 Mdot
.838 .34162 Mdot
.838 .34229 Mdot
.838 .34413 Mdot
.838 .34453 Mdot
.838 .34462 Mdot
.838 .34521 Mdot
.838 .34527 Mdot
.838 .34598 Mdot
.838 .3465 Mdot
.838 .34688 Mdot
.838 .3473 Mdot
.838 .34851 Mdot
.838 .34875 Mdot
.838 .34882 Mdot
.838 .34982 Mdot
.838 .35033 Mdot
.838 .35102 Mdot
.838 .35167 Mdot
.838 .35361 Mdot
.838 .35411 Mdot
.838 .35475 Mdot
.838 .35563 Mdot
.838 .35591 Mdot
.838 .35636 Mdot
.838 .3567 Mdot
.838 .35704 Mdot
.838 .35823 Mdot
.838 .35866 Mdot
.838 .36093 Mdot
.838 .36115 Mdot
.838 .36151 Mdot
.838 .36175 Mdot
.838 .36187 Mdot
.838 .36334 Mdot
.838 .36382 Mdot
.838 .36419 Mdot
.838 .36429 Mdot
.838 .36486 Mdot
.838 .36518 Mdot
.838 .36697 Mdot
.838 .3676 Mdot
.838 .36855 Mdot
.838 .36999 Mdot
.838 .37215 Mdot
.838 .37227 Mdot
.838 .37231 Mdot
.838 .37293 Mdot
.838 .37348 Mdot
.838 .37365 Mdot
.838 .37404 Mdot
.838 .37434 Mdot
.838 .37452 Mdot
.838 .37482 Mdot
.838 .37618 Mdot
.838 .37629 Mdot
.838 .37745 Mdot
.838 .37747 Mdot
.838 .37804 Mdot
.838 .37879 Mdot
.838 .37884 Mdot
.838 .37901 Mdot
.838 .37934 Mdot
.838 .38029 Mdot
.838 .38109 Mdot
.838 .38119 Mdot
.838 .38133 Mdot
.838 .3814 Mdot
.838 .3822 Mdot
.838 .3834 Mdot
.838 .38437 Mdot
.838 .38493 Mdot
.838 .38664 Mdot
.838 .38703 Mdot
.838 .38859 Mdot
.838 .38892 Mdot
.838 .38898 Mdot
.838 .38919 Mdot
.838 .38989 Mdot
.838 .3909 Mdot
.838 .39192 Mdot
.838 .39207 Mdot
.838 .39233 Mdot
.838 .39243 Mdot
.838 .39296 Mdot
.838 .39356 Mdot
.838 .39371 Mdot
.838 .39373 Mdot
.838 .394 Mdot
.838 .39416 Mdot
.838 .39466 Mdot
.838 .39485 Mdot
.838 .3953 Mdot
.838 .39734 Mdot
.838 .39943 Mdot
.838 .39995 Mdot
.838 .40014 Mdot
.838 .40031 Mdot
.838 .40063 Mdot
.838 .40109 Mdot
.838 .40129 Mdot
.838 .40151 Mdot
.838 .40178 Mdot
.838 .40212 Mdot
.838 .4024 Mdot
.838 .40304 Mdot
.838 .40313 Mdot
.838 .40451 Mdot
.838 .40683 Mdot
.838 .40817 Mdot
.838 .40837 Mdot
.838 .40839 Mdot
.838 .40861 Mdot
.838 .41162 Mdot
.838 .41177 Mdot
.838 .4118 Mdot
.838 .41423 Mdot
.838 .41491 Mdot
.838 .41527 Mdot
.838 .41527 Mdot
.838 .41646 Mdot
.838 .41707 Mdot
.838 .41816 Mdot
.838 .41825 Mdot
.838 .41881 Mdot
.838 .42298 Mdot
.838 .42467 Mdot
.838 .4254 Mdot
.838 .42601 Mdot
.838 .42687 Mdot
.838 .4284 Mdot
.838 .4302 Mdot
.838 .43025 Mdot
.838 .43069 Mdot
.838 .43303 Mdot
.838 .43349 Mdot
.838 .43504 Mdot
.838 .43569 Mdot
.838 .43749 Mdot
.838 .4438 Mdot
.838 .444 Mdot
.838 .44534 Mdot
.838 .44685 Mdot
.838 .44918 Mdot
.838 .44956 Mdot
.838 .45076 Mdot
.838 .4515 Mdot
.838 .45214 Mdot
.838 .45436 Mdot
.838 .45506 Mdot
.838 .45841 Mdot
.838 .45932 Mdot
.838 .46066 Mdot
.838 .46205 Mdot
.838 .46444 Mdot
.838 .4648 Mdot
.838 .46795 Mdot
.838 .46876 Mdot
.838 .46932 Mdot
.838 .4695 Mdot
.838 .47104 Mdot
.838 .47245 Mdot
.838 .47502 Mdot
.838 .47572 Mdot
.838 .47582 Mdot
.838 .47761 Mdot
.838 .47873 Mdot
.838 .47882 Mdot
.838 .47904 Mdot
.838 .47981 Mdot
.838 .47986 Mdot
.838 .48125 Mdot
.838 .48137 Mdot
.838 .48237 Mdot
.838 .48312 Mdot
.838 .48554 Mdot
.838 .48576 Mdot
.838 .4869 Mdot
.838 .48748 Mdot
.838 .48761 Mdot
.838 .48768 Mdot
.838 .48798 Mdot
.838 .48805 Mdot
.838 .49053 Mdot
.838 .49231 Mdot
.838 .49292 Mdot
.838 .49322 Mdot
.838 .4933 Mdot
.838 .49424 Mdot
.838 .49518 Mdot
.838 .49584 Mdot
.838 .4963 Mdot
.838 .49708 Mdot
.838 .49885 Mdot
.838 .49916 Mdot
.838 .49937 Mdot
.838 .50011 Mdot
.838 .50157 Mdot
.838 .50216 Mdot
.838 .5047 Mdot
.838 .50498 Mdot
.838 .50566 Mdot
.838 .50579 Mdot
.838 .50592 Mdot
.838 .50608 Mdot
.838 .50747 Mdot
.838 .50833 Mdot
.838 .50908 Mdot
.838 .5095 Mdot
.838 .50983 Mdot
.838 .51001 Mdot
.838 .51002 Mdot
.838 .51008 Mdot
.838 .51039 Mdot
.838 .51052 Mdot
.838 .51146 Mdot
.838 .51188 Mdot
.838 .51371 Mdot
.838 .51478 Mdot
.838 .51482 Mdot
.838 .51502 Mdot
.838 .51712 Mdot
.838 .51864 Mdot
.838 .51902 Mdot
.838 .51932 Mdot
.838 .51934 Mdot
.838 .5196 Mdot
.838 .51961 Mdot
.838 .52134 Mdot
.838 .52249 Mdot
.838 .52428 Mdot
.838 .5247 Mdot
.838 .52536 Mdot
.838 .526 Mdot
.838 .52612 Mdot
.838 .5269 Mdot
.838 .52725 Mdot
.838 .52767 Mdot
.838 .52799 Mdot
.838 .52827 Mdot
.838 .52845 Mdot
.838 .5285 Mdot
.838 .52906 Mdot
.838 .52945 Mdot
.838 .52965 Mdot
.838 .52988 Mdot
.838 .53049 Mdot
.838 .53122 Mdot
.838 .53268 Mdot
.838 .53295 Mdot
.838 .53529 Mdot
.838 .5358 Mdot
.838 .53602 Mdot
.838 .53658 Mdot
.838 .53676 Mdot
.838 .53707 Mdot
.838 .53708 Mdot
.838 .53725 Mdot
.838 .53756 Mdot
.838 .53792 Mdot
.838 .5383 Mdot
.838 .5385 Mdot
.838 .5386 Mdot
.838 .5389 Mdot
.838 .53906 Mdot
.838 .53948 Mdot
.838 .53968 Mdot
.838 .54016 Mdot
.838 .54042 Mdot
.838 .54124 Mdot
.838 .54198 Mdot
.838 .54221 Mdot
.838 .54227 Mdot
.838 .54262 Mdot
.838 .54284 Mdot
.838 .54423 Mdot
.838 .54463 Mdot
.838 .54538 Mdot
.838 .54619 Mdot
.838 .54636 Mdot
.838 .54692 Mdot
.838 .54763 Mdot
.838 .54786 Mdot
.838 .54823 Mdot
.838 .54903 Mdot
.838 .54946 Mdot
.838 .5498 Mdot
.838 .54987 Mdot
.838 .54992 Mdot
.838 .55 Mdot
.838 .55009 Mdot
.838 .55076 Mdot
.838 .55085 Mdot
.838 .55106 Mdot
.838 .5516 Mdot
.838 .55173 Mdot
.838 .55204 Mdot
.838 .55219 Mdot
.838 .55224 Mdot
.838 .55267 Mdot
.838 .55292 Mdot
.838 .55344 Mdot
.838 .55346 Mdot
.838 .55364 Mdot
.838 .55448 Mdot
.838 .55449 Mdot
.838 .55459 Mdot
.838 .55492 Mdot
.838 .55496 Mdot
.838 .55575 Mdot
.838 .55578 Mdot
.838 .55604 Mdot
.838 .55619 Mdot
.838 .55623 Mdot
.838 .55645 Mdot
.838 .55678 Mdot
.838 .55692 Mdot
.838 .55738 Mdot
.838 .55764 Mdot
.838 .55791 Mdot
.838 .55794 Mdot
.838 .55804 Mdot
.838 .55818 Mdot
.838 .55943 Mdot
.838 .55981 Mdot
.838 .56094 Mdot
.838 .56131 Mdot
.838 .56168 Mdot
.838 .56216 Mdot
.838 .56351 Mdot
.838 .56374 Mdot
.838 .56416 Mdot
.838 .56423 Mdot
.838 .5645 Mdot
.838 .56472 Mdot
.838 .56485 Mdot
.838 .56528 Mdot
.838 .56588 Mdot
.838 .56596 Mdot
.838 .56613 Mdot
.838 .56638 Mdot
.838 .56653 Mdot
.838 .56686 Mdot
.838 .56687 Mdot
.838 .56733 Mdot
.838 .56734 Mdot
.838 .56736 Mdot
.838 .56755 Mdot
.838 .56786 Mdot
.838 .56805 Mdot
.838 .56814 Mdot
.838 .56818 Mdot
.838 .56823 Mdot
.838 .56832 Mdot
.838 .56838 Mdot
.838 .56842 Mdot
.838 .56845 Mdot
.838 .56847 Mdot
.838 .56854 Mdot
.838 .56909 Mdot
.838 .56926 Mdot
.838 .56929 Mdot
.838 .56929 Mdot
.838 .56931 Mdot
.838 .56939 Mdot
.838 .56951 Mdot
.838 .56953 Mdot
.838 .56966 Mdot
.838 .56979 Mdot
.838 .56991 Mdot
.838 .56996 Mdot
.838 .57016 Mdot
.838 .5705 Mdot
.838 .57062 Mdot
.838 .57077 Mdot
.838 .57087 Mdot
.838 .57088 Mdot
.838 .5709 Mdot
.838 .57091 Mdot
.838 .57101 Mdot
.838 .57117 Mdot
.838 .5712 Mdot
.838 .57129 Mdot
.838 .57136 Mdot
.838 .57137 Mdot
.838 .57151 Mdot
.838 .57179 Mdot
.838 .57192 Mdot
.838 .572 Mdot
.838 .572 Mdot
.838 .57202 Mdot
.838 .57228 Mdot
.838 .57246 Mdot
.838 .57265 Mdot
.838 .57286 Mdot
.838 .5729 Mdot
.838 .57297 Mdot
.838 .57298 Mdot
.838 .57303 Mdot
.838 .57327 Mdot
.838 .5733 Mdot
.838 .57369 Mdot
.838 .57383 Mdot
.838 .57387 Mdot
.838 .57396 Mdot
.838 .57399 Mdot
.838 .57417 Mdot
.838 .57453 Mdot
.838 .57461 Mdot
.838 .57467 Mdot
.838 .57479 Mdot
.838 .57479 Mdot
.838 .57482 Mdot
.838 .57501 Mdot
.838 .57519 Mdot
.838 .5752 Mdot
.838 .57527 Mdot
.838 .57528 Mdot
.838 .57553 Mdot
.838 .57561 Mdot
.838 .57562 Mdot
.838 .57563 Mdot
.838 .57591 Mdot
.838 .57596 Mdot
.838 .57614 Mdot
.838 .57624 Mdot
.838 .57631 Mdot
.838 .57633 Mdot
.838 .57638 Mdot
.838 .57648 Mdot
.838 .57681 Mdot
.838 .57696 Mdot
.838 .57697 Mdot
.838 .57707 Mdot
.838 .57708 Mdot
.838 .57726 Mdot
.838 .57729 Mdot
.838 .5773 Mdot
.838 .57731 Mdot
.838 .57736 Mdot
.838 .57743 Mdot
.838 .57767 Mdot
.838 .57775 Mdot
.838 .57788 Mdot
.838 .578 Mdot
.838 .57802 Mdot
.838 .57807 Mdot
.838 .57832 Mdot
.838 .57836 Mdot
.838 .57838 Mdot
.838 .57853 Mdot
.838 .57853 Mdot
.838 .57915 Mdot
.838 .57948 Mdot
.838 .5797 Mdot
.838 .57971 Mdot
.838 .57976 Mdot
.838 .57978 Mdot
.838 .57991 Mdot
.838 .57991 Mdot
.838 .58018 Mdot
.838 .58022 Mdot
.838 .58028 Mdot
.838 .58033 Mdot
.838 .58063 Mdot
.838 .58063 Mdot
.838 .58068 Mdot
.838 .58074 Mdot
.838 .58085 Mdot
.838 .58089 Mdot
.838 .58112 Mdot
.838 .58117 Mdot
.838 .58136 Mdot
.838 .58145 Mdot
.838 .5815 Mdot
.838 .58153 Mdot
.838 .58154 Mdot
.838 .58165 Mdot
.838 .58168 Mdot
.838 .58176 Mdot
.838 .5818 Mdot
.838 .58182 Mdot
.838 .58219 Mdot
.838 .58226 Mdot
.838 .58227 Mdot
.838 .5823 Mdot
.838 .58235 Mdot
.838 .5824 Mdot
.838 .58243 Mdot
.838 .58248 Mdot
.838 .58249 Mdot
.838 .58251 Mdot
.838 .58254 Mdot
.838 .58264 Mdot
.838 .58265 Mdot
.838 .58267 Mdot
.838 .5828 Mdot
.838 .58281 Mdot
.838 .58288 Mdot
.838 .58288 Mdot
.838 .58296 Mdot
.838 .58298 Mdot
.838 .58301 Mdot
.838 .58312 Mdot
.838 .5833 Mdot
.838 .58332 Mdot
.838 .58339 Mdot
.838 .58346 Mdot
.838 .58346 Mdot
.838 .58348 Mdot
.838 .5835 Mdot
.838 .58355 Mdot
.838 .58357 Mdot
.838 .58358 Mdot
.838 .5836 Mdot
.838 .58364 Mdot
.838 .58365 Mdot
.838 .58365 Mdot
.838 .58367 Mdot
.838 .58376 Mdot
.838 .5838 Mdot
.838 .58384 Mdot
.838 .58388 Mdot
.838 .58389 Mdot
.838 .5839 Mdot
.838 .5839 Mdot
.838 .58401 Mdot
.838 .58402 Mdot
.838 .58402 Mdot
.838 .58403 Mdot
.838 .58403 Mdot
.838 .58405 Mdot
.838 .58407 Mdot
.838 .58411 Mdot
.838 .58415 Mdot
.838 .58418 Mdot
.838 .58418 Mdot
.838 .58418 Mdot
.838 .58425 Mdot
.838 .58425 Mdot
.84 .08531 Mdot
.84 .08532 Mdot
.84 .08533 Mdot
.84 .08535 Mdot
.84 .08535 Mdot
.84 .08538 Mdot
.84 .08542 Mdot
.84 .08548 Mdot
.84 .08553 Mdot
.84 .08553 Mdot
.84 .08568 Mdot
.84 .08573 Mdot
.84 .08576 Mdot
.84 .08578 Mdot
.84 .08581 Mdot
.84 .08584 Mdot
.84 .08591 Mdot
.84 .08592 Mdot
.84 .08621 Mdot
.84 .08625 Mdot
.84 .08633 Mdot
.84 .08633 Mdot
.84 .08643 Mdot
.84 .08678 Mdot
.84 .08701 Mdot
.84 .08737 Mdot
.84 .08742 Mdot
.84 .08751 Mdot
.84 .08767 Mdot
.84 .08768 Mdot
.84 .08771 Mdot
.84 .08794 Mdot
.84 .08817 Mdot
.84 .0882 Mdot
.84 .08827 Mdot
.84 .08869 Mdot
.84 .0888 Mdot
.84 .08893 Mdot
.84 .08897 Mdot
.84 .08937 Mdot
.84 .08946 Mdot
.84 .08953 Mdot
.84 .08961 Mdot
.84 .08985 Mdot
.84 .08995 Mdot
.84 .09004 Mdot
.84 .09019 Mdot
.84 .09029 Mdot
.84 .09031 Mdot
.84 .09041 Mdot
.84 .0905 Mdot
.84 .0907 Mdot
.84 .0913 Mdot
.84 .09132 Mdot
.84 .09151 Mdot
.84 .09169 Mdot
.84 .09203 Mdot
.84 .09209 Mdot
.84 .09237 Mdot
.84 .09247 Mdot
.84 .09251 Mdot
.84 .09267 Mdot
.84 .09303 Mdot
.84 .09317 Mdot
.84 .09348 Mdot
.84 .09349 Mdot
.84 .09366 Mdot
.84 .09396 Mdot
.84 .09448 Mdot
.84 .09451 Mdot
.84 .09547 Mdot
.84 .0955 Mdot
.84 .09556 Mdot
.84 .09563 Mdot
.84 .09578 Mdot
.84 .09603 Mdot
.84 .09611 Mdot
.84 .09635 Mdot
.84 .09652 Mdot
.84 .0966 Mdot
.84 .09663 Mdot
.84 .09672 Mdot
.84 .09682 Mdot
.84 .09683 Mdot
.84 .09721 Mdot
.84 .09753 Mdot
.84 .09779 Mdot
.84 .09808 Mdot
.84 .09847 Mdot
.84 .09856 Mdot
.84 .09901 Mdot
.84 .09921 Mdot
.84 .09926 Mdot
.84 .09944 Mdot
.84 .09953 Mdot
.84 .10033 Mdot
.84 .10127 Mdot
.84 .10148 Mdot
.84 .10185 Mdot
.84 .10283 Mdot
.84 .10293 Mdot
.84 .10326 Mdot
.84 .10373 Mdot
.84 .10461 Mdot
.84 .10485 Mdot
.84 .10517 Mdot
.84 .106 Mdot
.84 .10603 Mdot
.84 .10626 Mdot
.84 .10668 Mdot
.84 .10672 Mdot
.84 .10786 Mdot
.84 .10798 Mdot
.84 .10815 Mdot
.84 .10857 Mdot
.84 .10886 Mdot
.84 .10893 Mdot
.84 .10904 Mdot
.84 .11005 Mdot
.84 .11073 Mdot
.84 .11076 Mdot
.84 .11095 Mdot
.84 .11125 Mdot
.84 .1114 Mdot
.84 .1116 Mdot
.84 .11262 Mdot
.84 .11288 Mdot
.84 .11445 Mdot
.84 .11529 Mdot
.84 .11545 Mdot
.84 .11621 Mdot
.84 .11629 Mdot
.84 .11927 Mdot
.84 .11979 Mdot
.84 .12022 Mdot
.84 .12024 Mdot
.84 .12027 Mdot
.84 .12072 Mdot
.84 .12086 Mdot
.84 .12122 Mdot
.84 .12136 Mdot
.84 .1219 Mdot
.84 .12259 Mdot
.84 .12268 Mdot
.84 .12311 Mdot
.84 .12337 Mdot
.84 .12354 Mdot
.84 .12365 Mdot
.84 .12456 Mdot
.84 .12465 Mdot
.84 .12481 Mdot
.84 .12494 Mdot
.84 .12538 Mdot
.84 .1258 Mdot
.84 .12628 Mdot
.84 .12691 Mdot
.84 .12759 Mdot
.84 .12853 Mdot
.84 .12873 Mdot
.84 .12894 Mdot
.84 .12935 Mdot
.84 .12949 Mdot
.84 .12957 Mdot
.84 .13005 Mdot
.84 .13011 Mdot
.84 .13062 Mdot
.84 .13256 Mdot
.84 .13271 Mdot
.84 .13304 Mdot
.84 .13321 Mdot
.84 .13457 Mdot
.84 .13597 Mdot
.84 .13616 Mdot
.84 .1362 Mdot
.84 .13626 Mdot
.84 .1367 Mdot
.84 .13722 Mdot
.84 .1378 Mdot
.84 .13786 Mdot
.84 .13811 Mdot
.84 .13858 Mdot
.84 .13899 Mdot
.84 .14034 Mdot
.84 .1404 Mdot
.84 .14128 Mdot
.84 .14185 Mdot
.84 .14189 Mdot
.84 .14413 Mdot
.84 .14423 Mdot
.84 .14478 Mdot
.84 .14479 Mdot
.84 .14536 Mdot
.84 .14557 Mdot
.84 .1456 Mdot
.84 .14685 Mdot
.84 .1474 Mdot
.84 .14756 Mdot
.84 .14761 Mdot
.84 .14811 Mdot
.84 .1483 Mdot
.84 .1483 Mdot
.84 .14853 Mdot
.84 .14866 Mdot
.84 .14886 Mdot
.84 .14904 Mdot
.84 .14923 Mdot
.84 .15025 Mdot
.84 .15026 Mdot
.84 .15056 Mdot
.84 .15104 Mdot
.84 .15126 Mdot
.84 .15151 Mdot
.84 .15152 Mdot
.84 .15153 Mdot
.84 .15168 Mdot
.84 .15172 Mdot
.84 .15175 Mdot
.84 .15359 Mdot
.84 .15396 Mdot
.84 .15404 Mdot
.84 .15504 Mdot
.84 .1568 Mdot
.84 .16023 Mdot
.84 .16058 Mdot
.84 .16062 Mdot
.84 .16073 Mdot
.84 .16371 Mdot
.84 .16406 Mdot
.84 .16421 Mdot
.84 .16467 Mdot
.84 .17012 Mdot
.84 .17056 Mdot
.84 .1718 Mdot
.84 .17295 Mdot
.84 .17313 Mdot
.84 .17572 Mdot
.84 .1758 Mdot
.84 .17669 Mdot
.84 .17723 Mdot
.84 .17948 Mdot
.84 .18033 Mdot
.84 .18035 Mdot
.84 .18075 Mdot
.84 .18177 Mdot
.84 .18405 Mdot
.84 .1895 Mdot
.84 .19064 Mdot
.84 .19722 Mdot
.84 .1982 Mdot
.84 .20049 Mdot
.84 .20095 Mdot
.84 .20133 Mdot
.84 .20171 Mdot
.84 .20607 Mdot
.84 .2065 Mdot
.84 .20797 Mdot
.84 .21065 Mdot
.84 .21128 Mdot
.84 .21517 Mdot
.84 .21648 Mdot
.84 .22136 Mdot
.84 .22138 Mdot
.84 .22276 Mdot
.84 .22306 Mdot
.84 .22347 Mdot
.84 .22356 Mdot
.84 .2262 Mdot
.84 .22665 Mdot
.84 .22903 Mdot
.84 .23053 Mdot
.84 .23394 Mdot
.84 .23481 Mdot
.84 .23529 Mdot
.84 .23543 Mdot
.84 .23712 Mdot
.84 .24061 Mdot
.84 .24373 Mdot
.84 .24423 Mdot
.84 .24455 Mdot
.84 .24592 Mdot
.84 .24694 Mdot
.84 .25163 Mdot
.84 .25168 Mdot
.84 .25183 Mdot
.84 .25393 Mdot
.84 .25434 Mdot
.84 .25529 Mdot
.84 .2553 Mdot
.84 .25532 Mdot
.84 .25538 Mdot
.84 .25539 Mdot
.84 .2555 Mdot
.84 .25559 Mdot
.84 .25579 Mdot
.84 .25592 Mdot
.84 .25592 Mdot
.84 .25636 Mdot
.84 .25652 Mdot
.84 .2566 Mdot
.84 .25666 Mdot
.84 .25676 Mdot
.84 .25684 Mdot
.84 .25705 Mdot
.84 .25707 Mdot
.84 .25793 Mdot
.84 .25803 Mdot
.84 .25828 Mdot
.84 .25828 Mdot
.84 .25858 Mdot
.84 .25959 Mdot
.84 .26025 Mdot
.84 .26109 Mdot
.84 .2613 Mdot
.84 .26145 Mdot
.84 .26172 Mdot
.84 .2622 Mdot
.84 .26222 Mdot
.84 .26231 Mdot
.84 .26297 Mdot
.84 .26363 Mdot
.84 .26372 Mdot
.84 .26395 Mdot
.84 .26491 Mdot
.84 .26516 Mdot
.84 .26543 Mdot
.84 .26547 Mdot
.84 .26575 Mdot
.84 .26586 Mdot
.84 .26596 Mdot
.84 .26712 Mdot
.84 .26737 Mdot
.84 .26759 Mdot
.84 .26782 Mdot
.84 .26851 Mdot
.84 .26857 Mdot
.84 .26867 Mdot
.84 .26881 Mdot
.84 .26904 Mdot
.84 .26947 Mdot
.84 .26977 Mdot
.84 .26984 Mdot
.84 .27005 Mdot
.84 .27013 Mdot
.84 .27038 Mdot
.84 .27041 Mdot
.84 .27065 Mdot
.84 .27094 Mdot
.84 .27268 Mdot
.84 .27273 Mdot
.84 .27318 Mdot
.84 .27328 Mdot
.84 .27379 Mdot
.84 .27477 Mdot
.84 .27493 Mdot
.84 .27572 Mdot
.84 .276 Mdot
.84 .27613 Mdot
.84 .2766 Mdot
.84 .2776 Mdot
.84 .278 Mdot
.84 .27888 Mdot
.84 .27891 Mdot
.84 .2794 Mdot
.84 .28024 Mdot
.84 .28145 Mdot
.84 .28171 Mdot
.84 .28179 Mdot
.84 .28304 Mdot
.84 .28382 Mdot
.84 .2845 Mdot
.84 .28458 Mdot
.84 .28475 Mdot
.84 .28496 Mdot
.84 .28536 Mdot
.84 .28545 Mdot
.84 .28606 Mdot
.84 .28631 Mdot
.84 .28698 Mdot
.84 .28708 Mdot
.84 .28743 Mdot
.84 .28767 Mdot
.84 .28776 Mdot
.84 .28801 Mdot
.84 .28815 Mdot
.84 .28823 Mdot
.84 .28829 Mdot
.84 .28832 Mdot
.84 .28933 Mdot
.84 .28936 Mdot
.84 .29026 Mdot
.84 .29099 Mdot
.84 .29166 Mdot
.84 .29178 Mdot
.84 .29263 Mdot
.84 .29286 Mdot
.84 .29312 Mdot
.84 .29424 Mdot
.84 .29437 Mdot
.84 .29451 Mdot
.84 .2947 Mdot
.84 .29492 Mdot
.84 .29504 Mdot
.84 .29557 Mdot
.84 .29569 Mdot
.84 .29581 Mdot
.84 .29801 Mdot
.84 .29851 Mdot
.84 .29904 Mdot
.84 .30058 Mdot
.84 .30116 Mdot
.84 .30215 Mdot
.84 .3043 Mdot
.84 .30442 Mdot
.84 .30482 Mdot
.84 .30509 Mdot
.84 .30599 Mdot
.84 .30599 Mdot
.84 .30725 Mdot
.84 .30857 Mdot
.84 .30963 Mdot
.84 .30981 Mdot
.84 .31024 Mdot
.84 .31028 Mdot
.84 .31113 Mdot
.84 .31172 Mdot
.84 .31336 Mdot
.84 .31345 Mdot
.84 .31405 Mdot
.84 .31408 Mdot
.84 .31517 Mdot
.84 .31529 Mdot
.84 .31557 Mdot
.84 .31557 Mdot
.84 .31831 Mdot
.84 .31842 Mdot
.84 .31862 Mdot
.84 .31898 Mdot
.84 .31906 Mdot
.84 .31997 Mdot
.84 .32018 Mdot
.84 .32094 Mdot
.84 .32113 Mdot
.84 .32136 Mdot
.84 .32142 Mdot
.84 .32208 Mdot
.84 .32284 Mdot
.84 .32348 Mdot
.84 .32407 Mdot
.84 .32489 Mdot
.84 .32584 Mdot
.84 .32591 Mdot
.84 .32643 Mdot
.84 .32662 Mdot
.84 .32721 Mdot
.84 .32756 Mdot
.84 .32758 Mdot
.84 .32811 Mdot
.84 .33076 Mdot
.84 .33084 Mdot
.84 .33087 Mdot
.84 .33107 Mdot
.84 .33142 Mdot
.84 .33223 Mdot
.84 .33325 Mdot
.84 .33517 Mdot
.84 .33546 Mdot
.84 .33694 Mdot
.84 .33761 Mdot
.84 .33802 Mdot
.84 .33866 Mdot
.84 .33882 Mdot
.84 .33995 Mdot
.84 .34015 Mdot
.84 .34063 Mdot
.84 .34068 Mdot
.84 .34076 Mdot
.84 .34188 Mdot
.84 .34222 Mdot
.84 .34245 Mdot
.84 .34764 Mdot
.84 .34894 Mdot
.84 .35 Mdot
.84 .35005 Mdot
.84 .35014 Mdot
.84 .35124 Mdot
.84 .35159 Mdot
.84 .35249 Mdot
.84 .35284 Mdot
.84 .35416 Mdot
.84 .35586 Mdot
.84 .35607 Mdot
.84 .35662 Mdot
.84 .35714 Mdot
.84 .35776 Mdot
.84 .35818 Mdot
.84 .35846 Mdot
.84 .3595 Mdot
.84 .36009 Mdot
.84 .36065 Mdot
.84 .36089 Mdot
.84 .36128 Mdot
.84 .36159 Mdot
.84 .36264 Mdot
.84 .36351 Mdot
.84 .36366 Mdot
.84 .36482 Mdot
.84 .36634 Mdot
.84 .36757 Mdot
.84 .36771 Mdot
.84 .36777 Mdot
.84 .36795 Mdot
.84 .37003 Mdot
.84 .3702 Mdot
.84 .37066 Mdot
.84 .37116 Mdot
.84 .37215 Mdot
.84 .37247 Mdot
.84 .37267 Mdot
.84 .37379 Mdot
.84 .37394 Mdot
.84 .37512 Mdot
.84 .37703 Mdot
.84 .37967 Mdot
.84 .38 Mdot
.84 .38076 Mdot
.84 .38104 Mdot
.84 .38117 Mdot
.84 .3843 Mdot
.84 .38555 Mdot
.84 .38596 Mdot
.84 .3875 Mdot
.84 .38794 Mdot
.84 .38803 Mdot
.84 .38816 Mdot
.84 .38819 Mdot
.84 .38915 Mdot
.84 .38988 Mdot
.84 .39034 Mdot
.84 .39164 Mdot
.84 .39179 Mdot
.84 .39234 Mdot
.84 .39339 Mdot
.84 .39432 Mdot
.84 .39671 Mdot
.84 .39733 Mdot
.84 .39745 Mdot
.84 .3994 Mdot
.84 .4005 Mdot
.84 .40065 Mdot
.84 .40074 Mdot
.84 .40158 Mdot
.84 .40197 Mdot
.84 .40207 Mdot
.84 .40214 Mdot
.84 .40519 Mdot
.84 .40563 Mdot
.84 .40585 Mdot
.84 .4063 Mdot
.84 .40705 Mdot
.84 .40707 Mdot
.84 .40802 Mdot
.84 .40829 Mdot
.84 .40874 Mdot
.84 .40881 Mdot
.84 .40886 Mdot
.84 .40914 Mdot
.84 .40991 Mdot
.84 .4115 Mdot
.84 .41266 Mdot
.84 .413 Mdot
.84 .41312 Mdot
.84 .41352 Mdot
.84 .41416 Mdot
.84 .41456 Mdot
.84 .41456 Mdot
.84 .41506 Mdot
.84 .41533 Mdot
.84 .41548 Mdot
.84 .41575 Mdot
.84 .41613 Mdot
.84 .41652 Mdot
.84 .41868 Mdot
.84 .41868 Mdot
.84 .41874 Mdot
.84 .41905 Mdot
.84 .41932 Mdot
.84 .42031 Mdot
.84 .42077 Mdot
.84 .4213 Mdot
.84 .42131 Mdot
.84 .42133 Mdot
.84 .42163 Mdot
.84 .42172 Mdot
.84 .42178 Mdot
.84 .42556 Mdot
.84 .42633 Mdot
.84 .42649 Mdot
.84 .42848 Mdot
.84 .42852 Mdot
.84 .42913 Mdot
.84 .431 Mdot
.84 .43207 Mdot
.84 .43327 Mdot
.84 .43338 Mdot
.84 .43443 Mdot
.84 .43757 Mdot
.84 .43773 Mdot
.84 .43885 Mdot
.84 .43932 Mdot
.84 .43954 Mdot
.84 .43962 Mdot
.84 .43983 Mdot
.84 .4456 Mdot
.84 .44626 Mdot
.84 .44655 Mdot
.84 .44743 Mdot
.84 .45757 Mdot
.84 .45838 Mdot
.84 .45846 Mdot
.84 .46005 Mdot
.84 .46057 Mdot
.84 .46063 Mdot
.84 .46177 Mdot
.84 .46269 Mdot
.84 .46301 Mdot
.84 .4676 Mdot
.84 .46775 Mdot
.84 .4693 Mdot
.84 .47023 Mdot
.84 .47192 Mdot
.84 .47228 Mdot
.84 .47241 Mdot
.84 .4728 Mdot
.84 .4736 Mdot
.84 .47411 Mdot
.84 .47551 Mdot
.84 .47554 Mdot
.84 .47559 Mdot
.84 .47576 Mdot
.84 .47625 Mdot
.84 .47797 Mdot
.84 .48101 Mdot
.84 .48176 Mdot
.84 .48274 Mdot
.84 .48292 Mdot
.84 .48487 Mdot
.84 .4866 Mdot
.84 .48957 Mdot
.84 .49052 Mdot
.84 .49055 Mdot
.84 .4906 Mdot
.84 .4923 Mdot
.84 .49371 Mdot
.84 .49395 Mdot
.84 .49513 Mdot
.84 .50083 Mdot
.84 .50092 Mdot
.84 .50106 Mdot
.84 .5015 Mdot
.84 .50153 Mdot
.84 .50155 Mdot
.84 .50227 Mdot
.84 .50233 Mdot
.84 .503 Mdot
.84 .5037 Mdot
.84 .50444 Mdot
.84 .50484 Mdot
.84 .50529 Mdot
.84 .50537 Mdot
.84 .50538 Mdot
.84 .507 Mdot
.84 .50767 Mdot
.84 .50821 Mdot
.84 .50845 Mdot
.84 .50874 Mdot
.84 .50902 Mdot
.84 .50954 Mdot
.84 .50992 Mdot
.84 .51013 Mdot
.84 .5112 Mdot
.84 .5112 Mdot
.84 .51176 Mdot
.84 .51264 Mdot
.84 .5132 Mdot
.84 .51335 Mdot
.84 .51382 Mdot
.84 .51477 Mdot
.84 .51535 Mdot
.84 .5154 Mdot
.84 .51732 Mdot
.84 .51752 Mdot
.84 .51854 Mdot
.84 .5189 Mdot
.84 .51897 Mdot
.84 .51907 Mdot
.84 .51965 Mdot
.84 .52 Mdot
.84 .52084 Mdot
.84 .52123 Mdot
.84 .52126 Mdot
.84 .52164 Mdot
.84 .52223 Mdot
.84 .52281 Mdot
.84 .52308 Mdot
.84 .52365 Mdot
.84 .52655 Mdot
.84 .52744 Mdot
.84 .52752 Mdot
.84 .52765 Mdot
.84 .52813 Mdot
.84 .52816 Mdot
.84 .52913 Mdot
.84 .52925 Mdot
.84 .52943 Mdot
.84 .53074 Mdot
.84 .53304 Mdot
.84 .53318 Mdot
.84 .53389 Mdot
.84 .53394 Mdot
.84 .53396 Mdot
.84 .53554 Mdot
.84 .53588 Mdot
.84 .53634 Mdot
.84 .53644 Mdot
.84 .53661 Mdot
.84 .53765 Mdot
.84 .53881 Mdot
.84 .53937 Mdot
.84 .53942 Mdot
.84 .53957 Mdot
.84 .53986 Mdot
.84 .54098 Mdot
.84 .54147 Mdot
.84 .54225 Mdot
.84 .54239 Mdot
.84 .54325 Mdot
.84 .54328 Mdot
.84 .54341 Mdot
.84 .54351 Mdot
.84 .54396 Mdot
.84 .54396 Mdot
.84 .54554 Mdot
.84 .54596 Mdot
.84 .5472 Mdot
.84 .5474 Mdot
.84 .54826 Mdot
.84 .54872 Mdot
.84 .54886 Mdot
.84 .55024 Mdot
.84 .55036 Mdot
.84 .55048 Mdot
.84 .55062 Mdot
.84 .55134 Mdot
.84 .55165 Mdot
.84 .5537 Mdot
.84 .55405 Mdot
.84 .55574 Mdot
.84 .55644 Mdot
.84 .55675 Mdot
.84 .55688 Mdot
.84 .55688 Mdot
.84 .55714 Mdot
.84 .55783 Mdot
.84 .558 Mdot
.84 .55827 Mdot
.84 .55829 Mdot
.84 .55908 Mdot
.84 .55914 Mdot
.84 .55948 Mdot
.84 .55986 Mdot
.84 .56 Mdot
.84 .56164 Mdot
.84 .56178 Mdot
.84 .56182 Mdot
.84 .56193 Mdot
.84 .56282 Mdot
.84 .56286 Mdot
.84 .56287 Mdot
.84 .56297 Mdot
.84 .564 Mdot
.84 .56452 Mdot
.84 .56482 Mdot
.84 .56484 Mdot
.84 .56495 Mdot
.84 .5655 Mdot
.84 .56551 Mdot
.84 .56552 Mdot
.84 .56556 Mdot
.84 .56557 Mdot
.84 .56557 Mdot
.84 .56564 Mdot
.84 .56571 Mdot
.84 .56585 Mdot
.84 .56594 Mdot
.84 .56594 Mdot
.84 .56624 Mdot
.84 .5663 Mdot
.84 .56635 Mdot
.84 .56641 Mdot
.84 .56645 Mdot
.84 .56652 Mdot
.84 .56652 Mdot
.84 .56658 Mdot
.84 .56672 Mdot
.84 .56674 Mdot
.84 .56678 Mdot
.84 .56694 Mdot
.84 .56731 Mdot
.84 .56732 Mdot
.84 .56738 Mdot
.84 .56755 Mdot
.84 .56755 Mdot
.84 .56772 Mdot
.84 .56775 Mdot
.84 .5684 Mdot
.84 .56842 Mdot
.84 .56858 Mdot
.84 .56884 Mdot
.84 .56886 Mdot
.84 .56925 Mdot
.84 .56937 Mdot
.84 .56951 Mdot
.84 .56958 Mdot
.84 .5696 Mdot
.84 .56977 Mdot
.84 .56992 Mdot
.84 .57005 Mdot
.84 .57006 Mdot
.84 .57008 Mdot
.84 .57013 Mdot
.84 .57054 Mdot
.84 .57093 Mdot
.84 .57098 Mdot
.84 .57108 Mdot
.84 .57112 Mdot
.84 .57169 Mdot
.84 .57183 Mdot
.84 .57185 Mdot
.84 .57199 Mdot
.84 .57201 Mdot
.84 .57205 Mdot
.84 .57217 Mdot
.84 .57223 Mdot
.84 .57229 Mdot
.84 .57256 Mdot
.84 .57275 Mdot
.84 .57294 Mdot
.84 .57308 Mdot
.84 .5732 Mdot
.84 .57332 Mdot
.84 .57336 Mdot
.84 .57341 Mdot
.84 .57343 Mdot
.84 .57369 Mdot
.84 .57373 Mdot
.84 .57378 Mdot
.84 .57385 Mdot
.84 .57397 Mdot
.84 .574 Mdot
.84 .5742 Mdot
.84 .57435 Mdot
.84 .57439 Mdot
.84 .57449 Mdot
.84 .57453 Mdot
.84 .57466 Mdot
.84 .57467 Mdot
.84 .57468 Mdot
.84 .5748 Mdot
.84 .57495 Mdot
.84 .5758 Mdot
.84 .57582 Mdot
.84 .57604 Mdot
.84 .57608 Mdot
.84 .57632 Mdot
.84 .57677 Mdot
.84 .57684 Mdot
.84 .57713 Mdot
.84 .57719 Mdot
.84 .57723 Mdot
.84 .57731 Mdot
.84 .57737 Mdot
.84 .57738 Mdot
.84 .57757 Mdot
.84 .57786 Mdot
.84 .57789 Mdot
.84 .57791 Mdot
.84 .57799 Mdot
.84 .57811 Mdot
.84 .57816 Mdot
.84 .57819 Mdot
.84 .57851 Mdot
.84 .57852 Mdot
.84 .57864 Mdot
.84 .57871 Mdot
.84 .57871 Mdot
.84 .57895 Mdot
.84 .57904 Mdot
.84 .57911 Mdot
.84 .57935 Mdot
.84 .57949 Mdot
.84 .57958 Mdot
.84 .57961 Mdot
.84 .57988 Mdot
.84 .57998 Mdot
.84 .58004 Mdot
.84 .58031 Mdot
.84 .58053 Mdot
.84 .58056 Mdot
.84 .58061 Mdot
.84 .58062 Mdot
.84 .58068 Mdot
.84 .5808 Mdot
.84 .58083 Mdot
.84 .58094 Mdot
.84 .58102 Mdot
.84 .58109 Mdot
.84 .58118 Mdot
.84 .58129 Mdot
.84 .58129 Mdot
.84 .58132 Mdot
.84 .58134 Mdot
.84 .58135 Mdot
.84 .58137 Mdot
.84 .58142 Mdot
.84 .58149 Mdot
.84 .58151 Mdot
.84 .58158 Mdot
.84 .58162 Mdot
.84 .58164 Mdot
.84 .58166 Mdot
.84 .58167 Mdot
.84 .58193 Mdot
.84 .58194 Mdot
.84 .58209 Mdot
.84 .58217 Mdot
.84 .58222 Mdot
.84 .58222 Mdot
.84 .58231 Mdot
.84 .58235 Mdot
.84 .58244 Mdot
.84 .58249 Mdot
.84 .5825 Mdot
.84 .58253 Mdot
.84 .58261 Mdot
.84 .58262 Mdot
.84 .58272 Mdot
.84 .58277 Mdot
.84 .58282 Mdot
.84 .58283 Mdot
.84 .58299 Mdot
.84 .58305 Mdot
.84 .58307 Mdot
.84 .5831 Mdot
.84 .58311 Mdot
.84 .58314 Mdot
.84 .58318 Mdot
.84 .5832 Mdot
.84 .58323 Mdot
.84 .58329 Mdot
.84 .58332 Mdot
.84 .58334 Mdot
.84 .58336 Mdot
.84 .58347 Mdot
.84 .58348 Mdot
.84 .58352 Mdot
.84 .58355 Mdot
.84 .58366 Mdot
.84 .58369 Mdot
.84 .58369 Mdot
.84 .58376 Mdot
.84 .58382 Mdot
.84 .58383 Mdot
.84 .58383 Mdot
.84 .58388 Mdot
.84 .5839 Mdot
.84 .58392 Mdot
.84 .58402 Mdot
.84 .58408 Mdot
.84 .58417 Mdot
.84 .5842 Mdot
.84 .5842 Mdot
.84 .58423 Mdot
.84 .58424 Mdot
.84 .58432 Mdot
.84 .58432 Mdot
.84 .58434 Mdot
.84 .58435 Mdot
.84 .58435 Mdot
.84 .58436 Mdot
.84 .58437 Mdot
.84 .58438 Mdot
.84 .58442 Mdot
.84 .58442 Mdot
.84 .58444 Mdot
.84 .58445 Mdot
.84 .58446 Mdot
.84 .58447 Mdot
.84 .58447 Mdot
.84 .58448 Mdot
.84 .58448 Mdot
.84 .58448 Mdot
.842 .08449 Mdot
.842 .08449 Mdot
.842 .08449 Mdot
.842 .08449 Mdot
.842 .08449 Mdot
.842 .0845 Mdot
.842 .08451 Mdot
.842 .08453 Mdot
.842 .08453 Mdot
.842 .08454 Mdot
.842 .08455 Mdot
.842 .08455 Mdot
.842 .08459 Mdot
.842 .0846 Mdot
.842 .08474 Mdot
.842 .08482 Mdot
.842 .08516 Mdot
.842 .08519 Mdot
.842 .08523 Mdot
.842 .08524 Mdot
.842 .08525 Mdot
.842 .08535 Mdot
.842 .08537 Mdot
.842 .08552 Mdot
.842 .08555 Mdot
.842 .08568 Mdot
.842 .08577 Mdot
.842 .08581 Mdot
.842 .08594 Mdot
.842 .0862 Mdot
.842 .08629 Mdot
.842 .08667 Mdot
.842 .08694 Mdot
.842 .08702 Mdot
.842 .08744 Mdot
.842 .08764 Mdot
.842 .08789 Mdot
.842 .0886 Mdot
.842 .08892 Mdot
.842 .08897 Mdot
.842 .08907 Mdot
.842 .08913 Mdot
.842 .08929 Mdot
.842 .08965 Mdot
.842 .08965 Mdot
.842 .08987 Mdot
.842 .08993 Mdot
.842 .08999 Mdot
.842 .09015 Mdot
.842 .09031 Mdot
.842 .0907 Mdot
.842 .09083 Mdot
.842 .091 Mdot
.842 .09205 Mdot
.842 .09234 Mdot
.842 .0925 Mdot
.842 .09254 Mdot
.842 .09278 Mdot
.842 .09289 Mdot
.842 .09295 Mdot
.842 .09354 Mdot
.842 .09365 Mdot
.842 .09381 Mdot
.842 .09394 Mdot
.842 .09406 Mdot
.842 .09441 Mdot
.842 .09506 Mdot
.842 .09528 Mdot
.842 .09541 Mdot
.842 .09547 Mdot
.842 .09572 Mdot
.842 .09593 Mdot
.842 .09614 Mdot
.842 .09652 Mdot
.842 .09665 Mdot
.842 .09689 Mdot
.842 .09717 Mdot
.842 .09761 Mdot
.842 .09782 Mdot
.842 .09842 Mdot
.842 .09861 Mdot
.842 .09877 Mdot
.842 .0988 Mdot
.842 .09922 Mdot
.842 .09995 Mdot
.842 .10024 Mdot
.842 .1006 Mdot
.842 .10188 Mdot
.842 .10225 Mdot
.842 .10352 Mdot
.842 .10379 Mdot
.842 .10385 Mdot
.842 .104 Mdot
.842 .10423 Mdot
.842 .10447 Mdot
.842 .10493 Mdot
.842 .10494 Mdot
.842 .10512 Mdot
.842 .10556 Mdot
.842 .10574 Mdot
.842 .10636 Mdot
.842 .10643 Mdot
.842 .10725 Mdot
.842 .10792 Mdot
.842 .1082 Mdot
.842 .10865 Mdot
.842 .10955 Mdot
.842 .10968 Mdot
.842 .10988 Mdot
.842 .11049 Mdot
.842 .11057 Mdot
.842 .11188 Mdot
.842 .11248 Mdot
.842 .11257 Mdot
.842 .11292 Mdot
.842 .11556 Mdot
.842 .11682 Mdot
.842 .11767 Mdot
.842 .11831 Mdot
.842 .12032 Mdot
.842 .12114 Mdot
.842 .12197 Mdot
.842 .1223 Mdot
.842 .12261 Mdot
.842 .12378 Mdot
.842 .12378 Mdot
.842 .12427 Mdot
.842 .12431 Mdot
.842 .12454 Mdot
.842 .12575 Mdot
.842 .12576 Mdot
.842 .12664 Mdot
.842 .12691 Mdot
.842 .12701 Mdot
.842 .12759 Mdot
.842 .12786 Mdot
.842 .12849 Mdot
.842 .12931 Mdot
.842 .1297 Mdot
.842 .13046 Mdot
.842 .13077 Mdot
.842 .13259 Mdot
.842 .1326 Mdot
.842 .13375 Mdot
.842 .13393 Mdot
.842 .13425 Mdot
.842 .13432 Mdot
.842 .13466 Mdot
.842 .13543 Mdot
.842 .13594 Mdot
.842 .13667 Mdot
.842 .13799 Mdot
.842 .13933 Mdot
.842 .13986 Mdot
.842 .1401 Mdot
.842 .1416 Mdot
.842 .14174 Mdot
.842 .14214 Mdot
.842 .14215 Mdot
.842 .1441 Mdot
.842 .14471 Mdot
.842 .14487 Mdot
.842 .14509 Mdot
.842 .14635 Mdot
.842 .14649 Mdot
.842 .14739 Mdot
.842 .14762 Mdot
.842 .14828 Mdot
.842 .14918 Mdot
.842 .14936 Mdot
.842 .15024 Mdot
.842 .15044 Mdot
.842 .15057 Mdot
.842 .15109 Mdot
.842 .15127 Mdot
.842 .15133 Mdot
.842 .15141 Mdot
.842 .15169 Mdot
.842 .15186 Mdot
.842 .15334 Mdot
.842 .15337 Mdot
.842 .15382 Mdot
.842 .1543 Mdot
.842 .15476 Mdot
.842 .15488 Mdot
.842 .1559 Mdot
.842 .15597 Mdot
.842 .15629 Mdot
.842 .15631 Mdot
.842 .15637 Mdot
.842 .1564 Mdot
.842 .15645 Mdot
.842 .15659 Mdot
.842 .15661 Mdot
.842 .15668 Mdot
.842 .15671 Mdot
.842 .15673 Mdot
.842 .15673 Mdot
.842 .15673 Mdot
.842 .15859 Mdot
.842 .15862 Mdot
.842 .1588 Mdot
.842 .1588 Mdot
.842 .16024 Mdot
.842 .16081 Mdot
.842 .16112 Mdot
.842 .16345 Mdot
.842 .16438 Mdot
.842 .16458 Mdot
.842 .16469 Mdot
.842 .16479 Mdot
.842 .16606 Mdot
.842 .16956 Mdot
.842 .16998 Mdot
.842 .17099 Mdot
.842 .17253 Mdot
.842 .17332 Mdot
.842 .17421 Mdot
.842 .17523 Mdot
.842 .17688 Mdot
.842 .17777 Mdot
.842 .17873 Mdot
.842 .18181 Mdot
.842 .18196 Mdot
.842 .18281 Mdot
.842 .18349 Mdot
.842 .18485 Mdot
.842 .19034 Mdot
.842 .19075 Mdot
.842 .19202 Mdot
.842 .19269 Mdot
.842 .19386 Mdot
.842 .19694 Mdot
.842 .19722 Mdot
.842 .19736 Mdot
.842 .19897 Mdot
.842 .19979 Mdot
.842 .19987 Mdot
.842 .20006 Mdot
.842 .20009 Mdot
.842 .20023 Mdot
.842 .20322 Mdot
.842 .20501 Mdot
.842 .2053 Mdot
.842 .20658 Mdot
.842 .20872 Mdot
.842 .20888 Mdot
.842 .20935 Mdot
.842 .21179 Mdot
.842 .21258 Mdot
.842 .2173 Mdot
.842 .22105 Mdot
.842 .22599 Mdot
.842 .22635 Mdot
.842 .22891 Mdot
.842 .23436 Mdot
.842 .23557 Mdot
.842 .23616 Mdot
.842 .23727 Mdot
.842 .24458 Mdot
.842 .24525 Mdot
.842 .24622 Mdot
.842 .24685 Mdot
.842 .24742 Mdot
.842 .24796 Mdot
.842 .24978 Mdot
.842 .24981 Mdot
.842 .24986 Mdot
.842 .25029 Mdot
.842 .25212 Mdot
.842 .25221 Mdot
.842 .25295 Mdot
.842 .25295 Mdot
.842 .25295 Mdot
.842 .25296 Mdot
.842 .25297 Mdot
.842 .253 Mdot
.842 .25301 Mdot
.842 .25307 Mdot
.842 .25309 Mdot
.842 .2531 Mdot
.842 .25312 Mdot
.842 .25313 Mdot
.842 .25326 Mdot
.842 .25329 Mdot
.842 .2537 Mdot
.842 .25394 Mdot
.842 .25495 Mdot
.842 .25502 Mdot
.842 .25514 Mdot
.842 .25517 Mdot
.842 .25519 Mdot
.842 .25549 Mdot
.842 .25554 Mdot
.842 .256 Mdot
.842 .25608 Mdot
.842 .25646 Mdot
.842 .25674 Mdot
.842 .25684 Mdot
.842 .25723 Mdot
.842 .258 Mdot
.842 .25827 Mdot
.842 .25938 Mdot
.842 .26016 Mdot
.842 .2604 Mdot
.842 .26102 Mdot
.842 .26163 Mdot
.842 .26221 Mdot
.842 .26293 Mdot
.842 .26357 Mdot
.842 .26446 Mdot
.842 .26461 Mdot
.842 .26499 Mdot
.842 .26519 Mdot
.842 .26592 Mdot
.842 .26606 Mdot
.842 .26635 Mdot
.842 .26654 Mdot
.842 .267 Mdot
.842 .26776 Mdot
.842 .26778 Mdot
.842 .26804 Mdot
.842 .26804 Mdot
.842 .26866 Mdot
.842 .26883 Mdot
.842 .26902 Mdot
.842 .26947 Mdot
.842 .26992 Mdot
.842 .27105 Mdot
.842 .27142 Mdot
.842 .27191 Mdot
.842 .27453 Mdot
.842 .27491 Mdot
.842 .27575 Mdot
.842 .2762 Mdot
.842 .27633 Mdot
.842 .27701 Mdot
.842 .27731 Mdot
.842 .2775 Mdot
.842 .27915 Mdot
.842 .27947 Mdot
.842 .27994 Mdot
.842 .28029 Mdot
.842 .28065 Mdot
.842 .28162 Mdot
.842 .28191 Mdot
.842 .28293 Mdot
.842 .28323 Mdot
.842 .28347 Mdot
.842 .28409 Mdot
.842 .28444 Mdot
.842 .28461 Mdot
.842 .28477 Mdot
.842 .2853 Mdot
.842 .28589 Mdot
.842 .2865 Mdot
.842 .28686 Mdot
.842 .28757 Mdot
.842 .28769 Mdot
.842 .28791 Mdot
.842 .28858 Mdot
.842 .28894 Mdot
.842 .28938 Mdot
.842 .29014 Mdot
.842 .29061 Mdot
.842 .29066 Mdot
.842 .29119 Mdot
.842 .29286 Mdot
.842 .29338 Mdot
.842 .2936 Mdot
.842 .29381 Mdot
.842 .2939 Mdot
.842 .29429 Mdot
.842 .29505 Mdot
.842 .2953 Mdot
.842 .29588 Mdot
.842 .29707 Mdot
.842 .29788 Mdot
.842 .29887 Mdot
.842 .30031 Mdot
.842 .30053 Mdot
.842 .30158 Mdot
.842 .30167 Mdot
.842 .30235 Mdot
.842 .30301 Mdot
.842 .30337 Mdot
.842 .30368 Mdot
.842 .3068 Mdot
.842 .30754 Mdot
.842 .30771 Mdot
.842 .30811 Mdot
.842 .30838 Mdot
.842 .30867 Mdot
.842 .30872 Mdot
.842 .30938 Mdot
.842 .30946 Mdot
.842 .30998 Mdot
.842 .31044 Mdot
.842 .3106 Mdot
.842 .31064 Mdot
.842 .31112 Mdot
.842 .3123 Mdot
.842 .31277 Mdot
.842 .31444 Mdot
.842 .31459 Mdot
.842 .31464 Mdot
.842 .31509 Mdot
.842 .31561 Mdot
.842 .31608 Mdot
.842 .31682 Mdot
.842 .31859 Mdot
.842 .31933 Mdot
.842 .32053 Mdot
.842 .32266 Mdot
.842 .32289 Mdot
.842 .32322 Mdot
.842 .32375 Mdot
.842 .32405 Mdot
.842 .32534 Mdot
.842 .32556 Mdot
.842 .32719 Mdot
.842 .32769 Mdot
.842 .32781 Mdot
.842 .32853 Mdot
.842 .32883 Mdot
.842 .32896 Mdot
.842 .33052 Mdot
.842 .33076 Mdot
.842 .33097 Mdot
.842 .33165 Mdot
.842 .33188 Mdot
.842 .33254 Mdot
.842 .33356 Mdot
.842 .33759 Mdot
.842 .33763 Mdot
.842 .33791 Mdot
.842 .33843 Mdot
.842 .33843 Mdot
.842 .33901 Mdot
.842 .33945 Mdot
.842 .3395 Mdot
.842 .34007 Mdot
.842 .34162 Mdot
.842 .34223 Mdot
.842 .34356 Mdot
.842 .34377 Mdot
.842 .34538 Mdot
.842 .35039 Mdot
.842 .35103 Mdot
.842 .35163 Mdot
.842 .35243 Mdot
.842 .35447 Mdot
.842 .35502 Mdot
.842 .35526 Mdot
.842 .35529 Mdot
.842 .35545 Mdot
.842 .35606 Mdot
.842 .35798 Mdot
.842 .35872 Mdot
.842 .3589 Mdot
.842 .3589 Mdot
.842 .3601 Mdot
.842 .3602 Mdot
.842 .36075 Mdot
.842 .36241 Mdot
.842 .36276 Mdot
.842 .3637 Mdot
.842 .36371 Mdot
.842 .36389 Mdot
.842 .36428 Mdot
.842 .36584 Mdot
.842 .36591 Mdot
.842 .36648 Mdot
.842 .36671 Mdot
.842 .36683 Mdot
.842 .3681 Mdot
.842 .36875 Mdot
.842 .37024 Mdot
.842 .37148 Mdot
.842 .37218 Mdot
.842 .37311 Mdot
.842 .37456 Mdot
.842 .37461 Mdot
.842 .37491 Mdot
.842 .37515 Mdot
.842 .37563 Mdot
.842 .37754 Mdot
.842 .37768 Mdot
.842 .37812 Mdot
.842 .37835 Mdot
.842 .37875 Mdot
.842 .37978 Mdot
.842 .37988 Mdot
.842 .3799 Mdot
.842 .37993 Mdot
.842 .38047 Mdot
.842 .38074 Mdot
.842 .38083 Mdot
.842 .38084 Mdot
.842 .38089 Mdot
.842 .38256 Mdot
.842 .38297 Mdot
.842 .38372 Mdot
.842 .38387 Mdot
.842 .38466 Mdot
.842 .38491 Mdot
.842 .38641 Mdot
.842 .38759 Mdot
.842 .38923 Mdot
.842 .39002 Mdot
.842 .39222 Mdot
.842 .39256 Mdot
.842 .39474 Mdot
.842 .39494 Mdot
.842 .39522 Mdot
.842 .39541 Mdot
.842 .39558 Mdot
.842 .39574 Mdot
.842 .39627 Mdot
.842 .39628 Mdot
.842 .39629 Mdot
.842 .39642 Mdot
.842 .39696 Mdot
.842 .39953 Mdot
.842 .40027 Mdot
.842 .40052 Mdot
.842 .40056 Mdot
.842 .40146 Mdot
.842 .40147 Mdot
.842 .40338 Mdot
.842 .40573 Mdot
.842 .40582 Mdot
.842 .40683 Mdot
.842 .40706 Mdot
.842 .4074 Mdot
.842 .40773 Mdot
.842 .40788 Mdot
.842 .40888 Mdot
.842 .41053 Mdot
.842 .41059 Mdot
.842 .41088 Mdot
.842 .4109 Mdot
.842 .41127 Mdot
.842 .41281 Mdot
.842 .41316 Mdot
.842 .41329 Mdot
.842 .41441 Mdot
.842 .41455 Mdot
.842 .41469 Mdot
.842 .41659 Mdot
.842 .41696 Mdot
.842 .41882 Mdot
.842 .41924 Mdot
.842 .41951 Mdot
.842 .42059 Mdot
.842 .4206 Mdot
.842 .42097 Mdot
.842 .42108 Mdot
.842 .42125 Mdot
.842 .42183 Mdot
.842 .42218 Mdot
.842 .42433 Mdot
.842 .42523 Mdot
.842 .42529 Mdot
.842 .42621 Mdot
.842 .42719 Mdot
.842 .42759 Mdot
.842 .42812 Mdot
.842 .42837 Mdot
.842 .4296 Mdot
.842 .43042 Mdot
.842 .43044 Mdot
.842 .43058 Mdot
.842 .43122 Mdot
.842 .43125 Mdot
.842 .43137 Mdot
.842 .43143 Mdot
.842 .43154 Mdot
.842 .43181 Mdot
.842 .43185 Mdot
.842 .432 Mdot
.842 .43207 Mdot
.842 .43209 Mdot
.842 .4321 Mdot
.842 .43211 Mdot
.842 .43581 Mdot
.842 .43586 Mdot
.842 .43599 Mdot
.842 .43603 Mdot
.842 .43622 Mdot
.842 .43622 Mdot
.842 .43709 Mdot
.842 .43736 Mdot
.842 .43813 Mdot
.842 .43879 Mdot
.842 .43906 Mdot
.842 .43961 Mdot
.842 .44016 Mdot
.842 .44077 Mdot
.842 .44111 Mdot
.842 .44527 Mdot
.842 .44705 Mdot
.842 .44735 Mdot
.842 .44742 Mdot
.842 .44764 Mdot
.842 .44782 Mdot
.842 .45023 Mdot
.842 .4535 Mdot
.842 .45674 Mdot
.842 .45751 Mdot
.842 .45793 Mdot
.842 .45826 Mdot
.842 .45866 Mdot
.842 .45879 Mdot
.842 .45933 Mdot
.842 .45935 Mdot
.842 .46213 Mdot
.842 .46254 Mdot
.842 .46354 Mdot
.842 .46513 Mdot
.842 .46694 Mdot
.842 .46982 Mdot
.842 .46988 Mdot
.842 .47047 Mdot
.842 .47136 Mdot
.842 .47153 Mdot
.842 .47248 Mdot
.842 .47301 Mdot
.842 .47343 Mdot
.842 .4739 Mdot
.842 .47501 Mdot
.842 .47632 Mdot
.842 .47676 Mdot
.842 .47823 Mdot
.842 .47823 Mdot
.842 .47824 Mdot
.842 .47848 Mdot
.842 .47855 Mdot
.842 .47862 Mdot
.842 .47883 Mdot
.842 .47892 Mdot
.842 .4799 Mdot
.842 .48102 Mdot
.842 .48326 Mdot
.842 .48501 Mdot
.842 .48503 Mdot
.842 .48503 Mdot
.842 .48507 Mdot
.842 .48519 Mdot
.842 .48542 Mdot
.842 .48548 Mdot
.842 .48593 Mdot
.842 .4861 Mdot
.842 .4862 Mdot
.842 .48639 Mdot
.842 .48645 Mdot
.842 .48747 Mdot
.842 .4877 Mdot
.842 .48772 Mdot
.842 .48902 Mdot
.842 .49098 Mdot
.842 .49136 Mdot
.842 .49204 Mdot
.842 .4922 Mdot
.842 .49267 Mdot
.842 .49281 Mdot
.842 .49433 Mdot
.842 .49463 Mdot
.842 .49566 Mdot
.842 .49574 Mdot
.842 .49584 Mdot
.842 .49721 Mdot
.842 .49746 Mdot
.842 .50045 Mdot
.842 .50097 Mdot
.842 .50182 Mdot
.842 .50205 Mdot
.842 .50207 Mdot
.842 .50224 Mdot
.842 .50247 Mdot
.842 .50267 Mdot
.842 .50278 Mdot
.842 .5028 Mdot
.842 .50437 Mdot
.842 .50477 Mdot
.842 .50503 Mdot
.842 .50538 Mdot
.842 .50621 Mdot
.842 .50632 Mdot
.842 .5066 Mdot
.842 .50664 Mdot
.842 .50684 Mdot
.842 .50804 Mdot
.842 .50857 Mdot
.842 .51106 Mdot
.842 .51124 Mdot
.842 .51143 Mdot
.842 .51162 Mdot
.842 .51317 Mdot
.842 .51334 Mdot
.842 .51353 Mdot
.842 .51383 Mdot
.842 .51393 Mdot
.842 .51567 Mdot
.842 .51591 Mdot
.842 .51641 Mdot
.842 .51644 Mdot
.842 .51682 Mdot
.842 .5169 Mdot
.842 .51852 Mdot
.842 .51873 Mdot
.842 .51909 Mdot
.842 .51934 Mdot
.842 .5204 Mdot
.842 .52059 Mdot
.842 .52102 Mdot
.842 .52146 Mdot
.842 .52176 Mdot
.842 .52251 Mdot
.842 .52306 Mdot
.842 .52316 Mdot
.842 .52352 Mdot
.842 .52612 Mdot
.842 .52847 Mdot
.842 .52848 Mdot
.842 .52937 Mdot
.842 .52956 Mdot
.842 .52962 Mdot
.842 .52992 Mdot
.842 .5308 Mdot
.842 .5338 Mdot
.842 .53383 Mdot
.842 .53444 Mdot
.842 .53459 Mdot
.842 .5346 Mdot
.842 .53462 Mdot
.842 .53523 Mdot
.842 .53541 Mdot
.842 .5356 Mdot
.842 .53581 Mdot
.842 .53614 Mdot
.842 .53636 Mdot
.842 .53879 Mdot
.842 .53916 Mdot
.842 .53935 Mdot
.842 .53975 Mdot
.842 .54154 Mdot
.842 .54237 Mdot
.842 .54249 Mdot
.842 .54409 Mdot
.842 .5453 Mdot
.842 .54681 Mdot
.842 .54707 Mdot
.842 .54785 Mdot
.842 .54799 Mdot
.842 .54804 Mdot
.842 .54872 Mdot
.842 .54913 Mdot
.842 .54922 Mdot
.842 .54979 Mdot
.842 .55073 Mdot
.842 .55077 Mdot
.842 .55078 Mdot
.842 .55084 Mdot
.842 .55087 Mdot
.842 .55112 Mdot
.842 .55163 Mdot
.842 .55167 Mdot
.842 .55176 Mdot
.842 .55272 Mdot
.842 .55309 Mdot
.842 .5533 Mdot
.842 .55369 Mdot
.842 .55382 Mdot
.842 .55551 Mdot
.842 .55593 Mdot
.842 .55614 Mdot
.842 .5564 Mdot
.842 .55645 Mdot
.842 .55739 Mdot
.842 .55769 Mdot
.842 .55796 Mdot
.842 .55846 Mdot
.842 .55877 Mdot
.842 .55904 Mdot
.842 .55928 Mdot
.842 .55975 Mdot
.842 .56006 Mdot
.842 .56018 Mdot
.842 .56124 Mdot
.842 .56162 Mdot
.842 .56165 Mdot
.842 .56169 Mdot
.842 .56174 Mdot
.842 .56202 Mdot
.842 .56272 Mdot
.842 .56282 Mdot
.842 .56299 Mdot
.842 .56342 Mdot
.842 .56342 Mdot
.842 .56347 Mdot
.842 .56348 Mdot
.842 .56403 Mdot
.842 .56404 Mdot
.842 .56404 Mdot
.842 .56404 Mdot
.842 .56405 Mdot
.842 .56407 Mdot
.842 .56408 Mdot
.842 .56412 Mdot
.842 .56413 Mdot
.842 .56414 Mdot
.842 .56416 Mdot
.842 .56417 Mdot
.842 .56426 Mdot
.842 .56428 Mdot
.842 .56459 Mdot
.842 .56462 Mdot
.842 .56476 Mdot
.842 .5649 Mdot
.842 .56503 Mdot
.842 .56504 Mdot
.842 .56548 Mdot
.842 .56553 Mdot
.842 .56561 Mdot
.842 .56564 Mdot
.842 .56566 Mdot
.842 .56571 Mdot
.842 .56586 Mdot
.842 .5659 Mdot
.842 .56596 Mdot
.842 .56622 Mdot
.842 .56627 Mdot
.842 .56654 Mdot
.842 .56674 Mdot
.842 .5668 Mdot
.842 .56707 Mdot
.842 .56711 Mdot
.842 .56748 Mdot
.842 .56754 Mdot
.842 .56759 Mdot
.842 .56777 Mdot
.842 .56834 Mdot
.842 .56834 Mdot
.842 .56846 Mdot
.842 .5685 Mdot
.842 .56894 Mdot
.842 .56901 Mdot
.842 .56917 Mdot
.842 .56956 Mdot
.842 .56994 Mdot
.842 .57015 Mdot
.842 .5703 Mdot
.842 .57053 Mdot
.842 .57063 Mdot
.842 .57065 Mdot
.842 .57074 Mdot
.842 .57079 Mdot
.842 .57113 Mdot
.842 .57113 Mdot
.842 .57165 Mdot
.842 .57174 Mdot
.842 .57196 Mdot
.842 .57208 Mdot
.842 .57232 Mdot
.842 .5725 Mdot
.842 .57257 Mdot
.842 .57274 Mdot
.842 .57277 Mdot
.842 .57285 Mdot
.842 .5731 Mdot
.842 .5731 Mdot
.842 .57345 Mdot
.842 .57352 Mdot
.842 .57353 Mdot
.842 .57367 Mdot
.842 .57367 Mdot
.842 .574 Mdot
.842 .57409 Mdot
.842 .57419 Mdot
.842 .57443 Mdot
.842 .57466 Mdot
.842 .57524 Mdot
.842 .57542 Mdot
.842 .57566 Mdot
.842 .57602 Mdot
.842 .57677 Mdot
.842 .57687 Mdot
.842 .57689 Mdot
.842 .57706 Mdot
.842 .57743 Mdot
.842 .57746 Mdot
.842 .57763 Mdot
.842 .57769 Mdot
.842 .57772 Mdot
.842 .57798 Mdot
.842 .5781 Mdot
.842 .57818 Mdot
.842 .57837 Mdot
.842 .5786 Mdot
.842 .57862 Mdot
.842 .5788 Mdot
.842 .57885 Mdot
.842 .57897 Mdot
.842 .57902 Mdot
.842 .57903 Mdot
.842 .57916 Mdot
.842 .57922 Mdot
.842 .57929 Mdot
.842 .57933 Mdot
.842 .57935 Mdot
.842 .57942 Mdot
.842 .57978 Mdot
.842 .57988 Mdot
.842 .58024 Mdot
.842 .58034 Mdot
.842 .58042 Mdot
.842 .58063 Mdot
.842 .58075 Mdot
.842 .58075 Mdot
.842 .5808 Mdot
.842 .58085 Mdot
.842 .58102 Mdot
.842 .58108 Mdot
.842 .5812 Mdot
.842 .58128 Mdot
.842 .58135 Mdot
.842 .58138 Mdot
.842 .58149 Mdot
.842 .58155 Mdot
.842 .58161 Mdot
.842 .58168 Mdot
.842 .58169 Mdot
.842 .58173 Mdot
.842 .58179 Mdot
.842 .58197 Mdot
.842 .58207 Mdot
.842 .5821 Mdot
.842 .58214 Mdot
.842 .58218 Mdot
.842 .58221 Mdot
.842 .58238 Mdot
.842 .58239 Mdot
.842 .58242 Mdot
.842 .58249 Mdot
.842 .5825 Mdot
.842 .58255 Mdot
.842 .58263 Mdot
.842 .58292 Mdot
.842 .58297 Mdot
.842 .583 Mdot
.842 .58311 Mdot
.842 .58315 Mdot
.842 .5832 Mdot
.842 .58322 Mdot
.842 .58323 Mdot
.842 .58329 Mdot
.842 .58329 Mdot
.842 .58339 Mdot
.842 .58344 Mdot
.842 .58345 Mdot
.842 .58348 Mdot
.842 .58349 Mdot
.842 .58358 Mdot
.842 .58378 Mdot
.842 .58385 Mdot
.842 .5839 Mdot
.842 .58402 Mdot
.842 .58404 Mdot
.842 .58412 Mdot
.842 .58422 Mdot
.842 .58425 Mdot
.842 .58432 Mdot
.842 .58436 Mdot
.842 .58436 Mdot
.842 .58439 Mdot
.842 .58443 Mdot
.842 .58443 Mdot
.842 .58448 Mdot
.842 .58448 Mdot
.842 .58451 Mdot
.842 .58451 Mdot
.842 .58451 Mdot
.842 .58453 Mdot
.842 .58453 Mdot
.842 .58463 Mdot
.842 .58465 Mdot
.842 .58469 Mdot
.842 .58469 Mdot
.842 .5847 Mdot
.842 .5847 Mdot
.842 .5847 Mdot
.842 .58471 Mdot
.842 .58471 Mdot
.842 .58471 Mdot
.842 .58471 Mdot
.842 .58472 Mdot
.842 .58472 Mdot
.842 .58472 Mdot
.842 .58472 Mdot
.842 .58472 Mdot
.844 .08366 Mdot
.844 .08368 Mdot
.844 .0837 Mdot
.844 .08371 Mdot
.844 .08385 Mdot
.844 .08387 Mdot
.844 .08398 Mdot
.844 .08399 Mdot
.844 .08401 Mdot
.844 .08404 Mdot
.844 .08417 Mdot
.844 .08429 Mdot
.844 .0843 Mdot
.844 .08437 Mdot
.844 .08444 Mdot
.844 .08445 Mdot
.844 .08451 Mdot
.844 .08453 Mdot
.844 .08464 Mdot
.844 .08466 Mdot
.844 .08491 Mdot
.844 .08492 Mdot
.844 .08501 Mdot
.844 .08508 Mdot
.844 .08557 Mdot
.844 .0856 Mdot
.844 .08575 Mdot
.844 .08577 Mdot
.844 .08578 Mdot
.844 .08592 Mdot
.844 .08613 Mdot
.844 .08635 Mdot
.844 .0864 Mdot
.844 .08657 Mdot
.844 .08675 Mdot
.844 .08716 Mdot
.844 .08736 Mdot
.844 .08753 Mdot
.844 .08771 Mdot
.844 .0879 Mdot
.844 .08814 Mdot
.844 .08815 Mdot
.844 .0886 Mdot
.844 .08886 Mdot
.844 .08917 Mdot
.844 .08927 Mdot
.844 .08933 Mdot
.844 .08941 Mdot
.844 .08943 Mdot
.844 .08952 Mdot
.844 .08967 Mdot
.844 .08994 Mdot
.844 .08995 Mdot
.844 .09017 Mdot
.844 .09064 Mdot
.844 .09098 Mdot
.844 .09126 Mdot
.844 .09142 Mdot
.844 .09229 Mdot
.844 .09291 Mdot
.844 .09295 Mdot
.844 .0939 Mdot
.844 .09417 Mdot
.844 .09467 Mdot
.844 .09486 Mdot
.844 .09557 Mdot
.844 .09639 Mdot
.844 .09674 Mdot
.844 .09735 Mdot
.844 .09777 Mdot
.844 .09849 Mdot
.844 .09861 Mdot
.844 .09865 Mdot
.844 .09952 Mdot
.844 .09972 Mdot
.844 .10039 Mdot
.844 .10083 Mdot
.844 .10098 Mdot
.844 .10152 Mdot
.844 .10219 Mdot
.844 .1024 Mdot
.844 .1032 Mdot
.844 .10373 Mdot
.844 .1038 Mdot
.844 .10467 Mdot
.844 .10577 Mdot
.844 .10643 Mdot
.844 .10699 Mdot
.844 .107 Mdot
.844 .10718 Mdot
.844 .10764 Mdot
.844 .10781 Mdot
.844 .10831 Mdot
.844 .10907 Mdot
.844 .10984 Mdot
.844 .1104 Mdot
.844 .11051 Mdot
.844 .1111 Mdot
.844 .11224 Mdot
.844 .11378 Mdot
.844 .11382 Mdot
.844 .11457 Mdot
.844 .115 Mdot
.844 .11566 Mdot
.844 .11597 Mdot
.844 .11665 Mdot
.844 .11721 Mdot
.844 .11764 Mdot
.844 .11869 Mdot
.844 .11915 Mdot
.844 .11926 Mdot
.844 .11955 Mdot
.844 .12008 Mdot
.844 .12048 Mdot
.844 .12086 Mdot
.844 .12122 Mdot
.844 .1213 Mdot
.844 .12202 Mdot
.844 .12249 Mdot
.844 .12252 Mdot
.844 .12271 Mdot
.844 .12275 Mdot
.844 .12291 Mdot
.844 .12331 Mdot
.844 .12353 Mdot
.844 .12356 Mdot
.844 .12405 Mdot
.844 .12413 Mdot
.844 .12449 Mdot
.844 .12457 Mdot
.844 .12478 Mdot
.844 .12491 Mdot
.844 .12548 Mdot
.844 .12664 Mdot
.844 .12726 Mdot
.844 .1284 Mdot
.844 .12871 Mdot
.844 .13039 Mdot
.844 .13139 Mdot
.844 .13143 Mdot
.844 .13242 Mdot
.844 .13291 Mdot
.844 .13409 Mdot
.844 .13485 Mdot
.844 .13502 Mdot
.844 .13518 Mdot
.844 .13529 Mdot
.844 .13603 Mdot
.844 .13615 Mdot
.844 .13621 Mdot
.844 .13621 Mdot
.844 .13704 Mdot
.844 .13752 Mdot
.844 .13919 Mdot
.844 .14015 Mdot
.844 .14039 Mdot
.844 .14057 Mdot
.844 .14133 Mdot
.844 .14242 Mdot
.844 .14244 Mdot
.844 .14275 Mdot
.844 .14323 Mdot
.844 .1437 Mdot
.844 .14421 Mdot
.844 .14567 Mdot
.844 .14572 Mdot
.844 .14618 Mdot
.844 .14665 Mdot
.844 .14665 Mdot
.844 .14682 Mdot
.844 .14738 Mdot
.844 .14788 Mdot
.844 .14807 Mdot
.844 .14811 Mdot
.844 .14824 Mdot
.844 .14939 Mdot
.844 .15137 Mdot
.844 .15148 Mdot
.844 .15198 Mdot
.844 .15262 Mdot
.844 .15263 Mdot
.844 .15267 Mdot
.844 .15275 Mdot
.844 .15454 Mdot
.844 .15464 Mdot
.844 .15465 Mdot
.844 .15548 Mdot
.844 .15561 Mdot
.844 .15609 Mdot
.844 .15617 Mdot
.844 .15655 Mdot
.844 .15666 Mdot
.844 .15688 Mdot
.844 .15713 Mdot
.844 .1572 Mdot
.844 .15725 Mdot
.844 .15812 Mdot
.844 .15829 Mdot
.844 .15912 Mdot
.844 .15934 Mdot
.844 .15947 Mdot
.844 .15953 Mdot
.844 .1604 Mdot
.844 .1605 Mdot
.844 .16156 Mdot
.844 .16165 Mdot
.844 .16179 Mdot
.844 .16196 Mdot
.844 .16201 Mdot
.844 .16399 Mdot
.844 .1649 Mdot
.844 .16514 Mdot
.844 .16777 Mdot
.844 .16913 Mdot
.844 .17115 Mdot
.844 .17184 Mdot
.844 .17325 Mdot
.844 .17609 Mdot
.844 .17611 Mdot
.844 .17612 Mdot
.844 .17635 Mdot
.844 .17643 Mdot
.844 .17676 Mdot
.844 .18207 Mdot
.844 .18633 Mdot
.844 .18801 Mdot
.844 .18883 Mdot
.844 .18909 Mdot
.844 .18912 Mdot
.844 .19412 Mdot
.844 .19514 Mdot
.844 .19587 Mdot
.844 .19644 Mdot
.844 .19779 Mdot
.844 .199 Mdot
.844 .19923 Mdot
.844 .20398 Mdot
.844 .20401 Mdot
.844 .20579 Mdot
.844 .20756 Mdot
.844 .2098 Mdot
.844 .2104 Mdot
.844 .21144 Mdot
.844 .21254 Mdot
.844 .21302 Mdot
.844 .21365 Mdot
.844 .21428 Mdot
.844 .21544 Mdot
.844 .2162 Mdot
.844 .21809 Mdot
.844 .22159 Mdot
.844 .22246 Mdot
.844 .22292 Mdot
.844 .22295 Mdot
.844 .2249 Mdot
.844 .22907 Mdot
.844 .23259 Mdot
.844 .23363 Mdot
.844 .23571 Mdot
.844 .23775 Mdot
.844 .23864 Mdot
.844 .24505 Mdot
.844 .24517 Mdot
.844 .2452 Mdot
.844 .24528 Mdot
.844 .24685 Mdot
.844 .24982 Mdot
.844 .2506 Mdot
.844 .25067 Mdot
.844 .25072 Mdot
.844 .25076 Mdot
.844 .25117 Mdot
.844 .25121 Mdot
.844 .25156 Mdot
.844 .25158 Mdot
.844 .25163 Mdot
.844 .25172 Mdot
.844 .25211 Mdot
.844 .25246 Mdot
.844 .25248 Mdot
.844 .25251 Mdot
.844 .2527 Mdot
.844 .2529 Mdot
.844 .25293 Mdot
.844 .25312 Mdot
.844 .25317 Mdot
.844 .25352 Mdot
.844 .25356 Mdot
.844 .25429 Mdot
.844 .25432 Mdot
.844 .25434 Mdot
.844 .2546 Mdot
.844 .25481 Mdot
.844 .25568 Mdot
.844 .25617 Mdot
.844 .25624 Mdot
.844 .25632 Mdot
.844 .25677 Mdot
.844 .25685 Mdot
.844 .25685 Mdot
.844 .25727 Mdot
.844 .2579 Mdot
.844 .25854 Mdot
.844 .25868 Mdot
.844 .25869 Mdot
.844 .25917 Mdot
.844 .2597 Mdot
.844 .2609 Mdot
.844 .2615 Mdot
.844 .26153 Mdot
.844 .26193 Mdot
.844 .26198 Mdot
.844 .2625 Mdot
.844 .26306 Mdot
.844 .26377 Mdot
.844 .26379 Mdot
.844 .26428 Mdot
.844 .26511 Mdot
.844 .26584 Mdot
.844 .26675 Mdot
.844 .26704 Mdot
.844 .26722 Mdot
.844 .26745 Mdot
.844 .2675 Mdot
.844 .26775 Mdot
.844 .26777 Mdot
.844 .26818 Mdot
.844 .26857 Mdot
.844 .26896 Mdot
.844 .26901 Mdot
.844 .2692 Mdot
.844 .26963 Mdot
.844 .26992 Mdot
.844 .27009 Mdot
.844 .271 Mdot
.844 .27124 Mdot
.844 .27196 Mdot
.844 .27253 Mdot
.844 .27278 Mdot
.844 .27323 Mdot
.844 .27535 Mdot
.844 .27571 Mdot
.844 .27621 Mdot
.844 .27747 Mdot
.844 .27759 Mdot
.844 .2776 Mdot
.844 .27985 Mdot
.844 .2799 Mdot
.844 .28029 Mdot
.844 .28105 Mdot
.844 .28157 Mdot
.844 .28246 Mdot
.844 .283 Mdot
.844 .28389 Mdot
.844 .28501 Mdot
.844 .28556 Mdot
.844 .28732 Mdot
.844 .28827 Mdot
.844 .28931 Mdot
.844 .28998 Mdot
.844 .29115 Mdot
.844 .29149 Mdot
.844 .2919 Mdot
.844 .29315 Mdot
.844 .29348 Mdot
.844 .29359 Mdot
.844 .29462 Mdot
.844 .2953 Mdot
.844 .29569 Mdot
.844 .296 Mdot
.844 .29656 Mdot
.844 .2984 Mdot
.844 .29884 Mdot
.844 .29929 Mdot
.844 .29961 Mdot
.844 .29966 Mdot
.844 .30001 Mdot
.844 .30149 Mdot
.844 .30298 Mdot
.844 .30305 Mdot
.844 .30332 Mdot
.844 .30388 Mdot
.844 .30439 Mdot
.844 .30607 Mdot
.844 .30616 Mdot
.844 .3075 Mdot
.844 .30769 Mdot
.844 .30872 Mdot
.844 .31004 Mdot
.844 .3127 Mdot
.844 .31274 Mdot
.844 .31284 Mdot
.844 .31299 Mdot
.844 .31417 Mdot
.844 .31446 Mdot
.844 .31475 Mdot
.844 .31544 Mdot
.844 .31548 Mdot
.844 .31624 Mdot
.844 .31627 Mdot
.844 .31674 Mdot
.844 .31796 Mdot
.844 .31843 Mdot
.844 .31973 Mdot
.844 .32005 Mdot
.844 .32039 Mdot
.844 .32112 Mdot
.844 .32175 Mdot
.844 .32272 Mdot
.844 .32378 Mdot
.844 .32422 Mdot
.844 .32436 Mdot
.844 .32457 Mdot
.844 .3247 Mdot
.844 .32524 Mdot
.844 .32526 Mdot
.844 .32554 Mdot
.844 .32706 Mdot
.844 .32877 Mdot
.844 .33003 Mdot
.844 .33053 Mdot
.844 .3314 Mdot
.844 .33216 Mdot
.844 .33339 Mdot
.844 .33401 Mdot
.844 .33411 Mdot
.844 .33487 Mdot
.844 .33592 Mdot
.844 .33604 Mdot
.844 .33714 Mdot
.844 .33881 Mdot
.844 .33959 Mdot
.844 .34005 Mdot
.844 .34087 Mdot
.844 .34099 Mdot
.844 .34132 Mdot
.844 .34275 Mdot
.844 .34312 Mdot
.844 .34384 Mdot
.844 .34478 Mdot
.844 .34589 Mdot
.844 .34647 Mdot
.844 .34763 Mdot
.844 .34789 Mdot
.844 .34862 Mdot
.844 .34971 Mdot
.844 .34973 Mdot
.844 .34983 Mdot
.844 .34993 Mdot
.844 .35015 Mdot
.844 .35077 Mdot
.844 .35092 Mdot
.844 .35188 Mdot
.844 .35276 Mdot
.844 .35297 Mdot
.844 .35474 Mdot
.844 .35589 Mdot
.844 .35598 Mdot
.844 .35645 Mdot
.844 .35653 Mdot
.844 .35692 Mdot
.844 .3579 Mdot
.844 .35844 Mdot
.844 .35852 Mdot
.844 .3597 Mdot
.844 .35991 Mdot
.844 .36078 Mdot
.844 .36098 Mdot
.844 .3615 Mdot
.844 .36181 Mdot
.844 .36318 Mdot
.844 .36369 Mdot
.844 .36452 Mdot
.844 .36529 Mdot
.844 .36542 Mdot
.844 .36599 Mdot
.844 .36745 Mdot
.844 .36857 Mdot
.844 .36866 Mdot
.844 .36966 Mdot
.844 .37017 Mdot
.844 .37093 Mdot
.844 .3717 Mdot
.844 .37274 Mdot
.844 .37275 Mdot
.844 .37488 Mdot
.844 .37638 Mdot
.844 .37696 Mdot
.844 .37724 Mdot
.844 .37734 Mdot
.844 .37734 Mdot
.844 .37905 Mdot
.844 .37964 Mdot
.844 .37983 Mdot
.844 .38068 Mdot
.844 .38076 Mdot
.844 .38234 Mdot
.844 .38292 Mdot
.844 .38349 Mdot
.844 .38421 Mdot
.844 .38474 Mdot
.844 .38509 Mdot
.844 .38524 Mdot
.844 .38564 Mdot
.844 .38601 Mdot
.844 .38625 Mdot
.844 .38685 Mdot
.844 .38794 Mdot
.844 .38821 Mdot
.844 .38835 Mdot
.844 .38836 Mdot
.844 .39024 Mdot
.844 .39131 Mdot
.844 .39163 Mdot
.844 .39226 Mdot
.844 .39287 Mdot
.844 .39504 Mdot
.844 .39508 Mdot
.844 .39723 Mdot
.844 .39776 Mdot
.844 .39815 Mdot
.844 .39829 Mdot
.844 .39901 Mdot
.844 .39983 Mdot
.844 .40062 Mdot
.844 .4016 Mdot
.844 .40202 Mdot
.844 .40222 Mdot
.844 .40227 Mdot
.844 .40295 Mdot
.844 .40399 Mdot
.844 .40502 Mdot
.844 .40613 Mdot
.844 .40835 Mdot
.844 .4091 Mdot
.844 .40928 Mdot
.844 .40939 Mdot
.844 .41025 Mdot
.844 .41037 Mdot
.844 .41138 Mdot
.844 .4114 Mdot
.844 .41176 Mdot
.844 .41294 Mdot
.844 .41401 Mdot
.844 .41441 Mdot
.844 .41449 Mdot
.844 .41475 Mdot
.844 .41477 Mdot
.844 .416 Mdot
.844 .41609 Mdot
.844 .41628 Mdot
.844 .41671 Mdot
.844 .41711 Mdot
.844 .41715 Mdot
.844 .41721 Mdot
.844 .41724 Mdot
.844 .41739 Mdot
.844 .41833 Mdot
.844 .41924 Mdot
.844 .41957 Mdot
.844 .41996 Mdot
.844 .42134 Mdot
.844 .42156 Mdot
.844 .4226 Mdot
.844 .42391 Mdot
.844 .42394 Mdot
.844 .42403 Mdot
.844 .42419 Mdot
.844 .42762 Mdot
.844 .42784 Mdot
.844 .42805 Mdot
.844 .42808 Mdot
.844 .42975 Mdot
.844 .43003 Mdot
.844 .43099 Mdot
.844 .43114 Mdot
.844 .43191 Mdot
.844 .43213 Mdot
.844 .43257 Mdot
.844 .43273 Mdot
.844 .43307 Mdot
.844 .43321 Mdot
.844 .43331 Mdot
.844 .43377 Mdot
.844 .43505 Mdot
.844 .43522 Mdot
.844 .43538 Mdot
.844 .43683 Mdot
.844 .43703 Mdot
.844 .43746 Mdot
.844 .43772 Mdot
.844 .43783 Mdot
.844 .43954 Mdot
.844 .43974 Mdot
.844 .44005 Mdot
.844 .44163 Mdot
.844 .4418 Mdot
.844 .44199 Mdot
.844 .44224 Mdot
.844 .44249 Mdot
.844 .44258 Mdot
.844 .44268 Mdot
.844 .44648 Mdot
.844 .44733 Mdot
.844 .44822 Mdot
.844 .44866 Mdot
.844 .4536 Mdot
.844 .45612 Mdot
.844 .45656 Mdot
.844 .45737 Mdot
.844 .45901 Mdot
.844 .45983 Mdot
.844 .46055 Mdot
.844 .46108 Mdot
.844 .4636 Mdot
.844 .46732 Mdot
.844 .46751 Mdot
.844 .46767 Mdot
.844 .4681 Mdot
.844 .46855 Mdot
.844 .46862 Mdot
.844 .46866 Mdot
.844 .46868 Mdot
.844 .46887 Mdot
.844 .46908 Mdot
.844 .46917 Mdot
.844 .46921 Mdot
.844 .4698 Mdot
.844 .47192 Mdot
.844 .47245 Mdot
.844 .4728 Mdot
.844 .47571 Mdot
.844 .4759 Mdot
.844 .47635 Mdot
.844 .47707 Mdot
.844 .4774 Mdot
.844 .47886 Mdot
.844 .47983 Mdot
.844 .4801 Mdot
.844 .48038 Mdot
.844 .48248 Mdot
.844 .48325 Mdot
.844 .4834 Mdot
.844 .48363 Mdot
.844 .4842 Mdot
.844 .48445 Mdot
.844 .48516 Mdot
.844 .48553 Mdot
.844 .48586 Mdot
.844 .4866 Mdot
.844 .48676 Mdot
.844 .48701 Mdot
.844 .48855 Mdot
.844 .48855 Mdot
.844 .48899 Mdot
.844 .48985 Mdot
.844 .49027 Mdot
.844 .49031 Mdot
.844 .49162 Mdot
.844 .49168 Mdot
.844 .492 Mdot
.844 .49234 Mdot
.844 .49762 Mdot
.844 .49787 Mdot
.844 .498 Mdot
.844 .49804 Mdot
.844 .49804 Mdot
.844 .49957 Mdot
.844 .50002 Mdot
.844 .50067 Mdot
.844 .50152 Mdot
.844 .50156 Mdot
.844 .50189 Mdot
.844 .5035 Mdot
.844 .50392 Mdot
.844 .50449 Mdot
.844 .50497 Mdot
.844 .50526 Mdot
.844 .5056 Mdot
.844 .50628 Mdot
.844 .50762 Mdot
.844 .50784 Mdot
.844 .50789 Mdot
.844 .50797 Mdot
.844 .50802 Mdot
.844 .50859 Mdot
.844 .5092 Mdot
.844 .50948 Mdot
.844 .50961 Mdot
.844 .51133 Mdot
.844 .51135 Mdot
.844 .51171 Mdot
.844 .51182 Mdot
.844 .51232 Mdot
.844 .51236 Mdot
.844 .51237 Mdot
.844 .51385 Mdot
.844 .5148 Mdot
.844 .51545 Mdot
.844 .51594 Mdot
.844 .51597 Mdot
.844 .51718 Mdot
.844 .51732 Mdot
.844 .51748 Mdot
.844 .51863 Mdot
.844 .51877 Mdot
.844 .51901 Mdot
.844 .52 Mdot
.844 .52014 Mdot
.844 .52093 Mdot
.844 .52227 Mdot
.844 .52286 Mdot
.844 .52368 Mdot
.844 .52427 Mdot
.844 .52429 Mdot
.844 .52508 Mdot
.844 .52557 Mdot
.844 .52587 Mdot
.844 .52686 Mdot
.844 .52731 Mdot
.844 .52771 Mdot
.844 .52776 Mdot
.844 .52801 Mdot
.844 .52823 Mdot
.844 .52852 Mdot
.844 .52971 Mdot
.844 .53052 Mdot
.844 .53066 Mdot
.844 .53163 Mdot
.844 .53249 Mdot
.844 .53265 Mdot
.844 .53311 Mdot
.844 .53373 Mdot
.844 .53464 Mdot
.844 .53563 Mdot
.844 .53616 Mdot
.844 .53619 Mdot
.844 .53619 Mdot
.844 .53624 Mdot
.844 .53837 Mdot
.844 .53866 Mdot
.844 .53934 Mdot
.844 .54002 Mdot
.844 .54036 Mdot
.844 .54152 Mdot
.844 .54287 Mdot
.844 .54351 Mdot
.844 .54351 Mdot
.844 .54366 Mdot
.844 .54394 Mdot
.844 .54507 Mdot
.844 .54568 Mdot
.844 .54592 Mdot
.844 .5463 Mdot
.844 .5465 Mdot
.844 .5467 Mdot
.844 .54685 Mdot
.844 .54721 Mdot
.844 .54754 Mdot
.844 .54773 Mdot
.844 .54844 Mdot
.844 .549 Mdot
.844 .54956 Mdot
.844 .54957 Mdot
.844 .55107 Mdot
.844 .55114 Mdot
.844 .55152 Mdot
.844 .55194 Mdot
.844 .55212 Mdot
.844 .55235 Mdot
.844 .55267 Mdot
.844 .55422 Mdot
.844 .55423 Mdot
.844 .55431 Mdot
.844 .55456 Mdot
.844 .55508 Mdot
.844 .55639 Mdot
.844 .55802 Mdot
.844 .55812 Mdot
.844 .55814 Mdot
.844 .55821 Mdot
.844 .55821 Mdot
.844 .55822 Mdot
.844 .55908 Mdot
.844 .55951 Mdot
.844 .55972 Mdot
.844 .56033 Mdot
.844 .56074 Mdot
.844 .56154 Mdot
.844 .56161 Mdot
.844 .56188 Mdot
.844 .56247 Mdot
.844 .56249 Mdot
.844 .56254 Mdot
.844 .56258 Mdot
.844 .56261 Mdot
.844 .56293 Mdot
.844 .56296 Mdot
.844 .56322 Mdot
.844 .56323 Mdot
.844 .56327 Mdot
.844 .56334 Mdot
.844 .56359 Mdot
.844 .56364 Mdot
.844 .5639 Mdot
.844 .56391 Mdot
.844 .56393 Mdot
.844 .56401 Mdot
.844 .56407 Mdot
.844 .56411 Mdot
.844 .56422 Mdot
.844 .56424 Mdot
.844 .56438 Mdot
.844 .56443 Mdot
.844 .56467 Mdot
.844 .56467 Mdot
.844 .5647 Mdot
.844 .56523 Mdot
.844 .56526 Mdot
.844 .56527 Mdot
.844 .56527 Mdot
.844 .56546 Mdot
.844 .56561 Mdot
.844 .56564 Mdot
.844 .56623 Mdot
.844 .56657 Mdot
.844 .56661 Mdot
.844 .56662 Mdot
.844 .56667 Mdot
.844 .56682 Mdot
.844 .56698 Mdot
.844 .56704 Mdot
.844 .56704 Mdot
.844 .56718 Mdot
.844 .56731 Mdot
.844 .56733 Mdot
.844 .56775 Mdot
.844 .5679 Mdot
.844 .56804 Mdot
.844 .56818 Mdot
.844 .56827 Mdot
.844 .56828 Mdot
.844 .5686 Mdot
.844 .56882 Mdot
.844 .56887 Mdot
.844 .56894 Mdot
.844 .56922 Mdot
.844 .56971 Mdot
.844 .56985 Mdot
.844 .57009 Mdot
.844 .57009 Mdot
.844 .57011 Mdot
.844 .57014 Mdot
.844 .57036 Mdot
.844 .57039 Mdot
.844 .57044 Mdot
.844 .57049 Mdot
.844 .57071 Mdot
.844 .57105 Mdot
.844 .57119 Mdot
.844 .57148 Mdot
.844 .57149 Mdot
.844 .57178 Mdot
.844 .57223 Mdot
.844 .57226 Mdot
.844 .57235 Mdot
.844 .57268 Mdot
.844 .57286 Mdot
.844 .57319 Mdot
.844 .57336 Mdot
.844 .57339 Mdot
.844 .57345 Mdot
.844 .57348 Mdot
.844 .57358 Mdot
.844 .57361 Mdot
.844 .57374 Mdot
.844 .57375 Mdot
.844 .57382 Mdot
.844 .57393 Mdot
.844 .57398 Mdot
.844 .57399 Mdot
.844 .57404 Mdot
.844 .57405 Mdot
.844 .57419 Mdot
.844 .57439 Mdot
.844 .57442 Mdot
.844 .57452 Mdot
.844 .57463 Mdot
.844 .57474 Mdot
.844 .57489 Mdot
.844 .57498 Mdot
.844 .57501 Mdot
.844 .57514 Mdot
.844 .57544 Mdot
.844 .57556 Mdot
.844 .57572 Mdot
.844 .57592 Mdot
.844 .576 Mdot
.844 .57619 Mdot
.844 .57631 Mdot
.844 .57652 Mdot
.844 .57654 Mdot
.844 .57697 Mdot
.844 .5773 Mdot
.844 .57746 Mdot
.844 .57749 Mdot
.844 .57765 Mdot
.844 .57787 Mdot
.844 .57809 Mdot
.844 .57823 Mdot
.844 .57828 Mdot
.844 .5784 Mdot
.844 .57845 Mdot
.844 .57846 Mdot
.844 .57861 Mdot
.844 .5788 Mdot
.844 .57911 Mdot
.844 .57936 Mdot
.844 .57937 Mdot
.844 .57952 Mdot
.844 .57975 Mdot
.844 .57981 Mdot
.844 .58 Mdot
.844 .58015 Mdot
.844 .58019 Mdot
.844 .58031 Mdot
.844 .5805 Mdot
.844 .58056 Mdot
.844 .5808 Mdot
.844 .58081 Mdot
.844 .58084 Mdot
.844 .58104 Mdot
.844 .58116 Mdot
.844 .58133 Mdot
.844 .58143 Mdot
.844 .58166 Mdot
.844 .58186 Mdot
.844 .58191 Mdot
.844 .58205 Mdot
.844 .58212 Mdot
.844 .58239 Mdot
.844 .5824 Mdot
.844 .58257 Mdot
.844 .58281 Mdot
.844 .58285 Mdot
.844 .58293 Mdot
.844 .58303 Mdot
.844 .58316 Mdot
.844 .58322 Mdot
.844 .58322 Mdot
.844 .5833 Mdot
.844 .58334 Mdot
.844 .58336 Mdot
.844 .58337 Mdot
.844 .58339 Mdot
.844 .58341 Mdot
.844 .58343 Mdot
.844 .58352 Mdot
.844 .58359 Mdot
.844 .58372 Mdot
.844 .58372 Mdot
.844 .58379 Mdot
.844 .58384 Mdot
.844 .58389 Mdot
.844 .58393 Mdot
.844 .58399 Mdot
.844 .5841 Mdot
.844 .58415 Mdot
.844 .5842 Mdot
.844 .58421 Mdot
.844 .58427 Mdot
.844 .58433 Mdot
.844 .58437 Mdot
.844 .58437 Mdot
.844 .58438 Mdot
.844 .58442 Mdot
.844 .58443 Mdot
.844 .58456 Mdot
.844 .58458 Mdot
.844 .58461 Mdot
.844 .58461 Mdot
.844 .58468 Mdot
.844 .58468 Mdot
.844 .58472 Mdot
.844 .58472 Mdot
.844 .58474 Mdot
.844 .58474 Mdot
.844 .58476 Mdot
.844 .58478 Mdot
.844 .58478 Mdot
.844 .58481 Mdot
.844 .58485 Mdot
.844 .58486 Mdot
.844 .58486 Mdot
.844 .58487 Mdot
.844 .5849 Mdot
.844 .5849 Mdot
.844 .58494 Mdot
.844 .58494 Mdot
.844 .58495 Mdot
.844 .58495 Mdot
.846 .08283 Mdot
.846 .08286 Mdot
.846 .0829 Mdot
.846 .08302 Mdot
.846 .08306 Mdot
.846 .08309 Mdot
.846 .08312 Mdot
.846 .08314 Mdot
.846 .08314 Mdot
.846 .08328 Mdot
.846 .0835 Mdot
.846 .08375 Mdot
.846 .08379 Mdot
.846 .08425 Mdot
.846 .0843 Mdot
.846 .08441 Mdot
.846 .08448 Mdot
.846 .08456 Mdot
.846 .08462 Mdot
.846 .08482 Mdot
.846 .08494 Mdot
.846 .08516 Mdot
.846 .08531 Mdot
.846 .08538 Mdot
.846 .08564 Mdot
.846 .08567 Mdot
.846 .08584 Mdot
.846 .08587 Mdot
.846 .08613 Mdot
.846 .08613 Mdot
.846 .08627 Mdot
.846 .0863 Mdot
.846 .08635 Mdot
.846 .08642 Mdot
.846 .08656 Mdot
.846 .08669 Mdot
.846 .08701 Mdot
.846 .08706 Mdot
.846 .08749 Mdot
.846 .08766 Mdot
.846 .08856 Mdot
.846 .08857 Mdot
.846 .08876 Mdot
.846 .08898 Mdot
.846 .08947 Mdot
.846 .0901 Mdot
.846 .09019 Mdot
.846 .09023 Mdot
.846 .09091 Mdot
.846 .09103 Mdot
.846 .09106 Mdot
.846 .0911 Mdot
.846 .09114 Mdot
.846 .09119 Mdot
.846 .0913 Mdot
.846 .09137 Mdot
.846 .09141 Mdot
.846 .09165 Mdot
.846 .09234 Mdot
.846 .09242 Mdot
.846 .09263 Mdot
.846 .09291 Mdot
.846 .09306 Mdot
.846 .0938 Mdot
.846 .09524 Mdot
.846 .09532 Mdot
.846 .09548 Mdot
.846 .09587 Mdot
.846 .09671 Mdot
.846 .09687 Mdot
.846 .09724 Mdot
.846 .09742 Mdot
.846 .09748 Mdot
.846 .09784 Mdot
.846 .09838 Mdot
.846 .09849 Mdot
.846 .09904 Mdot
.846 .09913 Mdot
.846 .0998 Mdot
.846 .09983 Mdot
.846 .10011 Mdot
.846 .10051 Mdot
.846 .10062 Mdot
.846 .10089 Mdot
.846 .10191 Mdot
.846 .10265 Mdot
.846 .10303 Mdot
.846 .10311 Mdot
.846 .10362 Mdot
.846 .10528 Mdot
.846 .10559 Mdot
.846 .10621 Mdot
.846 .10704 Mdot
.846 .10717 Mdot
.846 .10728 Mdot
.846 .10742 Mdot
.846 .10775 Mdot
.846 .10831 Mdot
.846 .10844 Mdot
.846 .10865 Mdot
.846 .10893 Mdot
.846 .10901 Mdot
.846 .11007 Mdot
.846 .11007 Mdot
.846 .11088 Mdot
.846 .11127 Mdot
.846 .11179 Mdot
.846 .11182 Mdot
.846 .11292 Mdot
.846 .11312 Mdot
.846 .11346 Mdot
.846 .11378 Mdot
.846 .11396 Mdot
.846 .11399 Mdot
.846 .1142 Mdot
.846 .11441 Mdot
.846 .11462 Mdot
.846 .11474 Mdot
.846 .11537 Mdot
.846 .11553 Mdot
.846 .11665 Mdot
.846 .11724 Mdot
.846 .11754 Mdot
.846 .11881 Mdot
.846 .11895 Mdot
.846 .11901 Mdot
.846 .11947 Mdot
.846 .11956 Mdot
.846 .11959 Mdot
.846 .12002 Mdot
.846 .12015 Mdot
.846 .12212 Mdot
.846 .12256 Mdot
.846 .12274 Mdot
.846 .12285 Mdot
.846 .1243 Mdot
.846 .1256 Mdot
.846 .12598 Mdot
.846 .12686 Mdot
.846 .12726 Mdot
.846 .1278 Mdot
.846 .12796 Mdot
.846 .12804 Mdot
.846 .13152 Mdot
.846 .13247 Mdot
.846 .13262 Mdot
.846 .1334 Mdot
.846 .13444 Mdot
.846 .13478 Mdot
.846 .13538 Mdot
.846 .13542 Mdot
.846 .13574 Mdot
.846 .13574 Mdot
.846 .13616 Mdot
.846 .1363 Mdot
.846 .13715 Mdot
.846 .13751 Mdot
.846 .13843 Mdot
.846 .13955 Mdot
.846 .14024 Mdot
.846 .14045 Mdot
.846 .14133 Mdot
.846 .14183 Mdot
.846 .14214 Mdot
.846 .14235 Mdot
.846 .14278 Mdot
.846 .1433 Mdot
.846 .14331 Mdot
.846 .14424 Mdot
.846 .14449 Mdot
.846 .14502 Mdot
.846 .14527 Mdot
.846 .1457 Mdot
.846 .14587 Mdot
.846 .14641 Mdot
.846 .14661 Mdot
.846 .14845 Mdot
.846 .14895 Mdot
.846 .15 Mdot
.846 .15079 Mdot
.846 .15082 Mdot
.846 .15158 Mdot
.846 .15172 Mdot
.846 .15239 Mdot
.846 .15389 Mdot
.846 .15398 Mdot
.846 .15433 Mdot
.846 .15477 Mdot
.846 .15486 Mdot
.846 .15541 Mdot
.846 .15623 Mdot
.846 .15657 Mdot
.846 .15809 Mdot
.846 .1592 Mdot
.846 .15925 Mdot
.846 .1597 Mdot
.846 .16002 Mdot
.846 .16035 Mdot
.846 .16096 Mdot
.846 .16171 Mdot
.846 .16225 Mdot
.846 .16394 Mdot
.846 .165 Mdot
.846 .16507 Mdot
.846 .16509 Mdot
.846 .16516 Mdot
.846 .16541 Mdot
.846 .16568 Mdot
.846 .16599 Mdot
.846 .16605 Mdot
.846 .16659 Mdot
.846 .16681 Mdot
.846 .16691 Mdot
.846 .16726 Mdot
.846 .16745 Mdot
.846 .16776 Mdot
.846 .16829 Mdot
.846 .16959 Mdot
.846 .17208 Mdot
.846 .17267 Mdot
.846 .1745 Mdot
.846 .18249 Mdot
.846 .18526 Mdot
.846 .18949 Mdot
.846 .18966 Mdot
.846 .19213 Mdot
.846 .19219 Mdot
.846 .19553 Mdot
.846 .19601 Mdot
.846 .19707 Mdot
.846 .1973 Mdot
.846 .20257 Mdot
.846 .20483 Mdot
.846 .20996 Mdot
.846 .21006 Mdot
.846 .21239 Mdot
.846 .21334 Mdot
.846 .21675 Mdot
.846 .21701 Mdot
.846 .21753 Mdot
.846 .21845 Mdot
.846 .21937 Mdot
.846 .21939 Mdot
.846 .22193 Mdot
.846 .22246 Mdot
.846 .2235 Mdot
.846 .2298 Mdot
.846 .23117 Mdot
.846 .2325 Mdot
.846 .23354 Mdot
.846 .2383 Mdot
.846 .23942 Mdot
.846 .24277 Mdot
.846 .24563 Mdot
.846 .2463 Mdot
.846 .24792 Mdot
.846 .24812 Mdot
.846 .24824 Mdot
.846 .24831 Mdot
.846 .24844 Mdot
.846 .24879 Mdot
.846 .2489 Mdot
.846 .24901 Mdot
.846 .2491 Mdot
.846 .24914 Mdot
.846 .24916 Mdot
.846 .24957 Mdot
.846 .25022 Mdot
.846 .25096 Mdot
.846 .25109 Mdot
.846 .25245 Mdot
.846 .25259 Mdot
.846 .25292 Mdot
.846 .25314 Mdot
.846 .25318 Mdot
.846 .25335 Mdot
.846 .25353 Mdot
.846 .25414 Mdot
.846 .25448 Mdot
.846 .2548 Mdot
.846 .25513 Mdot
.846 .25557 Mdot
.846 .25578 Mdot
.846 .25656 Mdot
.846 .25664 Mdot
.846 .25687 Mdot
.846 .25694 Mdot
.846 .25713 Mdot
.846 .25724 Mdot
.846 .25798 Mdot
.846 .25798 Mdot
.846 .2584 Mdot
.846 .25849 Mdot
.846 .25863 Mdot
.846 .25885 Mdot
.846 .25924 Mdot
.846 .25964 Mdot
.846 .26014 Mdot
.846 .26056 Mdot
.846 .26073 Mdot
.846 .26153 Mdot
.846 .26154 Mdot
.846 .26198 Mdot
.846 .26247 Mdot
.846 .26284 Mdot
.846 .26337 Mdot
.846 .26507 Mdot
.846 .26511 Mdot
.846 .26519 Mdot
.846 .26546 Mdot
.846 .26566 Mdot
.846 .26611 Mdot
.846 .2663 Mdot
.846 .26773 Mdot
.846 .26788 Mdot
.846 .26949 Mdot
.846 .26954 Mdot
.846 .2698 Mdot
.846 .26991 Mdot
.846 .27186 Mdot
.846 .27223 Mdot
.846 .27229 Mdot
.846 .27242 Mdot
.846 .27255 Mdot
.846 .27269 Mdot
.846 .27279 Mdot
.846 .27299 Mdot
.846 .27319 Mdot
.846 .27331 Mdot
.846 .274 Mdot
.846 .27456 Mdot
.846 .27598 Mdot
.846 .2762 Mdot
.846 .27678 Mdot
.846 .27688 Mdot
.846 .27695 Mdot
.846 .27703 Mdot
.846 .27759 Mdot
.846 .27802 Mdot
.846 .27823 Mdot
.846 .28011 Mdot
.846 .28164 Mdot
.846 .2829 Mdot
.846 .2842 Mdot
.846 .28425 Mdot
.846 .28441 Mdot
.846 .28487 Mdot
.846 .28597 Mdot
.846 .28619 Mdot
.846 .2883 Mdot
.846 .28875 Mdot
.846 .28979 Mdot
.846 .29005 Mdot
.846 .2901 Mdot
.846 .2903 Mdot
.846 .29035 Mdot
.846 .29045 Mdot
.846 .29048 Mdot
.846 .29146 Mdot
.846 .29157 Mdot
.846 .29234 Mdot
.846 .29297 Mdot
.846 .29326 Mdot
.846 .2948 Mdot
.846 .29505 Mdot
.846 .29571 Mdot
.846 .2958 Mdot
.846 .29689 Mdot
.846 .29697 Mdot
.846 .29703 Mdot
.846 .29774 Mdot
.846 .29812 Mdot
.846 .29884 Mdot
.846 .29916 Mdot
.846 .29989 Mdot
.846 .30131 Mdot
.846 .30268 Mdot
.846 .30283 Mdot
.846 .30469 Mdot
.846 .30552 Mdot
.846 .30572 Mdot
.846 .30595 Mdot
.846 .30731 Mdot
.846 .30799 Mdot
.846 .30928 Mdot
.846 .3118 Mdot
.846 .31258 Mdot
.846 .31263 Mdot
.846 .3143 Mdot
.846 .31651 Mdot
.846 .31684 Mdot
.846 .31713 Mdot
.846 .31733 Mdot
.846 .31751 Mdot
.846 .31765 Mdot
.846 .31839 Mdot
.846 .31933 Mdot
.846 .31986 Mdot
.846 .32022 Mdot
.846 .32075 Mdot
.846 .32076 Mdot
.846 .32127 Mdot
.846 .32149 Mdot
.846 .32172 Mdot
.846 .32449 Mdot
.846 .32451 Mdot
.846 .32662 Mdot
.846 .32741 Mdot
.846 .32763 Mdot
.846 .32785 Mdot
.846 .32899 Mdot
.846 .32907 Mdot
.846 .32958 Mdot
.846 .33047 Mdot
.846 .33192 Mdot
.846 .33242 Mdot
.846 .3333 Mdot
.846 .33414 Mdot
.846 .33459 Mdot
.846 .33468 Mdot
.846 .33521 Mdot
.846 .33574 Mdot
.846 .33577 Mdot
.846 .33598 Mdot
.846 .3363 Mdot
.846 .33659 Mdot
.846 .33737 Mdot
.846 .3382 Mdot
.846 .33826 Mdot
.846 .33862 Mdot
.846 .34147 Mdot
.846 .34192 Mdot
.846 .34224 Mdot
.846 .34229 Mdot
.846 .34296 Mdot
.846 .34297 Mdot
.846 .34372 Mdot
.846 .34406 Mdot
.846 .34537 Mdot
.846 .34627 Mdot
.846 .34691 Mdot
.846 .34725 Mdot
.846 .34742 Mdot
.846 .3482 Mdot
.846 .34856 Mdot
.846 .34879 Mdot
.846 .34886 Mdot
.846 .34992 Mdot
.846 .35025 Mdot
.846 .35106 Mdot
.846 .35512 Mdot
.846 .35621 Mdot
.846 .35666 Mdot
.846 .35666 Mdot
.846 .35685 Mdot
.846 .35692 Mdot
.846 .3587 Mdot
.846 .35982 Mdot
.846 .36046 Mdot
.846 .36057 Mdot
.846 .36324 Mdot
.846 .36361 Mdot
.846 .36454 Mdot
.846 .36619 Mdot
.846 .36662 Mdot
.846 .36664 Mdot
.846 .36682 Mdot
.846 .36731 Mdot
.846 .3676 Mdot
.846 .3689 Mdot
.846 .36927 Mdot
.846 .36947 Mdot
.846 .36956 Mdot
.846 .3706 Mdot
.846 .37152 Mdot
.846 .37623 Mdot
.846 .3777 Mdot
.846 .37775 Mdot
.846 .37859 Mdot
.846 .3799 Mdot
.846 .38025 Mdot
.846 .38033 Mdot
.846 .38207 Mdot
.846 .38281 Mdot
.846 .38446 Mdot
.846 .38524 Mdot
.846 .38661 Mdot
.846 .3867 Mdot
.846 .38715 Mdot
.846 .38743 Mdot
.846 .38744 Mdot
.846 .38839 Mdot
.846 .38872 Mdot
.846 .39064 Mdot
.846 .39106 Mdot
.846 .39146 Mdot
.846 .39177 Mdot
.846 .3932 Mdot
.846 .39354 Mdot
.846 .39537 Mdot
.846 .39604 Mdot
.846 .39757 Mdot
.846 .39805 Mdot
.846 .39998 Mdot
.846 .39998 Mdot
.846 .40035 Mdot
.846 .4011 Mdot
.846 .40178 Mdot
.846 .40224 Mdot
.846 .40317 Mdot
.846 .40367 Mdot
.846 .40431 Mdot
.846 .40433 Mdot
.846 .40436 Mdot
.846 .40599 Mdot
.846 .40637 Mdot
.846 .4069 Mdot
.846 .40798 Mdot
.846 .40805 Mdot
.846 .40838 Mdot
.846 .4086 Mdot
.846 .40952 Mdot
.846 .40954 Mdot
.846 .40988 Mdot
.846 .41018 Mdot
.846 .41105 Mdot
.846 .41146 Mdot
.846 .41219 Mdot
.846 .41286 Mdot
.846 .4141 Mdot
.846 .41538 Mdot
.846 .41591 Mdot
.846 .4163 Mdot
.846 .41643 Mdot
.846 .41808 Mdot
.846 .4182 Mdot
.846 .41866 Mdot
.846 .41889 Mdot
.846 .4203 Mdot
.846 .42036 Mdot
.846 .42194 Mdot
.846 .42204 Mdot
.846 .42222 Mdot
.846 .42285 Mdot
.846 .42361 Mdot
.846 .42437 Mdot
.846 .42639 Mdot
.846 .42669 Mdot
.846 .42688 Mdot
.846 .42759 Mdot
.846 .42849 Mdot
.846 .42867 Mdot
.846 .42926 Mdot
.846 .42954 Mdot
.846 .42978 Mdot
.846 .43103 Mdot
.846 .43144 Mdot
.846 .43166 Mdot
.846 .43212 Mdot
.846 .43393 Mdot
.846 .43497 Mdot
.846 .43516 Mdot
.846 .43612 Mdot
.846 .43735 Mdot
.846 .43745 Mdot
.846 .43834 Mdot
.846 .43853 Mdot
.846 .43897 Mdot
.846 .4395 Mdot
.846 .43961 Mdot
.846 .43992 Mdot
.846 .4401 Mdot
.846 .44064 Mdot
.846 .44082 Mdot
.846 .44115 Mdot
.846 .44165 Mdot
.846 .44175 Mdot
.846 .44223 Mdot
.846 .44226 Mdot
.846 .44245 Mdot
.846 .44331 Mdot
.846 .44395 Mdot
.846 .4445 Mdot
.846 .44529 Mdot
.846 .44578 Mdot
.846 .44657 Mdot
.846 .44686 Mdot
.846 .44718 Mdot
.846 .44785 Mdot
.846 .44812 Mdot
.846 .44824 Mdot
.846 .44829 Mdot
.846 .44858 Mdot
.846 .44872 Mdot
.846 .44875 Mdot
.846 .44888 Mdot
.846 .44895 Mdot
.846 .44936 Mdot
.846 .44952 Mdot
.846 .44988 Mdot
.846 .45018 Mdot
.846 .45046 Mdot
.846 .45054 Mdot
.846 .45057 Mdot
.846 .45093 Mdot
.846 .45133 Mdot
.846 .45158 Mdot
.846 .45179 Mdot
.846 .452 Mdot
.846 .45219 Mdot
.846 .45254 Mdot
.846 .45284 Mdot
.846 .45319 Mdot
.846 .45321 Mdot
.846 .45328 Mdot
.846 .45342 Mdot
.846 .45377 Mdot
.846 .45394 Mdot
.846 .45451 Mdot
.846 .45476 Mdot
.846 .45517 Mdot
.846 .45546 Mdot
.846 .45623 Mdot
.846 .45634 Mdot
.846 .45659 Mdot
.846 .45664 Mdot
.846 .4569 Mdot
.846 .45716 Mdot
.846 .45744 Mdot
.846 .45753 Mdot
.846 .45774 Mdot
.846 .45824 Mdot
.846 .45946 Mdot
.846 .46004 Mdot
.846 .46056 Mdot
.846 .46169 Mdot
.846 .462 Mdot
.846 .46274 Mdot
.846 .46288 Mdot
.846 .46429 Mdot
.846 .46528 Mdot
.846 .46601 Mdot
.846 .4664 Mdot
.846 .46791 Mdot
.846 .46825 Mdot
.846 .4683 Mdot
.846 .46915 Mdot
.846 .46933 Mdot
.846 .47019 Mdot
.846 .47077 Mdot
.846 .47108 Mdot
.846 .47202 Mdot
.846 .47232 Mdot
.846 .47286 Mdot
.846 .47304 Mdot
.846 .47396 Mdot
.846 .47471 Mdot
.846 .47503 Mdot
.846 .47654 Mdot
.846 .47671 Mdot
.846 .47878 Mdot
.846 .47975 Mdot
.846 .48038 Mdot
.846 .4807 Mdot
.846 .48242 Mdot
.846 .48431 Mdot
.846 .48538 Mdot
.846 .48612 Mdot
.846 .48648 Mdot
.846 .48713 Mdot
.846 .48913 Mdot
.846 .48952 Mdot
.846 .48996 Mdot
.846 .49089 Mdot
.846 .4911 Mdot
.846 .49118 Mdot
.846 .49137 Mdot
.846 .49259 Mdot
.846 .49369 Mdot
.846 .494 Mdot
.846 .49445 Mdot
.846 .49521 Mdot
.846 .49529 Mdot
.846 .49756 Mdot
.846 .4987 Mdot
.846 .49984 Mdot
.846 .50036 Mdot
.846 .50079 Mdot
.846 .50105 Mdot
.846 .50108 Mdot
.846 .5012 Mdot
.846 .50264 Mdot
.846 .50299 Mdot
.846 .50353 Mdot
.846 .50363 Mdot
.846 .50567 Mdot
.846 .50602 Mdot
.846 .50668 Mdot
.846 .50685 Mdot
.846 .50919 Mdot
.846 .50939 Mdot
.846 .50993 Mdot
.846 .51056 Mdot
.846 .51068 Mdot
.846 .51246 Mdot
.846 .51369 Mdot
.846 .51417 Mdot
.846 .51508 Mdot
.846 .51607 Mdot
.846 .51662 Mdot
.846 .51779 Mdot
.846 .51818 Mdot
.846 .51863 Mdot
.846 .51866 Mdot
.846 .51988 Mdot
.846 .52016 Mdot
.846 .52056 Mdot
.846 .52059 Mdot
.846 .52068 Mdot
.846 .5207 Mdot
.846 .52208 Mdot
.846 .52277 Mdot
.846 .52325 Mdot
.846 .52369 Mdot
.846 .5249 Mdot
.846 .52532 Mdot
.846 .52535 Mdot
.846 .52537 Mdot
.846 .52619 Mdot
.846 .5268 Mdot
.846 .52795 Mdot
.846 .52851 Mdot
.846 .52912 Mdot
.846 .52934 Mdot
.846 .52944 Mdot
.846 .53006 Mdot
.846 .53024 Mdot
.846 .53069 Mdot
.846 .53069 Mdot
.846 .53117 Mdot
.846 .53226 Mdot
.846 .53228 Mdot
.846 .53299 Mdot
.846 .53354 Mdot
.846 .53524 Mdot
.846 .53531 Mdot
.846 .53585 Mdot
.846 .53607 Mdot
.846 .53703 Mdot
.846 .53814 Mdot
.846 .53851 Mdot
.846 .54008 Mdot
.846 .54042 Mdot
.846 .54086 Mdot
.846 .5413 Mdot
.846 .54335 Mdot
.846 .54369 Mdot
.846 .54386 Mdot
.846 .54468 Mdot
.846 .54469 Mdot
.846 .54499 Mdot
.846 .54528 Mdot
.846 .54545 Mdot
.846 .54553 Mdot
.846 .54662 Mdot
.846 .54693 Mdot
.846 .54767 Mdot
.846 .5477 Mdot
.846 .54933 Mdot
.846 .55004 Mdot
.846 .55169 Mdot
.846 .55177 Mdot
.846 .5521 Mdot
.846 .55225 Mdot
.846 .55329 Mdot
.846 .5533 Mdot
.846 .55407 Mdot
.846 .55412 Mdot
.846 .55543 Mdot
.846 .55628 Mdot
.846 .55872 Mdot
.846 .55928 Mdot
.846 .55946 Mdot
.846 .56021 Mdot
.846 .5606 Mdot
.846 .56077 Mdot
.846 .56086 Mdot
.846 .56092 Mdot
.846 .56102 Mdot
.846 .56105 Mdot
.846 .56112 Mdot
.846 .56128 Mdot
.846 .5613 Mdot
.846 .56139 Mdot
.846 .56147 Mdot
.846 .56155 Mdot
.846 .56157 Mdot
.846 .56157 Mdot
.846 .5616 Mdot
.846 .56191 Mdot
.846 .56242 Mdot
.846 .56258 Mdot
.846 .56281 Mdot
.846 .56299 Mdot
.846 .56309 Mdot
.846 .56318 Mdot
.846 .56332 Mdot
.846 .56333 Mdot
.846 .56366 Mdot
.846 .56412 Mdot
.846 .56422 Mdot
.846 .56446 Mdot
.846 .56463 Mdot
.846 .56465 Mdot
.846 .56478 Mdot
.846 .56489 Mdot
.846 .56491 Mdot
.846 .56536 Mdot
.846 .56556 Mdot
.846 .5656 Mdot
.846 .56582 Mdot
.846 .56583 Mdot
.846 .56606 Mdot
.846 .56638 Mdot
.846 .56652 Mdot
.846 .56707 Mdot
.846 .56712 Mdot
.846 .56728 Mdot
.846 .56733 Mdot
.846 .56746 Mdot
.846 .56753 Mdot
.846 .56769 Mdot
.846 .56776 Mdot
.846 .56803 Mdot
.846 .56804 Mdot
.846 .56819 Mdot
.846 .56831 Mdot
.846 .56837 Mdot
.846 .56847 Mdot
.846 .56861 Mdot
.846 .56887 Mdot
.846 .56893 Mdot
.846 .56913 Mdot
.846 .56946 Mdot
.846 .56973 Mdot
.846 .56983 Mdot
.846 .57008 Mdot
.846 .57012 Mdot
.846 .57024 Mdot
.846 .57024 Mdot
.846 .57034 Mdot
.846 .57035 Mdot
.846 .57052 Mdot
.846 .57062 Mdot
.846 .57092 Mdot
.846 .57115 Mdot
.846 .57119 Mdot
.846 .57146 Mdot
.846 .57247 Mdot
.846 .57249 Mdot
.846 .57254 Mdot
.846 .5727 Mdot
.846 .57281 Mdot
.846 .57306 Mdot
.846 .57317 Mdot
.846 .57355 Mdot
.846 .57396 Mdot
.846 .57399 Mdot
.846 .57404 Mdot
.846 .57417 Mdot
.846 .57473 Mdot
.846 .57477 Mdot
.846 .57489 Mdot
.846 .5749 Mdot
.846 .57493 Mdot
.846 .57506 Mdot
.846 .57508 Mdot
.846 .57512 Mdot
.846 .57548 Mdot
.846 .57556 Mdot
.846 .57573 Mdot
.846 .57605 Mdot
.846 .5761 Mdot
.846 .57628 Mdot
.846 .57631 Mdot
.846 .57637 Mdot
.846 .57643 Mdot
.846 .57649 Mdot
.846 .5765 Mdot
.846 .57655 Mdot
.846 .57664 Mdot
.846 .57674 Mdot
.846 .57679 Mdot
.846 .5771 Mdot
.846 .57711 Mdot
.846 .57726 Mdot
.846 .57737 Mdot
.846 .5776 Mdot
.846 .5776 Mdot
.846 .5779 Mdot
.846 .57792 Mdot
.846 .578 Mdot
.846 .57806 Mdot
.846 .5781 Mdot
.846 .57825 Mdot
.846 .57835 Mdot
.846 .57839 Mdot
.846 .57842 Mdot
.846 .57845 Mdot
.846 .57869 Mdot
.846 .57886 Mdot
.846 .57895 Mdot
.846 .57942 Mdot
.846 .57956 Mdot
.846 .57958 Mdot
.846 .57969 Mdot
.846 .57989 Mdot
.846 .58018 Mdot
.846 .58026 Mdot
.846 .58029 Mdot
.846 .5804 Mdot
.846 .58048 Mdot
.846 .58049 Mdot
.846 .58067 Mdot
.846 .5807 Mdot
.846 .58085 Mdot
.846 .58088 Mdot
.846 .58103 Mdot
.846 .58113 Mdot
.846 .58115 Mdot
.846 .5812 Mdot
.846 .58131 Mdot
.846 .58135 Mdot
.846 .58158 Mdot
.846 .58169 Mdot
.846 .58174 Mdot
.846 .58176 Mdot
.846 .58216 Mdot
.846 .58236 Mdot
.846 .58241 Mdot
.846 .58248 Mdot
.846 .58254 Mdot
.846 .58256 Mdot
.846 .58276 Mdot
.846 .58282 Mdot
.846 .58283 Mdot
.846 .58285 Mdot
.846 .58288 Mdot
.846 .5829 Mdot
.846 .58291 Mdot
.846 .58292 Mdot
.846 .58293 Mdot
.846 .58296 Mdot
.846 .58315 Mdot
.846 .58316 Mdot
.846 .58318 Mdot
.846 .58336 Mdot
.846 .5835 Mdot
.846 .58356 Mdot
.846 .58361 Mdot
.846 .58361 Mdot
.846 .58386 Mdot
.846 .58391 Mdot
.846 .58402 Mdot
.846 .58404 Mdot
.846 .58413 Mdot
.846 .58416 Mdot
.846 .5842 Mdot
.846 .58422 Mdot
.846 .58424 Mdot
.846 .58424 Mdot
.846 .58428 Mdot
.846 .58428 Mdot
.846 .58435 Mdot
.846 .58436 Mdot
.846 .58441 Mdot
.846 .58442 Mdot
.846 .58449 Mdot
.846 .58451 Mdot
.846 .58455 Mdot
.846 .58461 Mdot
.846 .58464 Mdot
.846 .5847 Mdot
.846 .58472 Mdot
.846 .58474 Mdot
.846 .58476 Mdot
.846 .58479 Mdot
.846 .5848 Mdot
.846 .58493 Mdot
.846 .58494 Mdot
.846 .58501 Mdot
.846 .58507 Mdot
.846 .5851 Mdot
.846 .58511 Mdot
.846 .58511 Mdot
.846 .58512 Mdot
.846 .58513 Mdot
.846 .58514 Mdot
.846 .58517 Mdot
.846 .58518 Mdot
.846 .58519 Mdot
.848 .082 Mdot
.848 .082 Mdot
.848 .08201 Mdot
.848 .08201 Mdot
.848 .08201 Mdot
.848 .08204 Mdot
.848 .08209 Mdot
.848 .08218 Mdot
.848 .08223 Mdot
.848 .0824 Mdot
.848 .08241 Mdot
.848 .08249 Mdot
.848 .08251 Mdot
.848 .08252 Mdot
.848 .08279 Mdot
.848 .08311 Mdot
.848 .0832 Mdot
.848 .08326 Mdot
.848 .08327 Mdot
.848 .08334 Mdot
.848 .08351 Mdot
.848 .0836 Mdot
.848 .08389 Mdot
.848 .084 Mdot
.848 .08442 Mdot
.848 .08449 Mdot
.848 .08449 Mdot
.848 .08471 Mdot
.848 .08531 Mdot
.848 .08558 Mdot
.848 .08579 Mdot
.848 .08591 Mdot
.848 .08603 Mdot
.848 .08617 Mdot
.848 .08637 Mdot
.848 .08678 Mdot
.848 .08699 Mdot
.848 .08717 Mdot
.848 .0878 Mdot
.848 .08803 Mdot
.848 .08809 Mdot
.848 .08812 Mdot
.848 .08819 Mdot
.848 .08859 Mdot
.848 .08867 Mdot
.848 .08875 Mdot
.848 .08887 Mdot
.848 .08913 Mdot
.848 .08934 Mdot
.848 .09034 Mdot
.848 .09109 Mdot
.848 .09122 Mdot
.848 .0915 Mdot
.848 .09315 Mdot
.848 .09329 Mdot
.848 .09335 Mdot
.848 .09433 Mdot
.848 .09438 Mdot
.848 .09455 Mdot
.848 .09458 Mdot
.848 .09499 Mdot
.848 .09634 Mdot
.848 .09694 Mdot
.848 .09705 Mdot
.848 .09739 Mdot
.848 .09833 Mdot
.848 .0984 Mdot
.848 .09883 Mdot
.848 .09892 Mdot
.848 .09952 Mdot
.848 .09959 Mdot
.848 .09972 Mdot
.848 .10094 Mdot
.848 .1027 Mdot
.848 .10348 Mdot
.848 .10371 Mdot
.848 .10426 Mdot
.848 .10437 Mdot
.848 .10521 Mdot
.848 .10573 Mdot
.848 .10716 Mdot
.848 .1095 Mdot
.848 .1102 Mdot
.848 .11021 Mdot
.848 .11156 Mdot
.848 .11289 Mdot
.848 .1135 Mdot
.848 .11373 Mdot
.848 .11415 Mdot
.848 .11545 Mdot
.848 .11665 Mdot
.848 .11724 Mdot
.848 .12007 Mdot
.848 .12009 Mdot
.848 .12185 Mdot
.848 .12195 Mdot
.848 .12248 Mdot
.848 .1226 Mdot
.848 .12366 Mdot
.848 .12381 Mdot
.848 .12528 Mdot
.848 .12579 Mdot
.848 .12593 Mdot
.848 .12641 Mdot
.848 .12673 Mdot
.848 .12687 Mdot
.848 .12908 Mdot
.848 .12926 Mdot
.848 .12953 Mdot
.848 .12967 Mdot
.848 .12981 Mdot
.848 .13017 Mdot
.848 .13065 Mdot
.848 .13114 Mdot
.848 .13162 Mdot
.848 .13254 Mdot
.848 .13374 Mdot
.848 .13391 Mdot
.848 .13396 Mdot
.848 .13456 Mdot
.848 .13554 Mdot
.848 .13665 Mdot
.848 .13781 Mdot
.848 .13805 Mdot
.848 .13859 Mdot
.848 .14025 Mdot
.848 .14029 Mdot
.848 .14065 Mdot
.848 .14071 Mdot
.848 .14109 Mdot
.848 .14181 Mdot
.848 .14209 Mdot
.848 .14258 Mdot
.848 .14298 Mdot
.848 .14298 Mdot
.848 .14379 Mdot
.848 .14392 Mdot
.848 .14461 Mdot
.848 .14515 Mdot
.848 .14522 Mdot
.848 .14525 Mdot
.848 .1461 Mdot
.848 .14634 Mdot
.848 .14645 Mdot
.848 .14732 Mdot
.848 .14745 Mdot
.848 .14794 Mdot
.848 .14831 Mdot
.848 .14866 Mdot
.848 .14901 Mdot
.848 .14947 Mdot
.848 .15026 Mdot
.848 .15127 Mdot
.848 .15134 Mdot
.848 .15206 Mdot
.848 .15224 Mdot
.848 .15248 Mdot
.848 .15308 Mdot
.848 .15329 Mdot
.848 .15377 Mdot
.848 .15383 Mdot
.848 .15388 Mdot
.848 .1539 Mdot
.848 .15439 Mdot
.848 .15519 Mdot
.848 .15618 Mdot
.848 .15696 Mdot
.848 .15748 Mdot
.848 .15816 Mdot
.848 .15829 Mdot
.848 .15833 Mdot
.848 .15897 Mdot
.848 .15898 Mdot
.848 .15907 Mdot
.848 .15926 Mdot
.848 .16052 Mdot
.848 .16122 Mdot
.848 .16257 Mdot
.848 .163 Mdot
.848 .16309 Mdot
.848 .16311 Mdot
.848 .16312 Mdot
.848 .16361 Mdot
.848 .16432 Mdot
.848 .16682 Mdot
.848 .16785 Mdot
.848 .16897 Mdot
.848 .1691 Mdot
.848 .16923 Mdot
.848 .16991 Mdot
.848 .16996 Mdot
.848 .1711 Mdot
.848 .17137 Mdot
.848 .17177 Mdot
.848 .17246 Mdot
.848 .17286 Mdot
.848 .17297 Mdot
.848 .17312 Mdot
.848 .17317 Mdot
.848 .17318 Mdot
.848 .1732 Mdot
.848 .17321 Mdot
.848 .17374 Mdot
.848 .17413 Mdot
.848 .17591 Mdot
.848 .17682 Mdot
.848 .17771 Mdot
.848 .17897 Mdot
.848 .18016 Mdot
.848 .18268 Mdot
.848 .18334 Mdot
.848 .18669 Mdot
.848 .1871 Mdot
.848 .1882 Mdot
.848 .18899 Mdot
.848 .189 Mdot
.848 .18995 Mdot
.848 .19222 Mdot
.848 .195 Mdot
.848 .19633 Mdot
.848 .20027 Mdot
.848 .20124 Mdot
.848 .20204 Mdot
.848 .20477 Mdot
.848 .20602 Mdot
.848 .20604 Mdot
.848 .20633 Mdot
.848 .20662 Mdot
.848 .20674 Mdot
.848 .20844 Mdot
.848 .2107 Mdot
.848 .21103 Mdot
.848 .21778 Mdot
.848 .21831 Mdot
.848 .21909 Mdot
.848 .21924 Mdot
.848 .21998 Mdot
.848 .22599 Mdot
.848 .22624 Mdot
.848 .2305 Mdot
.848 .23304 Mdot
.848 .23386 Mdot
.848 .23445 Mdot
.848 .23464 Mdot
.848 .23593 Mdot
.848 .23651 Mdot
.848 .23919 Mdot
.848 .24029 Mdot
.848 .24056 Mdot
.848 .24378 Mdot
.848 .24585 Mdot
.848 .24585 Mdot
.848 .24586 Mdot
.848 .24587 Mdot
.848 .24588 Mdot
.848 .24598 Mdot
.848 .24612 Mdot
.848 .24638 Mdot
.848 .24652 Mdot
.848 .24705 Mdot
.848 .24706 Mdot
.848 .24731 Mdot
.848 .24736 Mdot
.848 .24741 Mdot
.848 .24821 Mdot
.848 .24916 Mdot
.848 .24943 Mdot
.848 .24962 Mdot
.848 .24962 Mdot
.848 .24983 Mdot
.848 .25035 Mdot
.848 .25062 Mdot
.848 .25148 Mdot
.848 .25181 Mdot
.848 .25304 Mdot
.848 .25324 Mdot
.848 .25325 Mdot
.848 .25329 Mdot
.848 .25357 Mdot
.848 .25391 Mdot
.848 .25428 Mdot
.848 .25524 Mdot
.848 .25569 Mdot
.848 .25632 Mdot
.848 .25637 Mdot
.848 .25647 Mdot
.848 .25683 Mdot
.848 .25684 Mdot
.848 .25687 Mdot
.848 .2571 Mdot
.848 .2574 Mdot
.848 .25746 Mdot
.848 .2578 Mdot
.848 .25819 Mdot
.848 .2588 Mdot
.848 .259 Mdot
.848 .25974 Mdot
.848 .25998 Mdot
.848 .2601 Mdot
.848 .26062 Mdot
.848 .26113 Mdot
.848 .26196 Mdot
.848 .26296 Mdot
.848 .26366 Mdot
.848 .26384 Mdot
.848 .2639 Mdot
.848 .26397 Mdot
.848 .2641 Mdot
.848 .26528 Mdot
.848 .26535 Mdot
.848 .26551 Mdot
.848 .26575 Mdot
.848 .26608 Mdot
.848 .26683 Mdot
.848 .26691 Mdot
.848 .26746 Mdot
.848 .26752 Mdot
.848 .27035 Mdot
.848 .27137 Mdot
.848 .2725 Mdot
.848 .27286 Mdot
.848 .27366 Mdot
.848 .27449 Mdot
.848 .27449 Mdot
.848 .27839 Mdot
.848 .27878 Mdot
.848 .27894 Mdot
.848 .28079 Mdot
.848 .28172 Mdot
.848 .28183 Mdot
.848 .28188 Mdot
.848 .28235 Mdot
.848 .28243 Mdot
.848 .28277 Mdot
.848 .2836 Mdot
.848 .28397 Mdot
.848 .28608 Mdot
.848 .28629 Mdot
.848 .28722 Mdot
.848 .28727 Mdot
.848 .2874 Mdot
.848 .28908 Mdot
.848 .28938 Mdot
.848 .29033 Mdot
.848 .2915 Mdot
.848 .29208 Mdot
.848 .29232 Mdot
.848 .29294 Mdot
.848 .29314 Mdot
.848 .29433 Mdot
.848 .29458 Mdot
.848 .29551 Mdot
.848 .29624 Mdot
.848 .29643 Mdot
.848 .2968 Mdot
.848 .29726 Mdot
.848 .29898 Mdot
.848 .29988 Mdot
.848 .30014 Mdot
.848 .30085 Mdot
.848 .30176 Mdot
.848 .30176 Mdot
.848 .30222 Mdot
.848 .30328 Mdot
.848 .30436 Mdot
.848 .30442 Mdot
.848 .30494 Mdot
.848 .30707 Mdot
.848 .30769 Mdot
.848 .30862 Mdot
.848 .30907 Mdot
.848 .30917 Mdot
.848 .30947 Mdot
.848 .30969 Mdot
.848 .31172 Mdot
.848 .31208 Mdot
.848 .31312 Mdot
.848 .31353 Mdot
.848 .31609 Mdot
.848 .31647 Mdot
.848 .31695 Mdot
.848 .31919 Mdot
.848 .3192 Mdot
.848 .31965 Mdot
.848 .32199 Mdot
.848 .3222 Mdot
.848 .32314 Mdot
.848 .32457 Mdot
.848 .32497 Mdot
.848 .325 Mdot
.848 .32561 Mdot
.848 .32582 Mdot
.848 .32628 Mdot
.848 .32852 Mdot
.848 .3318 Mdot
.848 .33198 Mdot
.848 .33235 Mdot
.848 .33355 Mdot
.848 .33415 Mdot
.848 .33521 Mdot
.848 .33853 Mdot
.848 .33972 Mdot
.848 .34029 Mdot
.848 .34065 Mdot
.848 .3416 Mdot
.848 .3431 Mdot
.848 .34567 Mdot
.848 .34591 Mdot
.848 .34735 Mdot
.848 .34923 Mdot
.848 .34924 Mdot
.848 .35018 Mdot
.848 .35023 Mdot
.848 .35221 Mdot
.848 .35385 Mdot
.848 .3546 Mdot
.848 .35484 Mdot
.848 .35551 Mdot
.848 .35615 Mdot
.848 .35617 Mdot
.848 .35645 Mdot
.848 .35905 Mdot
.848 .35921 Mdot
.848 .3594 Mdot
.848 .35972 Mdot
.848 .36006 Mdot
.848 .36023 Mdot
.848 .36208 Mdot
.848 .36214 Mdot
.848 .3625 Mdot
.848 .36264 Mdot
.848 .36298 Mdot
.848 .36331 Mdot
.848 .36372 Mdot
.848 .36404 Mdot
.848 .36422 Mdot
.848 .36455 Mdot
.848 .36476 Mdot
.848 .36531 Mdot
.848 .36571 Mdot
.848 .36601 Mdot
.848 .36649 Mdot
.848 .36654 Mdot
.848 .3668 Mdot
.848 .36681 Mdot
.848 .36684 Mdot
.848 .36692 Mdot
.848 .36837 Mdot
.848 .3684 Mdot
.848 .3702 Mdot
.848 .37141 Mdot
.848 .37209 Mdot
.848 .37237 Mdot
.848 .37252 Mdot
.848 .37316 Mdot
.848 .37349 Mdot
.848 .3738 Mdot
.848 .37468 Mdot
.848 .37556 Mdot
.848 .37579 Mdot
.848 .37696 Mdot
.848 .37709 Mdot
.848 .37774 Mdot
.848 .37807 Mdot
.848 .37977 Mdot
.848 .38022 Mdot
.848 .38184 Mdot
.848 .38299 Mdot
.848 .3834 Mdot
.848 .38349 Mdot
.848 .38362 Mdot
.848 .38489 Mdot
.848 .38712 Mdot
.848 .38729 Mdot
.848 .38758 Mdot
.848 .38781 Mdot
.848 .38966 Mdot
.848 .38973 Mdot
.848 .39103 Mdot
.848 .39222 Mdot
.848 .39228 Mdot
.848 .39266 Mdot
.848 .39284 Mdot
.848 .39363 Mdot
.848 .39396 Mdot
.848 .39404 Mdot
.848 .39499 Mdot
.848 .39776 Mdot
.848 .39784 Mdot
.848 .39833 Mdot
.848 .39864 Mdot
.848 .39865 Mdot
.848 .39878 Mdot
.848 .39879 Mdot
.848 .3994 Mdot
.848 .39962 Mdot
.848 .40082 Mdot
.848 .40121 Mdot
.848 .40165 Mdot
.848 .40183 Mdot
.848 .40291 Mdot
.848 .40378 Mdot
.848 .40379 Mdot
.848 .40554 Mdot
.848 .40583 Mdot
.848 .40609 Mdot
.848 .40642 Mdot
.848 .40706 Mdot
.848 .40732 Mdot
.848 .40849 Mdot
.848 .40865 Mdot
.848 .40872 Mdot
.848 .41007 Mdot
.848 .41053 Mdot
.848 .41078 Mdot
.848 .41104 Mdot
.848 .41129 Mdot
.848 .41315 Mdot
.848 .41344 Mdot
.848 .41408 Mdot
.848 .41447 Mdot
.848 .41516 Mdot
.848 .41526 Mdot
.848 .41599 Mdot
.848 .41611 Mdot
.848 .41674 Mdot
.848 .41743 Mdot
.848 .4177 Mdot
.848 .41788 Mdot
.848 .41935 Mdot
.848 .4195 Mdot
.848 .42146 Mdot
.848 .42161 Mdot
.848 .4231 Mdot
.848 .42348 Mdot
.848 .42397 Mdot
.848 .42398 Mdot
.848 .42476 Mdot
.848 .4252 Mdot
.848 .42543 Mdot
.848 .42563 Mdot
.848 .42661 Mdot
.848 .42675 Mdot
.848 .42684 Mdot
.848 .42688 Mdot
.848 .42737 Mdot
.848 .42739 Mdot
.848 .42748 Mdot
.848 .42752 Mdot
.848 .4277 Mdot
.848 .42781 Mdot
.848 .42789 Mdot
.848 .42823 Mdot
.848 .42841 Mdot
.848 .42855 Mdot
.848 .42863 Mdot
.848 .42865 Mdot
.848 .42952 Mdot
.848 .43009 Mdot
.848 .43151 Mdot
.848 .43205 Mdot
.848 .4326 Mdot
.848 .43307 Mdot
.848 .43404 Mdot
.848 .43412 Mdot
.848 .43418 Mdot
.848 .43504 Mdot
.848 .43547 Mdot
.848 .43573 Mdot
.848 .43582 Mdot
.848 .43609 Mdot
.848 .43698 Mdot
.848 .43707 Mdot
.848 .43711 Mdot
.848 .43727 Mdot
.848 .43765 Mdot
.848 .43915 Mdot
.848 .43932 Mdot
.848 .44013 Mdot
.848 .4415 Mdot
.848 .44176 Mdot
.848 .44224 Mdot
.848 .44268 Mdot
.848 .44411 Mdot
.848 .44494 Mdot
.848 .44511 Mdot
.848 .44515 Mdot
.848 .44518 Mdot
.848 .44611 Mdot
.848 .4467 Mdot
.848 .44723 Mdot
.848 .44747 Mdot
.848 .45033 Mdot
.848 .4522 Mdot
.848 .45384 Mdot
.848 .45412 Mdot
.848 .4562 Mdot
.848 .45643 Mdot
.848 .45668 Mdot
.848 .45792 Mdot
.848 .45801 Mdot
.848 .45911 Mdot
.848 .45956 Mdot
.848 .46009 Mdot
.848 .46052 Mdot
.848 .46059 Mdot
.848 .46131 Mdot
.848 .46158 Mdot
.848 .46256 Mdot
.848 .46327 Mdot
.848 .46328 Mdot
.848 .46332 Mdot
.848 .46338 Mdot
.848 .46347 Mdot
.848 .46368 Mdot
.848 .46374 Mdot
.848 .46382 Mdot
.848 .46384 Mdot
.848 .46389 Mdot
.848 .46389 Mdot
.848 .46484 Mdot
.848 .46517 Mdot
.848 .46555 Mdot
.848 .4677 Mdot
.848 .46848 Mdot
.848 .46869 Mdot
.848 .46932 Mdot
.848 .46977 Mdot
.848 .47028 Mdot
.848 .47182 Mdot
.848 .47215 Mdot
.848 .47354 Mdot
.848 .47384 Mdot
.848 .47399 Mdot
.848 .47602 Mdot
.848 .4764 Mdot
.848 .47704 Mdot
.848 .47732 Mdot
.848 .47738 Mdot
.848 .47753 Mdot
.848 .47902 Mdot
.848 .47948 Mdot
.848 .47962 Mdot
.848 .48006 Mdot
.848 .48025 Mdot
.848 .48078 Mdot
.848 .48135 Mdot
.848 .4822 Mdot
.848 .4823 Mdot
.848 .48242 Mdot
.848 .48402 Mdot
.848 .48479 Mdot
.848 .48568 Mdot
.848 .48655 Mdot
.848 .48683 Mdot
.848 .48748 Mdot
.848 .48883 Mdot
.848 .48924 Mdot
.848 .48975 Mdot
.848 .4905 Mdot
.848 .49051 Mdot
.848 .49112 Mdot
.848 .49115 Mdot
.848 .49128 Mdot
.848 .4915 Mdot
.848 .49179 Mdot
.848 .49202 Mdot
.848 .49231 Mdot
.848 .49245 Mdot
.848 .49262 Mdot
.848 .49289 Mdot
.848 .49295 Mdot
.848 .4931 Mdot
.848 .49312 Mdot
.848 .49389 Mdot
.848 .49396 Mdot
.848 .4941 Mdot
.848 .49431 Mdot
.848 .49555 Mdot
.848 .49581 Mdot
.848 .49649 Mdot
.848 .49715 Mdot
.848 .49834 Mdot
.848 .49835 Mdot
.848 .4991 Mdot
.848 .49967 Mdot
.848 .49977 Mdot
.848 .50176 Mdot
.848 .5019 Mdot
.848 .50212 Mdot
.848 .50499 Mdot
.848 .50521 Mdot
.848 .50733 Mdot
.848 .50751 Mdot
.848 .50759 Mdot
.848 .50798 Mdot
.848 .50889 Mdot
.848 .50897 Mdot
.848 .50985 Mdot
.848 .51002 Mdot
.848 .51003 Mdot
.848 .51105 Mdot
.848 .51119 Mdot
.848 .51215 Mdot
.848 .5127 Mdot
.848 .51358 Mdot
.848 .51381 Mdot
.848 .51398 Mdot
.848 .51553 Mdot
.848 .51555 Mdot
.848 .51595 Mdot
.848 .51633 Mdot
.848 .5165 Mdot
.848 .5165 Mdot
.848 .51684 Mdot
.848 .51719 Mdot
.848 .51752 Mdot
.848 .51814 Mdot
.848 .51878 Mdot
.848 .51993 Mdot
.848 .52001 Mdot
.848 .52022 Mdot
.848 .52174 Mdot
.848 .52176 Mdot
.848 .52209 Mdot
.848 .52216 Mdot
.848 .52291 Mdot
.848 .52334 Mdot
.848 .52367 Mdot
.848 .52403 Mdot
.848 .52625 Mdot
.848 .52625 Mdot
.848 .52733 Mdot
.848 .52867 Mdot
.848 .52888 Mdot
.848 .52942 Mdot
.848 .52989 Mdot
.848 .53058 Mdot
.848 .53122 Mdot
.848 .53134 Mdot
.848 .53159 Mdot
.848 .53214 Mdot
.848 .53232 Mdot
.848 .53233 Mdot
.848 .53233 Mdot
.848 .53249 Mdot
.848 .5325 Mdot
.848 .53287 Mdot
.848 .5332 Mdot
.848 .53343 Mdot
.848 .53353 Mdot
.848 .53672 Mdot
.848 .53779 Mdot
.848 .53788 Mdot
.848 .53825 Mdot
.848 .53913 Mdot
.848 .53932 Mdot
.848 .53975 Mdot
.848 .53981 Mdot
.848 .54 Mdot
.848 .54027 Mdot
.848 .5411 Mdot
.848 .54249 Mdot
.848 .54258 Mdot
.848 .54452 Mdot
.848 .54476 Mdot
.848 .54481 Mdot
.848 .54506 Mdot
.848 .54523 Mdot
.848 .54739 Mdot
.848 .54749 Mdot
.848 .54821 Mdot
.848 .54875 Mdot
.848 .54879 Mdot
.848 .54888 Mdot
.848 .54897 Mdot
.848 .54898 Mdot
.848 .54937 Mdot
.848 .55023 Mdot
.848 .55048 Mdot
.848 .55079 Mdot
.848 .55202 Mdot
.848 .55244 Mdot
.848 .5533 Mdot
.848 .554 Mdot
.848 .5543 Mdot
.848 .5543 Mdot
.848 .55455 Mdot
.848 .55489 Mdot
.848 .55501 Mdot
.848 .55604 Mdot
.848 .55625 Mdot
.848 .55702 Mdot
.848 .55738 Mdot
.848 .55777 Mdot
.848 .55804 Mdot
.848 .55831 Mdot
.848 .55886 Mdot
.848 .55898 Mdot
.848 .55914 Mdot
.848 .55914 Mdot
.848 .55915 Mdot
.848 .55915 Mdot
.848 .55916 Mdot
.848 .55921 Mdot
.848 .55924 Mdot
.848 .55936 Mdot
.848 .55957 Mdot
.848 .55969 Mdot
.848 .55978 Mdot
.848 .56012 Mdot
.848 .56014 Mdot
.848 .56034 Mdot
.848 .56038 Mdot
.848 .56042 Mdot
.848 .56076 Mdot
.848 .56107 Mdot
.848 .56182 Mdot
.848 .56203 Mdot
.848 .56218 Mdot
.848 .56218 Mdot
.848 .56219 Mdot
.848 .56221 Mdot
.848 .56234 Mdot
.848 .56275 Mdot
.848 .56296 Mdot
.848 .56333 Mdot
.848 .56339 Mdot
.848 .56342 Mdot
.848 .56342 Mdot
.848 .56361 Mdot
.848 .56362 Mdot
.848 .56366 Mdot
.848 .56386 Mdot
.848 .56402 Mdot
.848 .56425 Mdot
.848 .56454 Mdot
.848 .56478 Mdot
.848 .56493 Mdot
.848 .56493 Mdot
.848 .56495 Mdot
.848 .56497 Mdot
.848 .56511 Mdot
.848 .56517 Mdot
.848 .56535 Mdot
.848 .56542 Mdot
.848 .56547 Mdot
.848 .56569 Mdot
.848 .56571 Mdot
.848 .56601 Mdot
.848 .56624 Mdot
.848 .56637 Mdot
.848 .56648 Mdot
.848 .56658 Mdot
.848 .56669 Mdot
.848 .56683 Mdot
.848 .56687 Mdot
.848 .56713 Mdot
.848 .56716 Mdot
.848 .56723 Mdot
.848 .56748 Mdot
.848 .56749 Mdot
.848 .56751 Mdot
.848 .56767 Mdot
.848 .56787 Mdot
.848 .56791 Mdot
.848 .56814 Mdot
.848 .56814 Mdot
.848 .56826 Mdot
.848 .56841 Mdot
.848 .56849 Mdot
.848 .5687 Mdot
.848 .56881 Mdot
.848 .56883 Mdot
.848 .56893 Mdot
.848 .56894 Mdot
.848 .56943 Mdot
.848 .56958 Mdot
.848 .56966 Mdot
.848 .56999 Mdot
.848 .57032 Mdot
.848 .5706 Mdot
.848 .57077 Mdot
.848 .57079 Mdot
.848 .57084 Mdot
.848 .57118 Mdot
.848 .57145 Mdot
.848 .57159 Mdot
.848 .57173 Mdot
.848 .57187 Mdot
.848 .57198 Mdot
.848 .57201 Mdot
.848 .57205 Mdot
.848 .57213 Mdot
.848 .57218 Mdot
.848 .57282 Mdot
.848 .57286 Mdot
.848 .57295 Mdot
.848 .57309 Mdot
.848 .57313 Mdot
.848 .57328 Mdot
.848 .5737 Mdot
.848 .57374 Mdot
.848 .57405 Mdot
.848 .57408 Mdot
.848 .57423 Mdot
.848 .57426 Mdot
.848 .57476 Mdot
.848 .57477 Mdot
.848 .57558 Mdot
.848 .57574 Mdot
.848 .57609 Mdot
.848 .57646 Mdot
.848 .57657 Mdot
.848 .57664 Mdot
.848 .57681 Mdot
.848 .57719 Mdot
.848 .57757 Mdot
.848 .57757 Mdot
.848 .57777 Mdot
.848 .57843 Mdot
.848 .57883 Mdot
.848 .57898 Mdot
.848 .57922 Mdot
.848 .57925 Mdot
.848 .5794 Mdot
.848 .57947 Mdot
.848 .57969 Mdot
.848 .58018 Mdot
.848 .58052 Mdot
.848 .58055 Mdot
.848 .58057 Mdot
.848 .58074 Mdot
.848 .58077 Mdot
.848 .58089 Mdot
.848 .58091 Mdot
.848 .58117 Mdot
.848 .58126 Mdot
.848 .58129 Mdot
.848 .58146 Mdot
.848 .58184 Mdot
.848 .58195 Mdot
.848 .58196 Mdot
.848 .58201 Mdot
.848 .58202 Mdot
.848 .58229 Mdot
.848 .58231 Mdot
.848 .58235 Mdot
.848 .58281 Mdot
.848 .58288 Mdot
.848 .58292 Mdot
.848 .58313 Mdot
.848 .5834 Mdot
.848 .58346 Mdot
.848 .58353 Mdot
.848 .58357 Mdot
.848 .58359 Mdot
.848 .58361 Mdot
.848 .58372 Mdot
.848 .58374 Mdot
.848 .58375 Mdot
.848 .58376 Mdot
.848 .58383 Mdot
.848 .584 Mdot
.848 .58405 Mdot
.848 .58411 Mdot
.848 .58422 Mdot
.848 .58428 Mdot
.848 .58432 Mdot
.848 .58435 Mdot
.848 .58438 Mdot
.848 .58444 Mdot
.848 .58451 Mdot
.848 .58468 Mdot
.848 .58474 Mdot
.848 .58474 Mdot
.848 .58476 Mdot
.848 .58488 Mdot
.848 .58491 Mdot
.848 .58499 Mdot
.848 .58501 Mdot
.848 .58506 Mdot
.848 .58508 Mdot
.848 .58508 Mdot
.848 .5851 Mdot
.848 .58512 Mdot
.848 .58521 Mdot
.848 .58528 Mdot
.848 .58529 Mdot
.848 .58529 Mdot
.848 .58531 Mdot
.848 .58532 Mdot
.848 .58536 Mdot
.848 .58538 Mdot
.848 .5854 Mdot
.848 .58541 Mdot
.848 .58542 Mdot
.848 .58542 Mdot
.848 .58542 Mdot
.848 .58543 Mdot
.848 .58543 Mdot
.85 .08117 Mdot
.85 .0812 Mdot
.85 .08122 Mdot
.85 .08124 Mdot
.85 .08126 Mdot
.85 .08135 Mdot
.85 .08154 Mdot
.85 .08158 Mdot
.85 .08173 Mdot
.85 .0819 Mdot
.85 .08198 Mdot
.85 .08199 Mdot
.85 .08233 Mdot
.85 .08253 Mdot
.85 .0826 Mdot
.85 .08263 Mdot
.85 .08288 Mdot
.85 .08292 Mdot
.85 .083 Mdot
.85 .0831 Mdot
.85 .08311 Mdot
.85 .0832 Mdot
.85 .08325 Mdot
.85 .08347 Mdot
.85 .08351 Mdot
.85 .08351 Mdot
.85 .08374 Mdot
.85 .08377 Mdot
.85 .08381 Mdot
.85 .08385 Mdot
.85 .08406 Mdot
.85 .08416 Mdot
.85 .08433 Mdot
.85 .08438 Mdot
.85 .08448 Mdot
.85 .08466 Mdot
.85 .08467 Mdot
.85 .08481 Mdot
.85 .08498 Mdot
.85 .08519 Mdot
.85 .08552 Mdot
.85 .08562 Mdot
.85 .08599 Mdot
.85 .08614 Mdot
.85 .08726 Mdot
.85 .08758 Mdot
.85 .08762 Mdot
.85 .0877 Mdot
.85 .08791 Mdot
.85 .08794 Mdot
.85 .08867 Mdot
.85 .08898 Mdot
.85 .0894 Mdot
.85 .0899 Mdot
.85 .09009 Mdot
.85 .09051 Mdot
.85 .09051 Mdot
.85 .09085 Mdot
.85 .09106 Mdot
.85 .0911 Mdot
.85 .09116 Mdot
.85 .09156 Mdot
.85 .09174 Mdot
.85 .09191 Mdot
.85 .092 Mdot
.85 .09205 Mdot
.85 .09217 Mdot
.85 .09222 Mdot
.85 .09283 Mdot
.85 .09332 Mdot
.85 .09409 Mdot
.85 .09502 Mdot
.85 .0953 Mdot
.85 .09534 Mdot
.85 .09542 Mdot
.85 .09635 Mdot
.85 .09645 Mdot
.85 .09676 Mdot
.85 .09713 Mdot
.85 .09758 Mdot
.85 .09923 Mdot
.85 .09954 Mdot
.85 .09965 Mdot
.85 .09992 Mdot
.85 .10095 Mdot
.85 .10202 Mdot
.85 .10213 Mdot
.85 .10263 Mdot
.85 .10378 Mdot
.85 .10466 Mdot
.85 .1052 Mdot
.85 .10594 Mdot
.85 .10731 Mdot
.85 .10734 Mdot
.85 .1075 Mdot
.85 .10751 Mdot
.85 .10784 Mdot
.85 .10804 Mdot
.85 .10808 Mdot
.85 .10826 Mdot
.85 .10855 Mdot
.85 .10867 Mdot
.85 .10926 Mdot
.85 .10947 Mdot
.85 .11032 Mdot
.85 .11036 Mdot
.85 .11048 Mdot
.85 .11135 Mdot
.85 .11219 Mdot
.85 .11221 Mdot
.85 .1125 Mdot
.85 .11268 Mdot
.85 .11375 Mdot
.85 .11411 Mdot
.85 .11462 Mdot
.85 .11543 Mdot
.85 .11546 Mdot
.85 .11759 Mdot
.85 .11848 Mdot
.85 .11859 Mdot
.85 .12134 Mdot
.85 .12367 Mdot
.85 .12543 Mdot
.85 .1273 Mdot
.85 .1276 Mdot
.85 .12913 Mdot
.85 .12976 Mdot
.85 .12993 Mdot
.85 .13057 Mdot
.85 .13122 Mdot
.85 .13175 Mdot
.85 .13201 Mdot
.85 .13326 Mdot
.85 .13331 Mdot
.85 .13396 Mdot
.85 .134 Mdot
.85 .13825 Mdot
.85 .13867 Mdot
.85 .13946 Mdot
.85 .13995 Mdot
.85 .14048 Mdot
.85 .14131 Mdot
.85 .14231 Mdot
.85 .14485 Mdot
.85 .14553 Mdot
.85 .14604 Mdot
.85 .14611 Mdot
.85 .1471 Mdot
.85 .14733 Mdot
.85 .14784 Mdot
.85 .14876 Mdot
.85 .14936 Mdot
.85 .14989 Mdot
.85 .15 Mdot
.85 .15006 Mdot
.85 .15058 Mdot
.85 .15157 Mdot
.85 .15165 Mdot
.85 .15297 Mdot
.85 .1537 Mdot
.85 .15407 Mdot
.85 .15414 Mdot
.85 .15534 Mdot
.85 .15612 Mdot
.85 .15769 Mdot
.85 .15797 Mdot
.85 .1583 Mdot
.85 .1585 Mdot
.85 .15902 Mdot
.85 .16026 Mdot
.85 .16029 Mdot
.85 .16058 Mdot
.85 .16131 Mdot
.85 .16167 Mdot
.85 .16226 Mdot
.85 .16267 Mdot
.85 .16318 Mdot
.85 .1634 Mdot
.85 .16346 Mdot
.85 .16426 Mdot
.85 .16484 Mdot
.85 .16516 Mdot
.85 .16582 Mdot
.85 .16721 Mdot
.85 .16745 Mdot
.85 .16796 Mdot
.85 .16888 Mdot
.85 .16956 Mdot
.85 .171 Mdot
.85 .17114 Mdot
.85 .17124 Mdot
.85 .17222 Mdot
.85 .17224 Mdot
.85 .1724 Mdot
.85 .17243 Mdot
.85 .17303 Mdot
.85 .17311 Mdot
.85 .17437 Mdot
.85 .17455 Mdot
.85 .17577 Mdot
.85 .17607 Mdot
.85 .17715 Mdot
.85 .17749 Mdot
.85 .17766 Mdot
.85 .1783 Mdot
.85 .17839 Mdot
.85 .17844 Mdot
.85 .17865 Mdot
.85 .17884 Mdot
.85 .179 Mdot
.85 .17921 Mdot
.85 .17932 Mdot
.85 .1822 Mdot
.85 .1823 Mdot
.85 .18258 Mdot
.85 .18578 Mdot
.85 .18647 Mdot
.85 .18661 Mdot
.85 .187 Mdot
.85 .18794 Mdot
.85 .18804 Mdot
.85 .18898 Mdot
.85 .19063 Mdot
.85 .19153 Mdot
.85 .19213 Mdot
.85 .19246 Mdot
.85 .19529 Mdot
.85 .19569 Mdot
.85 .19618 Mdot
.85 .19725 Mdot
.85 .19909 Mdot
.85 .20119 Mdot
.85 .20159 Mdot
.85 .20623 Mdot
.85 .20654 Mdot
.85 .20676 Mdot
.85 .21383 Mdot
.85 .21711 Mdot
.85 .22024 Mdot
.85 .22479 Mdot
.85 .22497 Mdot
.85 .23093 Mdot
.85 .23196 Mdot
.85 .2342 Mdot
.85 .23669 Mdot
.85 .2373 Mdot
.85 .23765 Mdot
.85 .23795 Mdot
.85 .23901 Mdot
.85 .24007 Mdot
.85 .24116 Mdot
.85 .24346 Mdot
.85 .24353 Mdot
.85 .24359 Mdot
.85 .24366 Mdot
.85 .24373 Mdot
.85 .24401 Mdot
.85 .24457 Mdot
.85 .24468 Mdot
.85 .24512 Mdot
.85 .24518 Mdot
.85 .24564 Mdot
.85 .24589 Mdot
.85 .2459 Mdot
.85 .24694 Mdot
.85 .24719 Mdot
.85 .24753 Mdot
.85 .24772 Mdot
.85 .24781 Mdot
.85 .24858 Mdot
.85 .2487 Mdot
.85 .24892 Mdot
.85 .24923 Mdot
.85 .24925 Mdot
.85 .24953 Mdot
.85 .24968 Mdot
.85 .25033 Mdot
.85 .25044 Mdot
.85 .25045 Mdot
.85 .25093 Mdot
.85 .25114 Mdot
.85 .25122 Mdot
.85 .25134 Mdot
.85 .25145 Mdot
.85 .25207 Mdot
.85 .25238 Mdot
.85 .25286 Mdot
.85 .25289 Mdot
.85 .25304 Mdot
.85 .25333 Mdot
.85 .25386 Mdot
.85 .2539 Mdot
.85 .2543 Mdot
.85 .25451 Mdot
.85 .2548 Mdot
.85 .25505 Mdot
.85 .25543 Mdot
.85 .2564 Mdot
.85 .25669 Mdot
.85 .25778 Mdot
.85 .25821 Mdot
.85 .25858 Mdot
.85 .25938 Mdot
.85 .26149 Mdot
.85 .26151 Mdot
.85 .26242 Mdot
.85 .26255 Mdot
.85 .2628 Mdot
.85 .26341 Mdot
.85 .2635 Mdot
.85 .2638 Mdot
.85 .26562 Mdot
.85 .26651 Mdot
.85 .26772 Mdot
.85 .26919 Mdot
.85 .26925 Mdot
.85 .26973 Mdot
.85 .27092 Mdot
.85 .27094 Mdot
.85 .2719 Mdot
.85 .27252 Mdot
.85 .27263 Mdot
.85 .2728 Mdot
.85 .27394 Mdot
.85 .27446 Mdot
.85 .27459 Mdot
.85 .27496 Mdot
.85 .27522 Mdot
.85 .27536 Mdot
.85 .27548 Mdot
.85 .2757 Mdot
.85 .27583 Mdot
.85 .27672 Mdot
.85 .27758 Mdot
.85 .27817 Mdot
.85 .27898 Mdot
.85 .28096 Mdot
.85 .28117 Mdot
.85 .28315 Mdot
.85 .2838 Mdot
.85 .28458 Mdot
.85 .28469 Mdot
.85 .28493 Mdot
.85 .28576 Mdot
.85 .28752 Mdot
.85 .28782 Mdot
.85 .28858 Mdot
.85 .28868 Mdot
.85 .28926 Mdot
.85 .28927 Mdot
.85 .28971 Mdot
.85 .29048 Mdot
.85 .29096 Mdot
.85 .29132 Mdot
.85 .29224 Mdot
.85 .29463 Mdot
.85 .29555 Mdot
.85 .29642 Mdot
.85 .2967 Mdot
.85 .29745 Mdot
.85 .29867 Mdot
.85 .29915 Mdot
.85 .29923 Mdot
.85 .29971 Mdot
.85 .29982 Mdot
.85 .3003 Mdot
.85 .30123 Mdot
.85 .30149 Mdot
.85 .30206 Mdot
.85 .3032 Mdot
.85 .30321 Mdot
.85 .30351 Mdot
.85 .30489 Mdot
.85 .30626 Mdot
.85 .30707 Mdot
.85 .30735 Mdot
.85 .308 Mdot
.85 .30891 Mdot
.85 .31037 Mdot
.85 .31183 Mdot
.85 .31295 Mdot
.85 .31382 Mdot
.85 .31672 Mdot
.85 .31746 Mdot
.85 .31756 Mdot
.85 .31798 Mdot
.85 .31799 Mdot
.85 .31889 Mdot
.85 .31942 Mdot
.85 .3195 Mdot
.85 .31958 Mdot
.85 .31998 Mdot
.85 .32018 Mdot
.85 .32049 Mdot
.85 .32076 Mdot
.85 .32108 Mdot
.85 .3211 Mdot
.85 .32196 Mdot
.85 .32263 Mdot
.85 .32319 Mdot
.85 .32496 Mdot
.85 .32536 Mdot
.85 .32542 Mdot
.85 .32553 Mdot
.85 .32583 Mdot
.85 .32812 Mdot
.85 .32912 Mdot
.85 .32939 Mdot
.85 .32985 Mdot
.85 .33004 Mdot
.85 .3303 Mdot
.85 .33035 Mdot
.85 .33047 Mdot
.85 .3311 Mdot
.85 .33156 Mdot
.85 .33338 Mdot
.85 .33433 Mdot
.85 .33458 Mdot
.85 .33525 Mdot
.85 .33655 Mdot
.85 .33679 Mdot
.85 .33784 Mdot
.85 .33862 Mdot
.85 .3387 Mdot
.85 .34082 Mdot
.85 .34223 Mdot
.85 .34233 Mdot
.85 .3427 Mdot
.85 .343 Mdot
.85 .34412 Mdot
.85 .34419 Mdot
.85 .34472 Mdot
.85 .34522 Mdot
.85 .34634 Mdot
.85 .34663 Mdot
.85 .35334 Mdot
.85 .35349 Mdot
.85 .35493 Mdot
.85 .35619 Mdot
.85 .35622 Mdot
.85 .35847 Mdot
.85 .359 Mdot
.85 .35922 Mdot
.85 .36185 Mdot
.85 .36188 Mdot
.85 .36229 Mdot
.85 .36239 Mdot
.85 .36345 Mdot
.85 .3635 Mdot
.85 .36799 Mdot
.85 .36813 Mdot
.85 .3687 Mdot
.85 .3697 Mdot
.85 .37162 Mdot
.85 .37167 Mdot
.85 .37171 Mdot
.85 .37207 Mdot
.85 .37208 Mdot
.85 .37236 Mdot
.85 .37384 Mdot
.85 .37425 Mdot
.85 .37428 Mdot
.85 .37461 Mdot
.85 .37562 Mdot
.85 .37566 Mdot
.85 .37576 Mdot
.85 .3771 Mdot
.85 .37715 Mdot
.85 .37728 Mdot
.85 .37761 Mdot
.85 .37764 Mdot
.85 .37852 Mdot
.85 .37882 Mdot
.85 .37914 Mdot
.85 .38022 Mdot
.85 .38203 Mdot
.85 .38216 Mdot
.85 .38366 Mdot
.85 .38376 Mdot
.85 .38807 Mdot
.85 .38947 Mdot
.85 .38953 Mdot
.85 .39133 Mdot
.85 .39164 Mdot
.85 .39232 Mdot
.85 .39334 Mdot
.85 .39343 Mdot
.85 .39375 Mdot
.85 .39406 Mdot
.85 .39438 Mdot
.85 .39556 Mdot
.85 .39615 Mdot
.85 .39724 Mdot
.85 .39827 Mdot
.85 .39842 Mdot
.85 .39943 Mdot
.85 .39966 Mdot
.85 .40027 Mdot
.85 .40246 Mdot
.85 .40395 Mdot
.85 .40455 Mdot
.85 .40495 Mdot
.85 .40572 Mdot
.85 .40633 Mdot
.85 .40705 Mdot
.85 .40782 Mdot
.85 .40801 Mdot
.85 .40801 Mdot
.85 .40834 Mdot
.85 .40857 Mdot
.85 .40882 Mdot
.85 .40947 Mdot
.85 .41057 Mdot
.85 .41071 Mdot
.85 .41073 Mdot
.85 .41086 Mdot
.85 .41089 Mdot
.85 .41134 Mdot
.85 .41263 Mdot
.85 .41285 Mdot
.85 .41292 Mdot
.85 .41334 Mdot
.85 .41443 Mdot
.85 .41544 Mdot
.85 .4162 Mdot
.85 .41636 Mdot
.85 .41661 Mdot
.85 .41764 Mdot
.85 .41775 Mdot
.85 .41875 Mdot
.85 .41882 Mdot
.85 .41899 Mdot
.85 .4191 Mdot
.85 .41988 Mdot
.85 .42019 Mdot
.85 .42106 Mdot
.85 .42222 Mdot
.85 .42225 Mdot
.85 .42242 Mdot
.85 .42288 Mdot
.85 .42301 Mdot
.85 .42515 Mdot
.85 .42591 Mdot
.85 .42665 Mdot
.85 .4274 Mdot
.85 .42752 Mdot
.85 .42754 Mdot
.85 .42782 Mdot
.85 .42947 Mdot
.85 .42998 Mdot
.85 .43 Mdot
.85 .4301 Mdot
.85 .43068 Mdot
.85 .43077 Mdot
.85 .43104 Mdot
.85 .43144 Mdot
.85 .43156 Mdot
.85 .43188 Mdot
.85 .43433 Mdot
.85 .4347 Mdot
.85 .43471 Mdot
.85 .43519 Mdot
.85 .43528 Mdot
.85 .43592 Mdot
.85 .43632 Mdot
.85 .43704 Mdot
.85 .43735 Mdot
.85 .43741 Mdot
.85 .43856 Mdot
.85 .43979 Mdot
.85 .43986 Mdot
.85 .44041 Mdot
.85 .44042 Mdot
.85 .44096 Mdot
.85 .44164 Mdot
.85 .44185 Mdot
.85 .44256 Mdot
.85 .44284 Mdot
.85 .44316 Mdot
.85 .44369 Mdot
.85 .44448 Mdot
.85 .44546 Mdot
.85 .44589 Mdot
.85 .446 Mdot
.85 .44612 Mdot
.85 .44754 Mdot
.85 .44764 Mdot
.85 .44796 Mdot
.85 .44863 Mdot
.85 .44882 Mdot
.85 .44924 Mdot
.85 .4505 Mdot
.85 .4531 Mdot
.85 .45355 Mdot
.85 .45371 Mdot
.85 .45451 Mdot
.85 .45604 Mdot
.85 .45621 Mdot
.85 .45683 Mdot
.85 .45717 Mdot
.85 .45746 Mdot
.85 .4584 Mdot
.85 .45898 Mdot
.85 .45917 Mdot
.85 .4601 Mdot
.85 .46035 Mdot
.85 .46053 Mdot
.85 .46175 Mdot
.85 .46197 Mdot
.85 .46217 Mdot
.85 .46231 Mdot
.85 .46235 Mdot
.85 .46264 Mdot
.85 .46269 Mdot
.85 .46295 Mdot
.85 .46376 Mdot
.85 .46391 Mdot
.85 .46469 Mdot
.85 .4661 Mdot
.85 .46616 Mdot
.85 .46648 Mdot
.85 .46704 Mdot
.85 .4676 Mdot
.85 .46811 Mdot
.85 .46862 Mdot
.85 .46916 Mdot
.85 .46935 Mdot
.85 .46971 Mdot
.85 .4709 Mdot
.85 .47103 Mdot
.85 .47164 Mdot
.85 .47185 Mdot
.85 .47186 Mdot
.85 .47193 Mdot
.85 .4728 Mdot
.85 .47292 Mdot
.85 .47303 Mdot
.85 .47318 Mdot
.85 .47327 Mdot
.85 .47363 Mdot
.85 .47396 Mdot
.85 .47423 Mdot
.85 .47459 Mdot
.85 .47477 Mdot
.85 .47505 Mdot
.85 .47699 Mdot
.85 .4771 Mdot
.85 .47762 Mdot
.85 .47883 Mdot
.85 .4795 Mdot
.85 .47964 Mdot
.85 .47982 Mdot
.85 .48028 Mdot
.85 .48058 Mdot
.85 .48071 Mdot
.85 .48151 Mdot
.85 .48153 Mdot
.85 .48215 Mdot
.85 .48556 Mdot
.85 .48615 Mdot
.85 .48666 Mdot
.85 .48667 Mdot
.85 .48687 Mdot
.85 .48689 Mdot
.85 .4875 Mdot
.85 .48752 Mdot
.85 .48795 Mdot
.85 .48809 Mdot
.85 .48902 Mdot
.85 .48902 Mdot
.85 .48917 Mdot
.85 .48919 Mdot
.85 .48921 Mdot
.85 .49002 Mdot
.85 .49068 Mdot
.85 .49262 Mdot
.85 .49306 Mdot
.85 .4931 Mdot
.85 .49327 Mdot
.85 .49328 Mdot
.85 .49445 Mdot
.85 .49467 Mdot
.85 .49558 Mdot
.85 .49559 Mdot
.85 .49611 Mdot
.85 .49675 Mdot
.85 .5 Mdot
.85 .5002 Mdot
.85 .50041 Mdot
.85 .50088 Mdot
.85 .501 Mdot
.85 .50114 Mdot
.85 .50119 Mdot
.85 .50174 Mdot
.85 .50291 Mdot
.85 .50332 Mdot
.85 .50418 Mdot
.85 .50465 Mdot
.85 .50577 Mdot
.85 .50594 Mdot
.85 .50601 Mdot
.85 .50619 Mdot
.85 .50629 Mdot
.85 .50773 Mdot
.85 .50789 Mdot
.85 .50903 Mdot
.85 .50935 Mdot
.85 .50958 Mdot
.85 .5097 Mdot
.85 .50993 Mdot
.85 .511 Mdot
.85 .51242 Mdot
.85 .51392 Mdot
.85 .51449 Mdot
.85 .5146 Mdot
.85 .51489 Mdot
.85 .51602 Mdot
.85 .51644 Mdot
.85 .51664 Mdot
.85 .51674 Mdot
.85 .51725 Mdot
.85 .5173 Mdot
.85 .51747 Mdot
.85 .5175 Mdot
.85 .51767 Mdot
.85 .51914 Mdot
.85 .52 Mdot
.85 .52033 Mdot
.85 .52063 Mdot
.85 .52106 Mdot
.85 .52107 Mdot
.85 .52131 Mdot
.85 .52231 Mdot
.85 .52324 Mdot
.85 .52401 Mdot
.85 .52499 Mdot
.85 .52551 Mdot
.85 .52594 Mdot
.85 .52625 Mdot
.85 .52811 Mdot
.85 .52999 Mdot
.85 .53077 Mdot
.85 .5315 Mdot
.85 .53177 Mdot
.85 .53297 Mdot
.85 .53315 Mdot
.85 .53371 Mdot
.85 .53436 Mdot
.85 .53561 Mdot
.85 .53629 Mdot
.85 .53762 Mdot
.85 .53799 Mdot
.85 .53834 Mdot
.85 .53869 Mdot
.85 .53879 Mdot
.85 .5389 Mdot
.85 .5391 Mdot
.85 .53992 Mdot
.85 .54066 Mdot
.85 .54099 Mdot
.85 .54293 Mdot
.85 .54299 Mdot
.85 .54446 Mdot
.85 .54547 Mdot
.85 .54652 Mdot
.85 .54877 Mdot
.85 .54884 Mdot
.85 .54893 Mdot
.85 .5504 Mdot
.85 .55052 Mdot
.85 .55118 Mdot
.85 .55176 Mdot
.85 .55209 Mdot
.85 .55224 Mdot
.85 .55237 Mdot
.85 .55325 Mdot
.85 .55335 Mdot
.85 .55354 Mdot
.85 .55382 Mdot
.85 .55433 Mdot
.85 .55462 Mdot
.85 .55465 Mdot
.85 .55494 Mdot
.85 .55506 Mdot
.85 .5551 Mdot
.85 .55531 Mdot
.85 .5563 Mdot
.85 .55638 Mdot
.85 .55642 Mdot
.85 .5573 Mdot
.85 .55733 Mdot
.85 .55739 Mdot
.85 .55744 Mdot
.85 .5575 Mdot
.85 .55757 Mdot
.85 .55758 Mdot
.85 .55761 Mdot
.85 .5578 Mdot
.85 .55785 Mdot
.85 .55796 Mdot
.85 .55829 Mdot
.85 .55838 Mdot
.85 .55875 Mdot
.85 .5588 Mdot
.85 .55919 Mdot
.85 .55921 Mdot
.85 .55939 Mdot
.85 .5594 Mdot
.85 .55945 Mdot
.85 .55946 Mdot
.85 .55975 Mdot
.85 .55978 Mdot
.85 .55982 Mdot
.85 .56026 Mdot
.85 .56047 Mdot
.85 .56074 Mdot
.85 .5609 Mdot
.85 .56097 Mdot
.85 .56139 Mdot
.85 .56159 Mdot
.85 .56168 Mdot
.85 .56185 Mdot
.85 .5621 Mdot
.85 .56211 Mdot
.85 .56218 Mdot
.85 .56233 Mdot
.85 .56245 Mdot
.85 .56263 Mdot
.85 .56274 Mdot
.85 .56296 Mdot
.85 .56304 Mdot
.85 .56305 Mdot
.85 .56342 Mdot
.85 .56358 Mdot
.85 .56364 Mdot
.85 .56373 Mdot
.85 .56382 Mdot
.85 .56429 Mdot
.85 .56452 Mdot
.85 .56487 Mdot
.85 .56489 Mdot
.85 .565 Mdot
.85 .56522 Mdot
.85 .56561 Mdot
.85 .56564 Mdot
.85 .56593 Mdot
.85 .56608 Mdot
.85 .5661 Mdot
.85 .56613 Mdot
.85 .56629 Mdot
.85 .56646 Mdot
.85 .56673 Mdot
.85 .56688 Mdot
.85 .56695 Mdot
.85 .56724 Mdot
.85 .56726 Mdot
.85 .56741 Mdot
.85 .56761 Mdot
.85 .56836 Mdot
.85 .56865 Mdot
.85 .56889 Mdot
.85 .56905 Mdot
.85 .56919 Mdot
.85 .56942 Mdot
.85 .56954 Mdot
.85 .57077 Mdot
.85 .57079 Mdot
.85 .57098 Mdot
.85 .57099 Mdot
.85 .57135 Mdot
.85 .57143 Mdot
.85 .57158 Mdot
.85 .57177 Mdot
.85 .57195 Mdot
.85 .572 Mdot
.85 .57218 Mdot
.85 .57263 Mdot
.85 .57271 Mdot
.85 .57325 Mdot
.85 .57375 Mdot
.85 .57442 Mdot
.85 .5752 Mdot
.85 .57524 Mdot
.85 .57549 Mdot
.85 .5761 Mdot
.85 .5761 Mdot
.85 .57633 Mdot
.85 .57648 Mdot
.85 .57658 Mdot
.85 .57688 Mdot
.85 .57693 Mdot
.85 .57702 Mdot
.85 .57702 Mdot
.85 .57726 Mdot
.85 .57751 Mdot
.85 .57754 Mdot
.85 .57755 Mdot
.85 .57779 Mdot
.85 .57785 Mdot
.85 .57802 Mdot
.85 .57805 Mdot
.85 .57813 Mdot
.85 .57818 Mdot
.85 .57819 Mdot
.85 .57825 Mdot
.85 .57834 Mdot
.85 .57835 Mdot
.85 .57839 Mdot
.85 .5784 Mdot
.85 .57878 Mdot
.85 .57899 Mdot
.85 .57915 Mdot
.85 .57939 Mdot
.85 .57971 Mdot
.85 .57985 Mdot
.85 .57989 Mdot
.85 .58018 Mdot
.85 .58047 Mdot
.85 .58055 Mdot
.85 .58058 Mdot
.85 .58067 Mdot
.85 .58113 Mdot
.85 .58125 Mdot
.85 .58135 Mdot
.85 .58144 Mdot
.85 .58147 Mdot
.85 .58173 Mdot
.85 .58175 Mdot
.85 .58176 Mdot
.85 .58184 Mdot
.85 .5821 Mdot
.85 .58231 Mdot
.85 .58245 Mdot
.85 .58262 Mdot
.85 .58263 Mdot
.85 .58266 Mdot
.85 .58268 Mdot
.85 .5827 Mdot
.85 .58275 Mdot
.85 .5828 Mdot
.85 .58291 Mdot
.85 .58293 Mdot
.85 .58294 Mdot
.85 .583 Mdot
.85 .58309 Mdot
.85 .58309 Mdot
.85 .5832 Mdot
.85 .58326 Mdot
.85 .5834 Mdot
.85 .58351 Mdot
.85 .5836 Mdot
.85 .5838 Mdot
.85 .58381 Mdot
.85 .58386 Mdot
.85 .58389 Mdot
.85 .5839 Mdot
.85 .58399 Mdot
.85 .5843 Mdot
.85 .58434 Mdot
.85 .58444 Mdot
.85 .58447 Mdot
.85 .58456 Mdot
.85 .58462 Mdot
.85 .58466 Mdot
.85 .5847 Mdot
.85 .5847 Mdot
.85 .58475 Mdot
.85 .58478 Mdot
.85 .58479 Mdot
.85 .58484 Mdot
.85 .58487 Mdot
.85 .58493 Mdot
.85 .58494 Mdot
.85 .58495 Mdot
.85 .58496 Mdot
.85 .58502 Mdot
.85 .58502 Mdot
.85 .58503 Mdot
.85 .58509 Mdot
.85 .5851 Mdot
.85 .58513 Mdot
.85 .58513 Mdot
.85 .58516 Mdot
.85 .58518 Mdot
.85 .58519 Mdot
.85 .58526 Mdot
.85 .58527 Mdot
.85 .58529 Mdot
.85 .58534 Mdot
.85 .58544 Mdot
.85 .58544 Mdot
.85 .58546 Mdot
.85 .58551 Mdot
.85 .58555 Mdot
.85 .58556 Mdot
.85 .58561 Mdot
.85 .58564 Mdot
.85 .58564 Mdot
.85 .58565 Mdot
.85 .58565 Mdot
.85 .58566 Mdot
.852 .08034 Mdot
.852 .08034 Mdot
.852 .08035 Mdot
.852 .08037 Mdot
.852 .08037 Mdot
.852 .08042 Mdot
.852 .08043 Mdot
.852 .08044 Mdot
.852 .08047 Mdot
.852 .08056 Mdot
.852 .08058 Mdot
.852 .08074 Mdot
.852 .08084 Mdot
.852 .08086 Mdot
.852 .08091 Mdot
.852 .081 Mdot
.852 .08103 Mdot
.852 .08107 Mdot
.852 .08109 Mdot
.852 .08138 Mdot
.852 .08142 Mdot
.852 .08149 Mdot
.852 .0816 Mdot
.852 .08164 Mdot
.852 .08174 Mdot
.852 .08193 Mdot
.852 .08206 Mdot
.852 .08207 Mdot
.852 .0821 Mdot
.852 .08214 Mdot
.852 .08224 Mdot
.852 .08229 Mdot
.852 .08234 Mdot
.852 .08294 Mdot
.852 .08297 Mdot
.852 .08347 Mdot
.852 .08389 Mdot
.852 .08392 Mdot
.852 .08407 Mdot
.852 .08461 Mdot
.852 .08463 Mdot
.852 .08465 Mdot
.852 .08498 Mdot
.852 .08506 Mdot
.852 .08518 Mdot
.852 .08523 Mdot
.852 .0857 Mdot
.852 .08601 Mdot
.852 .08625 Mdot
.852 .08658 Mdot
.852 .08664 Mdot
.852 .08673 Mdot
.852 .0868 Mdot
.852 .08723 Mdot
.852 .08728 Mdot
.852 .08788 Mdot
.852 .08856 Mdot
.852 .08862 Mdot
.852 .08877 Mdot
.852 .08937 Mdot
.852 .08944 Mdot
.852 .08984 Mdot
.852 .08996 Mdot
.852 .08998 Mdot
.852 .09154 Mdot
.852 .0927 Mdot
.852 .09289 Mdot
.852 .0929 Mdot
.852 .09424 Mdot
.852 .09446 Mdot
.852 .09505 Mdot
.852 .09531 Mdot
.852 .09587 Mdot
.852 .09683 Mdot
.852 .09687 Mdot
.852 .09737 Mdot
.852 .09816 Mdot
.852 .0982 Mdot
.852 .09899 Mdot
.852 .10093 Mdot
.852 .10097 Mdot
.852 .10157 Mdot
.852 .10169 Mdot
.852 .10295 Mdot
.852 .10325 Mdot
.852 .10335 Mdot
.852 .10341 Mdot
.852 .10343 Mdot
.852 .10386 Mdot
.852 .10427 Mdot
.852 .1058 Mdot
.852 .1066 Mdot
.852 .1068 Mdot
.852 .10727 Mdot
.852 .10802 Mdot
.852 .10838 Mdot
.852 .10866 Mdot
.852 .10877 Mdot
.852 .10943 Mdot
.852 .10946 Mdot
.852 .10988 Mdot
.852 .11017 Mdot
.852 .11117 Mdot
.852 .11142 Mdot
.852 .11145 Mdot
.852 .11409 Mdot
.852 .11681 Mdot
.852 .11725 Mdot
.852 .11732 Mdot
.852 .11799 Mdot
.852 .12015 Mdot
.852 .12052 Mdot
.852 .12123 Mdot
.852 .12302 Mdot
.852 .12354 Mdot
.852 .12388 Mdot
.852 .12475 Mdot
.852 .12515 Mdot
.852 .12657 Mdot
.852 .1292 Mdot
.852 .13128 Mdot
.852 .13245 Mdot
.852 .13289 Mdot
.852 .13319 Mdot
.852 .13427 Mdot
.852 .13594 Mdot
.852 .13596 Mdot
.852 .13641 Mdot
.852 .13693 Mdot
.852 .13702 Mdot
.852 .13723 Mdot
.852 .13739 Mdot
.852 .13782 Mdot
.852 .1388 Mdot
.852 .1396 Mdot
.852 .14041 Mdot
.852 .14072 Mdot
.852 .14125 Mdot
.852 .14336 Mdot
.852 .14362 Mdot
.852 .14401 Mdot
.852 .1448 Mdot
.852 .14564 Mdot
.852 .14663 Mdot
.852 .14674 Mdot
.852 .14695 Mdot
.852 .14784 Mdot
.852 .148 Mdot
.852 .14835 Mdot
.852 .14839 Mdot
.852 .14939 Mdot
.852 .15078 Mdot
.852 .15109 Mdot
.852 .15154 Mdot
.852 .15508 Mdot
.852 .15563 Mdot
.852 .1562 Mdot
.852 .15641 Mdot
.852 .1565 Mdot
.852 .15739 Mdot
.852 .1575 Mdot
.852 .15887 Mdot
.852 .15966 Mdot
.852 .15972 Mdot
.852 .16043 Mdot
.852 .16356 Mdot
.852 .16374 Mdot
.852 .1653 Mdot
.852 .16594 Mdot
.852 .16859 Mdot
.852 .16895 Mdot
.852 .1694 Mdot
.852 .17016 Mdot
.852 .1705 Mdot
.852 .17077 Mdot
.852 .17083 Mdot
.852 .17193 Mdot
.852 .17321 Mdot
.852 .17351 Mdot
.852 .17431 Mdot
.852 .1747 Mdot
.852 .17558 Mdot
.852 .1762 Mdot
.852 .1765 Mdot
.852 .17761 Mdot
.852 .17808 Mdot
.852 .1782 Mdot
.852 .179 Mdot
.852 .1791 Mdot
.852 .17935 Mdot
.852 .1795 Mdot
.852 .17973 Mdot
.852 .18048 Mdot
.852 .18095 Mdot
.852 .18113 Mdot
.852 .18195 Mdot
.852 .18236 Mdot
.852 .18337 Mdot
.852 .18357 Mdot
.852 .18432 Mdot
.852 .18458 Mdot
.852 .18471 Mdot
.852 .18472 Mdot
.852 .18476 Mdot
.852 .18519 Mdot
.852 .18524 Mdot
.852 .18538 Mdot
.852 .18544 Mdot
.852 .18547 Mdot
.852 .18663 Mdot
.852 .18712 Mdot
.852 .18722 Mdot
.852 .19021 Mdot
.852 .1906 Mdot
.852 .1914 Mdot
.852 .19496 Mdot
.852 .19523 Mdot
.852 .19535 Mdot
.852 .1971 Mdot
.852 .19775 Mdot
.852 .19812 Mdot
.852 .19844 Mdot
.852 .19844 Mdot
.852 .19878 Mdot
.852 .20035 Mdot
.852 .20055 Mdot
.852 .20096 Mdot
.852 .20213 Mdot
.852 .20423 Mdot
.852 .20482 Mdot
.852 .20604 Mdot
.852 .20653 Mdot
.852 .2066 Mdot
.852 .20814 Mdot
.852 .2083 Mdot
.852 .21128 Mdot
.852 .213 Mdot
.852 .21373 Mdot
.852 .21487 Mdot
.852 .21813 Mdot
.852 .21897 Mdot
.852 .22034 Mdot
.852 .22054 Mdot
.852 .2207 Mdot
.852 .2208 Mdot
.852 .22277 Mdot
.852 .22403 Mdot
.852 .22411 Mdot
.852 .22627 Mdot
.852 .22793 Mdot
.852 .22859 Mdot
.852 .23017 Mdot
.852 .23144 Mdot
.852 .2318 Mdot
.852 .23463 Mdot
.852 .23482 Mdot
.852 .2355 Mdot
.852 .23776 Mdot
.852 .23904 Mdot
.852 .2393 Mdot
.852 .24065 Mdot
.852 .24105 Mdot
.852 .24106 Mdot
.852 .24108 Mdot
.852 .24113 Mdot
.852 .24114 Mdot
.852 .24129 Mdot
.852 .24131 Mdot
.852 .24135 Mdot
.852 .24144 Mdot
.852 .2417 Mdot
.852 .24177 Mdot
.852 .24212 Mdot
.852 .24226 Mdot
.852 .24255 Mdot
.852 .24261 Mdot
.852 .24278 Mdot
.852 .24304 Mdot
.852 .24312 Mdot
.852 .24326 Mdot
.852 .2433 Mdot
.852 .24362 Mdot
.852 .24418 Mdot
.852 .24429 Mdot
.852 .24451 Mdot
.852 .24482 Mdot
.852 .24497 Mdot
.852 .24525 Mdot
.852 .24582 Mdot
.852 .24623 Mdot
.852 .24625 Mdot
.852 .24635 Mdot
.852 .24647 Mdot
.852 .24675 Mdot
.852 .24691 Mdot
.852 .24705 Mdot
.852 .24827 Mdot
.852 .24886 Mdot
.852 .24892 Mdot
.852 .25012 Mdot
.852 .25039 Mdot
.852 .25041 Mdot
.852 .25072 Mdot
.852 .25125 Mdot
.852 .2513 Mdot
.852 .25168 Mdot
.852 .25176 Mdot
.852 .25199 Mdot
.852 .2522 Mdot
.852 .25362 Mdot
.852 .2538 Mdot
.852 .25387 Mdot
.852 .25393 Mdot
.852 .25449 Mdot
.852 .25491 Mdot
.852 .25513 Mdot
.852 .2555 Mdot
.852 .25559 Mdot
.852 .25564 Mdot
.852 .25674 Mdot
.852 .25691 Mdot
.852 .25702 Mdot
.852 .25793 Mdot
.852 .25864 Mdot
.852 .25962 Mdot
.852 .25969 Mdot
.852 .25979 Mdot
.852 .25983 Mdot
.852 .26006 Mdot
.852 .26026 Mdot
.852 .26103 Mdot
.852 .26153 Mdot
.852 .26167 Mdot
.852 .2634 Mdot
.852 .26538 Mdot
.852 .26558 Mdot
.852 .26602 Mdot
.852 .26619 Mdot
.852 .26775 Mdot
.852 .26795 Mdot
.852 .2691 Mdot
.852 .26946 Mdot
.852 .2695 Mdot
.852 .26974 Mdot
.852 .27126 Mdot
.852 .27281 Mdot
.852 .274 Mdot
.852 .27488 Mdot
.852 .27535 Mdot
.852 .27629 Mdot
.852 .27731 Mdot
.852 .27758 Mdot
.852 .27787 Mdot
.852 .27788 Mdot
.852 .27792 Mdot
.852 .278 Mdot
.852 .2782 Mdot
.852 .2796 Mdot
.852 .27962 Mdot
.852 .28169 Mdot
.852 .28231 Mdot
.852 .28274 Mdot
.852 .28399 Mdot
.852 .28421 Mdot
.852 .28472 Mdot
.852 .2863 Mdot
.852 .28896 Mdot
.852 .28898 Mdot
.852 .28911 Mdot
.852 .29043 Mdot
.852 .29051 Mdot
.852 .29207 Mdot
.852 .2927 Mdot
.852 .29282 Mdot
.852 .295 Mdot
.852 .29512 Mdot
.852 .29565 Mdot
.852 .29569 Mdot
.852 .29681 Mdot
.852 .29861 Mdot
.852 .30036 Mdot
.852 .30046 Mdot
.852 .30139 Mdot
.852 .30166 Mdot
.852 .3021 Mdot
.852 .30244 Mdot
.852 .30344 Mdot
.852 .30349 Mdot
.852 .30377 Mdot
.852 .30437 Mdot
.852 .30586 Mdot
.852 .30601 Mdot
.852 .30668 Mdot
.852 .30696 Mdot
.852 .30712 Mdot
.852 .30718 Mdot
.852 .30797 Mdot
.852 .30835 Mdot
.852 .30943 Mdot
.852 .31017 Mdot
.852 .31311 Mdot
.852 .31357 Mdot
.852 .3139 Mdot
.852 .31436 Mdot
.852 .31571 Mdot
.852 .31624 Mdot
.852 .31714 Mdot
.852 .31748 Mdot
.852 .3175 Mdot
.852 .3179 Mdot
.852 .31803 Mdot
.852 .31813 Mdot
.852 .31947 Mdot
.852 .32042 Mdot
.852 .32117 Mdot
.852 .32147 Mdot
.852 .32241 Mdot
.852 .32322 Mdot
.852 .32328 Mdot
.852 .32395 Mdot
.852 .32438 Mdot
.852 .32471 Mdot
.852 .32514 Mdot
.852 .32542 Mdot
.852 .32602 Mdot
.852 .32674 Mdot
.852 .32777 Mdot
.852 .32843 Mdot
.852 .3285 Mdot
.852 .33064 Mdot
.852 .33192 Mdot
.852 .33192 Mdot
.852 .33312 Mdot
.852 .33451 Mdot
.852 .33533 Mdot
.852 .33637 Mdot
.852 .33698 Mdot
.852 .33886 Mdot
.852 .33895 Mdot
.852 .34226 Mdot
.852 .34239 Mdot
.852 .34338 Mdot
.852 .34356 Mdot
.852 .34363 Mdot
.852 .34405 Mdot
.852 .3443 Mdot
.852 .34448 Mdot
.852 .34508 Mdot
.852 .34524 Mdot
.852 .35066 Mdot
.852 .35158 Mdot
.852 .35335 Mdot
.852 .35562 Mdot
.852 .35616 Mdot
.852 .35776 Mdot
.852 .3586 Mdot
.852 .35904 Mdot
.852 .35974 Mdot
.852 .35988 Mdot
.852 .36163 Mdot
.852 .36198 Mdot
.852 .36296 Mdot
.852 .36311 Mdot
.852 .36639 Mdot
.852 .37 Mdot
.852 .37267 Mdot
.852 .37424 Mdot
.852 .37445 Mdot
.852 .37486 Mdot
.852 .37672 Mdot
.852 .37755 Mdot
.852 .37758 Mdot
.852 .3786 Mdot
.852 .38019 Mdot
.852 .38031 Mdot
.852 .38089 Mdot
.852 .38111 Mdot
.852 .38123 Mdot
.852 .38133 Mdot
.852 .38133 Mdot
.852 .38144 Mdot
.852 .38196 Mdot
.852 .38202 Mdot
.852 .38216 Mdot
.852 .3838 Mdot
.852 .38395 Mdot
.852 .38398 Mdot
.852 .38447 Mdot
.852 .38452 Mdot
.852 .38546 Mdot
.852 .386 Mdot
.852 .3876 Mdot
.852 .38829 Mdot
.852 .38835 Mdot
.852 .3884 Mdot
.852 .38843 Mdot
.852 .38903 Mdot
.852 .38942 Mdot
.852 .3906 Mdot
.852 .3908 Mdot
.852 .39128 Mdot
.852 .39166 Mdot
.852 .39261 Mdot
.852 .39267 Mdot
.852 .39287 Mdot
.852 .39354 Mdot
.852 .3944 Mdot
.852 .39483 Mdot
.852 .39662 Mdot
.852 .39716 Mdot
.852 .39748 Mdot
.852 .39817 Mdot
.852 .39842 Mdot
.852 .39873 Mdot
.852 .39911 Mdot
.852 .39994 Mdot
.852 .40028 Mdot
.852 .40174 Mdot
.852 .40274 Mdot
.852 .40359 Mdot
.852 .40417 Mdot
.852 .40456 Mdot
.852 .40492 Mdot
.852 .40502 Mdot
.852 .40509 Mdot
.852 .40548 Mdot
.852 .40549 Mdot
.852 .40635 Mdot
.852 .40806 Mdot
.852 .40846 Mdot
.852 .4089 Mdot
.852 .40988 Mdot
.852 .41019 Mdot
.852 .41068 Mdot
.852 .412 Mdot
.852 .41208 Mdot
.852 .41224 Mdot
.852 .41268 Mdot
.852 .41459 Mdot
.852 .4148 Mdot
.852 .41492 Mdot
.852 .41566 Mdot
.852 .41576 Mdot
.852 .41587 Mdot
.852 .41593 Mdot
.852 .41787 Mdot
.852 .41803 Mdot
.852 .41822 Mdot
.852 .42077 Mdot
.852 .42143 Mdot
.852 .42145 Mdot
.852 .42236 Mdot
.852 .42287 Mdot
.852 .42291 Mdot
.852 .42585 Mdot
.852 .42599 Mdot
.852 .42693 Mdot
.852 .42963 Mdot
.852 .43075 Mdot
.852 .43162 Mdot
.852 .4319 Mdot
.852 .43232 Mdot
.852 .43251 Mdot
.852 .43262 Mdot
.852 .43386 Mdot
.852 .43428 Mdot
.852 .4345 Mdot
.852 .43562 Mdot
.852 .43585 Mdot
.852 .43681 Mdot
.852 .43723 Mdot
.852 .43803 Mdot
.852 .43879 Mdot
.852 .43891 Mdot
.852 .4403 Mdot
.852 .4408 Mdot
.852 .44182 Mdot
.852 .4424 Mdot
.852 .44371 Mdot
.852 .44456 Mdot
.852 .44638 Mdot
.852 .44672 Mdot
.852 .44892 Mdot
.852 .44968 Mdot
.852 .4509 Mdot
.852 .45314 Mdot
.852 .45541 Mdot
.852 .45585 Mdot
.852 .45653 Mdot
.852 .45683 Mdot
.852 .45735 Mdot
.852 .45876 Mdot
.852 .45937 Mdot
.852 .45986 Mdot
.852 .45997 Mdot
.852 .46086 Mdot
.852 .46147 Mdot
.852 .46197 Mdot
.852 .46427 Mdot
.852 .46473 Mdot
.852 .4648 Mdot
.852 .46623 Mdot
.852 .46625 Mdot
.852 .46693 Mdot
.852 .46847 Mdot
.852 .46856 Mdot
.852 .46956 Mdot
.852 .46959 Mdot
.852 .47009 Mdot
.852 .47137 Mdot
.852 .47202 Mdot
.852 .47224 Mdot
.852 .47284 Mdot
.852 .47305 Mdot
.852 .47442 Mdot
.852 .4746 Mdot
.852 .47463 Mdot
.852 .47484 Mdot
.852 .47502 Mdot
.852 .47528 Mdot
.852 .47567 Mdot
.852 .47613 Mdot
.852 .47694 Mdot
.852 .47749 Mdot
.852 .47774 Mdot
.852 .47805 Mdot
.852 .47819 Mdot
.852 .47942 Mdot
.852 .4798 Mdot
.852 .4801 Mdot
.852 .48019 Mdot
.852 .4818 Mdot
.852 .48206 Mdot
.852 .48212 Mdot
.852 .48242 Mdot
.852 .48312 Mdot
.852 .48335 Mdot
.852 .48379 Mdot
.852 .484 Mdot
.852 .48401 Mdot
.852 .48408 Mdot
.852 .48479 Mdot
.852 .48487 Mdot
.852 .48509 Mdot
.852 .48514 Mdot
.852 .48519 Mdot
.852 .48524 Mdot
.852 .48533 Mdot
.852 .48563 Mdot
.852 .48631 Mdot
.852 .48676 Mdot
.852 .48711 Mdot
.852 .48791 Mdot
.852 .48808 Mdot
.852 .48817 Mdot
.852 .48995 Mdot
.852 .49282 Mdot
.852 .49343 Mdot
.852 .4942 Mdot
.852 .49467 Mdot
.852 .49566 Mdot
.852 .49588 Mdot
.852 .50011 Mdot
.852 .50035 Mdot
.852 .50042 Mdot
.852 .50052 Mdot
.852 .50069 Mdot
.852 .50118 Mdot
.852 .50253 Mdot
.852 .50256 Mdot
.852 .5033 Mdot
.852 .50354 Mdot
.852 .50426 Mdot
.852 .5048 Mdot
.852 .50526 Mdot
.852 .50526 Mdot
.852 .50576 Mdot
.852 .50725 Mdot
.852 .50753 Mdot
.852 .50776 Mdot
.852 .50803 Mdot
.852 .50832 Mdot
.852 .5089 Mdot
.852 .51052 Mdot
.852 .51056 Mdot
.852 .51061 Mdot
.852 .51076 Mdot
.852 .51089 Mdot
.852 .51193 Mdot
.852 .51211 Mdot
.852 .5124 Mdot
.852 .51349 Mdot
.852 .51431 Mdot
.852 .51503 Mdot
.852 .51563 Mdot
.852 .51585 Mdot
.852 .51596 Mdot
.852 .51597 Mdot
.852 .51663 Mdot
.852 .51672 Mdot
.852 .51774 Mdot
.852 .51839 Mdot
.852 .5188 Mdot
.852 .51881 Mdot
.852 .519 Mdot
.852 .5201 Mdot
.852 .52069 Mdot
.852 .52121 Mdot
.852 .5229 Mdot
.852 .52342 Mdot
.852 .52452 Mdot
.852 .52453 Mdot
.852 .52502 Mdot
.852 .5251 Mdot
.852 .52512 Mdot
.852 .52524 Mdot
.852 .52569 Mdot
.852 .52602 Mdot
.852 .52619 Mdot
.852 .52691 Mdot
.852 .52745 Mdot
.852 .52797 Mdot
.852 .5292 Mdot
.852 .53097 Mdot
.852 .53138 Mdot
.852 .53142 Mdot
.852 .53237 Mdot
.852 .53243 Mdot
.852 .53282 Mdot
.852 .53319 Mdot
.852 .53349 Mdot
.852 .53404 Mdot
.852 .53427 Mdot
.852 .53428 Mdot
.852 .53446 Mdot
.852 .53457 Mdot
.852 .53466 Mdot
.852 .53528 Mdot
.852 .53684 Mdot
.852 .53734 Mdot
.852 .53782 Mdot
.852 .53827 Mdot
.852 .53836 Mdot
.852 .53878 Mdot
.852 .53953 Mdot
.852 .53975 Mdot
.852 .53981 Mdot
.852 .54074 Mdot
.852 .54086 Mdot
.852 .54127 Mdot
.852 .54179 Mdot
.852 .542 Mdot
.852 .54254 Mdot
.852 .54324 Mdot
.852 .54327 Mdot
.852 .54368 Mdot
.852 .54431 Mdot
.852 .54434 Mdot
.852 .5444 Mdot
.852 .54446 Mdot
.852 .5449 Mdot
.852 .54517 Mdot
.852 .54621 Mdot
.852 .54658 Mdot
.852 .54681 Mdot
.852 .54736 Mdot
.852 .5483 Mdot
.852 .54835 Mdot
.852 .54884 Mdot
.852 .54887 Mdot
.852 .54902 Mdot
.852 .5494 Mdot
.852 .54959 Mdot
.852 .55025 Mdot
.852 .55062 Mdot
.852 .55075 Mdot
.852 .55081 Mdot
.852 .5513 Mdot
.852 .55141 Mdot
.852 .55141 Mdot
.852 .55151 Mdot
.852 .55162 Mdot
.852 .55183 Mdot
.852 .55237 Mdot
.852 .55241 Mdot
.852 .55249 Mdot
.852 .5536 Mdot
.852 .55385 Mdot
.852 .55397 Mdot
.852 .55489 Mdot
.852 .55492 Mdot
.852 .55508 Mdot
.852 .55543 Mdot
.852 .55544 Mdot
.852 .55546 Mdot
.852 .5555 Mdot
.852 .55552 Mdot
.852 .55565 Mdot
.852 .55566 Mdot
.852 .55567 Mdot
.852 .55571 Mdot
.852 .55579 Mdot
.852 .55602 Mdot
.852 .55608 Mdot
.852 .55639 Mdot
.852 .55651 Mdot
.852 .55676 Mdot
.852 .55682 Mdot
.852 .55696 Mdot
.852 .55719 Mdot
.852 .55726 Mdot
.852 .55731 Mdot
.852 .55738 Mdot
.852 .55741 Mdot
.852 .55766 Mdot
.852 .55769 Mdot
.852 .55784 Mdot
.852 .55818 Mdot
.852 .55827 Mdot
.852 .55846 Mdot
.852 .55872 Mdot
.852 .55884 Mdot
.852 .55909 Mdot
.852 .55918 Mdot
.852 .55956 Mdot
.852 .5599 Mdot
.852 .55992 Mdot
.852 .56 Mdot
.852 .5601 Mdot
.852 .56033 Mdot
.852 .56046 Mdot
.852 .56057 Mdot
.852 .56137 Mdot
.852 .56156 Mdot
.852 .56203 Mdot
.852 .56208 Mdot
.852 .56302 Mdot
.852 .56323 Mdot
.852 .56325 Mdot
.852 .56348 Mdot
.852 .56389 Mdot
.852 .56393 Mdot
.852 .56419 Mdot
.852 .56422 Mdot
.852 .56428 Mdot
.852 .56445 Mdot
.852 .56461 Mdot
.852 .56566 Mdot
.852 .56579 Mdot
.852 .56589 Mdot
.852 .56629 Mdot
.852 .56659 Mdot
.852 .5666 Mdot
.852 .5667 Mdot
.852 .56675 Mdot
.852 .56701 Mdot
.852 .56707 Mdot
.852 .56711 Mdot
.852 .5674 Mdot
.852 .56764 Mdot
.852 .56787 Mdot
.852 .56799 Mdot
.852 .56807 Mdot
.852 .56868 Mdot
.852 .56884 Mdot
.852 .56893 Mdot
.852 .56916 Mdot
.852 .5694 Mdot
.852 .56968 Mdot
.852 .56981 Mdot
.852 .56985 Mdot
.852 .56992 Mdot
.852 .56994 Mdot
.852 .57009 Mdot
.852 .57022 Mdot
.852 .57023 Mdot
.852 .57071 Mdot
.852 .57103 Mdot
.852 .57111 Mdot
.852 .57124 Mdot
.852 .57158 Mdot
.852 .57218 Mdot
.852 .57293 Mdot
.852 .57334 Mdot
.852 .57346 Mdot
.852 .5737 Mdot
.852 .5738 Mdot
.852 .57395 Mdot
.852 .57446 Mdot
.852 .57467 Mdot
.852 .57477 Mdot
.852 .57539 Mdot
.852 .57558 Mdot
.852 .5756 Mdot
.852 .57572 Mdot
.852 .57649 Mdot
.852 .57724 Mdot
.852 .57725 Mdot
.852 .57732 Mdot
.852 .5776 Mdot
.852 .57769 Mdot
.852 .5778 Mdot
.852 .57781 Mdot
.852 .578 Mdot
.852 .57803 Mdot
.852 .57811 Mdot
.852 .57821 Mdot
.852 .57842 Mdot
.852 .57855 Mdot
.852 .57861 Mdot
.852 .57883 Mdot
.852 .57927 Mdot
.852 .57938 Mdot
.852 .5795 Mdot
.852 .5795 Mdot
.852 .57952 Mdot
.852 .57955 Mdot
.852 .57964 Mdot
.852 .57999 Mdot
.852 .58002 Mdot
.852 .58019 Mdot
.852 .5802 Mdot
.852 .58074 Mdot
.852 .58096 Mdot
.852 .58097 Mdot
.852 .58119 Mdot
.852 .58133 Mdot
.852 .58134 Mdot
.852 .58161 Mdot
.852 .58177 Mdot
.852 .58184 Mdot
.852 .582 Mdot
.852 .58206 Mdot
.852 .58244 Mdot
.852 .58244 Mdot
.852 .58249 Mdot
.852 .58281 Mdot
.852 .58325 Mdot
.852 .58325 Mdot
.852 .58328 Mdot
.852 .58339 Mdot
.852 .58341 Mdot
.852 .58358 Mdot
.852 .58362 Mdot
.852 .58364 Mdot
.852 .58383 Mdot
.852 .58399 Mdot
.852 .584 Mdot
.852 .58412 Mdot
.852 .58414 Mdot
.852 .58417 Mdot
.852 .58418 Mdot
.852 .58427 Mdot
.852 .58434 Mdot
.852 .58443 Mdot
.852 .58455 Mdot
.852 .58457 Mdot
.852 .5846 Mdot
.852 .58462 Mdot
.852 .58471 Mdot
.852 .58472 Mdot
.852 .58473 Mdot
.852 .58487 Mdot
.852 .58491 Mdot
.852 .58492 Mdot
.852 .58504 Mdot
.852 .58518 Mdot
.852 .58518 Mdot
.852 .58535 Mdot
.852 .58536 Mdot
.852 .58538 Mdot
.852 .5854 Mdot
.852 .58541 Mdot
.852 .58542 Mdot
.852 .58542 Mdot
.852 .58546 Mdot
.852 .58551 Mdot
.852 .58554 Mdot
.852 .58555 Mdot
.852 .58558 Mdot
.852 .5856 Mdot
.852 .58561 Mdot
.852 .58569 Mdot
.852 .5857 Mdot
.852 .58571 Mdot
.852 .58572 Mdot
.852 .58574 Mdot
.852 .58575 Mdot
.852 .58576 Mdot
.852 .58579 Mdot
.852 .58583 Mdot
.852 .58584 Mdot
.852 .58586 Mdot
.852 .58587 Mdot
.852 .58587 Mdot
.852 .58587 Mdot
.852 .58589 Mdot
.852 .58589 Mdot
.852 .58589 Mdot
.852 .5859 Mdot
.852 .5859 Mdot
.854 .07951 Mdot
.854 .07951 Mdot
.854 .07951 Mdot
.854 .07952 Mdot
.854 .07952 Mdot
.854 .07959 Mdot
.854 .0796 Mdot
.854 .07979 Mdot
.854 .07979 Mdot
.854 .07984 Mdot
.854 .08002 Mdot
.854 .08011 Mdot
.854 .08013 Mdot
.854 .08032 Mdot
.854 .08052 Mdot
.854 .08057 Mdot
.854 .08081 Mdot
.854 .08099 Mdot
.854 .08099 Mdot
.854 .08101 Mdot
.854 .08119 Mdot
.854 .0812 Mdot
.854 .08132 Mdot
.854 .08158 Mdot
.854 .08162 Mdot
.854 .08169 Mdot
.854 .08171 Mdot
.854 .08194 Mdot
.854 .08203 Mdot
.854 .08212 Mdot
.854 .08235 Mdot
.854 .08244 Mdot
.854 .08274 Mdot
.854 .08282 Mdot
.854 .08287 Mdot
.854 .08312 Mdot
.854 .08314 Mdot
.854 .08412 Mdot
.854 .08486 Mdot
.854 .08509 Mdot
.854 .08586 Mdot
.854 .08607 Mdot
.854 .08656 Mdot
.854 .08716 Mdot
.854 .08785 Mdot
.854 .08811 Mdot
.854 .08817 Mdot
.854 .089 Mdot
.854 .08998 Mdot
.854 .09154 Mdot
.854 .09155 Mdot
.854 .09168 Mdot
.854 .09172 Mdot
.854 .0919 Mdot
.854 .09223 Mdot
.854 .09256 Mdot
.854 .09269 Mdot
.854 .09355 Mdot
.854 .09459 Mdot
.854 .0953 Mdot
.854 .09557 Mdot
.854 .09594 Mdot
.854 .09594 Mdot
.854 .09718 Mdot
.854 .09729 Mdot
.854 .09783 Mdot
.854 .09982 Mdot
.854 .10002 Mdot
.854 .10025 Mdot
.854 .10032 Mdot
.854 .10067 Mdot
.854 .10335 Mdot
.854 .10377 Mdot
.854 .10387 Mdot
.854 .10395 Mdot
.854 .10534 Mdot
.854 .10654 Mdot
.854 .1068 Mdot
.854 .10699 Mdot
.854 .10701 Mdot
.854 .10719 Mdot
.854 .1073 Mdot
.854 .10763 Mdot
.854 .10782 Mdot
.854 .10845 Mdot
.854 .10848 Mdot
.854 .11077 Mdot
.854 .11258 Mdot
.854 .11529 Mdot
.854 .11627 Mdot
.854 .11705 Mdot
.854 .12161 Mdot
.854 .12404 Mdot
.854 .12437 Mdot
.854 .12536 Mdot
.854 .12621 Mdot
.854 .12622 Mdot
.854 .12649 Mdot
.854 .12683 Mdot
.854 .12697 Mdot
.854 .12801 Mdot
.854 .1284 Mdot
.854 .1303 Mdot
.854 .13045 Mdot
.854 .13153 Mdot
.854 .13165 Mdot
.854 .13185 Mdot
.854 .13209 Mdot
.854 .13231 Mdot
.854 .13236 Mdot
.854 .1324 Mdot
.854 .13249 Mdot
.854 .13272 Mdot
.854 .13282 Mdot
.854 .13462 Mdot
.854 .13503 Mdot
.854 .13576 Mdot
.854 .13657 Mdot
.854 .13791 Mdot
.854 .13831 Mdot
.854 .13886 Mdot
.854 .13982 Mdot
.854 .13988 Mdot
.854 .14019 Mdot
.854 .1403 Mdot
.854 .14118 Mdot
.854 .14131 Mdot
.854 .14306 Mdot
.854 .14407 Mdot
.854 .14539 Mdot
.854 .14556 Mdot
.854 .14613 Mdot
.854 .14667 Mdot
.854 .14829 Mdot
.854 .14885 Mdot
.854 .14918 Mdot
.854 .1498 Mdot
.854 .15016 Mdot
.854 .15072 Mdot
.854 .15287 Mdot
.854 .15318 Mdot
.854 .1533 Mdot
.854 .15373 Mdot
.854 .15396 Mdot
.854 .15403 Mdot
.854 .15423 Mdot
.854 .15444 Mdot
.854 .15529 Mdot
.854 .15568 Mdot
.854 .15777 Mdot
.854 .15862 Mdot
.854 .15878 Mdot
.854 .15893 Mdot
.854 .16007 Mdot
.854 .1606 Mdot
.854 .16124 Mdot
.854 .16134 Mdot
.854 .16143 Mdot
.854 .16144 Mdot
.854 .16338 Mdot
.854 .1638 Mdot
.854 .16438 Mdot
.854 .1652 Mdot
.854 .16537 Mdot
.854 .16672 Mdot
.854 .16679 Mdot
.854 .16754 Mdot
.854 .16773 Mdot
.854 .16946 Mdot
.854 .17018 Mdot
.854 .17046 Mdot
.854 .17089 Mdot
.854 .17282 Mdot
.854 .17293 Mdot
.854 .17355 Mdot
.854 .17391 Mdot
.854 .17488 Mdot
.854 .17607 Mdot
.854 .17689 Mdot
.854 .17709 Mdot
.854 .17712 Mdot
.854 .17718 Mdot
.854 .17874 Mdot
.854 .17889 Mdot
.854 .1789 Mdot
.854 .17892 Mdot
.854 .18025 Mdot
.854 .18035 Mdot
.854 .18046 Mdot
.854 .18131 Mdot
.854 .18253 Mdot
.854 .183 Mdot
.854 .1837 Mdot
.854 .18468 Mdot
.854 .18535 Mdot
.854 .18643 Mdot
.854 .18658 Mdot
.854 .18718 Mdot
.854 .18739 Mdot
.854 .1887 Mdot
.854 .18896 Mdot
.854 .1894 Mdot
.854 .18942 Mdot
.854 .18952 Mdot
.854 .19095 Mdot
.854 .19117 Mdot
.854 .19121 Mdot
.854 .19155 Mdot
.854 .19186 Mdot
.854 .19187 Mdot
.854 .19193 Mdot
.854 .19196 Mdot
.854 .19197 Mdot
.854 .19264 Mdot
.854 .19264 Mdot
.854 .19292 Mdot
.854 .19413 Mdot
.854 .19453 Mdot
.854 .19481 Mdot
.854 .19541 Mdot
.854 .19707 Mdot
.854 .19754 Mdot
.854 .19775 Mdot
.854 .1983 Mdot
.854 .19937 Mdot
.854 .20219 Mdot
.854 .2035 Mdot
.854 .20454 Mdot
.854 .20463 Mdot
.854 .20543 Mdot
.854 .21054 Mdot
.854 .21075 Mdot
.854 .21311 Mdot
.854 .21374 Mdot
.854 .2172 Mdot
.854 .2191 Mdot
.854 .22255 Mdot
.854 .22468 Mdot
.854 .22479 Mdot
.854 .22518 Mdot
.854 .22585 Mdot
.854 .22821 Mdot
.854 .22824 Mdot
.854 .23181 Mdot
.854 .23261 Mdot
.854 .23449 Mdot
.854 .23485 Mdot
.854 .23527 Mdot
.854 .23619 Mdot
.854 .23654 Mdot
.854 .23831 Mdot
.854 .23863 Mdot
.854 .23863 Mdot
.854 .23864 Mdot
.854 .23866 Mdot
.854 .23867 Mdot
.854 .23888 Mdot
.854 .2389 Mdot
.854 .23948 Mdot
.854 .23949 Mdot
.854 .23964 Mdot
.854 .24017 Mdot
.854 .24045 Mdot
.854 .2405 Mdot
.854 .24109 Mdot
.854 .24167 Mdot
.854 .24183 Mdot
.854 .24255 Mdot
.854 .24259 Mdot
.854 .24309 Mdot
.854 .2431 Mdot
.854 .24316 Mdot
.854 .2437 Mdot
.854 .24373 Mdot
.854 .24381 Mdot
.854 .2441 Mdot
.854 .24487 Mdot
.854 .245 Mdot
.854 .24522 Mdot
.854 .24526 Mdot
.854 .24596 Mdot
.854 .24622 Mdot
.854 .24648 Mdot
.854 .24718 Mdot
.854 .24746 Mdot
.854 .24748 Mdot
.854 .24799 Mdot
.854 .24835 Mdot
.854 .24857 Mdot
.854 .24873 Mdot
.854 .24946 Mdot
.854 .24954 Mdot
.854 .24979 Mdot
.854 .24999 Mdot
.854 .25043 Mdot
.854 .25246 Mdot
.854 .2528 Mdot
.854 .25366 Mdot
.854 .25403 Mdot
.854 .25465 Mdot
.854 .25532 Mdot
.854 .25578 Mdot
.854 .25758 Mdot
.854 .25802 Mdot
.854 .2582 Mdot
.854 .25864 Mdot
.854 .25966 Mdot
.854 .26002 Mdot
.854 .26053 Mdot
.854 .26136 Mdot
.854 .2614 Mdot
.854 .26159 Mdot
.854 .26169 Mdot
.854 .26246 Mdot
.854 .26343 Mdot
.854 .26418 Mdot
.854 .26435 Mdot
.854 .26679 Mdot
.854 .26961 Mdot
.854 .2741 Mdot
.854 .27412 Mdot
.854 .27451 Mdot
.854 .27463 Mdot
.854 .27483 Mdot
.854 .2749 Mdot
.854 .27515 Mdot
.854 .27531 Mdot
.854 .27608 Mdot
.854 .27704 Mdot
.854 .27711 Mdot
.854 .27739 Mdot
.854 .27924 Mdot
.854 .27954 Mdot
.854 .2797 Mdot
.854 .27985 Mdot
.854 .28175 Mdot
.854 .2828 Mdot
.854 .28333 Mdot
.854 .2848 Mdot
.854 .28556 Mdot
.854 .28567 Mdot
.854 .28645 Mdot
.854 .28661 Mdot
.854 .28662 Mdot
.854 .28813 Mdot
.854 .29009 Mdot
.854 .29038 Mdot
.854 .29188 Mdot
.854 .29378 Mdot
.854 .29517 Mdot
.854 .29677 Mdot
.854 .29742 Mdot
.854 .29797 Mdot
.854 .29861 Mdot
.854 .29879 Mdot
.854 .29965 Mdot
.854 .29974 Mdot
.854 .30255 Mdot
.854 .30319 Mdot
.854 .30394 Mdot
.854 .30401 Mdot
.854 .30441 Mdot
.854 .30528 Mdot
.854 .30707 Mdot
.854 .30713 Mdot
.854 .30822 Mdot
.854 .30825 Mdot
.854 .30848 Mdot
.854 .30861 Mdot
.854 .3087 Mdot
.854 .31245 Mdot
.854 .31247 Mdot
.854 .31566 Mdot
.854 .31637 Mdot
.854 .31685 Mdot
.854 .31686 Mdot
.854 .31691 Mdot
.854 .31738 Mdot
.854 .3174 Mdot
.854 .31769 Mdot
.854 .31855 Mdot
.854 .31858 Mdot
.854 .31907 Mdot
.854 .31988 Mdot
.854 .32074 Mdot
.854 .32084 Mdot
.854 .3213 Mdot
.854 .32394 Mdot
.854 .32527 Mdot
.854 .32553 Mdot
.854 .32686 Mdot
.854 .328 Mdot
.854 .32891 Mdot
.854 .33155 Mdot
.854 .33176 Mdot
.854 .33205 Mdot
.854 .33412 Mdot
.854 .33493 Mdot
.854 .33523 Mdot
.854 .33621 Mdot
.854 .3367 Mdot
.854 .33854 Mdot
.854 .34104 Mdot
.854 .343 Mdot
.854 .34302 Mdot
.854 .3453 Mdot
.854 .34635 Mdot
.854 .34788 Mdot
.854 .34885 Mdot
.854 .35247 Mdot
.854 .35264 Mdot
.854 .35313 Mdot
.854 .35355 Mdot
.854 .35355 Mdot
.854 .35391 Mdot
.854 .35442 Mdot
.854 .3555 Mdot
.854 .35608 Mdot
.854 .35614 Mdot
.854 .35623 Mdot
.854 .35647 Mdot
.854 .35648 Mdot
.854 .35652 Mdot
.854 .35768 Mdot
.854 .35897 Mdot
.854 .35914 Mdot
.854 .35981 Mdot
.854 .35996 Mdot
.854 .36039 Mdot
.854 .3612 Mdot
.854 .36163 Mdot
.854 .36218 Mdot
.854 .36249 Mdot
.854 .36361 Mdot
.854 .36374 Mdot
.854 .36414 Mdot
.854 .36535 Mdot
.854 .3654 Mdot
.854 .36567 Mdot
.854 .36569 Mdot
.854 .36577 Mdot
.854 .36585 Mdot
.854 .36619 Mdot
.854 .36634 Mdot
.854 .36716 Mdot
.854 .36749 Mdot
.854 .36755 Mdot
.854 .36853 Mdot
.854 .36856 Mdot
.854 .36998 Mdot
.854 .37092 Mdot
.854 .37192 Mdot
.854 .37351 Mdot
.854 .3743 Mdot
.854 .37493 Mdot
.854 .37541 Mdot
.854 .37577 Mdot
.854 .3766 Mdot
.854 .37717 Mdot
.854 .37779 Mdot
.854 .37831 Mdot
.854 .37858 Mdot
.854 .37906 Mdot
.854 .37926 Mdot
.854 .37963 Mdot
.854 .37963 Mdot
.854 .38012 Mdot
.854 .38025 Mdot
.854 .38035 Mdot
.854 .38055 Mdot
.854 .38109 Mdot
.854 .38125 Mdot
.854 .38132 Mdot
.854 .38351 Mdot
.854 .3838 Mdot
.854 .38549 Mdot
.854 .38642 Mdot
.854 .3875 Mdot
.854 .38809 Mdot
.854 .38915 Mdot
.854 .38995 Mdot
.854 .39015 Mdot
.854 .39086 Mdot
.854 .39087 Mdot
.854 .39194 Mdot
.854 .39274 Mdot
.854 .39297 Mdot
.854 .39387 Mdot
.854 .39513 Mdot
.854 .39655 Mdot
.854 .3967 Mdot
.854 .39722 Mdot
.854 .39728 Mdot
.854 .3974 Mdot
.854 .39808 Mdot
.854 .39833 Mdot
.854 .39844 Mdot
.854 .39958 Mdot
.854 .39975 Mdot
.854 .40014 Mdot
.854 .40029 Mdot
.854 .40052 Mdot
.854 .40059 Mdot
.854 .40062 Mdot
.854 .40432 Mdot
.854 .40443 Mdot
.854 .40552 Mdot
.854 .4056 Mdot
.854 .40564 Mdot
.854 .40621 Mdot
.854 .40664 Mdot
.854 .40796 Mdot
.854 .4095 Mdot
.854 .40987 Mdot
.854 .41031 Mdot
.854 .41108 Mdot
.854 .41187 Mdot
.854 .41204 Mdot
.854 .41224 Mdot
.854 .41226 Mdot
.854 .41237 Mdot
.854 .4131 Mdot
.854 .4157 Mdot
.854 .41615 Mdot
.854 .41651 Mdot
.854 .41688 Mdot
.854 .41758 Mdot
.854 .41793 Mdot
.854 .41801 Mdot
.854 .4189 Mdot
.854 .41965 Mdot
.854 .42057 Mdot
.854 .42083 Mdot
.854 .42416 Mdot
.854 .42516 Mdot
.854 .42529 Mdot
.854 .42549 Mdot
.854 .42591 Mdot
.854 .42616 Mdot
.854 .42704 Mdot
.854 .42752 Mdot
.854 .42766 Mdot
.854 .42774 Mdot
.854 .42807 Mdot
.854 .42818 Mdot
.854 .4285 Mdot
.854 .42872 Mdot
.854 .42934 Mdot
.854 .43022 Mdot
.854 .43102 Mdot
.854 .43177 Mdot
.854 .43216 Mdot
.854 .43328 Mdot
.854 .43476 Mdot
.854 .43522 Mdot
.854 .43522 Mdot
.854 .43571 Mdot
.854 .43676 Mdot
.854 .4369 Mdot
.854 .43723 Mdot
.854 .43753 Mdot
.854 .4378 Mdot
.854 .43879 Mdot
.854 .43976 Mdot
.854 .44039 Mdot
.854 .44081 Mdot
.854 .44206 Mdot
.854 .44226 Mdot
.854 .44244 Mdot
.854 .44246 Mdot
.854 .44439 Mdot
.854 .44536 Mdot
.854 .44553 Mdot
.854 .4462 Mdot
.854 .4463 Mdot
.854 .44661 Mdot
.854 .44702 Mdot
.854 .44728 Mdot
.854 .44813 Mdot
.854 .44968 Mdot
.854 .44995 Mdot
.854 .45 Mdot
.854 .45022 Mdot
.854 .45255 Mdot
.854 .45269 Mdot
.854 .45409 Mdot
.854 .45444 Mdot
.854 .4546 Mdot
.854 .455 Mdot
.854 .45509 Mdot
.854 .45559 Mdot
.854 .45765 Mdot
.854 .45846 Mdot
.854 .45896 Mdot
.854 .45949 Mdot
.854 .46001 Mdot
.854 .46026 Mdot
.854 .46049 Mdot
.854 .46123 Mdot
.854 .46179 Mdot
.854 .46198 Mdot
.854 .46318 Mdot
.854 .46348 Mdot
.854 .46375 Mdot
.854 .46396 Mdot
.854 .46506 Mdot
.854 .46522 Mdot
.854 .46571 Mdot
.854 .46743 Mdot
.854 .46865 Mdot
.854 .46869 Mdot
.854 .46936 Mdot
.854 .46953 Mdot
.854 .47097 Mdot
.854 .47131 Mdot
.854 .47136 Mdot
.854 .47146 Mdot
.854 .47154 Mdot
.854 .47227 Mdot
.854 .47336 Mdot
.854 .47416 Mdot
.854 .47442 Mdot
.854 .47444 Mdot
.854 .47448 Mdot
.854 .47503 Mdot
.854 .47671 Mdot
.854 .47675 Mdot
.854 .47692 Mdot
.854 .4771 Mdot
.854 .47718 Mdot
.854 .47769 Mdot
.854 .47824 Mdot
.854 .47847 Mdot
.854 .47853 Mdot
.854 .48023 Mdot
.854 .48058 Mdot
.854 .48106 Mdot
.854 .48106 Mdot
.854 .48137 Mdot
.854 .48181 Mdot
.854 .48253 Mdot
.854 .48414 Mdot
.854 .48427 Mdot
.854 .48524 Mdot
.854 .48609 Mdot
.854 .48672 Mdot
.854 .48699 Mdot
.854 .48723 Mdot
.854 .48794 Mdot
.854 .48821 Mdot
.854 .48854 Mdot
.854 .48921 Mdot
.854 .49062 Mdot
.854 .49063 Mdot
.854 .49104 Mdot
.854 .4916 Mdot
.854 .49174 Mdot
.854 .49178 Mdot
.854 .49193 Mdot
.854 .49195 Mdot
.854 .49245 Mdot
.854 .49262 Mdot
.854 .49314 Mdot
.854 .49326 Mdot
.854 .49349 Mdot
.854 .49417 Mdot
.854 .49423 Mdot
.854 .49451 Mdot
.854 .49458 Mdot
.854 .4951 Mdot
.854 .49557 Mdot
.854 .49559 Mdot
.854 .4956 Mdot
.854 .49569 Mdot
.854 .49573 Mdot
.854 .49575 Mdot
.854 .49599 Mdot
.854 .49663 Mdot
.854 .49678 Mdot
.854 .49678 Mdot
.854 .49695 Mdot
.854 .49715 Mdot
.854 .49721 Mdot
.854 .49867 Mdot
.854 .49905 Mdot
.854 .49966 Mdot
.854 .50008 Mdot
.854 .50099 Mdot
.854 .50346 Mdot
.854 .50365 Mdot
.854 .50403 Mdot
.854 .50415 Mdot
.854 .50446 Mdot
.854 .50526 Mdot
.854 .50538 Mdot
.854 .50647 Mdot
.854 .50682 Mdot
.854 .50776 Mdot
.854 .50787 Mdot
.854 .50837 Mdot
.854 .50937 Mdot
.854 .50991 Mdot
.854 .51041 Mdot
.854 .51085 Mdot
.854 .51104 Mdot
.854 .51269 Mdot
.854 .51412 Mdot
.854 .51425 Mdot
.854 .51466 Mdot
.854 .51534 Mdot
.854 .51566 Mdot
.854 .51581 Mdot
.854 .51583 Mdot
.854 .51611 Mdot
.854 .51635 Mdot
.854 .5174 Mdot
.854 .51844 Mdot
.854 .51903 Mdot
.854 .51952 Mdot
.854 .52155 Mdot
.854 .52215 Mdot
.854 .52242 Mdot
.854 .52326 Mdot
.854 .52381 Mdot
.854 .52453 Mdot
.854 .52459 Mdot
.854 .5247 Mdot
.854 .52545 Mdot
.854 .52607 Mdot
.854 .52622 Mdot
.854 .52624 Mdot
.854 .53052 Mdot
.854 .53078 Mdot
.854 .53081 Mdot
.854 .53089 Mdot
.854 .53117 Mdot
.854 .53135 Mdot
.854 .53182 Mdot
.854 .53203 Mdot
.854 .53279 Mdot
.854 .53338 Mdot
.854 .5335 Mdot
.854 .5338 Mdot
.854 .53459 Mdot
.854 .53474 Mdot
.854 .53481 Mdot
.854 .53541 Mdot
.854 .53558 Mdot
.854 .53681 Mdot
.854 .53721 Mdot
.854 .53863 Mdot
.854 .53921 Mdot
.854 .53933 Mdot
.854 .53963 Mdot
.854 .53977 Mdot
.854 .53989 Mdot
.854 .5405 Mdot
.854 .54077 Mdot
.854 .54193 Mdot
.854 .54194 Mdot
.854 .54271 Mdot
.854 .54292 Mdot
.854 .54305 Mdot
.854 .54308 Mdot
.854 .54377 Mdot
.854 .54489 Mdot
.854 .54549 Mdot
.854 .5466 Mdot
.854 .5468 Mdot
.854 .54755 Mdot
.854 .54762 Mdot
.854 .54924 Mdot
.854 .54949 Mdot
.854 .54952 Mdot
.854 .54984 Mdot
.854 .55026 Mdot
.854 .55114 Mdot
.854 .55148 Mdot
.854 .55165 Mdot
.854 .55171 Mdot
.854 .55186 Mdot
.854 .55238 Mdot
.854 .55257 Mdot
.854 .55265 Mdot
.854 .55278 Mdot
.854 .55315 Mdot
.854 .55324 Mdot
.854 .55324 Mdot
.854 .55345 Mdot
.854 .55345 Mdot
.854 .55346 Mdot
.854 .55348 Mdot
.854 .55348 Mdot
.854 .55358 Mdot
.854 .55368 Mdot
.854 .5537 Mdot
.854 .55376 Mdot
.854 .5542 Mdot
.854 .55423 Mdot
.854 .55424 Mdot
.854 .55438 Mdot
.854 .55446 Mdot
.854 .55486 Mdot
.854 .55493 Mdot
.854 .55511 Mdot
.854 .55516 Mdot
.854 .55549 Mdot
.854 .5557 Mdot
.854 .556 Mdot
.854 .55621 Mdot
.854 .55636 Mdot
.854 .55673 Mdot
.854 .55699 Mdot
.854 .55702 Mdot
.854 .55705 Mdot
.854 .55746 Mdot
.854 .55747 Mdot
.854 .55747 Mdot
.854 .55752 Mdot
.854 .55799 Mdot
.854 .55801 Mdot
.854 .55802 Mdot
.854 .55808 Mdot
.854 .55833 Mdot
.854 .55869 Mdot
.854 .55898 Mdot
.854 .55909 Mdot
.854 .55928 Mdot
.854 .55932 Mdot
.854 .5599 Mdot
.854 .56003 Mdot
.854 .56011 Mdot
.854 .56033 Mdot
.854 .56085 Mdot
.854 .56091 Mdot
.854 .56113 Mdot
.854 .56115 Mdot
.854 .56156 Mdot
.854 .56161 Mdot
.854 .56186 Mdot
.854 .56203 Mdot
.854 .56216 Mdot
.854 .56274 Mdot
.854 .56274 Mdot
.854 .56277 Mdot
.854 .5628 Mdot
.854 .56299 Mdot
.854 .56315 Mdot
.854 .56348 Mdot
.854 .56353 Mdot
.854 .56358 Mdot
.854 .56383 Mdot
.854 .56445 Mdot
.854 .56457 Mdot
.854 .56482 Mdot
.854 .56488 Mdot
.854 .56494 Mdot
.854 .56496 Mdot
.854 .56503 Mdot
.854 .56516 Mdot
.854 .56519 Mdot
.854 .56528 Mdot
.854 .56592 Mdot
.854 .56608 Mdot
.854 .56619 Mdot
.854 .56637 Mdot
.854 .56647 Mdot
.854 .56663 Mdot
.854 .56711 Mdot
.854 .56727 Mdot
.854 .56744 Mdot
.854 .56749 Mdot
.854 .56787 Mdot
.854 .56817 Mdot
.854 .56868 Mdot
.854 .56872 Mdot
.854 .56898 Mdot
.854 .56901 Mdot
.854 .5691 Mdot
.854 .56911 Mdot
.854 .56939 Mdot
.854 .56956 Mdot
.854 .56967 Mdot
.854 .57006 Mdot
.854 .5703 Mdot
.854 .57051 Mdot
.854 .57062 Mdot
.854 .57115 Mdot
.854 .57117 Mdot
.854 .57124 Mdot
.854 .57127 Mdot
.854 .57128 Mdot
.854 .57129 Mdot
.854 .57136 Mdot
.854 .57143 Mdot
.854 .57148 Mdot
.854 .57152 Mdot
.854 .57183 Mdot
.854 .57187 Mdot
.854 .57242 Mdot
.854 .57253 Mdot
.854 .57283 Mdot
.854 .57287 Mdot
.854 .57297 Mdot
.854 .57305 Mdot
.854 .57305 Mdot
.854 .57329 Mdot
.854 .57358 Mdot
.854 .57367 Mdot
.854 .57437 Mdot
.854 .57567 Mdot
.854 .57589 Mdot
.854 .57617 Mdot
.854 .57694 Mdot
.854 .57744 Mdot
.854 .57809 Mdot
.854 .5781 Mdot
.854 .57828 Mdot
.854 .57833 Mdot
.854 .57842 Mdot
.854 .57845 Mdot
.854 .57851 Mdot
.854 .57851 Mdot
.854 .57856 Mdot
.854 .57864 Mdot
.854 .57897 Mdot
.854 .57936 Mdot
.854 .57939 Mdot
.854 .57941 Mdot
.854 .57953 Mdot
.854 .58028 Mdot
.854 .58038 Mdot
.854 .5804 Mdot
.854 .58046 Mdot
.854 .58052 Mdot
.854 .58108 Mdot
.854 .58123 Mdot
.854 .58125 Mdot
.854 .5816 Mdot
.854 .5816 Mdot
.854 .5817 Mdot
.854 .58178 Mdot
.854 .58197 Mdot
.854 .58226 Mdot
.854 .5825 Mdot
.854 .58254 Mdot
.854 .58263 Mdot
.854 .58272 Mdot
.854 .58277 Mdot
.854 .58278 Mdot
.854 .58282 Mdot
.854 .58282 Mdot
.854 .58325 Mdot
.854 .58352 Mdot
.854 .58375 Mdot
.854 .58377 Mdot
.854 .58384 Mdot
.854 .58403 Mdot
.854 .5842 Mdot
.854 .58433 Mdot
.854 .58439 Mdot
.854 .5846 Mdot
.854 .58466 Mdot
.854 .58487 Mdot
.854 .58514 Mdot
.854 .58514 Mdot
.854 .58521 Mdot
.854 .58523 Mdot
.854 .58525 Mdot
.854 .58533 Mdot
.854 .58535 Mdot
.854 .58542 Mdot
.854 .58544 Mdot
.854 .58547 Mdot
.854 .58553 Mdot
.854 .58553 Mdot
.854 .58555 Mdot
.854 .58556 Mdot
.854 .58564 Mdot
.854 .58567 Mdot
.854 .58567 Mdot
.854 .58572 Mdot
.854 .58573 Mdot
.854 .58573 Mdot
.854 .58578 Mdot
.854 .58584 Mdot
.854 .58586 Mdot
.854 .58591 Mdot
.854 .58596 Mdot
.854 .58597 Mdot
.854 .58599 Mdot
.854 .58604 Mdot
.854 .58605 Mdot
.854 .58605 Mdot
.854 .58611 Mdot
.854 .58611 Mdot
.854 .58613 Mdot
.854 .58613 Mdot
.854 .58613 Mdot
.854 .58613 Mdot
.854 .58613 Mdot
.856 .07867 Mdot
.856 .07867 Mdot
.856 .07867 Mdot
.856 .07873 Mdot
.856 .07875 Mdot
.856 .07877 Mdot
.856 .07878 Mdot
.856 .07899 Mdot
.856 .07902 Mdot
.856 .07906 Mdot
.856 .07909 Mdot
.856 .07909 Mdot
.856 .07914 Mdot
.856 .0794 Mdot
.856 .07947 Mdot
.856 .07948 Mdot
.856 .07969 Mdot
.856 .07987 Mdot
.856 .07996 Mdot
.856 .07998 Mdot
.856 .08006 Mdot
.856 .08012 Mdot
.856 .08037 Mdot
.856 .08038 Mdot
.856 .0805 Mdot
.856 .0809 Mdot
.856 .08103 Mdot
.856 .08142 Mdot
.856 .08182 Mdot
.856 .0824 Mdot
.856 .08249 Mdot
.856 .08251 Mdot
.856 .08268 Mdot
.856 .08289 Mdot
.856 .08308 Mdot
.856 .08316 Mdot
.856 .08343 Mdot
.856 .08359 Mdot
.856 .08378 Mdot
.856 .08474 Mdot
.856 .08477 Mdot
.856 .08491 Mdot
.856 .08537 Mdot
.856 .08558 Mdot
.856 .08568 Mdot
.856 .08571 Mdot
.856 .08586 Mdot
.856 .08596 Mdot
.856 .08648 Mdot
.856 .08662 Mdot
.856 .08682 Mdot
.856 .08688 Mdot
.856 .08726 Mdot
.856 .08777 Mdot
.856 .08872 Mdot
.856 .08914 Mdot
.856 .08917 Mdot
.856 .08919 Mdot
.856 .08945 Mdot
.856 .09008 Mdot
.856 .09086 Mdot
.856 .09138 Mdot
.856 .09196 Mdot
.856 .0928 Mdot
.856 .09317 Mdot
.856 .09586 Mdot
.856 .09612 Mdot
.856 .0978 Mdot
.856 .09785 Mdot
.856 .09795 Mdot
.856 .09822 Mdot
.856 .09824 Mdot
.856 .09871 Mdot
.856 .09941 Mdot
.856 .09942 Mdot
.856 .1004 Mdot
.856 .10094 Mdot
.856 .10134 Mdot
.856 .1019 Mdot
.856 .10254 Mdot
.856 .10344 Mdot
.856 .10401 Mdot
.856 .10467 Mdot
.856 .10476 Mdot
.856 .10556 Mdot
.856 .10557 Mdot
.856 .10616 Mdot
.856 .10664 Mdot
.856 .10727 Mdot
.856 .10829 Mdot
.856 .10884 Mdot
.856 .10897 Mdot
.856 .10908 Mdot
.856 .10937 Mdot
.856 .11006 Mdot
.856 .11043 Mdot
.856 .11079 Mdot
.856 .11085 Mdot
.856 .11097 Mdot
.856 .11134 Mdot
.856 .112 Mdot
.856 .11475 Mdot
.856 .11477 Mdot
.856 .11479 Mdot
.856 .11521 Mdot
.856 .11563 Mdot
.856 .11606 Mdot
.856 .11661 Mdot
.856 .11684 Mdot
.856 .1171 Mdot
.856 .11769 Mdot
.856 .11776 Mdot
.856 .11792 Mdot
.856 .1181 Mdot
.856 .11813 Mdot
.856 .11821 Mdot
.856 .11898 Mdot
.856 .11938 Mdot
.856 .11961 Mdot
.856 .11963 Mdot
.856 .1197 Mdot
.856 .11988 Mdot
.856 .11997 Mdot
.856 .12058 Mdot
.856 .12225 Mdot
.856 .12234 Mdot
.856 .12747 Mdot
.856 .12789 Mdot
.856 .12949 Mdot
.856 .13002 Mdot
.856 .13065 Mdot
.856 .13093 Mdot
.856 .1311 Mdot
.856 .13122 Mdot
.856 .13138 Mdot
.856 .13352 Mdot
.856 .13392 Mdot
.856 .13475 Mdot
.856 .13525 Mdot
.856 .13532 Mdot
.856 .13616 Mdot
.856 .13937 Mdot
.856 .13963 Mdot
.856 .14031 Mdot
.856 .14086 Mdot
.856 .14136 Mdot
.856 .14155 Mdot
.856 .14203 Mdot
.856 .14222 Mdot
.856 .14369 Mdot
.856 .14702 Mdot
.856 .14797 Mdot
.856 .14823 Mdot
.856 .14884 Mdot
.856 .14965 Mdot
.856 .15252 Mdot
.856 .15421 Mdot
.856 .15537 Mdot
.856 .15541 Mdot
.856 .15681 Mdot
.856 .15742 Mdot
.856 .15801 Mdot
.856 .15862 Mdot
.856 .15906 Mdot
.856 .15944 Mdot
.856 .1598 Mdot
.856 .16016 Mdot
.856 .1608 Mdot
.856 .16119 Mdot
.856 .16147 Mdot
.856 .16224 Mdot
.856 .16307 Mdot
.856 .16341 Mdot
.856 .16395 Mdot
.856 .16414 Mdot
.856 .16501 Mdot
.856 .16534 Mdot
.856 .16548 Mdot
.856 .16621 Mdot
.856 .16686 Mdot
.856 .16704 Mdot
.856 .16727 Mdot
.856 .1688 Mdot
.856 .16897 Mdot
.856 .17097 Mdot
.856 .17236 Mdot
.856 .17241 Mdot
.856 .17245 Mdot
.856 .1733 Mdot
.856 .17434 Mdot
.856 .17462 Mdot
.856 .17764 Mdot
.856 .17767 Mdot
.856 .17814 Mdot
.856 .17876 Mdot
.856 .17963 Mdot
.856 .18218 Mdot
.856 .18241 Mdot
.856 .18325 Mdot
.856 .18331 Mdot
.856 .18433 Mdot
.856 .18447 Mdot
.856 .18553 Mdot
.856 .18553 Mdot
.856 .18605 Mdot
.856 .18637 Mdot
.856 .18681 Mdot
.856 .18699 Mdot
.856 .18748 Mdot
.856 .1878 Mdot
.856 .18799 Mdot
.856 .18927 Mdot
.856 .18944 Mdot
.856 .19134 Mdot
.856 .19141 Mdot
.856 .19204 Mdot
.856 .19351 Mdot
.856 .19393 Mdot
.856 .19399 Mdot
.856 .1944 Mdot
.856 .19487 Mdot
.856 .19489 Mdot
.856 .19514 Mdot
.856 .19555 Mdot
.856 .19578 Mdot
.856 .19779 Mdot
.856 .19787 Mdot
.856 .19807 Mdot
.856 .19821 Mdot
.856 .19876 Mdot
.856 .19876 Mdot
.856 .19877 Mdot
.856 .20235 Mdot
.856 .20258 Mdot
.856 .2033 Mdot
.856 .20529 Mdot
.856 .20549 Mdot
.856 .20639 Mdot
.856 .20689 Mdot
.856 .20805 Mdot
.856 .21156 Mdot
.856 .21229 Mdot
.856 .21525 Mdot
.856 .2158 Mdot
.856 .22016 Mdot
.856 .22052 Mdot
.856 .22057 Mdot
.856 .22121 Mdot
.856 .222 Mdot
.856 .23187 Mdot
.856 .23472 Mdot
.856 .23502 Mdot
.856 .23618 Mdot
.856 .23618 Mdot
.856 .23618 Mdot
.856 .23636 Mdot
.856 .23641 Mdot
.856 .23647 Mdot
.856 .2365 Mdot
.856 .23716 Mdot
.856 .23723 Mdot
.856 .23737 Mdot
.856 .23745 Mdot
.856 .23746 Mdot
.856 .23761 Mdot
.856 .23839 Mdot
.856 .2386 Mdot
.856 .23862 Mdot
.856 .23926 Mdot
.856 .23932 Mdot
.856 .23981 Mdot
.856 .24009 Mdot
.856 .24015 Mdot
.856 .2404 Mdot
.856 .24058 Mdot
.856 .24134 Mdot
.856 .24136 Mdot
.856 .24173 Mdot
.856 .24292 Mdot
.856 .24331 Mdot
.856 .24447 Mdot
.856 .24515 Mdot
.856 .24568 Mdot
.856 .24647 Mdot
.856 .24742 Mdot
.856 .24769 Mdot
.856 .24774 Mdot
.856 .24786 Mdot
.856 .24826 Mdot
.856 .24846 Mdot
.856 .2489 Mdot
.856 .24944 Mdot
.856 .24969 Mdot
.856 .25011 Mdot
.856 .25028 Mdot
.856 .25051 Mdot
.856 .25074 Mdot
.856 .25097 Mdot
.856 .25152 Mdot
.856 .25154 Mdot
.856 .25381 Mdot
.856 .25438 Mdot
.856 .25449 Mdot
.856 .25488 Mdot
.856 .25626 Mdot
.856 .25688 Mdot
.856 .25697 Mdot
.856 .25717 Mdot
.856 .25725 Mdot
.856 .2577 Mdot
.856 .25799 Mdot
.856 .25811 Mdot
.856 .25951 Mdot
.856 .25992 Mdot
.856 .26052 Mdot
.856 .2607 Mdot
.856 .2618 Mdot
.856 .26202 Mdot
.856 .26231 Mdot
.856 .26331 Mdot
.856 .26351 Mdot
.856 .26607 Mdot
.856 .26693 Mdot
.856 .26724 Mdot
.856 .26728 Mdot
.856 .26738 Mdot
.856 .26742 Mdot
.856 .2682 Mdot
.856 .26831 Mdot
.856 .26875 Mdot
.856 .26889 Mdot
.856 .26931 Mdot
.856 .27002 Mdot
.856 .27226 Mdot
.856 .27247 Mdot
.856 .27375 Mdot
.856 .27543 Mdot
.856 .27783 Mdot
.856 .27886 Mdot
.856 .27956 Mdot
.856 .28007 Mdot
.856 .28043 Mdot
.856 .28203 Mdot
.856 .28223 Mdot
.856 .28649 Mdot
.856 .28722 Mdot
.856 .28857 Mdot
.856 .29174 Mdot
.856 .29192 Mdot
.856 .29207 Mdot
.856 .29233 Mdot
.856 .2931 Mdot
.856 .29315 Mdot
.856 .29446 Mdot
.856 .29496 Mdot
.856 .2951 Mdot
.856 .29537 Mdot
.856 .29641 Mdot
.856 .29644 Mdot
.856 .29914 Mdot
.856 .29941 Mdot
.856 .30062 Mdot
.856 .30126 Mdot
.856 .30171 Mdot
.856 .30324 Mdot
.856 .3046 Mdot
.856 .30499 Mdot
.856 .30537 Mdot
.856 .30693 Mdot
.856 .30744 Mdot
.856 .30899 Mdot
.856 .30922 Mdot
.856 .30926 Mdot
.856 .31078 Mdot
.856 .31101 Mdot
.856 .3128 Mdot
.856 .31318 Mdot
.856 .31319 Mdot
.856 .31451 Mdot
.856 .31477 Mdot
.856 .3155 Mdot
.856 .31606 Mdot
.856 .31638 Mdot
.856 .31661 Mdot
.856 .31743 Mdot
.856 .31773 Mdot
.856 .31968 Mdot
.856 .32044 Mdot
.856 .32145 Mdot
.856 .32191 Mdot
.856 .32225 Mdot
.856 .32253 Mdot
.856 .3233 Mdot
.856 .3251 Mdot
.856 .32608 Mdot
.856 .32642 Mdot
.856 .32703 Mdot
.856 .32718 Mdot
.856 .32742 Mdot
.856 .32749 Mdot
.856 .32791 Mdot
.856 .32847 Mdot
.856 .32988 Mdot
.856 .32992 Mdot
.856 .32993 Mdot
.856 .3302 Mdot
.856 .33202 Mdot
.856 .33255 Mdot
.856 .33329 Mdot
.856 .3336 Mdot
.856 .33729 Mdot
.856 .33733 Mdot
.856 .3374 Mdot
.856 .33761 Mdot
.856 .33847 Mdot
.856 .33954 Mdot
.856 .33982 Mdot
.856 .34063 Mdot
.856 .34123 Mdot
.856 .34161 Mdot
.856 .34204 Mdot
.856 .34209 Mdot
.856 .34261 Mdot
.856 .34298 Mdot
.856 .34328 Mdot
.856 .34367 Mdot
.856 .34462 Mdot
.856 .3447 Mdot
.856 .34476 Mdot
.856 .34494 Mdot
.856 .34534 Mdot
.856 .34581 Mdot
.856 .34587 Mdot
.856 .34609 Mdot
.856 .34647 Mdot
.856 .34802 Mdot
.856 .34804 Mdot
.856 .34826 Mdot
.856 .34849 Mdot
.856 .34902 Mdot
.856 .3496 Mdot
.856 .34964 Mdot
.856 .34982 Mdot
.856 .34988 Mdot
.856 .35028 Mdot
.856 .35049 Mdot
.856 .35062 Mdot
.856 .352 Mdot
.856 .35548 Mdot
.856 .35615 Mdot
.856 .35628 Mdot
.856 .35636 Mdot
.856 .35789 Mdot
.856 .35815 Mdot
.856 .3639 Mdot
.856 .36537 Mdot
.856 .36604 Mdot
.856 .36807 Mdot
.856 .36821 Mdot
.856 .36873 Mdot
.856 .36884 Mdot
.856 .36944 Mdot
.856 .36984 Mdot
.856 .37085 Mdot
.856 .37092 Mdot
.856 .371 Mdot
.856 .37163 Mdot
.856 .37285 Mdot
.856 .37287 Mdot
.856 .37319 Mdot
.856 .37366 Mdot
.856 .37474 Mdot
.856 .3749 Mdot
.856 .37542 Mdot
.856 .37638 Mdot
.856 .37704 Mdot
.856 .37709 Mdot
.856 .37745 Mdot
.856 .37774 Mdot
.856 .37811 Mdot
.856 .37828 Mdot
.856 .38013 Mdot
.856 .38027 Mdot
.856 .38029 Mdot
.856 .38309 Mdot
.856 .38395 Mdot
.856 .38402 Mdot
.856 .3843 Mdot
.856 .38446 Mdot
.856 .38483 Mdot
.856 .38593 Mdot
.856 .38708 Mdot
.856 .38725 Mdot
.856 .3886 Mdot
.856 .38871 Mdot
.856 .38872 Mdot
.856 .38892 Mdot
.856 .38916 Mdot
.856 .39213 Mdot
.856 .39298 Mdot
.856 .39307 Mdot
.856 .39433 Mdot
.856 .39642 Mdot
.856 .39699 Mdot
.856 .39765 Mdot
.856 .39853 Mdot
.856 .39943 Mdot
.856 .39975 Mdot
.856 .40085 Mdot
.856 .40094 Mdot
.856 .40128 Mdot
.856 .40232 Mdot
.856 .40262 Mdot
.856 .40274 Mdot
.856 .4029 Mdot
.856 .40378 Mdot
.856 .40588 Mdot
.856 .40598 Mdot
.856 .40642 Mdot
.856 .40821 Mdot
.856 .40907 Mdot
.856 .40994 Mdot
.856 .41005 Mdot
.856 .41316 Mdot
.856 .41377 Mdot
.856 .41379 Mdot
.856 .41519 Mdot
.856 .41575 Mdot
.856 .41596 Mdot
.856 .41656 Mdot
.856 .41703 Mdot
.856 .41835 Mdot
.856 .41861 Mdot
.856 .41874 Mdot
.856 .4213 Mdot
.856 .42188 Mdot
.856 .42235 Mdot
.856 .42271 Mdot
.856 .42416 Mdot
.856 .42472 Mdot
.856 .42621 Mdot
.856 .4282 Mdot
.856 .4293 Mdot
.856 .42933 Mdot
.856 .42947 Mdot
.856 .42966 Mdot
.856 .43003 Mdot
.856 .43007 Mdot
.856 .43056 Mdot
.856 .43064 Mdot
.856 .43246 Mdot
.856 .43347 Mdot
.856 .4336 Mdot
.856 .43469 Mdot
.856 .43473 Mdot
.856 .43587 Mdot
.856 .43621 Mdot
.856 .43709 Mdot
.856 .43756 Mdot
.856 .43796 Mdot
.856 .43848 Mdot
.856 .43872 Mdot
.856 .43942 Mdot
.856 .44012 Mdot
.856 .44138 Mdot
.856 .44139 Mdot
.856 .44197 Mdot
.856 .44213 Mdot
.856 .44261 Mdot
.856 .44268 Mdot
.856 .44357 Mdot
.856 .44379 Mdot
.856 .44418 Mdot
.856 .44559 Mdot
.856 .44578 Mdot
.856 .44579 Mdot
.856 .44644 Mdot
.856 .44675 Mdot
.856 .44747 Mdot
.856 .44784 Mdot
.856 .44809 Mdot
.856 .4489 Mdot
.856 .4495 Mdot
.856 .44956 Mdot
.856 .45006 Mdot
.856 .45012 Mdot
.856 .45039 Mdot
.856 .45131 Mdot
.856 .45167 Mdot
.856 .45177 Mdot
.856 .45188 Mdot
.856 .45206 Mdot
.856 .45272 Mdot
.856 .45299 Mdot
.856 .45334 Mdot
.856 .45376 Mdot
.856 .45446 Mdot
.856 .45496 Mdot
.856 .45507 Mdot
.856 .45599 Mdot
.856 .45611 Mdot
.856 .4566 Mdot
.856 .45693 Mdot
.856 .45723 Mdot
.856 .45871 Mdot
.856 .45917 Mdot
.856 .45985 Mdot
.856 .46059 Mdot
.856 .46115 Mdot
.856 .46172 Mdot
.856 .46291 Mdot
.856 .46293 Mdot
.856 .46311 Mdot
.856 .4632 Mdot
.856 .46327 Mdot
.856 .46328 Mdot
.856 .46479 Mdot
.856 .46579 Mdot
.856 .46648 Mdot
.856 .46666 Mdot
.856 .46688 Mdot
.856 .46716 Mdot
.856 .46845 Mdot
.856 .46857 Mdot
.856 .46942 Mdot
.856 .4697 Mdot
.856 .47072 Mdot
.856 .47073 Mdot
.856 .47246 Mdot
.856 .47251 Mdot
.856 .47292 Mdot
.856 .47332 Mdot
.856 .47414 Mdot
.856 .47438 Mdot
.856 .47534 Mdot
.856 .47574 Mdot
.856 .47587 Mdot
.856 .47663 Mdot
.856 .47732 Mdot
.856 .47811 Mdot
.856 .47959 Mdot
.856 .48015 Mdot
.856 .48019 Mdot
.856 .48057 Mdot
.856 .48198 Mdot
.856 .48207 Mdot
.856 .48207 Mdot
.856 .48212 Mdot
.856 .48376 Mdot
.856 .48392 Mdot
.856 .48399 Mdot
.856 .48414 Mdot
.856 .48572 Mdot
.856 .48573 Mdot
.856 .48579 Mdot
.856 .48658 Mdot
.856 .48709 Mdot
.856 .48779 Mdot
.856 .48808 Mdot
.856 .48874 Mdot
.856 .48887 Mdot
.856 .48888 Mdot
.856 .48939 Mdot
.856 .48966 Mdot
.856 .48969 Mdot
.856 .48972 Mdot
.856 .49031 Mdot
.856 .49061 Mdot
.856 .49083 Mdot
.856 .49088 Mdot
.856 .49172 Mdot
.856 .492 Mdot
.856 .49261 Mdot
.856 .49497 Mdot
.856 .49507 Mdot
.856 .49573 Mdot
.856 .49605 Mdot
.856 .49801 Mdot
.856 .49831 Mdot
.856 .49886 Mdot
.856 .49895 Mdot
.856 .49905 Mdot
.856 .49967 Mdot
.856 .50037 Mdot
.856 .5004 Mdot
.856 .50078 Mdot
.856 .50105 Mdot
.856 .5014 Mdot
.856 .50159 Mdot
.856 .50174 Mdot
.856 .50229 Mdot
.856 .50316 Mdot
.856 .50472 Mdot
.856 .50484 Mdot
.856 .50512 Mdot
.856 .50533 Mdot
.856 .50613 Mdot
.856 .50614 Mdot
.856 .50615 Mdot
.856 .50691 Mdot
.856 .50709 Mdot
.856 .50748 Mdot
.856 .50936 Mdot
.856 .51003 Mdot
.856 .51088 Mdot
.856 .51118 Mdot
.856 .51127 Mdot
.856 .5116 Mdot
.856 .51197 Mdot
.856 .51261 Mdot
.856 .51392 Mdot
.856 .51394 Mdot
.856 .51478 Mdot
.856 .51536 Mdot
.856 .51564 Mdot
.856 .51686 Mdot
.856 .51753 Mdot
.856 .51899 Mdot
.856 .51909 Mdot
.856 .51914 Mdot
.856 .5203 Mdot
.856 .52143 Mdot
.856 .52368 Mdot
.856 .52375 Mdot
.856 .52432 Mdot
.856 .52444 Mdot
.856 .52462 Mdot
.856 .5271 Mdot
.856 .5282 Mdot
.856 .52834 Mdot
.856 .52839 Mdot
.856 .52854 Mdot
.856 .52891 Mdot
.856 .52902 Mdot
.856 .53019 Mdot
.856 .5306 Mdot
.856 .5307 Mdot
.856 .53203 Mdot
.856 .53242 Mdot
.856 .53349 Mdot
.856 .53426 Mdot
.856 .53452 Mdot
.856 .53468 Mdot
.856 .53473 Mdot
.856 .53529 Mdot
.856 .53549 Mdot
.856 .53595 Mdot
.856 .53639 Mdot
.856 .53833 Mdot
.856 .53974 Mdot
.856 .53984 Mdot
.856 .54077 Mdot
.856 .54398 Mdot
.856 .54423 Mdot
.856 .54444 Mdot
.856 .54446 Mdot
.856 .54457 Mdot
.856 .54597 Mdot
.856 .54614 Mdot
.856 .54709 Mdot
.856 .54732 Mdot
.856 .54843 Mdot
.856 .5488 Mdot
.856 .54896 Mdot
.856 .54924 Mdot
.856 .54931 Mdot
.856 .54993 Mdot
.856 .55016 Mdot
.856 .55023 Mdot
.856 .55135 Mdot
.856 .55136 Mdot
.856 .55136 Mdot
.856 .55153 Mdot
.856 .55157 Mdot
.856 .55163 Mdot
.856 .55166 Mdot
.856 .55229 Mdot
.856 .55236 Mdot
.856 .55248 Mdot
.856 .55256 Mdot
.856 .55257 Mdot
.856 .55271 Mdot
.856 .55284 Mdot
.856 .55286 Mdot
.856 .55299 Mdot
.856 .55345 Mdot
.856 .55364 Mdot
.856 .55366 Mdot
.856 .55425 Mdot
.856 .55431 Mdot
.856 .5547 Mdot
.856 .55476 Mdot
.856 .55486 Mdot
.856 .55501 Mdot
.856 .55506 Mdot
.856 .5552 Mdot
.856 .5553 Mdot
.856 .55546 Mdot
.856 .55546 Mdot
.856 .55578 Mdot
.856 .55583 Mdot
.856 .55614 Mdot
.856 .55616 Mdot
.856 .55642 Mdot
.856 .55648 Mdot
.856 .55727 Mdot
.856 .55753 Mdot
.856 .55772 Mdot
.856 .55786 Mdot
.856 .55787 Mdot
.856 .55879 Mdot
.856 .55887 Mdot
.856 .55919 Mdot
.856 .55944 Mdot
.856 .55946 Mdot
.856 .55947 Mdot
.856 .55989 Mdot
.856 .56049 Mdot
.856 .56055 Mdot
.856 .56101 Mdot
.856 .56108 Mdot
.856 .56113 Mdot
.856 .56133 Mdot
.856 .56155 Mdot
.856 .56159 Mdot
.856 .56169 Mdot
.856 .56195 Mdot
.856 .562 Mdot
.856 .56217 Mdot
.856 .56227 Mdot
.856 .56252 Mdot
.856 .56275 Mdot
.856 .56283 Mdot
.856 .56294 Mdot
.856 .56314 Mdot
.856 .56324 Mdot
.856 .56335 Mdot
.856 .56346 Mdot
.856 .56359 Mdot
.856 .56378 Mdot
.856 .56395 Mdot
.856 .56413 Mdot
.856 .56455 Mdot
.856 .56456 Mdot
.856 .5649 Mdot
.856 .5654 Mdot
.856 .56625 Mdot
.856 .56649 Mdot
.856 .56667 Mdot
.856 .56675 Mdot
.856 .56702 Mdot
.856 .568 Mdot
.856 .56843 Mdot
.856 .56849 Mdot
.856 .56862 Mdot
.856 .56868 Mdot
.856 .56899 Mdot
.856 .56919 Mdot
.856 .56926 Mdot
.856 .57019 Mdot
.856 .57044 Mdot
.856 .57046 Mdot
.856 .5706 Mdot
.856 .57084 Mdot
.856 .57096 Mdot
.856 .57158 Mdot
.856 .57162 Mdot
.856 .57166 Mdot
.856 .57171 Mdot
.856 .57179 Mdot
.856 .57197 Mdot
.856 .57212 Mdot
.856 .57258 Mdot
.856 .5727 Mdot
.856 .57417 Mdot
.856 .5742 Mdot
.856 .57468 Mdot
.856 .57485 Mdot
.856 .57487 Mdot
.856 .57492 Mdot
.856 .57495 Mdot
.856 .57495 Mdot
.856 .57502 Mdot
.856 .57513 Mdot
.856 .57535 Mdot
.856 .57537 Mdot
.856 .57538 Mdot
.856 .57543 Mdot
.856 .57548 Mdot
.856 .5755 Mdot
.856 .57566 Mdot
.856 .57574 Mdot
.856 .5758 Mdot
.856 .57596 Mdot
.856 .57608 Mdot
.856 .5762 Mdot
.856 .57632 Mdot
.856 .57633 Mdot
.856 .57633 Mdot
.856 .57711 Mdot
.856 .5773 Mdot
.856 .5774 Mdot
.856 .57743 Mdot
.856 .57745 Mdot
.856 .57755 Mdot
.856 .57766 Mdot
.856 .57785 Mdot
.856 .57793 Mdot
.856 .57796 Mdot
.856 .578 Mdot
.856 .57816 Mdot
.856 .57844 Mdot
.856 .57862 Mdot
.856 .57876 Mdot
.856 .57892 Mdot
.856 .57892 Mdot
.856 .57915 Mdot
.856 .57917 Mdot
.856 .57936 Mdot
.856 .57952 Mdot
.856 .57977 Mdot
.856 .57995 Mdot
.856 .58011 Mdot
.856 .58022 Mdot
.856 .58037 Mdot
.856 .58064 Mdot
.856 .58064 Mdot
.856 .58084 Mdot
.856 .58097 Mdot
.856 .58098 Mdot
.856 .58105 Mdot
.856 .58108 Mdot
.856 .58109 Mdot
.856 .58156 Mdot
.856 .58163 Mdot
.856 .58238 Mdot
.856 .58248 Mdot
.856 .58271 Mdot
.856 .58288 Mdot
.856 .58302 Mdot
.856 .58323 Mdot
.856 .58341 Mdot
.856 .58348 Mdot
.856 .58348 Mdot
.856 .58349 Mdot
.856 .58361 Mdot
.856 .58387 Mdot
.856 .58401 Mdot
.856 .58412 Mdot
.856 .58413 Mdot
.856 .58419 Mdot
.856 .58423 Mdot
.856 .58437 Mdot
.856 .5844 Mdot
.856 .58444 Mdot
.856 .58445 Mdot
.856 .58447 Mdot
.856 .58453 Mdot
.856 .58466 Mdot
.856 .5847 Mdot
.856 .58471 Mdot
.856 .58497 Mdot
.856 .58502 Mdot
.856 .58506 Mdot
.856 .58509 Mdot
.856 .58514 Mdot
.856 .58516 Mdot
.856 .58521 Mdot
.856 .58527 Mdot
.856 .58532 Mdot
.856 .58532 Mdot
.856 .58535 Mdot
.856 .58551 Mdot
.856 .58562 Mdot
.856 .58572 Mdot
.856 .58576 Mdot
.856 .58587 Mdot
.856 .5859 Mdot
.856 .5859 Mdot
.856 .58597 Mdot
.856 .58599 Mdot
.856 .58601 Mdot
.856 .58602 Mdot
.856 .58604 Mdot
.856 .58609 Mdot
.856 .58615 Mdot
.856 .58615 Mdot
.856 .58617 Mdot
.856 .58624 Mdot
.856 .58625 Mdot
.856 .58625 Mdot
.856 .58626 Mdot
.856 .58627 Mdot
.856 .58628 Mdot
.856 .58634 Mdot
.856 .58634 Mdot
.856 .58635 Mdot
.856 .58635 Mdot
.856 .58637 Mdot
.856 .58637 Mdot
.856 .58637 Mdot
.858 .07784 Mdot
.858 .07785 Mdot
.858 .07785 Mdot
.858 .07785 Mdot
.858 .07785 Mdot
.858 .07787 Mdot
.858 .07787 Mdot
.858 .07789 Mdot
.858 .07791 Mdot
.858 .07795 Mdot
.858 .07797 Mdot
.858 .07798 Mdot
.858 .07798 Mdot
.858 .07801 Mdot
.858 .07808 Mdot
.858 .07811 Mdot
.858 .07815 Mdot
.858 .07818 Mdot
.858 .0782 Mdot
.858 .0782 Mdot
.858 .0782 Mdot
.858 .0783 Mdot
.858 .07836 Mdot
.858 .07841 Mdot
.858 .07848 Mdot
.858 .07855 Mdot
.858 .07856 Mdot
.858 .07856 Mdot
.858 .07858 Mdot
.858 .07859 Mdot
.858 .07864 Mdot
.858 .07869 Mdot
.858 .07872 Mdot
.858 .07873 Mdot
.858 .07886 Mdot
.858 .07887 Mdot
.858 .07889 Mdot
.858 .07894 Mdot
.858 .079 Mdot
.858 .07902 Mdot
.858 .07902 Mdot
.858 .07905 Mdot
.858 .07911 Mdot
.858 .07927 Mdot
.858 .07951 Mdot
.858 .07981 Mdot
.858 .07987 Mdot
.858 .07995 Mdot
.858 .08013 Mdot
.858 .08049 Mdot
.858 .08065 Mdot
.858 .08071 Mdot
.858 .08083 Mdot
.858 .08141 Mdot
.858 .08169 Mdot
.858 .08189 Mdot
.858 .08195 Mdot
.858 .08209 Mdot
.858 .08284 Mdot
.858 .08285 Mdot
.858 .08298 Mdot
.858 .08433 Mdot
.858 .08495 Mdot
.858 .08609 Mdot
.858 .08642 Mdot
.858 .08685 Mdot
.858 .08694 Mdot
.858 .0871 Mdot
.858 .08714 Mdot
.858 .08723 Mdot
.858 .0873 Mdot
.858 .08745 Mdot
.858 .08751 Mdot
.858 .08776 Mdot
.858 .08814 Mdot
.858 .08847 Mdot
.858 .08848 Mdot
.858 .08865 Mdot
.858 .08878 Mdot
.858 .0895 Mdot
.858 .09019 Mdot
.858 .09132 Mdot
.858 .09137 Mdot
.858 .09148 Mdot
.858 .09178 Mdot
.858 .09223 Mdot
.858 .0923 Mdot
.858 .09269 Mdot
.858 .09281 Mdot
.858 .09303 Mdot
.858 .09353 Mdot
.858 .09381 Mdot
.858 .09396 Mdot
.858 .096 Mdot
.858 .09635 Mdot
.858 .09672 Mdot
.858 .09692 Mdot
.858 .09695 Mdot
.858 .098 Mdot
.858 .09999 Mdot
.858 .10055 Mdot
.858 .10062 Mdot
.858 .10093 Mdot
.858 .10138 Mdot
.858 .1014 Mdot
.858 .10175 Mdot
.858 .10186 Mdot
.858 .10311 Mdot
.858 .1034 Mdot
.858 .1044 Mdot
.858 .10532 Mdot
.858 .10538 Mdot
.858 .10542 Mdot
.858 .10561 Mdot
.858 .10684 Mdot
.858 .10734 Mdot
.858 .10761 Mdot
.858 .10813 Mdot
.858 .10894 Mdot
.858 .10937 Mdot
.858 .11093 Mdot
.858 .11294 Mdot
.858 .11323 Mdot
.858 .11338 Mdot
.858 .11469 Mdot
.858 .11601 Mdot
.858 .11692 Mdot
.858 .11693 Mdot
.858 .11956 Mdot
.858 .12029 Mdot
.858 .12044 Mdot
.858 .12095 Mdot
.858 .12119 Mdot
.858 .12167 Mdot
.858 .12168 Mdot
.858 .12185 Mdot
.858 .12271 Mdot
.858 .12276 Mdot
.858 .12343 Mdot
.858 .12373 Mdot
.858 .12469 Mdot
.858 .12494 Mdot
.858 .12609 Mdot
.858 .12698 Mdot
.858 .12745 Mdot
.858 .12748 Mdot
.858 .12835 Mdot
.858 .12853 Mdot
.858 .1289 Mdot
.858 .12984 Mdot
.858 .12989 Mdot
.858 .13034 Mdot
.858 .13092 Mdot
.858 .13113 Mdot
.858 .13218 Mdot
.858 .1322 Mdot
.858 .13273 Mdot
.858 .13298 Mdot
.858 .13323 Mdot
.858 .13373 Mdot
.858 .13557 Mdot
.858 .13694 Mdot
.858 .13781 Mdot
.858 .13862 Mdot
.858 .14381 Mdot
.858 .14414 Mdot
.858 .14459 Mdot
.858 .14563 Mdot
.858 .14574 Mdot
.858 .15024 Mdot
.858 .15253 Mdot
.858 .15808 Mdot
.858 .16064 Mdot
.858 .16099 Mdot
.858 .16121 Mdot
.858 .16162 Mdot
.858 .16169 Mdot
.858 .16685 Mdot
.858 .16775 Mdot
.858 .16802 Mdot
.858 .16894 Mdot
.858 .16944 Mdot
.858 .17043 Mdot
.858 .17113 Mdot
.858 .17178 Mdot
.858 .17345 Mdot
.858 .17434 Mdot
.858 .17673 Mdot
.858 .17705 Mdot
.858 .17732 Mdot
.858 .17838 Mdot
.858 .17947 Mdot
.858 .17961 Mdot
.858 .17998 Mdot
.858 .18006 Mdot
.858 .18133 Mdot
.858 .18188 Mdot
.858 .18236 Mdot
.858 .18407 Mdot
.858 .18451 Mdot
.858 .18466 Mdot
.858 .18496 Mdot
.858 .18549 Mdot
.858 .18618 Mdot
.858 .18687 Mdot
.858 .18739 Mdot
.858 .19012 Mdot
.858 .19228 Mdot
.858 .19282 Mdot
.858 .19284 Mdot
.858 .19303 Mdot
.858 .1938 Mdot
.858 .19405 Mdot
.858 .19435 Mdot
.858 .19459 Mdot
.858 .19465 Mdot
.858 .19478 Mdot
.858 .19518 Mdot
.858 .19538 Mdot
.858 .19582 Mdot
.858 .19604 Mdot
.858 .19605 Mdot
.858 .19677 Mdot
.858 .19734 Mdot
.858 .19737 Mdot
.858 .1977 Mdot
.858 .19819 Mdot
.858 .19858 Mdot
.858 .19863 Mdot
.858 .19871 Mdot
.858 .19888 Mdot
.858 .19894 Mdot
.858 .19896 Mdot
.858 .19899 Mdot
.858 .19964 Mdot
.858 .20032 Mdot
.858 .20037 Mdot
.858 .20075 Mdot
.858 .20133 Mdot
.858 .20226 Mdot
.858 .20234 Mdot
.858 .20235 Mdot
.858 .20246 Mdot
.858 .20258 Mdot
.858 .20274 Mdot
.858 .20317 Mdot
.858 .20348 Mdot
.858 .20354 Mdot
.858 .20354 Mdot
.858 .20401 Mdot
.858 .20413 Mdot
.858 .20439 Mdot
.858 .2044 Mdot
.858 .20441 Mdot
.858 .20452 Mdot
.858 .20466 Mdot
.858 .2051 Mdot
.858 .20523 Mdot
.858 .20544 Mdot
.858 .2055 Mdot
.858 .20565 Mdot
.858 .20566 Mdot
.858 .20568 Mdot
.858 .20569 Mdot
.858 .20578 Mdot
.858 .20947 Mdot
.858 .20966 Mdot
.858 .2147 Mdot
.858 .21752 Mdot
.858 .22497 Mdot
.858 .2278 Mdot
.858 .23093 Mdot
.858 .23373 Mdot
.858 .23376 Mdot
.858 .23376 Mdot
.858 .23377 Mdot
.858 .23377 Mdot
.858 .23382 Mdot
.858 .23383 Mdot
.858 .2339 Mdot
.858 .23394 Mdot
.858 .23408 Mdot
.858 .23413 Mdot
.858 .23417 Mdot
.858 .23417 Mdot
.858 .23425 Mdot
.858 .23444 Mdot
.858 .23444 Mdot
.858 .23446 Mdot
.858 .23456 Mdot
.858 .2347 Mdot
.858 .23479 Mdot
.858 .23482 Mdot
.858 .23483 Mdot
.858 .23485 Mdot
.858 .23515 Mdot
.858 .23533 Mdot
.858 .23547 Mdot
.858 .23569 Mdot
.858 .23591 Mdot
.858 .23592 Mdot
.858 .23594 Mdot
.858 .23599 Mdot
.858 .23602 Mdot
.858 .23616 Mdot
.858 .23632 Mdot
.858 .23643 Mdot
.858 .23644 Mdot
.858 .23686 Mdot
.858 .23686 Mdot
.858 .23694 Mdot
.858 .23708 Mdot
.858 .23714 Mdot
.858 .23728 Mdot
.858 .23732 Mdot
.858 .23734 Mdot
.858 .23742 Mdot
.858 .23751 Mdot
.858 .2376 Mdot
.858 .2381 Mdot
.858 .23882 Mdot
.858 .23973 Mdot
.858 .2399 Mdot
.858 .24014 Mdot
.858 .24065 Mdot
.858 .24071 Mdot
.858 .24144 Mdot
.858 .24179 Mdot
.858 .24226 Mdot
.858 .24243 Mdot
.858 .24282 Mdot
.858 .24423 Mdot
.858 .24455 Mdot
.858 .24538 Mdot
.858 .24599 Mdot
.858 .24617 Mdot
.858 .2466 Mdot
.858 .24885 Mdot
.858 .24887 Mdot
.858 .24924 Mdot
.858 .25328 Mdot
.858 .25511 Mdot
.858 .25846 Mdot
.858 .25945 Mdot
.858 .26026 Mdot
.858 .26072 Mdot
.858 .26096 Mdot
.858 .26097 Mdot
.858 .26145 Mdot
.858 .26154 Mdot
.858 .26181 Mdot
.858 .26202 Mdot
.858 .26204 Mdot
.858 .26248 Mdot
.858 .26265 Mdot
.858 .26338 Mdot
.858 .26449 Mdot
.858 .26544 Mdot
.858 .26546 Mdot
.858 .26598 Mdot
.858 .26635 Mdot
.858 .26843 Mdot
.858 .26892 Mdot
.858 .27035 Mdot
.858 .27043 Mdot
.858 .27368 Mdot
.858 .27384 Mdot
.858 .27414 Mdot
.858 .27502 Mdot
.858 .27631 Mdot
.858 .27649 Mdot
.858 .27763 Mdot
.858 .27795 Mdot
.858 .27859 Mdot
.858 .28 Mdot
.858 .2808 Mdot
.858 .28123 Mdot
.858 .2815 Mdot
.858 .28386 Mdot
.858 .28405 Mdot
.858 .287 Mdot
.858 .28769 Mdot
.858 .28799 Mdot
.858 .28871 Mdot
.858 .28903 Mdot
.858 .2894 Mdot
.858 .28958 Mdot
.858 .28967 Mdot
.858 .29014 Mdot
.858 .2926 Mdot
.858 .29596 Mdot
.858 .29685 Mdot
.858 .29812 Mdot
.858 .29853 Mdot
.858 .29967 Mdot
.858 .29984 Mdot
.858 .30069 Mdot
.858 .30193 Mdot
.858 .30201 Mdot
.858 .30227 Mdot
.858 .30296 Mdot
.858 .30308 Mdot
.858 .30326 Mdot
.858 .30343 Mdot
.858 .30347 Mdot
.858 .30353 Mdot
.858 .30357 Mdot
.858 .30414 Mdot
.858 .30434 Mdot
.858 .30515 Mdot
.858 .30565 Mdot
.858 .30586 Mdot
.858 .30668 Mdot
.858 .3068 Mdot
.858 .30728 Mdot
.858 .30745 Mdot
.858 .30778 Mdot
.858 .30823 Mdot
.858 .30825 Mdot
.858 .3083 Mdot
.858 .30927 Mdot
.858 .3097 Mdot
.858 .31015 Mdot
.858 .31147 Mdot
.858 .31148 Mdot
.858 .3117 Mdot
.858 .31265 Mdot
.858 .31281 Mdot
.858 .31288 Mdot
.858 .31292 Mdot
.858 .31341 Mdot
.858 .31447 Mdot
.858 .31509 Mdot
.858 .31554 Mdot
.858 .31555 Mdot
.858 .31562 Mdot
.858 .31596 Mdot
.858 .316 Mdot
.858 .31627 Mdot
.858 .31673 Mdot
.858 .31806 Mdot
.858 .31877 Mdot
.858 .3198 Mdot
.858 .32015 Mdot
.858 .32164 Mdot
.858 .32197 Mdot
.858 .32229 Mdot
.858 .32342 Mdot
.858 .32343 Mdot
.858 .32361 Mdot
.858 .32619 Mdot
.858 .32752 Mdot
.858 .32866 Mdot
.858 .32876 Mdot
.858 .32884 Mdot
.858 .32906 Mdot
.858 .32971 Mdot
.858 .33003 Mdot
.858 .33022 Mdot
.858 .33168 Mdot
.858 .3327 Mdot
.858 .33275 Mdot
.858 .33284 Mdot
.858 .33311 Mdot
.858 .33349 Mdot
.858 .33355 Mdot
.858 .33389 Mdot
.858 .33458 Mdot
.858 .33481 Mdot
.858 .33493 Mdot
.858 .33708 Mdot
.858 .33725 Mdot
.858 .33983 Mdot
.858 .33987 Mdot
.858 .34039 Mdot
.858 .34064 Mdot
.858 .34071 Mdot
.858 .34237 Mdot
.858 .34295 Mdot
.858 .34299 Mdot
.858 .34313 Mdot
.858 .34467 Mdot
.858 .34515 Mdot
.858 .3454 Mdot
.858 .3463 Mdot
.858 .34744 Mdot
.858 .3484 Mdot
.858 .34961 Mdot
.858 .35098 Mdot
.858 .35135 Mdot
.858 .35143 Mdot
.858 .35181 Mdot
.858 .35205 Mdot
.858 .35214 Mdot
.858 .35293 Mdot
.858 .35307 Mdot
.858 .35367 Mdot
.858 .35422 Mdot
.858 .35487 Mdot
.858 .35488 Mdot
.858 .3553 Mdot
.858 .35743 Mdot
.858 .35754 Mdot
.858 .35919 Mdot
.858 .35992 Mdot
.858 .36213 Mdot
.858 .36226 Mdot
.858 .36245 Mdot
.858 .36288 Mdot
.858 .36566 Mdot
.858 .36782 Mdot
.858 .36893 Mdot
.858 .36901 Mdot
.858 .3711 Mdot
.858 .37153 Mdot
.858 .3724 Mdot
.858 .37289 Mdot
.858 .37464 Mdot
.858 .37475 Mdot
.858 .37485 Mdot
.858 .37565 Mdot
.858 .3758 Mdot
.858 .37643 Mdot
.858 .37718 Mdot
.858 .37748 Mdot
.858 .37766 Mdot
.858 .38011 Mdot
.858 .38012 Mdot
.858 .38018 Mdot
.858 .38141 Mdot
.858 .382 Mdot
.858 .38213 Mdot
.858 .38257 Mdot
.858 .38329 Mdot
.858 .38374 Mdot
.858 .38387 Mdot
.858 .38547 Mdot
.858 .38553 Mdot
.858 .38797 Mdot
.858 .39109 Mdot
.858 .39202 Mdot
.858 .39306 Mdot
.858 .39386 Mdot
.858 .39397 Mdot
.858 .39489 Mdot
.858 .39512 Mdot
.858 .39593 Mdot
.858 .40071 Mdot
.858 .40101 Mdot
.858 .40241 Mdot
.858 .40293 Mdot
.858 .4064 Mdot
.858 .40705 Mdot
.858 .4071 Mdot
.858 .4081 Mdot
.858 .40876 Mdot
.858 .41034 Mdot
.858 .41058 Mdot
.858 .41103 Mdot
.858 .41203 Mdot
.858 .41299 Mdot
.858 .41325 Mdot
.858 .41558 Mdot
.858 .4156 Mdot
.858 .41719 Mdot
.858 .42011 Mdot
.858 .42015 Mdot
.858 .42022 Mdot
.858 .4206 Mdot
.858 .42213 Mdot
.858 .42491 Mdot
.858 .42542 Mdot
.858 .42783 Mdot
.858 .43137 Mdot
.858 .43157 Mdot
.858 .43395 Mdot
.858 .43619 Mdot
.858 .43649 Mdot
.858 .44011 Mdot
.858 .44124 Mdot
.858 .44193 Mdot
.858 .44194 Mdot
.858 .44236 Mdot
.858 .44315 Mdot
.858 .44318 Mdot
.858 .44328 Mdot
.858 .44523 Mdot
.858 .4462 Mdot
.858 .44944 Mdot
.858 .45315 Mdot
.858 .45484 Mdot
.858 .45534 Mdot
.858 .4564 Mdot
.858 .45704 Mdot
.858 .45797 Mdot
.858 .4598 Mdot
.858 .46107 Mdot
.858 .46225 Mdot
.858 .46235 Mdot
.858 .46409 Mdot
.858 .46526 Mdot
.858 .46684 Mdot
.858 .46758 Mdot
.858 .46776 Mdot
.858 .46781 Mdot
.858 .4692 Mdot
.858 .46995 Mdot
.858 .46996 Mdot
.858 .47105 Mdot
.858 .47117 Mdot
.858 .47162 Mdot
.858 .47209 Mdot
.858 .47313 Mdot
.858 .47392 Mdot
.858 .4758 Mdot
.858 .47604 Mdot
.858 .47667 Mdot
.858 .47681 Mdot
.858 .47895 Mdot
.858 .47931 Mdot
.858 .47982 Mdot
.858 .47987 Mdot
.858 .48068 Mdot
.858 .48352 Mdot
.858 .48355 Mdot
.858 .48424 Mdot
.858 .4845 Mdot
.858 .48499 Mdot
.858 .48586 Mdot
.858 .48698 Mdot
.858 .48743 Mdot
.858 .48776 Mdot
.858 .4881 Mdot
.858 .48893 Mdot
.858 .49327 Mdot
.858 .4934 Mdot
.858 .49662 Mdot
.858 .49714 Mdot
.858 .49746 Mdot
.858 .49749 Mdot
.858 .49777 Mdot
.858 .49792 Mdot
.858 .49895 Mdot
.858 .49934 Mdot
.858 .49979 Mdot
.858 .50015 Mdot
.858 .50025 Mdot
.858 .50044 Mdot
.858 .50105 Mdot
.858 .50135 Mdot
.858 .50199 Mdot
.858 .50212 Mdot
.858 .50232 Mdot
.858 .50234 Mdot
.858 .50341 Mdot
.858 .50425 Mdot
.858 .5043 Mdot
.858 .50439 Mdot
.858 .50479 Mdot
.858 .50496 Mdot
.858 .50506 Mdot
.858 .50512 Mdot
.858 .50551 Mdot
.858 .50607 Mdot
.858 .50614 Mdot
.858 .50627 Mdot
.858 .50651 Mdot
.858 .5066 Mdot
.858 .50663 Mdot
.858 .50667 Mdot
.858 .50761 Mdot
.858 .50859 Mdot
.858 .50866 Mdot
.858 .50921 Mdot
.858 .50934 Mdot
.858 .51003 Mdot
.858 .51136 Mdot
.858 .51146 Mdot
.858 .51147 Mdot
.858 .5116 Mdot
.858 .51163 Mdot
.858 .51163 Mdot
.858 .5118 Mdot
.858 .51203 Mdot
.858 .51263 Mdot
.858 .51306 Mdot
.858 .51314 Mdot
.858 .51315 Mdot
.858 .5138 Mdot
.858 .51396 Mdot
.858 .51432 Mdot
.858 .51434 Mdot
.858 .51435 Mdot
.858 .51451 Mdot
.858 .5147 Mdot
.858 .51487 Mdot
.858 .51522 Mdot
.858 .5153 Mdot
.858 .51548 Mdot
.858 .51577 Mdot
.858 .51585 Mdot
.858 .51606 Mdot
.858 .51607 Mdot
.858 .5161 Mdot
.858 .51611 Mdot
.858 .51624 Mdot
.858 .51653 Mdot
.858 .51789 Mdot
.858 .5185 Mdot
.858 .51882 Mdot
.858 .52091 Mdot
.858 .52118 Mdot
.858 .52142 Mdot
.858 .52179 Mdot
.858 .52308 Mdot
.858 .52314 Mdot
.858 .52398 Mdot
.858 .52787 Mdot
.858 .52837 Mdot
.858 .52902 Mdot
.858 .53073 Mdot
.858 .53109 Mdot
.858 .53133 Mdot
.858 .53673 Mdot
.858 .53766 Mdot
.858 .53792 Mdot
.858 .53895 Mdot
.858 .53907 Mdot
.858 .53996 Mdot
.858 .53996 Mdot
.858 .54111 Mdot
.858 .54213 Mdot
.858 .54305 Mdot
.858 .54544 Mdot
.858 .54635 Mdot
.858 .54795 Mdot
.858 .54801 Mdot
.858 .54917 Mdot
.858 .5492 Mdot
.858 .54921 Mdot
.858 .54921 Mdot
.858 .54922 Mdot
.858 .54927 Mdot
.858 .54928 Mdot
.858 .54935 Mdot
.858 .54939 Mdot
.858 .54953 Mdot
.858 .54957 Mdot
.858 .54961 Mdot
.858 .54961 Mdot
.858 .54962 Mdot
.858 .5497 Mdot
.858 .54973 Mdot
.858 .54988 Mdot
.858 .54988 Mdot
.858 .5499 Mdot
.858 .55 Mdot
.858 .55013 Mdot
.858 .55018 Mdot
.858 .55022 Mdot
.858 .55026 Mdot
.858 .55026 Mdot
.858 .55028 Mdot
.858 .55058 Mdot
.858 .55076 Mdot
.858 .55088 Mdot
.858 .55089 Mdot
.858 .5511 Mdot
.858 .55131 Mdot
.858 .55132 Mdot
.858 .55132 Mdot
.858 .55134 Mdot
.858 .55139 Mdot
.858 .55142 Mdot
.858 .55144 Mdot
.858 .55156 Mdot
.858 .55171 Mdot
.858 .55181 Mdot
.858 .55182 Mdot
.858 .552 Mdot
.858 .55223 Mdot
.858 .55223 Mdot
.858 .5523 Mdot
.858 .55243 Mdot
.858 .55249 Mdot
.858 .55262 Mdot
.858 .55266 Mdot
.858 .55268 Mdot
.858 .55275 Mdot
.858 .55285 Mdot
.858 .55292 Mdot
.858 .55316 Mdot
.858 .55322 Mdot
.858 .55323 Mdot
.858 .5534 Mdot
.858 .55406 Mdot
.858 .55491 Mdot
.858 .55506 Mdot
.858 .55528 Mdot
.858 .55549 Mdot
.858 .55565 Mdot
.858 .55575 Mdot
.858 .55579 Mdot
.858 .55593 Mdot
.858 .55645 Mdot
.858 .5566 Mdot
.858 .55677 Mdot
.858 .55715 Mdot
.858 .55718 Mdot
.858 .55729 Mdot
.858 .55733 Mdot
.858 .55767 Mdot
.858 .55799 Mdot
.858 .55807 Mdot
.858 .55817 Mdot
.858 .55889 Mdot
.858 .55916 Mdot
.858 .55967 Mdot
.858 .55986 Mdot
.858 .56007 Mdot
.858 .56037 Mdot
.858 .56053 Mdot
.858 .5608 Mdot
.858 .56088 Mdot
.858 .56115 Mdot
.858 .5627 Mdot
.858 .56272 Mdot
.858 .56284 Mdot
.858 .56291 Mdot
.858 .56301 Mdot
.858 .56377 Mdot
.858 .56542 Mdot
.858 .56609 Mdot
.858 .56742 Mdot
.858 .56745 Mdot
.858 .56775 Mdot
.858 .56788 Mdot
.858 .56798 Mdot
.858 .56949 Mdot
.858 .56973 Mdot
.858 .56998 Mdot
.858 .57038 Mdot
.858 .57091 Mdot
.858 .57106 Mdot
.858 .57113 Mdot
.858 .5712 Mdot
.858 .57135 Mdot
.858 .57136 Mdot
.858 .57166 Mdot
.858 .57172 Mdot
.858 .57189 Mdot
.858 .57202 Mdot
.858 .57203 Mdot
.858 .5723 Mdot
.858 .57241 Mdot
.858 .57246 Mdot
.858 .57271 Mdot
.858 .57272 Mdot
.858 .57285 Mdot
.858 .57311 Mdot
.858 .57344 Mdot
.858 .57351 Mdot
.858 .57379 Mdot
.858 .57387 Mdot
.858 .57406 Mdot
.858 .57408 Mdot
.858 .57432 Mdot
.858 .57437 Mdot
.858 .57437 Mdot
.858 .57451 Mdot
.858 .57458 Mdot
.858 .57473 Mdot
.858 .57477 Mdot
.858 .57498 Mdot
.858 .57572 Mdot
.858 .57573 Mdot
.858 .57599 Mdot
.858 .57636 Mdot
.858 .57673 Mdot
.858 .57677 Mdot
.858 .57686 Mdot
.858 .57742 Mdot
.858 .57786 Mdot
.858 .57798 Mdot
.858 .57821 Mdot
.858 .57836 Mdot
.858 .57843 Mdot
.858 .57857 Mdot
.858 .57892 Mdot
.858 .57897 Mdot
.858 .57898 Mdot
.858 .579 Mdot
.858 .57926 Mdot
.858 .57954 Mdot
.858 .57962 Mdot
.858 .57997 Mdot
.858 .58 Mdot
.858 .5801 Mdot
.858 .5801 Mdot
.858 .58023 Mdot
.858 .58032 Mdot
.858 .58033 Mdot
.858 .58049 Mdot
.858 .58105 Mdot
.858 .58134 Mdot
.858 .58135 Mdot
.858 .5814 Mdot
.858 .5815 Mdot
.858 .5816 Mdot
.858 .58217 Mdot
.858 .58221 Mdot
.858 .58229 Mdot
.858 .58243 Mdot
.858 .58249 Mdot
.858 .58252 Mdot
.858 .58263 Mdot
.858 .58265 Mdot
.858 .58277 Mdot
.858 .58286 Mdot
.858 .58289 Mdot
.858 .5829 Mdot
.858 .58321 Mdot
.858 .5834 Mdot
.858 .5836 Mdot
.858 .58364 Mdot
.858 .58368 Mdot
.858 .58369 Mdot
.858 .58378 Mdot
.858 .58388 Mdot
.858 .58395 Mdot
.858 .58397 Mdot
.858 .58401 Mdot
.858 .58403 Mdot
.858 .58405 Mdot
.858 .58406 Mdot
.858 .58411 Mdot
.858 .58413 Mdot
.858 .58425 Mdot
.858 .58434 Mdot
.858 .58466 Mdot
.858 .58482 Mdot
.858 .5852 Mdot
.858 .58523 Mdot
.858 .58523 Mdot
.858 .58544 Mdot
.858 .58548 Mdot
.858 .58549 Mdot
.858 .58555 Mdot
.858 .58563 Mdot
.858 .58578 Mdot
.858 .58582 Mdot
.858 .58583 Mdot
.858 .58588 Mdot
.858 .58598 Mdot
.858 .58603 Mdot
.858 .58605 Mdot
.858 .58606 Mdot
.858 .58615 Mdot
.858 .58621 Mdot
.858 .58626 Mdot
.858 .58627 Mdot
.858 .58628 Mdot
.858 .58628 Mdot
.858 .58628 Mdot
.858 .5863 Mdot
.858 .58631 Mdot
.858 .58632 Mdot
.858 .58632 Mdot
.858 .58636 Mdot
.858 .58636 Mdot
.858 .58637 Mdot
.858 .58638 Mdot
.858 .5864 Mdot
.858 .5864 Mdot
.858 .5864 Mdot
.858 .58641 Mdot
.858 .58641 Mdot
.858 .58645 Mdot
.858 .58646 Mdot
.858 .58648 Mdot
.858 .5865 Mdot
.858 .5865 Mdot
.858 .5865 Mdot
.858 .58651 Mdot
.858 .58652 Mdot
.858 .58653 Mdot
.858 .58654 Mdot
.858 .58656 Mdot
.858 .58656 Mdot
.858 .58656 Mdot
.858 .58657 Mdot
.858 .58657 Mdot
.858 .58658 Mdot
.858 .58659 Mdot
.858 .58659 Mdot
.858 .58659 Mdot
.858 .5866 Mdot
.858 .5866 Mdot
.858 .5866 Mdot
.858 .5866 Mdot
.858 .5866 Mdot
.86 .077 Mdot
.86 .077 Mdot
.86 .077 Mdot
.86 .077 Mdot
.86 .077 Mdot
.86 .07703 Mdot
.86 .07704 Mdot
.86 .07707 Mdot
.86 .07707 Mdot
.86 .0771 Mdot
.86 .07711 Mdot
.86 .07712 Mdot
.86 .07713 Mdot
.86 .07716 Mdot
.86 .0773 Mdot
.86 .07749 Mdot
.86 .07756 Mdot
.86 .0776 Mdot
.86 .07793 Mdot
.86 .07793 Mdot
.86 .07802 Mdot
.86 .07804 Mdot
.86 .07812 Mdot
.86 .07823 Mdot
.86 .07823 Mdot
.86 .07827 Mdot
.86 .07833 Mdot
.86 .07839 Mdot
.86 .07846 Mdot
.86 .0789 Mdot
.86 .07894 Mdot
.86 .07894 Mdot
.86 .07951 Mdot
.86 .07965 Mdot
.86 .07998 Mdot
.86 .08 Mdot
.86 .08 Mdot
.86 .08026 Mdot
.86 .08027 Mdot
.86 .08032 Mdot
.86 .08033 Mdot
.86 .08037 Mdot
.86 .08041 Mdot
.86 .08077 Mdot
.86 .08084 Mdot
.86 .08103 Mdot
.86 .08111 Mdot
.86 .08118 Mdot
.86 .0812 Mdot
.86 .08129 Mdot
.86 .08216 Mdot
.86 .08217 Mdot
.86 .08242 Mdot
.86 .0829 Mdot
.86 .0829 Mdot
.86 .08322 Mdot
.86 .08328 Mdot
.86 .08388 Mdot
.86 .08401 Mdot
.86 .08431 Mdot
.86 .08469 Mdot
.86 .08546 Mdot
.86 .08592 Mdot
.86 .08617 Mdot
.86 .08629 Mdot
.86 .08657 Mdot
.86 .08681 Mdot
.86 .08689 Mdot
.86 .0871 Mdot
.86 .08755 Mdot
.86 .08773 Mdot
.86 .08809 Mdot
.86 .08891 Mdot
.86 .08933 Mdot
.86 .08936 Mdot
.86 .0894 Mdot
.86 .08965 Mdot
.86 .09173 Mdot
.86 .09185 Mdot
.86 .09187 Mdot
.86 .09301 Mdot
.86 .09462 Mdot
.86 .09495 Mdot
.86 .095 Mdot
.86 .09575 Mdot
.86 .09651 Mdot
.86 .09662 Mdot
.86 .09686 Mdot
.86 .09696 Mdot
.86 .09713 Mdot
.86 .09761 Mdot
.86 .09779 Mdot
.86 .09807 Mdot
.86 .09912 Mdot
.86 .09933 Mdot
.86 .09962 Mdot
.86 .09968 Mdot
.86 .10066 Mdot
.86 .10128 Mdot
.86 .10152 Mdot
.86 .10166 Mdot
.86 .10297 Mdot
.86 .10308 Mdot
.86 .10311 Mdot
.86 .1033 Mdot
.86 .10346 Mdot
.86 .1035 Mdot
.86 .1039 Mdot
.86 .10408 Mdot
.86 .10414 Mdot
.86 .10469 Mdot
.86 .10472 Mdot
.86 .10646 Mdot
.86 .10658 Mdot
.86 .10668 Mdot
.86 .10675 Mdot
.86 .10723 Mdot
.86 .10726 Mdot
.86 .10875 Mdot
.86 .10891 Mdot
.86 .11155 Mdot
.86 .11247 Mdot
.86 .11332 Mdot
.86 .11428 Mdot
.86 .11484 Mdot
.86 .11487 Mdot
.86 .1151 Mdot
.86 .11588 Mdot
.86 .11648 Mdot
.86 .11671 Mdot
.86 .1169 Mdot
.86 .11733 Mdot
.86 .11923 Mdot
.86 .12171 Mdot
.86 .12406 Mdot
.86 .12558 Mdot
.86 .12607 Mdot
.86 .12621 Mdot
.86 .12716 Mdot
.86 .12733 Mdot
.86 .12847 Mdot
.86 .12862 Mdot
.86 .13018 Mdot
.86 .13022 Mdot
.86 .13153 Mdot
.86 .13205 Mdot
.86 .13231 Mdot
.86 .13358 Mdot
.86 .13544 Mdot
.86 .1363 Mdot
.86 .13746 Mdot
.86 .138 Mdot
.86 .14011 Mdot
.86 .14062 Mdot
.86 .14117 Mdot
.86 .14229 Mdot
.86 .14438 Mdot
.86 .14627 Mdot
.86 .14664 Mdot
.86 .1491 Mdot
.86 .14946 Mdot
.86 .15165 Mdot
.86 .15169 Mdot
.86 .15206 Mdot
.86 .15212 Mdot
.86 .15268 Mdot
.86 .15291 Mdot
.86 .15732 Mdot
.86 .15774 Mdot
.86 .15885 Mdot
.86 .15993 Mdot
.86 .16028 Mdot
.86 .16031 Mdot
.86 .16244 Mdot
.86 .1641 Mdot
.86 .165 Mdot
.86 .16617 Mdot
.86 .16623 Mdot
.86 .16733 Mdot
.86 .16829 Mdot
.86 .16867 Mdot
.86 .17076 Mdot
.86 .17356 Mdot
.86 .1743 Mdot
.86 .17446 Mdot
.86 .17506 Mdot
.86 .17575 Mdot
.86 .17731 Mdot
.86 .17741 Mdot
.86 .17797 Mdot
.86 .17878 Mdot
.86 .17901 Mdot
.86 .18114 Mdot
.86 .18148 Mdot
.86 .18182 Mdot
.86 .18196 Mdot
.86 .18234 Mdot
.86 .18249 Mdot
.86 .18299 Mdot
.86 .18356 Mdot
.86 .18473 Mdot
.86 .18475 Mdot
.86 .18491 Mdot
.86 .18788 Mdot
.86 .18813 Mdot
.86 .18921 Mdot
.86 .19178 Mdot
.86 .19357 Mdot
.86 .19444 Mdot
.86 .19446 Mdot
.86 .19479 Mdot
.86 .19693 Mdot
.86 .19808 Mdot
.86 .1985 Mdot
.86 .19889 Mdot
.86 .19957 Mdot
.86 .19994 Mdot
.86 .2002 Mdot
.86 .20021 Mdot
.86 .20077 Mdot
.86 .20097 Mdot
.86 .20112 Mdot
.86 .20112 Mdot
.86 .2013 Mdot
.86 .20219 Mdot
.86 .20243 Mdot
.86 .20276 Mdot
.86 .20288 Mdot
.86 .20313 Mdot
.86 .20394 Mdot
.86 .20403 Mdot
.86 .20718 Mdot
.86 .20757 Mdot
.86 .20827 Mdot
.86 .21005 Mdot
.86 .21145 Mdot
.86 .21161 Mdot
.86 .21179 Mdot
.86 .21189 Mdot
.86 .21198 Mdot
.86 .21207 Mdot
.86 .21232 Mdot
.86 .21237 Mdot
.86 .21268 Mdot
.86 .21275 Mdot
.86 .213 Mdot
.86 .21301 Mdot
.86 .21304 Mdot
.86 .21307 Mdot
.86 .21308 Mdot
.86 .2144 Mdot
.86 .21648 Mdot
.86 .21831 Mdot
.86 .21876 Mdot
.86 .21898 Mdot
.86 .22143 Mdot
.86 .22231 Mdot
.86 .22462 Mdot
.86 .22773 Mdot
.86 .2295 Mdot
.86 .22964 Mdot
.86 .23125 Mdot
.86 .23125 Mdot
.86 .23126 Mdot
.86 .23127 Mdot
.86 .23127 Mdot
.86 .23135 Mdot
.86 .23137 Mdot
.86 .23147 Mdot
.86 .23148 Mdot
.86 .23156 Mdot
.86 .23159 Mdot
.86 .23162 Mdot
.86 .23165 Mdot
.86 .2317 Mdot
.86 .23175 Mdot
.86 .23219 Mdot
.86 .23275 Mdot
.86 .23297 Mdot
.86 .23309 Mdot
.86 .23409 Mdot
.86 .23412 Mdot
.86 .23437 Mdot
.86 .23445 Mdot
.86 .2346 Mdot
.86 .23467 Mdot
.86 .23496 Mdot
.86 .23501 Mdot
.86 .23501 Mdot
.86 .23506 Mdot
.86 .23513 Mdot
.86 .23531 Mdot
.86 .23551 Mdot
.86 .23573 Mdot
.86 .23586 Mdot
.86 .23637 Mdot
.86 .23706 Mdot
.86 .23717 Mdot
.86 .23718 Mdot
.86 .2389 Mdot
.86 .23935 Mdot
.86 .24035 Mdot
.86 .2404 Mdot
.86 .24041 Mdot
.86 .24081 Mdot
.86 .24117 Mdot
.86 .24122 Mdot
.86 .24135 Mdot
.86 .2414 Mdot
.86 .24152 Mdot
.86 .24163 Mdot
.86 .24272 Mdot
.86 .24292 Mdot
.86 .24295 Mdot
.86 .2435 Mdot
.86 .24374 Mdot
.86 .24396 Mdot
.86 .24401 Mdot
.86 .24427 Mdot
.86 .24527 Mdot
.86 .24602 Mdot
.86 .24691 Mdot
.86 .24693 Mdot
.86 .24769 Mdot
.86 .2491 Mdot
.86 .24911 Mdot
.86 .25008 Mdot
.86 .25023 Mdot
.86 .25203 Mdot
.86 .25225 Mdot
.86 .25242 Mdot
.86 .25331 Mdot
.86 .25445 Mdot
.86 .2546 Mdot
.86 .25537 Mdot
.86 .25624 Mdot
.86 .25671 Mdot
.86 .25694 Mdot
.86 .25806 Mdot
.86 .2583 Mdot
.86 .2588 Mdot
.86 .25918 Mdot
.86 .26 Mdot
.86 .26057 Mdot
.86 .26069 Mdot
.86 .26092 Mdot
.86 .26154 Mdot
.86 .26233 Mdot
.86 .26286 Mdot
.86 .26339 Mdot
.86 .26346 Mdot
.86 .26443 Mdot
.86 .26683 Mdot
.86 .26803 Mdot
.86 .26814 Mdot
.86 .26826 Mdot
.86 .26899 Mdot
.86 .26943 Mdot
.86 .27094 Mdot
.86 .27382 Mdot
.86 .27496 Mdot
.86 .27533 Mdot
.86 .27537 Mdot
.86 .27573 Mdot
.86 .27576 Mdot
.86 .27586 Mdot
.86 .27598 Mdot
.86 .276 Mdot
.86 .27692 Mdot
.86 .27702 Mdot
.86 .27718 Mdot
.86 .2783 Mdot
.86 .27849 Mdot
.86 .27864 Mdot
.86 .27938 Mdot
.86 .27971 Mdot
.86 .28005 Mdot
.86 .28043 Mdot
.86 .28108 Mdot
.86 .28165 Mdot
.86 .28321 Mdot
.86 .28416 Mdot
.86 .28428 Mdot
.86 .2861 Mdot
.86 .2864 Mdot
.86 .28678 Mdot
.86 .28757 Mdot
.86 .2881 Mdot
.86 .28855 Mdot
.86 .28885 Mdot
.86 .28952 Mdot
.86 .28979 Mdot
.86 .2903 Mdot
.86 .29162 Mdot
.86 .29214 Mdot
.86 .2929 Mdot
.86 .29339 Mdot
.86 .29584 Mdot
.86 .29587 Mdot
.86 .29598 Mdot
.86 .29642 Mdot
.86 .29714 Mdot
.86 .29721 Mdot
.86 .29728 Mdot
.86 .29738 Mdot
.86 .29741 Mdot
.86 .29791 Mdot
.86 .30007 Mdot
.86 .30123 Mdot
.86 .30178 Mdot
.86 .30244 Mdot
.86 .30283 Mdot
.86 .3042 Mdot
.86 .30641 Mdot
.86 .30669 Mdot
.86 .30679 Mdot
.86 .3073 Mdot
.86 .30773 Mdot
.86 .30784 Mdot
.86 .30892 Mdot
.86 .30922 Mdot
.86 .30941 Mdot
.86 .30956 Mdot
.86 .30958 Mdot
.86 .3108 Mdot
.86 .31106 Mdot
.86 .31115 Mdot
.86 .31257 Mdot
.86 .31351 Mdot
.86 .314 Mdot
.86 .31524 Mdot
.86 .31551 Mdot
.86 .31582 Mdot
.86 .31615 Mdot
.86 .31615 Mdot
.86 .31642 Mdot
.86 .31661 Mdot
.86 .31788 Mdot
.86 .31797 Mdot
.86 .3192 Mdot
.86 .31949 Mdot
.86 .32016 Mdot
.86 .32016 Mdot
.86 .32073 Mdot
.86 .32151 Mdot
.86 .32193 Mdot
.86 .32233 Mdot
.86 .32363 Mdot
.86 .32364 Mdot
.86 .324 Mdot
.86 .32464 Mdot
.86 .32507 Mdot
.86 .32606 Mdot
.86 .32687 Mdot
.86 .32864 Mdot
.86 .32894 Mdot
.86 .32926 Mdot
.86 .33012 Mdot
.86 .33167 Mdot
.86 .33171 Mdot
.86 .33386 Mdot
.86 .3361 Mdot
.86 .33635 Mdot
.86 .33753 Mdot
.86 .33778 Mdot
.86 .33785 Mdot
.86 .33846 Mdot
.86 .33978 Mdot
.86 .34044 Mdot
.86 .34196 Mdot
.86 .34255 Mdot
.86 .34305 Mdot
.86 .34413 Mdot
.86 .34427 Mdot
.86 .34431 Mdot
.86 .3446 Mdot
.86 .34462 Mdot
.86 .3455 Mdot
.86 .34559 Mdot
.86 .34761 Mdot
.86 .34808 Mdot
.86 .3489 Mdot
.86 .34892 Mdot
.86 .34946 Mdot
.86 .35022 Mdot
.86 .35245 Mdot
.86 .35434 Mdot
.86 .35509 Mdot
.86 .35577 Mdot
.86 .35651 Mdot
.86 .36087 Mdot
.86 .36458 Mdot
.86 .36559 Mdot
.86 .36576 Mdot
.86 .36609 Mdot
.86 .36838 Mdot
.86 .36879 Mdot
.86 .36973 Mdot
.86 .37067 Mdot
.86 .37153 Mdot
.86 .37188 Mdot
.86 .37559 Mdot
.86 .37567 Mdot
.86 .37703 Mdot
.86 .37877 Mdot
.86 .37998 Mdot
.86 .38057 Mdot
.86 .38204 Mdot
.86 .38264 Mdot
.86 .38273 Mdot
.86 .38354 Mdot
.86 .38719 Mdot
.86 .38783 Mdot
.86 .3886 Mdot
.86 .38934 Mdot
.86 .38961 Mdot
.86 .38979 Mdot
.86 .39124 Mdot
.86 .39177 Mdot
.86 .39181 Mdot
.86 .39242 Mdot
.86 .39328 Mdot
.86 .39338 Mdot
.86 .39365 Mdot
.86 .3938 Mdot
.86 .39509 Mdot
.86 .39639 Mdot
.86 .39839 Mdot
.86 .39952 Mdot
.86 .4001 Mdot
.86 .40074 Mdot
.86 .40123 Mdot
.86 .40322 Mdot
.86 .40443 Mdot
.86 .40531 Mdot
.86 .40779 Mdot
.86 .40819 Mdot
.86 .40833 Mdot
.86 .41043 Mdot
.86 .41078 Mdot
.86 .41081 Mdot
.86 .41098 Mdot
.86 .41187 Mdot
.86 .41267 Mdot
.86 .41443 Mdot
.86 .41568 Mdot
.86 .41665 Mdot
.86 .41792 Mdot
.86 .4182 Mdot
.86 .41868 Mdot
.86 .41922 Mdot
.86 .42148 Mdot
.86 .42207 Mdot
.86 .42326 Mdot
.86 .42333 Mdot
.86 .42334 Mdot
.86 .42412 Mdot
.86 .42424 Mdot
.86 .4246 Mdot
.86 .4248 Mdot
.86 .42539 Mdot
.86 .42588 Mdot
.86 .42645 Mdot
.86 .43181 Mdot
.86 .43485 Mdot
.86 .43511 Mdot
.86 .43568 Mdot
.86 .4361 Mdot
.86 .43788 Mdot
.86 .43818 Mdot
.86 .44002 Mdot
.86 .44071 Mdot
.86 .44077 Mdot
.86 .44169 Mdot
.86 .44202 Mdot
.86 .4427 Mdot
.86 .44408 Mdot
.86 .44442 Mdot
.86 .44492 Mdot
.86 .44637 Mdot
.86 .44755 Mdot
.86 .44811 Mdot
.86 .44908 Mdot
.86 .44984 Mdot
.86 .45038 Mdot
.86 .45113 Mdot
.86 .45149 Mdot
.86 .45171 Mdot
.86 .45205 Mdot
.86 .45216 Mdot
.86 .45235 Mdot
.86 .45275 Mdot
.86 .45343 Mdot
.86 .45423 Mdot
.86 .45484 Mdot
.86 .45585 Mdot
.86 .45603 Mdot
.86 .45674 Mdot
.86 .45708 Mdot
.86 .45726 Mdot
.86 .45904 Mdot
.86 .46008 Mdot
.86 .46057 Mdot
.86 .46221 Mdot
.86 .46484 Mdot
.86 .46564 Mdot
.86 .46574 Mdot
.86 .46635 Mdot
.86 .46695 Mdot
.86 .46724 Mdot
.86 .46831 Mdot
.86 .4688 Mdot
.86 .46953 Mdot
.86 .46999 Mdot
.86 .47058 Mdot
.86 .47218 Mdot
.86 .47226 Mdot
.86 .47228 Mdot
.86 .47244 Mdot
.86 .47341 Mdot
.86 .47347 Mdot
.86 .47479 Mdot
.86 .47519 Mdot
.86 .47664 Mdot
.86 .47715 Mdot
.86 .47882 Mdot
.86 .47939 Mdot
.86 .47997 Mdot
.86 .48015 Mdot
.86 .4802 Mdot
.86 .48085 Mdot
.86 .48086 Mdot
.86 .4811 Mdot
.86 .48181 Mdot
.86 .48193 Mdot
.86 .48226 Mdot
.86 .48287 Mdot
.86 .4848 Mdot
.86 .48484 Mdot
.86 .4851 Mdot
.86 .48724 Mdot
.86 .48992 Mdot
.86 .49031 Mdot
.86 .49203 Mdot
.86 .49575 Mdot
.86 .49605 Mdot
.86 .49663 Mdot
.86 .49739 Mdot
.86 .49828 Mdot
.86 .49859 Mdot
.86 .49881 Mdot
.86 .49914 Mdot
.86 .49932 Mdot
.86 .50013 Mdot
.86 .50016 Mdot
.86 .50051 Mdot
.86 .50052 Mdot
.86 .50063 Mdot
.86 .50065 Mdot
.86 .50241 Mdot
.86 .50329 Mdot
.86 .50385 Mdot
.86 .50555 Mdot
.86 .50616 Mdot
.86 .50661 Mdot
.86 .50672 Mdot
.86 .5074 Mdot
.86 .50771 Mdot
.86 .50809 Mdot
.86 .50825 Mdot
.86 .50849 Mdot
.86 .50863 Mdot
.86 .50863 Mdot
.86 .50944 Mdot
.86 .50973 Mdot
.86 .50994 Mdot
.86 .50995 Mdot
.86 .5102 Mdot
.86 .51031 Mdot
.86 .51145 Mdot
.86 .51169 Mdot
.86 .51179 Mdot
.86 .51225 Mdot
.86 .51243 Mdot
.86 .51278 Mdot
.86 .51344 Mdot
.86 .5139 Mdot
.86 .51403 Mdot
.86 .51587 Mdot
.86 .51695 Mdot
.86 .51816 Mdot
.86 .51834 Mdot
.86 .51839 Mdot
.86 .51844 Mdot
.86 .51886 Mdot
.86 .5189 Mdot
.86 .51979 Mdot
.86 .52168 Mdot
.86 .52187 Mdot
.86 .52215 Mdot
.86 .52239 Mdot
.86 .52397 Mdot
.86 .52417 Mdot
.86 .52439 Mdot
.86 .52453 Mdot
.86 .52465 Mdot
.86 .52476 Mdot
.86 .52507 Mdot
.86 .52514 Mdot
.86 .52553 Mdot
.86 .52559 Mdot
.86 .52562 Mdot
.86 .52594 Mdot
.86 .52595 Mdot
.86 .52599 Mdot
.86 .52603 Mdot
.86 .52604 Mdot
.86 .5267 Mdot
.86 .5277 Mdot
.86 .52823 Mdot
.86 .53028 Mdot
.86 .53066 Mdot
.86 .53126 Mdot
.86 .53204 Mdot
.86 .5325 Mdot
.86 .53273 Mdot
.86 .53303 Mdot
.86 .53329 Mdot
.86 .53408 Mdot
.86 .53617 Mdot
.86 .53642 Mdot
.86 .53718 Mdot
.86 .5379 Mdot
.86 .53936 Mdot
.86 .53953 Mdot
.86 .53979 Mdot
.86 .53982 Mdot
.86 .53994 Mdot
.86 .54089 Mdot
.86 .54156 Mdot
.86 .5416 Mdot
.86 .54218 Mdot
.86 .54319 Mdot
.86 .54374 Mdot
.86 .54393 Mdot
.86 .54422 Mdot
.86 .545 Mdot
.86 .54508 Mdot
.86 .54522 Mdot
.86 .5458 Mdot
.86 .54647 Mdot
.86 .54689 Mdot
.86 .54689 Mdot
.86 .5469 Mdot
.86 .54691 Mdot
.86 .54691 Mdot
.86 .54699 Mdot
.86 .54702 Mdot
.86 .54711 Mdot
.86 .54713 Mdot
.86 .54721 Mdot
.86 .54724 Mdot
.86 .54727 Mdot
.86 .5473 Mdot
.86 .54736 Mdot
.86 .54741 Mdot
.86 .54785 Mdot
.86 .54842 Mdot
.86 .54864 Mdot
.86 .54876 Mdot
.86 .54975 Mdot
.86 .54978 Mdot
.86 .55003 Mdot
.86 .55011 Mdot
.86 .55015 Mdot
.86 .55026 Mdot
.86 .55033 Mdot
.86 .55061 Mdot
.86 .55066 Mdot
.86 .55066 Mdot
.86 .55071 Mdot
.86 .55078 Mdot
.86 .55095 Mdot
.86 .55095 Mdot
.86 .55103 Mdot
.86 .55115 Mdot
.86 .55136 Mdot
.86 .55148 Mdot
.86 .55162 Mdot
.86 .55197 Mdot
.86 .55264 Mdot
.86 .55274 Mdot
.86 .55275 Mdot
.86 .55302 Mdot
.86 .55357 Mdot
.86 .55437 Mdot
.86 .5547 Mdot
.86 .55478 Mdot
.86 .55569 Mdot
.86 .55574 Mdot
.86 .55575 Mdot
.86 .55611 Mdot
.86 .55628 Mdot
.86 .55643 Mdot
.86 .55648 Mdot
.86 .5566 Mdot
.86 .55664 Mdot
.86 .55674 Mdot
.86 .55685 Mdot
.86 .55749 Mdot
.86 .55757 Mdot
.86 .55781 Mdot
.86 .55798 Mdot
.86 .55801 Mdot
.86 .55849 Mdot
.86 .55869 Mdot
.86 .55888 Mdot
.86 .55893 Mdot
.86 .55915 Mdot
.86 .56 Mdot
.86 .56062 Mdot
.86 .56074 Mdot
.86 .56103 Mdot
.86 .56136 Mdot
.86 .56138 Mdot
.86 .56173 Mdot
.86 .562 Mdot
.86 .56249 Mdot
.86 .56313 Mdot
.86 .56314 Mdot
.86 .56324 Mdot
.86 .56356 Mdot
.86 .56389 Mdot
.86 .56401 Mdot
.86 .56532 Mdot
.86 .56539 Mdot
.86 .56555 Mdot
.86 .56557 Mdot
.86 .56568 Mdot
.86 .56569 Mdot
.86 .56634 Mdot
.86 .56644 Mdot
.86 .56717 Mdot
.86 .56728 Mdot
.86 .56783 Mdot
.86 .56844 Mdot
.86 .56877 Mdot
.86 .56893 Mdot
.86 .56908 Mdot
.86 .56969 Mdot
.86 .56985 Mdot
.86 .57018 Mdot
.86 .57043 Mdot
.86 .57097 Mdot
.86 .57134 Mdot
.86 .57141 Mdot
.86 .57156 Mdot
.86 .57194 Mdot
.86 .57195 Mdot
.86 .5724 Mdot
.86 .57244 Mdot
.86 .57277 Mdot
.86 .57282 Mdot
.86 .57309 Mdot
.86 .57313 Mdot
.86 .57327 Mdot
.86 .57371 Mdot
.86 .57438 Mdot
.86 .57508 Mdot
.86 .57562 Mdot
.86 .57574 Mdot
.86 .5758 Mdot
.86 .57587 Mdot
.86 .57603 Mdot
.86 .57625 Mdot
.86 .57632 Mdot
.86 .57633 Mdot
.86 .57649 Mdot
.86 .57676 Mdot
.86 .577 Mdot
.86 .57726 Mdot
.86 .578 Mdot
.86 .57805 Mdot
.86 .57847 Mdot
.86 .57847 Mdot
.86 .57861 Mdot
.86 .57863 Mdot
.86 .57866 Mdot
.86 .57869 Mdot
.86 .57918 Mdot
.86 .57919 Mdot
.86 .57934 Mdot
.86 .57936 Mdot
.86 .57941 Mdot
.86 .57952 Mdot
.86 .57953 Mdot
.86 .57958 Mdot
.86 .57963 Mdot
.86 .57964 Mdot
.86 .57967 Mdot
.86 .58004 Mdot
.86 .58007 Mdot
.86 .58014 Mdot
.86 .58032 Mdot
.86 .58059 Mdot
.86 .5806 Mdot
.86 .58068 Mdot
.86 .58074 Mdot
.86 .58104 Mdot
.86 .58111 Mdot
.86 .58116 Mdot
.86 .5813 Mdot
.86 .58135 Mdot
.86 .58137 Mdot
.86 .58144 Mdot
.86 .58147 Mdot
.86 .58168 Mdot
.86 .58189 Mdot
.86 .5819 Mdot
.86 .58199 Mdot
.86 .58244 Mdot
.86 .58276 Mdot
.86 .58276 Mdot
.86 .5828 Mdot
.86 .58337 Mdot
.86 .58344 Mdot
.86 .58345 Mdot
.86 .58346 Mdot
.86 .58357 Mdot
.86 .5838 Mdot
.86 .5839 Mdot
.86 .58395 Mdot
.86 .58407 Mdot
.86 .58413 Mdot
.86 .58415 Mdot
.86 .58422 Mdot
.86 .58429 Mdot
.86 .58433 Mdot
.86 .5844 Mdot
.86 .58452 Mdot
.86 .58473 Mdot
.86 .58484 Mdot
.86 .58492 Mdot
.86 .58496 Mdot
.86 .58512 Mdot
.86 .58514 Mdot
.86 .58523 Mdot
.86 .58523 Mdot
.86 .58536 Mdot
.86 .58543 Mdot
.86 .58543 Mdot
.86 .58567 Mdot
.86 .58569 Mdot
.86 .5857 Mdot
.86 .58572 Mdot
.86 .58574 Mdot
.86 .58579 Mdot
.86 .58581 Mdot
.86 .58591 Mdot
.86 .58592 Mdot
.86 .58593 Mdot
.86 .58593 Mdot
.86 .58594 Mdot
.86 .58595 Mdot
.86 .58602 Mdot
.86 .58602 Mdot
.86 .58602 Mdot
.86 .58611 Mdot
.86 .58615 Mdot
.86 .58631 Mdot
.86 .58631 Mdot
.86 .58632 Mdot
.86 .58644 Mdot
.86 .58646 Mdot
.86 .58648 Mdot
.86 .58649 Mdot
.86 .5865 Mdot
.86 .5865 Mdot
.86 .58653 Mdot
.86 .58655 Mdot
.86 .58656 Mdot
.86 .58658 Mdot
.86 .58659 Mdot
.86 .58667 Mdot
.86 .58669 Mdot
.86 .5867 Mdot
.86 .58675 Mdot
.86 .58679 Mdot
.86 .5868 Mdot
.86 .58681 Mdot
.86 .58681 Mdot
.86 .58681 Mdot
.86 .58682 Mdot
.86 .58682 Mdot
.86 .58683 Mdot
.86 .58683 Mdot
.86 .58684 Mdot
.86 .58684 Mdot
.86 .58684 Mdot
.86 .58684 Mdot
.86 .58684 Mdot
.862 .07616 Mdot
.862 .07616 Mdot
.862 .07617 Mdot
.862 .07617 Mdot
.862 .07618 Mdot
.862 .07619 Mdot
.862 .07622 Mdot
.862 .07627 Mdot
.862 .07632 Mdot
.862 .07636 Mdot
.862 .07646 Mdot
.862 .07655 Mdot
.862 .07656 Mdot
.862 .07664 Mdot
.862 .07665 Mdot
.862 .07669 Mdot
.862 .07678 Mdot
.862 .07685 Mdot
.862 .07691 Mdot
.862 .07718 Mdot
.862 .07722 Mdot
.862 .07733 Mdot
.862 .07746 Mdot
.862 .07776 Mdot
.862 .07782 Mdot
.862 .07782 Mdot
.862 .07785 Mdot
.862 .07802 Mdot
.862 .07804 Mdot
.862 .0781 Mdot
.862 .07827 Mdot
.862 .07827 Mdot
.862 .07834 Mdot
.862 .07837 Mdot
.862 .07861 Mdot
.862 .07936 Mdot
.862 .07941 Mdot
.862 .07961 Mdot
.862 .0797 Mdot
.862 .08071 Mdot
.862 .08144 Mdot
.862 .08188 Mdot
.862 .08195 Mdot
.862 .08199 Mdot
.862 .08202 Mdot
.862 .0821 Mdot
.862 .08252 Mdot
.862 .08255 Mdot
.862 .0836 Mdot
.862 .08369 Mdot
.862 .08392 Mdot
.862 .08422 Mdot
.862 .08432 Mdot
.862 .08433 Mdot
.862 .08441 Mdot
.862 .08457 Mdot
.862 .08464 Mdot
.862 .08531 Mdot
.862 .08532 Mdot
.862 .08551 Mdot
.862 .08611 Mdot
.862 .08625 Mdot
.862 .08798 Mdot
.862 .08803 Mdot
.862 .08808 Mdot
.862 .08834 Mdot
.862 .08841 Mdot
.862 .08848 Mdot
.862 .08979 Mdot
.862 .09032 Mdot
.862 .0905 Mdot
.862 .09134 Mdot
.862 .09138 Mdot
.862 .09142 Mdot
.862 .09265 Mdot
.862 .09328 Mdot
.862 .09483 Mdot
.862 .09513 Mdot
.862 .09588 Mdot
.862 .09709 Mdot
.862 .09748 Mdot
.862 .09752 Mdot
.862 .09829 Mdot
.862 .09966 Mdot
.862 .10184 Mdot
.862 .10217 Mdot
.862 .1031 Mdot
.862 .1033 Mdot
.862 .10348 Mdot
.862 .10404 Mdot
.862 .1052 Mdot
.862 .10539 Mdot
.862 .10555 Mdot
.862 .10576 Mdot
.862 .10634 Mdot
.862 .10696 Mdot
.862 .10699 Mdot
.862 .10817 Mdot
.862 .10834 Mdot
.862 .10968 Mdot
.862 .1106 Mdot
.862 .11082 Mdot
.862 .11151 Mdot
.862 .11309 Mdot
.862 .11338 Mdot
.862 .11339 Mdot
.862 .11474 Mdot
.862 .11688 Mdot
.862 .11759 Mdot
.862 .11896 Mdot
.862 .12019 Mdot
.862 .12077 Mdot
.862 .12079 Mdot
.862 .12115 Mdot
.862 .12156 Mdot
.862 .12185 Mdot
.862 .12199 Mdot
.862 .12313 Mdot
.862 .12343 Mdot
.862 .1237 Mdot
.862 .12381 Mdot
.862 .12594 Mdot
.862 .12681 Mdot
.862 .12694 Mdot
.862 .127 Mdot
.862 .12748 Mdot
.862 .1279 Mdot
.862 .12818 Mdot
.862 .1303 Mdot
.862 .13074 Mdot
.862 .13169 Mdot
.862 .13347 Mdot
.862 .13444 Mdot
.862 .13451 Mdot
.862 .13474 Mdot
.862 .13572 Mdot
.862 .13614 Mdot
.862 .13765 Mdot
.862 .13826 Mdot
.862 .1398 Mdot
.862 .14115 Mdot
.862 .14121 Mdot
.862 .14264 Mdot
.862 .14265 Mdot
.862 .14343 Mdot
.862 .14605 Mdot
.862 .1462 Mdot
.862 .14655 Mdot
.862 .14672 Mdot
.862 .14777 Mdot
.862 .14837 Mdot
.862 .14839 Mdot
.862 .14914 Mdot
.862 .15001 Mdot
.862 .15092 Mdot
.862 .15129 Mdot
.862 .15142 Mdot
.862 .15164 Mdot
.862 .1532 Mdot
.862 .15388 Mdot
.862 .15465 Mdot
.862 .15588 Mdot
.862 .15631 Mdot
.862 .15714 Mdot
.862 .15751 Mdot
.862 .15755 Mdot
.862 .15792 Mdot
.862 .15799 Mdot
.862 .15887 Mdot
.862 .15972 Mdot
.862 .16035 Mdot
.862 .16042 Mdot
.862 .16058 Mdot
.862 .16099 Mdot
.862 .16126 Mdot
.862 .1621 Mdot
.862 .16235 Mdot
.862 .16331 Mdot
.862 .16512 Mdot
.862 .16583 Mdot
.862 .16642 Mdot
.862 .16672 Mdot
.862 .16701 Mdot
.862 .16761 Mdot
.862 .16872 Mdot
.862 .17131 Mdot
.862 .17144 Mdot
.862 .17743 Mdot
.862 .17753 Mdot
.862 .17878 Mdot
.862 .17936 Mdot
.862 .18238 Mdot
.862 .18472 Mdot
.862 .18658 Mdot
.862 .18738 Mdot
.862 .18842 Mdot
.862 .18905 Mdot
.862 .18922 Mdot
.862 .18962 Mdot
.862 .19182 Mdot
.862 .19394 Mdot
.862 .19471 Mdot
.862 .19529 Mdot
.862 .19656 Mdot
.862 .19662 Mdot
.862 .19802 Mdot
.862 .19877 Mdot
.862 .19882 Mdot
.862 .19882 Mdot
.862 .19911 Mdot
.862 .19982 Mdot
.862 .19985 Mdot
.862 .20077 Mdot
.862 .20143 Mdot
.862 .20177 Mdot
.862 .20202 Mdot
.862 .20224 Mdot
.862 .20382 Mdot
.862 .20416 Mdot
.862 .20416 Mdot
.862 .20421 Mdot
.862 .20473 Mdot
.862 .20635 Mdot
.862 .20763 Mdot
.862 .20885 Mdot
.862 .20888 Mdot
.862 .20944 Mdot
.862 .20991 Mdot
.862 .21002 Mdot
.862 .21034 Mdot
.862 .21113 Mdot
.862 .21304 Mdot
.862 .21366 Mdot
.862 .21438 Mdot
.862 .21486 Mdot
.862 .21527 Mdot
.862 .21564 Mdot
.862 .21572 Mdot
.862 .21655 Mdot
.862 .21668 Mdot
.862 .21751 Mdot
.862 .21849 Mdot
.862 .21858 Mdot
.862 .21896 Mdot
.862 .21948 Mdot
.862 .21998 Mdot
.862 .22031 Mdot
.862 .2204 Mdot
.862 .22047 Mdot
.862 .22048 Mdot
.862 .22054 Mdot
.862 .22056 Mdot
.862 .22163 Mdot
.862 .22423 Mdot
.862 .22431 Mdot
.862 .22767 Mdot
.862 .22877 Mdot
.862 .22878 Mdot
.862 .2288 Mdot
.862 .2288 Mdot
.862 .22882 Mdot
.862 .22885 Mdot
.862 .22895 Mdot
.862 .2291 Mdot
.862 .22926 Mdot
.862 .22937 Mdot
.862 .2297 Mdot
.862 .22996 Mdot
.862 .22999 Mdot
.862 .23025 Mdot
.862 .23027 Mdot
.862 .23038 Mdot
.862 .23066 Mdot
.862 .23088 Mdot
.862 .23107 Mdot
.862 .23191 Mdot
.862 .23201 Mdot
.862 .23237 Mdot
.862 .23276 Mdot
.862 .23316 Mdot
.862 .23367 Mdot
.862 .23385 Mdot
.862 .23385 Mdot
.862 .23395 Mdot
.862 .23446 Mdot
.862 .23453 Mdot
.862 .23471 Mdot
.862 .23493 Mdot
.862 .23522 Mdot
.862 .23523 Mdot
.862 .23546 Mdot
.862 .23555 Mdot
.862 .23555 Mdot
.862 .23581 Mdot
.862 .23628 Mdot
.862 .23669 Mdot
.862 .23783 Mdot
.862 .23855 Mdot
.862 .23868 Mdot
.862 .2393 Mdot
.862 .23956 Mdot
.862 .24264 Mdot
.862 .24478 Mdot
.862 .24483 Mdot
.862 .24616 Mdot
.862 .24637 Mdot
.862 .24648 Mdot
.862 .24659 Mdot
.862 .2468 Mdot
.862 .24808 Mdot
.862 .24817 Mdot
.862 .24849 Mdot
.862 .24859 Mdot
.862 .2488 Mdot
.862 .24882 Mdot
.862 .24906 Mdot
.862 .24938 Mdot
.862 .24988 Mdot
.862 .25052 Mdot
.862 .25129 Mdot
.862 .25155 Mdot
.862 .25225 Mdot
.862 .2523 Mdot
.862 .25315 Mdot
.862 .25345 Mdot
.862 .25346 Mdot
.862 .2537 Mdot
.862 .25412 Mdot
.862 .25419 Mdot
.862 .25439 Mdot
.862 .25546 Mdot
.862 .25579 Mdot
.862 .25639 Mdot
.862 .25641 Mdot
.862 .25698 Mdot
.862 .25873 Mdot
.862 .25916 Mdot
.862 .25926 Mdot
.862 .25972 Mdot
.862 .26051 Mdot
.862 .26094 Mdot
.862 .26224 Mdot
.862 .26269 Mdot
.862 .26423 Mdot
.862 .26436 Mdot
.862 .26451 Mdot
.862 .26528 Mdot
.862 .26548 Mdot
.862 .26566 Mdot
.862 .26567 Mdot
.862 .26596 Mdot
.862 .26728 Mdot
.862 .26764 Mdot
.862 .26877 Mdot
.862 .26949 Mdot
.862 .27052 Mdot
.862 .27103 Mdot
.862 .27155 Mdot
.862 .27232 Mdot
.862 .27242 Mdot
.862 .27313 Mdot
.862 .27397 Mdot
.862 .27407 Mdot
.862 .27418 Mdot
.862 .27536 Mdot
.862 .27548 Mdot
.862 .27772 Mdot
.862 .27866 Mdot
.862 .2792 Mdot
.862 .2795 Mdot
.862 .28235 Mdot
.862 .28285 Mdot
.862 .28392 Mdot
.862 .28478 Mdot
.862 .28524 Mdot
.862 .28642 Mdot
.862 .28684 Mdot
.862 .28688 Mdot
.862 .28857 Mdot
.862 .29029 Mdot
.862 .29064 Mdot
.862 .29076 Mdot
.862 .29138 Mdot
.862 .29148 Mdot
.862 .2928 Mdot
.862 .29364 Mdot
.862 .29425 Mdot
.862 .2953 Mdot
.862 .29744 Mdot
.862 .29969 Mdot
.862 .30007 Mdot
.862 .30021 Mdot
.862 .30089 Mdot
.862 .30205 Mdot
.862 .30345 Mdot
.862 .30368 Mdot
.862 .30435 Mdot
.862 .30501 Mdot
.862 .30615 Mdot
.862 .30643 Mdot
.862 .30688 Mdot
.862 .30743 Mdot
.862 .30792 Mdot
.862 .30811 Mdot
.862 .30827 Mdot
.862 .30829 Mdot
.862 .30942 Mdot
.862 .30954 Mdot
.862 .31256 Mdot
.862 .31308 Mdot
.862 .31348 Mdot
.862 .31352 Mdot
.862 .31406 Mdot
.862 .31552 Mdot
.862 .31562 Mdot
.862 .31634 Mdot
.862 .31729 Mdot
.862 .31729 Mdot
.862 .31737 Mdot
.862 .31777 Mdot
.862 .31834 Mdot
.862 .31851 Mdot
.862 .31858 Mdot
.862 .31908 Mdot
.862 .32051 Mdot
.862 .32094 Mdot
.862 .3211 Mdot
.862 .32449 Mdot
.862 .32453 Mdot
.862 .32458 Mdot
.862 .32468 Mdot
.862 .32527 Mdot
.862 .32693 Mdot
.862 .32739 Mdot
.862 .32749 Mdot
.862 .32848 Mdot
.862 .32849 Mdot
.862 .32869 Mdot
.862 .32931 Mdot
.862 .33124 Mdot
.862 .33148 Mdot
.862 .33155 Mdot
.862 .33341 Mdot
.862 .33414 Mdot
.862 .33418 Mdot
.862 .33687 Mdot
.862 .3371 Mdot
.862 .33765 Mdot
.862 .33881 Mdot
.862 .34175 Mdot
.862 .34196 Mdot
.862 .34279 Mdot
.862 .34313 Mdot
.862 .34419 Mdot
.862 .34454 Mdot
.862 .34493 Mdot
.862 .34713 Mdot
.862 .34838 Mdot
.862 .34853 Mdot
.862 .35146 Mdot
.862 .3529 Mdot
.862 .35296 Mdot
.862 .35385 Mdot
.862 .35487 Mdot
.862 .35528 Mdot
.862 .35537 Mdot
.862 .35559 Mdot
.862 .35592 Mdot
.862 .35689 Mdot
.862 .35874 Mdot
.862 .35949 Mdot
.862 .36014 Mdot
.862 .3604 Mdot
.862 .36225 Mdot
.862 .3637 Mdot
.862 .36523 Mdot
.862 .36559 Mdot
.862 .36587 Mdot
.862 .36704 Mdot
.862 .36768 Mdot
.862 .36799 Mdot
.862 .36814 Mdot
.862 .36829 Mdot
.862 .36832 Mdot
.862 .36929 Mdot
.862 .37031 Mdot
.862 .37097 Mdot
.862 .37228 Mdot
.862 .37535 Mdot
.862 .37582 Mdot
.862 .37602 Mdot
.862 .37705 Mdot
.862 .37784 Mdot
.862 .37908 Mdot
.862 .37929 Mdot
.862 .3809 Mdot
.862 .38115 Mdot
.862 .38177 Mdot
.862 .38247 Mdot
.862 .38343 Mdot
.862 .3842 Mdot
.862 .38567 Mdot
.862 .38584 Mdot
.862 .38599 Mdot
.862 .38637 Mdot
.862 .38752 Mdot
.862 .38863 Mdot
.862 .38958 Mdot
.862 .39039 Mdot
.862 .3907 Mdot
.862 .39139 Mdot
.862 .39302 Mdot
.862 .39354 Mdot
.862 .39406 Mdot
.862 .39439 Mdot
.862 .39787 Mdot
.862 .40065 Mdot
.862 .40087 Mdot
.862 .40099 Mdot
.862 .40286 Mdot
.862 .40415 Mdot
.862 .40418 Mdot
.862 .40502 Mdot
.862 .40589 Mdot
.862 .40604 Mdot
.862 .40704 Mdot
.862 .40973 Mdot
.862 .41012 Mdot
.862 .41158 Mdot
.862 .41172 Mdot
.862 .4119 Mdot
.862 .41221 Mdot
.862 .41265 Mdot
.862 .413 Mdot
.862 .41338 Mdot
.862 .41525 Mdot
.862 .41639 Mdot
.862 .41654 Mdot
.862 .41658 Mdot
.862 .41673 Mdot
.862 .41817 Mdot
.862 .41836 Mdot
.862 .41993 Mdot
.862 .42 Mdot
.862 .42191 Mdot
.862 .42268 Mdot
.862 .42296 Mdot
.862 .42341 Mdot
.862 .42446 Mdot
.862 .42624 Mdot
.862 .42664 Mdot
.862 .42803 Mdot
.862 .42928 Mdot
.862 .42962 Mdot
.862 .43158 Mdot
.862 .4321 Mdot
.862 .43243 Mdot
.862 .4329 Mdot
.862 .43297 Mdot
.862 .43313 Mdot
.862 .43377 Mdot
.862 .43424 Mdot
.862 .43464 Mdot
.862 .43539 Mdot
.862 .43547 Mdot
.862 .43622 Mdot
.862 .43635 Mdot
.862 .43809 Mdot
.862 .43952 Mdot
.862 .43978 Mdot
.862 .44103 Mdot
.862 .44116 Mdot
.862 .44147 Mdot
.862 .44227 Mdot
.862 .44236 Mdot
.862 .4428 Mdot
.862 .44322 Mdot
.862 .44444 Mdot
.862 .44492 Mdot
.862 .44574 Mdot
.862 .44636 Mdot
.862 .44679 Mdot
.862 .44696 Mdot
.862 .44709 Mdot
.862 .44853 Mdot
.862 .44955 Mdot
.862 .45025 Mdot
.862 .45059 Mdot
.862 .45062 Mdot
.862 .4516 Mdot
.862 .45271 Mdot
.862 .45273 Mdot
.862 .45328 Mdot
.862 .45381 Mdot
.862 .45456 Mdot
.862 .45463 Mdot
.862 .45494 Mdot
.862 .45526 Mdot
.862 .45656 Mdot
.862 .457 Mdot
.862 .45845 Mdot
.862 .4611 Mdot
.862 .46133 Mdot
.862 .46165 Mdot
.862 .46176 Mdot
.862 .46199 Mdot
.862 .46242 Mdot
.862 .46354 Mdot
.862 .46503 Mdot
.862 .46589 Mdot
.862 .46805 Mdot
.862 .4688 Mdot
.862 .46957 Mdot
.862 .46973 Mdot
.862 .47114 Mdot
.862 .47169 Mdot
.862 .47191 Mdot
.862 .47266 Mdot
.862 .47284 Mdot
.862 .47408 Mdot
.862 .47453 Mdot
.862 .475 Mdot
.862 .47598 Mdot
.862 .47698 Mdot
.862 .47992 Mdot
.862 .48015 Mdot
.862 .4811 Mdot
.862 .4814 Mdot
.862 .48154 Mdot
.862 .48279 Mdot
.862 .48346 Mdot
.862 .48423 Mdot
.862 .48498 Mdot
.862 .48528 Mdot
.862 .48554 Mdot
.862 .48565 Mdot
.862 .48643 Mdot
.862 .48696 Mdot
.862 .48781 Mdot
.862 .48801 Mdot
.862 .48931 Mdot
.862 .49096 Mdot
.862 .49097 Mdot
.862 .49149 Mdot
.862 .49198 Mdot
.862 .49224 Mdot
.862 .49287 Mdot
.862 .49347 Mdot
.862 .49565 Mdot
.862 .49627 Mdot
.862 .49631 Mdot
.862 .49901 Mdot
.862 .49957 Mdot
.862 .5006 Mdot
.862 .50073 Mdot
.862 .50128 Mdot
.862 .50161 Mdot
.862 .50169 Mdot
.862 .50285 Mdot
.862 .50351 Mdot
.862 .5036 Mdot
.862 .50566 Mdot
.862 .50568 Mdot
.862 .50578 Mdot
.862 .50676 Mdot
.862 .50683 Mdot
.862 .50684 Mdot
.862 .50725 Mdot
.862 .50806 Mdot
.862 .50829 Mdot
.862 .50832 Mdot
.862 .50834 Mdot
.862 .50964 Mdot
.862 .5104 Mdot
.862 .51059 Mdot
.862 .51061 Mdot
.862 .51068 Mdot
.862 .51089 Mdot
.862 .51107 Mdot
.862 .51143 Mdot
.862 .51173 Mdot
.862 .51249 Mdot
.862 .51395 Mdot
.862 .51441 Mdot
.862 .51442 Mdot
.862 .51448 Mdot
.862 .5151 Mdot
.862 .5152 Mdot
.862 .51562 Mdot
.862 .5161 Mdot
.862 .5167 Mdot
.862 .51712 Mdot
.862 .51737 Mdot
.862 .51742 Mdot
.862 .51756 Mdot
.862 .51914 Mdot
.862 .51952 Mdot
.862 .52004 Mdot
.862 .52077 Mdot
.862 .52081 Mdot
.862 .52155 Mdot
.862 .52217 Mdot
.862 .52232 Mdot
.862 .52274 Mdot
.862 .52358 Mdot
.862 .52376 Mdot
.862 .52486 Mdot
.862 .52505 Mdot
.862 .52616 Mdot
.862 .52621 Mdot
.862 .52698 Mdot
.862 .52723 Mdot
.862 .52726 Mdot
.862 .52789 Mdot
.862 .52849 Mdot
.862 .52888 Mdot
.862 .529 Mdot
.862 .52946 Mdot
.862 .52956 Mdot
.862 .53057 Mdot
.862 .53073 Mdot
.862 .53117 Mdot
.862 .53132 Mdot
.862 .53159 Mdot
.862 .53174 Mdot
.862 .53292 Mdot
.862 .53303 Mdot
.862 .53348 Mdot
.862 .5341 Mdot
.862 .53469 Mdot
.862 .53491 Mdot
.862 .53507 Mdot
.862 .53518 Mdot
.862 .53526 Mdot
.862 .53527 Mdot
.862 .53534 Mdot
.862 .53537 Mdot
.862 .53661 Mdot
.862 .53891 Mdot
.862 .53928 Mdot
.862 .53957 Mdot
.862 .53966 Mdot
.862 .53986 Mdot
.862 .54044 Mdot
.862 .54223 Mdot
.862 .54298 Mdot
.862 .54332 Mdot
.862 .54334 Mdot
.862 .54418 Mdot
.862 .54452 Mdot
.862 .54453 Mdot
.862 .54455 Mdot
.862 .54455 Mdot
.862 .54458 Mdot
.862 .5446 Mdot
.862 .54471 Mdot
.862 .54487 Mdot
.862 .54504 Mdot
.862 .54516 Mdot
.862 .54519 Mdot
.862 .5455 Mdot
.862 .54577 Mdot
.862 .54581 Mdot
.862 .54607 Mdot
.862 .5461 Mdot
.862 .54622 Mdot
.862 .54635 Mdot
.862 .5465 Mdot
.862 .54673 Mdot
.862 .54693 Mdot
.862 .54753 Mdot
.862 .54778 Mdot
.862 .54789 Mdot
.862 .54792 Mdot
.862 .54807 Mdot
.862 .54825 Mdot
.862 .54826 Mdot
.862 .54864 Mdot
.862 .54905 Mdot
.862 .54956 Mdot
.862 .54972 Mdot
.862 .54974 Mdot
.862 .54974 Mdot
.862 .54984 Mdot
.862 .55034 Mdot
.862 .55041 Mdot
.862 .55048 Mdot
.862 .55059 Mdot
.862 .5508 Mdot
.862 .55109 Mdot
.862 .55109 Mdot
.862 .55132 Mdot
.862 .55141 Mdot
.862 .55141 Mdot
.862 .55142 Mdot
.862 .55166 Mdot
.862 .55209 Mdot
.862 .55211 Mdot
.862 .55251 Mdot
.862 .55269 Mdot
.862 .55293 Mdot
.862 .55358 Mdot
.862 .55426 Mdot
.862 .55439 Mdot
.862 .55444 Mdot
.862 .55463 Mdot
.862 .55495 Mdot
.862 .5552 Mdot
.862 .55577 Mdot
.862 .55649 Mdot
.862 .55741 Mdot
.862 .55758 Mdot
.862 .55796 Mdot
.862 .558 Mdot
.862 .55981 Mdot
.862 .55985 Mdot
.862 .56063 Mdot
.862 .56096 Mdot
.862 .56114 Mdot
.862 .56123 Mdot
.862 .56132 Mdot
.862 .56149 Mdot
.862 .56171 Mdot
.862 .56225 Mdot
.862 .56254 Mdot
.862 .56261 Mdot
.862 .56286 Mdot
.862 .56294 Mdot
.862 .56307 Mdot
.862 .56311 Mdot
.862 .56313 Mdot
.862 .56332 Mdot
.862 .56357 Mdot
.862 .56383 Mdot
.862 .56385 Mdot
.862 .56396 Mdot
.862 .56398 Mdot
.862 .56409 Mdot
.862 .56433 Mdot
.862 .56446 Mdot
.862 .56482 Mdot
.862 .56505 Mdot
.862 .56525 Mdot
.862 .56571 Mdot
.862 .56578 Mdot
.862 .56582 Mdot
.862 .56592 Mdot
.862 .56619 Mdot
.862 .56645 Mdot
.862 .56667 Mdot
.862 .56668 Mdot
.862 .56685 Mdot
.862 .56716 Mdot
.862 .56721 Mdot
.862 .56731 Mdot
.862 .56735 Mdot
.862 .56812 Mdot
.862 .56835 Mdot
.862 .56835 Mdot
.862 .56877 Mdot
.862 .56879 Mdot
.862 .56918 Mdot
.862 .56963 Mdot
.862 .5698 Mdot
.862 .57024 Mdot
.862 .57036 Mdot
.862 .57065 Mdot
.862 .57071 Mdot
.862 .57074 Mdot
.862 .57102 Mdot
.862 .57153 Mdot
.862 .5718 Mdot
.862 .57193 Mdot
.862 .57254 Mdot
.862 .57262 Mdot
.862 .57274 Mdot
.862 .57288 Mdot
.862 .57289 Mdot
.862 .57293 Mdot
.862 .57318 Mdot
.862 .57379 Mdot
.862 .57382 Mdot
.862 .5739 Mdot
.862 .57398 Mdot
.862 .57431 Mdot
.862 .57435 Mdot
.862 .57443 Mdot
.862 .57455 Mdot
.862 .57465 Mdot
.862 .57466 Mdot
.862 .57482 Mdot
.862 .57517 Mdot
.862 .57556 Mdot
.862 .57576 Mdot
.862 .57637 Mdot
.862 .57675 Mdot
.862 .57675 Mdot
.862 .57684 Mdot
.862 .57728 Mdot
.862 .57748 Mdot
.862 .57754 Mdot
.862 .5778 Mdot
.862 .57818 Mdot
.862 .57822 Mdot
.862 .57855 Mdot
.862 .57856 Mdot
.862 .57874 Mdot
.862 .5789 Mdot
.862 .57896 Mdot
.862 .579 Mdot
.862 .57906 Mdot
.862 .57938 Mdot
.862 .57954 Mdot
.862 .57959 Mdot
.862 .57964 Mdot
.862 .5799 Mdot
.862 .57999 Mdot
.862 .5806 Mdot
.862 .58098 Mdot
.862 .5812 Mdot
.862 .58121 Mdot
.862 .58132 Mdot
.862 .58165 Mdot
.862 .58186 Mdot
.862 .58195 Mdot
.862 .58238 Mdot
.862 .58255 Mdot
.862 .58289 Mdot
.862 .5829 Mdot
.862 .58291 Mdot
.862 .58314 Mdot
.862 .58319 Mdot
.862 .58334 Mdot
.862 .5837 Mdot
.862 .58372 Mdot
.862 .58374 Mdot
.862 .58381 Mdot
.862 .58382 Mdot
.862 .58384 Mdot
.862 .58431 Mdot
.862 .58435 Mdot
.862 .58452 Mdot
.862 .58457 Mdot
.862 .58457 Mdot
.862 .58476 Mdot
.862 .58477 Mdot
.862 .58482 Mdot
.862 .58484 Mdot
.862 .58484 Mdot
.862 .58487 Mdot
.862 .58495 Mdot
.862 .58502 Mdot
.862 .58504 Mdot
.862 .58533 Mdot
.862 .58534 Mdot
.862 .58545 Mdot
.862 .58547 Mdot
.862 .58548 Mdot
.862 .58549 Mdot
.862 .58551 Mdot
.862 .58563 Mdot
.862 .58583 Mdot
.862 .58611 Mdot
.862 .58613 Mdot
.862 .58619 Mdot
.862 .5862 Mdot
.862 .5864 Mdot
.862 .58647 Mdot
.862 .58648 Mdot
.862 .5865 Mdot
.862 .5865 Mdot
.862 .58654 Mdot
.862 .58656 Mdot
.862 .58657 Mdot
.862 .58661 Mdot
.862 .58662 Mdot
.862 .58662 Mdot
.862 .58664 Mdot
.862 .58672 Mdot
.862 .58675 Mdot
.862 .58679 Mdot
.862 .58679 Mdot
.862 .58687 Mdot
.862 .58689 Mdot
.862 .58691 Mdot
.862 .58693 Mdot
.862 .58694 Mdot
.862 .58694 Mdot
.862 .58696 Mdot
.862 .58697 Mdot
.862 .58699 Mdot
.862 .58702 Mdot
.862 .58703 Mdot
.862 .58704 Mdot
.862 .58706 Mdot
.862 .58707 Mdot
.862 .58707 Mdot
.862 .58707 Mdot
.862 .58707 Mdot
.862 .58707 Mdot
.862 .58707 Mdot
.864 .07535 Mdot
.864 .07535 Mdot
.864 .07538 Mdot
.864 .07539 Mdot
.864 .07539 Mdot
.864 .07549 Mdot
.864 .07558 Mdot
.864 .07558 Mdot
.864 .0757 Mdot
.864 .0757 Mdot
.864 .07573 Mdot
.864 .07591 Mdot
.864 .07603 Mdot
.864 .07636 Mdot
.864 .07665 Mdot
.864 .07688 Mdot
.864 .07696 Mdot
.864 .07704 Mdot
.864 .07709 Mdot
.864 .07719 Mdot
.864 .07733 Mdot
.864 .07734 Mdot
.864 .07748 Mdot
.864 .07815 Mdot
.864 .07818 Mdot
.864 .07871 Mdot
.864 .0788 Mdot
.864 .07914 Mdot
.864 .07945 Mdot
.864 .0795 Mdot
.864 .08043 Mdot
.864 .08094 Mdot
.864 .08112 Mdot
.864 .08127 Mdot
.864 .08142 Mdot
.864 .08151 Mdot
.864 .08182 Mdot
.864 .0821 Mdot
.864 .08231 Mdot
.864 .08272 Mdot
.864 .08323 Mdot
.864 .08338 Mdot
.864 .08342 Mdot
.864 .08368 Mdot
.864 .08433 Mdot
.864 .08442 Mdot
.864 .08458 Mdot
.864 .08476 Mdot
.864 .08499 Mdot
.864 .08506 Mdot
.864 .08551 Mdot
.864 .08575 Mdot
.864 .08635 Mdot
.864 .08688 Mdot
.864 .08824 Mdot
.864 .0884 Mdot
.864 .08859 Mdot
.864 .08866 Mdot
.864 .08873 Mdot
.864 .08911 Mdot
.864 .08929 Mdot
.864 .08954 Mdot
.864 .08975 Mdot
.864 .08977 Mdot
.864 .08999 Mdot
.864 .09023 Mdot
.864 .09067 Mdot
.864 .09129 Mdot
.864 .09137 Mdot
.864 .09176 Mdot
.864 .09183 Mdot
.864 .09202 Mdot
.864 .09226 Mdot
.864 .09502 Mdot
.864 .09516 Mdot
.864 .09544 Mdot
.864 .09669 Mdot
.864 .09682 Mdot
.864 .09767 Mdot
.864 .09908 Mdot
.864 .09927 Mdot
.864 .0999 Mdot
.864 .1004 Mdot
.864 .10051 Mdot
.864 .10072 Mdot
.864 .10076 Mdot
.864 .10144 Mdot
.864 .10186 Mdot
.864 .10232 Mdot
.864 .10239 Mdot
.864 .10263 Mdot
.864 .10425 Mdot
.864 .1043 Mdot
.864 .10447 Mdot
.864 .10481 Mdot
.864 .1066 Mdot
.864 .10788 Mdot
.864 .10825 Mdot
.864 .10831 Mdot
.864 .10978 Mdot
.864 .10982 Mdot
.864 .1101 Mdot
.864 .11068 Mdot
.864 .11108 Mdot
.864 .11135 Mdot
.864 .11138 Mdot
.864 .11155 Mdot
.864 .11187 Mdot
.864 .11255 Mdot
.864 .11267 Mdot
.864 .11322 Mdot
.864 .11336 Mdot
.864 .11356 Mdot
.864 .11378 Mdot
.864 .11386 Mdot
.864 .11467 Mdot
.864 .11471 Mdot
.864 .11514 Mdot
.864 .11615 Mdot
.864 .1162 Mdot
.864 .11621 Mdot
.864 .11763 Mdot
.864 .11835 Mdot
.864 .11874 Mdot
.864 .11881 Mdot
.864 .11913 Mdot
.864 .12026 Mdot
.864 .12118 Mdot
.864 .12349 Mdot
.864 .12391 Mdot
.864 .12592 Mdot
.864 .12659 Mdot
.864 .12677 Mdot
.864 .12776 Mdot
.864 .12964 Mdot
.864 .1321 Mdot
.864 .13314 Mdot
.864 .13443 Mdot
.864 .13591 Mdot
.864 .13605 Mdot
.864 .13717 Mdot
.864 .13748 Mdot
.864 .13845 Mdot
.864 .13854 Mdot
.864 .1389 Mdot
.864 .14204 Mdot
.864 .14258 Mdot
.864 .14423 Mdot
.864 .14516 Mdot
.864 .14556 Mdot
.864 .14658 Mdot
.864 .1467 Mdot
.864 .14739 Mdot
.864 .14821 Mdot
.864 .15044 Mdot
.864 .1509 Mdot
.864 .15225 Mdot
.864 .1543 Mdot
.864 .15462 Mdot
.864 .15463 Mdot
.864 .15511 Mdot
.864 .15575 Mdot
.864 .15578 Mdot
.864 .15747 Mdot
.864 .15759 Mdot
.864 .15941 Mdot
.864 .15984 Mdot
.864 .16212 Mdot
.864 .16232 Mdot
.864 .16309 Mdot
.864 .16456 Mdot
.864 .16489 Mdot
.864 .16637 Mdot
.864 .16645 Mdot
.864 .16713 Mdot
.864 .16789 Mdot
.864 .16802 Mdot
.864 .16806 Mdot
.864 .16975 Mdot
.864 .17051 Mdot
.864 .17184 Mdot
.864 .17237 Mdot
.864 .17311 Mdot
.864 .17458 Mdot
.864 .17463 Mdot
.864 .17491 Mdot
.864 .17641 Mdot
.864 .17846 Mdot
.864 .17894 Mdot
.864 .17905 Mdot
.864 .18191 Mdot
.864 .18201 Mdot
.864 .18209 Mdot
.864 .18273 Mdot
.864 .18457 Mdot
.864 .18667 Mdot
.864 .18745 Mdot
.864 .18784 Mdot
.864 .1904 Mdot
.864 .19074 Mdot
.864 .19174 Mdot
.864 .19366 Mdot
.864 .19388 Mdot
.864 .19472 Mdot
.864 .19555 Mdot
.864 .19706 Mdot
.864 .19736 Mdot
.864 .19895 Mdot
.864 .19924 Mdot
.864 .19977 Mdot
.864 .20002 Mdot
.864 .20144 Mdot
.864 .20153 Mdot
.864 .20298 Mdot
.864 .20656 Mdot
.864 .20791 Mdot
.864 .20803 Mdot
.864 .20867 Mdot
.864 .20873 Mdot
.864 .2094 Mdot
.864 .21015 Mdot
.864 .2104 Mdot
.864 .21085 Mdot
.864 .21161 Mdot
.864 .2123 Mdot
.864 .21245 Mdot
.864 .21279 Mdot
.864 .2132 Mdot
.864 .21423 Mdot
.864 .21461 Mdot
.864 .2147 Mdot
.864 .21648 Mdot
.864 .21763 Mdot
.864 .21794 Mdot
.864 .21888 Mdot
.864 .21982 Mdot
.864 .22083 Mdot
.864 .22102 Mdot
.864 .22163 Mdot
.864 .22224 Mdot
.864 .22229 Mdot
.864 .22258 Mdot
.864 .2234 Mdot
.864 .22372 Mdot
.864 .22389 Mdot
.864 .22404 Mdot
.864 .22406 Mdot
.864 .22445 Mdot
.864 .22445 Mdot
.864 .22544 Mdot
.864 .22549 Mdot
.864 .22562 Mdot
.864 .22565 Mdot
.864 .22604 Mdot
.864 .22634 Mdot
.864 .22637 Mdot
.864 .22644 Mdot
.864 .22647 Mdot
.864 .22649 Mdot
.864 .22663 Mdot
.864 .22677 Mdot
.864 .22706 Mdot
.864 .22707 Mdot
.864 .22711 Mdot
.864 .22713 Mdot
.864 .22742 Mdot
.864 .22743 Mdot
.864 .22754 Mdot
.864 .22759 Mdot
.864 .22764 Mdot
.864 .22774 Mdot
.864 .22798 Mdot
.864 .22807 Mdot
.864 .22809 Mdot
.864 .22846 Mdot
.864 .2291 Mdot
.864 .22939 Mdot
.864 .22948 Mdot
.864 .22983 Mdot
.864 .23037 Mdot
.864 .2304 Mdot
.864 .23052 Mdot
.864 .23084 Mdot
.864 .23096 Mdot
.864 .23107 Mdot
.864 .23111 Mdot
.864 .23133 Mdot
.864 .23156 Mdot
.864 .2317 Mdot
.864 .23178 Mdot
.864 .23201 Mdot
.864 .23222 Mdot
.864 .23244 Mdot
.864 .23248 Mdot
.864 .2329 Mdot
.864 .23448 Mdot
.864 .23451 Mdot
.864 .23497 Mdot
.864 .23504 Mdot
.864 .23582 Mdot
.864 .23591 Mdot
.864 .2364 Mdot
.864 .23667 Mdot
.864 .23694 Mdot
.864 .23701 Mdot
.864 .23797 Mdot
.864 .23808 Mdot
.864 .23893 Mdot
.864 .23906 Mdot
.864 .23932 Mdot
.864 .24002 Mdot
.864 .24092 Mdot
.864 .24189 Mdot
.864 .24193 Mdot
.864 .2421 Mdot
.864 .2428 Mdot
.864 .24342 Mdot
.864 .24395 Mdot
.864 .24421 Mdot
.864 .2444 Mdot
.864 .24487 Mdot
.864 .24514 Mdot
.864 .24575 Mdot
.864 .24608 Mdot
.864 .24636 Mdot
.864 .24689 Mdot
.864 .24701 Mdot
.864 .24755 Mdot
.864 .24876 Mdot
.864 .2503 Mdot
.864 .25054 Mdot
.864 .25073 Mdot
.864 .25085 Mdot
.864 .25165 Mdot
.864 .25356 Mdot
.864 .25384 Mdot
.864 .25389 Mdot
.864 .2543 Mdot
.864 .25484 Mdot
.864 .25551 Mdot
.864 .25574 Mdot
.864 .25705 Mdot
.864 .2572 Mdot
.864 .25779 Mdot
.864 .25833 Mdot
.864 .25954 Mdot
.864 .2611 Mdot
.864 .26242 Mdot
.864 .2625 Mdot
.864 .26509 Mdot
.864 .26554 Mdot
.864 .2661 Mdot
.864 .2663 Mdot
.864 .2665 Mdot
.864 .26759 Mdot
.864 .26762 Mdot
.864 .26815 Mdot
.864 .26882 Mdot
.864 .26886 Mdot
.864 .26917 Mdot
.864 .26946 Mdot
.864 .26952 Mdot
.864 .27016 Mdot
.864 .27033 Mdot
.864 .27055 Mdot
.864 .27087 Mdot
.864 .27188 Mdot
.864 .27192 Mdot
.864 .27213 Mdot
.864 .27394 Mdot
.864 .27414 Mdot
.864 .27428 Mdot
.864 .27528 Mdot
.864 .27543 Mdot
.864 .27547 Mdot
.864 .27577 Mdot
.864 .27603 Mdot
.864 .27671 Mdot
.864 .27703 Mdot
.864 .27757 Mdot
.864 .27853 Mdot
.864 .28011 Mdot
.864 .28291 Mdot
.864 .28456 Mdot
.864 .28458 Mdot
.864 .28496 Mdot
.864 .28512 Mdot
.864 .28546 Mdot
.864 .28575 Mdot
.864 .28715 Mdot
.864 .28825 Mdot
.864 .28927 Mdot
.864 .28963 Mdot
.864 .29073 Mdot
.864 .29094 Mdot
.864 .29203 Mdot
.864 .29263 Mdot
.864 .29336 Mdot
.864 .29379 Mdot
.864 .29589 Mdot
.864 .29596 Mdot
.864 .29647 Mdot
.864 .29821 Mdot
.864 .29959 Mdot
.864 .29989 Mdot
.864 .30048 Mdot
.864 .30059 Mdot
.864 .30245 Mdot
.864 .3036 Mdot
.864 .30408 Mdot
.864 .30488 Mdot
.864 .30507 Mdot
.864 .30507 Mdot
.864 .30571 Mdot
.864 .30726 Mdot
.864 .31011 Mdot
.864 .31026 Mdot
.864 .3106 Mdot
.864 .31072 Mdot
.864 .31164 Mdot
.864 .3123 Mdot
.864 .31643 Mdot
.864 .31704 Mdot
.864 .31725 Mdot
.864 .31779 Mdot
.864 .31811 Mdot
.864 .31987 Mdot
.864 .32084 Mdot
.864 .321 Mdot
.864 .32354 Mdot
.864 .32448 Mdot
.864 .32488 Mdot
.864 .325 Mdot
.864 .32574 Mdot
.864 .32649 Mdot
.864 .32725 Mdot
.864 .3276 Mdot
.864 .32831 Mdot
.864 .32857 Mdot
.864 .329 Mdot
.864 .32908 Mdot
.864 .32953 Mdot
.864 .33037 Mdot
.864 .33214 Mdot
.864 .33245 Mdot
.864 .33251 Mdot
.864 .33328 Mdot
.864 .33366 Mdot
.864 .33387 Mdot
.864 .33423 Mdot
.864 .33475 Mdot
.864 .33481 Mdot
.864 .33518 Mdot
.864 .33533 Mdot
.864 .33552 Mdot
.864 .33762 Mdot
.864 .33772 Mdot
.864 .33881 Mdot
.864 .3389 Mdot
.864 .34058 Mdot
.864 .3414 Mdot
.864 .34154 Mdot
.864 .34156 Mdot
.864 .34379 Mdot
.864 .34516 Mdot
.864 .34698 Mdot
.864 .34701 Mdot
.864 .34785 Mdot
.864 .34796 Mdot
.864 .34814 Mdot
.864 .34894 Mdot
.864 .34905 Mdot
.864 .34964 Mdot
.864 .34966 Mdot
.864 .35044 Mdot
.864 .35117 Mdot
.864 .35177 Mdot
.864 .35406 Mdot
.864 .35427 Mdot
.864 .35521 Mdot
.864 .35607 Mdot
.864 .35804 Mdot
.864 .35906 Mdot
.864 .35976 Mdot
.864 .36038 Mdot
.864 .36079 Mdot
.864 .3648 Mdot
.864 .36568 Mdot
.864 .36586 Mdot
.864 .3673 Mdot
.864 .36774 Mdot
.864 .36839 Mdot
.864 .36843 Mdot
.864 .36912 Mdot
.864 .37012 Mdot
.864 .3702 Mdot
.864 .37171 Mdot
.864 .37222 Mdot
.864 .37227 Mdot
.864 .37459 Mdot
.864 .37471 Mdot
.864 .37715 Mdot
.864 .37718 Mdot
.864 .37739 Mdot
.864 .38039 Mdot
.864 .38273 Mdot
.864 .38282 Mdot
.864 .38401 Mdot
.864 .3858 Mdot
.864 .38922 Mdot
.864 .38952 Mdot
.864 .38976 Mdot
.864 .39048 Mdot
.864 .39108 Mdot
.864 .39141 Mdot
.864 .39208 Mdot
.864 .39221 Mdot
.864 .39251 Mdot
.864 .39278 Mdot
.864 .39291 Mdot
.864 .39499 Mdot
.864 .39519 Mdot
.864 .39599 Mdot
.864 .39684 Mdot
.864 .40157 Mdot
.864 .40299 Mdot
.864 .40374 Mdot
.864 .40417 Mdot
.864 .40418 Mdot
.864 .40515 Mdot
.864 .40599 Mdot
.864 .40779 Mdot
.864 .40834 Mdot
.864 .40981 Mdot
.864 .41069 Mdot
.864 .41287 Mdot
.864 .41314 Mdot
.864 .41372 Mdot
.864 .41461 Mdot
.864 .41631 Mdot
.864 .41636 Mdot
.864 .41934 Mdot
.864 .42037 Mdot
.864 .42057 Mdot
.864 .42107 Mdot
.864 .42204 Mdot
.864 .42469 Mdot
.864 .42484 Mdot
.864 .42484 Mdot
.864 .42505 Mdot
.864 .42524 Mdot
.864 .42604 Mdot
.864 .42651 Mdot
.864 .42703 Mdot
.864 .42879 Mdot
.864 .42906 Mdot
.864 .42972 Mdot
.864 .42973 Mdot
.864 .42991 Mdot
.864 .43072 Mdot
.864 .43073 Mdot
.864 .432 Mdot
.864 .43201 Mdot
.864 .43207 Mdot
.864 .43379 Mdot
.864 .43549 Mdot
.864 .43565 Mdot
.864 .43573 Mdot
.864 .43716 Mdot
.864 .43841 Mdot
.864 .43935 Mdot
.864 .44019 Mdot
.864 .44231 Mdot
.864 .44456 Mdot
.864 .4446 Mdot
.864 .44465 Mdot
.864 .44471 Mdot
.864 .44505 Mdot
.864 .44519 Mdot
.864 .44597 Mdot
.864 .44653 Mdot
.864 .44702 Mdot
.864 .44794 Mdot
.864 .44935 Mdot
.864 .44998 Mdot
.864 .45036 Mdot
.864 .45065 Mdot
.864 .45279 Mdot
.864 .45295 Mdot
.864 .45421 Mdot
.864 .45469 Mdot
.864 .45524 Mdot
.864 .45564 Mdot
.864 .45589 Mdot
.864 .45594 Mdot
.864 .45596 Mdot
.864 .45711 Mdot
.864 .4591 Mdot
.864 .45972 Mdot
.864 .46048 Mdot
.864 .4614 Mdot
.864 .46229 Mdot
.864 .46292 Mdot
.864 .46332 Mdot
.864 .46387 Mdot
.864 .46473 Mdot
.864 .46497 Mdot
.864 .4652 Mdot
.864 .46559 Mdot
.864 .46568 Mdot
.864 .46578 Mdot
.864 .46586 Mdot
.864 .46783 Mdot
.864 .46793 Mdot
.864 .46842 Mdot
.864 .46985 Mdot
.864 .47106 Mdot
.864 .47355 Mdot
.864 .47463 Mdot
.864 .47501 Mdot
.864 .47546 Mdot
.864 .47565 Mdot
.864 .47663 Mdot
.864 .47876 Mdot
.864 .4805 Mdot
.864 .48068 Mdot
.864 .48081 Mdot
.864 .48116 Mdot
.864 .4813 Mdot
.864 .48156 Mdot
.864 .48188 Mdot
.864 .48438 Mdot
.864 .48493 Mdot
.864 .48721 Mdot
.864 .4873 Mdot
.864 .48731 Mdot
.864 .48835 Mdot
.864 .48937 Mdot
.864 .48939 Mdot
.864 .48961 Mdot
.864 .49024 Mdot
.864 .49069 Mdot
.864 .49097 Mdot
.864 .49099 Mdot
.864 .49204 Mdot
.864 .49248 Mdot
.864 .49429 Mdot
.864 .49483 Mdot
.864 .49525 Mdot
.864 .49604 Mdot
.864 .49639 Mdot
.864 .49677 Mdot
.864 .49801 Mdot
.864 .49831 Mdot
.864 .49862 Mdot
.864 .49862 Mdot
.864 .49886 Mdot
.864 .49934 Mdot
.864 .49967 Mdot
.864 .50095 Mdot
.864 .5022 Mdot
.864 .50286 Mdot
.864 .50431 Mdot
.864 .50445 Mdot
.864 .50489 Mdot
.864 .50504 Mdot
.864 .50534 Mdot
.864 .50685 Mdot
.864 .50722 Mdot
.864 .50764 Mdot
.864 .50841 Mdot
.864 .50877 Mdot
.864 .51081 Mdot
.864 .51093 Mdot
.864 .51113 Mdot
.864 .51121 Mdot
.864 .51298 Mdot
.864 .5136 Mdot
.864 .51484 Mdot
.864 .51564 Mdot
.864 .516 Mdot
.864 .51897 Mdot
.864 .51973 Mdot
.864 .51988 Mdot
.864 .52014 Mdot
.864 .52075 Mdot
.864 .52082 Mdot
.864 .52171 Mdot
.864 .5221 Mdot
.864 .5227 Mdot
.864 .52282 Mdot
.864 .52302 Mdot
.864 .5236 Mdot
.864 .52458 Mdot
.864 .52514 Mdot
.864 .52547 Mdot
.864 .52566 Mdot
.864 .5261 Mdot
.864 .52622 Mdot
.864 .52662 Mdot
.864 .52744 Mdot
.864 .52745 Mdot
.864 .52791 Mdot
.864 .52799 Mdot
.864 .52839 Mdot
.864 .52851 Mdot
.864 .52893 Mdot
.864 .53067 Mdot
.864 .5307 Mdot
.864 .53209 Mdot
.864 .53248 Mdot
.864 .53359 Mdot
.864 .53472 Mdot
.864 .5359 Mdot
.864 .53612 Mdot
.864 .53632 Mdot
.864 .53683 Mdot
.864 .5373 Mdot
.864 .53753 Mdot
.864 .53759 Mdot
.864 .53792 Mdot
.864 .53822 Mdot
.864 .53845 Mdot
.864 .53886 Mdot
.864 .53921 Mdot
.864 .53941 Mdot
.864 .53957 Mdot
.864 .5396 Mdot
.864 .54003 Mdot
.864 .54004 Mdot
.864 .54078 Mdot
.864 .54092 Mdot
.864 .54114 Mdot
.864 .54119 Mdot
.864 .54123 Mdot
.864 .54133 Mdot
.864 .54137 Mdot
.864 .54156 Mdot
.864 .5417 Mdot
.864 .54179 Mdot
.864 .54213 Mdot
.864 .54216 Mdot
.864 .54224 Mdot
.864 .54227 Mdot
.864 .54228 Mdot
.864 .54243 Mdot
.864 .54244 Mdot
.864 .54259 Mdot
.864 .54279 Mdot
.864 .54291 Mdot
.864 .54292 Mdot
.864 .54296 Mdot
.864 .54298 Mdot
.864 .5433 Mdot
.864 .5433 Mdot
.864 .54342 Mdot
.864 .54343 Mdot
.864 .54348 Mdot
.864 .54354 Mdot
.864 .54364 Mdot
.864 .5439 Mdot
.864 .54399 Mdot
.864 .54401 Mdot
.864 .54421 Mdot
.864 .5444 Mdot
.864 .54446 Mdot
.864 .54479 Mdot
.864 .54509 Mdot
.864 .54539 Mdot
.864 .54549 Mdot
.864 .54586 Mdot
.864 .54642 Mdot
.864 .54645 Mdot
.864 .54658 Mdot
.864 .5469 Mdot
.864 .54703 Mdot
.864 .54714 Mdot
.864 .54719 Mdot
.864 .54741 Mdot
.864 .54765 Mdot
.864 .54779 Mdot
.864 .54787 Mdot
.864 .54811 Mdot
.864 .54832 Mdot
.864 .54834 Mdot
.864 .54854 Mdot
.864 .54858 Mdot
.864 .549 Mdot
.864 .55013 Mdot
.864 .55059 Mdot
.864 .55061 Mdot
.864 .55106 Mdot
.864 .55114 Mdot
.864 .5513 Mdot
.864 .55139 Mdot
.864 .55189 Mdot
.864 .55198 Mdot
.864 .55245 Mdot
.864 .55271 Mdot
.864 .55297 Mdot
.864 .55304 Mdot
.864 .55363 Mdot
.864 .55394 Mdot
.864 .55405 Mdot
.864 .55483 Mdot
.864 .55495 Mdot
.864 .55519 Mdot
.864 .55584 Mdot
.864 .5564 Mdot
.864 .5566 Mdot
.864 .55662 Mdot
.864 .55665 Mdot
.864 .55752 Mdot
.864 .55756 Mdot
.864 .5577 Mdot
.864 .55833 Mdot
.864 .55878 Mdot
.864 .55886 Mdot
.864 .55888 Mdot
.864 .55932 Mdot
.864 .55955 Mdot
.864 .55971 Mdot
.864 .56011 Mdot
.864 .56034 Mdot
.864 .56085 Mdot
.864 .56086 Mdot
.864 .5609 Mdot
.864 .56113 Mdot
.864 .56133 Mdot
.864 .56135 Mdot
.864 .5618 Mdot
.864 .5619 Mdot
.864 .56233 Mdot
.864 .56256 Mdot
.864 .56262 Mdot
.864 .5633 Mdot
.864 .56343 Mdot
.864 .56397 Mdot
.864 .56401 Mdot
.864 .56451 Mdot
.864 .56452 Mdot
.864 .56471 Mdot
.864 .56485 Mdot
.864 .56485 Mdot
.864 .56495 Mdot
.864 .56555 Mdot
.864 .56595 Mdot
.864 .56608 Mdot
.864 .56674 Mdot
.864 .56698 Mdot
.864 .56718 Mdot
.864 .56722 Mdot
.864 .56751 Mdot
.864 .56791 Mdot
.864 .56839 Mdot
.864 .56854 Mdot
.864 .56946 Mdot
.864 .56956 Mdot
.864 .56959 Mdot
.864 .56987 Mdot
.864 .56996 Mdot
.864 .57028 Mdot
.864 .57032 Mdot
.864 .57075 Mdot
.864 .57112 Mdot
.864 .57142 Mdot
.864 .57213 Mdot
.864 .57267 Mdot
.864 .57295 Mdot
.864 .57301 Mdot
.864 .5732 Mdot
.864 .57377 Mdot
.864 .57389 Mdot
.864 .57455 Mdot
.864 .57481 Mdot
.864 .57514 Mdot
.864 .57523 Mdot
.864 .57525 Mdot
.864 .57536 Mdot
.864 .57556 Mdot
.864 .57596 Mdot
.864 .57597 Mdot
.864 .57598 Mdot
.864 .57627 Mdot
.864 .57639 Mdot
.864 .5764 Mdot
.864 .57663 Mdot
.864 .57665 Mdot
.864 .57671 Mdot
.864 .57677 Mdot
.864 .57681 Mdot
.864 .57696 Mdot
.864 .577 Mdot
.864 .57719 Mdot
.864 .57728 Mdot
.864 .57733 Mdot
.864 .57734 Mdot
.864 .57741 Mdot
.864 .57753 Mdot
.864 .57769 Mdot
.864 .57777 Mdot
.864 .57778 Mdot
.864 .57819 Mdot
.864 .57821 Mdot
.864 .57831 Mdot
.864 .57867 Mdot
.864 .57917 Mdot
.864 .57927 Mdot
.864 .57932 Mdot
.864 .57933 Mdot
.864 .57979 Mdot
.864 .57985 Mdot
.864 .57987 Mdot
.864 .58 Mdot
.864 .58012 Mdot
.864 .58031 Mdot
.864 .58032 Mdot
.864 .58038 Mdot
.864 .58041 Mdot
.864 .58055 Mdot
.864 .58072 Mdot
.864 .58077 Mdot
.864 .58117 Mdot
.864 .5814 Mdot
.864 .58144 Mdot
.864 .58179 Mdot
.864 .58186 Mdot
.864 .5819 Mdot
.864 .58267 Mdot
.864 .58273 Mdot
.864 .58279 Mdot
.864 .5828 Mdot
.864 .58291 Mdot
.864 .58293 Mdot
.864 .58311 Mdot
.864 .58323 Mdot
.864 .58329 Mdot
.864 .58335 Mdot
.864 .58336 Mdot
.864 .58342 Mdot
.864 .58348 Mdot
.864 .58353 Mdot
.864 .58364 Mdot
.864 .58366 Mdot
.864 .58368 Mdot
.864 .58373 Mdot
.864 .58377 Mdot
.864 .58415 Mdot
.864 .58429 Mdot
.864 .58446 Mdot
.864 .58453 Mdot
.864 .58465 Mdot
.864 .58467 Mdot
.864 .58473 Mdot
.864 .58478 Mdot
.864 .58482 Mdot
.864 .58485 Mdot
.864 .58503 Mdot
.864 .5851 Mdot
.864 .58511 Mdot
.864 .58515 Mdot
.864 .58529 Mdot
.864 .5854 Mdot
.864 .58546 Mdot
.864 .58553 Mdot
.864 .58562 Mdot
.864 .58565 Mdot
.864 .58569 Mdot
.864 .58573 Mdot
.864 .58578 Mdot
.864 .58592 Mdot
.864 .58617 Mdot
.864 .58618 Mdot
.864 .58627 Mdot
.864 .58636 Mdot
.864 .58638 Mdot
.864 .58653 Mdot
.864 .58654 Mdot
.864 .58672 Mdot
.864 .58676 Mdot
.864 .58676 Mdot
.864 .5868 Mdot
.864 .58683 Mdot
.864 .58684 Mdot
.864 .58686 Mdot
.864 .58688 Mdot
.864 .58695 Mdot
.864 .58702 Mdot
.864 .58712 Mdot
.864 .58715 Mdot
.864 .5872 Mdot
.864 .58721 Mdot
.864 .58721 Mdot
.864 .58724 Mdot
.864 .58724 Mdot
.864 .58726 Mdot
.864 .58729 Mdot
.864 .58729 Mdot
.864 .58729 Mdot
.864 .5873 Mdot
.864 .5873 Mdot
.866 .07448 Mdot
.866 .07448 Mdot
.866 .07448 Mdot
.866 .0745 Mdot
.866 .07452 Mdot
.866 .0746 Mdot
.866 .07467 Mdot
.866 .07468 Mdot
.866 .07471 Mdot
.866 .07471 Mdot
.866 .07485 Mdot
.866 .07486 Mdot
.866 .07493 Mdot
.866 .07497 Mdot
.866 .07513 Mdot
.866 .07515 Mdot
.866 .07518 Mdot
.866 .07529 Mdot
.866 .0754 Mdot
.866 .07552 Mdot
.866 .07564 Mdot
.866 .07569 Mdot
.866 .07569 Mdot
.866 .07572 Mdot
.866 .07591 Mdot
.866 .07594 Mdot
.866 .07607 Mdot
.866 .07622 Mdot
.866 .07628 Mdot
.866 .07661 Mdot
.866 .0767 Mdot
.866 .07683 Mdot
.866 .07887 Mdot
.866 .07907 Mdot
.866 .07912 Mdot
.866 .07966 Mdot
.866 .07982 Mdot
.866 .07985 Mdot
.866 .07989 Mdot
.866 .08037 Mdot
.866 .08063 Mdot
.866 .08065 Mdot
.866 .08154 Mdot
.866 .08169 Mdot
.866 .08178 Mdot
.866 .08209 Mdot
.866 .08282 Mdot
.866 .0833 Mdot
.866 .08358 Mdot
.866 .08373 Mdot
.866 .08381 Mdot
.866 .0841 Mdot
.866 .08491 Mdot
.866 .08562 Mdot
.866 .08649 Mdot
.866 .0867 Mdot
.866 .0883 Mdot
.866 .08866 Mdot
.866 .08876 Mdot
.866 .08913 Mdot
.866 .08939 Mdot
.866 .08948 Mdot
.866 .08992 Mdot
.866 .09083 Mdot
.866 .09091 Mdot
.866 .09155 Mdot
.866 .09176 Mdot
.866 .09248 Mdot
.866 .09293 Mdot
.866 .09353 Mdot
.866 .09358 Mdot
.866 .0937 Mdot
.866 .09385 Mdot
.866 .09397 Mdot
.866 .09417 Mdot
.866 .09575 Mdot
.866 .09604 Mdot
.866 .09659 Mdot
.866 .09672 Mdot
.866 .09689 Mdot
.866 .09738 Mdot
.866 .09761 Mdot
.866 .09848 Mdot
.866 .1002 Mdot
.866 .1007 Mdot
.866 .10118 Mdot
.866 .10121 Mdot
.866 .10126 Mdot
.866 .1014 Mdot
.866 .10167 Mdot
.866 .10214 Mdot
.866 .10221 Mdot
.866 .10265 Mdot
.866 .10296 Mdot
.866 .10332 Mdot
.866 .10388 Mdot
.866 .10417 Mdot
.866 .10526 Mdot
.866 .10571 Mdot
.866 .10578 Mdot
.866 .10609 Mdot
.866 .10664 Mdot
.866 .10937 Mdot
.866 .10975 Mdot
.866 .11075 Mdot
.866 .11116 Mdot
.866 .11225 Mdot
.866 .1128 Mdot
.866 .11292 Mdot
.866 .11308 Mdot
.866 .11316 Mdot
.866 .11362 Mdot
.866 .11364 Mdot
.866 .11384 Mdot
.866 .11444 Mdot
.866 .11505 Mdot
.866 .11622 Mdot
.866 .11712 Mdot
.866 .11719 Mdot
.866 .11777 Mdot
.866 .11983 Mdot
.866 .12002 Mdot
.866 .12139 Mdot
.866 .12234 Mdot
.866 .12412 Mdot
.866 .1246 Mdot
.866 .12695 Mdot
.866 .12871 Mdot
.866 .12918 Mdot
.866 .12981 Mdot
.866 .13042 Mdot
.866 .13125 Mdot
.866 .1314 Mdot
.866 .1319 Mdot
.866 .13433 Mdot
.866 .13447 Mdot
.866 .1354 Mdot
.866 .13551 Mdot
.866 .13597 Mdot
.866 .13712 Mdot
.866 .13728 Mdot
.866 .13849 Mdot
.866 .13926 Mdot
.866 .13977 Mdot
.866 .14091 Mdot
.866 .14133 Mdot
.866 .14147 Mdot
.866 .14209 Mdot
.866 .14215 Mdot
.866 .1422 Mdot
.866 .14304 Mdot
.866 .1455 Mdot
.866 .14652 Mdot
.866 .14717 Mdot
.866 .14813 Mdot
.866 .1503 Mdot
.866 .15095 Mdot
.866 .1521 Mdot
.866 .15531 Mdot
.866 .15661 Mdot
.866 .15679 Mdot
.866 .15806 Mdot
.866 .15914 Mdot
.866 .15936 Mdot
.866 .16401 Mdot
.866 .16653 Mdot
.866 .16732 Mdot
.866 .16733 Mdot
.866 .16772 Mdot
.866 .16807 Mdot
.866 .16858 Mdot
.866 .17105 Mdot
.866 .17124 Mdot
.866 .17246 Mdot
.866 .17422 Mdot
.866 .17552 Mdot
.866 .1762 Mdot
.866 .17639 Mdot
.866 .17864 Mdot
.866 .17972 Mdot
.866 .1798 Mdot
.866 .18294 Mdot
.866 .18331 Mdot
.866 .1836 Mdot
.866 .18439 Mdot
.866 .18502 Mdot
.866 .18521 Mdot
.866 .18522 Mdot
.866 .18553 Mdot
.866 .18609 Mdot
.866 .18659 Mdot
.866 .18919 Mdot
.866 .18972 Mdot
.866 .18985 Mdot
.866 .18998 Mdot
.866 .19012 Mdot
.866 .19046 Mdot
.866 .19103 Mdot
.866 .19212 Mdot
.866 .19229 Mdot
.866 .19368 Mdot
.866 .19374 Mdot
.866 .19496 Mdot
.866 .19498 Mdot
.866 .195 Mdot
.866 .19565 Mdot
.866 .19576 Mdot
.866 .1963 Mdot
.866 .19719 Mdot
.866 .19917 Mdot
.866 .1992 Mdot
.866 .19954 Mdot
.866 .20009 Mdot
.866 .20146 Mdot
.866 .2016 Mdot
.866 .20187 Mdot
.866 .20269 Mdot
.866 .20292 Mdot
.866 .20296 Mdot
.866 .20739 Mdot
.866 .20768 Mdot
.866 .20769 Mdot
.866 .20788 Mdot
.866 .2089 Mdot
.866 .20927 Mdot
.866 .21023 Mdot
.866 .21175 Mdot
.866 .21204 Mdot
.866 .21286 Mdot
.866 .21304 Mdot
.866 .21336 Mdot
.866 .21428 Mdot
.866 .21456 Mdot
.866 .21585 Mdot
.866 .21668 Mdot
.866 .21702 Mdot
.866 .21752 Mdot
.866 .21757 Mdot
.866 .21773 Mdot
.866 .21821 Mdot
.866 .21869 Mdot
.866 .2188 Mdot
.866 .21977 Mdot
.866 .22018 Mdot
.866 .2202 Mdot
.866 .22103 Mdot
.866 .22141 Mdot
.866 .22281 Mdot
.866 .22336 Mdot
.866 .22361 Mdot
.866 .22362 Mdot
.866 .22373 Mdot
.866 .22374 Mdot
.866 .22374 Mdot
.866 .22381 Mdot
.866 .22386 Mdot
.866 .22413 Mdot
.866 .22413 Mdot
.866 .22434 Mdot
.866 .22438 Mdot
.866 .22445 Mdot
.866 .22447 Mdot
.866 .22491 Mdot
.866 .22491 Mdot
.866 .22514 Mdot
.866 .22528 Mdot
.866 .2254 Mdot
.866 .22575 Mdot
.866 .22582 Mdot
.866 .2259 Mdot
.866 .22604 Mdot
.866 .22627 Mdot
.866 .22656 Mdot
.866 .2266 Mdot
.866 .22661 Mdot
.866 .22662 Mdot
.866 .22678 Mdot
.866 .22697 Mdot
.866 .22734 Mdot
.866 .2275 Mdot
.866 .2275 Mdot
.866 .22757 Mdot
.866 .22774 Mdot
.866 .22816 Mdot
.866 .22827 Mdot
.866 .22852 Mdot
.866 .22865 Mdot
.866 .22895 Mdot
.866 .22898 Mdot
.866 .22912 Mdot
.866 .22927 Mdot
.866 .22932 Mdot
.866 .22949 Mdot
.866 .23023 Mdot
.866 .23032 Mdot
.866 .2306 Mdot
.866 .2307 Mdot
.866 .23101 Mdot
.866 .2311 Mdot
.866 .23157 Mdot
.866 .23235 Mdot
.866 .23236 Mdot
.866 .23385 Mdot
.866 .23392 Mdot
.866 .23418 Mdot
.866 .23431 Mdot
.866 .23503 Mdot
.866 .23503 Mdot
.866 .23595 Mdot
.866 .23613 Mdot
.866 .23637 Mdot
.866 .23638 Mdot
.866 .23638 Mdot
.866 .23678 Mdot
.866 .2368 Mdot
.866 .23725 Mdot
.866 .23766 Mdot
.866 .23785 Mdot
.866 .23801 Mdot
.866 .23958 Mdot
.866 .23959 Mdot
.866 .23965 Mdot
.866 .23986 Mdot
.866 .24013 Mdot
.866 .24022 Mdot
.866 .24035 Mdot
.866 .2418 Mdot
.866 .24258 Mdot
.866 .24264 Mdot
.866 .24444 Mdot
.866 .24532 Mdot
.866 .24562 Mdot
.866 .24576 Mdot
.866 .24577 Mdot
.866 .24605 Mdot
.866 .24696 Mdot
.866 .24867 Mdot
.866 .24876 Mdot
.866 .24916 Mdot
.866 .24964 Mdot
.866 .2502 Mdot
.866 .25143 Mdot
.866 .25188 Mdot
.866 .25213 Mdot
.866 .25298 Mdot
.866 .25362 Mdot
.866 .25403 Mdot
.866 .25539 Mdot
.866 .25573 Mdot
.866 .25742 Mdot
.866 .25749 Mdot
.866 .25798 Mdot
.866 .25818 Mdot
.866 .25863 Mdot
.866 .25869 Mdot
.866 .25976 Mdot
.866 .25998 Mdot
.866 .26004 Mdot
.866 .26069 Mdot
.866 .26118 Mdot
.866 .26199 Mdot
.866 .26308 Mdot
.866 .26416 Mdot
.866 .26537 Mdot
.866 .2664 Mdot
.866 .26669 Mdot
.866 .26779 Mdot
.866 .26811 Mdot
.866 .26842 Mdot
.866 .26853 Mdot
.866 .26854 Mdot
.866 .26878 Mdot
.866 .26883 Mdot
.866 .26891 Mdot
.866 .26897 Mdot
.866 .26986 Mdot
.866 .27008 Mdot
.866 .27271 Mdot
.866 .27293 Mdot
.866 .2732 Mdot
.866 .27436 Mdot
.866 .27458 Mdot
.866 .27477 Mdot
.866 .27504 Mdot
.866 .27509 Mdot
.866 .27538 Mdot
.866 .27567 Mdot
.866 .27744 Mdot
.866 .27803 Mdot
.866 .27873 Mdot
.866 .2791 Mdot
.866 .28045 Mdot
.866 .28059 Mdot
.866 .28092 Mdot
.866 .28137 Mdot
.866 .28171 Mdot
.866 .28227 Mdot
.866 .28472 Mdot
.866 .28675 Mdot
.866 .28757 Mdot
.866 .28827 Mdot
.866 .28909 Mdot
.866 .28948 Mdot
.866 .28964 Mdot
.866 .28994 Mdot
.866 .29131 Mdot
.866 .29196 Mdot
.866 .29343 Mdot
.866 .29414 Mdot
.866 .29419 Mdot
.866 .29441 Mdot
.866 .29527 Mdot
.866 .29557 Mdot
.866 .29918 Mdot
.866 .30055 Mdot
.866 .30188 Mdot
.866 .30195 Mdot
.866 .30209 Mdot
.866 .30247 Mdot
.866 .30322 Mdot
.866 .30376 Mdot
.866 .30449 Mdot
.866 .3047 Mdot
.866 .30589 Mdot
.866 .30618 Mdot
.866 .30673 Mdot
.866 .30773 Mdot
.866 .30884 Mdot
.866 .30908 Mdot
.866 .30923 Mdot
.866 .31002 Mdot
.866 .31193 Mdot
.866 .3121 Mdot
.866 .31296 Mdot
.866 .31297 Mdot
.866 .31419 Mdot
.866 .31438 Mdot
.866 .31519 Mdot
.866 .31608 Mdot
.866 .31668 Mdot
.866 .31678 Mdot
.866 .3171 Mdot
.866 .31763 Mdot
.866 .31838 Mdot
.866 .31858 Mdot
.866 .32284 Mdot
.866 .32395 Mdot
.866 .32493 Mdot
.866 .32496 Mdot
.866 .32625 Mdot
.866 .32636 Mdot
.866 .32756 Mdot
.866 .32864 Mdot
.866 .33149 Mdot
.866 .33292 Mdot
.866 .33323 Mdot
.866 .33363 Mdot
.866 .33385 Mdot
.866 .33392 Mdot
.866 .33429 Mdot
.866 .33503 Mdot
.866 .33509 Mdot
.866 .3356 Mdot
.866 .33715 Mdot
.866 .33724 Mdot
.866 .33735 Mdot
.866 .33872 Mdot
.866 .3394 Mdot
.866 .33951 Mdot
.866 .33985 Mdot
.866 .34172 Mdot
.866 .34204 Mdot
.866 .34235 Mdot
.866 .3424 Mdot
.866 .34248 Mdot
.866 .34401 Mdot
.866 .34418 Mdot
.866 .34514 Mdot
.866 .34564 Mdot
.866 .34719 Mdot
.866 .3474 Mdot
.866 .34877 Mdot
.866 .35085 Mdot
.866 .3513 Mdot
.866 .35275 Mdot
.866 .35342 Mdot
.866 .35472 Mdot
.866 .35706 Mdot
.866 .35762 Mdot
.866 .3598 Mdot
.866 .36112 Mdot
.866 .36144 Mdot
.866 .36166 Mdot
.866 .36213 Mdot
.866 .36236 Mdot
.866 .36262 Mdot
.866 .36266 Mdot
.866 .36301 Mdot
.866 .36467 Mdot
.866 .36833 Mdot
.866 .37253 Mdot
.866 .37366 Mdot
.866 .37409 Mdot
.866 .3747 Mdot
.866 .37515 Mdot
.866 .3766 Mdot
.866 .37662 Mdot
.866 .37856 Mdot
.866 .37874 Mdot
.866 .37891 Mdot
.866 .37977 Mdot
.866 .37994 Mdot
.866 .37998 Mdot
.866 .38007 Mdot
.866 .38073 Mdot
.866 .38237 Mdot
.866 .38311 Mdot
.866 .38329 Mdot
.866 .38377 Mdot
.866 .3842 Mdot
.866 .38559 Mdot
.866 .38574 Mdot
.866 .38606 Mdot
.866 .38617 Mdot
.866 .38728 Mdot
.866 .38819 Mdot
.866 .38845 Mdot
.866 .3887 Mdot
.866 .3895 Mdot
.866 .39212 Mdot
.866 .3925 Mdot
.866 .39523 Mdot
.866 .39531 Mdot
.866 .39696 Mdot
.866 .39811 Mdot
.866 .40064 Mdot
.866 .40066 Mdot
.866 .40095 Mdot
.866 .40158 Mdot
.866 .40188 Mdot
.866 .40327 Mdot
.866 .40336 Mdot
.866 .40339 Mdot
.866 .40349 Mdot
.866 .40351 Mdot
.866 .40505 Mdot
.866 .40519 Mdot
.866 .40535 Mdot
.866 .41072 Mdot
.866 .41291 Mdot
.866 .41355 Mdot
.866 .41425 Mdot
.866 .41432 Mdot
.866 .41635 Mdot
.866 .41677 Mdot
.866 .41682 Mdot
.866 .42094 Mdot
.866 .4217 Mdot
.866 .4223 Mdot
.866 .42296 Mdot
.866 .42376 Mdot
.866 .42471 Mdot
.866 .42824 Mdot
.866 .42841 Mdot
.866 .43129 Mdot
.866 .43277 Mdot
.866 .43344 Mdot
.866 .43369 Mdot
.866 .43381 Mdot
.866 .43392 Mdot
.866 .43428 Mdot
.866 .43683 Mdot
.866 .43894 Mdot
.866 .43898 Mdot
.866 .43943 Mdot
.866 .4425 Mdot
.866 .44415 Mdot
.866 .44437 Mdot
.866 .44562 Mdot
.866 .44705 Mdot
.866 .44708 Mdot
.866 .44848 Mdot
.866 .44991 Mdot
.866 .45328 Mdot
.866 .45475 Mdot
.866 .45477 Mdot
.866 .45551 Mdot
.866 .45615 Mdot
.866 .45626 Mdot
.866 .45711 Mdot
.866 .45891 Mdot
.866 .46148 Mdot
.866 .46154 Mdot
.866 .46166 Mdot
.866 .462 Mdot
.866 .46414 Mdot
.866 .46422 Mdot
.866 .46638 Mdot
.866 .46677 Mdot
.866 .46737 Mdot
.866 .46968 Mdot
.866 .46971 Mdot
.866 .47089 Mdot
.866 .47122 Mdot
.866 .47507 Mdot
.866 .47513 Mdot
.866 .47584 Mdot
.866 .4759 Mdot
.866 .47698 Mdot
.866 .47712 Mdot
.866 .47951 Mdot
.866 .48241 Mdot
.866 .48303 Mdot
.866 .48351 Mdot
.866 .48376 Mdot
.866 .48436 Mdot
.866 .48455 Mdot
.866 .48475 Mdot
.866 .48483 Mdot
.866 .48515 Mdot
.866 .48585 Mdot
.866 .48617 Mdot
.866 .48619 Mdot
.866 .48626 Mdot
.866 .4867 Mdot
.866 .4876 Mdot
.866 .48841 Mdot
.866 .48867 Mdot
.866 .49259 Mdot
.866 .49327 Mdot
.866 .49342 Mdot
.866 .49354 Mdot
.866 .49363 Mdot
.866 .49383 Mdot
.866 .49405 Mdot
.866 .49458 Mdot
.866 .49547 Mdot
.866 .49717 Mdot
.866 .49744 Mdot
.866 .49903 Mdot
.866 .49957 Mdot
.866 .49965 Mdot
.866 .50046 Mdot
.866 .50151 Mdot
.866 .50155 Mdot
.866 .50156 Mdot
.866 .50169 Mdot
.866 .50254 Mdot
.866 .50267 Mdot
.866 .50272 Mdot
.866 .50352 Mdot
.866 .50356 Mdot
.866 .5047 Mdot
.866 .50485 Mdot
.866 .50774 Mdot
.866 .50778 Mdot
.866 .50827 Mdot
.866 .50908 Mdot
.866 .51068 Mdot
.866 .51076 Mdot
.866 .51104 Mdot
.866 .51123 Mdot
.866 .51135 Mdot
.866 .51161 Mdot
.866 .51277 Mdot
.866 .51309 Mdot
.866 .51316 Mdot
.866 .51421 Mdot
.866 .5143 Mdot
.866 .51528 Mdot
.866 .51616 Mdot
.866 .51913 Mdot
.866 .51924 Mdot
.866 .51963 Mdot
.866 .51964 Mdot
.866 .5199 Mdot
.866 .52125 Mdot
.866 .52174 Mdot
.866 .523 Mdot
.866 .52497 Mdot
.866 .52535 Mdot
.866 .52617 Mdot
.866 .52637 Mdot
.866 .52639 Mdot
.866 .52655 Mdot
.866 .52663 Mdot
.866 .52703 Mdot
.866 .52819 Mdot
.866 .52849 Mdot
.866 .52851 Mdot
.866 .52854 Mdot
.866 .52864 Mdot
.866 .52868 Mdot
.866 .52879 Mdot
.866 .53014 Mdot
.866 .53051 Mdot
.866 .53089 Mdot
.866 .53116 Mdot
.866 .53157 Mdot
.866 .53164 Mdot
.866 .53201 Mdot
.866 .53203 Mdot
.866 .53218 Mdot
.866 .53224 Mdot
.866 .53243 Mdot
.866 .53301 Mdot
.866 .53358 Mdot
.866 .53372 Mdot
.866 .53487 Mdot
.866 .53505 Mdot
.866 .53535 Mdot
.866 .53538 Mdot
.866 .53634 Mdot
.866 .53639 Mdot
.866 .53679 Mdot
.866 .5383 Mdot
.866 .53839 Mdot
.866 .53839 Mdot
.866 .53902 Mdot
.866 .53931 Mdot
.866 .53931 Mdot
.866 .53944 Mdot
.866 .53945 Mdot
.866 .53945 Mdot
.866 .53953 Mdot
.866 .53958 Mdot
.866 .53989 Mdot
.866 .53989 Mdot
.866 .54012 Mdot
.866 .54017 Mdot
.866 .54025 Mdot
.866 .54027 Mdot
.866 .54076 Mdot
.866 .54076 Mdot
.866 .54102 Mdot
.866 .54117 Mdot
.866 .5413 Mdot
.866 .54145 Mdot
.866 .5417 Mdot
.866 .54177 Mdot
.866 .54186 Mdot
.866 .54187 Mdot
.866 .54201 Mdot
.866 .54226 Mdot
.866 .54258 Mdot
.866 .54262 Mdot
.866 .54263 Mdot
.866 .54265 Mdot
.866 .54281 Mdot
.866 .54302 Mdot
.866 .54343 Mdot
.866 .54359 Mdot
.866 .5436 Mdot
.866 .54368 Mdot
.866 .54386 Mdot
.866 .54431 Mdot
.866 .54443 Mdot
.866 .54469 Mdot
.866 .5447 Mdot
.866 .54483 Mdot
.866 .54514 Mdot
.866 .54518 Mdot
.866 .54533 Mdot
.866 .54548 Mdot
.866 .54553 Mdot
.866 .54555 Mdot
.866 .54571 Mdot
.866 .54582 Mdot
.866 .54608 Mdot
.866 .5465 Mdot
.866 .54659 Mdot
.866 .54688 Mdot
.866 .54698 Mdot
.866 .54704 Mdot
.866 .5473 Mdot
.866 .54739 Mdot
.866 .54787 Mdot
.866 .54817 Mdot
.866 .54829 Mdot
.866 .54861 Mdot
.866 .54867 Mdot
.866 .54868 Mdot
.866 .54877 Mdot
.866 .55016 Mdot
.866 .55017 Mdot
.866 .55025 Mdot
.866 .5505 Mdot
.866 .55059 Mdot
.866 .55063 Mdot
.866 .55106 Mdot
.866 .55123 Mdot
.866 .55134 Mdot
.866 .55135 Mdot
.866 .55196 Mdot
.866 .55224 Mdot
.866 .55241 Mdot
.866 .55264 Mdot
.866 .55265 Mdot
.866 .55266 Mdot
.866 .55304 Mdot
.866 .55305 Mdot
.866 .55348 Mdot
.866 .55354 Mdot
.866 .55387 Mdot
.866 .55405 Mdot
.866 .55415 Mdot
.866 .5542 Mdot
.866 .55424 Mdot
.866 .55428 Mdot
.866 .55444 Mdot
.866 .55524 Mdot
.866 .55539 Mdot
.866 .55556 Mdot
.866 .55566 Mdot
.866 .55566 Mdot
.866 .55572 Mdot
.866 .55591 Mdot
.866 .55616 Mdot
.866 .55625 Mdot
.866 .55636 Mdot
.866 .55732 Mdot
.866 .55734 Mdot
.866 .55767 Mdot
.866 .55835 Mdot
.866 .55841 Mdot
.866 .55862 Mdot
.866 .55901 Mdot
.866 .55954 Mdot
.866 .55991 Mdot
.866 .55996 Mdot
.866 .56071 Mdot
.866 .56086 Mdot
.866 .56097 Mdot
.866 .56109 Mdot
.866 .56109 Mdot
.866 .56132 Mdot
.866 .56208 Mdot
.866 .56346 Mdot
.866 .56353 Mdot
.866 .56385 Mdot
.866 .56423 Mdot
.866 .56428 Mdot
.866 .56466 Mdot
.866 .56561 Mdot
.866 .56595 Mdot
.866 .56614 Mdot
.866 .56678 Mdot
.866 .56706 Mdot
.866 .56725 Mdot
.866 .56755 Mdot
.866 .56827 Mdot
.866 .56851 Mdot
.866 .56853 Mdot
.866 .56854 Mdot
.866 .56873 Mdot
.866 .56877 Mdot
.866 .56889 Mdot
.866 .56922 Mdot
.866 .56937 Mdot
.866 .56959 Mdot
.866 .56994 Mdot
.866 .56999 Mdot
.866 .57032 Mdot
.866 .57045 Mdot
.866 .57049 Mdot
.866 .57075 Mdot
.866 .57079 Mdot
.866 .5715 Mdot
.866 .57164 Mdot
.866 .57168 Mdot
.866 .57192 Mdot
.866 .5721 Mdot
.866 .57228 Mdot
.866 .57241 Mdot
.866 .57292 Mdot
.866 .57359 Mdot
.866 .57373 Mdot
.866 .57424 Mdot
.866 .5745 Mdot
.866 .5749 Mdot
.866 .57495 Mdot
.866 .57553 Mdot
.866 .5757 Mdot
.866 .57572 Mdot
.866 .57597 Mdot
.866 .5763 Mdot
.866 .57648 Mdot
.866 .57665 Mdot
.866 .5767 Mdot
.866 .57671 Mdot
.866 .57684 Mdot
.866 .57686 Mdot
.866 .57691 Mdot
.866 .57694 Mdot
.866 .5771 Mdot
.866 .5774 Mdot
.866 .57752 Mdot
.866 .5778 Mdot
.866 .57791 Mdot
.866 .57867 Mdot
.866 .57883 Mdot
.866 .57891 Mdot
.866 .57893 Mdot
.866 .57906 Mdot
.866 .57937 Mdot
.866 .57945 Mdot
.866 .5796 Mdot
.866 .5797 Mdot
.866 .57979 Mdot
.866 .57991 Mdot
.866 .57993 Mdot
.866 .58006 Mdot
.866 .58014 Mdot
.866 .58018 Mdot
.866 .58019 Mdot
.866 .5802 Mdot
.866 .58033 Mdot
.866 .58047 Mdot
.866 .58095 Mdot
.866 .58119 Mdot
.866 .58126 Mdot
.866 .58139 Mdot
.866 .58144 Mdot
.866 .58148 Mdot
.866 .58163 Mdot
.866 .58171 Mdot
.866 .58215 Mdot
.866 .5822 Mdot
.866 .58223 Mdot
.866 .58228 Mdot
.866 .58231 Mdot
.866 .58232 Mdot
.866 .58249 Mdot
.866 .58261 Mdot
.866 .58281 Mdot
.866 .58287 Mdot
.866 .58305 Mdot
.866 .58307 Mdot
.866 .58332 Mdot
.866 .58344 Mdot
.866 .58347 Mdot
.866 .58354 Mdot
.866 .58364 Mdot
.866 .58367 Mdot
.866 .58377 Mdot
.866 .58421 Mdot
.866 .58427 Mdot
.866 .5845 Mdot
.866 .5847 Mdot
.866 .58492 Mdot
.866 .585 Mdot
.866 .58502 Mdot
.866 .58506 Mdot
.866 .58514 Mdot
.866 .58527 Mdot
.866 .58547 Mdot
.866 .58555 Mdot
.866 .58558 Mdot
.866 .58562 Mdot
.866 .58586 Mdot
.866 .58587 Mdot
.866 .58594 Mdot
.866 .58607 Mdot
.866 .58608 Mdot
.866 .58609 Mdot
.866 .58613 Mdot
.866 .58628 Mdot
.866 .58629 Mdot
.866 .58635 Mdot
.866 .5869 Mdot
.866 .58694 Mdot
.866 .58697 Mdot
.866 .58705 Mdot
.866 .58707 Mdot
.866 .58711 Mdot
.866 .58715 Mdot
.866 .58716 Mdot
.866 .58721 Mdot
.866 .58721 Mdot
.866 .58721 Mdot
.866 .58723 Mdot
.866 .58726 Mdot
.866 .58729 Mdot
.866 .58732 Mdot
.866 .58735 Mdot
.866 .58736 Mdot
.866 .58737 Mdot
.866 .58741 Mdot
.866 .58742 Mdot
.866 .58744 Mdot
.866 .58744 Mdot
.866 .58748 Mdot
.866 .58748 Mdot
.866 .58749 Mdot
.866 .58749 Mdot
.866 .58751 Mdot
.866 .58753 Mdot
.866 .58754 Mdot
.866 .58754 Mdot
.866 .58754 Mdot
.866 .58754 Mdot
.868 .07363 Mdot
.868 .07367 Mdot
.868 .07368 Mdot
.868 .0737 Mdot
.868 .0738 Mdot
.868 .07388 Mdot
.868 .07388 Mdot
.868 .07394 Mdot
.868 .074 Mdot
.868 .07421 Mdot
.868 .07433 Mdot
.868 .07456 Mdot
.868 .07482 Mdot
.868 .07492 Mdot
.868 .07503 Mdot
.868 .07516 Mdot
.868 .07517 Mdot
.868 .07557 Mdot
.868 .07586 Mdot
.868 .0763 Mdot
.868 .07697 Mdot
.868 .07713 Mdot
.868 .0772 Mdot
.868 .07788 Mdot
.868 .07844 Mdot
.868 .07873 Mdot
.868 .07883 Mdot
.868 .07885 Mdot
.868 .07958 Mdot
.868 .07978 Mdot
.868 .08006 Mdot
.868 .08067 Mdot
.868 .08172 Mdot
.868 .08207 Mdot
.868 .08234 Mdot
.868 .08252 Mdot
.868 .08283 Mdot
.868 .08294 Mdot
.868 .08309 Mdot
.868 .08333 Mdot
.868 .08398 Mdot
.868 .08415 Mdot
.868 .08437 Mdot
.868 .08458 Mdot
.868 .08553 Mdot
.868 .08584 Mdot
.868 .0861 Mdot
.868 .08633 Mdot
.868 .08638 Mdot
.868 .08646 Mdot
.868 .08661 Mdot
.868 .08675 Mdot
.868 .08719 Mdot
.868 .08721 Mdot
.868 .08764 Mdot
.868 .08768 Mdot
.868 .08804 Mdot
.868 .08895 Mdot
.868 .09135 Mdot
.868 .09138 Mdot
.868 .09159 Mdot
.868 .09333 Mdot
.868 .0935 Mdot
.868 .09396 Mdot
.868 .09401 Mdot
.868 .09402 Mdot
.868 .09522 Mdot
.868 .09545 Mdot
.868 .09615 Mdot
.868 .09623 Mdot
.868 .09714 Mdot
.868 .09807 Mdot
.868 .09935 Mdot
.868 .1015 Mdot
.868 .10245 Mdot
.868 .10259 Mdot
.868 .10332 Mdot
.868 .10389 Mdot
.868 .10519 Mdot
.868 .10573 Mdot
.868 .1073 Mdot
.868 .10969 Mdot
.868 .11109 Mdot
.868 .11228 Mdot
.868 .1125 Mdot
.868 .1128 Mdot
.868 .11514 Mdot
.868 .11533 Mdot
.868 .11726 Mdot
.868 .11804 Mdot
.868 .11887 Mdot
.868 .12015 Mdot
.868 .1203 Mdot
.868 .12047 Mdot
.868 .12148 Mdot
.868 .12263 Mdot
.868 .1229 Mdot
.868 .12295 Mdot
.868 .12309 Mdot
.868 .1239 Mdot
.868 .124 Mdot
.868 .12414 Mdot
.868 .12425 Mdot
.868 .12556 Mdot
.868 .12574 Mdot
.868 .12772 Mdot
.868 .12806 Mdot
.868 .1284 Mdot
.868 .12852 Mdot
.868 .12948 Mdot
.868 .13034 Mdot
.868 .13047 Mdot
.868 .13099 Mdot
.868 .1311 Mdot
.868 .13126 Mdot
.868 .13131 Mdot
.868 .13188 Mdot
.868 .13215 Mdot
.868 .13288 Mdot
.868 .13296 Mdot
.868 .13461 Mdot
.868 .13556 Mdot
.868 .13676 Mdot
.868 .13762 Mdot
.868 .1382 Mdot
.868 .13866 Mdot
.868 .13901 Mdot
.868 .13962 Mdot
.868 .13978 Mdot
.868 .14361 Mdot
.868 .14514 Mdot
.868 .14676 Mdot
.868 .14694 Mdot
.868 .14747 Mdot
.868 .14753 Mdot
.868 .14808 Mdot
.868 .14862 Mdot
.868 .1495 Mdot
.868 .15309 Mdot
.868 .15409 Mdot
.868 .15494 Mdot
.868 .15579 Mdot
.868 .15582 Mdot
.868 .15614 Mdot
.868 .15699 Mdot
.868 .15766 Mdot
.868 .15923 Mdot
.868 .1595 Mdot
.868 .16079 Mdot
.868 .16096 Mdot
.868 .16126 Mdot
.868 .1614 Mdot
.868 .16316 Mdot
.868 .16347 Mdot
.868 .16458 Mdot
.868 .16576 Mdot
.868 .16604 Mdot
.868 .16606 Mdot
.868 .16652 Mdot
.868 .16677 Mdot
.868 .16771 Mdot
.868 .16813 Mdot
.868 .16993 Mdot
.868 .17087 Mdot
.868 .17121 Mdot
.868 .17192 Mdot
.868 .17197 Mdot
.868 .17267 Mdot
.868 .17298 Mdot
.868 .17509 Mdot
.868 .17518 Mdot
.868 .17576 Mdot
.868 .17747 Mdot
.868 .17749 Mdot
.868 .17895 Mdot
.868 .17952 Mdot
.868 .17985 Mdot
.868 .18049 Mdot
.868 .18068 Mdot
.868 .18153 Mdot
.868 .18181 Mdot
.868 .18306 Mdot
.868 .18345 Mdot
.868 .1839 Mdot
.868 .18423 Mdot
.868 .18457 Mdot
.868 .18464 Mdot
.868 .1848 Mdot
.868 .18535 Mdot
.868 .18577 Mdot
.868 .1863 Mdot
.868 .18665 Mdot
.868 .18834 Mdot
.868 .189 Mdot
.868 .18981 Mdot
.868 .19158 Mdot
.868 .19162 Mdot
.868 .19172 Mdot
.868 .19174 Mdot
.868 .19207 Mdot
.868 .19209 Mdot
.868 .19271 Mdot
.868 .19305 Mdot
.868 .19507 Mdot
.868 .19545 Mdot
.868 .19561 Mdot
.868 .19579 Mdot
.868 .19703 Mdot
.868 .19761 Mdot
.868 .19865 Mdot
.868 .19978 Mdot
.868 .19992 Mdot
.868 .20086 Mdot
.868 .20127 Mdot
.868 .2017 Mdot
.868 .20397 Mdot
.868 .20572 Mdot
.868 .2075 Mdot
.868 .20814 Mdot
.868 .20857 Mdot
.868 .20952 Mdot
.868 .20971 Mdot
.868 .20978 Mdot
.868 .21214 Mdot
.868 .21304 Mdot
.868 .21334 Mdot
.868 .21404 Mdot
.868 .21445 Mdot
.868 .21603 Mdot
.868 .21651 Mdot
.868 .21695 Mdot
.868 .22033 Mdot
.868 .22081 Mdot
.868 .22102 Mdot
.868 .22121 Mdot
.868 .2213 Mdot
.868 .22134 Mdot
.868 .22141 Mdot
.868 .22173 Mdot
.868 .22196 Mdot
.868 .22196 Mdot
.868 .22216 Mdot
.868 .22235 Mdot
.868 .22265 Mdot
.868 .22301 Mdot
.868 .22307 Mdot
.868 .22336 Mdot
.868 .22397 Mdot
.868 .22408 Mdot
.868 .22488 Mdot
.868 .2252 Mdot
.868 .22555 Mdot
.868 .22593 Mdot
.868 .22597 Mdot
.868 .22617 Mdot
.868 .22722 Mdot
.868 .22749 Mdot
.868 .2281 Mdot
.868 .22816 Mdot
.868 .2283 Mdot
.868 .22946 Mdot
.868 .2296 Mdot
.868 .23021 Mdot
.868 .23042 Mdot
.868 .23079 Mdot
.868 .23153 Mdot
.868 .23189 Mdot
.868 .23202 Mdot
.868 .23222 Mdot
.868 .23277 Mdot
.868 .23403 Mdot
.868 .2343 Mdot
.868 .23464 Mdot
.868 .235 Mdot
.868 .23602 Mdot
.868 .23691 Mdot
.868 .23711 Mdot
.868 .23722 Mdot
.868 .23726 Mdot
.868 .23727 Mdot
.868 .23811 Mdot
.868 .23833 Mdot
.868 .2395 Mdot
.868 .23956 Mdot
.868 .24009 Mdot
.868 .2406 Mdot
.868 .24089 Mdot
.868 .24095 Mdot
.868 .24128 Mdot
.868 .24197 Mdot
.868 .24198 Mdot
.868 .24276 Mdot
.868 .2428 Mdot
.868 .24364 Mdot
.868 .2439 Mdot
.868 .24414 Mdot
.868 .24426 Mdot
.868 .2446 Mdot
.868 .24523 Mdot
.868 .24538 Mdot
.868 .24572 Mdot
.868 .24597 Mdot
.868 .24598 Mdot
.868 .24702 Mdot
.868 .24766 Mdot
.868 .24782 Mdot
.868 .24788 Mdot
.868 .24836 Mdot
.868 .24846 Mdot
.868 .2493 Mdot
.868 .24962 Mdot
.868 .24975 Mdot
.868 .25007 Mdot
.868 .25077 Mdot
.868 .25216 Mdot
.868 .25272 Mdot
.868 .25324 Mdot
.868 .25388 Mdot
.868 .2545 Mdot
.868 .25653 Mdot
.868 .25733 Mdot
.868 .25825 Mdot
.868 .259 Mdot
.868 .25968 Mdot
.868 .25971 Mdot
.868 .25983 Mdot
.868 .26006 Mdot
.868 .2605 Mdot
.868 .26093 Mdot
.868 .26098 Mdot
.868 .26129 Mdot
.868 .2622 Mdot
.868 .26228 Mdot
.868 .263 Mdot
.868 .26352 Mdot
.868 .26365 Mdot
.868 .26469 Mdot
.868 .26735 Mdot
.868 .26872 Mdot
.868 .26884 Mdot
.868 .27023 Mdot
.868 .27246 Mdot
.868 .27277 Mdot
.868 .27388 Mdot
.868 .27432 Mdot
.868 .27441 Mdot
.868 .27499 Mdot
.868 .27718 Mdot
.868 .27997 Mdot
.868 .27997 Mdot
.868 .28034 Mdot
.868 .28047 Mdot
.868 .28177 Mdot
.868 .28193 Mdot
.868 .28195 Mdot
.868 .28464 Mdot
.868 .28535 Mdot
.868 .28588 Mdot
.868 .28602 Mdot
.868 .28613 Mdot
.868 .28687 Mdot
.868 .28798 Mdot
.868 .2882 Mdot
.868 .28928 Mdot
.868 .28956 Mdot
.868 .29038 Mdot
.868 .29077 Mdot
.868 .292 Mdot
.868 .29276 Mdot
.868 .29338 Mdot
.868 .29438 Mdot
.868 .29692 Mdot
.868 .30107 Mdot
.868 .30285 Mdot
.868 .30546 Mdot
.868 .30585 Mdot
.868 .30736 Mdot
.868 .30766 Mdot
.868 .30784 Mdot
.868 .30938 Mdot
.868 .31167 Mdot
.868 .31218 Mdot
.868 .31292 Mdot
.868 .3139 Mdot
.868 .31436 Mdot
.868 .31599 Mdot
.868 .31629 Mdot
.868 .3166 Mdot
.868 .31692 Mdot
.868 .31794 Mdot
.868 .31857 Mdot
.868 .31948 Mdot
.868 .32073 Mdot
.868 .321 Mdot
.868 .32222 Mdot
.868 .32307 Mdot
.868 .32349 Mdot
.868 .32363 Mdot
.868 .32491 Mdot
.868 .32795 Mdot
.868 .32814 Mdot
.868 .32859 Mdot
.868 .329 Mdot
.868 .32966 Mdot
.868 .33025 Mdot
.868 .33145 Mdot
.868 .33169 Mdot
.868 .33194 Mdot
.868 .33228 Mdot
.868 .33266 Mdot
.868 .33305 Mdot
.868 .33309 Mdot
.868 .33416 Mdot
.868 .33802 Mdot
.868 .33891 Mdot
.868 .33908 Mdot
.868 .33956 Mdot
.868 .33961 Mdot
.868 .34023 Mdot
.868 .34168 Mdot
.868 .34449 Mdot
.868 .34647 Mdot
.868 .34856 Mdot
.868 .34947 Mdot
.868 .35078 Mdot
.868 .35176 Mdot
.868 .35215 Mdot
.868 .35256 Mdot
.868 .35319 Mdot
.868 .35326 Mdot
.868 .35383 Mdot
.868 .35453 Mdot
.868 .3546 Mdot
.868 .35498 Mdot
.868 .35509 Mdot
.868 .35514 Mdot
.868 .3569 Mdot
.868 .35792 Mdot
.868 .35825 Mdot
.868 .3586 Mdot
.868 .35872 Mdot
.868 .35907 Mdot
.868 .36019 Mdot
.868 .36106 Mdot
.868 .36131 Mdot
.868 .36164 Mdot
.868 .3619 Mdot
.868 .36197 Mdot
.868 .36487 Mdot
.868 .36508 Mdot
.868 .3651 Mdot
.868 .36553 Mdot
.868 .36764 Mdot
.868 .3683 Mdot
.868 .36899 Mdot
.868 .37032 Mdot
.868 .37113 Mdot
.868 .37153 Mdot
.868 .37195 Mdot
.868 .37222 Mdot
.868 .37415 Mdot
.868 .3745 Mdot
.868 .37547 Mdot
.868 .37656 Mdot
.868 .37687 Mdot
.868 .37753 Mdot
.868 .37808 Mdot
.868 .37823 Mdot
.868 .37834 Mdot
.868 .37845 Mdot
.868 .37871 Mdot
.868 .37885 Mdot
.868 .37903 Mdot
.868 .37914 Mdot
.868 .38018 Mdot
.868 .38081 Mdot
.868 .38092 Mdot
.868 .38124 Mdot
.868 .38189 Mdot
.868 .38206 Mdot
.868 .38212 Mdot
.868 .38252 Mdot
.868 .3827 Mdot
.868 .38344 Mdot
.868 .38386 Mdot
.868 .38471 Mdot
.868 .38644 Mdot
.868 .38652 Mdot
.868 .38752 Mdot
.868 .38795 Mdot
.868 .38871 Mdot
.868 .39042 Mdot
.868 .39147 Mdot
.868 .39266 Mdot
.868 .39272 Mdot
.868 .39341 Mdot
.868 .39378 Mdot
.868 .39472 Mdot
.868 .39576 Mdot
.868 .39655 Mdot
.868 .39705 Mdot
.868 .39715 Mdot
.868 .39776 Mdot
.868 .39793 Mdot
.868 .39829 Mdot
.868 .4002 Mdot
.868 .40144 Mdot
.868 .40361 Mdot
.868 .40461 Mdot
.868 .40665 Mdot
.868 .40675 Mdot
.868 .40791 Mdot
.868 .40917 Mdot
.868 .40924 Mdot
.868 .4101 Mdot
.868 .41359 Mdot
.868 .41398 Mdot
.868 .41511 Mdot
.868 .41525 Mdot
.868 .4157 Mdot
.868 .41625 Mdot
.868 .41641 Mdot
.868 .4165 Mdot
.868 .4175 Mdot
.868 .41757 Mdot
.868 .41789 Mdot
.868 .41822 Mdot
.868 .41943 Mdot
.868 .41966 Mdot
.868 .41983 Mdot
.868 .41999 Mdot
.868 .4203 Mdot
.868 .42061 Mdot
.868 .42073 Mdot
.868 .42201 Mdot
.868 .42611 Mdot
.868 .42691 Mdot
.868 .42726 Mdot
.868 .42776 Mdot
.868 .42898 Mdot
.868 .42987 Mdot
.868 .43004 Mdot
.868 .4307 Mdot
.868 .43245 Mdot
.868 .4325 Mdot
.868 .43265 Mdot
.868 .43314 Mdot
.868 .43344 Mdot
.868 .43391 Mdot
.868 .43486 Mdot
.868 .43562 Mdot
.868 .43621 Mdot
.868 .43738 Mdot
.868 .43934 Mdot
.868 .43988 Mdot
.868 .44021 Mdot
.868 .44242 Mdot
.868 .44249 Mdot
.868 .44275 Mdot
.868 .44333 Mdot
.868 .44338 Mdot
.868 .44342 Mdot
.868 .4435 Mdot
.868 .44358 Mdot
.868 .44361 Mdot
.868 .44396 Mdot
.868 .4455 Mdot
.868 .44703 Mdot
.868 .44762 Mdot
.868 .44888 Mdot
.868 .4495 Mdot
.868 .44974 Mdot
.868 .44975 Mdot
.868 .44978 Mdot
.868 .4498 Mdot
.868 .45143 Mdot
.868 .4515 Mdot
.868 .45151 Mdot
.868 .45199 Mdot
.868 .45253 Mdot
.868 .45253 Mdot
.868 .45257 Mdot
.868 .45343 Mdot
.868 .45344 Mdot
.868 .45345 Mdot
.868 .45358 Mdot
.868 .45391 Mdot
.868 .45566 Mdot
.868 .45645 Mdot
.868 .45664 Mdot
.868 .45669 Mdot
.868 .45673 Mdot
.868 .45675 Mdot
.868 .4572 Mdot
.868 .45836 Mdot
.868 .45979 Mdot
.868 .46067 Mdot
.868 .46152 Mdot
.868 .46175 Mdot
.868 .46214 Mdot
.868 .46342 Mdot
.868 .46351 Mdot
.868 .46453 Mdot
.868 .46478 Mdot
.868 .46533 Mdot
.868 .4673 Mdot
.868 .46792 Mdot
.868 .46797 Mdot
.868 .46812 Mdot
.868 .46827 Mdot
.868 .46834 Mdot
.868 .46842 Mdot
.868 .4691 Mdot
.868 .46926 Mdot
.868 .46944 Mdot
.868 .46991 Mdot
.868 .47003 Mdot
.868 .47029 Mdot
.868 .47329 Mdot
.868 .47332 Mdot
.868 .4739 Mdot
.868 .47447 Mdot
.868 .4754 Mdot
.868 .47586 Mdot
.868 .47684 Mdot
.868 .47739 Mdot
.868 .47848 Mdot
.868 .47876 Mdot
.868 .4788 Mdot
.868 .48025 Mdot
.868 .48072 Mdot
.868 .48074 Mdot
.868 .48173 Mdot
.868 .48281 Mdot
.868 .48299 Mdot
.868 .48346 Mdot
.868 .48421 Mdot
.868 .48457 Mdot
.868 .48476 Mdot
.868 .48532 Mdot
.868 .48535 Mdot
.868 .48542 Mdot
.868 .4857 Mdot
.868 .48584 Mdot
.868 .48659 Mdot
.868 .48664 Mdot
.868 .48689 Mdot
.868 .48698 Mdot
.868 .48728 Mdot
.868 .48815 Mdot
.868 .48871 Mdot
.868 .48981 Mdot
.868 .49086 Mdot
.868 .49115 Mdot
.868 .49142 Mdot
.868 .49248 Mdot
.868 .49257 Mdot
.868 .49376 Mdot
.868 .49448 Mdot
.868 .49527 Mdot
.868 .49582 Mdot
.868 .49653 Mdot
.868 .49659 Mdot
.868 .49675 Mdot
.868 .49678 Mdot
.868 .49706 Mdot
.868 .49729 Mdot
.868 .49732 Mdot
.868 .49828 Mdot
.868 .4988 Mdot
.868 .50188 Mdot
.868 .50244 Mdot
.868 .50269 Mdot
.868 .50296 Mdot
.868 .50331 Mdot
.868 .5048 Mdot
.868 .50521 Mdot
.868 .50538 Mdot
.868 .50566 Mdot
.868 .50585 Mdot
.868 .50631 Mdot
.868 .50653 Mdot
.868 .50679 Mdot
.868 .50711 Mdot
.868 .50719 Mdot
.868 .50882 Mdot
.868 .50888 Mdot
.868 .50904 Mdot
.868 .50936 Mdot
.868 .50982 Mdot
.868 .50992 Mdot
.868 .51039 Mdot
.868 .51097 Mdot
.868 .51135 Mdot
.868 .51147 Mdot
.868 .51158 Mdot
.868 .5117 Mdot
.868 .51247 Mdot
.868 .51311 Mdot
.868 .5133 Mdot
.868 .51478 Mdot
.868 .51489 Mdot
.868 .51718 Mdot
.868 .5196 Mdot
.868 .52018 Mdot
.868 .52045 Mdot
.868 .52103 Mdot
.868 .52132 Mdot
.868 .52142 Mdot
.868 .52228 Mdot
.868 .52254 Mdot
.868 .52263 Mdot
.868 .52307 Mdot
.868 .52458 Mdot
.868 .52471 Mdot
.868 .52568 Mdot
.868 .52683 Mdot
.868 .52722 Mdot
.868 .52732 Mdot
.868 .52809 Mdot
.868 .52857 Mdot
.868 .52862 Mdot
.868 .53057 Mdot
.868 .53116 Mdot
.868 .53126 Mdot
.868 .53169 Mdot
.868 .53277 Mdot
.868 .53505 Mdot
.868 .53548 Mdot
.868 .53567 Mdot
.868 .53575 Mdot
.868 .53631 Mdot
.868 .53639 Mdot
.868 .5365 Mdot
.868 .53655 Mdot
.868 .53677 Mdot
.868 .53688 Mdot
.868 .53691 Mdot
.868 .537 Mdot
.868 .53708 Mdot
.868 .53737 Mdot
.868 .53763 Mdot
.868 .53763 Mdot
.868 .53786 Mdot
.868 .53799 Mdot
.868 .53809 Mdot
.868 .53843 Mdot
.868 .53883 Mdot
.868 .53891 Mdot
.868 .53918 Mdot
.868 .53924 Mdot
.868 .53993 Mdot
.868 .54004 Mdot
.868 .54024 Mdot
.868 .54065 Mdot
.868 .54094 Mdot
.868 .5413 Mdot
.868 .54142 Mdot
.868 .54149 Mdot
.868 .54169 Mdot
.868 .54211 Mdot
.868 .54215 Mdot
.868 .54237 Mdot
.868 .5428 Mdot
.868 .54351 Mdot
.868 .5438 Mdot
.868 .54393 Mdot
.868 .54446 Mdot
.868 .54452 Mdot
.868 .54468 Mdot
.868 .54576 Mdot
.868 .5459 Mdot
.868 .54605 Mdot
.868 .54656 Mdot
.868 .54669 Mdot
.868 .54691 Mdot
.868 .54701 Mdot
.868 .54729 Mdot
.868 .54804 Mdot
.868 .54806 Mdot
.868 .54812 Mdot
.868 .54842 Mdot
.868 .54856 Mdot
.868 .54876 Mdot
.868 .54932 Mdot
.868 .54987 Mdot
.868 .55058 Mdot
.868 .55071 Mdot
.868 .55084 Mdot
.868 .55113 Mdot
.868 .55118 Mdot
.868 .55153 Mdot
.868 .55186 Mdot
.868 .55204 Mdot
.868 .55242 Mdot
.868 .55248 Mdot
.868 .55253 Mdot
.868 .55264 Mdot
.868 .55327 Mdot
.868 .55338 Mdot
.868 .55357 Mdot
.868 .55358 Mdot
.868 .55368 Mdot
.868 .55368 Mdot
.868 .55371 Mdot
.868 .55373 Mdot
.868 .55427 Mdot
.868 .55452 Mdot
.868 .55472 Mdot
.868 .55524 Mdot
.868 .55535 Mdot
.868 .55551 Mdot
.868 .55564 Mdot
.868 .55581 Mdot
.868 .55586 Mdot
.868 .55588 Mdot
.868 .55598 Mdot
.868 .55609 Mdot
.868 .55622 Mdot
.868 .55634 Mdot
.868 .55672 Mdot
.868 .55681 Mdot
.868 .55707 Mdot
.868 .55713 Mdot
.868 .55732 Mdot
.868 .55742 Mdot
.868 .55759 Mdot
.868 .55804 Mdot
.868 .55804 Mdot
.868 .55856 Mdot
.868 .55874 Mdot
.868 .55877 Mdot
.868 .5594 Mdot
.868 .5595 Mdot
.868 .55971 Mdot
.868 .55972 Mdot
.868 .55994 Mdot
.868 .56004 Mdot
.868 .56032 Mdot
.868 .56086 Mdot
.868 .56099 Mdot
.868 .56127 Mdot
.868 .56135 Mdot
.868 .56148 Mdot
.868 .56149 Mdot
.868 .56157 Mdot
.868 .56193 Mdot
.868 .56226 Mdot
.868 .56235 Mdot
.868 .56287 Mdot
.868 .56292 Mdot
.868 .563 Mdot
.868 .56305 Mdot
.868 .56344 Mdot
.868 .56352 Mdot
.868 .56399 Mdot
.868 .56418 Mdot
.868 .56444 Mdot
.868 .56453 Mdot
.868 .56454 Mdot
.868 .56479 Mdot
.868 .56504 Mdot
.868 .56534 Mdot
.868 .56639 Mdot
.868 .56665 Mdot
.868 .56681 Mdot
.868 .56697 Mdot
.868 .56699 Mdot
.868 .56714 Mdot
.868 .5672 Mdot
.868 .56767 Mdot
.868 .56812 Mdot
.868 .56923 Mdot
.868 .56928 Mdot
.868 .56945 Mdot
.868 .56956 Mdot
.868 .56969 Mdot
.868 .56986 Mdot
.868 .5701 Mdot
.868 .57045 Mdot
.868 .57073 Mdot
.868 .5712 Mdot
.868 .57123 Mdot
.868 .57144 Mdot
.868 .57151 Mdot
.868 .57168 Mdot
.868 .57169 Mdot
.868 .57174 Mdot
.868 .57177 Mdot
.868 .57192 Mdot
.868 .57196 Mdot
.868 .57221 Mdot
.868 .57248 Mdot
.868 .57251 Mdot
.868 .57261 Mdot
.868 .57271 Mdot
.868 .57328 Mdot
.868 .57333 Mdot
.868 .5737 Mdot
.868 .57373 Mdot
.868 .57377 Mdot
.868 .5738 Mdot
.868 .57403 Mdot
.868 .57407 Mdot
.868 .57409 Mdot
.868 .57417 Mdot
.868 .57449 Mdot
.868 .57478 Mdot
.868 .57483 Mdot
.868 .57487 Mdot
.868 .57523 Mdot
.868 .57547 Mdot
.868 .57569 Mdot
.868 .57624 Mdot
.868 .57629 Mdot
.868 .57695 Mdot
.868 .57703 Mdot
.868 .5771 Mdot
.868 .57743 Mdot
.868 .57783 Mdot
.868 .5785 Mdot
.868 .57894 Mdot
.868 .57909 Mdot
.868 .57945 Mdot
.868 .57961 Mdot
.868 .57982 Mdot
.868 .57986 Mdot
.868 .58012 Mdot
.868 .58072 Mdot
.868 .58107 Mdot
.868 .58133 Mdot
.868 .58159 Mdot
.868 .58161 Mdot
.868 .5818 Mdot
.868 .58187 Mdot
.868 .5822 Mdot
.868 .5822 Mdot
.868 .58221 Mdot
.868 .58234 Mdot
.868 .58239 Mdot
.868 .58287 Mdot
.868 .58293 Mdot
.868 .58293 Mdot
.868 .5836 Mdot
.868 .58385 Mdot
.868 .58394 Mdot
.868 .58396 Mdot
.868 .58407 Mdot
.868 .58408 Mdot
.868 .5842 Mdot
.868 .58424 Mdot
.868 .58428 Mdot
.868 .5843 Mdot
.868 .58432 Mdot
.868 .58438 Mdot
.868 .58445 Mdot
.868 .58453 Mdot
.868 .5848 Mdot
.868 .58485 Mdot
.868 .58491 Mdot
.868 .58496 Mdot
.868 .58514 Mdot
.868 .5852 Mdot
.868 .58525 Mdot
.868 .58527 Mdot
.868 .58536 Mdot
.868 .58541 Mdot
.868 .58548 Mdot
.868 .58558 Mdot
.868 .58587 Mdot
.868 .58603 Mdot
.868 .58611 Mdot
.868 .58616 Mdot
.868 .58636 Mdot
.868 .58637 Mdot
.868 .58639 Mdot
.868 .58647 Mdot
.868 .58663 Mdot
.868 .58681 Mdot
.868 .58683 Mdot
.868 .58687 Mdot
.868 .58706 Mdot
.868 .58718 Mdot
.868 .58725 Mdot
.868 .58736 Mdot
.868 .58737 Mdot
.868 .5874 Mdot
.868 .58743 Mdot
.868 .58746 Mdot
.868 .58753 Mdot
.868 .58759 Mdot
.868 .58762 Mdot
.868 .58768 Mdot
.868 .5877 Mdot
.868 .58771 Mdot
.868 .58771 Mdot
.868 .58773 Mdot
.868 .58776 Mdot
.868 .58777 Mdot
.868 .58777 Mdot
.868 .58778 Mdot
.87 .0728 Mdot
.87 .0728 Mdot
.87 .07291 Mdot
.87 .07296 Mdot
.87 .07298 Mdot
.87 .07324 Mdot
.87 .07325 Mdot
.87 .07336 Mdot
.87 .07339 Mdot
.87 .0734 Mdot
.87 .07341 Mdot
.87 .07348 Mdot
.87 .07355 Mdot
.87 .07362 Mdot
.87 .07369 Mdot
.87 .07374 Mdot
.87 .07411 Mdot
.87 .07432 Mdot
.87 .0747 Mdot
.87 .07471 Mdot
.87 .07486 Mdot
.87 .07543 Mdot
.87 .07593 Mdot
.87 .07608 Mdot
.87 .07611 Mdot
.87 .07619 Mdot
.87 .07623 Mdot
.87 .07628 Mdot
.87 .07663 Mdot
.87 .07665 Mdot
.87 .0772 Mdot
.87 .0773 Mdot
.87 .07765 Mdot
.87 .07768 Mdot
.87 .07783 Mdot
.87 .07798 Mdot
.87 .07805 Mdot
.87 .07834 Mdot
.87 .07877 Mdot
.87 .07897 Mdot
.87 .07943 Mdot
.87 .07947 Mdot
.87 .07956 Mdot
.87 .0801 Mdot
.87 .08018 Mdot
.87 .08073 Mdot
.87 .08098 Mdot
.87 .08106 Mdot
.87 .08119 Mdot
.87 .0812 Mdot
.87 .08182 Mdot
.87 .08252 Mdot
.87 .08256 Mdot
.87 .08361 Mdot
.87 .08379 Mdot
.87 .0853 Mdot
.87 .08532 Mdot
.87 .08547 Mdot
.87 .08559 Mdot
.87 .08642 Mdot
.87 .0875 Mdot
.87 .08787 Mdot
.87 .088 Mdot
.87 .08863 Mdot
.87 .08909 Mdot
.87 .08994 Mdot
.87 .09004 Mdot
.87 .09055 Mdot
.87 .09205 Mdot
.87 .09209 Mdot
.87 .0926 Mdot
.87 .09274 Mdot
.87 .09473 Mdot
.87 .09543 Mdot
.87 .09552 Mdot
.87 .09602 Mdot
.87 .09717 Mdot
.87 .09743 Mdot
.87 .09766 Mdot
.87 .09802 Mdot
.87 .09823 Mdot
.87 .09841 Mdot
.87 .09876 Mdot
.87 .09913 Mdot
.87 .10102 Mdot
.87 .10187 Mdot
.87 .10267 Mdot
.87 .10342 Mdot
.87 .10529 Mdot
.87 .10532 Mdot
.87 .10554 Mdot
.87 .10557 Mdot
.87 .10596 Mdot
.87 .10758 Mdot
.87 .10816 Mdot
.87 .10872 Mdot
.87 .10919 Mdot
.87 .10989 Mdot
.87 .11162 Mdot
.87 .11314 Mdot
.87 .11334 Mdot
.87 .11437 Mdot
.87 .11456 Mdot
.87 .11575 Mdot
.87 .11597 Mdot
.87 .11728 Mdot
.87 .11909 Mdot
.87 .1197 Mdot
.87 .12025 Mdot
.87 .12048 Mdot
.87 .12259 Mdot
.87 .12279 Mdot
.87 .12426 Mdot
.87 .1263 Mdot
.87 .12661 Mdot
.87 .12697 Mdot
.87 .12832 Mdot
.87 .12947 Mdot
.87 .12969 Mdot
.87 .12977 Mdot
.87 .13082 Mdot
.87 .13232 Mdot
.87 .13313 Mdot
.87 .13328 Mdot
.87 .13536 Mdot
.87 .13588 Mdot
.87 .13622 Mdot
.87 .13698 Mdot
.87 .1373 Mdot
.87 .1374 Mdot
.87 .13781 Mdot
.87 .13929 Mdot
.87 .13971 Mdot
.87 .14013 Mdot
.87 .14123 Mdot
.87 .14365 Mdot
.87 .14679 Mdot
.87 .14684 Mdot
.87 .14784 Mdot
.87 .14852 Mdot
.87 .14992 Mdot
.87 .14994 Mdot
.87 .15141 Mdot
.87 .15182 Mdot
.87 .15193 Mdot
.87 .15227 Mdot
.87 .15337 Mdot
.87 .15374 Mdot
.87 .15607 Mdot
.87 .15668 Mdot
.87 .15819 Mdot
.87 .15853 Mdot
.87 .1591 Mdot
.87 .15948 Mdot
.87 .15985 Mdot
.87 .16116 Mdot
.87 .16328 Mdot
.87 .16399 Mdot
.87 .16432 Mdot
.87 .16451 Mdot
.87 .16458 Mdot
.87 .16492 Mdot
.87 .16576 Mdot
.87 .16696 Mdot
.87 .1678 Mdot
.87 .16816 Mdot
.87 .16898 Mdot
.87 .16958 Mdot
.87 .16963 Mdot
.87 .17079 Mdot
.87 .17112 Mdot
.87 .17147 Mdot
.87 .17173 Mdot
.87 .17271 Mdot
.87 .17345 Mdot
.87 .17363 Mdot
.87 .17391 Mdot
.87 .1742 Mdot
.87 .17471 Mdot
.87 .1749 Mdot
.87 .17513 Mdot
.87 .17562 Mdot
.87 .17788 Mdot
.87 .17849 Mdot
.87 .17917 Mdot
.87 .18116 Mdot
.87 .18209 Mdot
.87 .18412 Mdot
.87 .18492 Mdot
.87 .1853 Mdot
.87 .18569 Mdot
.87 .18618 Mdot
.87 .18633 Mdot
.87 .18685 Mdot
.87 .18949 Mdot
.87 .19006 Mdot
.87 .19035 Mdot
.87 .19091 Mdot
.87 .19139 Mdot
.87 .1928 Mdot
.87 .19381 Mdot
.87 .19549 Mdot
.87 .19825 Mdot
.87 .19867 Mdot
.87 .19894 Mdot
.87 .19973 Mdot
.87 .1998 Mdot
.87 .2004 Mdot
.87 .20044 Mdot
.87 .20117 Mdot
.87 .20186 Mdot
.87 .2021 Mdot
.87 .20559 Mdot
.87 .20584 Mdot
.87 .20594 Mdot
.87 .20657 Mdot
.87 .20664 Mdot
.87 .20725 Mdot
.87 .21005 Mdot
.87 .21072 Mdot
.87 .21203 Mdot
.87 .21227 Mdot
.87 .21233 Mdot
.87 .21334 Mdot
.87 .21339 Mdot
.87 .21534 Mdot
.87 .2158 Mdot
.87 .21632 Mdot
.87 .21667 Mdot
.87 .21757 Mdot
.87 .21789 Mdot
.87 .21869 Mdot
.87 .2187 Mdot
.87 .21903 Mdot
.87 .21919 Mdot
.87 .21925 Mdot
.87 .21929 Mdot
.87 .21941 Mdot
.87 .22005 Mdot
.87 .22009 Mdot
.87 .22044 Mdot
.87 .22052 Mdot
.87 .22057 Mdot
.87 .22058 Mdot
.87 .22082 Mdot
.87 .22102 Mdot
.87 .22124 Mdot
.87 .22147 Mdot
.87 .22161 Mdot
.87 .22163 Mdot
.87 .2219 Mdot
.87 .22276 Mdot
.87 .22342 Mdot
.87 .22453 Mdot
.87 .22459 Mdot
.87 .22465 Mdot
.87 .2251 Mdot
.87 .22519 Mdot
.87 .22688 Mdot
.87 .22774 Mdot
.87 .2284 Mdot
.87 .22886 Mdot
.87 .22895 Mdot
.87 .22923 Mdot
.87 .22933 Mdot
.87 .22949 Mdot
.87 .23022 Mdot
.87 .23023 Mdot
.87 .23054 Mdot
.87 .23056 Mdot
.87 .23064 Mdot
.87 .23104 Mdot
.87 .2321 Mdot
.87 .23229 Mdot
.87 .23231 Mdot
.87 .23251 Mdot
.87 .23262 Mdot
.87 .23371 Mdot
.87 .23379 Mdot
.87 .23423 Mdot
.87 .23424 Mdot
.87 .23471 Mdot
.87 .23492 Mdot
.87 .2358 Mdot
.87 .23634 Mdot
.87 .23712 Mdot
.87 .23746 Mdot
.87 .23774 Mdot
.87 .23861 Mdot
.87 .23883 Mdot
.87 .23912 Mdot
.87 .23924 Mdot
.87 .23951 Mdot
.87 .24117 Mdot
.87 .2414 Mdot
.87 .24161 Mdot
.87 .24255 Mdot
.87 .24263 Mdot
.87 .24307 Mdot
.87 .24313 Mdot
.87 .24382 Mdot
.87 .24394 Mdot
.87 .24406 Mdot
.87 .24446 Mdot
.87 .24448 Mdot
.87 .24469 Mdot
.87 .24511 Mdot
.87 .24541 Mdot
.87 .24583 Mdot
.87 .24626 Mdot
.87 .24628 Mdot
.87 .24635 Mdot
.87 .24647 Mdot
.87 .24672 Mdot
.87 .24797 Mdot
.87 .24811 Mdot
.87 .24846 Mdot
.87 .24859 Mdot
.87 .24915 Mdot
.87 .2504 Mdot
.87 .25081 Mdot
.87 .25094 Mdot
.87 .25115 Mdot
.87 .25171 Mdot
.87 .25172 Mdot
.87 .25226 Mdot
.87 .25253 Mdot
.87 .25292 Mdot
.87 .25294 Mdot
.87 .25419 Mdot
.87 .25579 Mdot
.87 .25658 Mdot
.87 .25675 Mdot
.87 .2568 Mdot
.87 .25693 Mdot
.87 .25725 Mdot
.87 .25761 Mdot
.87 .25892 Mdot
.87 .26004 Mdot
.87 .26017 Mdot
.87 .26129 Mdot
.87 .26145 Mdot
.87 .26322 Mdot
.87 .26331 Mdot
.87 .26431 Mdot
.87 .26443 Mdot
.87 .26469 Mdot
.87 .26498 Mdot
.87 .26653 Mdot
.87 .26787 Mdot
.87 .26969 Mdot
.87 .27033 Mdot
.87 .27064 Mdot
.87 .2721 Mdot
.87 .27211 Mdot
.87 .27225 Mdot
.87 .27379 Mdot
.87 .27598 Mdot
.87 .27621 Mdot
.87 .27644 Mdot
.87 .27655 Mdot
.87 .27692 Mdot
.87 .27707 Mdot
.87 .27801 Mdot
.87 .27841 Mdot
.87 .28041 Mdot
.87 .28081 Mdot
.87 .28194 Mdot
.87 .28233 Mdot
.87 .28408 Mdot
.87 .2844 Mdot
.87 .28605 Mdot
.87 .28632 Mdot
.87 .28774 Mdot
.87 .28975 Mdot
.87 .29067 Mdot
.87 .29096 Mdot
.87 .29168 Mdot
.87 .29235 Mdot
.87 .29335 Mdot
.87 .29393 Mdot
.87 .29442 Mdot
.87 .29485 Mdot
.87 .29542 Mdot
.87 .29643 Mdot
.87 .29714 Mdot
.87 .29741 Mdot
.87 .2998 Mdot
.87 .30017 Mdot
.87 .3011 Mdot
.87 .30166 Mdot
.87 .30398 Mdot
.87 .3062 Mdot
.87 .30633 Mdot
.87 .30675 Mdot
.87 .30824 Mdot
.87 .30984 Mdot
.87 .31331 Mdot
.87 .31337 Mdot
.87 .31387 Mdot
.87 .31397 Mdot
.87 .31404 Mdot
.87 .31435 Mdot
.87 .3146 Mdot
.87 .31485 Mdot
.87 .3151 Mdot
.87 .31528 Mdot
.87 .3179 Mdot
.87 .31943 Mdot
.87 .32036 Mdot
.87 .32068 Mdot
.87 .32083 Mdot
.87 .32098 Mdot
.87 .32157 Mdot
.87 .32247 Mdot
.87 .32314 Mdot
.87 .3234 Mdot
.87 .32371 Mdot
.87 .32495 Mdot
.87 .32558 Mdot
.87 .32644 Mdot
.87 .32745 Mdot
.87 .3276 Mdot
.87 .3276 Mdot
.87 .32902 Mdot
.87 .32906 Mdot
.87 .33011 Mdot
.87 .33173 Mdot
.87 .33187 Mdot
.87 .33271 Mdot
.87 .33406 Mdot
.87 .33457 Mdot
.87 .33495 Mdot
.87 .33562 Mdot
.87 .33725 Mdot
.87 .33773 Mdot
.87 .33914 Mdot
.87 .33968 Mdot
.87 .34079 Mdot
.87 .34135 Mdot
.87 .34324 Mdot
.87 .34375 Mdot
.87 .34469 Mdot
.87 .34579 Mdot
.87 .34616 Mdot
.87 .34707 Mdot
.87 .34796 Mdot
.87 .34926 Mdot
.87 .35006 Mdot
.87 .35069 Mdot
.87 .35079 Mdot
.87 .35139 Mdot
.87 .35216 Mdot
.87 .3555 Mdot
.87 .35644 Mdot
.87 .35735 Mdot
.87 .35796 Mdot
.87 .35846 Mdot
.87 .35947 Mdot
.87 .35953 Mdot
.87 .36064 Mdot
.87 .36207 Mdot
.87 .36241 Mdot
.87 .36286 Mdot
.87 .36705 Mdot
.87 .36778 Mdot
.87 .36866 Mdot
.87 .36978 Mdot
.87 .37054 Mdot
.87 .3719 Mdot
.87 .37305 Mdot
.87 .37431 Mdot
.87 .37465 Mdot
.87 .37506 Mdot
.87 .37516 Mdot
.87 .37534 Mdot
.87 .37565 Mdot
.87 .37753 Mdot
.87 .37785 Mdot
.87 .37904 Mdot
.87 .37925 Mdot
.87 .38048 Mdot
.87 .38075 Mdot
.87 .38136 Mdot
.87 .38324 Mdot
.87 .38358 Mdot
.87 .3836 Mdot
.87 .38403 Mdot
.87 .38549 Mdot
.87 .38679 Mdot
.87 .3884 Mdot
.87 .38959 Mdot
.87 .39038 Mdot
.87 .39135 Mdot
.87 .39211 Mdot
.87 .39283 Mdot
.87 .39307 Mdot
.87 .394 Mdot
.87 .39494 Mdot
.87 .39533 Mdot
.87 .39713 Mdot
.87 .39733 Mdot
.87 .39827 Mdot
.87 .39923 Mdot
.87 .39969 Mdot
.87 .40036 Mdot
.87 .40101 Mdot
.87 .40167 Mdot
.87 .40254 Mdot
.87 .40399 Mdot
.87 .40511 Mdot
.87 .40596 Mdot
.87 .4069 Mdot
.87 .40701 Mdot
.87 .40742 Mdot
.87 .40942 Mdot
.87 .40966 Mdot
.87 .41382 Mdot
.87 .41393 Mdot
.87 .41475 Mdot
.87 .41581 Mdot
.87 .416 Mdot
.87 .41606 Mdot
.87 .41751 Mdot
.87 .41782 Mdot
.87 .41871 Mdot
.87 .4194 Mdot
.87 .4194 Mdot
.87 .41977 Mdot
.87 .42047 Mdot
.87 .42051 Mdot
.87 .42073 Mdot
.87 .42131 Mdot
.87 .42148 Mdot
.87 .4224 Mdot
.87 .42346 Mdot
.87 .4236 Mdot
.87 .42412 Mdot
.87 .42445 Mdot
.87 .42468 Mdot
.87 .42539 Mdot
.87 .42557 Mdot
.87 .42688 Mdot
.87 .42766 Mdot
.87 .42843 Mdot
.87 .43033 Mdot
.87 .43053 Mdot
.87 .43151 Mdot
.87 .43279 Mdot
.87 .43318 Mdot
.87 .43403 Mdot
.87 .43441 Mdot
.87 .43475 Mdot
.87 .43698 Mdot
.87 .43745 Mdot
.87 .43812 Mdot
.87 .43829 Mdot
.87 .43847 Mdot
.87 .43925 Mdot
.87 .43976 Mdot
.87 .44001 Mdot
.87 .44068 Mdot
.87 .44074 Mdot
.87 .44209 Mdot
.87 .44237 Mdot
.87 .44332 Mdot
.87 .44342 Mdot
.87 .44367 Mdot
.87 .44388 Mdot
.87 .44497 Mdot
.87 .44625 Mdot
.87 .44744 Mdot
.87 .44805 Mdot
.87 .4488 Mdot
.87 .44944 Mdot
.87 .44952 Mdot
.87 .4498 Mdot
.87 .44993 Mdot
.87 .45058 Mdot
.87 .45148 Mdot
.87 .45203 Mdot
.87 .45218 Mdot
.87 .45235 Mdot
.87 .45264 Mdot
.87 .45367 Mdot
.87 .45443 Mdot
.87 .45537 Mdot
.87 .45602 Mdot
.87 .45658 Mdot
.87 .45669 Mdot
.87 .45682 Mdot
.87 .45736 Mdot
.87 .4575 Mdot
.87 .45821 Mdot
.87 .45868 Mdot
.87 .45933 Mdot
.87 .45942 Mdot
.87 .46007 Mdot
.87 .46118 Mdot
.87 .46154 Mdot
.87 .46215 Mdot
.87 .46279 Mdot
.87 .46326 Mdot
.87 .46336 Mdot
.87 .46504 Mdot
.87 .46567 Mdot
.87 .46637 Mdot
.87 .46669 Mdot
.87 .4672 Mdot
.87 .46763 Mdot
.87 .46772 Mdot
.87 .46799 Mdot
.87 .46845 Mdot
.87 .46862 Mdot
.87 .46862 Mdot
.87 .46895 Mdot
.87 .46937 Mdot
.87 .47022 Mdot
.87 .47031 Mdot
.87 .47081 Mdot
.87 .47317 Mdot
.87 .47328 Mdot
.87 .47419 Mdot
.87 .47443 Mdot
.87 .47486 Mdot
.87 .47525 Mdot
.87 .47576 Mdot
.87 .47641 Mdot
.87 .4771 Mdot
.87 .47739 Mdot
.87 .47769 Mdot
.87 .47884 Mdot
.87 .47963 Mdot
.87 .47981 Mdot
.87 .48139 Mdot
.87 .48337 Mdot
.87 .48394 Mdot
.87 .48457 Mdot
.87 .48476 Mdot
.87 .48597 Mdot
.87 .48609 Mdot
.87 .48661 Mdot
.87 .4867 Mdot
.87 .48734 Mdot
.87 .48814 Mdot
.87 .48838 Mdot
.87 .4887 Mdot
.87 .48923 Mdot
.87 .49028 Mdot
.87 .4906 Mdot
.87 .49345 Mdot
.87 .49363 Mdot
.87 .49436 Mdot
.87 .49481 Mdot
.87 .49484 Mdot
.87 .49569 Mdot
.87 .49606 Mdot
.87 .49644 Mdot
.87 .49809 Mdot
.87 .49837 Mdot
.87 .49862 Mdot
.87 .49946 Mdot
.87 .49981 Mdot
.87 .50017 Mdot
.87 .50032 Mdot
.87 .50112 Mdot
.87 .50132 Mdot
.87 .50271 Mdot
.87 .50292 Mdot
.87 .50429 Mdot
.87 .50455 Mdot
.87 .50541 Mdot
.87 .50574 Mdot
.87 .50579 Mdot
.87 .50681 Mdot
.87 .50683 Mdot
.87 .50737 Mdot
.87 .50737 Mdot
.87 .50743 Mdot
.87 .50781 Mdot
.87 .50837 Mdot
.87 .50896 Mdot
.87 .50906 Mdot
.87 .50965 Mdot
.87 .50993 Mdot
.87 .50999 Mdot
.87 .51011 Mdot
.87 .51103 Mdot
.87 .51201 Mdot
.87 .51217 Mdot
.87 .51226 Mdot
.87 .51235 Mdot
.87 .51253 Mdot
.87 .51402 Mdot
.87 .51515 Mdot
.87 .51531 Mdot
.87 .51722 Mdot
.87 .51755 Mdot
.87 .51769 Mdot
.87 .51855 Mdot
.87 .51865 Mdot
.87 .51947 Mdot
.87 .52096 Mdot
.87 .52129 Mdot
.87 .52319 Mdot
.87 .52392 Mdot
.87 .52406 Mdot
.87 .52445 Mdot
.87 .52459 Mdot
.87 .52576 Mdot
.87 .52581 Mdot
.87 .52606 Mdot
.87 .52614 Mdot
.87 .5269 Mdot
.87 .52743 Mdot
.87 .52748 Mdot
.87 .52832 Mdot
.87 .52993 Mdot
.87 .53012 Mdot
.87 .5305 Mdot
.87 .53114 Mdot
.87 .53119 Mdot
.87 .53157 Mdot
.87 .532 Mdot
.87 .53267 Mdot
.87 .53279 Mdot
.87 .53305 Mdot
.87 .53359 Mdot
.87 .53401 Mdot
.87 .53402 Mdot
.87 .53415 Mdot
.87 .53442 Mdot
.87 .53461 Mdot
.87 .53468 Mdot
.87 .53472 Mdot
.87 .53486 Mdot
.87 .53528 Mdot
.87 .53563 Mdot
.87 .53567 Mdot
.87 .53609 Mdot
.87 .53617 Mdot
.87 .53624 Mdot
.87 .53625 Mdot
.87 .53639 Mdot
.87 .53653 Mdot
.87 .53663 Mdot
.87 .53677 Mdot
.87 .53701 Mdot
.87 .53728 Mdot
.87 .53745 Mdot
.87 .53747 Mdot
.87 .53779 Mdot
.87 .5387 Mdot
.87 .53877 Mdot
.87 .53915 Mdot
.87 .53952 Mdot
.87 .54021 Mdot
.87 .54077 Mdot
.87 .54084 Mdot
.87 .5409 Mdot
.87 .54125 Mdot
.87 .54141 Mdot
.87 .54151 Mdot
.87 .54151 Mdot
.87 .54232 Mdot
.87 .54314 Mdot
.87 .54336 Mdot
.87 .5442 Mdot
.87 .5443 Mdot
.87 .545 Mdot
.87 .54504 Mdot
.87 .54549 Mdot
.87 .54559 Mdot
.87 .54588 Mdot
.87 .54599 Mdot
.87 .54615 Mdot
.87 .5463 Mdot
.87 .54692 Mdot
.87 .54693 Mdot
.87 .54726 Mdot
.87 .54728 Mdot
.87 .54735 Mdot
.87 .54777 Mdot
.87 .54798 Mdot
.87 .54886 Mdot
.87 .54905 Mdot
.87 .54908 Mdot
.87 .54927 Mdot
.87 .54931 Mdot
.87 .54938 Mdot
.87 .55048 Mdot
.87 .55055 Mdot
.87 .55077 Mdot
.87 .551 Mdot
.87 .55101 Mdot
.87 .5512 Mdot
.87 .55122 Mdot
.87 .55147 Mdot
.87 .55155 Mdot
.87 .55168 Mdot
.87 .55254 Mdot
.87 .55306 Mdot
.87 .55337 Mdot
.87 .5538 Mdot
.87 .55395 Mdot
.87 .55413 Mdot
.87 .55421 Mdot
.87 .55439 Mdot
.87 .5552 Mdot
.87 .55536 Mdot
.87 .55541 Mdot
.87 .55556 Mdot
.87 .55568 Mdot
.87 .55579 Mdot
.87 .55604 Mdot
.87 .55666 Mdot
.87 .55694 Mdot
.87 .55755 Mdot
.87 .55775 Mdot
.87 .55794 Mdot
.87 .55863 Mdot
.87 .55877 Mdot
.87 .55884 Mdot
.87 .5589 Mdot
.87 .55905 Mdot
.87 .55914 Mdot
.87 .55923 Mdot
.87 .55928 Mdot
.87 .5595 Mdot
.87 .5598 Mdot
.87 .55988 Mdot
.87 .55998 Mdot
.87 .56008 Mdot
.87 .56043 Mdot
.87 .56045 Mdot
.87 .56063 Mdot
.87 .56087 Mdot
.87 .56098 Mdot
.87 .56123 Mdot
.87 .56159 Mdot
.87 .56184 Mdot
.87 .56194 Mdot
.87 .56196 Mdot
.87 .56202 Mdot
.87 .56212 Mdot
.87 .56233 Mdot
.87 .56296 Mdot
.87 .56335 Mdot
.87 .56346 Mdot
.87 .56358 Mdot
.87 .56374 Mdot
.87 .56384 Mdot
.87 .56429 Mdot
.87 .56447 Mdot
.87 .56516 Mdot
.87 .56527 Mdot
.87 .56559 Mdot
.87 .56569 Mdot
.87 .56573 Mdot
.87 .56585 Mdot
.87 .56628 Mdot
.87 .56629 Mdot
.87 .5667 Mdot
.87 .5669 Mdot
.87 .56719 Mdot
.87 .5672 Mdot
.87 .56812 Mdot
.87 .56882 Mdot
.87 .56914 Mdot
.87 .56927 Mdot
.87 .56939 Mdot
.87 .56982 Mdot
.87 .56994 Mdot
.87 .56997 Mdot
.87 .57006 Mdot
.87 .57028 Mdot
.87 .57038 Mdot
.87 .57053 Mdot
.87 .57113 Mdot
.87 .57117 Mdot
.87 .5714 Mdot
.87 .57183 Mdot
.87 .57214 Mdot
.87 .57216 Mdot
.87 .57222 Mdot
.87 .57255 Mdot
.87 .57294 Mdot
.87 .57304 Mdot
.87 .57313 Mdot
.87 .57371 Mdot
.87 .57413 Mdot
.87 .57419 Mdot
.87 .57479 Mdot
.87 .57485 Mdot
.87 .57501 Mdot
.87 .57518 Mdot
.87 .5757 Mdot
.87 .57607 Mdot
.87 .57613 Mdot
.87 .57647 Mdot
.87 .57652 Mdot
.87 .57681 Mdot
.87 .57687 Mdot
.87 .57729 Mdot
.87 .57778 Mdot
.87 .57798 Mdot
.87 .57811 Mdot
.87 .57827 Mdot
.87 .57843 Mdot
.87 .57888 Mdot
.87 .57899 Mdot
.87 .579 Mdot
.87 .57906 Mdot
.87 .57907 Mdot
.87 .57959 Mdot
.87 .5798 Mdot
.87 .58003 Mdot
.87 .58026 Mdot
.87 .58079 Mdot
.87 .58089 Mdot
.87 .58099 Mdot
.87 .58104 Mdot
.87 .5811 Mdot
.87 .5812 Mdot
.87 .58126 Mdot
.87 .58133 Mdot
.87 .58165 Mdot
.87 .58179 Mdot
.87 .58182 Mdot
.87 .58201 Mdot
.87 .58256 Mdot
.87 .5826 Mdot
.87 .58274 Mdot
.87 .58275 Mdot
.87 .58316 Mdot
.87 .5833 Mdot
.87 .58333 Mdot
.87 .58357 Mdot
.87 .58369 Mdot
.87 .58387 Mdot
.87 .5839 Mdot
.87 .584 Mdot
.87 .5843 Mdot
.87 .58453 Mdot
.87 .58456 Mdot
.87 .5846 Mdot
.87 .58461 Mdot
.87 .58502 Mdot
.87 .58507 Mdot
.87 .58536 Mdot
.87 .58537 Mdot
.87 .58556 Mdot
.87 .58573 Mdot
.87 .58573 Mdot
.87 .58577 Mdot
.87 .58579 Mdot
.87 .58586 Mdot
.87 .58601 Mdot
.87 .58603 Mdot
.87 .58618 Mdot
.87 .5862 Mdot
.87 .58633 Mdot
.87 .58639 Mdot
.87 .58651 Mdot
.87 .58659 Mdot
.87 .58661 Mdot
.87 .58665 Mdot
.87 .58669 Mdot
.87 .58669 Mdot
.87 .58679 Mdot
.87 .58682 Mdot
.87 .58697 Mdot
.87 .58697 Mdot
.87 .58707 Mdot
.87 .58708 Mdot
.87 .58709 Mdot
.87 .58712 Mdot
.87 .58712 Mdot
.87 .58716 Mdot
.87 .5873 Mdot
.87 .58745 Mdot
.87 .58749 Mdot
.87 .5875 Mdot
.87 .5876 Mdot
.87 .58766 Mdot
.87 .58776 Mdot
.87 .58777 Mdot
.87 .58779 Mdot
.87 .58781 Mdot
.87 .58783 Mdot
.87 .58785 Mdot
.87 .58785 Mdot
.87 .58785 Mdot
.87 .58786 Mdot
.87 .58789 Mdot
.87 .58789 Mdot
.87 .58796 Mdot
.87 .58797 Mdot
.87 .58798 Mdot
.87 .58801 Mdot
.87 .58801 Mdot
.872 .07195 Mdot
.872 .0722 Mdot
.872 .07222 Mdot
.872 .07226 Mdot
.872 .07232 Mdot
.872 .07237 Mdot
.872 .07271 Mdot
.872 .07272 Mdot
.872 .07287 Mdot
.872 .07313 Mdot
.872 .07322 Mdot
.872 .07339 Mdot
.872 .07398 Mdot
.872 .07401 Mdot
.872 .07404 Mdot
.872 .07409 Mdot
.872 .07415 Mdot
.872 .07418 Mdot
.872 .07421 Mdot
.872 .07422 Mdot
.872 .07429 Mdot
.872 .07451 Mdot
.872 .07461 Mdot
.872 .07468 Mdot
.872 .07493 Mdot
.872 .07506 Mdot
.872 .07508 Mdot
.872 .07543 Mdot
.872 .07548 Mdot
.872 .07555 Mdot
.872 .07568 Mdot
.872 .07582 Mdot
.872 .07611 Mdot
.872 .07677 Mdot
.872 .07768 Mdot
.872 .0777 Mdot
.872 .07874 Mdot
.872 .07885 Mdot
.872 .0794 Mdot
.872 .07968 Mdot
.872 .07969 Mdot
.872 .07979 Mdot
.872 .07994 Mdot
.872 .08002 Mdot
.872 .0801 Mdot
.872 .08022 Mdot
.872 .08093 Mdot
.872 .08154 Mdot
.872 .08278 Mdot
.872 .08365 Mdot
.872 .08415 Mdot
.872 .08504 Mdot
.872 .08573 Mdot
.872 .08606 Mdot
.872 .0863 Mdot
.872 .08668 Mdot
.872 .08748 Mdot
.872 .08936 Mdot
.872 .08943 Mdot
.872 .08979 Mdot
.872 .08985 Mdot
.872 .09152 Mdot
.872 .09159 Mdot
.872 .09457 Mdot
.872 .09704 Mdot
.872 .09721 Mdot
.872 .09809 Mdot
.872 .0981 Mdot
.872 .09856 Mdot
.872 .09955 Mdot
.872 .09986 Mdot
.872 .10031 Mdot
.872 .10085 Mdot
.872 .10102 Mdot
.872 .10233 Mdot
.872 .10486 Mdot
.872 .10521 Mdot
.872 .10575 Mdot
.872 .10594 Mdot
.872 .10719 Mdot
.872 .10818 Mdot
.872 .10827 Mdot
.872 .10853 Mdot
.872 .10995 Mdot
.872 .11047 Mdot
.872 .11085 Mdot
.872 .11158 Mdot
.872 .11207 Mdot
.872 .11439 Mdot
.872 .11592 Mdot
.872 .11614 Mdot
.872 .11681 Mdot
.872 .11794 Mdot
.872 .11826 Mdot
.872 .11849 Mdot
.872 .12189 Mdot
.872 .12271 Mdot
.872 .12352 Mdot
.872 .12421 Mdot
.872 .12541 Mdot
.872 .12542 Mdot
.872 .12705 Mdot
.872 .12793 Mdot
.872 .12945 Mdot
.872 .12958 Mdot
.872 .12998 Mdot
.872 .13063 Mdot
.872 .13095 Mdot
.872 .13116 Mdot
.872 .13137 Mdot
.872 .13164 Mdot
.872 .13235 Mdot
.872 .13246 Mdot
.872 .13271 Mdot
.872 .13336 Mdot
.872 .13345 Mdot
.872 .13461 Mdot
.872 .13502 Mdot
.872 .1351 Mdot
.872 .13625 Mdot
.872 .13644 Mdot
.872 .13748 Mdot
.872 .13831 Mdot
.872 .13866 Mdot
.872 .1398 Mdot
.872 .14256 Mdot
.872 .14418 Mdot
.872 .14466 Mdot
.872 .14488 Mdot
.872 .14562 Mdot
.872 .14592 Mdot
.872 .14595 Mdot
.872 .14598 Mdot
.872 .14864 Mdot
.872 .15006 Mdot
.872 .15147 Mdot
.872 .15397 Mdot
.872 .15545 Mdot
.872 .1563 Mdot
.872 .1565 Mdot
.872 .15727 Mdot
.872 .15736 Mdot
.872 .15794 Mdot
.872 .16058 Mdot
.872 .16202 Mdot
.872 .1657 Mdot
.872 .16582 Mdot
.872 .16916 Mdot
.872 .17008 Mdot
.872 .1702 Mdot
.872 .17095 Mdot
.872 .1723 Mdot
.872 .17316 Mdot
.872 .17403 Mdot
.872 .17596 Mdot
.872 .17665 Mdot
.872 .17713 Mdot
.872 .17717 Mdot
.872 .17824 Mdot
.872 .17879 Mdot
.872 .17894 Mdot
.872 .17917 Mdot
.872 .17944 Mdot
.872 .17971 Mdot
.872 .18053 Mdot
.872 .18103 Mdot
.872 .18106 Mdot
.872 .18191 Mdot
.872 .182 Mdot
.872 .18203 Mdot
.872 .18276 Mdot
.872 .18426 Mdot
.872 .18427 Mdot
.872 .18462 Mdot
.872 .18469 Mdot
.872 .18486 Mdot
.872 .18572 Mdot
.872 .18576 Mdot
.872 .18652 Mdot
.872 .18771 Mdot
.872 .18772 Mdot
.872 .18828 Mdot
.872 .18902 Mdot
.872 .18919 Mdot
.872 .18972 Mdot
.872 .18998 Mdot
.872 .19027 Mdot
.872 .19039 Mdot
.872 .19078 Mdot
.872 .19122 Mdot
.872 .1913 Mdot
.872 .19192 Mdot
.872 .19213 Mdot
.872 .19221 Mdot
.872 .19244 Mdot
.872 .19282 Mdot
.872 .19361 Mdot
.872 .19499 Mdot
.872 .19542 Mdot
.872 .19596 Mdot
.872 .1963 Mdot
.872 .19639 Mdot
.872 .19704 Mdot
.872 .19766 Mdot
.872 .19902 Mdot
.872 .20026 Mdot
.872 .20049 Mdot
.872 .2007 Mdot
.872 .20088 Mdot
.872 .20096 Mdot
.872 .20191 Mdot
.872 .20235 Mdot
.872 .20523 Mdot
.872 .20593 Mdot
.872 .20638 Mdot
.872 .2081 Mdot
.872 .20827 Mdot
.872 .20954 Mdot
.872 .20992 Mdot
.872 .2106 Mdot
.872 .21253 Mdot
.872 .21265 Mdot
.872 .21332 Mdot
.872 .21515 Mdot
.872 .21612 Mdot
.872 .21662 Mdot
.872 .21676 Mdot
.872 .21688 Mdot
.872 .21697 Mdot
.872 .21701 Mdot
.872 .21709 Mdot
.872 .21728 Mdot
.872 .21743 Mdot
.872 .21849 Mdot
.872 .21853 Mdot
.872 .21897 Mdot
.872 .21966 Mdot
.872 .21981 Mdot
.872 .22008 Mdot
.872 .22062 Mdot
.872 .22104 Mdot
.872 .22143 Mdot
.872 .22174 Mdot
.872 .22211 Mdot
.872 .2222 Mdot
.872 .22242 Mdot
.872 .22246 Mdot
.872 .22256 Mdot
.872 .22263 Mdot
.872 .2228 Mdot
.872 .223 Mdot
.872 .22308 Mdot
.872 .22314 Mdot
.872 .22317 Mdot
.872 .22319 Mdot
.872 .22342 Mdot
.872 .22351 Mdot
.872 .22367 Mdot
.872 .22379 Mdot
.872 .22393 Mdot
.872 .22409 Mdot
.872 .22435 Mdot
.872 .22442 Mdot
.872 .22446 Mdot
.872 .22461 Mdot
.872 .22484 Mdot
.872 .2254 Mdot
.872 .22582 Mdot
.872 .22586 Mdot
.872 .226 Mdot
.872 .22692 Mdot
.872 .22696 Mdot
.872 .22711 Mdot
.872 .22733 Mdot
.872 .22739 Mdot
.872 .22753 Mdot
.872 .22774 Mdot
.872 .22815 Mdot
.872 .22894 Mdot
.872 .22902 Mdot
.872 .22906 Mdot
.872 .2303 Mdot
.872 .23089 Mdot
.872 .23109 Mdot
.872 .2316 Mdot
.872 .23165 Mdot
.872 .23218 Mdot
.872 .23232 Mdot
.872 .23254 Mdot
.872 .23344 Mdot
.872 .23387 Mdot
.872 .23395 Mdot
.872 .23402 Mdot
.872 .23448 Mdot
.872 .23491 Mdot
.872 .23545 Mdot
.872 .23576 Mdot
.872 .23658 Mdot
.872 .23665 Mdot
.872 .23675 Mdot
.872 .23695 Mdot
.872 .23711 Mdot
.872 .23724 Mdot
.872 .23728 Mdot
.872 .23746 Mdot
.872 .23769 Mdot
.872 .23792 Mdot
.872 .23811 Mdot
.872 .2385 Mdot
.872 .23876 Mdot
.872 .23905 Mdot
.872 .2391 Mdot
.872 .23913 Mdot
.872 .23925 Mdot
.872 .23999 Mdot
.872 .24 Mdot
.872 .24003 Mdot
.872 .24031 Mdot
.872 .24032 Mdot
.872 .24076 Mdot
.872 .24086 Mdot
.872 .24103 Mdot
.872 .24126 Mdot
.872 .24162 Mdot
.872 .24164 Mdot
.872 .24269 Mdot
.872 .24376 Mdot
.872 .24406 Mdot
.872 .24438 Mdot
.872 .24556 Mdot
.872 .24561 Mdot
.872 .24745 Mdot
.872 .24842 Mdot
.872 .24895 Mdot
.872 .24935 Mdot
.872 .2499 Mdot
.872 .25139 Mdot
.872 .25194 Mdot
.872 .25299 Mdot
.872 .25312 Mdot
.872 .25341 Mdot
.872 .25546 Mdot
.872 .25607 Mdot
.872 .25692 Mdot
.872 .25744 Mdot
.872 .25811 Mdot
.872 .25815 Mdot
.872 .25843 Mdot
.872 .25858 Mdot
.872 .25889 Mdot
.872 .2591 Mdot
.872 .25919 Mdot
.872 .25933 Mdot
.872 .25979 Mdot
.872 .25984 Mdot
.872 .26091 Mdot
.872 .26165 Mdot
.872 .2629 Mdot
.872 .26328 Mdot
.872 .26517 Mdot
.872 .26617 Mdot
.872 .26813 Mdot
.872 .26877 Mdot
.872 .26897 Mdot
.872 .27001 Mdot
.872 .2702 Mdot
.872 .27185 Mdot
.872 .27205 Mdot
.872 .27431 Mdot
.872 .27474 Mdot
.872 .27502 Mdot
.872 .27521 Mdot
.872 .27583 Mdot
.872 .27613 Mdot
.872 .2819 Mdot
.872 .28372 Mdot
.872 .28439 Mdot
.872 .28521 Mdot
.872 .28581 Mdot
.872 .28917 Mdot
.872 .29059 Mdot
.872 .29072 Mdot
.872 .29091 Mdot
.872 .29108 Mdot
.872 .2912 Mdot
.872 .2912 Mdot
.872 .29153 Mdot
.872 .29365 Mdot
.872 .29369 Mdot
.872 .29495 Mdot
.872 .29698 Mdot
.872 .29769 Mdot
.872 .29771 Mdot
.872 .29844 Mdot
.872 .29856 Mdot
.872 .29937 Mdot
.872 .29938 Mdot
.872 .29964 Mdot
.872 .29981 Mdot
.872 .29988 Mdot
.872 .30132 Mdot
.872 .30178 Mdot
.872 .30204 Mdot
.872 .30539 Mdot
.872 .30828 Mdot
.872 .31226 Mdot
.872 .31242 Mdot
.872 .31298 Mdot
.872 .31321 Mdot
.872 .31463 Mdot
.872 .31467 Mdot
.872 .31516 Mdot
.872 .31828 Mdot
.872 .31853 Mdot
.872 .31859 Mdot
.872 .31926 Mdot
.872 .32007 Mdot
.872 .32097 Mdot
.872 .32117 Mdot
.872 .32139 Mdot
.872 .32161 Mdot
.872 .32208 Mdot
.872 .32571 Mdot
.872 .32584 Mdot
.872 .32722 Mdot
.872 .32822 Mdot
.872 .33012 Mdot
.872 .33095 Mdot
.872 .33141 Mdot
.872 .33311 Mdot
.872 .33332 Mdot
.872 .3358 Mdot
.872 .33586 Mdot
.872 .33616 Mdot
.872 .33618 Mdot
.872 .33743 Mdot
.872 .33748 Mdot
.872 .33958 Mdot
.872 .34123 Mdot
.872 .34134 Mdot
.872 .34192 Mdot
.872 .34362 Mdot
.872 .34451 Mdot
.872 .34649 Mdot
.872 .34659 Mdot
.872 .34729 Mdot
.872 .34788 Mdot
.872 .34879 Mdot
.872 .34965 Mdot
.872 .3511 Mdot
.872 .35197 Mdot
.872 .35231 Mdot
.872 .35302 Mdot
.872 .35313 Mdot
.872 .35551 Mdot
.872 .35583 Mdot
.872 .35639 Mdot
.872 .35751 Mdot
.872 .35842 Mdot
.872 .35903 Mdot
.872 .3595 Mdot
.872 .36042 Mdot
.872 .36063 Mdot
.872 .36119 Mdot
.872 .36162 Mdot
.872 .36211 Mdot
.872 .36369 Mdot
.872 .36434 Mdot
.872 .36454 Mdot
.872 .36503 Mdot
.872 .36506 Mdot
.872 .36718 Mdot
.872 .36901 Mdot
.872 .36936 Mdot
.872 .3694 Mdot
.872 .3711 Mdot
.872 .37401 Mdot
.872 .37474 Mdot
.872 .37504 Mdot
.872 .376 Mdot
.872 .37623 Mdot
.872 .37696 Mdot
.872 .37709 Mdot
.872 .37754 Mdot
.872 .37829 Mdot
.872 .37879 Mdot
.872 .37928 Mdot
.872 .37992 Mdot
.872 .3804 Mdot
.872 .38066 Mdot
.872 .38106 Mdot
.872 .38135 Mdot
.872 .38158 Mdot
.872 .38183 Mdot
.872 .38241 Mdot
.872 .38269 Mdot
.872 .38272 Mdot
.872 .38293 Mdot
.872 .38394 Mdot
.872 .38414 Mdot
.872 .38446 Mdot
.872 .38682 Mdot
.872 .38777 Mdot
.872 .38797 Mdot
.872 .38853 Mdot
.872 .39041 Mdot
.872 .39061 Mdot
.872 .39103 Mdot
.872 .39115 Mdot
.872 .39128 Mdot
.872 .39131 Mdot
.872 .39142 Mdot
.872 .39176 Mdot
.872 .39265 Mdot
.872 .39302 Mdot
.872 .39341 Mdot
.872 .39505 Mdot
.872 .39517 Mdot
.872 .39529 Mdot
.872 .39556 Mdot
.872 .39607 Mdot
.872 .39708 Mdot
.872 .39864 Mdot
.872 .4002 Mdot
.872 .40123 Mdot
.872 .40226 Mdot
.872 .40316 Mdot
.872 .4037 Mdot
.872 .40477 Mdot
.872 .4058 Mdot
.872 .40588 Mdot
.872 .40833 Mdot
.872 .40939 Mdot
.872 .40985 Mdot
.872 .4099 Mdot
.872 .41002 Mdot
.872 .41147 Mdot
.872 .41186 Mdot
.872 .4121 Mdot
.872 .41217 Mdot
.872 .41224 Mdot
.872 .41445 Mdot
.872 .41554 Mdot
.872 .41794 Mdot
.872 .42094 Mdot
.872 .42163 Mdot
.872 .42173 Mdot
.872 .42389 Mdot
.872 .42499 Mdot
.872 .42609 Mdot
.872 .4282 Mdot
.872 .42906 Mdot
.872 .43209 Mdot
.872 .43324 Mdot
.872 .43382 Mdot
.872 .43422 Mdot
.872 .43577 Mdot
.872 .43596 Mdot
.872 .43599 Mdot
.872 .43635 Mdot
.872 .43645 Mdot
.872 .43711 Mdot
.872 .43981 Mdot
.872 .44236 Mdot
.872 .44398 Mdot
.872 .44516 Mdot
.872 .44793 Mdot
.872 .45001 Mdot
.872 .45109 Mdot
.872 .45167 Mdot
.872 .45197 Mdot
.872 .45213 Mdot
.872 .45225 Mdot
.872 .45239 Mdot
.872 .45248 Mdot
.872 .45264 Mdot
.872 .45294 Mdot
.872 .45351 Mdot
.872 .45459 Mdot
.872 .45662 Mdot
.872 .45874 Mdot
.872 .46043 Mdot
.872 .46047 Mdot
.872 .46065 Mdot
.872 .46202 Mdot
.872 .46449 Mdot
.872 .46551 Mdot
.872 .46603 Mdot
.872 .4676 Mdot
.872 .46764 Mdot
.872 .47052 Mdot
.872 .47102 Mdot
.872 .47223 Mdot
.872 .47308 Mdot
.872 .47313 Mdot
.872 .47497 Mdot
.872 .47501 Mdot
.872 .47596 Mdot
.872 .4762 Mdot
.872 .47661 Mdot
.872 .47707 Mdot
.872 .47754 Mdot
.872 .47893 Mdot
.872 .4796 Mdot
.872 .47978 Mdot
.872 .47983 Mdot
.872 .48072 Mdot
.872 .48089 Mdot
.872 .48127 Mdot
.872 .48143 Mdot
.872 .48147 Mdot
.872 .48149 Mdot
.872 .48154 Mdot
.872 .48187 Mdot
.872 .48269 Mdot
.872 .48445 Mdot
.872 .48511 Mdot
.872 .4852 Mdot
.872 .48521 Mdot
.872 .48578 Mdot
.872 .4859 Mdot
.872 .48608 Mdot
.872 .48619 Mdot
.872 .48759 Mdot
.872 .48765 Mdot
.872 .48795 Mdot
.872 .48889 Mdot
.872 .49081 Mdot
.872 .49083 Mdot
.872 .49173 Mdot
.872 .49282 Mdot
.872 .4929 Mdot
.872 .49317 Mdot
.872 .49402 Mdot
.872 .49419 Mdot
.872 .49442 Mdot
.872 .49488 Mdot
.872 .49507 Mdot
.872 .49569 Mdot
.872 .49636 Mdot
.872 .49649 Mdot
.872 .49745 Mdot
.872 .4975 Mdot
.872 .49778 Mdot
.872 .49791 Mdot
.872 .49826 Mdot
.872 .49884 Mdot
.872 .49918 Mdot
.872 .50005 Mdot
.872 .50087 Mdot
.872 .50216 Mdot
.872 .5028 Mdot
.872 .50362 Mdot
.872 .50412 Mdot
.872 .50413 Mdot
.872 .50425 Mdot
.872 .50427 Mdot
.872 .50523 Mdot
.872 .50531 Mdot
.872 .50614 Mdot
.872 .50814 Mdot
.872 .50968 Mdot
.872 .50993 Mdot
.872 .51026 Mdot
.872 .51056 Mdot
.872 .51082 Mdot
.872 .51093 Mdot
.872 .51229 Mdot
.872 .5129 Mdot
.872 .51311 Mdot
.872 .51464 Mdot
.872 .51692 Mdot
.872 .5177 Mdot
.872 .51779 Mdot
.872 .51788 Mdot
.872 .51788 Mdot
.872 .51822 Mdot
.872 .51849 Mdot
.872 .51875 Mdot
.872 .5207 Mdot
.872 .52082 Mdot
.872 .52086 Mdot
.872 .52092 Mdot
.872 .52104 Mdot
.872 .52154 Mdot
.872 .52273 Mdot
.872 .52294 Mdot
.872 .52323 Mdot
.872 .52411 Mdot
.872 .52613 Mdot
.872 .52623 Mdot
.872 .52661 Mdot
.872 .52676 Mdot
.872 .52754 Mdot
.872 .52761 Mdot
.872 .52889 Mdot
.872 .52956 Mdot
.872 .5299 Mdot
.872 .53068 Mdot
.872 .5311 Mdot
.872 .53172 Mdot
.872 .53189 Mdot
.872 .53194 Mdot
.872 .53204 Mdot
.872 .53214 Mdot
.872 .5322 Mdot
.872 .53229 Mdot
.872 .53253 Mdot
.872 .5327 Mdot
.872 .5332 Mdot
.872 .53399 Mdot
.872 .53403 Mdot
.872 .53456 Mdot
.872 .53506 Mdot
.872 .53538 Mdot
.872 .53556 Mdot
.872 .53588 Mdot
.872 .53651 Mdot
.872 .5369 Mdot
.872 .537 Mdot
.872 .53746 Mdot
.872 .53781 Mdot
.872 .53806 Mdot
.872 .53824 Mdot
.872 .53834 Mdot
.872 .53859 Mdot
.872 .53864 Mdot
.872 .53866 Mdot
.872 .53875 Mdot
.872 .53884 Mdot
.872 .53897 Mdot
.872 .53903 Mdot
.872 .53911 Mdot
.872 .53924 Mdot
.872 .53925 Mdot
.872 .53935 Mdot
.872 .53941 Mdot
.872 .53945 Mdot
.872 .53947 Mdot
.872 .53974 Mdot
.872 .53984 Mdot
.872 .54002 Mdot
.872 .54016 Mdot
.872 .54031 Mdot
.872 .5405 Mdot
.872 .54079 Mdot
.872 .54086 Mdot
.872 .54091 Mdot
.872 .54108 Mdot
.872 .54109 Mdot
.872 .54133 Mdot
.872 .54152 Mdot
.872 .54193 Mdot
.872 .54196 Mdot
.872 .54242 Mdot
.872 .54246 Mdot
.872 .54261 Mdot
.872 .54291 Mdot
.872 .54329 Mdot
.872 .54341 Mdot
.872 .54344 Mdot
.872 .54358 Mdot
.872 .54362 Mdot
.872 .54366 Mdot
.872 .54371 Mdot
.872 .54383 Mdot
.872 .54406 Mdot
.872 .54414 Mdot
.872 .54416 Mdot
.872 .54428 Mdot
.872 .54438 Mdot
.872 .5445 Mdot
.872 .54495 Mdot
.872 .54579 Mdot
.872 .54587 Mdot
.872 .54592 Mdot
.872 .54639 Mdot
.872 .54697 Mdot
.872 .54718 Mdot
.872 .54722 Mdot
.872 .54783 Mdot
.872 .54804 Mdot
.872 .54816 Mdot
.872 .54857 Mdot
.872 .54862 Mdot
.872 .54916 Mdot
.872 .5493 Mdot
.872 .54952 Mdot
.872 .55043 Mdot
.872 .55056 Mdot
.872 .55086 Mdot
.872 .55088 Mdot
.872 .55094 Mdot
.872 .55101 Mdot
.872 .55108 Mdot
.872 .55146 Mdot
.872 .55189 Mdot
.872 .55208 Mdot
.872 .55228 Mdot
.872 .55231 Mdot
.872 .55241 Mdot
.872 .55258 Mdot
.872 .55271 Mdot
.872 .55314 Mdot
.872 .55339 Mdot
.872 .5535 Mdot
.872 .55357 Mdot
.872 .5536 Mdot
.872 .55367 Mdot
.872 .55386 Mdot
.872 .55388 Mdot
.872 .55402 Mdot
.872 .55414 Mdot
.872 .55417 Mdot
.872 .55426 Mdot
.872 .55434 Mdot
.872 .55451 Mdot
.872 .55456 Mdot
.872 .55478 Mdot
.872 .55496 Mdot
.872 .55496 Mdot
.872 .55533 Mdot
.872 .55556 Mdot
.872 .55557 Mdot
.872 .55583 Mdot
.872 .55589 Mdot
.872 .55591 Mdot
.872 .55601 Mdot
.872 .55602 Mdot
.872 .55648 Mdot
.872 .5567 Mdot
.872 .55671 Mdot
.872 .55673 Mdot
.872 .557 Mdot
.872 .557 Mdot
.872 .55716 Mdot
.872 .5574 Mdot
.872 .55749 Mdot
.872 .55757 Mdot
.872 .55764 Mdot
.872 .55768 Mdot
.872 .55785 Mdot
.872 .55818 Mdot
.872 .55819 Mdot
.872 .55833 Mdot
.872 .55854 Mdot
.872 .55913 Mdot
.872 .55939 Mdot
.872 .55965 Mdot
.872 .56005 Mdot
.872 .56028 Mdot
.872 .56032 Mdot
.872 .56059 Mdot
.872 .56159 Mdot
.872 .56163 Mdot
.872 .56273 Mdot
.872 .56315 Mdot
.872 .56394 Mdot
.872 .56411 Mdot
.872 .56414 Mdot
.872 .56436 Mdot
.872 .56442 Mdot
.872 .56467 Mdot
.872 .56511 Mdot
.872 .56585 Mdot
.872 .56626 Mdot
.872 .56668 Mdot
.872 .56746 Mdot
.872 .56746 Mdot
.872 .56747 Mdot
.872 .56756 Mdot
.872 .56778 Mdot
.872 .56784 Mdot
.872 .56798 Mdot
.872 .56845 Mdot
.872 .56925 Mdot
.872 .56959 Mdot
.872 .56969 Mdot
.872 .56993 Mdot
.872 .57023 Mdot
.872 .57028 Mdot
.872 .57061 Mdot
.872 .57064 Mdot
.872 .57076 Mdot
.872 .57109 Mdot
.872 .57112 Mdot
.872 .57131 Mdot
.872 .57138 Mdot
.872 .57141 Mdot
.872 .57161 Mdot
.872 .57169 Mdot
.872 .57175 Mdot
.872 .57181 Mdot
.872 .5719 Mdot
.872 .57209 Mdot
.872 .5722 Mdot
.872 .57224 Mdot
.872 .57268 Mdot
.872 .57293 Mdot
.872 .57339 Mdot
.872 .5734 Mdot
.872 .57374 Mdot
.872 .57393 Mdot
.872 .57417 Mdot
.872 .5744 Mdot
.872 .57537 Mdot
.872 .57543 Mdot
.872 .57552 Mdot
.872 .57584 Mdot
.872 .57603 Mdot
.872 .57609 Mdot
.872 .57652 Mdot
.872 .57718 Mdot
.872 .57732 Mdot
.872 .57752 Mdot
.872 .57763 Mdot
.872 .57778 Mdot
.872 .57818 Mdot
.872 .57825 Mdot
.872 .57827 Mdot
.872 .57855 Mdot
.872 .5789 Mdot
.872 .57895 Mdot
.872 .5791 Mdot
.872 .5792 Mdot
.872 .57991 Mdot
.872 .58027 Mdot
.872 .58032 Mdot
.872 .58047 Mdot
.872 .5806 Mdot
.872 .58068 Mdot
.872 .58096 Mdot
.872 .58108 Mdot
.872 .58109 Mdot
.872 .58133 Mdot
.872 .58138 Mdot
.872 .58206 Mdot
.872 .58289 Mdot
.872 .5829 Mdot
.872 .58336 Mdot
.872 .58337 Mdot
.872 .58338 Mdot
.872 .58348 Mdot
.872 .5835 Mdot
.872 .58402 Mdot
.872 .58424 Mdot
.872 .58434 Mdot
.872 .58441 Mdot
.872 .5845 Mdot
.872 .58469 Mdot
.872 .58493 Mdot
.872 .58507 Mdot
.872 .5853 Mdot
.872 .58564 Mdot
.872 .58581 Mdot
.872 .586 Mdot
.872 .58604 Mdot
.872 .58606 Mdot
.872 .58608 Mdot
.872 .58612 Mdot
.872 .58615 Mdot
.872 .58615 Mdot
.872 .58623 Mdot
.872 .58638 Mdot
.872 .58641 Mdot
.872 .58669 Mdot
.872 .5867 Mdot
.872 .58694 Mdot
.872 .58712 Mdot
.872 .5872 Mdot
.872 .58724 Mdot
.872 .58727 Mdot
.872 .58729 Mdot
.872 .58731 Mdot
.872 .5874 Mdot
.872 .58741 Mdot
.872 .58744 Mdot
.872 .58751 Mdot
.872 .58753 Mdot
.872 .58756 Mdot
.872 .58761 Mdot
.872 .58763 Mdot
.872 .58764 Mdot
.872 .58764 Mdot
.872 .58765 Mdot
.872 .58767 Mdot
.872 .58768 Mdot
.872 .58769 Mdot
.872 .5877 Mdot
.872 .58786 Mdot
.872 .5879 Mdot
.872 .58793 Mdot
.872 .588 Mdot
.872 .58804 Mdot
.872 .58804 Mdot
.872 .58813 Mdot
.872 .58815 Mdot
.872 .58816 Mdot
.872 .58817 Mdot
.872 .58818 Mdot
.872 .58825 Mdot
.874 .0711 Mdot
.874 .0711 Mdot
.874 .07112 Mdot
.874 .07113 Mdot
.874 .07115 Mdot
.874 .07121 Mdot
.874 .07123 Mdot
.874 .07129 Mdot
.874 .07141 Mdot
.874 .07143 Mdot
.874 .0715 Mdot
.874 .07152 Mdot
.874 .07165 Mdot
.874 .07182 Mdot
.874 .07185 Mdot
.874 .07194 Mdot
.874 .07198 Mdot
.874 .07203 Mdot
.874 .07227 Mdot
.874 .07231 Mdot
.874 .07255 Mdot
.874 .07269 Mdot
.874 .07274 Mdot
.874 .0728 Mdot
.874 .07288 Mdot
.874 .07308 Mdot
.874 .07318 Mdot
.874 .07319 Mdot
.874 .07324 Mdot
.874 .07343 Mdot
.874 .07349 Mdot
.874 .07393 Mdot
.874 .07409 Mdot
.874 .07446 Mdot
.874 .07536 Mdot
.874 .07552 Mdot
.874 .07603 Mdot
.874 .07657 Mdot
.874 .0771 Mdot
.874 .07739 Mdot
.874 .07814 Mdot
.874 .07825 Mdot
.874 .07893 Mdot
.874 .07948 Mdot
.874 .07948 Mdot
.874 .07962 Mdot
.874 .08004 Mdot
.874 .08141 Mdot
.874 .08156 Mdot
.874 .08194 Mdot
.874 .08274 Mdot
.874 .08288 Mdot
.874 .08324 Mdot
.874 .08383 Mdot
.874 .08422 Mdot
.874 .08474 Mdot
.874 .08568 Mdot
.874 .08714 Mdot
.874 .08717 Mdot
.874 .08718 Mdot
.874 .08726 Mdot
.874 .08731 Mdot
.874 .08759 Mdot
.874 .08861 Mdot
.874 .08865 Mdot
.874 .0891 Mdot
.874 .08923 Mdot
.874 .08924 Mdot
.874 .08928 Mdot
.874 .08971 Mdot
.874 .08999 Mdot
.874 .09005 Mdot
.874 .09015 Mdot
.874 .09107 Mdot
.874 .09184 Mdot
.874 .09253 Mdot
.874 .09362 Mdot
.874 .09369 Mdot
.874 .09382 Mdot
.874 .09426 Mdot
.874 .09438 Mdot
.874 .09439 Mdot
.874 .09482 Mdot
.874 .0951 Mdot
.874 .09539 Mdot
.874 .09574 Mdot
.874 .09692 Mdot
.874 .09742 Mdot
.874 .09819 Mdot
.874 .09873 Mdot
.874 .10105 Mdot
.874 .10188 Mdot
.874 .10209 Mdot
.874 .10274 Mdot
.874 .10317 Mdot
.874 .10342 Mdot
.874 .10388 Mdot
.874 .10567 Mdot
.874 .10619 Mdot
.874 .10648 Mdot
.874 .10661 Mdot
.874 .10671 Mdot
.874 .10696 Mdot
.874 .10704 Mdot
.874 .10724 Mdot
.874 .10761 Mdot
.874 .10773 Mdot
.874 .10798 Mdot
.874 .10891 Mdot
.874 .10945 Mdot
.874 .1096 Mdot
.874 .11031 Mdot
.874 .11055 Mdot
.874 .1106 Mdot
.874 .11078 Mdot
.874 .11132 Mdot
.874 .11332 Mdot
.874 .11388 Mdot
.874 .11393 Mdot
.874 .11415 Mdot
.874 .11546 Mdot
.874 .1157 Mdot
.874 .11599 Mdot
.874 .11631 Mdot
.874 .11748 Mdot
.874 .11764 Mdot
.874 .11889 Mdot
.874 .12025 Mdot
.874 .1217 Mdot
.874 .12203 Mdot
.874 .12234 Mdot
.874 .12283 Mdot
.874 .12292 Mdot
.874 .12307 Mdot
.874 .12307 Mdot
.874 .12351 Mdot
.874 .12377 Mdot
.874 .12391 Mdot
.874 .12573 Mdot
.874 .12619 Mdot
.874 .12724 Mdot
.874 .12745 Mdot
.874 .12834 Mdot
.874 .12964 Mdot
.874 .13023 Mdot
.874 .13073 Mdot
.874 .13143 Mdot
.874 .13158 Mdot
.874 .13159 Mdot
.874 .13284 Mdot
.874 .13344 Mdot
.874 .13407 Mdot
.874 .13409 Mdot
.874 .13488 Mdot
.874 .13531 Mdot
.874 .13561 Mdot
.874 .13586 Mdot
.874 .13645 Mdot
.874 .13908 Mdot
.874 .13947 Mdot
.874 .14259 Mdot
.874 .14334 Mdot
.874 .14632 Mdot
.874 .14641 Mdot
.874 .14753 Mdot
.874 .1478 Mdot
.874 .14961 Mdot
.874 .15023 Mdot
.874 .15042 Mdot
.874 .15081 Mdot
.874 .15083 Mdot
.874 .15087 Mdot
.874 .15187 Mdot
.874 .1525 Mdot
.874 .15349 Mdot
.874 .15368 Mdot
.874 .15423 Mdot
.874 .15486 Mdot
.874 .15498 Mdot
.874 .15716 Mdot
.874 .15802 Mdot
.874 .1586 Mdot
.874 .16028 Mdot
.874 .16102 Mdot
.874 .16121 Mdot
.874 .16141 Mdot
.874 .16197 Mdot
.874 .16292 Mdot
.874 .16298 Mdot
.874 .16361 Mdot
.874 .16446 Mdot
.874 .16456 Mdot
.874 .16589 Mdot
.874 .16625 Mdot
.874 .16853 Mdot
.874 .16863 Mdot
.874 .16897 Mdot
.874 .1706 Mdot
.874 .17335 Mdot
.874 .17474 Mdot
.874 .17491 Mdot
.874 .17597 Mdot
.874 .17744 Mdot
.874 .17782 Mdot
.874 .17906 Mdot
.874 .18103 Mdot
.874 .18169 Mdot
.874 .1829 Mdot
.874 .18291 Mdot
.874 .18481 Mdot
.874 .18597 Mdot
.874 .18653 Mdot
.874 .18703 Mdot
.874 .18713 Mdot
.874 .18803 Mdot
.874 .18819 Mdot
.874 .19021 Mdot
.874 .19112 Mdot
.874 .19325 Mdot
.874 .19449 Mdot
.874 .19554 Mdot
.874 .19628 Mdot
.874 .19754 Mdot
.874 .19778 Mdot
.874 .20069 Mdot
.874 .20169 Mdot
.874 .20288 Mdot
.874 .20299 Mdot
.874 .20543 Mdot
.874 .20552 Mdot
.874 .20574 Mdot
.874 .21103 Mdot
.874 .21151 Mdot
.874 .21164 Mdot
.874 .21169 Mdot
.874 .21351 Mdot
.874 .21353 Mdot
.874 .21358 Mdot
.874 .21361 Mdot
.874 .21366 Mdot
.874 .21385 Mdot
.874 .21393 Mdot
.874 .21412 Mdot
.874 .21448 Mdot
.874 .21456 Mdot
.874 .21477 Mdot
.874 .21481 Mdot
.874 .21485 Mdot
.874 .21523 Mdot
.874 .21577 Mdot
.874 .21586 Mdot
.874 .21616 Mdot
.874 .21629 Mdot
.874 .21643 Mdot
.874 .21658 Mdot
.874 .21711 Mdot
.874 .21721 Mdot
.874 .21732 Mdot
.874 .21808 Mdot
.874 .21851 Mdot
.874 .21866 Mdot
.874 .21885 Mdot
.874 .21898 Mdot
.874 .21909 Mdot
.874 .21926 Mdot
.874 .21942 Mdot
.874 .21974 Mdot
.874 .22004 Mdot
.874 .22006 Mdot
.874 .22024 Mdot
.874 .22081 Mdot
.874 .221 Mdot
.874 .22153 Mdot
.874 .22183 Mdot
.874 .22237 Mdot
.874 .22288 Mdot
.874 .22355 Mdot
.874 .22357 Mdot
.874 .22404 Mdot
.874 .22681 Mdot
.874 .22733 Mdot
.874 .22742 Mdot
.874 .22809 Mdot
.874 .22889 Mdot
.874 .23057 Mdot
.874 .23219 Mdot
.874 .23304 Mdot
.874 .23308 Mdot
.874 .23467 Mdot
.874 .23475 Mdot
.874 .23538 Mdot
.874 .23572 Mdot
.874 .23611 Mdot
.874 .23709 Mdot
.874 .2378 Mdot
.874 .23885 Mdot
.874 .23948 Mdot
.874 .23948 Mdot
.874 .23988 Mdot
.874 .24076 Mdot
.874 .24118 Mdot
.874 .2418 Mdot
.874 .24216 Mdot
.874 .24365 Mdot
.874 .24421 Mdot
.874 .24433 Mdot
.874 .2453 Mdot
.874 .24577 Mdot
.874 .24635 Mdot
.874 .2469 Mdot
.874 .24697 Mdot
.874 .24704 Mdot
.874 .24731 Mdot
.874 .24813 Mdot
.874 .24926 Mdot
.874 .2493 Mdot
.874 .24954 Mdot
.874 .24974 Mdot
.874 .24982 Mdot
.874 .25043 Mdot
.874 .25081 Mdot
.874 .25082 Mdot
.874 .25129 Mdot
.874 .25199 Mdot
.874 .25252 Mdot
.874 .25256 Mdot
.874 .25373 Mdot
.874 .25403 Mdot
.874 .25529 Mdot
.874 .25678 Mdot
.874 .25719 Mdot
.874 .25753 Mdot
.874 .2578 Mdot
.874 .25805 Mdot
.874 .25943 Mdot
.874 .26 Mdot
.874 .26049 Mdot
.874 .26096 Mdot
.874 .26206 Mdot
.874 .26238 Mdot
.874 .26238 Mdot
.874 .26245 Mdot
.874 .26249 Mdot
.874 .26271 Mdot
.874 .26286 Mdot
.874 .26301 Mdot
.874 .26369 Mdot
.874 .26434 Mdot
.874 .26575 Mdot
.874 .2659 Mdot
.874 .26601 Mdot
.874 .26666 Mdot
.874 .26678 Mdot
.874 .2668 Mdot
.874 .26708 Mdot
.874 .26811 Mdot
.874 .26839 Mdot
.874 .26848 Mdot
.874 .26851 Mdot
.874 .26864 Mdot
.874 .26909 Mdot
.874 .26938 Mdot
.874 .26988 Mdot
.874 .27008 Mdot
.874 .27028 Mdot
.874 .27039 Mdot
.874 .27057 Mdot
.874 .27063 Mdot
.874 .2707 Mdot
.874 .27086 Mdot
.874 .27115 Mdot
.874 .27242 Mdot
.874 .27381 Mdot
.874 .27604 Mdot
.874 .27736 Mdot
.874 .27755 Mdot
.874 .27802 Mdot
.874 .27802 Mdot
.874 .27849 Mdot
.874 .27978 Mdot
.874 .28034 Mdot
.874 .28113 Mdot
.874 .28134 Mdot
.874 .2817 Mdot
.874 .28218 Mdot
.874 .28298 Mdot
.874 .28332 Mdot
.874 .28334 Mdot
.874 .28455 Mdot
.874 .28535 Mdot
.874 .28581 Mdot
.874 .28616 Mdot
.874 .28716 Mdot
.874 .29048 Mdot
.874 .2919 Mdot
.874 .29405 Mdot
.874 .29556 Mdot
.874 .29965 Mdot
.874 .29977 Mdot
.874 .30048 Mdot
.874 .30082 Mdot
.874 .30197 Mdot
.874 .30285 Mdot
.874 .30358 Mdot
.874 .30427 Mdot
.874 .30483 Mdot
.874 .30494 Mdot
.874 .30544 Mdot
.874 .30615 Mdot
.874 .30663 Mdot
.874 .30685 Mdot
.874 .30778 Mdot
.874 .30846 Mdot
.874 .30973 Mdot
.874 .31009 Mdot
.874 .31051 Mdot
.874 .31275 Mdot
.874 .31456 Mdot
.874 .3149 Mdot
.874 .31504 Mdot
.874 .31596 Mdot
.874 .31674 Mdot
.874 .31709 Mdot
.874 .31736 Mdot
.874 .31803 Mdot
.874 .31825 Mdot
.874 .31878 Mdot
.874 .31891 Mdot
.874 .31977 Mdot
.874 .32008 Mdot
.874 .32075 Mdot
.874 .32222 Mdot
.874 .32322 Mdot
.874 .32469 Mdot
.874 .32506 Mdot
.874 .326 Mdot
.874 .32693 Mdot
.874 .32755 Mdot
.874 .3277 Mdot
.874 .32816 Mdot
.874 .32957 Mdot
.874 .32973 Mdot
.874 .3301 Mdot
.874 .33101 Mdot
.874 .33134 Mdot
.874 .33473 Mdot
.874 .33479 Mdot
.874 .33483 Mdot
.874 .33589 Mdot
.874 .33623 Mdot
.874 .33634 Mdot
.874 .33637 Mdot
.874 .33694 Mdot
.874 .33702 Mdot
.874 .33874 Mdot
.874 .33949 Mdot
.874 .33962 Mdot
.874 .33993 Mdot
.874 .3403 Mdot
.874 .34091 Mdot
.874 .34167 Mdot
.874 .34248 Mdot
.874 .34282 Mdot
.874 .34472 Mdot
.874 .34484 Mdot
.874 .34522 Mdot
.874 .34547 Mdot
.874 .34588 Mdot
.874 .3476 Mdot
.874 .34802 Mdot
.874 .34902 Mdot
.874 .35244 Mdot
.874 .35301 Mdot
.874 .35309 Mdot
.874 .35586 Mdot
.874 .35604 Mdot
.874 .35687 Mdot
.874 .35764 Mdot
.874 .35886 Mdot
.874 .35908 Mdot
.874 .35938 Mdot
.874 .35944 Mdot
.874 .35944 Mdot
.874 .36051 Mdot
.874 .36103 Mdot
.874 .36115 Mdot
.874 .3615 Mdot
.874 .36258 Mdot
.874 .36594 Mdot
.874 .36698 Mdot
.874 .36706 Mdot
.874 .36721 Mdot
.874 .36784 Mdot
.874 .36959 Mdot
.874 .37011 Mdot
.874 .37134 Mdot
.874 .3717 Mdot
.874 .37193 Mdot
.874 .37223 Mdot
.874 .37286 Mdot
.874 .37366 Mdot
.874 .37534 Mdot
.874 .37581 Mdot
.874 .37673 Mdot
.874 .37793 Mdot
.874 .37957 Mdot
.874 .37975 Mdot
.874 .37991 Mdot
.874 .37994 Mdot
.874 .38029 Mdot
.874 .38124 Mdot
.874 .38288 Mdot
.874 .38427 Mdot
.874 .38459 Mdot
.874 .38575 Mdot
.874 .38577 Mdot
.874 .38761 Mdot
.874 .38765 Mdot
.874 .38766 Mdot
.874 .38861 Mdot
.874 .3893 Mdot
.874 .38986 Mdot
.874 .38999 Mdot
.874 .39122 Mdot
.874 .39235 Mdot
.874 .39488 Mdot
.874 .39661 Mdot
.874 .39719 Mdot
.874 .39806 Mdot
.874 .39869 Mdot
.874 .401 Mdot
.874 .40244 Mdot
.874 .40501 Mdot
.874 .40665 Mdot
.874 .40715 Mdot
.874 .40764 Mdot
.874 .40862 Mdot
.874 .41233 Mdot
.874 .41314 Mdot
.874 .41333 Mdot
.874 .41369 Mdot
.874 .41382 Mdot
.874 .41401 Mdot
.874 .41419 Mdot
.874 .41574 Mdot
.874 .4163 Mdot
.874 .41821 Mdot
.874 .41885 Mdot
.874 .41919 Mdot
.874 .42016 Mdot
.874 .42058 Mdot
.874 .42146 Mdot
.874 .42148 Mdot
.874 .42187 Mdot
.874 .42205 Mdot
.874 .42269 Mdot
.874 .42272 Mdot
.874 .4228 Mdot
.874 .42404 Mdot
.874 .42407 Mdot
.874 .42417 Mdot
.874 .42489 Mdot
.874 .42618 Mdot
.874 .4262 Mdot
.874 .42824 Mdot
.874 .42865 Mdot
.874 .42978 Mdot
.874 .43106 Mdot
.874 .4313 Mdot
.874 .43308 Mdot
.874 .43346 Mdot
.874 .43433 Mdot
.874 .43573 Mdot
.874 .43745 Mdot
.874 .438 Mdot
.874 .4386 Mdot
.874 .44034 Mdot
.874 .44157 Mdot
.874 .44193 Mdot
.874 .44197 Mdot
.874 .44202 Mdot
.874 .44339 Mdot
.874 .44375 Mdot
.874 .44399 Mdot
.874 .44415 Mdot
.874 .44468 Mdot
.874 .44471 Mdot
.874 .44525 Mdot
.874 .4471 Mdot
.874 .4472 Mdot
.874 .44843 Mdot
.874 .44952 Mdot
.874 .45006 Mdot
.874 .45025 Mdot
.874 .45026 Mdot
.874 .45158 Mdot
.874 .45278 Mdot
.874 .45347 Mdot
.874 .45385 Mdot
.874 .45634 Mdot
.874 .45636 Mdot
.874 .4567 Mdot
.874 .45771 Mdot
.874 .45774 Mdot
.874 .45794 Mdot
.874 .45856 Mdot
.874 .45974 Mdot
.874 .46156 Mdot
.874 .46199 Mdot
.874 .46218 Mdot
.874 .46555 Mdot
.874 .46651 Mdot
.874 .46656 Mdot
.874 .46657 Mdot
.874 .46752 Mdot
.874 .46779 Mdot
.874 .46822 Mdot
.874 .46888 Mdot
.874 .46904 Mdot
.874 .46934 Mdot
.874 .47122 Mdot
.874 .47131 Mdot
.874 .47139 Mdot
.874 .47146 Mdot
.874 .47209 Mdot
.874 .4738 Mdot
.874 .47424 Mdot
.874 .47447 Mdot
.874 .4766 Mdot
.874 .47725 Mdot
.874 .47828 Mdot
.874 .47921 Mdot
.874 .47997 Mdot
.874 .48108 Mdot
.874 .48212 Mdot
.874 .48313 Mdot
.874 .48314 Mdot
.874 .48446 Mdot
.874 .48589 Mdot
.874 .4863 Mdot
.874 .48653 Mdot
.874 .48819 Mdot
.874 .4891 Mdot
.874 .48943 Mdot
.874 .48982 Mdot
.874 .48992 Mdot
.874 .49007 Mdot
.874 .49152 Mdot
.874 .49178 Mdot
.874 .49188 Mdot
.874 .49368 Mdot
.874 .49432 Mdot
.874 .49499 Mdot
.874 .49641 Mdot
.874 .49752 Mdot
.874 .49755 Mdot
.874 .49954 Mdot
.874 .49971 Mdot
.874 .50065 Mdot
.874 .5008 Mdot
.874 .50085 Mdot
.874 .50159 Mdot
.874 .50272 Mdot
.874 .50284 Mdot
.874 .50289 Mdot
.874 .50318 Mdot
.874 .50385 Mdot
.874 .50411 Mdot
.874 .50429 Mdot
.874 .5047 Mdot
.874 .50474 Mdot
.874 .50604 Mdot
.874 .50617 Mdot
.874 .50651 Mdot
.874 .50665 Mdot
.874 .50807 Mdot
.874 .50857 Mdot
.874 .5095 Mdot
.874 .51075 Mdot
.874 .51219 Mdot
.874 .51224 Mdot
.874 .51304 Mdot
.874 .51386 Mdot
.874 .51402 Mdot
.874 .51521 Mdot
.874 .51546 Mdot
.874 .51572 Mdot
.874 .51591 Mdot
.874 .5164 Mdot
.874 .51667 Mdot
.874 .5174 Mdot
.874 .51752 Mdot
.874 .51778 Mdot
.874 .51783 Mdot
.874 .52277 Mdot
.874 .52405 Mdot
.874 .52469 Mdot
.874 .52489 Mdot
.874 .52534 Mdot
.874 .5255 Mdot
.874 .52567 Mdot
.874 .52573 Mdot
.874 .52745 Mdot
.874 .52807 Mdot
.874 .52808 Mdot
.874 .52815 Mdot
.874 .52818 Mdot
.874 .52825 Mdot
.874 .52849 Mdot
.874 .52859 Mdot
.874 .52883 Mdot
.874 .52928 Mdot
.874 .52939 Mdot
.874 .52965 Mdot
.874 .52969 Mdot
.874 .52974 Mdot
.874 .53022 Mdot
.874 .53067 Mdot
.874 .53089 Mdot
.874 .531 Mdot
.874 .53137 Mdot
.874 .53153 Mdot
.874 .5317 Mdot
.874 .53189 Mdot
.874 .53244 Mdot
.874 .53253 Mdot
.874 .53265 Mdot
.874 .53279 Mdot
.874 .53371 Mdot
.874 .53422 Mdot
.874 .5344 Mdot
.874 .53463 Mdot
.874 .53479 Mdot
.874 .53492 Mdot
.874 .53512 Mdot
.874 .53522 Mdot
.874 .53531 Mdot
.874 .53568 Mdot
.874 .53596 Mdot
.874 .53605 Mdot
.874 .53607 Mdot
.874 .53628 Mdot
.874 .53695 Mdot
.874 .53699 Mdot
.874 .53717 Mdot
.874 .53766 Mdot
.874 .53778 Mdot
.874 .53813 Mdot
.874 .53876 Mdot
.874 .53933 Mdot
.874 .53965 Mdot
.874 .5401 Mdot
.874 .54012 Mdot
.874 .54066 Mdot
.874 .54226 Mdot
.874 .54248 Mdot
.874 .54372 Mdot
.874 .54373 Mdot
.874 .54428 Mdot
.874 .54438 Mdot
.874 .54505 Mdot
.874 .5451 Mdot
.874 .54519 Mdot
.874 .54579 Mdot
.874 .54596 Mdot
.874 .54652 Mdot
.874 .54751 Mdot
.874 .54753 Mdot
.874 .54757 Mdot
.874 .54772 Mdot
.874 .54939 Mdot
.874 .54946 Mdot
.874 .54948 Mdot
.874 .55025 Mdot
.874 .55028 Mdot
.874 .55065 Mdot
.874 .55097 Mdot
.874 .55187 Mdot
.874 .55195 Mdot
.874 .55234 Mdot
.874 .55257 Mdot
.874 .55289 Mdot
.874 .55328 Mdot
.874 .55393 Mdot
.874 .55421 Mdot
.874 .55483 Mdot
.874 .55488 Mdot
.874 .55516 Mdot
.874 .55519 Mdot
.874 .55535 Mdot
.874 .55552 Mdot
.874 .55587 Mdot
.874 .55645 Mdot
.874 .55645 Mdot
.874 .55682 Mdot
.874 .55702 Mdot
.874 .55762 Mdot
.874 .558 Mdot
.874 .55812 Mdot
.874 .55856 Mdot
.874 .55888 Mdot
.874 .55893 Mdot
.874 .55935 Mdot
.874 .56018 Mdot
.874 .56067 Mdot
.874 .56077 Mdot
.874 .5608 Mdot
.874 .56148 Mdot
.874 .56159 Mdot
.874 .56199 Mdot
.874 .56202 Mdot
.874 .56227 Mdot
.874 .56246 Mdot
.874 .56248 Mdot
.874 .56276 Mdot
.874 .56293 Mdot
.874 .56299 Mdot
.874 .56304 Mdot
.874 .56326 Mdot
.874 .56376 Mdot
.874 .56393 Mdot
.874 .56418 Mdot
.874 .56483 Mdot
.874 .56487 Mdot
.874 .56505 Mdot
.874 .56521 Mdot
.874 .56527 Mdot
.874 .56556 Mdot
.874 .56575 Mdot
.874 .56604 Mdot
.874 .56605 Mdot
.874 .56606 Mdot
.874 .56617 Mdot
.874 .56623 Mdot
.874 .56641 Mdot
.874 .56694 Mdot
.874 .56702 Mdot
.874 .56735 Mdot
.874 .56737 Mdot
.874 .56824 Mdot
.874 .56846 Mdot
.874 .56936 Mdot
.874 .56948 Mdot
.874 .57024 Mdot
.874 .57041 Mdot
.874 .57048 Mdot
.874 .57057 Mdot
.874 .57069 Mdot
.874 .57092 Mdot
.874 .57092 Mdot
.874 .57111 Mdot
.874 .57128 Mdot
.874 .57164 Mdot
.874 .57164 Mdot
.874 .57169 Mdot
.874 .57189 Mdot
.874 .57203 Mdot
.874 .5722 Mdot
.874 .57257 Mdot
.874 .57283 Mdot
.874 .57289 Mdot
.874 .57319 Mdot
.874 .57332 Mdot
.874 .57384 Mdot
.874 .57388 Mdot
.874 .57395 Mdot
.874 .57408 Mdot
.874 .57408 Mdot
.874 .57412 Mdot
.874 .57414 Mdot
.874 .57428 Mdot
.874 .57437 Mdot
.874 .57447 Mdot
.874 .57488 Mdot
.874 .57527 Mdot
.874 .57562 Mdot
.874 .57566 Mdot
.874 .576 Mdot
.874 .57608 Mdot
.874 .57617 Mdot
.874 .57624 Mdot
.874 .5766 Mdot
.874 .57667 Mdot
.874 .57668 Mdot
.874 .57684 Mdot
.874 .5774 Mdot
.874 .57755 Mdot
.874 .5776 Mdot
.874 .57762 Mdot
.874 .57769 Mdot
.874 .57788 Mdot
.874 .57793 Mdot
.874 .57808 Mdot
.874 .57834 Mdot
.874 .57841 Mdot
.874 .57844 Mdot
.874 .57855 Mdot
.874 .5786 Mdot
.874 .57863 Mdot
.874 .5787 Mdot
.874 .57872 Mdot
.874 .57876 Mdot
.874 .57884 Mdot
.874 .57899 Mdot
.874 .57949 Mdot
.874 .57962 Mdot
.874 .57969 Mdot
.874 .5798 Mdot
.874 .57999 Mdot
.874 .58004 Mdot
.874 .58028 Mdot
.874 .58092 Mdot
.874 .58107 Mdot
.874 .58128 Mdot
.874 .58142 Mdot
.874 .58175 Mdot
.874 .58185 Mdot
.874 .58193 Mdot
.874 .582 Mdot
.874 .58212 Mdot
.874 .58212 Mdot
.874 .58216 Mdot
.874 .58228 Mdot
.874 .58232 Mdot
.874 .58234 Mdot
.874 .58264 Mdot
.874 .58283 Mdot
.874 .58304 Mdot
.874 .58329 Mdot
.874 .58332 Mdot
.874 .58333 Mdot
.874 .58341 Mdot
.874 .58353 Mdot
.874 .58354 Mdot
.874 .58354 Mdot
.874 .58358 Mdot
.874 .5837 Mdot
.874 .58372 Mdot
.874 .58399 Mdot
.874 .58407 Mdot
.874 .58409 Mdot
.874 .58411 Mdot
.874 .58411 Mdot
.874 .58412 Mdot
.874 .58452 Mdot
.874 .58477 Mdot
.874 .58492 Mdot
.874 .58503 Mdot
.874 .58519 Mdot
.874 .58528 Mdot
.874 .58532 Mdot
.874 .58554 Mdot
.874 .58564 Mdot
.874 .58569 Mdot
.874 .58606 Mdot
.874 .58617 Mdot
.874 .58621 Mdot
.874 .58621 Mdot
.874 .58636 Mdot
.874 .58655 Mdot
.874 .58658 Mdot
.874 .58678 Mdot
.874 .58686 Mdot
.874 .587 Mdot
.874 .58715 Mdot
.874 .58729 Mdot
.874 .58733 Mdot
.874 .58757 Mdot
.874 .58768 Mdot
.874 .58772 Mdot
.874 .58784 Mdot
.874 .58786 Mdot
.874 .58791 Mdot
.874 .58792 Mdot
.874 .58792 Mdot
.874 .58795 Mdot
.874 .588 Mdot
.874 .58803 Mdot
.874 .58804 Mdot
.874 .58805 Mdot
.874 .58809 Mdot
.874 .58816 Mdot
.874 .58817 Mdot
.874 .58823 Mdot
.874 .58825 Mdot
.874 .58826 Mdot
.874 .58828 Mdot
.874 .58829 Mdot
.874 .58834 Mdot
.874 .58837 Mdot
.874 .58838 Mdot
.874 .58839 Mdot
.874 .5884 Mdot
.874 .58843 Mdot
.874 .58845 Mdot
.874 .58846 Mdot
.874 .58847 Mdot
.874 .58848 Mdot
.874 .58848 Mdot
.874 .58848 Mdot
.874 .58848 Mdot
.876 .07024 Mdot
.876 .07025 Mdot
.876 .07025 Mdot
.876 .07028 Mdot
.876 .07033 Mdot
.876 .07036 Mdot
.876 .07037 Mdot
.876 .07048 Mdot
.876 .07051 Mdot
.876 .07068 Mdot
.876 .07069 Mdot
.876 .07071 Mdot
.876 .07093 Mdot
.876 .07103 Mdot
.876 .07111 Mdot
.876 .07117 Mdot
.876 .07155 Mdot
.876 .07186 Mdot
.876 .07197 Mdot
.876 .07205 Mdot
.876 .07221 Mdot
.876 .07242 Mdot
.876 .07288 Mdot
.876 .07292 Mdot
.876 .07298 Mdot
.876 .07304 Mdot
.876 .07333 Mdot
.876 .07355 Mdot
.876 .07365 Mdot
.876 .07366 Mdot
.876 .07366 Mdot
.876 .0737 Mdot
.876 .074 Mdot
.876 .07403 Mdot
.876 .07415 Mdot
.876 .07423 Mdot
.876 .0743 Mdot
.876 .0744 Mdot
.876 .07451 Mdot
.876 .07461 Mdot
.876 .07467 Mdot
.876 .07473 Mdot
.876 .07481 Mdot
.876 .07487 Mdot
.876 .0749 Mdot
.876 .07517 Mdot
.876 .0752 Mdot
.876 .07527 Mdot
.876 .07594 Mdot
.876 .07622 Mdot
.876 .07689 Mdot
.876 .07692 Mdot
.876 .07692 Mdot
.876 .07718 Mdot
.876 .07812 Mdot
.876 .07816 Mdot
.876 .07841 Mdot
.876 .07877 Mdot
.876 .07972 Mdot
.876 .08048 Mdot
.876 .08055 Mdot
.876 .08092 Mdot
.876 .08105 Mdot
.876 .08245 Mdot
.876 .08293 Mdot
.876 .08324 Mdot
.876 .08342 Mdot
.876 .08344 Mdot
.876 .08374 Mdot
.876 .08422 Mdot
.876 .08425 Mdot
.876 .08486 Mdot
.876 .0851 Mdot
.876 .08779 Mdot
.876 .08787 Mdot
.876 .08825 Mdot
.876 .08953 Mdot
.876 .08973 Mdot
.876 .08985 Mdot
.876 .08998 Mdot
.876 .09023 Mdot
.876 .09037 Mdot
.876 .09058 Mdot
.876 .09081 Mdot
.876 .09095 Mdot
.876 .09113 Mdot
.876 .09114 Mdot
.876 .09119 Mdot
.876 .09137 Mdot
.876 .09149 Mdot
.876 .09172 Mdot
.876 .09214 Mdot
.876 .09241 Mdot
.876 .09293 Mdot
.876 .09307 Mdot
.876 .09316 Mdot
.876 .09343 Mdot
.876 .09395 Mdot
.876 .09497 Mdot
.876 .09511 Mdot
.876 .09527 Mdot
.876 .09552 Mdot
.876 .09647 Mdot
.876 .09697 Mdot
.876 .0976 Mdot
.876 .09792 Mdot
.876 .09805 Mdot
.876 .09862 Mdot
.876 .09885 Mdot
.876 .09899 Mdot
.876 .09908 Mdot
.876 .09935 Mdot
.876 .0995 Mdot
.876 .09969 Mdot
.876 .09977 Mdot
.876 .10044 Mdot
.876 .10062 Mdot
.876 .10133 Mdot
.876 .10245 Mdot
.876 .10275 Mdot
.876 .10277 Mdot
.876 .10356 Mdot
.876 .10382 Mdot
.876 .10383 Mdot
.876 .10427 Mdot
.876 .10515 Mdot
.876 .10553 Mdot
.876 .10576 Mdot
.876 .10579 Mdot
.876 .10627 Mdot
.876 .10689 Mdot
.876 .10706 Mdot
.876 .10742 Mdot
.876 .10796 Mdot
.876 .10831 Mdot
.876 .10836 Mdot
.876 .10869 Mdot
.876 .1089 Mdot
.876 .11285 Mdot
.876 .11442 Mdot
.876 .11449 Mdot
.876 .11526 Mdot
.876 .11751 Mdot
.876 .11752 Mdot
.876 .11805 Mdot
.876 .12268 Mdot
.876 .12506 Mdot
.876 .12719 Mdot
.876 .12792 Mdot
.876 .12796 Mdot
.876 .1289 Mdot
.876 .12967 Mdot
.876 .13022 Mdot
.876 .13053 Mdot
.876 .13299 Mdot
.876 .13437 Mdot
.876 .13593 Mdot
.876 .13637 Mdot
.876 .13769 Mdot
.876 .13793 Mdot
.876 .13845 Mdot
.876 .14013 Mdot
.876 .14217 Mdot
.876 .14236 Mdot
.876 .14304 Mdot
.876 .14449 Mdot
.876 .14561 Mdot
.876 .14603 Mdot
.876 .14834 Mdot
.876 .14849 Mdot
.876 .14989 Mdot
.876 .15004 Mdot
.876 .15038 Mdot
.876 .15231 Mdot
.876 .15362 Mdot
.876 .15471 Mdot
.876 .15621 Mdot
.876 .15626 Mdot
.876 .15638 Mdot
.876 .15656 Mdot
.876 .15664 Mdot
.876 .15796 Mdot
.876 .15831 Mdot
.876 .16053 Mdot
.876 .16141 Mdot
.876 .16168 Mdot
.876 .16725 Mdot
.876 .16799 Mdot
.876 .168 Mdot
.876 .16803 Mdot
.876 .16913 Mdot
.876 .17237 Mdot
.876 .17299 Mdot
.876 .1733 Mdot
.876 .17449 Mdot
.876 .17697 Mdot
.876 .17715 Mdot
.876 .17771 Mdot
.876 .17782 Mdot
.876 .17787 Mdot
.876 .17918 Mdot
.876 .17934 Mdot
.876 .17983 Mdot
.876 .1832 Mdot
.876 .18867 Mdot
.876 .18929 Mdot
.876 .19024 Mdot
.876 .19104 Mdot
.876 .19205 Mdot
.876 .19439 Mdot
.876 .19444 Mdot
.876 .19482 Mdot
.876 .19579 Mdot
.876 .19585 Mdot
.876 .19693 Mdot
.876 .19712 Mdot
.876 .19723 Mdot
.876 .19956 Mdot
.876 .19963 Mdot
.876 .20008 Mdot
.876 .20202 Mdot
.876 .20286 Mdot
.876 .20402 Mdot
.876 .20464 Mdot
.876 .20642 Mdot
.876 .20663 Mdot
.876 .20667 Mdot
.876 .20669 Mdot
.876 .20689 Mdot
.876 .2069 Mdot
.876 .2075 Mdot
.876 .20751 Mdot
.876 .21028 Mdot
.876 .21075 Mdot
.876 .21089 Mdot
.876 .21092 Mdot
.876 .21092 Mdot
.876 .21099 Mdot
.876 .21116 Mdot
.876 .21126 Mdot
.876 .21128 Mdot
.876 .21162 Mdot
.876 .21172 Mdot
.876 .21228 Mdot
.876 .21231 Mdot
.876 .21232 Mdot
.876 .21237 Mdot
.876 .21307 Mdot
.876 .21337 Mdot
.876 .21361 Mdot
.876 .21374 Mdot
.876 .21383 Mdot
.876 .21438 Mdot
.876 .21501 Mdot
.876 .21597 Mdot
.876 .21632 Mdot
.876 .2166 Mdot
.876 .21664 Mdot
.876 .21709 Mdot
.876 .21732 Mdot
.876 .21774 Mdot
.876 .2192 Mdot
.876 .21931 Mdot
.876 .21949 Mdot
.876 .21951 Mdot
.876 .21965 Mdot
.876 .21968 Mdot
.876 .22058 Mdot
.876 .22066 Mdot
.876 .22129 Mdot
.876 .2216 Mdot
.876 .22161 Mdot
.876 .22162 Mdot
.876 .22174 Mdot
.876 .22269 Mdot
.876 .22278 Mdot
.876 .22285 Mdot
.876 .22316 Mdot
.876 .22339 Mdot
.876 .22363 Mdot
.876 .22363 Mdot
.876 .22392 Mdot
.876 .22428 Mdot
.876 .22434 Mdot
.876 .22458 Mdot
.876 .22462 Mdot
.876 .22476 Mdot
.876 .22494 Mdot
.876 .2252 Mdot
.876 .2254 Mdot
.876 .22549 Mdot
.876 .22633 Mdot
.876 .22641 Mdot
.876 .22662 Mdot
.876 .2275 Mdot
.876 .2278 Mdot
.876 .22849 Mdot
.876 .2287 Mdot
.876 .22937 Mdot
.876 .22956 Mdot
.876 .22999 Mdot
.876 .23047 Mdot
.876 .23061 Mdot
.876 .23146 Mdot
.876 .23164 Mdot
.876 .23165 Mdot
.876 .23171 Mdot
.876 .23173 Mdot
.876 .23253 Mdot
.876 .23289 Mdot
.876 .23315 Mdot
.876 .23389 Mdot
.876 .23391 Mdot
.876 .23474 Mdot
.876 .23508 Mdot
.876 .23541 Mdot
.876 .23553 Mdot
.876 .23554 Mdot
.876 .23629 Mdot
.876 .23661 Mdot
.876 .23687 Mdot
.876 .23718 Mdot
.876 .23738 Mdot
.876 .23916 Mdot
.876 .24028 Mdot
.876 .2405 Mdot
.876 .24094 Mdot
.876 .24095 Mdot
.876 .24099 Mdot
.876 .24124 Mdot
.876 .24208 Mdot
.876 .24259 Mdot
.876 .2428 Mdot
.876 .24392 Mdot
.876 .24431 Mdot
.876 .24432 Mdot
.876 .24458 Mdot
.876 .24777 Mdot
.876 .2479 Mdot
.876 .24838 Mdot
.876 .24848 Mdot
.876 .24854 Mdot
.876 .2491 Mdot
.876 .2495 Mdot
.876 .24999 Mdot
.876 .25072 Mdot
.876 .25085 Mdot
.876 .2509 Mdot
.876 .25144 Mdot
.876 .2515 Mdot
.876 .25239 Mdot
.876 .25256 Mdot
.876 .25383 Mdot
.876 .25391 Mdot
.876 .25473 Mdot
.876 .25572 Mdot
.876 .25626 Mdot
.876 .25644 Mdot
.876 .25709 Mdot
.876 .25767 Mdot
.876 .25872 Mdot
.876 .25886 Mdot
.876 .25984 Mdot
.876 .25985 Mdot
.876 .26112 Mdot
.876 .26438 Mdot
.876 .26463 Mdot
.876 .26463 Mdot
.876 .26573 Mdot
.876 .26693 Mdot
.876 .26897 Mdot
.876 .26908 Mdot
.876 .26928 Mdot
.876 .26947 Mdot
.876 .26976 Mdot
.876 .26995 Mdot
.876 .27004 Mdot
.876 .27038 Mdot
.876 .27064 Mdot
.876 .27066 Mdot
.876 .27078 Mdot
.876 .27149 Mdot
.876 .27174 Mdot
.876 .27189 Mdot
.876 .27252 Mdot
.876 .27317 Mdot
.876 .27359 Mdot
.876 .27409 Mdot
.876 .27414 Mdot
.876 .27426 Mdot
.876 .27435 Mdot
.876 .27451 Mdot
.876 .27457 Mdot
.876 .27465 Mdot
.876 .27479 Mdot
.876 .27514 Mdot
.876 .27581 Mdot
.876 .27613 Mdot
.876 .27674 Mdot
.876 .277 Mdot
.876 .2771 Mdot
.876 .27777 Mdot
.876 .2783 Mdot
.876 .27837 Mdot
.876 .27846 Mdot
.876 .27882 Mdot
.876 .279 Mdot
.876 .27929 Mdot
.876 .27945 Mdot
.876 .27967 Mdot
.876 .2797 Mdot
.876 .27971 Mdot
.876 .27984 Mdot
.876 .27994 Mdot
.876 .28036 Mdot
.876 .28053 Mdot
.876 .28072 Mdot
.876 .28211 Mdot
.876 .28218 Mdot
.876 .28508 Mdot
.876 .2855 Mdot
.876 .28594 Mdot
.876 .28666 Mdot
.876 .28799 Mdot
.876 .28848 Mdot
.876 .28933 Mdot
.876 .29075 Mdot
.876 .29103 Mdot
.876 .2925 Mdot
.876 .29251 Mdot
.876 .29254 Mdot
.876 .2934 Mdot
.876 .29377 Mdot
.876 .2948 Mdot
.876 .29483 Mdot
.876 .29537 Mdot
.876 .29558 Mdot
.876 .29567 Mdot
.876 .29582 Mdot
.876 .296 Mdot
.876 .29639 Mdot
.876 .29659 Mdot
.876 .29664 Mdot
.876 .29715 Mdot
.876 .2974 Mdot
.876 .2978 Mdot
.876 .29834 Mdot
.876 .29857 Mdot
.876 .30043 Mdot
.876 .30064 Mdot
.876 .30091 Mdot
.876 .30286 Mdot
.876 .30336 Mdot
.876 .30574 Mdot
.876 .30594 Mdot
.876 .30676 Mdot
.876 .30683 Mdot
.876 .30896 Mdot
.876 .30967 Mdot
.876 .3097 Mdot
.876 .31016 Mdot
.876 .31089 Mdot
.876 .31326 Mdot
.876 .31329 Mdot
.876 .31338 Mdot
.876 .31432 Mdot
.876 .31494 Mdot
.876 .31502 Mdot
.876 .31631 Mdot
.876 .31797 Mdot
.876 .31843 Mdot
.876 .31939 Mdot
.876 .31959 Mdot
.876 .32081 Mdot
.876 .32081 Mdot
.876 .32081 Mdot
.876 .32176 Mdot
.876 .32188 Mdot
.876 .32254 Mdot
.876 .32276 Mdot
.876 .3228 Mdot
.876 .32333 Mdot
.876 .32585 Mdot
.876 .32696 Mdot
.876 .32768 Mdot
.876 .32948 Mdot
.876 .32992 Mdot
.876 .33182 Mdot
.876 .33225 Mdot
.876 .33227 Mdot
.876 .33297 Mdot
.876 .33349 Mdot
.876 .3337 Mdot
.876 .33621 Mdot
.876 .33717 Mdot
.876 .3374 Mdot
.876 .33778 Mdot
.876 .33793 Mdot
.876 .33849 Mdot
.876 .33991 Mdot
.876 .34113 Mdot
.876 .34261 Mdot
.876 .34281 Mdot
.876 .34434 Mdot
.876 .34568 Mdot
.876 .3457 Mdot
.876 .3463 Mdot
.876 .34704 Mdot
.876 .34878 Mdot
.876 .35189 Mdot
.876 .35192 Mdot
.876 .35582 Mdot
.876 .35786 Mdot
.876 .35861 Mdot
.876 .35894 Mdot
.876 .36241 Mdot
.876 .36262 Mdot
.876 .36447 Mdot
.876 .36504 Mdot
.876 .36951 Mdot
.876 .36962 Mdot
.876 .37107 Mdot
.876 .37139 Mdot
.876 .37148 Mdot
.876 .37373 Mdot
.876 .37555 Mdot
.876 .37686 Mdot
.876 .37759 Mdot
.876 .38293 Mdot
.876 .38335 Mdot
.876 .38339 Mdot
.876 .38428 Mdot
.876 .3857 Mdot
.876 .38624 Mdot
.876 .38633 Mdot
.876 .38657 Mdot
.876 .39019 Mdot
.876 .39118 Mdot
.876 .39419 Mdot
.876 .39474 Mdot
.876 .39591 Mdot
.876 .3965 Mdot
.876 .39917 Mdot
.876 .39921 Mdot
.876 .39969 Mdot
.876 .40111 Mdot
.876 .4017 Mdot
.876 .40424 Mdot
.876 .40447 Mdot
.876 .40466 Mdot
.876 .40615 Mdot
.876 .40673 Mdot
.876 .40692 Mdot
.876 .40733 Mdot
.876 .40933 Mdot
.876 .40946 Mdot
.876 .41014 Mdot
.876 .41176 Mdot
.876 .41268 Mdot
.876 .41598 Mdot
.876 .41763 Mdot
.876 .41795 Mdot
.876 .41926 Mdot
.876 .41955 Mdot
.876 .41973 Mdot
.876 .4202 Mdot
.876 .42031 Mdot
.876 .42092 Mdot
.876 .42124 Mdot
.876 .42194 Mdot
.876 .42253 Mdot
.876 .42404 Mdot
.876 .42454 Mdot
.876 .42518 Mdot
.876 .42599 Mdot
.876 .42752 Mdot
.876 .42869 Mdot
.876 .43052 Mdot
.876 .43092 Mdot
.876 .43398 Mdot
.876 .43409 Mdot
.876 .43433 Mdot
.876 .43469 Mdot
.876 .43486 Mdot
.876 .4375 Mdot
.876 .43819 Mdot
.876 .43958 Mdot
.876 .4426 Mdot
.876 .44359 Mdot
.876 .44371 Mdot
.876 .44374 Mdot
.876 .44433 Mdot
.876 .44487 Mdot
.876 .44646 Mdot
.876 .45553 Mdot
.876 .45692 Mdot
.876 .45694 Mdot
.876 .457 Mdot
.876 .45903 Mdot
.876 .46352 Mdot
.876 .46498 Mdot
.876 .46611 Mdot
.876 .46641 Mdot
.876 .46666 Mdot
.876 .46738 Mdot
.876 .46843 Mdot
.876 .46848 Mdot
.876 .4687 Mdot
.876 .46879 Mdot
.876 .47046 Mdot
.876 .47317 Mdot
.876 .47348 Mdot
.876 .47446 Mdot
.876 .47464 Mdot
.876 .47473 Mdot
.876 .47576 Mdot
.876 .477 Mdot
.876 .47727 Mdot
.876 .47812 Mdot
.876 .47814 Mdot
.876 .47932 Mdot
.876 .48377 Mdot
.876 .48381 Mdot
.876 .48405 Mdot
.876 .48465 Mdot
.876 .48505 Mdot
.876 .48523 Mdot
.876 .49024 Mdot
.876 .49089 Mdot
.876 .49273 Mdot
.876 .49372 Mdot
.876 .49381 Mdot
.876 .49522 Mdot
.876 .49566 Mdot
.876 .49648 Mdot
.876 .49804 Mdot
.876 .49806 Mdot
.876 .4993 Mdot
.876 .50028 Mdot
.876 .50105 Mdot
.876 .50165 Mdot
.876 .50172 Mdot
.876 .5023 Mdot
.876 .50333 Mdot
.876 .50375 Mdot
.876 .50384 Mdot
.876 .50422 Mdot
.876 .50526 Mdot
.876 .50546 Mdot
.876 .50573 Mdot
.876 .50574 Mdot
.876 .50591 Mdot
.876 .50663 Mdot
.876 .5068 Mdot
.876 .50748 Mdot
.876 .50776 Mdot
.876 .50818 Mdot
.876 .50933 Mdot
.876 .50943 Mdot
.876 .51008 Mdot
.876 .51008 Mdot
.876 .51054 Mdot
.876 .51285 Mdot
.876 .51289 Mdot
.876 .51403 Mdot
.876 .51566 Mdot
.876 .51652 Mdot
.876 .51751 Mdot
.876 .51877 Mdot
.876 .51897 Mdot
.876 .51925 Mdot
.876 .5193 Mdot
.876 .51933 Mdot
.876 .5196 Mdot
.876 .51961 Mdot
.876 .52042 Mdot
.876 .52043 Mdot
.876 .52096 Mdot
.876 .52186 Mdot
.876 .52204 Mdot
.876 .52411 Mdot
.876 .52466 Mdot
.876 .52473 Mdot
.876 .52491 Mdot
.876 .52495 Mdot
.876 .52496 Mdot
.876 .52504 Mdot
.876 .5252 Mdot
.876 .52526 Mdot
.876 .52539 Mdot
.876 .52542 Mdot
.876 .52544 Mdot
.876 .52586 Mdot
.876 .52599 Mdot
.876 .5262 Mdot
.876 .52671 Mdot
.876 .52674 Mdot
.876 .52676 Mdot
.876 .52682 Mdot
.876 .52772 Mdot
.876 .52809 Mdot
.876 .5281 Mdot
.876 .52834 Mdot
.876 .5284 Mdot
.876 .52857 Mdot
.876 .52863 Mdot
.876 .52867 Mdot
.876 .52937 Mdot
.876 .53016 Mdot
.876 .53135 Mdot
.876 .53178 Mdot
.876 .53179 Mdot
.876 .53212 Mdot
.876 .53216 Mdot
.876 .53252 Mdot
.876 .53271 Mdot
.876 .53299 Mdot
.876 .53351 Mdot
.876 .53424 Mdot
.876 .53481 Mdot
.876 .53485 Mdot
.876 .53526 Mdot
.876 .5354 Mdot
.876 .5356 Mdot
.876 .53563 Mdot
.876 .53579 Mdot
.876 .53584 Mdot
.876 .5369 Mdot
.876 .53698 Mdot
.876 .53772 Mdot
.876 .538 Mdot
.876 .53808 Mdot
.876 .53809 Mdot
.876 .5381 Mdot
.876 .53824 Mdot
.876 .53868 Mdot
.876 .53933 Mdot
.876 .53943 Mdot
.876 .53952 Mdot
.876 .53987 Mdot
.876 .54002 Mdot
.876 .54013 Mdot
.876 .5404 Mdot
.876 .54041 Mdot
.876 .54065 Mdot
.876 .54073 Mdot
.876 .54114 Mdot
.876 .5412 Mdot
.876 .54147 Mdot
.876 .54152 Mdot
.876 .54168 Mdot
.876 .54188 Mdot
.876 .54216 Mdot
.876 .54239 Mdot
.876 .54248 Mdot
.876 .54341 Mdot
.876 .5435 Mdot
.876 .54373 Mdot
.876 .54398 Mdot
.876 .54468 Mdot
.876 .54501 Mdot
.876 .54506 Mdot
.876 .54575 Mdot
.876 .54597 Mdot
.876 .54668 Mdot
.876 .54689 Mdot
.876 .54734 Mdot
.876 .54783 Mdot
.876 .54798 Mdot
.876 .54886 Mdot
.876 .54886 Mdot
.876 .54905 Mdot
.876 .54905 Mdot
.876 .54911 Mdot
.876 .54912 Mdot
.876 .54913 Mdot
.876 .5492 Mdot
.876 .54976 Mdot
.876 .54995 Mdot
.876 .55031 Mdot
.876 .55058 Mdot
.876 .55118 Mdot
.876 .55132 Mdot
.876 .55134 Mdot
.876 .55207 Mdot
.876 .5521 Mdot
.876 .55216 Mdot
.876 .5525 Mdot
.876 .55251 Mdot
.876 .55281 Mdot
.876 .55293 Mdot
.876 .55295 Mdot
.876 .55367 Mdot
.876 .55398 Mdot
.876 .55423 Mdot
.876 .55452 Mdot
.876 .55471 Mdot
.876 .55638 Mdot
.876 .55741 Mdot
.876 .55756 Mdot
.876 .55761 Mdot
.876 .55801 Mdot
.876 .55802 Mdot
.876 .55805 Mdot
.876 .55822 Mdot
.876 .55828 Mdot
.876 .55903 Mdot
.876 .55939 Mdot
.876 .55948 Mdot
.876 .55966 Mdot
.876 .56064 Mdot
.876 .56097 Mdot
.876 .56098 Mdot
.876 .56098 Mdot
.876 .5612 Mdot
.876 .56286 Mdot
.876 .56294 Mdot
.876 .5632 Mdot
.876 .56386 Mdot
.876 .56397 Mdot
.876 .56435 Mdot
.876 .56438 Mdot
.876 .56443 Mdot
.876 .56447 Mdot
.876 .56448 Mdot
.876 .56493 Mdot
.876 .56525 Mdot
.876 .56563 Mdot
.876 .5662 Mdot
.876 .5663 Mdot
.876 .56634 Mdot
.876 .56675 Mdot
.876 .5668 Mdot
.876 .56747 Mdot
.876 .5676 Mdot
.876 .56792 Mdot
.876 .56834 Mdot
.876 .56854 Mdot
.876 .5686 Mdot
.876 .56919 Mdot
.876 .56968 Mdot
.876 .56983 Mdot
.876 .5699 Mdot
.876 .57028 Mdot
.876 .5704 Mdot
.876 .57086 Mdot
.876 .57125 Mdot
.876 .57196 Mdot
.876 .57205 Mdot
.876 .57221 Mdot
.876 .57242 Mdot
.876 .57269 Mdot
.876 .5727 Mdot
.876 .57291 Mdot
.876 .57352 Mdot
.876 .5742 Mdot
.876 .57552 Mdot
.876 .57566 Mdot
.876 .57567 Mdot
.876 .5763 Mdot
.876 .57652 Mdot
.876 .57654 Mdot
.876 .57698 Mdot
.876 .57809 Mdot
.876 .57815 Mdot
.876 .57824 Mdot
.876 .57826 Mdot
.876 .57836 Mdot
.876 .57851 Mdot
.876 .57861 Mdot
.876 .57866 Mdot
.876 .57883 Mdot
.876 .57896 Mdot
.876 .57897 Mdot
.876 .57903 Mdot
.876 .57914 Mdot
.876 .57939 Mdot
.876 .57951 Mdot
.876 .57951 Mdot
.876 .57959 Mdot
.876 .5798 Mdot
.876 .57981 Mdot
.876 .5799 Mdot
.876 .58021 Mdot
.876 .5804 Mdot
.876 .58045 Mdot
.876 .58064 Mdot
.876 .58066 Mdot
.876 .58072 Mdot
.876 .58076 Mdot
.876 .58083 Mdot
.876 .58086 Mdot
.876 .5809 Mdot
.876 .58096 Mdot
.876 .58112 Mdot
.876 .58115 Mdot
.876 .58124 Mdot
.876 .58142 Mdot
.876 .58156 Mdot
.876 .58182 Mdot
.876 .58189 Mdot
.876 .58193 Mdot
.876 .58197 Mdot
.876 .58225 Mdot
.876 .58239 Mdot
.876 .58247 Mdot
.876 .5825 Mdot
.876 .58253 Mdot
.876 .58268 Mdot
.876 .58275 Mdot
.876 .58287 Mdot
.876 .58293 Mdot
.876 .58296 Mdot
.876 .58301 Mdot
.876 .58303 Mdot
.876 .58303 Mdot
.876 .58308 Mdot
.876 .58312 Mdot
.876 .58318 Mdot
.876 .58324 Mdot
.876 .58328 Mdot
.876 .58335 Mdot
.876 .58338 Mdot
.876 .58342 Mdot
.876 .58347 Mdot
.876 .58382 Mdot
.876 .58392 Mdot
.876 .58395 Mdot
.876 .58469 Mdot
.876 .58475 Mdot
.876 .58492 Mdot
.876 .58493 Mdot
.876 .58506 Mdot
.876 .58514 Mdot
.876 .58514 Mdot
.876 .58519 Mdot
.876 .58528 Mdot
.876 .58541 Mdot
.876 .58579 Mdot
.876 .58583 Mdot
.876 .58593 Mdot
.876 .58595 Mdot
.876 .58615 Mdot
.876 .58641 Mdot
.876 .58651 Mdot
.876 .58658 Mdot
.876 .58659 Mdot
.876 .58684 Mdot
.876 .58691 Mdot
.876 .58692 Mdot
.876 .58692 Mdot
.876 .58711 Mdot
.876 .58718 Mdot
.876 .58736 Mdot
.876 .58738 Mdot
.876 .58739 Mdot
.876 .58746 Mdot
.876 .58747 Mdot
.876 .58749 Mdot
.876 .58751 Mdot
.876 .58753 Mdot
.876 .58754 Mdot
.876 .58757 Mdot
.876 .5876 Mdot
.876 .58762 Mdot
.876 .58765 Mdot
.876 .58767 Mdot
.876 .5877 Mdot
.876 .58771 Mdot
.876 .58779 Mdot
.876 .5878 Mdot
.876 .5878 Mdot
.876 .5878 Mdot
.876 .58783 Mdot
.876 .58789 Mdot
.876 .58797 Mdot
.876 .58798 Mdot
.876 .588 Mdot
.876 .58801 Mdot
.876 .58813 Mdot
.876 .58819 Mdot
.876 .58823 Mdot
.876 .58826 Mdot
.876 .58829 Mdot
.876 .58837 Mdot
.876 .58847 Mdot
.876 .58849 Mdot
.876 .58851 Mdot
.876 .58854 Mdot
.876 .5886 Mdot
.876 .5886 Mdot
.876 .5886 Mdot
.876 .58865 Mdot
.876 .58866 Mdot
.876 .58869 Mdot
.876 .58869 Mdot
.876 .5887 Mdot
.876 .58871 Mdot
.876 .58872 Mdot
.876 .58872 Mdot
.876 .58872 Mdot
.878 .06939 Mdot
.878 .06939 Mdot
.878 .0694 Mdot
.878 .0694 Mdot
.878 .06944 Mdot
.878 .06945 Mdot
.878 .06948 Mdot
.878 .06952 Mdot
.878 .06954 Mdot
.878 .06956 Mdot
.878 .06958 Mdot
.878 .06969 Mdot
.878 .06972 Mdot
.878 .06981 Mdot
.878 .07018 Mdot
.878 .07023 Mdot
.878 .07039 Mdot
.878 .07045 Mdot
.878 .07047 Mdot
.878 .07073 Mdot
.878 .07092 Mdot
.878 .07116 Mdot
.878 .07123 Mdot
.878 .07127 Mdot
.878 .07158 Mdot
.878 .07179 Mdot
.878 .07186 Mdot
.878 .072 Mdot
.878 .07204 Mdot
.878 .07231 Mdot
.878 .07262 Mdot
.878 .07279 Mdot
.878 .07295 Mdot
.878 .07527 Mdot
.878 .07532 Mdot
.878 .07569 Mdot
.878 .07692 Mdot
.878 .07779 Mdot
.878 .07829 Mdot
.878 .07896 Mdot
.878 .07897 Mdot
.878 .07907 Mdot
.878 .07909 Mdot
.878 .07913 Mdot
.878 .07916 Mdot
.878 .07934 Mdot
.878 .07957 Mdot
.878 .07975 Mdot
.878 .07993 Mdot
.878 .08008 Mdot
.878 .08011 Mdot
.878 .08047 Mdot
.878 .08057 Mdot
.878 .08083 Mdot
.878 .08115 Mdot
.878 .08125 Mdot
.878 .0814 Mdot
.878 .0814 Mdot
.878 .08155 Mdot
.878 .08177 Mdot
.878 .08204 Mdot
.878 .08209 Mdot
.878 .0823 Mdot
.878 .0823 Mdot
.878 .08276 Mdot
.878 .08291 Mdot
.878 .08315 Mdot
.878 .08331 Mdot
.878 .08354 Mdot
.878 .0839 Mdot
.878 .08405 Mdot
.878 .08449 Mdot
.878 .08502 Mdot
.878 .08672 Mdot
.878 .08697 Mdot
.878 .0872 Mdot
.878 .08972 Mdot
.878 .09014 Mdot
.878 .0906 Mdot
.878 .09065 Mdot
.878 .09103 Mdot
.878 .09391 Mdot
.878 .09445 Mdot
.878 .09473 Mdot
.878 .09488 Mdot
.878 .09533 Mdot
.878 .09535 Mdot
.878 .0956 Mdot
.878 .09926 Mdot
.878 .10034 Mdot
.878 .10044 Mdot
.878 .10111 Mdot
.878 .1014 Mdot
.878 .10226 Mdot
.878 .10263 Mdot
.878 .1033 Mdot
.878 .10372 Mdot
.878 .1041 Mdot
.878 .10595 Mdot
.878 .10644 Mdot
.878 .10735 Mdot
.878 .10778 Mdot
.878 .108 Mdot
.878 .10932 Mdot
.878 .11044 Mdot
.878 .11092 Mdot
.878 .11129 Mdot
.878 .11183 Mdot
.878 .11188 Mdot
.878 .11196 Mdot
.878 .11249 Mdot
.878 .1137 Mdot
.878 .1159 Mdot
.878 .11596 Mdot
.878 .11776 Mdot
.878 .11864 Mdot
.878 .11873 Mdot
.878 .11877 Mdot
.878 .11928 Mdot
.878 .12036 Mdot
.878 .12072 Mdot
.878 .12121 Mdot
.878 .12218 Mdot
.878 .12219 Mdot
.878 .12235 Mdot
.878 .12309 Mdot
.878 .12381 Mdot
.878 .12447 Mdot
.878 .12571 Mdot
.878 .12571 Mdot
.878 .12616 Mdot
.878 .12663 Mdot
.878 .1271 Mdot
.878 .1279 Mdot
.878 .12988 Mdot
.878 .13085 Mdot
.878 .13103 Mdot
.878 .13233 Mdot
.878 .13508 Mdot
.878 .13553 Mdot
.878 .13851 Mdot
.878 .13861 Mdot
.878 .13905 Mdot
.878 .13941 Mdot
.878 .1395 Mdot
.878 .14267 Mdot
.878 .14379 Mdot
.878 .14406 Mdot
.878 .14634 Mdot
.878 .14659 Mdot
.878 .14669 Mdot
.878 .14671 Mdot
.878 .1473 Mdot
.878 .14836 Mdot
.878 .14958 Mdot
.878 .14962 Mdot
.878 .15156 Mdot
.878 .15241 Mdot
.878 .15258 Mdot
.878 .15279 Mdot
.878 .15392 Mdot
.878 .15566 Mdot
.878 .15617 Mdot
.878 .15646 Mdot
.878 .15649 Mdot
.878 .15734 Mdot
.878 .1581 Mdot
.878 .15821 Mdot
.878 .15867 Mdot
.878 .16008 Mdot
.878 .16088 Mdot
.878 .16095 Mdot
.878 .16246 Mdot
.878 .16278 Mdot
.878 .16402 Mdot
.878 .16404 Mdot
.878 .1642 Mdot
.878 .16527 Mdot
.878 .16619 Mdot
.878 .16831 Mdot
.878 .16892 Mdot
.878 .1691 Mdot
.878 .17052 Mdot
.878 .17191 Mdot
.878 .17212 Mdot
.878 .17295 Mdot
.878 .17433 Mdot
.878 .17453 Mdot
.878 .17495 Mdot
.878 .17535 Mdot
.878 .17561 Mdot
.878 .177 Mdot
.878 .17858 Mdot
.878 .17862 Mdot
.878 .18028 Mdot
.878 .181 Mdot
.878 .18139 Mdot
.878 .18184 Mdot
.878 .18239 Mdot
.878 .18272 Mdot
.878 .18274 Mdot
.878 .18401 Mdot
.878 .18429 Mdot
.878 .18431 Mdot
.878 .18472 Mdot
.878 .18475 Mdot
.878 .18484 Mdot
.878 .18488 Mdot
.878 .18567 Mdot
.878 .18573 Mdot
.878 .18585 Mdot
.878 .18594 Mdot
.878 .18619 Mdot
.878 .18663 Mdot
.878 .19035 Mdot
.878 .19103 Mdot
.878 .19134 Mdot
.878 .19219 Mdot
.878 .19226 Mdot
.878 .19473 Mdot
.878 .19539 Mdot
.878 .19708 Mdot
.878 .19708 Mdot
.878 .20058 Mdot
.878 .20255 Mdot
.878 .20339 Mdot
.878 .20576 Mdot
.878 .20827 Mdot
.878 .20828 Mdot
.878 .20829 Mdot
.878 .2083 Mdot
.878 .20841 Mdot
.878 .20846 Mdot
.878 .20854 Mdot
.878 .20867 Mdot
.878 .20874 Mdot
.878 .20882 Mdot
.878 .20888 Mdot
.878 .20921 Mdot
.878 .2093 Mdot
.878 .2096 Mdot
.878 .21068 Mdot
.878 .21076 Mdot
.878 .21084 Mdot
.878 .21093 Mdot
.878 .21145 Mdot
.878 .21162 Mdot
.878 .21169 Mdot
.878 .21252 Mdot
.878 .21282 Mdot
.878 .2131 Mdot
.878 .21386 Mdot
.878 .21408 Mdot
.878 .21423 Mdot
.878 .21513 Mdot
.878 .2152 Mdot
.878 .21585 Mdot
.878 .21606 Mdot
.878 .21627 Mdot
.878 .2165 Mdot
.878 .21664 Mdot
.878 .21749 Mdot
.878 .21751 Mdot
.878 .21835 Mdot
.878 .21846 Mdot
.878 .219 Mdot
.878 .2195 Mdot
.878 .22218 Mdot
.878 .22225 Mdot
.878 .22234 Mdot
.878 .22268 Mdot
.878 .22551 Mdot
.878 .22672 Mdot
.878 .22683 Mdot
.878 .22687 Mdot
.878 .228 Mdot
.878 .22826 Mdot
.878 .2318 Mdot
.878 .2334 Mdot
.878 .23449 Mdot
.878 .23602 Mdot
.878 .23663 Mdot
.878 .23783 Mdot
.878 .23805 Mdot
.878 .23808 Mdot
.878 .23814 Mdot
.878 .2384 Mdot
.878 .23841 Mdot
.878 .23845 Mdot
.878 .23858 Mdot
.878 .23868 Mdot
.878 .23921 Mdot
.878 .23967 Mdot
.878 .23991 Mdot
.878 .24046 Mdot
.878 .24047 Mdot
.878 .241 Mdot
.878 .24147 Mdot
.878 .24156 Mdot
.878 .24266 Mdot
.878 .24296 Mdot
.878 .2432 Mdot
.878 .24376 Mdot
.878 .24397 Mdot
.878 .24471 Mdot
.878 .24503 Mdot
.878 .24546 Mdot
.878 .24547 Mdot
.878 .24591 Mdot
.878 .24602 Mdot
.878 .24659 Mdot
.878 .24687 Mdot
.878 .24738 Mdot
.878 .24755 Mdot
.878 .24759 Mdot
.878 .24787 Mdot
.878 .24818 Mdot
.878 .24819 Mdot
.878 .24912 Mdot
.878 .24955 Mdot
.878 .24968 Mdot
.878 .25001 Mdot
.878 .25074 Mdot
.878 .25122 Mdot
.878 .25162 Mdot
.878 .25189 Mdot
.878 .25199 Mdot
.878 .25298 Mdot
.878 .25342 Mdot
.878 .25472 Mdot
.878 .25504 Mdot
.878 .25508 Mdot
.878 .2563 Mdot
.878 .25819 Mdot
.878 .25868 Mdot
.878 .25954 Mdot
.878 .2603 Mdot
.878 .26105 Mdot
.878 .26135 Mdot
.878 .26167 Mdot
.878 .26208 Mdot
.878 .26276 Mdot
.878 .26343 Mdot
.878 .26367 Mdot
.878 .26612 Mdot
.878 .26672 Mdot
.878 .26698 Mdot
.878 .26705 Mdot
.878 .26751 Mdot
.878 .26834 Mdot
.878 .27012 Mdot
.878 .27114 Mdot
.878 .27135 Mdot
.878 .27217 Mdot
.878 .27267 Mdot
.878 .27283 Mdot
.878 .27322 Mdot
.878 .27328 Mdot
.878 .27392 Mdot
.878 .27634 Mdot
.878 .27663 Mdot
.878 .27673 Mdot
.878 .27727 Mdot
.878 .27921 Mdot
.878 .27951 Mdot
.878 .27983 Mdot
.878 .28013 Mdot
.878 .28217 Mdot
.878 .28237 Mdot
.878 .28372 Mdot
.878 .28416 Mdot
.878 .28452 Mdot
.878 .28465 Mdot
.878 .28496 Mdot
.878 .28529 Mdot
.878 .28564 Mdot
.878 .28623 Mdot
.878 .28628 Mdot
.878 .28686 Mdot
.878 .287 Mdot
.878 .2871 Mdot
.878 .28739 Mdot
.878 .28764 Mdot
.878 .28812 Mdot
.878 .28845 Mdot
.878 .28863 Mdot
.878 .28904 Mdot
.878 .28908 Mdot
.878 .28912 Mdot
.878 .28914 Mdot
.878 .28926 Mdot
.878 .29725 Mdot
.878 .29864 Mdot
.878 .30027 Mdot
.878 .30037 Mdot
.878 .30054 Mdot
.878 .30163 Mdot
.878 .30239 Mdot
.878 .30263 Mdot
.878 .30318 Mdot
.878 .30337 Mdot
.878 .30539 Mdot
.878 .30555 Mdot
.878 .30622 Mdot
.878 .30637 Mdot
.878 .30657 Mdot
.878 .30768 Mdot
.878 .30839 Mdot
.878 .30877 Mdot
.878 .30937 Mdot
.878 .30954 Mdot
.878 .31056 Mdot
.878 .31089 Mdot
.878 .31128 Mdot
.878 .31314 Mdot
.878 .31557 Mdot
.878 .31689 Mdot
.878 .31846 Mdot
.878 .31889 Mdot
.878 .31903 Mdot
.878 .31931 Mdot
.878 .31992 Mdot
.878 .32048 Mdot
.878 .32106 Mdot
.878 .3245 Mdot
.878 .32456 Mdot
.878 .32503 Mdot
.878 .32653 Mdot
.878 .32753 Mdot
.878 .32807 Mdot
.878 .32879 Mdot
.878 .32976 Mdot
.878 .32994 Mdot
.878 .33029 Mdot
.878 .33117 Mdot
.878 .33131 Mdot
.878 .33151 Mdot
.878 .33199 Mdot
.878 .33199 Mdot
.878 .33253 Mdot
.878 .33288 Mdot
.878 .33604 Mdot
.878 .33856 Mdot
.878 .34112 Mdot
.878 .3417 Mdot
.878 .34186 Mdot
.878 .34607 Mdot
.878 .34645 Mdot
.878 .34817 Mdot
.878 .34866 Mdot
.878 .34889 Mdot
.878 .349 Mdot
.878 .35028 Mdot
.878 .35071 Mdot
.878 .35101 Mdot
.878 .35299 Mdot
.878 .35302 Mdot
.878 .35389 Mdot
.878 .3543 Mdot
.878 .35434 Mdot
.878 .35511 Mdot
.878 .3555 Mdot
.878 .35595 Mdot
.878 .35602 Mdot
.878 .35753 Mdot
.878 .35753 Mdot
.878 .35794 Mdot
.878 .35815 Mdot
.878 .35977 Mdot
.878 .3604 Mdot
.878 .36155 Mdot
.878 .36317 Mdot
.878 .36335 Mdot
.878 .36516 Mdot
.878 .36618 Mdot
.878 .36618 Mdot
.878 .36728 Mdot
.878 .36841 Mdot
.878 .36955 Mdot
.878 .36974 Mdot
.878 .37147 Mdot
.878 .37263 Mdot
.878 .37434 Mdot
.878 .37531 Mdot
.878 .37566 Mdot
.878 .37613 Mdot
.878 .3762 Mdot
.878 .37634 Mdot
.878 .37849 Mdot
.878 .37864 Mdot
.878 .37893 Mdot
.878 .37894 Mdot
.878 .37944 Mdot
.878 .3796 Mdot
.878 .37991 Mdot
.878 .38006 Mdot
.878 .38162 Mdot
.878 .38172 Mdot
.878 .38199 Mdot
.878 .3828 Mdot
.878 .38301 Mdot
.878 .38354 Mdot
.878 .38524 Mdot
.878 .3855 Mdot
.878 .38773 Mdot
.878 .38778 Mdot
.878 .38837 Mdot
.878 .38907 Mdot
.878 .38941 Mdot
.878 .39118 Mdot
.878 .39214 Mdot
.878 .39294 Mdot
.878 .39442 Mdot
.878 .39622 Mdot
.878 .39644 Mdot
.878 .39722 Mdot
.878 .39743 Mdot
.878 .39801 Mdot
.878 .39825 Mdot
.878 .39845 Mdot
.878 .39888 Mdot
.878 .40235 Mdot
.878 .40357 Mdot
.878 .40373 Mdot
.878 .40382 Mdot
.878 .4055 Mdot
.878 .40644 Mdot
.878 .40795 Mdot
.878 .40856 Mdot
.878 .40979 Mdot
.878 .41273 Mdot
.878 .41306 Mdot
.878 .41332 Mdot
.878 .41351 Mdot
.878 .41404 Mdot
.878 .41426 Mdot
.878 .4143 Mdot
.878 .41492 Mdot
.878 .41508 Mdot
.878 .41558 Mdot
.878 .41607 Mdot
.878 .41756 Mdot
.878 .4176 Mdot
.878 .41783 Mdot
.878 .41901 Mdot
.878 .41915 Mdot
.878 .41954 Mdot
.878 .41994 Mdot
.878 .42042 Mdot
.878 .42051 Mdot
.878 .42109 Mdot
.878 .42458 Mdot
.878 .42512 Mdot
.878 .42636 Mdot
.878 .4267 Mdot
.878 .42712 Mdot
.878 .42714 Mdot
.878 .42826 Mdot
.878 .42902 Mdot
.878 .42948 Mdot
.878 .43066 Mdot
.878 .43295 Mdot
.878 .43303 Mdot
.878 .43408 Mdot
.878 .43421 Mdot
.878 .43465 Mdot
.878 .43472 Mdot
.878 .43644 Mdot
.878 .43796 Mdot
.878 .43819 Mdot
.878 .43909 Mdot
.878 .43947 Mdot
.878 .44016 Mdot
.878 .4418 Mdot
.878 .44189 Mdot
.878 .44196 Mdot
.878 .44238 Mdot
.878 .44309 Mdot
.878 .44346 Mdot
.878 .4436 Mdot
.878 .44401 Mdot
.878 .44561 Mdot
.878 .44656 Mdot
.878 .44717 Mdot
.878 .44956 Mdot
.878 .4496 Mdot
.878 .44991 Mdot
.878 .45016 Mdot
.878 .4506 Mdot
.878 .45197 Mdot
.878 .45348 Mdot
.878 .4537 Mdot
.878 .45606 Mdot
.878 .45688 Mdot
.878 .45735 Mdot
.878 .4577 Mdot
.878 .45792 Mdot
.878 .458 Mdot
.878 .45883 Mdot
.878 .45917 Mdot
.878 .46179 Mdot
.878 .46241 Mdot
.878 .46354 Mdot
.878 .46434 Mdot
.878 .4647 Mdot
.878 .46526 Mdot
.878 .46622 Mdot
.878 .46814 Mdot
.878 .46868 Mdot
.878 .46887 Mdot
.878 .46905 Mdot
.878 .46912 Mdot
.878 .46979 Mdot
.878 .4698 Mdot
.878 .4705 Mdot
.878 .47096 Mdot
.878 .47103 Mdot
.878 .47178 Mdot
.878 .4719 Mdot
.878 .47205 Mdot
.878 .47341 Mdot
.878 .47494 Mdot
.878 .47612 Mdot
.878 .47616 Mdot
.878 .47624 Mdot
.878 .47678 Mdot
.878 .47834 Mdot
.878 .47872 Mdot
.878 .47908 Mdot
.878 .48031 Mdot
.878 .48096 Mdot
.878 .48131 Mdot
.878 .48173 Mdot
.878 .48265 Mdot
.878 .48321 Mdot
.878 .48323 Mdot
.878 .48419 Mdot
.878 .48431 Mdot
.878 .48504 Mdot
.878 .48527 Mdot
.878 .48535 Mdot
.878 .48581 Mdot
.878 .48586 Mdot
.878 .48652 Mdot
.878 .48658 Mdot
.878 .48672 Mdot
.878 .48678 Mdot
.878 .487 Mdot
.878 .48712 Mdot
.878 .48809 Mdot
.878 .48818 Mdot
.878 .48838 Mdot
.878 .48853 Mdot
.878 .48894 Mdot
.878 .48965 Mdot
.878 .49085 Mdot
.878 .49274 Mdot
.878 .49349 Mdot
.878 .49469 Mdot
.878 .4956 Mdot
.878 .49646 Mdot
.878 .49649 Mdot
.878 .49667 Mdot
.878 .49713 Mdot
.878 .49715 Mdot
.878 .49766 Mdot
.878 .49846 Mdot
.878 .49858 Mdot
.878 .49959 Mdot
.878 .50042 Mdot
.878 .50236 Mdot
.878 .50335 Mdot
.878 .50568 Mdot
.878 .50589 Mdot
.878 .50589 Mdot
.878 .50654 Mdot
.878 .50667 Mdot
.878 .50738 Mdot
.878 .50797 Mdot
.878 .50854 Mdot
.878 .50874 Mdot
.878 .51046 Mdot
.878 .51079 Mdot
.878 .51084 Mdot
.878 .51101 Mdot
.878 .51298 Mdot
.878 .51367 Mdot
.878 .51381 Mdot
.878 .51437 Mdot
.878 .51459 Mdot
.878 .51499 Mdot
.878 .51547 Mdot
.878 .51552 Mdot
.878 .51583 Mdot
.878 .51656 Mdot
.878 .51683 Mdot
.878 .51719 Mdot
.878 .51765 Mdot
.878 .51828 Mdot
.878 .52163 Mdot
.878 .52167 Mdot
.878 .52168 Mdot
.878 .52169 Mdot
.878 .5217 Mdot
.878 .52185 Mdot
.878 .52191 Mdot
.878 .52203 Mdot
.878 .5222 Mdot
.878 .52229 Mdot
.878 .52239 Mdot
.878 .52248 Mdot
.878 .52291 Mdot
.878 .52303 Mdot
.878 .52326 Mdot
.878 .52343 Mdot
.878 .52406 Mdot
.878 .52484 Mdot
.878 .52495 Mdot
.878 .52506 Mdot
.878 .52517 Mdot
.878 .52584 Mdot
.878 .52603 Mdot
.878 .52606 Mdot
.878 .52616 Mdot
.878 .52722 Mdot
.878 .52724 Mdot
.878 .52761 Mdot
.878 .52796 Mdot
.878 .52892 Mdot
.878 .52921 Mdot
.878 .52937 Mdot
.878 .52939 Mdot
.878 .52948 Mdot
.878 .52969 Mdot
.878 .53052 Mdot
.878 .5306 Mdot
.878 .5312 Mdot
.878 .53141 Mdot
.878 .53166 Mdot
.878 .53192 Mdot
.878 .53221 Mdot
.878 .53238 Mdot
.878 .53342 Mdot
.878 .53344 Mdot
.878 .53446 Mdot
.878 .53459 Mdot
.878 .53523 Mdot
.878 .53542 Mdot
.878 .53584 Mdot
.878 .53593 Mdot
.878 .53617 Mdot
.878 .53645 Mdot
.878 .53713 Mdot
.878 .53738 Mdot
.878 .53828 Mdot
.878 .53855 Mdot
.878 .53896 Mdot
.878 .53905 Mdot
.878 .53915 Mdot
.878 .53954 Mdot
.878 .5406 Mdot
.878 .54227 Mdot
.878 .54273 Mdot
.878 .54315 Mdot
.878 .54406 Mdot
.878 .54417 Mdot
.878 .5442 Mdot
.878 .54422 Mdot
.878 .54545 Mdot
.878 .54572 Mdot
.878 .54611 Mdot
.878 .54647 Mdot
.878 .5472 Mdot
.878 .54783 Mdot
.878 .54788 Mdot
.878 .54943 Mdot
.878 .55017 Mdot
.878 .55043 Mdot
.878 .55105 Mdot
.878 .55214 Mdot
.878 .55214 Mdot
.878 .55266 Mdot
.878 .55287 Mdot
.878 .55363 Mdot
.878 .55365 Mdot
.878 .55391 Mdot
.878 .55401 Mdot
.878 .55422 Mdot
.878 .55536 Mdot
.878 .55549 Mdot
.878 .55557 Mdot
.878 .5556 Mdot
.878 .55563 Mdot
.878 .55565 Mdot
.878 .55589 Mdot
.878 .55591 Mdot
.878 .55593 Mdot
.878 .55594 Mdot
.878 .55607 Mdot
.878 .55607 Mdot
.878 .55616 Mdot
.878 .55655 Mdot
.878 .55655 Mdot
.878 .55665 Mdot
.878 .55682 Mdot
.878 .55696 Mdot
.878 .55707 Mdot
.878 .55729 Mdot
.878 .5578 Mdot
.878 .55781 Mdot
.878 .55829 Mdot
.878 .55871 Mdot
.878 .55879 Mdot
.878 .55891 Mdot
.878 .55903 Mdot
.878 .5591 Mdot
.878 .55951 Mdot
.878 .55976 Mdot
.878 .55982 Mdot
.878 .56024 Mdot
.878 .56067 Mdot
.878 .56072 Mdot
.878 .5609 Mdot
.878 .56154 Mdot
.878 .56181 Mdot
.878 .56213 Mdot
.878 .56218 Mdot
.878 .56219 Mdot
.878 .56255 Mdot
.878 .56265 Mdot
.878 .5631 Mdot
.878 .56312 Mdot
.878 .56336 Mdot
.878 .56377 Mdot
.878 .56391 Mdot
.878 .56394 Mdot
.878 .56417 Mdot
.878 .56442 Mdot
.878 .56443 Mdot
.878 .56451 Mdot
.878 .56466 Mdot
.878 .56517 Mdot
.878 .56551 Mdot
.878 .56557 Mdot
.878 .56562 Mdot
.878 .56587 Mdot
.878 .56644 Mdot
.878 .56645 Mdot
.878 .56681 Mdot
.878 .56712 Mdot
.878 .56729 Mdot
.878 .5673 Mdot
.878 .56733 Mdot
.878 .5674 Mdot
.878 .56806 Mdot
.878 .56814 Mdot
.878 .56847 Mdot
.878 .56939 Mdot
.878 .56941 Mdot
.878 .56952 Mdot
.878 .56964 Mdot
.878 .56967 Mdot
.878 .57053 Mdot
.878 .57066 Mdot
.878 .57145 Mdot
.878 .57183 Mdot
.878 .57188 Mdot
.878 .57216 Mdot
.878 .57273 Mdot
.878 .57295 Mdot
.878 .57309 Mdot
.878 .57322 Mdot
.878 .57335 Mdot
.878 .57335 Mdot
.878 .5737 Mdot
.878 .57389 Mdot
.878 .5741 Mdot
.878 .57431 Mdot
.878 .57435 Mdot
.878 .57435 Mdot
.878 .57463 Mdot
.878 .57477 Mdot
.878 .57487 Mdot
.878 .57518 Mdot
.878 .57532 Mdot
.878 .57534 Mdot
.878 .57536 Mdot
.878 .57561 Mdot
.878 .57612 Mdot
.878 .57613 Mdot
.878 .57676 Mdot
.878 .5771 Mdot
.878 .57724 Mdot
.878 .57727 Mdot
.878 .57728 Mdot
.878 .57743 Mdot
.878 .57754 Mdot
.878 .57767 Mdot
.878 .57799 Mdot
.878 .57836 Mdot
.878 .57842 Mdot
.878 .57854 Mdot
.878 .57879 Mdot
.878 .57893 Mdot
.878 .57945 Mdot
.878 .57955 Mdot
.878 .57967 Mdot
.878 .57985 Mdot
.878 .57996 Mdot
.878 .5802 Mdot
.878 .58028 Mdot
.878 .58046 Mdot
.878 .58049 Mdot
.878 .58079 Mdot
.878 .5818 Mdot
.878 .58187 Mdot
.878 .58188 Mdot
.878 .582 Mdot
.878 .58205 Mdot
.878 .58212 Mdot
.878 .58227 Mdot
.878 .58307 Mdot
.878 .58317 Mdot
.878 .58319 Mdot
.878 .58331 Mdot
.878 .58343 Mdot
.878 .58412 Mdot
.878 .58418 Mdot
.878 .58425 Mdot
.878 .58472 Mdot
.878 .58486 Mdot
.878 .58498 Mdot
.878 .58502 Mdot
.878 .58512 Mdot
.878 .58518 Mdot
.878 .58523 Mdot
.878 .58529 Mdot
.878 .58533 Mdot
.878 .58546 Mdot
.878 .58546 Mdot
.878 .58552 Mdot
.878 .58553 Mdot
.878 .5856 Mdot
.878 .58566 Mdot
.878 .5857 Mdot
.878 .5857 Mdot
.878 .58574 Mdot
.878 .58577 Mdot
.878 .58586 Mdot
.878 .58593 Mdot
.878 .58596 Mdot
.878 .58606 Mdot
.878 .58606 Mdot
.878 .58611 Mdot
.878 .58615 Mdot
.878 .5862 Mdot
.878 .58631 Mdot
.878 .58632 Mdot
.878 .58633 Mdot
.878 .58634 Mdot
.878 .58637 Mdot
.878 .58637 Mdot
.878 .58655 Mdot
.878 .58669 Mdot
.878 .58692 Mdot
.878 .58726 Mdot
.878 .58736 Mdot
.878 .58737 Mdot
.878 .588 Mdot
.878 .58804 Mdot
.878 .58809 Mdot
.878 .58817 Mdot
.878 .58824 Mdot
.878 .58825 Mdot
.878 .58829 Mdot
.878 .58831 Mdot
.878 .58837 Mdot
.878 .58845 Mdot
.878 .58846 Mdot
.878 .58848 Mdot
.878 .58855 Mdot
.878 .5886 Mdot
.878 .58867 Mdot
.878 .58867 Mdot
.878 .58869 Mdot
.878 .58873 Mdot
.878 .58875 Mdot
.878 .58884 Mdot
.878 .58887 Mdot
.878 .58888 Mdot
.878 .58891 Mdot
.878 .58891 Mdot
.878 .58892 Mdot
.878 .58892 Mdot
.878 .58893 Mdot
.878 .58894 Mdot
.878 .58895 Mdot
.878 .58895 Mdot
.878 .58896 Mdot
.878 .58896 Mdot
.878 .58896 Mdot
.88 .06854 Mdot
.88 .06855 Mdot
.88 .06855 Mdot
.88 .06855 Mdot
.88 .06855 Mdot
.88 .06857 Mdot
.88 .06861 Mdot
.88 .06888 Mdot
.88 .06926 Mdot
.88 .06927 Mdot
.88 .06936 Mdot
.88 .0694 Mdot
.88 .06953 Mdot
.88 .06953 Mdot
.88 .06977 Mdot
.88 .06984 Mdot
.88 .06986 Mdot
.88 .07019 Mdot
.88 .07023 Mdot
.88 .0704 Mdot
.88 .07064 Mdot
.88 .0707 Mdot
.88 .07076 Mdot
.88 .07079 Mdot
.88 .07102 Mdot
.88 .07112 Mdot
.88 .07118 Mdot
.88 .07121 Mdot
.88 .07125 Mdot
.88 .07126 Mdot
.88 .07127 Mdot
.88 .07131 Mdot
.88 .07137 Mdot
.88 .07166 Mdot
.88 .07175 Mdot
.88 .07184 Mdot
.88 .07204 Mdot
.88 .07214 Mdot
.88 .07232 Mdot
.88 .07238 Mdot
.88 .07277 Mdot
.88 .07305 Mdot
.88 .0737 Mdot
.88 .07382 Mdot
.88 .07386 Mdot
.88 .07418 Mdot
.88 .07432 Mdot
.88 .07449 Mdot
.88 .07486 Mdot
.88 .07518 Mdot
.88 .07571 Mdot
.88 .07603 Mdot
.88 .07634 Mdot
.88 .07657 Mdot
.88 .07686 Mdot
.88 .07696 Mdot
.88 .07713 Mdot
.88 .07725 Mdot
.88 .07737 Mdot
.88 .07746 Mdot
.88 .07756 Mdot
.88 .07794 Mdot
.88 .078 Mdot
.88 .07857 Mdot
.88 .07911 Mdot
.88 .07912 Mdot
.88 .07919 Mdot
.88 .08069 Mdot
.88 .0807 Mdot
.88 .08092 Mdot
.88 .08141 Mdot
.88 .08156 Mdot
.88 .08226 Mdot
.88 .08244 Mdot
.88 .08256 Mdot
.88 .08307 Mdot
.88 .08322 Mdot
.88 .08339 Mdot
.88 .084 Mdot
.88 .08403 Mdot
.88 .08474 Mdot
.88 .08478 Mdot
.88 .08506 Mdot
.88 .08528 Mdot
.88 .0863 Mdot
.88 .08726 Mdot
.88 .08897 Mdot
.88 .08943 Mdot
.88 .08992 Mdot
.88 .09005 Mdot
.88 .09067 Mdot
.88 .09081 Mdot
.88 .09123 Mdot
.88 .09142 Mdot
.88 .09314 Mdot
.88 .09447 Mdot
.88 .09469 Mdot
.88 .09498 Mdot
.88 .09641 Mdot
.88 .0968 Mdot
.88 .09731 Mdot
.88 .09818 Mdot
.88 .0991 Mdot
.88 .09934 Mdot
.88 .09963 Mdot
.88 .10008 Mdot
.88 .10032 Mdot
.88 .1015 Mdot
.88 .10213 Mdot
.88 .10324 Mdot
.88 .1039 Mdot
.88 .1061 Mdot
.88 .10617 Mdot
.88 .10619 Mdot
.88 .10655 Mdot
.88 .107 Mdot
.88 .10778 Mdot
.88 .10912 Mdot
.88 .10919 Mdot
.88 .10961 Mdot
.88 .11013 Mdot
.88 .11023 Mdot
.88 .11035 Mdot
.88 .11057 Mdot
.88 .11128 Mdot
.88 .11213 Mdot
.88 .11242 Mdot
.88 .11246 Mdot
.88 .11263 Mdot
.88 .11273 Mdot
.88 .11315 Mdot
.88 .11317 Mdot
.88 .11362 Mdot
.88 .11489 Mdot
.88 .115 Mdot
.88 .11932 Mdot
.88 .11936 Mdot
.88 .11984 Mdot
.88 .12213 Mdot
.88 .12246 Mdot
.88 .12459 Mdot
.88 .12496 Mdot
.88 .12565 Mdot
.88 .12682 Mdot
.88 .12695 Mdot
.88 .12831 Mdot
.88 .13044 Mdot
.88 .13228 Mdot
.88 .13243 Mdot
.88 .13266 Mdot
.88 .13302 Mdot
.88 .13379 Mdot
.88 .13423 Mdot
.88 .13504 Mdot
.88 .13628 Mdot
.88 .13629 Mdot
.88 .13651 Mdot
.88 .13655 Mdot
.88 .13731 Mdot
.88 .13937 Mdot
.88 .14007 Mdot
.88 .14167 Mdot
.88 .14177 Mdot
.88 .14177 Mdot
.88 .14182 Mdot
.88 .14211 Mdot
.88 .143 Mdot
.88 .14365 Mdot
.88 .14423 Mdot
.88 .14506 Mdot
.88 .14542 Mdot
.88 .14601 Mdot
.88 .14679 Mdot
.88 .14813 Mdot
.88 .14928 Mdot
.88 .15323 Mdot
.88 .15336 Mdot
.88 .1534 Mdot
.88 .15354 Mdot
.88 .15387 Mdot
.88 .15436 Mdot
.88 .15438 Mdot
.88 .1544 Mdot
.88 .1552 Mdot
.88 .15582 Mdot
.88 .15681 Mdot
.88 .15703 Mdot
.88 .16027 Mdot
.88 .16166 Mdot
.88 .16194 Mdot
.88 .16299 Mdot
.88 .16344 Mdot
.88 .16724 Mdot
.88 .1691 Mdot
.88 .16918 Mdot
.88 .17239 Mdot
.88 .17557 Mdot
.88 .17827 Mdot
.88 .18283 Mdot
.88 .18301 Mdot
.88 .18347 Mdot
.88 .18353 Mdot
.88 .1843 Mdot
.88 .18548 Mdot
.88 .18714 Mdot
.88 .18731 Mdot
.88 .18843 Mdot
.88 .18862 Mdot
.88 .18959 Mdot
.88 .19161 Mdot
.88 .19221 Mdot
.88 .19275 Mdot
.88 .19412 Mdot
.88 .19446 Mdot
.88 .19471 Mdot
.88 .19711 Mdot
.88 .1984 Mdot
.88 .19911 Mdot
.88 .19941 Mdot
.88 .19971 Mdot
.88 .19983 Mdot
.88 .20032 Mdot
.88 .20152 Mdot
.88 .20273 Mdot
.88 .20289 Mdot
.88 .20443 Mdot
.88 .20447 Mdot
.88 .20458 Mdot
.88 .20458 Mdot
.88 .20543 Mdot
.88 .20561 Mdot
.88 .20564 Mdot
.88 .20565 Mdot
.88 .20567 Mdot
.88 .20568 Mdot
.88 .20568 Mdot
.88 .20573 Mdot
.88 .20587 Mdot
.88 .2062 Mdot
.88 .20672 Mdot
.88 .20701 Mdot
.88 .20787 Mdot
.88 .20793 Mdot
.88 .20796 Mdot
.88 .20807 Mdot
.88 .20824 Mdot
.88 .20838 Mdot
.88 .20839 Mdot
.88 .20878 Mdot
.88 .20879 Mdot
.88 .20955 Mdot
.88 .20977 Mdot
.88 .20982 Mdot
.88 .21065 Mdot
.88 .21074 Mdot
.88 .21076 Mdot
.88 .21088 Mdot
.88 .21102 Mdot
.88 .21155 Mdot
.88 .21217 Mdot
.88 .21231 Mdot
.88 .2124 Mdot
.88 .21251 Mdot
.88 .21269 Mdot
.88 .21278 Mdot
.88 .2135 Mdot
.88 .21381 Mdot
.88 .21387 Mdot
.88 .214 Mdot
.88 .2141 Mdot
.88 .21422 Mdot
.88 .21426 Mdot
.88 .21428 Mdot
.88 .21442 Mdot
.88 .2146 Mdot
.88 .21551 Mdot
.88 .21581 Mdot
.88 .2161 Mdot
.88 .21672 Mdot
.88 .21704 Mdot
.88 .21718 Mdot
.88 .2176 Mdot
.88 .21779 Mdot
.88 .21805 Mdot
.88 .219 Mdot
.88 .21989 Mdot
.88 .22191 Mdot
.88 .22203 Mdot
.88 .22214 Mdot
.88 .2223 Mdot
.88 .22241 Mdot
.88 .22275 Mdot
.88 .22342 Mdot
.88 .22385 Mdot
.88 .22386 Mdot
.88 .22407 Mdot
.88 .22416 Mdot
.88 .22439 Mdot
.88 .22554 Mdot
.88 .22615 Mdot
.88 .22653 Mdot
.88 .22817 Mdot
.88 .22916 Mdot
.88 .23009 Mdot
.88 .2301 Mdot
.88 .23013 Mdot
.88 .23081 Mdot
.88 .23091 Mdot
.88 .23123 Mdot
.88 .23171 Mdot
.88 .23197 Mdot
.88 .232 Mdot
.88 .23202 Mdot
.88 .23254 Mdot
.88 .23291 Mdot
.88 .23328 Mdot
.88 .23347 Mdot
.88 .23357 Mdot
.88 .23388 Mdot
.88 .23504 Mdot
.88 .23522 Mdot
.88 .23583 Mdot
.88 .23697 Mdot
.88 .23703 Mdot
.88 .23739 Mdot
.88 .23799 Mdot
.88 .23837 Mdot
.88 .23862 Mdot
.88 .23864 Mdot
.88 .23879 Mdot
.88 .23885 Mdot
.88 .24343 Mdot
.88 .24346 Mdot
.88 .2441 Mdot
.88 .24559 Mdot
.88 .24596 Mdot
.88 .24606 Mdot
.88 .24656 Mdot
.88 .2478 Mdot
.88 .24816 Mdot
.88 .24868 Mdot
.88 .24907 Mdot
.88 .24912 Mdot
.88 .25059 Mdot
.88 .25103 Mdot
.88 .25154 Mdot
.88 .25221 Mdot
.88 .25253 Mdot
.88 .25336 Mdot
.88 .25347 Mdot
.88 .25349 Mdot
.88 .25416 Mdot
.88 .25558 Mdot
.88 .25568 Mdot
.88 .25569 Mdot
.88 .2562 Mdot
.88 .25653 Mdot
.88 .25718 Mdot
.88 .25734 Mdot
.88 .25903 Mdot
.88 .25962 Mdot
.88 .26019 Mdot
.88 .26066 Mdot
.88 .26176 Mdot
.88 .26303 Mdot
.88 .26305 Mdot
.88 .2651 Mdot
.88 .26577 Mdot
.88 .26599 Mdot
.88 .266 Mdot
.88 .26626 Mdot
.88 .26634 Mdot
.88 .26636 Mdot
.88 .26651 Mdot
.88 .26693 Mdot
.88 .26729 Mdot
.88 .26778 Mdot
.88 .268 Mdot
.88 .26803 Mdot
.88 .26873 Mdot
.88 .26914 Mdot
.88 .26938 Mdot
.88 .26962 Mdot
.88 .27081 Mdot
.88 .27118 Mdot
.88 .2718 Mdot
.88 .27215 Mdot
.88 .27283 Mdot
.88 .27297 Mdot
.88 .27323 Mdot
.88 .2734 Mdot
.88 .27354 Mdot
.88 .27409 Mdot
.88 .27461 Mdot
.88 .27516 Mdot
.88 .27605 Mdot
.88 .27638 Mdot
.88 .27838 Mdot
.88 .27889 Mdot
.88 .27932 Mdot
.88 .27941 Mdot
.88 .27976 Mdot
.88 .28009 Mdot
.88 .28133 Mdot
.88 .28285 Mdot
.88 .28302 Mdot
.88 .28385 Mdot
.88 .28388 Mdot
.88 .28453 Mdot
.88 .28534 Mdot
.88 .2861 Mdot
.88 .28674 Mdot
.88 .28675 Mdot
.88 .28825 Mdot
.88 .28825 Mdot
.88 .28879 Mdot
.88 .28938 Mdot
.88 .28944 Mdot
.88 .28984 Mdot
.88 .28995 Mdot
.88 .29018 Mdot
.88 .2905 Mdot
.88 .29193 Mdot
.88 .29298 Mdot
.88 .29345 Mdot
.88 .29436 Mdot
.88 .29454 Mdot
.88 .29591 Mdot
.88 .29652 Mdot
.88 .29692 Mdot
.88 .29759 Mdot
.88 .29776 Mdot
.88 .2983 Mdot
.88 .29841 Mdot
.88 .29849 Mdot
.88 .29851 Mdot
.88 .29853 Mdot
.88 .2986 Mdot
.88 .29867 Mdot
.88 .29878 Mdot
.88 .29945 Mdot
.88 .29964 Mdot
.88 .30032 Mdot
.88 .30083 Mdot
.88 .30268 Mdot
.88 .30268 Mdot
.88 .3031 Mdot
.88 .30325 Mdot
.88 .30357 Mdot
.88 .30529 Mdot
.88 .30728 Mdot
.88 .30824 Mdot
.88 .30834 Mdot
.88 .30855 Mdot
.88 .30916 Mdot
.88 .30976 Mdot
.88 .31013 Mdot
.88 .31443 Mdot
.88 .31609 Mdot
.88 .31628 Mdot
.88 .31632 Mdot
.88 .31731 Mdot
.88 .31826 Mdot
.88 .31851 Mdot
.88 .31905 Mdot
.88 .3206 Mdot
.88 .32094 Mdot
.88 .32141 Mdot
.88 .32256 Mdot
.88 .32372 Mdot
.88 .32417 Mdot
.88 .32435 Mdot
.88 .32546 Mdot
.88 .32648 Mdot
.88 .32684 Mdot
.88 .3271 Mdot
.88 .32742 Mdot
.88 .32772 Mdot
.88 .32798 Mdot
.88 .32985 Mdot
.88 .33149 Mdot
.88 .33208 Mdot
.88 .33284 Mdot
.88 .33295 Mdot
.88 .33338 Mdot
.88 .33365 Mdot
.88 .33475 Mdot
.88 .33478 Mdot
.88 .33597 Mdot
.88 .33924 Mdot
.88 .33953 Mdot
.88 .34079 Mdot
.88 .3418 Mdot
.88 .34311 Mdot
.88 .34845 Mdot
.88 .34846 Mdot
.88 .35052 Mdot
.88 .35057 Mdot
.88 .35063 Mdot
.88 .35182 Mdot
.88 .35288 Mdot
.88 .35522 Mdot
.88 .35642 Mdot
.88 .35754 Mdot
.88 .35836 Mdot
.88 .35991 Mdot
.88 .36075 Mdot
.88 .361 Mdot
.88 .36132 Mdot
.88 .36244 Mdot
.88 .36276 Mdot
.88 .36359 Mdot
.88 .3645 Mdot
.88 .36454 Mdot
.88 .36503 Mdot
.88 .36528 Mdot
.88 .36619 Mdot
.88 .36898 Mdot
.88 .36903 Mdot
.88 .36915 Mdot
.88 .36933 Mdot
.88 .36934 Mdot
.88 .36964 Mdot
.88 .37031 Mdot
.88 .3726 Mdot
.88 .3757 Mdot
.88 .37678 Mdot
.88 .37768 Mdot
.88 .38058 Mdot
.88 .38137 Mdot
.88 .38201 Mdot
.88 .38238 Mdot
.88 .38292 Mdot
.88 .38375 Mdot
.88 .38437 Mdot
.88 .3846 Mdot
.88 .38554 Mdot
.88 .38606 Mdot
.88 .38637 Mdot
.88 .38655 Mdot
.88 .38706 Mdot
.88 .38836 Mdot
.88 .38843 Mdot
.88 .39012 Mdot
.88 .39129 Mdot
.88 .39132 Mdot
.88 .39182 Mdot
.88 .39191 Mdot
.88 .39364 Mdot
.88 .39831 Mdot
.88 .39866 Mdot
.88 .39989 Mdot
.88 .40177 Mdot
.88 .40287 Mdot
.88 .40368 Mdot
.88 .40368 Mdot
.88 .40378 Mdot
.88 .40442 Mdot
.88 .40466 Mdot
.88 .40639 Mdot
.88 .40781 Mdot
.88 .40908 Mdot
.88 .4109 Mdot
.88 .41167 Mdot
.88 .41297 Mdot
.88 .41465 Mdot
.88 .4149 Mdot
.88 .41498 Mdot
.88 .41751 Mdot
.88 .41995 Mdot
.88 .42529 Mdot
.88 .42702 Mdot
.88 .42733 Mdot
.88 .42822 Mdot
.88 .4285 Mdot
.88 .42858 Mdot
.88 .42887 Mdot
.88 .42895 Mdot
.88 .42953 Mdot
.88 .43055 Mdot
.88 .43059 Mdot
.88 .43064 Mdot
.88 .43227 Mdot
.88 .43353 Mdot
.88 .43494 Mdot
.88 .43553 Mdot
.88 .43599 Mdot
.88 .4382 Mdot
.88 .43901 Mdot
.88 .43929 Mdot
.88 .44244 Mdot
.88 .44518 Mdot
.88 .44572 Mdot
.88 .44616 Mdot
.88 .44776 Mdot
.88 .44864 Mdot
.88 .45587 Mdot
.88 .45935 Mdot
.88 .45949 Mdot
.88 .4599 Mdot
.88 .46152 Mdot
.88 .46445 Mdot
.88 .46524 Mdot
.88 .46538 Mdot
.88 .46622 Mdot
.88 .47108 Mdot
.88 .47112 Mdot
.88 .47582 Mdot
.88 .47662 Mdot
.88 .47712 Mdot
.88 .4785 Mdot
.88 .48226 Mdot
.88 .48303 Mdot
.88 .48359 Mdot
.88 .48388 Mdot
.88 .48402 Mdot
.88 .48465 Mdot
.88 .48475 Mdot
.88 .48603 Mdot
.88 .48636 Mdot
.88 .48797 Mdot
.88 .48843 Mdot
.88 .49068 Mdot
.88 .49095 Mdot
.88 .49108 Mdot
.88 .49116 Mdot
.88 .49123 Mdot
.88 .49275 Mdot
.88 .49286 Mdot
.88 .49305 Mdot
.88 .49378 Mdot
.88 .49392 Mdot
.88 .49437 Mdot
.88 .4945 Mdot
.88 .4946 Mdot
.88 .49494 Mdot
.88 .49635 Mdot
.88 .49683 Mdot
.88 .49777 Mdot
.88 .49869 Mdot
.88 .49953 Mdot
.88 .49953 Mdot
.88 .50163 Mdot
.88 .50215 Mdot
.88 .50254 Mdot
.88 .50613 Mdot
.88 .50757 Mdot
.88 .50804 Mdot
.88 .50908 Mdot
.88 .50952 Mdot
.88 .50995 Mdot
.88 .51012 Mdot
.88 .51083 Mdot
.88 .51113 Mdot
.88 .51255 Mdot
.88 .51427 Mdot
.88 .51449 Mdot
.88 .51472 Mdot
.88 .51483 Mdot
.88 .51518 Mdot
.88 .51665 Mdot
.88 .51671 Mdot
.88 .51686 Mdot
.88 .51686 Mdot
.88 .51752 Mdot
.88 .51802 Mdot
.88 .51826 Mdot
.88 .51831 Mdot
.88 .51833 Mdot
.88 .51836 Mdot
.88 .51837 Mdot
.88 .51837 Mdot
.88 .51844 Mdot
.88 .51863 Mdot
.88 .51908 Mdot
.88 .5193 Mdot
.88 .51979 Mdot
.88 .52018 Mdot
.88 .52035 Mdot
.88 .52134 Mdot
.88 .52142 Mdot
.88 .52146 Mdot
.88 .5216 Mdot
.88 .52183 Mdot
.88 .52203 Mdot
.88 .52203 Mdot
.88 .52256 Mdot
.88 .52256 Mdot
.88 .52279 Mdot
.88 .52358 Mdot
.88 .52387 Mdot
.88 .52393 Mdot
.88 .52446 Mdot
.88 .52501 Mdot
.88 .52513 Mdot
.88 .52516 Mdot
.88 .52531 Mdot
.88 .52549 Mdot
.88 .52619 Mdot
.88 .5263 Mdot
.88 .52698 Mdot
.88 .52717 Mdot
.88 .52728 Mdot
.88 .52742 Mdot
.88 .52765 Mdot
.88 .52777 Mdot
.88 .52852 Mdot
.88 .52869 Mdot
.88 .52883 Mdot
.88 .52908 Mdot
.88 .52915 Mdot
.88 .52932 Mdot
.88 .52944 Mdot
.88 .52959 Mdot
.88 .52964 Mdot
.88 .52964 Mdot
.88 .52967 Mdot
.88 .52976 Mdot
.88 .52976 Mdot
.88 .52984 Mdot
.88 .53007 Mdot
.88 .53076 Mdot
.88 .5312 Mdot
.88 .53158 Mdot
.88 .53193 Mdot
.88 .53213 Mdot
.88 .5327 Mdot
.88 .53308 Mdot
.88 .53325 Mdot
.88 .53377 Mdot
.88 .53399 Mdot
.88 .53431 Mdot
.88 .53442 Mdot
.88 .53545 Mdot
.88 .53589 Mdot
.88 .5363 Mdot
.88 .5365 Mdot
.88 .53886 Mdot
.88 .539 Mdot
.88 .53913 Mdot
.88 .53932 Mdot
.88 .53944 Mdot
.88 .53983 Mdot
.88 .5406 Mdot
.88 .54108 Mdot
.88 .54109 Mdot
.88 .54133 Mdot
.88 .54143 Mdot
.88 .5417 Mdot
.88 .5417 Mdot
.88 .54297 Mdot
.88 .54361 Mdot
.88 .54364 Mdot
.88 .54371 Mdot
.88 .54407 Mdot
.88 .54426 Mdot
.88 .5443 Mdot
.88 .54557 Mdot
.88 .54585 Mdot
.88 .5469 Mdot
.88 .54736 Mdot
.88 .54744 Mdot
.88 .54788 Mdot
.88 .54789 Mdot
.88 .54792 Mdot
.88 .54863 Mdot
.88 .54873 Mdot
.88 .54879 Mdot
.88 .54906 Mdot
.88 .54932 Mdot
.88 .5495 Mdot
.88 .54956 Mdot
.88 .54982 Mdot
.88 .54982 Mdot
.88 .54986 Mdot
.88 .54987 Mdot
.88 .55035 Mdot
.88 .5504 Mdot
.88 .55078 Mdot
.88 .55115 Mdot
.88 .55131 Mdot
.88 .55134 Mdot
.88 .55144 Mdot
.88 .55153 Mdot
.88 .55175 Mdot
.88 .55215 Mdot
.88 .55289 Mdot
.88 .55297 Mdot
.88 .55308 Mdot
.88 .5535 Mdot
.88 .55367 Mdot
.88 .55385 Mdot
.88 .55447 Mdot
.88 .55477 Mdot
.88 .55483 Mdot
.88 .55517 Mdot
.88 .55522 Mdot
.88 .55573 Mdot
.88 .55609 Mdot
.88 .55633 Mdot
.88 .55634 Mdot
.88 .55648 Mdot
.88 .55654 Mdot
.88 .55792 Mdot
.88 .55874 Mdot
.88 .5597 Mdot
.88 .56066 Mdot
.88 .56069 Mdot
.88 .56124 Mdot
.88 .56237 Mdot
.88 .56251 Mdot
.88 .56282 Mdot
.88 .5629 Mdot
.88 .56332 Mdot
.88 .56427 Mdot
.88 .56434 Mdot
.88 .56463 Mdot
.88 .56481 Mdot
.88 .56505 Mdot
.88 .56506 Mdot
.88 .56506 Mdot
.88 .56521 Mdot
.88 .5653 Mdot
.88 .56534 Mdot
.88 .56536 Mdot
.88 .5654 Mdot
.88 .56655 Mdot
.88 .56689 Mdot
.88 .56728 Mdot
.88 .56751 Mdot
.88 .56768 Mdot
.88 .56779 Mdot
.88 .56803 Mdot
.88 .5682 Mdot
.88 .56839 Mdot
.88 .56864 Mdot
.88 .56873 Mdot
.88 .56874 Mdot
.88 .56874 Mdot
.88 .56877 Mdot
.88 .56923 Mdot
.88 .56944 Mdot
.88 .57004 Mdot
.88 .57025 Mdot
.88 .57026 Mdot
.88 .57033 Mdot
.88 .57033 Mdot
.88 .57069 Mdot
.88 .57092 Mdot
.88 .57105 Mdot
.88 .57127 Mdot
.88 .57137 Mdot
.88 .57144 Mdot
.88 .57148 Mdot
.88 .57201 Mdot
.88 .57262 Mdot
.88 .57301 Mdot
.88 .57305 Mdot
.88 .57338 Mdot
.88 .57358 Mdot
.88 .57368 Mdot
.88 .57429 Mdot
.88 .57438 Mdot
.88 .57503 Mdot
.88 .57517 Mdot
.88 .57518 Mdot
.88 .5764 Mdot
.88 .57643 Mdot
.88 .57679 Mdot
.88 .57692 Mdot
.88 .57692 Mdot
.88 .57704 Mdot
.88 .57707 Mdot
.88 .57711 Mdot
.88 .57713 Mdot
.88 .57721 Mdot
.88 .57745 Mdot
.88 .57765 Mdot
.88 .57771 Mdot
.88 .57774 Mdot
.88 .57777 Mdot
.88 .57792 Mdot
.88 .57803 Mdot
.88 .57805 Mdot
.88 .57843 Mdot
.88 .57865 Mdot
.88 .57877 Mdot
.88 .57887 Mdot
.88 .57888 Mdot
.88 .5789 Mdot
.88 .57951 Mdot
.88 .5797 Mdot
.88 .58001 Mdot
.88 .58018 Mdot
.88 .58051 Mdot
.88 .58057 Mdot
.88 .5807 Mdot
.88 .58078 Mdot
.88 .58085 Mdot
.88 .5811 Mdot
.88 .58134 Mdot
.88 .58148 Mdot
.88 .58159 Mdot
.88 .58199 Mdot
.88 .58207 Mdot
.88 .58213 Mdot
.88 .58249 Mdot
.88 .58297 Mdot
.88 .58302 Mdot
.88 .58313 Mdot
.88 .58317 Mdot
.88 .58334 Mdot
.88 .58338 Mdot
.88 .58351 Mdot
.88 .58364 Mdot
.88 .58411 Mdot
.88 .58437 Mdot
.88 .58465 Mdot
.88 .58471 Mdot
.88 .58479 Mdot
.88 .5848 Mdot
.88 .58499 Mdot
.88 .585 Mdot
.88 .58517 Mdot
.88 .58522 Mdot
.88 .58525 Mdot
.88 .58539 Mdot
.88 .58543 Mdot
.88 .58548 Mdot
.88 .58567 Mdot
.88 .58571 Mdot
.88 .58584 Mdot
.88 .5859 Mdot
.88 .5859 Mdot
.88 .58631 Mdot
.88 .58633 Mdot
.88 .58633 Mdot
.88 .58648 Mdot
.88 .58664 Mdot
.88 .58665 Mdot
.88 .58675 Mdot
.88 .58678 Mdot
.88 .58681 Mdot
.88 .58684 Mdot
.88 .58687 Mdot
.88 .58692 Mdot
.88 .58695 Mdot
.88 .58702 Mdot
.88 .58708 Mdot
.88 .58717 Mdot
.88 .58726 Mdot
.88 .5874 Mdot
.88 .58749 Mdot
.88 .58759 Mdot
.88 .58763 Mdot
.88 .58767 Mdot
.88 .58776 Mdot
.88 .58777 Mdot
.88 .5878 Mdot
.88 .58798 Mdot
.88 .58805 Mdot
.88 .58816 Mdot
.88 .58817 Mdot
.88 .58822 Mdot
.88 .58825 Mdot
.88 .5883 Mdot
.88 .58833 Mdot
.88 .58835 Mdot
.88 .58843 Mdot
.88 .58845 Mdot
.88 .58846 Mdot
.88 .58846 Mdot
.88 .58846 Mdot
.88 .58847 Mdot
.88 .58848 Mdot
.88 .5885 Mdot
.88 .58852 Mdot
.88 .58859 Mdot
.88 .58859 Mdot
.88 .58861 Mdot
.88 .58863 Mdot
.88 .58869 Mdot
.88 .58874 Mdot
.88 .58875 Mdot
.88 .58884 Mdot
.88 .58884 Mdot
.88 .58886 Mdot
.88 .58893 Mdot
.88 .58893 Mdot
.88 .58896 Mdot
.88 .58897 Mdot
.88 .589 Mdot
.88 .589 Mdot
.88 .5891 Mdot
.88 .58917 Mdot
.88 .58918 Mdot
.88 .58919 Mdot
.88 .58919 Mdot
.88 .58919 Mdot
.88 .58919 Mdot
.88 .58919 Mdot
.882 .06771 Mdot
.882 .20305 Mdot
.882 .30812 Mdot
.882 .51492 Mdot
.882 .58942 Mdot
.884 .06683 Mdot
.884 .06683 Mdot
.884 .06685 Mdot
.884 .06685 Mdot
.884 .06686 Mdot
.884 .06687 Mdot
.884 .06688 Mdot
.884 .0669 Mdot
.884 .06692 Mdot
.884 .06692 Mdot
.884 .06694 Mdot
.884 .06694 Mdot
.884 .06696 Mdot
.884 .067 Mdot
.884 .06701 Mdot
.884 .06702 Mdot
.884 .06707 Mdot
.884 .06749 Mdot
.884 .06758 Mdot
.884 .06764 Mdot
.884 .06769 Mdot
.884 .06772 Mdot
.884 .06775 Mdot
.884 .06779 Mdot
.884 .06799 Mdot
.884 .06805 Mdot
.884 .06807 Mdot
.884 .06824 Mdot
.884 .06829 Mdot
.884 .06835 Mdot
.884 .06838 Mdot
.884 .06844 Mdot
.884 .06847 Mdot
.884 .06847 Mdot
.884 .06851 Mdot
.884 .06856 Mdot
.884 .06864 Mdot
.884 .06869 Mdot
.884 .06872 Mdot
.884 .06872 Mdot
.884 .06873 Mdot
.884 .06878 Mdot
.884 .06883 Mdot
.884 .06884 Mdot
.884 .06885 Mdot
.884 .06891 Mdot
.884 .06893 Mdot
.884 .06901 Mdot
.884 .06906 Mdot
.884 .06924 Mdot
.884 .0693 Mdot
.884 .06963 Mdot
.884 .06964 Mdot
.884 .0698 Mdot
.884 .06981 Mdot
.884 .06993 Mdot
.884 .07012 Mdot
.884 .07044 Mdot
.884 .07057 Mdot
.884 .07074 Mdot
.884 .07075 Mdot
.884 .07079 Mdot
.884 .07082 Mdot
.884 .07084 Mdot
.884 .07104 Mdot
.884 .07143 Mdot
.884 .0717 Mdot
.884 .07172 Mdot
.884 .07177 Mdot
.884 .07181 Mdot
.884 .07224 Mdot
.884 .07262 Mdot
.884 .07264 Mdot
.884 .07271 Mdot
.884 .07275 Mdot
.884 .07282 Mdot
.884 .07287 Mdot
.884 .07345 Mdot
.884 .07361 Mdot
.884 .07394 Mdot
.884 .0744 Mdot
.884 .07463 Mdot
.884 .07501 Mdot
.884 .07651 Mdot
.884 .07697 Mdot
.884 .07727 Mdot
.884 .07741 Mdot
.884 .07775 Mdot
.884 .0778 Mdot
.884 .07794 Mdot
.884 .07854 Mdot
.884 .07863 Mdot
.884 .08097 Mdot
.884 .08163 Mdot
.884 .08184 Mdot
.884 .08224 Mdot
.884 .08229 Mdot
.884 .08231 Mdot
.884 .08484 Mdot
.884 .08502 Mdot
.884 .08567 Mdot
.884 .08605 Mdot
.884 .08689 Mdot
.884 .08762 Mdot
.884 .08802 Mdot
.884 .08949 Mdot
.884 .09006 Mdot
.884 .09017 Mdot
.884 .09025 Mdot
.884 .09052 Mdot
.884 .09053 Mdot
.884 .0911 Mdot
.884 .09289 Mdot
.884 .09338 Mdot
.884 .09479 Mdot
.884 .09555 Mdot
.884 .09582 Mdot
.884 .09599 Mdot
.884 .09626 Mdot
.884 .09777 Mdot
.884 .09786 Mdot
.884 .09879 Mdot
.884 .09881 Mdot
.884 .09883 Mdot
.884 .09884 Mdot
.884 .09977 Mdot
.884 .10022 Mdot
.884 .10061 Mdot
.884 .10121 Mdot
.884 .10239 Mdot
.884 .10244 Mdot
.884 .10265 Mdot
.884 .10352 Mdot
.884 .10409 Mdot
.884 .10425 Mdot
.884 .10454 Mdot
.884 .10542 Mdot
.884 .10551 Mdot
.884 .10812 Mdot
.884 .1091 Mdot
.884 .11114 Mdot
.884 .11134 Mdot
.884 .11266 Mdot
.884 .11514 Mdot
.884 .1162 Mdot
.884 .11644 Mdot
.884 .11857 Mdot
.884 .11972 Mdot
.884 .11976 Mdot
.884 .12069 Mdot
.884 .1218 Mdot
.884 .12223 Mdot
.884 .12281 Mdot
.884 .12466 Mdot
.884 .12533 Mdot
.884 .1255 Mdot
.884 .12589 Mdot
.884 .12745 Mdot
.884 .12796 Mdot
.884 .12796 Mdot
.884 .12841 Mdot
.884 .12851 Mdot
.884 .13254 Mdot
.884 .13386 Mdot
.884 .13492 Mdot
.884 .13658 Mdot
.884 .13854 Mdot
.884 .13909 Mdot
.884 .14041 Mdot
.884 .14328 Mdot
.884 .14432 Mdot
.884 .1468 Mdot
.884 .14831 Mdot
.884 .15197 Mdot
.884 .15265 Mdot
.884 .15346 Mdot
.884 .15364 Mdot
.884 .15411 Mdot
.884 .15476 Mdot
.884 .15479 Mdot
.884 .15591 Mdot
.884 .15704 Mdot
.884 .15742 Mdot
.884 .15796 Mdot
.884 .15914 Mdot
.884 .15972 Mdot
.884 .16051 Mdot
.884 .16052 Mdot
.884 .16181 Mdot
.884 .1629 Mdot
.884 .16355 Mdot
.884 .16359 Mdot
.884 .16384 Mdot
.884 .16418 Mdot
.884 .16428 Mdot
.884 .16489 Mdot
.884 .16538 Mdot
.884 .16823 Mdot
.884 .17848 Mdot
.884 .17869 Mdot
.884 .18195 Mdot
.884 .18396 Mdot
.884 .1862 Mdot
.884 .18706 Mdot
.884 .19043 Mdot
.884 .19055 Mdot
.884 .19287 Mdot
.884 .19324 Mdot
.884 .19421 Mdot
.884 .19459 Mdot
.884 .19469 Mdot
.884 .19556 Mdot
.884 .19637 Mdot
.884 .19811 Mdot
.884 .19952 Mdot
.884 .20032 Mdot
.884 .20033 Mdot
.884 .20037 Mdot
.884 .20037 Mdot
.884 .2004 Mdot
.884 .20046 Mdot
.884 .20049 Mdot
.884 .20054 Mdot
.884 .20059 Mdot
.884 .20059 Mdot
.884 .20065 Mdot
.884 .20067 Mdot
.884 .20074 Mdot
.884 .20087 Mdot
.884 .20088 Mdot
.884 .20093 Mdot
.884 .20109 Mdot
.884 .20243 Mdot
.884 .20249 Mdot
.884 .20271 Mdot
.884 .20291 Mdot
.884 .20308 Mdot
.884 .20313 Mdot
.884 .20319 Mdot
.884 .20325 Mdot
.884 .20339 Mdot
.884 .20404 Mdot
.884 .20424 Mdot
.884 .20428 Mdot
.884 .20485 Mdot
.884 .20498 Mdot
.884 .20514 Mdot
.884 .20518 Mdot
.884 .20527 Mdot
.884 .20548 Mdot
.884 .20556 Mdot
.884 .20556 Mdot
.884 .20571 Mdot
.884 .20585 Mdot
.884 .20611 Mdot
.884 .20626 Mdot
.884 .20637 Mdot
.884 .20637 Mdot
.884 .20641 Mdot
.884 .20656 Mdot
.884 .20673 Mdot
.884 .20674 Mdot
.884 .20679 Mdot
.884 .20698 Mdot
.884 .20703 Mdot
.884 .20714 Mdot
.884 .20728 Mdot
.884 .20746 Mdot
.884 .20801 Mdot
.884 .20823 Mdot
.884 .20928 Mdot
.884 .20928 Mdot
.884 .20981 Mdot
.884 .20985 Mdot
.884 .21021 Mdot
.884 .21035 Mdot
.884 .21082 Mdot
.884 .21129 Mdot
.884 .21173 Mdot
.884 .21185 Mdot
.884 .21209 Mdot
.884 .21225 Mdot
.884 .2128 Mdot
.884 .21283 Mdot
.884 .21296 Mdot
.884 .21304 Mdot
.884 .2131 Mdot
.884 .21374 Mdot
.884 .21497 Mdot
.884 .21582 Mdot
.884 .21586 Mdot
.884 .21605 Mdot
.884 .21616 Mdot
.884 .21617 Mdot
.884 .2175 Mdot
.884 .21872 Mdot
.884 .21879 Mdot
.884 .219 Mdot
.884 .21912 Mdot
.884 .21932 Mdot
.884 .2195 Mdot
.884 .2197 Mdot
.884 .22032 Mdot
.884 .22131 Mdot
.884 .2218 Mdot
.884 .22275 Mdot
.884 .22284 Mdot
.884 .22425 Mdot
.884 .22428 Mdot
.884 .22498 Mdot
.884 .22618 Mdot
.884 .22689 Mdot
.884 .22933 Mdot
.884 .22944 Mdot
.884 .22985 Mdot
.884 .23082 Mdot
.884 .23223 Mdot
.884 .23314 Mdot
.884 .23358 Mdot
.884 .23437 Mdot
.884 .23464 Mdot
.884 .23467 Mdot
.884 .23479 Mdot
.884 .23521 Mdot
.884 .23706 Mdot
.884 .23733 Mdot
.884 .23805 Mdot
.884 .23871 Mdot
.884 .23977 Mdot
.884 .23984 Mdot
.884 .24328 Mdot
.884 .24427 Mdot
.884 .24444 Mdot
.884 .2448 Mdot
.884 .24551 Mdot
.884 .24625 Mdot
.884 .24646 Mdot
.884 .24688 Mdot
.884 .24707 Mdot
.884 .24762 Mdot
.884 .24802 Mdot
.884 .24827 Mdot
.884 .24844 Mdot
.884 .24851 Mdot
.884 .2488 Mdot
.884 .24906 Mdot
.884 .25345 Mdot
.884 .25497 Mdot
.884 .25607 Mdot
.884 .25661 Mdot
.884 .2583 Mdot
.884 .25834 Mdot
.884 .25853 Mdot
.884 .25875 Mdot
.884 .25943 Mdot
.884 .25959 Mdot
.884 .25966 Mdot
.884 .26077 Mdot
.884 .26214 Mdot
.884 .26269 Mdot
.884 .26367 Mdot
.884 .26429 Mdot
.884 .26548 Mdot
.884 .26724 Mdot
.884 .26909 Mdot
.884 .2696 Mdot
.884 .26976 Mdot
.884 .26985 Mdot
.884 .27015 Mdot
.884 .27063 Mdot
.884 .27074 Mdot
.884 .27142 Mdot
.884 .27176 Mdot
.884 .27197 Mdot
.884 .27276 Mdot
.884 .27278 Mdot
.884 .27279 Mdot
.884 .27333 Mdot
.884 .27338 Mdot
.884 .27427 Mdot
.884 .27444 Mdot
.884 .2747 Mdot
.884 .27635 Mdot
.884 .27807 Mdot
.884 .27812 Mdot
.884 .2782 Mdot
.884 .27858 Mdot
.884 .27959 Mdot
.884 .27988 Mdot
.884 .2804 Mdot
.884 .28101 Mdot
.884 .28178 Mdot
.884 .28191 Mdot
.884 .2839 Mdot
.884 .28392 Mdot
.884 .28503 Mdot
.884 .28711 Mdot
.884 .2872 Mdot
.884 .2879 Mdot
.884 .28795 Mdot
.884 .28842 Mdot
.884 .28872 Mdot
.884 .28919 Mdot
.884 .29079 Mdot
.884 .29149 Mdot
.884 .29203 Mdot
.884 .29244 Mdot
.884 .29263 Mdot
.884 .29337 Mdot
.884 .29344 Mdot
.884 .29352 Mdot
.884 .29357 Mdot
.884 .29369 Mdot
.884 .29421 Mdot
.884 .29481 Mdot
.884 .29486 Mdot
.884 .29495 Mdot
.884 .29497 Mdot
.884 .29536 Mdot
.884 .29595 Mdot
.884 .2963 Mdot
.884 .29635 Mdot
.884 .29641 Mdot
.884 .29643 Mdot
.884 .29692 Mdot
.884 .29748 Mdot
.884 .29803 Mdot
.884 .29805 Mdot
.884 .29836 Mdot
.884 .29836 Mdot
.884 .29901 Mdot
.884 .29915 Mdot
.884 .29951 Mdot
.884 .29963 Mdot
.884 .30024 Mdot
.884 .30027 Mdot
.884 .30076 Mdot
.884 .30094 Mdot
.884 .30134 Mdot
.884 .30293 Mdot
.884 .303 Mdot
.884 .30311 Mdot
.884 .30385 Mdot
.884 .30625 Mdot
.884 .30635 Mdot
.884 .30638 Mdot
.884 .3069 Mdot
.884 .30696 Mdot
.884 .30715 Mdot
.884 .30736 Mdot
.884 .30755 Mdot
.884 .30769 Mdot
.884 .30819 Mdot
.884 .30898 Mdot
.884 .30935 Mdot
.884 .30982 Mdot
.884 .31005 Mdot
.884 .31089 Mdot
.884 .31133 Mdot
.884 .31213 Mdot
.884 .31451 Mdot
.884 .31474 Mdot
.884 .31524 Mdot
.884 .31587 Mdot
.884 .31605 Mdot
.884 .31609 Mdot
.884 .31658 Mdot
.884 .31685 Mdot
.884 .31692 Mdot
.884 .31715 Mdot
.884 .31716 Mdot
.884 .31738 Mdot
.884 .31757 Mdot
.884 .31768 Mdot
.884 .31776 Mdot
.884 .3179 Mdot
.884 .31802 Mdot
.884 .31803 Mdot
.884 .31806 Mdot
.884 .31819 Mdot
.884 .31823 Mdot
.884 .32022 Mdot
.884 .32132 Mdot
.884 .32176 Mdot
.884 .32437 Mdot
.884 .32681 Mdot
.884 .32975 Mdot
.884 .33027 Mdot
.884 .33357 Mdot
.884 .33374 Mdot
.884 .33407 Mdot
.884 .33674 Mdot
.884 .34014 Mdot
.884 .34015 Mdot
.884 .34053 Mdot
.884 .34199 Mdot
.884 .34287 Mdot
.884 .3435 Mdot
.884 .34527 Mdot
.884 .3458 Mdot
.884 .34726 Mdot
.884 .34889 Mdot
.884 .35029 Mdot
.884 .35181 Mdot
.884 .35191 Mdot
.884 .35424 Mdot
.884 .35587 Mdot
.884 .35631 Mdot
.884 .35681 Mdot
.884 .357 Mdot
.884 .35808 Mdot
.884 .3595 Mdot
.884 .36239 Mdot
.884 .36384 Mdot
.884 .36406 Mdot
.884 .3657 Mdot
.884 .3661 Mdot
.884 .36705 Mdot
.884 .36762 Mdot
.884 .37 Mdot
.884 .37082 Mdot
.884 .37206 Mdot
.884 .37206 Mdot
.884 .3729 Mdot
.884 .37313 Mdot
.884 .37314 Mdot
.884 .37335 Mdot
.884 .37338 Mdot
.884 .38205 Mdot
.884 .38209 Mdot
.884 .38294 Mdot
.884 .386 Mdot
.884 .38661 Mdot
.884 .38847 Mdot
.884 .38992 Mdot
.884 .39096 Mdot
.884 .39228 Mdot
.884 .3939 Mdot
.884 .39642 Mdot
.884 .39674 Mdot
.884 .39798 Mdot
.884 .39813 Mdot
.884 .40095 Mdot
.884 .40254 Mdot
.884 .40333 Mdot
.884 .40479 Mdot
.884 .40593 Mdot
.884 .4072 Mdot
.884 .40723 Mdot
.884 .40734 Mdot
.884 .4096 Mdot
.884 .41164 Mdot
.884 .41256 Mdot
.884 .41323 Mdot
.884 .41499 Mdot
.884 .4176 Mdot
.884 .41767 Mdot
.884 .41823 Mdot
.884 .42179 Mdot
.884 .42466 Mdot
.884 .42594 Mdot
.884 .42725 Mdot
.884 .42737 Mdot
.884 .42903 Mdot
.884 .4294 Mdot
.884 .43037 Mdot
.884 .43172 Mdot
.884 .43178 Mdot
.884 .43406 Mdot
.884 .43523 Mdot
.884 .43635 Mdot
.884 .43711 Mdot
.884 .43776 Mdot
.884 .4382 Mdot
.884 .43993 Mdot
.884 .44022 Mdot
.884 .44055 Mdot
.884 .44056 Mdot
.884 .44171 Mdot
.884 .44195 Mdot
.884 .44213 Mdot
.884 .44327 Mdot
.884 .44329 Mdot
.884 .44437 Mdot
.884 .44513 Mdot
.884 .44582 Mdot
.884 .44794 Mdot
.884 .44862 Mdot
.884 .44921 Mdot
.884 .44928 Mdot
.884 .44937 Mdot
.884 .44975 Mdot
.884 .45041 Mdot
.884 .45061 Mdot
.884 .45156 Mdot
.884 .45177 Mdot
.884 .45237 Mdot
.884 .45259 Mdot
.884 .45272 Mdot
.884 .45283 Mdot
.884 .45325 Mdot
.884 .45439 Mdot
.884 .45478 Mdot
.884 .45657 Mdot
.884 .45696 Mdot
.884 .4581 Mdot
.884 .45819 Mdot
.884 .45889 Mdot
.884 .45906 Mdot
.884 .45921 Mdot
.884 .46029 Mdot
.884 .46154 Mdot
.884 .46544 Mdot
.884 .46668 Mdot
.884 .46804 Mdot
.884 .46998 Mdot
.884 .47002 Mdot
.884 .47205 Mdot
.884 .47236 Mdot
.884 .47278 Mdot
.884 .47479 Mdot
.884 .47481 Mdot
.884 .47539 Mdot
.884 .4759 Mdot
.884 .47656 Mdot
.884 .47691 Mdot
.884 .47888 Mdot
.884 .47964 Mdot
.884 .48075 Mdot
.884 .48203 Mdot
.884 .48248 Mdot
.884 .48391 Mdot
.884 .48585 Mdot
.884 .48587 Mdot
.884 .48954 Mdot
.884 .48962 Mdot
.884 .48972 Mdot
.884 .49093 Mdot
.884 .49191 Mdot
.884 .49346 Mdot
.884 .49405 Mdot
.884 .49631 Mdot
.884 .49651 Mdot
.884 .49669 Mdot
.884 .49687 Mdot
.884 .49891 Mdot
.884 .50011 Mdot
.884 .50068 Mdot
.884 .50089 Mdot
.884 .50218 Mdot
.884 .50275 Mdot
.884 .5029 Mdot
.884 .50421 Mdot
.884 .50524 Mdot
.884 .50543 Mdot
.884 .50801 Mdot
.884 .51007 Mdot
.884 .51049 Mdot
.884 .51123 Mdot
.884 .51124 Mdot
.884 .51129 Mdot
.884 .5113 Mdot
.884 .51131 Mdot
.884 .51135 Mdot
.884 .5114 Mdot
.884 .51143 Mdot
.884 .51148 Mdot
.884 .51155 Mdot
.884 .51163 Mdot
.884 .51163 Mdot
.884 .51172 Mdot
.884 .51174 Mdot
.884 .51184 Mdot
.884 .51203 Mdot
.884 .51204 Mdot
.884 .51211 Mdot
.884 .51234 Mdot
.884 .51426 Mdot
.884 .51434 Mdot
.884 .51465 Mdot
.884 .51493 Mdot
.884 .51512 Mdot
.884 .51517 Mdot
.884 .51524 Mdot
.884 .51532 Mdot
.884 .51541 Mdot
.884 .51561 Mdot
.884 .51652 Mdot
.884 .51678 Mdot
.884 .51685 Mdot
.884 .51757 Mdot
.884 .51763 Mdot
.884 .51782 Mdot
.884 .51804 Mdot
.884 .51809 Mdot
.884 .51822 Mdot
.884 .5185 Mdot
.884 .5185 Mdot
.884 .51861 Mdot
.884 .51862 Mdot
.884 .51882 Mdot
.884 .51902 Mdot
.884 .51936 Mdot
.884 .51958 Mdot
.884 .51972 Mdot
.884 .51972 Mdot
.884 .51975 Mdot
.884 .51977 Mdot
.884 .51999 Mdot
.884 .52022 Mdot
.884 .52023 Mdot
.884 .52029 Mdot
.884 .52055 Mdot
.884 .52062 Mdot
.884 .52076 Mdot
.884 .52096 Mdot
.884 .52121 Mdot
.884 .52194 Mdot
.884 .52223 Mdot
.884 .52251 Mdot
.884 .52363 Mdot
.884 .52364 Mdot
.884 .52433 Mdot
.884 .52438 Mdot
.884 .52486 Mdot
.884 .52504 Mdot
.884 .5255 Mdot
.884 .52563 Mdot
.884 .52566 Mdot
.884 .52567 Mdot
.884 .52627 Mdot
.884 .52684 Mdot
.884 .52699 Mdot
.884 .5273 Mdot
.884 .52732 Mdot
.884 .52751 Mdot
.884 .52821 Mdot
.884 .52825 Mdot
.884 .52841 Mdot
.884 .52851 Mdot
.884 .5286 Mdot
.884 .52877 Mdot
.884 .52941 Mdot
.884 .53062 Mdot
.884 .53096 Mdot
.884 .53161 Mdot
.884 .532 Mdot
.884 .53206 Mdot
.884 .53229 Mdot
.884 .53243 Mdot
.884 .53244 Mdot
.884 .53356 Mdot
.884 .53407 Mdot
.884 .53554 Mdot
.884 .53562 Mdot
.884 .53588 Mdot
.884 .53601 Mdot
.884 .53626 Mdot
.884 .53647 Mdot
.884 .53671 Mdot
.884 .53695 Mdot
.884 .53712 Mdot
.884 .53745 Mdot
.884 .53858 Mdot
.884 .5386 Mdot
.884 .53895 Mdot
.884 .53917 Mdot
.884 .54027 Mdot
.884 .54037 Mdot
.884 .54184 Mdot
.884 .54197 Mdot
.884 .542 Mdot
.884 .54279 Mdot
.884 .54364 Mdot
.884 .54412 Mdot
.884 .5449 Mdot
.884 .5451 Mdot
.884 .54622 Mdot
.884 .54751 Mdot
.884 .54762 Mdot
.884 .54776 Mdot
.884 .54806 Mdot
.884 .54907 Mdot
.884 .5497 Mdot
.884 .55032 Mdot
.884 .55052 Mdot
.884 .55145 Mdot
.884 .55189 Mdot
.884 .55243 Mdot
.884 .55268 Mdot
.884 .55295 Mdot
.884 .55298 Mdot
.884 .55309 Mdot
.884 .55339 Mdot
.884 .55351 Mdot
.884 .55422 Mdot
.884 .55426 Mdot
.884 .55529 Mdot
.884 .55555 Mdot
.884 .55624 Mdot
.884 .55685 Mdot
.884 .55784 Mdot
.884 .5579 Mdot
.884 .56098 Mdot
.884 .56183 Mdot
.884 .56198 Mdot
.884 .56216 Mdot
.884 .56219 Mdot
.884 .56229 Mdot
.884 .56237 Mdot
.884 .56238 Mdot
.884 .56257 Mdot
.884 .5629 Mdot
.884 .56328 Mdot
.884 .56328 Mdot
.884 .56351 Mdot
.884 .56369 Mdot
.884 .56403 Mdot
.884 .56419 Mdot
.884 .56431 Mdot
.884 .56464 Mdot
.884 .56497 Mdot
.884 .56498 Mdot
.884 .56517 Mdot
.884 .56531 Mdot
.884 .56536 Mdot
.884 .5656 Mdot
.884 .5658 Mdot
.884 .56687 Mdot
.884 .56731 Mdot
.884 .56803 Mdot
.884 .56833 Mdot
.884 .56917 Mdot
.884 .56955 Mdot
.884 .56971 Mdot
.884 .57027 Mdot
.884 .57075 Mdot
.884 .57106 Mdot
.884 .57144 Mdot
.884 .57259 Mdot
.884 .57262 Mdot
.884 .57275 Mdot
.884 .57275 Mdot
.884 .57289 Mdot
.884 .57334 Mdot
.884 .57345 Mdot
.884 .5735 Mdot
.884 .57369 Mdot
.884 .57421 Mdot
.884 .57438 Mdot
.884 .5745 Mdot
.884 .57481 Mdot
.884 .57508 Mdot
.884 .57509 Mdot
.884 .57542 Mdot
.884 .57602 Mdot
.884 .57609 Mdot
.884 .57638 Mdot
.884 .57708 Mdot
.884 .57745 Mdot
.884 .57751 Mdot
.884 .57808 Mdot
.884 .57835 Mdot
.884 .57908 Mdot
.884 .57911 Mdot
.884 .57935 Mdot
.884 .57943 Mdot
.884 .57948 Mdot
.884 .57964 Mdot
.884 .57988 Mdot
.884 .57994 Mdot
.884 .57995 Mdot
.884 .58028 Mdot
.884 .58045 Mdot
.884 .58055 Mdot
.884 .58068 Mdot
.884 .58094 Mdot
.884 .58094 Mdot
.884 .58095 Mdot
.884 .58095 Mdot
.884 .58121 Mdot
.884 .58123 Mdot
.884 .58165 Mdot
.884 .58173 Mdot
.884 .58177 Mdot
.884 .58185 Mdot
.884 .58206 Mdot
.884 .58244 Mdot
.884 .58258 Mdot
.884 .58307 Mdot
.884 .58323 Mdot
.884 .58323 Mdot
.884 .58331 Mdot
.884 .58333 Mdot
.884 .58336 Mdot
.884 .58352 Mdot
.884 .58392 Mdot
.884 .58403 Mdot
.884 .58423 Mdot
.884 .58446 Mdot
.884 .58456 Mdot
.884 .58474 Mdot
.884 .58479 Mdot
.884 .58548 Mdot
.884 .58548 Mdot
.884 .5855 Mdot
.884 .58561 Mdot
.884 .58566 Mdot
.884 .58584 Mdot
.884 .58648 Mdot
.884 .5865 Mdot
.884 .58667 Mdot
.884 .5867 Mdot
.884 .58672 Mdot
.884 .58681 Mdot
.884 .58685 Mdot
.884 .58693 Mdot
.884 .58705 Mdot
.884 .58746 Mdot
.884 .58756 Mdot
.884 .58762 Mdot
.884 .58775 Mdot
.884 .58784 Mdot
.884 .58788 Mdot
.884 .58804 Mdot
.884 .58805 Mdot
.884 .58807 Mdot
.884 .58808 Mdot
.884 .5881 Mdot
.884 .5881 Mdot
.884 .58821 Mdot
.884 .58832 Mdot
.884 .58833 Mdot
.884 .58835 Mdot
.884 .58835 Mdot
.884 .58843 Mdot
.884 .58853 Mdot
.884 .58859 Mdot
.884 .58859 Mdot
.884 .5886 Mdot
.884 .58861 Mdot
.884 .58861 Mdot
.884 .58866 Mdot
.884 .58869 Mdot
.884 .58878 Mdot
.884 .58883 Mdot
.884 .58886 Mdot
.884 .58887 Mdot
.884 .58891 Mdot
.884 .58891 Mdot
.884 .589 Mdot
.884 .58902 Mdot
.884 .58906 Mdot
.884 .58908 Mdot
.884 .5891 Mdot
.884 .5891 Mdot
.884 .58912 Mdot
.884 .58912 Mdot
.884 .58913 Mdot
.884 .58914 Mdot
.884 .58915 Mdot
.884 .58916 Mdot
.884 .58916 Mdot
.884 .58916 Mdot
.884 .58918 Mdot
.884 .5892 Mdot
.884 .58921 Mdot
.884 .58922 Mdot
.884 .58922 Mdot
.884 .58923 Mdot
.884 .58925 Mdot
.884 .58926 Mdot
.884 .58927 Mdot
.884 .58928 Mdot
.884 .58933 Mdot
.884 .58934 Mdot
.884 .58935 Mdot
.884 .58941 Mdot
.884 .58942 Mdot
.884 .58942 Mdot
.884 .58943 Mdot
.884 .58945 Mdot
.884 .58946 Mdot
.884 .58949 Mdot
.884 .5896 Mdot
.884 .58961 Mdot
.884 .58962 Mdot
.884 .58962 Mdot
.884 .58963 Mdot
.884 .58963 Mdot
.884 .58964 Mdot
.884 .58964 Mdot
.884 .58964 Mdot
.884 .58965 Mdot
.884 .58965 Mdot
.884 .58965 Mdot
.884 .58966 Mdot
.884 .58966 Mdot
.884 .58966 Mdot
.884 .58966 Mdot
.884 .58966 Mdot
.886 .06598 Mdot
.886 .06599 Mdot
.886 .06599 Mdot
.886 .066 Mdot
.886 .06602 Mdot
.886 .06603 Mdot
.886 .06604 Mdot
.886 .0661 Mdot
.886 .0661 Mdot
.886 .06612 Mdot
.886 .0662 Mdot
.886 .06626 Mdot
.886 .06626 Mdot
.886 .06631 Mdot
.886 .06634 Mdot
.886 .06648 Mdot
.886 .06664 Mdot
.886 .06689 Mdot
.886 .06696 Mdot
.886 .06697 Mdot
.886 .067 Mdot
.886 .0671 Mdot
.886 .06715 Mdot
.886 .06724 Mdot
.886 .06734 Mdot
.886 .06738 Mdot
.886 .06742 Mdot
.886 .06745 Mdot
.886 .06781 Mdot
.886 .06783 Mdot
.886 .06813 Mdot
.886 .06827 Mdot
.886 .06871 Mdot
.886 .06889 Mdot
.886 .06915 Mdot
.886 .06943 Mdot
.886 .06947 Mdot
.886 .0695 Mdot
.886 .06977 Mdot
.886 .0699 Mdot
.886 .07006 Mdot
.886 .07096 Mdot
.886 .07113 Mdot
.886 .07121 Mdot
.886 .07127 Mdot
.886 .07134 Mdot
.886 .07152 Mdot
.886 .07187 Mdot
.886 .07201 Mdot
.886 .07203 Mdot
.886 .0726 Mdot
.886 .07305 Mdot
.886 .07346 Mdot
.886 .07369 Mdot
.886 .07372 Mdot
.886 .07379 Mdot
.886 .07385 Mdot
.886 .07415 Mdot
.886 .07425 Mdot
.886 .07435 Mdot
.886 .07438 Mdot
.886 .0745 Mdot
.886 .07454 Mdot
.886 .07474 Mdot
.886 .07489 Mdot
.886 .07494 Mdot
.886 .07504 Mdot
.886 .0755 Mdot
.886 .07567 Mdot
.886 .07587 Mdot
.886 .07606 Mdot
.886 .07618 Mdot
.886 .07829 Mdot
.886 .07903 Mdot
.886 .07951 Mdot
.886 .07955 Mdot
.886 .07986 Mdot
.886 .0801 Mdot
.886 .08039 Mdot
.886 .08052 Mdot
.886 .08061 Mdot
.886 .08141 Mdot
.886 .08277 Mdot
.886 .08331 Mdot
.886 .08373 Mdot
.886 .08463 Mdot
.886 .08584 Mdot
.886 .08612 Mdot
.886 .08646 Mdot
.886 .08676 Mdot
.886 .08741 Mdot
.886 .08742 Mdot
.886 .08852 Mdot
.886 .0895 Mdot
.886 .08956 Mdot
.886 .09006 Mdot
.886 .09075 Mdot
.886 .09088 Mdot
.886 .09108 Mdot
.886 .09385 Mdot
.886 .09509 Mdot
.886 .09608 Mdot
.886 .09671 Mdot
.886 .09813 Mdot
.886 .09822 Mdot
.886 .10021 Mdot
.886 .10101 Mdot
.886 .10285 Mdot
.886 .10304 Mdot
.886 .10318 Mdot
.886 .10417 Mdot
.886 .1046 Mdot
.886 .10754 Mdot
.886 .10794 Mdot
.886 .10802 Mdot
.886 .10876 Mdot
.886 .11 Mdot
.886 .11017 Mdot
.886 .11214 Mdot
.886 .11316 Mdot
.886 .11405 Mdot
.886 .11413 Mdot
.886 .11422 Mdot
.886 .11448 Mdot
.886 .11505 Mdot
.886 .11535 Mdot
.886 .11538 Mdot
.886 .11544 Mdot
.886 .11711 Mdot
.886 .11851 Mdot
.886 .1196 Mdot
.886 .12039 Mdot
.886 .12046 Mdot
.886 .12057 Mdot
.886 .12156 Mdot
.886 .12186 Mdot
.886 .12209 Mdot
.886 .12343 Mdot
.886 .1239 Mdot
.886 .12425 Mdot
.886 .12453 Mdot
.886 .12492 Mdot
.886 .12582 Mdot
.886 .12612 Mdot
.886 .127 Mdot
.886 .13118 Mdot
.886 .13141 Mdot
.886 .13155 Mdot
.886 .1323 Mdot
.886 .13359 Mdot
.886 .13372 Mdot
.886 .13404 Mdot
.886 .13442 Mdot
.886 .13526 Mdot
.886 .13543 Mdot
.886 .13585 Mdot
.886 .13602 Mdot
.886 .13615 Mdot
.886 .13672 Mdot
.886 .1379 Mdot
.886 .13797 Mdot
.886 .13822 Mdot
.886 .1403 Mdot
.886 .14062 Mdot
.886 .1412 Mdot
.886 .14449 Mdot
.886 .1455 Mdot
.886 .14603 Mdot
.886 .14797 Mdot
.886 .1488 Mdot
.886 .1498 Mdot
.886 .15294 Mdot
.886 .15373 Mdot
.886 .16007 Mdot
.886 .16141 Mdot
.886 .16346 Mdot
.886 .16371 Mdot
.886 .16705 Mdot
.886 .1671 Mdot
.886 .16757 Mdot
.886 .16782 Mdot
.886 .16804 Mdot
.886 .16838 Mdot
.886 .16902 Mdot
.886 .17159 Mdot
.886 .17186 Mdot
.886 .17375 Mdot
.886 .17446 Mdot
.886 .1766 Mdot
.886 .17697 Mdot
.886 .17993 Mdot
.886 .18096 Mdot
.886 .18152 Mdot
.886 .18302 Mdot
.886 .18312 Mdot
.886 .1847 Mdot
.886 .18572 Mdot
.886 .18576 Mdot
.886 .1885 Mdot
.886 .18897 Mdot
.886 .18994 Mdot
.886 .19127 Mdot
.886 .19197 Mdot
.886 .19242 Mdot
.886 .19391 Mdot
.886 .19462 Mdot
.886 .19479 Mdot
.886 .19499 Mdot
.886 .19765 Mdot
.886 .19768 Mdot
.886 .19769 Mdot
.886 .19773 Mdot
.886 .19779 Mdot
.886 .1978 Mdot
.886 .19784 Mdot
.886 .19802 Mdot
.886 .19803 Mdot
.886 .1981 Mdot
.886 .19836 Mdot
.886 .19855 Mdot
.886 .19856 Mdot
.886 .19872 Mdot
.886 .19881 Mdot
.886 .19927 Mdot
.886 .19952 Mdot
.886 .19978 Mdot
.886 .20059 Mdot
.886 .20067 Mdot
.886 .20081 Mdot
.886 .20085 Mdot
.886 .20095 Mdot
.886 .20096 Mdot
.886 .20101 Mdot
.886 .20124 Mdot
.886 .20142 Mdot
.886 .20171 Mdot
.886 .20196 Mdot
.886 .20202 Mdot
.886 .20217 Mdot
.886 .2023 Mdot
.886 .2024 Mdot
.886 .20355 Mdot
.886 .20358 Mdot
.886 .20444 Mdot
.886 .20457 Mdot
.886 .20501 Mdot
.886 .20509 Mdot
.886 .20642 Mdot
.886 .207 Mdot
.886 .20733 Mdot
.886 .20781 Mdot
.886 .20872 Mdot
.886 .20885 Mdot
.886 .20891 Mdot
.886 .20894 Mdot
.886 .20962 Mdot
.886 .2098 Mdot
.886 .21021 Mdot
.886 .21072 Mdot
.886 .21081 Mdot
.886 .21257 Mdot
.886 .21286 Mdot
.886 .21355 Mdot
.886 .21356 Mdot
.886 .21385 Mdot
.886 .21411 Mdot
.886 .21436 Mdot
.886 .21453 Mdot
.886 .21475 Mdot
.886 .21492 Mdot
.886 .21517 Mdot
.886 .21533 Mdot
.886 .21644 Mdot
.886 .2167 Mdot
.886 .21687 Mdot
.886 .21689 Mdot
.886 .21694 Mdot
.886 .21797 Mdot
.886 .21842 Mdot
.886 .21874 Mdot
.886 .21958 Mdot
.886 .21978 Mdot
.886 .2198 Mdot
.886 .22013 Mdot
.886 .22025 Mdot
.886 .22082 Mdot
.886 .22142 Mdot
.886 .22162 Mdot
.886 .22215 Mdot
.886 .22224 Mdot
.886 .22246 Mdot
.886 .22265 Mdot
.886 .22267 Mdot
.886 .22268 Mdot
.886 .22321 Mdot
.886 .22357 Mdot
.886 .2239 Mdot
.886 .22421 Mdot
.886 .22429 Mdot
.886 .22467 Mdot
.886 .2248 Mdot
.886 .22482 Mdot
.886 .22506 Mdot
.886 .22534 Mdot
.886 .22541 Mdot
.886 .22588 Mdot
.886 .22603 Mdot
.886 .22604 Mdot
.886 .22634 Mdot
.886 .22687 Mdot
.886 .22694 Mdot
.886 .22741 Mdot
.886 .22773 Mdot
.886 .22778 Mdot
.886 .22831 Mdot
.886 .22871 Mdot
.886 .22892 Mdot
.886 .22901 Mdot
.886 .22953 Mdot
.886 .22988 Mdot
.886 .2301 Mdot
.886 .23125 Mdot
.886 .23249 Mdot
.886 .23435 Mdot
.886 .23441 Mdot
.886 .23446 Mdot
.886 .23468 Mdot
.886 .23515 Mdot
.886 .23529 Mdot
.886 .23593 Mdot
.886 .23624 Mdot
.886 .23639 Mdot
.886 .23726 Mdot
.886 .23811 Mdot
.886 .23863 Mdot
.886 .23881 Mdot
.886 .24012 Mdot
.886 .24024 Mdot
.886 .24095 Mdot
.886 .24119 Mdot
.886 .24182 Mdot
.886 .24191 Mdot
.886 .24278 Mdot
.886 .243 Mdot
.886 .24319 Mdot
.886 .24344 Mdot
.886 .24345 Mdot
.886 .24461 Mdot
.886 .2447 Mdot
.886 .24541 Mdot
.886 .24588 Mdot
.886 .24844 Mdot
.886 .24959 Mdot
.886 .24997 Mdot
.886 .25121 Mdot
.886 .25159 Mdot
.886 .25285 Mdot
.886 .25412 Mdot
.886 .2549 Mdot
.886 .25497 Mdot
.886 .25513 Mdot
.886 .2552 Mdot
.886 .25554 Mdot
.886 .25583 Mdot
.886 .25671 Mdot
.886 .25677 Mdot
.886 .25913 Mdot
.886 .25996 Mdot
.886 .26086 Mdot
.886 .26099 Mdot
.886 .26143 Mdot
.886 .26151 Mdot
.886 .26187 Mdot
.886 .26236 Mdot
.886 .26301 Mdot
.886 .26378 Mdot
.886 .26381 Mdot
.886 .26382 Mdot
.886 .26436 Mdot
.886 .26444 Mdot
.886 .26535 Mdot
.886 .26632 Mdot
.886 .26702 Mdot
.886 .26739 Mdot
.886 .26743 Mdot
.886 .26991 Mdot
.886 .26998 Mdot
.886 .27009 Mdot
.886 .27109 Mdot
.886 .27153 Mdot
.886 .27353 Mdot
.886 .2739 Mdot
.886 .27449 Mdot
.886 .27765 Mdot
.886 .2799 Mdot
.886 .28145 Mdot
.886 .28213 Mdot
.886 .28245 Mdot
.886 .28396 Mdot
.886 .2847 Mdot
.886 .28481 Mdot
.886 .28505 Mdot
.886 .28556 Mdot
.886 .28599 Mdot
.886 .28867 Mdot
.886 .28879 Mdot
.886 .28899 Mdot
.886 .28919 Mdot
.886 .28936 Mdot
.886 .29056 Mdot
.886 .29082 Mdot
.886 .29122 Mdot
.886 .29209 Mdot
.886 .29429 Mdot
.886 .29457 Mdot
.886 .29482 Mdot
.886 .29707 Mdot
.886 .29938 Mdot
.886 .29967 Mdot
.886 .30037 Mdot
.886 .30136 Mdot
.886 .30147 Mdot
.886 .30187 Mdot
.886 .30257 Mdot
.886 .30517 Mdot
.886 .30532 Mdot
.886 .30599 Mdot
.886 .30757 Mdot
.886 .30763 Mdot
.886 .30816 Mdot
.886 .30855 Mdot
.886 .30976 Mdot
.886 .31013 Mdot
.886 .31063 Mdot
.886 .31123 Mdot
.886 .31125 Mdot
.886 .31143 Mdot
.886 .31241 Mdot
.886 .31242 Mdot
.886 .31354 Mdot
.886 .31421 Mdot
.886 .3151 Mdot
.886 .31532 Mdot
.886 .31537 Mdot
.886 .31575 Mdot
.886 .31591 Mdot
.886 .31643 Mdot
.886 .31675 Mdot
.886 .31764 Mdot
.886 .31954 Mdot
.886 .31988 Mdot
.886 .32035 Mdot
.886 .32084 Mdot
.886 .32091 Mdot
.886 .32141 Mdot
.886 .32162 Mdot
.886 .32187 Mdot
.886 .32358 Mdot
.886 .32365 Mdot
.886 .324 Mdot
.886 .32447 Mdot
.886 .32465 Mdot
.886 .32467 Mdot
.886 .3254 Mdot
.886 .32643 Mdot
.886 .3267 Mdot
.886 .32673 Mdot
.886 .32688 Mdot
.886 .32733 Mdot
.886 .32744 Mdot
.886 .3276 Mdot
.886 .32765 Mdot
.886 .32787 Mdot
.886 .32803 Mdot
.886 .32808 Mdot
.886 .32818 Mdot
.886 .33138 Mdot
.886 .33251 Mdot
.886 .33277 Mdot
.886 .33341 Mdot
.886 .33516 Mdot
.886 .33747 Mdot
.886 .33767 Mdot
.886 .33792 Mdot
.886 .33859 Mdot
.886 .33859 Mdot
.886 .33935 Mdot
.886 .34001 Mdot
.886 .34005 Mdot
.886 .34083 Mdot
.886 .34091 Mdot
.886 .34105 Mdot
.886 .34279 Mdot
.886 .34533 Mdot
.886 .34538 Mdot
.886 .34865 Mdot
.886 .34888 Mdot
.886 .3504 Mdot
.886 .35163 Mdot
.886 .35317 Mdot
.886 .35363 Mdot
.886 .3538 Mdot
.886 .35407 Mdot
.886 .35655 Mdot
.886 .35728 Mdot
.886 .35787 Mdot
.886 .35835 Mdot
.886 .35852 Mdot
.886 .35903 Mdot
.886 .35941 Mdot
.886 .36117 Mdot
.886 .36163 Mdot
.886 .36215 Mdot
.886 .36234 Mdot
.886 .36319 Mdot
.886 .36342 Mdot
.886 .36388 Mdot
.886 .36401 Mdot
.886 .36483 Mdot
.886 .36495 Mdot
.886 .36703 Mdot
.886 .36776 Mdot
.886 .36988 Mdot
.886 .37475 Mdot
.886 .37492 Mdot
.886 .37889 Mdot
.886 .37989 Mdot
.886 .38043 Mdot
.886 .38076 Mdot
.886 .38252 Mdot
.886 .38508 Mdot
.886 .38544 Mdot
.886 .38553 Mdot
.886 .38583 Mdot
.886 .38659 Mdot
.886 .38746 Mdot
.886 .38941 Mdot
.886 .3898 Mdot
.886 .39075 Mdot
.886 .39115 Mdot
.886 .39129 Mdot
.886 .39146 Mdot
.886 .39277 Mdot
.886 .39346 Mdot
.886 .39544 Mdot
.886 .39562 Mdot
.886 .39617 Mdot
.886 .39745 Mdot
.886 .40086 Mdot
.886 .40108 Mdot
.886 .40157 Mdot
.886 .40288 Mdot
.886 .40365 Mdot
.886 .40889 Mdot
.886 .41014 Mdot
.886 .41027 Mdot
.886 .41032 Mdot
.886 .41081 Mdot
.886 .41234 Mdot
.886 .41349 Mdot
.886 .41466 Mdot
.886 .41507 Mdot
.886 .41767 Mdot
.886 .41816 Mdot
.886 .4185 Mdot
.886 .41943 Mdot
.886 .4212 Mdot
.886 .42156 Mdot
.886 .42172 Mdot
.886 .42478 Mdot
.886 .42813 Mdot
.886 .42826 Mdot
.886 .42836 Mdot
.886 .42892 Mdot
.886 .42938 Mdot
.886 .42977 Mdot
.886 .43903 Mdot
.886 .4397 Mdot
.886 .44142 Mdot
.886 .44156 Mdot
.886 .44256 Mdot
.886 .44267 Mdot
.886 .44348 Mdot
.886 .44442 Mdot
.886 .44522 Mdot
.886 .44614 Mdot
.886 .44632 Mdot
.886 .44919 Mdot
.886 .4497 Mdot
.886 .45606 Mdot
.886 .45615 Mdot
.886 .45703 Mdot
.886 .4575 Mdot
.886 .45791 Mdot
.886 .45847 Mdot
.886 .45854 Mdot
.886 .45941 Mdot
.886 .45974 Mdot
.886 .46449 Mdot
.886 .46471 Mdot
.886 .46498 Mdot
.886 .46503 Mdot
.886 .4667 Mdot
.886 .46815 Mdot
.886 .4684 Mdot
.886 .46967 Mdot
.886 .46983 Mdot
.886 .47127 Mdot
.886 .47146 Mdot
.886 .47324 Mdot
.886 .47346 Mdot
.886 .47348 Mdot
.886 .47411 Mdot
.886 .47649 Mdot
.886 .47764 Mdot
.886 .47925 Mdot
.886 .48101 Mdot
.886 .48195 Mdot
.886 .48448 Mdot
.886 .48464 Mdot
.886 .48727 Mdot
.886 .48894 Mdot
.886 .48901 Mdot
.886 .49306 Mdot
.886 .49345 Mdot
.886 .49369 Mdot
.886 .49421 Mdot
.886 .49442 Mdot
.886 .49532 Mdot
.886 .49547 Mdot
.886 .49568 Mdot
.886 .49575 Mdot
.886 .49782 Mdot
.886 .49892 Mdot
.886 .49962 Mdot
.886 .5009 Mdot
.886 .50192 Mdot
.886 .503 Mdot
.886 .50326 Mdot
.886 .50355 Mdot
.886 .50555 Mdot
.886 .50579 Mdot
.886 .50632 Mdot
.886 .50754 Mdot
.886 .50758 Mdot
.886 .5076 Mdot
.886 .50766 Mdot
.886 .50774 Mdot
.886 .50776 Mdot
.886 .50782 Mdot
.886 .50809 Mdot
.886 .5081 Mdot
.886 .5082 Mdot
.886 .50859 Mdot
.886 .50886 Mdot
.886 .50887 Mdot
.886 .50894 Mdot
.886 .50912 Mdot
.886 .50925 Mdot
.886 .50992 Mdot
.886 .51028 Mdot
.886 .5103 Mdot
.886 .51066 Mdot
.886 .51079 Mdot
.886 .5115 Mdot
.886 .51183 Mdot
.886 .51194 Mdot
.886 .51214 Mdot
.886 .5122 Mdot
.886 .51234 Mdot
.886 .51236 Mdot
.886 .51244 Mdot
.886 .51277 Mdot
.886 .51301 Mdot
.886 .51343 Mdot
.886 .51379 Mdot
.886 .51387 Mdot
.886 .51409 Mdot
.886 .51427 Mdot
.886 .51441 Mdot
.886 .5152 Mdot
.886 .51578 Mdot
.886 .51603 Mdot
.886 .51608 Mdot
.886 .51728 Mdot
.886 .51742 Mdot
.886 .51746 Mdot
.886 .51807 Mdot
.886 .51818 Mdot
.886 .51901 Mdot
.886 .52 Mdot
.886 .52078 Mdot
.886 .52109 Mdot
.886 .52124 Mdot
.886 .52175 Mdot
.886 .52181 Mdot
.886 .52189 Mdot
.886 .522 Mdot
.886 .52309 Mdot
.886 .52327 Mdot
.886 .52336 Mdot
.886 .5234 Mdot
.886 .52366 Mdot
.886 .5243 Mdot
.886 .52453 Mdot
.886 .52507 Mdot
.886 .52573 Mdot
.886 .52586 Mdot
.886 .52812 Mdot
.886 .5285 Mdot
.886 .52938 Mdot
.886 .52939 Mdot
.886 .52976 Mdot
.886 .53009 Mdot
.886 .5304 Mdot
.886 .53043 Mdot
.886 .53061 Mdot
.886 .53088 Mdot
.886 .5311 Mdot
.886 .53139 Mdot
.886 .53142 Mdot
.886 .53161 Mdot
.886 .53299 Mdot
.886 .53301 Mdot
.886 .53331 Mdot
.886 .53352 Mdot
.886 .53354 Mdot
.886 .53359 Mdot
.886 .53362 Mdot
.886 .53388 Mdot
.886 .53485 Mdot
.886 .53539 Mdot
.886 .53577 Mdot
.886 .53678 Mdot
.886 .53701 Mdot
.886 .53704 Mdot
.886 .53743 Mdot
.886 .53757 Mdot
.886 .53796 Mdot
.886 .53825 Mdot
.886 .53895 Mdot
.886 .53918 Mdot
.886 .53945 Mdot
.886 .53979 Mdot
.886 .53989 Mdot
.886 .5401 Mdot
.886 .54014 Mdot
.886 .5403 Mdot
.886 .54037 Mdot
.886 .54038 Mdot
.886 .5404 Mdot
.886 .54101 Mdot
.886 .54141 Mdot
.886 .54178 Mdot
.886 .54214 Mdot
.886 .54223 Mdot
.886 .54255 Mdot
.886 .54265 Mdot
.886 .5428 Mdot
.886 .54282 Mdot
.886 .54309 Mdot
.886 .54332 Mdot
.886 .54341 Mdot
.886 .54348 Mdot
.886 .544 Mdot
.886 .54417 Mdot
.886 .54417 Mdot
.886 .54451 Mdot
.886 .54476 Mdot
.886 .54495 Mdot
.886 .54509 Mdot
.886 .5451 Mdot
.886 .54516 Mdot
.886 .54553 Mdot
.886 .54567 Mdot
.886 .54602 Mdot
.886 .54608 Mdot
.886 .54656 Mdot
.886 .54664 Mdot
.886 .54698 Mdot
.886 .54707 Mdot
.886 .54729 Mdot
.886 .54739 Mdot
.886 .54794 Mdot
.886 .54831 Mdot
.886 .54854 Mdot
.886 .54903 Mdot
.886 .54974 Mdot
.886 .54994 Mdot
.886 .55071 Mdot
.886 .55101 Mdot
.886 .55103 Mdot
.886 .55112 Mdot
.886 .55147 Mdot
.886 .55288 Mdot
.886 .55294 Mdot
.886 .55299 Mdot
.886 .55321 Mdot
.886 .55367 Mdot
.886 .55381 Mdot
.886 .55402 Mdot
.886 .55443 Mdot
.886 .55473 Mdot
.886 .55487 Mdot
.886 .55571 Mdot
.886 .55572 Mdot
.886 .55603 Mdot
.886 .55651 Mdot
.886 .55654 Mdot
.886 .557 Mdot
.886 .55717 Mdot
.886 .55748 Mdot
.886 .55838 Mdot
.886 .55849 Mdot
.886 .55913 Mdot
.886 .55935 Mdot
.886 .55991 Mdot
.886 .56 Mdot
.886 .56077 Mdot
.886 .56096 Mdot
.886 .56106 Mdot
.886 .56113 Mdot
.886 .5612 Mdot
.886 .56134 Mdot
.886 .56135 Mdot
.886 .56235 Mdot
.886 .56242 Mdot
.886 .56303 Mdot
.886 .56343 Mdot
.886 .5653 Mdot
.886 .56553 Mdot
.886 .56645 Mdot
.886 .56674 Mdot
.886 .56698 Mdot
.886 .56755 Mdot
.886 .56771 Mdot
.886 .568 Mdot
.886 .56895 Mdot
.886 .56912 Mdot
.886 .56921 Mdot
.886 .56982 Mdot
.886 .56989 Mdot
.886 .56991 Mdot
.886 .57025 Mdot
.886 .57041 Mdot
.886 .57045 Mdot
.886 .5705 Mdot
.886 .57062 Mdot
.886 .57067 Mdot
.886 .57091 Mdot
.886 .57102 Mdot
.886 .57111 Mdot
.886 .57115 Mdot
.886 .57152 Mdot
.886 .57173 Mdot
.886 .57177 Mdot
.886 .57184 Mdot
.886 .57304 Mdot
.886 .57329 Mdot
.886 .57337 Mdot
.886 .57363 Mdot
.886 .57374 Mdot
.886 .57392 Mdot
.886 .57405 Mdot
.886 .57443 Mdot
.886 .5745 Mdot
.886 .57458 Mdot
.886 .57486 Mdot
.886 .57489 Mdot
.886 .57491 Mdot
.886 .57514 Mdot
.886 .57545 Mdot
.886 .57584 Mdot
.886 .57631 Mdot
.886 .57633 Mdot
.886 .57634 Mdot
.886 .57642 Mdot
.886 .57658 Mdot
.886 .57665 Mdot
.886 .57668 Mdot
.886 .5767 Mdot
.886 .57695 Mdot
.886 .57724 Mdot
.886 .57779 Mdot
.886 .57784 Mdot
.886 .57819 Mdot
.886 .57839 Mdot
.886 .57841 Mdot
.886 .57853 Mdot
.886 .57935 Mdot
.886 .57947 Mdot
.886 .57974 Mdot
.886 .57978 Mdot
.886 .57983 Mdot
.886 .58035 Mdot
.886 .58057 Mdot
.886 .58112 Mdot
.886 .58114 Mdot
.886 .58154 Mdot
.886 .58171 Mdot
.886 .58198 Mdot
.886 .58232 Mdot
.886 .58309 Mdot
.886 .58314 Mdot
.886 .58318 Mdot
.886 .58337 Mdot
.886 .5835 Mdot
.886 .58352 Mdot
.886 .58379 Mdot
.886 .58409 Mdot
.886 .58409 Mdot
.886 .58427 Mdot
.886 .58435 Mdot
.886 .58445 Mdot
.886 .58452 Mdot
.886 .58485 Mdot
.886 .5851 Mdot
.886 .58521 Mdot
.886 .58536 Mdot
.886 .58573 Mdot
.886 .58595 Mdot
.886 .58597 Mdot
.886 .58601 Mdot
.886 .58609 Mdot
.886 .58615 Mdot
.886 .58624 Mdot
.886 .58625 Mdot
.886 .58638 Mdot
.886 .58658 Mdot
.886 .58715 Mdot
.886 .58718 Mdot
.886 .58723 Mdot
.886 .58729 Mdot
.886 .58733 Mdot
.886 .58746 Mdot
.886 .58749 Mdot
.886 .5875 Mdot
.886 .58754 Mdot
.886 .58759 Mdot
.886 .5876 Mdot
.886 .58764 Mdot
.886 .58764 Mdot
.886 .58767 Mdot
.886 .5877 Mdot
.886 .58778 Mdot
.886 .5878 Mdot
.886 .58782 Mdot
.886 .58782 Mdot
.886 .58789 Mdot
.886 .588 Mdot
.886 .58812 Mdot
.886 .58827 Mdot
.886 .58828 Mdot
.886 .58831 Mdot
.886 .58841 Mdot
.886 .58846 Mdot
.886 .58848 Mdot
.886 .58849 Mdot
.886 .58851 Mdot
.886 .58856 Mdot
.886 .5888 Mdot
.886 .58884 Mdot
.886 .58888 Mdot
.886 .58895 Mdot
.886 .58896 Mdot
.886 .58897 Mdot
.886 .58905 Mdot
.886 .58912 Mdot
.886 .58916 Mdot
.886 .58928 Mdot
.886 .58932 Mdot
.886 .5894 Mdot
.886 .58941 Mdot
.886 .5895 Mdot
.886 .58951 Mdot
.886 .58952 Mdot
.886 .58953 Mdot
.886 .58956 Mdot
.886 .58958 Mdot
.886 .5896 Mdot
.886 .58962 Mdot
.886 .58963 Mdot
.886 .58963 Mdot
.886 .58965 Mdot
.886 .58972 Mdot
.886 .58976 Mdot
.886 .5898 Mdot
.886 .58981 Mdot
.886 .58982 Mdot
.886 .58982 Mdot
.886 .58984 Mdot
.886 .58986 Mdot
.886 .58987 Mdot
.886 .58987 Mdot
.886 .58988 Mdot
.886 .58989 Mdot
.886 .58989 Mdot
.886 .58989 Mdot
.886 .58989 Mdot
.886 .5899 Mdot
.886 .5899 Mdot
.888 .06515 Mdot
.888 .06516 Mdot
.888 .06519 Mdot
.888 .06523 Mdot
.888 .06536 Mdot
.888 .06537 Mdot
.888 .06537 Mdot
.888 .06546 Mdot
.888 .06548 Mdot
.888 .0655 Mdot
.888 .06556 Mdot
.888 .06557 Mdot
.888 .0657 Mdot
.888 .06583 Mdot
.888 .06589 Mdot
.888 .06599 Mdot
.888 .06611 Mdot
.888 .06672 Mdot
.888 .06701 Mdot
.888 .06702 Mdot
.888 .06712 Mdot
.888 .06715 Mdot
.888 .0672 Mdot
.888 .06735 Mdot
.888 .06736 Mdot
.888 .06763 Mdot
.888 .06776 Mdot
.888 .06777 Mdot
.888 .0678 Mdot
.888 .06823 Mdot
.888 .06836 Mdot
.888 .06838 Mdot
.888 .06861 Mdot
.888 .06902 Mdot
.888 .06987 Mdot
.888 .07011 Mdot
.888 .07019 Mdot
.888 .07043 Mdot
.888 .07077 Mdot
.888 .07095 Mdot
.888 .07113 Mdot
.888 .07154 Mdot
.888 .07168 Mdot
.888 .07188 Mdot
.888 .07207 Mdot
.888 .07242 Mdot
.888 .07257 Mdot
.888 .07265 Mdot
.888 .07273 Mdot
.888 .0729 Mdot
.888 .073 Mdot
.888 .07303 Mdot
.888 .07311 Mdot
.888 .07338 Mdot
.888 .07428 Mdot
.888 .07431 Mdot
.888 .07442 Mdot
.888 .07463 Mdot
.888 .07475 Mdot
.888 .07513 Mdot
.888 .07535 Mdot
.888 .07653 Mdot
.888 .07705 Mdot
.888 .07708 Mdot
.888 .07728 Mdot
.888 .07816 Mdot
.888 .07896 Mdot
.888 .07907 Mdot
.888 .07988 Mdot
.888 .08031 Mdot
.888 .08055 Mdot
.888 .08074 Mdot
.888 .08082 Mdot
.888 .08136 Mdot
.888 .08164 Mdot
.888 .08173 Mdot
.888 .08184 Mdot
.888 .08198 Mdot
.888 .08204 Mdot
.888 .08215 Mdot
.888 .08279 Mdot
.888 .08431 Mdot
.888 .08498 Mdot
.888 .08506 Mdot
.888 .08556 Mdot
.888 .08578 Mdot
.888 .08647 Mdot
.888 .08707 Mdot
.888 .08764 Mdot
.888 .08764 Mdot
.888 .0883 Mdot
.888 .08862 Mdot
.888 .08989 Mdot
.888 .09033 Mdot
.888 .09053 Mdot
.888 .09078 Mdot
.888 .09185 Mdot
.888 .09236 Mdot
.888 .09251 Mdot
.888 .09542 Mdot
.888 .09559 Mdot
.888 .09683 Mdot
.888 .09702 Mdot
.888 .09785 Mdot
.888 .09814 Mdot
.888 .10002 Mdot
.888 .10005 Mdot
.888 .10013 Mdot
.888 .10039 Mdot
.888 .10155 Mdot
.888 .10449 Mdot
.888 .10565 Mdot
.888 .10681 Mdot
.888 .10713 Mdot
.888 .10715 Mdot
.888 .10796 Mdot
.888 .10844 Mdot
.888 .10874 Mdot
.888 .10901 Mdot
.888 .1097 Mdot
.888 .10995 Mdot
.888 .10996 Mdot
.888 .11082 Mdot
.888 .11302 Mdot
.888 .11305 Mdot
.888 .11308 Mdot
.888 .11456 Mdot
.888 .11471 Mdot
.888 .11529 Mdot
.888 .1154 Mdot
.888 .11662 Mdot
.888 .12057 Mdot
.888 .12364 Mdot
.888 .1238 Mdot
.888 .12523 Mdot
.888 .12678 Mdot
.888 .12786 Mdot
.888 .13005 Mdot
.888 .13028 Mdot
.888 .1305 Mdot
.888 .13085 Mdot
.888 .13145 Mdot
.888 .13207 Mdot
.888 .13235 Mdot
.888 .13303 Mdot
.888 .13305 Mdot
.888 .13328 Mdot
.888 .13583 Mdot
.888 .13608 Mdot
.888 .1384 Mdot
.888 .1394 Mdot
.888 .14019 Mdot
.888 .14053 Mdot
.888 .14186 Mdot
.888 .14193 Mdot
.888 .142 Mdot
.888 .14763 Mdot
.888 .14885 Mdot
.888 .14904 Mdot
.888 .15201 Mdot
.888 .15288 Mdot
.888 .15321 Mdot
.888 .15351 Mdot
.888 .15379 Mdot
.888 .15431 Mdot
.888 .15547 Mdot
.888 .15596 Mdot
.888 .15636 Mdot
.888 .15677 Mdot
.888 .15716 Mdot
.888 .15756 Mdot
.888 .15856 Mdot
.888 .15926 Mdot
.888 .15953 Mdot
.888 .16394 Mdot
.888 .16407 Mdot
.888 .16424 Mdot
.888 .16492 Mdot
.888 .16661 Mdot
.888 .16737 Mdot
.888 .16846 Mdot
.888 .16874 Mdot
.888 .1689 Mdot
.888 .17097 Mdot
.888 .17164 Mdot
.888 .17263 Mdot
.888 .17458 Mdot
.888 .17628 Mdot
.888 .17768 Mdot
.888 .17781 Mdot
.888 .18011 Mdot
.888 .18016 Mdot
.888 .18035 Mdot
.888 .18036 Mdot
.888 .18066 Mdot
.888 .18121 Mdot
.888 .18311 Mdot
.888 .18476 Mdot
.888 .18527 Mdot
.888 .18798 Mdot
.888 .18884 Mdot
.888 .18941 Mdot
.888 .19089 Mdot
.888 .19151 Mdot
.888 .19278 Mdot
.888 .1939 Mdot
.888 .19401 Mdot
.888 .19503 Mdot
.888 .19507 Mdot
.888 .19516 Mdot
.888 .19531 Mdot
.888 .19572 Mdot
.888 .19574 Mdot
.888 .19576 Mdot
.888 .19605 Mdot
.888 .1961 Mdot
.888 .19619 Mdot
.888 .19636 Mdot
.888 .19639 Mdot
.888 .19657 Mdot
.888 .19677 Mdot
.888 .19682 Mdot
.888 .19724 Mdot
.888 .19743 Mdot
.888 .19751 Mdot
.888 .19777 Mdot
.888 .19801 Mdot
.888 .19816 Mdot
.888 .19822 Mdot
.888 .19846 Mdot
.888 .19952 Mdot
.888 .19981 Mdot
.888 .20011 Mdot
.888 .20103 Mdot
.888 .20109 Mdot
.888 .20138 Mdot
.888 .20149 Mdot
.888 .20165 Mdot
.888 .20166 Mdot
.888 .20213 Mdot
.888 .20218 Mdot
.888 .20291 Mdot
.888 .20303 Mdot
.888 .20344 Mdot
.888 .2035 Mdot
.888 .20358 Mdot
.888 .20494 Mdot
.888 .20508 Mdot
.888 .20538 Mdot
.888 .20544 Mdot
.888 .20616 Mdot
.888 .20749 Mdot
.888 .20752 Mdot
.888 .20947 Mdot
.888 .21018 Mdot
.888 .21095 Mdot
.888 .21121 Mdot
.888 .21195 Mdot
.888 .21246 Mdot
.888 .21304 Mdot
.888 .21341 Mdot
.888 .21363 Mdot
.888 .21379 Mdot
.888 .21419 Mdot
.888 .21447 Mdot
.888 .21549 Mdot
.888 .21593 Mdot
.888 .21656 Mdot
.888 .21715 Mdot
.888 .21734 Mdot
.888 .21738 Mdot
.888 .21824 Mdot
.888 .21826 Mdot
.888 .21871 Mdot
.888 .21896 Mdot
.888 .21921 Mdot
.888 .21974 Mdot
.888 .21975 Mdot
.888 .22006 Mdot
.888 .22017 Mdot
.888 .22021 Mdot
.888 .2204 Mdot
.888 .22125 Mdot
.888 .22286 Mdot
.888 .22316 Mdot
.888 .22383 Mdot
.888 .22409 Mdot
.888 .22417 Mdot
.888 .22426 Mdot
.888 .2245 Mdot
.888 .22498 Mdot
.888 .22514 Mdot
.888 .22515 Mdot
.888 .2252 Mdot
.888 .22553 Mdot
.888 .22572 Mdot
.888 .22672 Mdot
.888 .22741 Mdot
.888 .22742 Mdot
.888 .22826 Mdot
.888 .22857 Mdot
.888 .22886 Mdot
.888 .22974 Mdot
.888 .23033 Mdot
.888 .23106 Mdot
.888 .2321 Mdot
.888 .23266 Mdot
.888 .23275 Mdot
.888 .23315 Mdot
.888 .23337 Mdot
.888 .23446 Mdot
.888 .23449 Mdot
.888 .23543 Mdot
.888 .23607 Mdot
.888 .23721 Mdot
.888 .2379 Mdot
.888 .23852 Mdot
.888 .23869 Mdot
.888 .23886 Mdot
.888 .23887 Mdot
.888 .24134 Mdot
.888 .24189 Mdot
.888 .24259 Mdot
.888 .24265 Mdot
.888 .24274 Mdot
.888 .24311 Mdot
.888 .24337 Mdot
.888 .24395 Mdot
.888 .24419 Mdot
.888 .24424 Mdot
.888 .24429 Mdot
.888 .24583 Mdot
.888 .24617 Mdot
.888 .24666 Mdot
.888 .2468 Mdot
.888 .24695 Mdot
.888 .24709 Mdot
.888 .24727 Mdot
.888 .24768 Mdot
.888 .24787 Mdot
.888 .24797 Mdot
.888 .2482 Mdot
.888 .24961 Mdot
.888 .24968 Mdot
.888 .25013 Mdot
.888 .25283 Mdot
.888 .25296 Mdot
.888 .25327 Mdot
.888 .25366 Mdot
.888 .25468 Mdot
.888 .25581 Mdot
.888 .25608 Mdot
.888 .2567 Mdot
.888 .25684 Mdot
.888 .25693 Mdot
.888 .25839 Mdot
.888 .25905 Mdot
.888 .25974 Mdot
.888 .26109 Mdot
.888 .26287 Mdot
.888 .26344 Mdot
.888 .26349 Mdot
.888 .26453 Mdot
.888 .26454 Mdot
.888 .26456 Mdot
.888 .26562 Mdot
.888 .26604 Mdot
.888 .2665 Mdot
.888 .26664 Mdot
.888 .26703 Mdot
.888 .26743 Mdot
.888 .26744 Mdot
.888 .2676 Mdot
.888 .2682 Mdot
.888 .2688 Mdot
.888 .27036 Mdot
.888 .27099 Mdot
.888 .27113 Mdot
.888 .27224 Mdot
.888 .2724 Mdot
.888 .27288 Mdot
.888 .27299 Mdot
.888 .27371 Mdot
.888 .27566 Mdot
.888 .27666 Mdot
.888 .27682 Mdot
.888 .27828 Mdot
.888 .27873 Mdot
.888 .27953 Mdot
.888 .28058 Mdot
.888 .28221 Mdot
.888 .28383 Mdot
.888 .28702 Mdot
.888 .28751 Mdot
.888 .28961 Mdot
.888 .28975 Mdot
.888 .29104 Mdot
.888 .29147 Mdot
.888 .29156 Mdot
.888 .29272 Mdot
.888 .2939 Mdot
.888 .2947 Mdot
.888 .29481 Mdot
.888 .29757 Mdot
.888 .29781 Mdot
.888 .29895 Mdot
.888 .29949 Mdot
.888 .29996 Mdot
.888 .30004 Mdot
.888 .30024 Mdot
.888 .30097 Mdot
.888 .30417 Mdot
.888 .30476 Mdot
.888 .30506 Mdot
.888 .30529 Mdot
.888 .30686 Mdot
.888 .30731 Mdot
.888 .31015 Mdot
.888 .31035 Mdot
.888 .31215 Mdot
.888 .3122 Mdot
.888 .31222 Mdot
.888 .31283 Mdot
.888 .31324 Mdot
.888 .31438 Mdot
.888 .3146 Mdot
.888 .31497 Mdot
.888 .31536 Mdot
.888 .31775 Mdot
.888 .31818 Mdot
.888 .3185 Mdot
.888 .31934 Mdot
.888 .31937 Mdot
.888 .31942 Mdot
.888 .3205 Mdot
.888 .32089 Mdot
.888 .32157 Mdot
.888 .32287 Mdot
.888 .32366 Mdot
.888 .32438 Mdot
.888 .32461 Mdot
.888 .32514 Mdot
.888 .32556 Mdot
.888 .32579 Mdot
.888 .3262 Mdot
.888 .32638 Mdot
.888 .32676 Mdot
.888 .32687 Mdot
.888 .32691 Mdot
.888 .3273 Mdot
.888 .32831 Mdot
.888 .32864 Mdot
.888 .32915 Mdot
.888 .32938 Mdot
.888 .33104 Mdot
.888 .33122 Mdot
.888 .33202 Mdot
.888 .33271 Mdot
.888 .33281 Mdot
.888 .3335 Mdot
.888 .33385 Mdot
.888 .33405 Mdot
.888 .33427 Mdot
.888 .3347 Mdot
.888 .33492 Mdot
.888 .335 Mdot
.888 .33508 Mdot
.888 .33519 Mdot
.888 .33524 Mdot
.888 .33532 Mdot
.888 .33695 Mdot
.888 .3375 Mdot
.888 .33786 Mdot
.888 .33802 Mdot
.888 .33892 Mdot
.888 .33931 Mdot
.888 .33997 Mdot
.888 .3408 Mdot
.888 .34108 Mdot
.888 .34205 Mdot
.888 .34246 Mdot
.888 .34422 Mdot
.888 .34684 Mdot
.888 .34686 Mdot
.888 .35125 Mdot
.888 .35187 Mdot
.888 .352 Mdot
.888 .3542 Mdot
.888 .35427 Mdot
.888 .35836 Mdot
.888 .36009 Mdot
.888 .36101 Mdot
.888 .36158 Mdot
.888 .36184 Mdot
.888 .36224 Mdot
.888 .36233 Mdot
.888 .36346 Mdot
.888 .36572 Mdot
.888 .36574 Mdot
.888 .36577 Mdot
.888 .36951 Mdot
.888 .36995 Mdot
.888 .37151 Mdot
.888 .37211 Mdot
.888 .37636 Mdot
.888 .37735 Mdot
.888 .37791 Mdot
.888 .37837 Mdot
.888 .37841 Mdot
.888 .37924 Mdot
.888 .37924 Mdot
.888 .38066 Mdot
.888 .38169 Mdot
.888 .38214 Mdot
.888 .3828 Mdot
.888 .3832 Mdot
.888 .38437 Mdot
.888 .38443 Mdot
.888 .38481 Mdot
.888 .38495 Mdot
.888 .38631 Mdot
.888 .38957 Mdot
.888 .39088 Mdot
.888 .39145 Mdot
.888 .39222 Mdot
.888 .39263 Mdot
.888 .39437 Mdot
.888 .39554 Mdot
.888 .39555 Mdot
.888 .39582 Mdot
.888 .39632 Mdot
.888 .39651 Mdot
.888 .39673 Mdot
.888 .399 Mdot
.888 .40078 Mdot
.888 .40155 Mdot
.888 .40175 Mdot
.888 .40354 Mdot
.888 .40413 Mdot
.888 .40451 Mdot
.888 .40467 Mdot
.888 .40483 Mdot
.888 .40541 Mdot
.888 .40591 Mdot
.888 .40813 Mdot
.888 .40899 Mdot
.888 .411 Mdot
.888 .41132 Mdot
.888 .41709 Mdot
.888 .41781 Mdot
.888 .41862 Mdot
.888 .41971 Mdot
.888 .42012 Mdot
.888 .42204 Mdot
.888 .42215 Mdot
.888 .4235 Mdot
.888 .42525 Mdot
.888 .42637 Mdot
.888 .42656 Mdot
.888 .42818 Mdot
.888 .42885 Mdot
.888 .429 Mdot
.888 .42948 Mdot
.888 .43007 Mdot
.888 .43113 Mdot
.888 .43153 Mdot
.888 .4335 Mdot
.888 .43412 Mdot
.888 .43451 Mdot
.888 .43531 Mdot
.888 .43614 Mdot
.888 .43693 Mdot
.888 .43775 Mdot
.888 .43928 Mdot
.888 .43974 Mdot
.888 .43989 Mdot
.888 .44093 Mdot
.888 .44115 Mdot
.888 .44167 Mdot
.888 .44366 Mdot
.888 .44456 Mdot
.888 .44459 Mdot
.888 .44494 Mdot
.888 .44575 Mdot
.888 .44775 Mdot
.888 .45031 Mdot
.888 .45055 Mdot
.888 .45056 Mdot
.888 .45088 Mdot
.888 .45218 Mdot
.888 .45396 Mdot
.888 .45541 Mdot
.888 .45644 Mdot
.888 .45685 Mdot
.888 .45703 Mdot
.888 .45705 Mdot
.888 .4575 Mdot
.888 .45888 Mdot
.888 .4594 Mdot
.888 .45971 Mdot
.888 .46226 Mdot
.888 .46353 Mdot
.888 .46476 Mdot
.888 .46593 Mdot
.888 .46656 Mdot
.888 .46739 Mdot
.888 .46803 Mdot
.888 .46808 Mdot
.888 .46969 Mdot
.888 .47007 Mdot
.888 .47308 Mdot
.888 .47323 Mdot
.888 .47414 Mdot
.888 .47453 Mdot
.888 .47554 Mdot
.888 .47577 Mdot
.888 .47634 Mdot
.888 .47661 Mdot
.888 .47741 Mdot
.888 .47973 Mdot
.888 .47982 Mdot
.888 .48004 Mdot
.888 .48016 Mdot
.888 .48016 Mdot
.888 .48068 Mdot
.888 .48144 Mdot
.888 .48162 Mdot
.888 .48277 Mdot
.888 .48417 Mdot
.888 .48482 Mdot
.888 .48551 Mdot
.888 .48615 Mdot
.888 .48719 Mdot
.888 .48755 Mdot
.888 .4884 Mdot
.888 .49042 Mdot
.888 .49107 Mdot
.888 .49279 Mdot
.888 .49281 Mdot
.888 .49373 Mdot
.888 .49419 Mdot
.888 .4945 Mdot
.888 .49473 Mdot
.888 .4951 Mdot
.888 .4958 Mdot
.888 .49744 Mdot
.888 .49834 Mdot
.888 .4984 Mdot
.888 .49864 Mdot
.888 .50038 Mdot
.888 .50038 Mdot
.888 .5021 Mdot
.888 .50226 Mdot
.888 .50307 Mdot
.888 .50382 Mdot
.888 .50388 Mdot
.888 .50402 Mdot
.888 .50423 Mdot
.888 .50486 Mdot
.888 .50489 Mdot
.888 .50491 Mdot
.888 .5051 Mdot
.888 .50527 Mdot
.888 .50535 Mdot
.888 .50542 Mdot
.888 .50556 Mdot
.888 .50582 Mdot
.888 .50586 Mdot
.888 .50613 Mdot
.888 .50643 Mdot
.888 .5065 Mdot
.888 .50713 Mdot
.888 .50741 Mdot
.888 .50754 Mdot
.888 .50792 Mdot
.888 .50812 Mdot
.888 .50827 Mdot
.888 .50849 Mdot
.888 .50858 Mdot
.888 .50874 Mdot
.888 .50893 Mdot
.888 .51033 Mdot
.888 .51048 Mdot
.888 .51091 Mdot
.888 .51134 Mdot
.888 .5115 Mdot
.888 .51253 Mdot
.888 .51267 Mdot
.888 .51275 Mdot
.888 .51317 Mdot
.888 .51332 Mdot
.888 .51356 Mdot
.888 .51357 Mdot
.888 .51423 Mdot
.888 .51431 Mdot
.888 .51534 Mdot
.888 .51551 Mdot
.888 .51608 Mdot
.888 .51616 Mdot
.888 .51627 Mdot
.888 .51818 Mdot
.888 .51837 Mdot
.888 .51878 Mdot
.888 .51887 Mdot
.888 .51985 Mdot
.888 .5206 Mdot
.888 .52104 Mdot
.888 .52165 Mdot
.888 .5217 Mdot
.888 .52374 Mdot
.888 .5243 Mdot
.888 .52487 Mdot
.888 .52524 Mdot
.888 .52624 Mdot
.888 .52658 Mdot
.888 .52754 Mdot
.888 .52776 Mdot
.888 .52819 Mdot
.888 .52841 Mdot
.888 .52894 Mdot
.888 .52915 Mdot
.888 .52935 Mdot
.888 .52941 Mdot
.888 .52955 Mdot
.888 .52968 Mdot
.888 .52989 Mdot
.888 .53003 Mdot
.888 .5304 Mdot
.888 .53075 Mdot
.888 .53077 Mdot
.888 .53202 Mdot
.888 .533 Mdot
.888 .53326 Mdot
.888 .53335 Mdot
.888 .53406 Mdot
.888 .5342 Mdot
.888 .5343 Mdot
.888 .53434 Mdot
.888 .53539 Mdot
.888 .53542 Mdot
.888 .53596 Mdot
.888 .53625 Mdot
.888 .53635 Mdot
.888 .53656 Mdot
.888 .53718 Mdot
.888 .53719 Mdot
.888 .53757 Mdot
.888 .53769 Mdot
.888 .53774 Mdot
.888 .53797 Mdot
.888 .53896 Mdot
.888 .53902 Mdot
.888 .53927 Mdot
.888 .5395 Mdot
.888 .54008 Mdot
.888 .54039 Mdot
.888 .5404 Mdot
.888 .54082 Mdot
.888 .54116 Mdot
.888 .54174 Mdot
.888 .54193 Mdot
.888 .54221 Mdot
.888 .5423 Mdot
.888 .54241 Mdot
.888 .54268 Mdot
.888 .54322 Mdot
.888 .54339 Mdot
.888 .54341 Mdot
.888 .54346 Mdot
.888 .54369 Mdot
.888 .54383 Mdot
.888 .54404 Mdot
.888 .54414 Mdot
.888 .54499 Mdot
.888 .54514 Mdot
.888 .54561 Mdot
.888 .54589 Mdot
.888 .5459 Mdot
.888 .54681 Mdot
.888 .54703 Mdot
.888 .54715 Mdot
.888 .54745 Mdot
.888 .54839 Mdot
.888 .549 Mdot
.888 .54976 Mdot
.888 .55044 Mdot
.888 .55083 Mdot
.888 .5514 Mdot
.888 .5515 Mdot
.888 .55182 Mdot
.888 .5519 Mdot
.888 .55196 Mdot
.888 .55212 Mdot
.888 .55235 Mdot
.888 .55241 Mdot
.888 .5532 Mdot
.888 .55323 Mdot
.888 .55358 Mdot
.888 .55397 Mdot
.888 .55416 Mdot
.888 .55461 Mdot
.888 .55479 Mdot
.888 .55505 Mdot
.888 .55588 Mdot
.888 .55604 Mdot
.888 .55654 Mdot
.888 .55711 Mdot
.888 .55728 Mdot
.888 .55737 Mdot
.888 .55737 Mdot
.888 .55743 Mdot
.888 .55745 Mdot
.888 .55814 Mdot
.888 .55818 Mdot
.888 .55861 Mdot
.888 .55912 Mdot
.888 .5597 Mdot
.888 .56 Mdot
.888 .5602 Mdot
.888 .56082 Mdot
.888 .56087 Mdot
.888 .56095 Mdot
.888 .56128 Mdot
.888 .5615 Mdot
.888 .56201 Mdot
.888 .56221 Mdot
.888 .56226 Mdot
.888 .5623 Mdot
.888 .56361 Mdot
.888 .56368 Mdot
.888 .56389 Mdot
.888 .56419 Mdot
.888 .56431 Mdot
.888 .56442 Mdot
.888 .56454 Mdot
.888 .56466 Mdot
.888 .5648 Mdot
.888 .56514 Mdot
.888 .5653 Mdot
.888 .56538 Mdot
.888 .56547 Mdot
.888 .56556 Mdot
.888 .56582 Mdot
.888 .56669 Mdot
.888 .56674 Mdot
.888 .5671 Mdot
.888 .56874 Mdot
.888 .56876 Mdot
.888 .56878 Mdot
.888 .56916 Mdot
.888 .56926 Mdot
.888 .56949 Mdot
.888 .56978 Mdot
.888 .57045 Mdot
.888 .57052 Mdot
.888 .57125 Mdot
.888 .57132 Mdot
.888 .57132 Mdot
.888 .57152 Mdot
.888 .5716 Mdot
.888 .57178 Mdot
.888 .57195 Mdot
.888 .57205 Mdot
.888 .57211 Mdot
.888 .57218 Mdot
.888 .5728 Mdot
.888 .57311 Mdot
.888 .57355 Mdot
.888 .57396 Mdot
.888 .574 Mdot
.888 .57488 Mdot
.888 .57599 Mdot
.888 .57633 Mdot
.888 .57637 Mdot
.888 .57653 Mdot
.888 .57657 Mdot
.888 .57699 Mdot
.888 .577 Mdot
.888 .577 Mdot
.888 .57762 Mdot
.888 .57786 Mdot
.888 .57786 Mdot
.888 .57793 Mdot
.888 .57813 Mdot
.888 .5782 Mdot
.888 .57829 Mdot
.888 .57842 Mdot
.888 .57865 Mdot
.888 .57865 Mdot
.888 .57874 Mdot
.888 .57907 Mdot
.888 .57939 Mdot
.888 .58021 Mdot
.888 .58053 Mdot
.888 .5806 Mdot
.888 .58062 Mdot
.888 .58063 Mdot
.888 .58115 Mdot
.888 .58123 Mdot
.888 .58146 Mdot
.888 .58151 Mdot
.888 .58186 Mdot
.888 .5819 Mdot
.888 .5827 Mdot
.888 .58274 Mdot
.888 .58288 Mdot
.888 .58318 Mdot
.888 .58325 Mdot
.888 .5833 Mdot
.888 .58342 Mdot
.888 .58377 Mdot
.888 .58386 Mdot
.888 .58404 Mdot
.888 .58404 Mdot
.888 .58419 Mdot
.888 .58436 Mdot
.888 .58455 Mdot
.888 .58461 Mdot
.888 .58474 Mdot
.888 .58476 Mdot
.888 .58495 Mdot
.888 .58536 Mdot
.888 .58554 Mdot
.888 .58557 Mdot
.888 .58558 Mdot
.888 .58562 Mdot
.888 .58565 Mdot
.888 .58568 Mdot
.888 .58575 Mdot
.888 .5859 Mdot
.888 .58592 Mdot
.888 .58597 Mdot
.888 .58604 Mdot
.888 .58615 Mdot
.888 .58637 Mdot
.888 .5864 Mdot
.888 .58662 Mdot
.888 .58686 Mdot
.888 .58691 Mdot
.888 .58692 Mdot
.888 .58706 Mdot
.888 .58738 Mdot
.888 .58744 Mdot
.888 .58758 Mdot
.888 .58763 Mdot
.888 .58766 Mdot
.888 .58767 Mdot
.888 .58791 Mdot
.888 .58799 Mdot
.888 .58801 Mdot
.888 .58802 Mdot
.888 .58804 Mdot
.888 .58809 Mdot
.888 .58811 Mdot
.888 .58813 Mdot
.888 .58817 Mdot
.888 .58827 Mdot
.888 .58832 Mdot
.888 .58837 Mdot
.888 .58841 Mdot
.888 .58852 Mdot
.888 .58857 Mdot
.888 .58862 Mdot
.888 .58871 Mdot
.888 .58877 Mdot
.888 .58879 Mdot
.888 .58886 Mdot
.888 .58909 Mdot
.888 .5892 Mdot
.888 .58926 Mdot
.888 .58926 Mdot
.888 .5893 Mdot
.888 .58942 Mdot
.888 .58942 Mdot
.888 .58943 Mdot
.888 .58946 Mdot
.888 .58953 Mdot
.888 .58954 Mdot
.888 .58958 Mdot
.888 .58959 Mdot
.888 .5896 Mdot
.888 .58962 Mdot
.888 .58963 Mdot
.888 .5897 Mdot
.888 .58987 Mdot
.888 .5899 Mdot
.888 .58993 Mdot
.888 .58994 Mdot
.888 .58998 Mdot
.888 .59001 Mdot
.888 .59002 Mdot
.888 .59003 Mdot
.888 .59004 Mdot
.888 .59004 Mdot
.888 .59007 Mdot
.888 .59007 Mdot
.888 .59007 Mdot
.888 .5901 Mdot
.888 .59012 Mdot
.888 .59012 Mdot
.888 .59013 Mdot
.89 .06426 Mdot
.89 .06428 Mdot
.89 .06428 Mdot
.89 .06429 Mdot
.89 .06433 Mdot
.89 .06443 Mdot
.89 .06446 Mdot
.89 .06448 Mdot
.89 .06454 Mdot
.89 .06454 Mdot
.89 .06455 Mdot
.89 .06461 Mdot
.89 .06463 Mdot
.89 .06465 Mdot
.89 .06472 Mdot
.89 .06475 Mdot
.89 .06478 Mdot
.89 .0648 Mdot
.89 .06487 Mdot
.89 .0649 Mdot
.89 .06492 Mdot
.89 .0652 Mdot
.89 .06527 Mdot
.89 .06539 Mdot
.89 .06551 Mdot
.89 .06555 Mdot
.89 .06568 Mdot
.89 .06573 Mdot
.89 .06602 Mdot
.89 .06616 Mdot
.89 .06628 Mdot
.89 .06646 Mdot
.89 .06678 Mdot
.89 .06682 Mdot
.89 .06686 Mdot
.89 .06703 Mdot
.89 .06707 Mdot
.89 .06736 Mdot
.89 .06749 Mdot
.89 .06763 Mdot
.89 .06767 Mdot
.89 .0678 Mdot
.89 .06812 Mdot
.89 .06834 Mdot
.89 .06836 Mdot
.89 .06906 Mdot
.89 .06912 Mdot
.89 .06951 Mdot
.89 .06977 Mdot
.89 .07022 Mdot
.89 .07048 Mdot
.89 .07076 Mdot
.89 .07134 Mdot
.89 .07163 Mdot
.89 .07327 Mdot
.89 .07378 Mdot
.89 .07389 Mdot
.89 .0742 Mdot
.89 .0744 Mdot
.89 .07453 Mdot
.89 .0747 Mdot
.89 .07473 Mdot
.89 .07505 Mdot
.89 .07537 Mdot
.89 .07569 Mdot
.89 .07577 Mdot
.89 .0758 Mdot
.89 .07593 Mdot
.89 .0761 Mdot
.89 .07672 Mdot
.89 .07682 Mdot
.89 .07761 Mdot
.89 .07819 Mdot
.89 .07831 Mdot
.89 .07855 Mdot
.89 .07861 Mdot
.89 .07879 Mdot
.89 .07904 Mdot
.89 .07959 Mdot
.89 .07962 Mdot
.89 .08004 Mdot
.89 .08014 Mdot
.89 .08017 Mdot
.89 .0806 Mdot
.89 .08082 Mdot
.89 .08087 Mdot
.89 .08189 Mdot
.89 .0822 Mdot
.89 .0829 Mdot
.89 .08314 Mdot
.89 .08461 Mdot
.89 .08507 Mdot
.89 .08514 Mdot
.89 .08524 Mdot
.89 .08759 Mdot
.89 .0877 Mdot
.89 .0883 Mdot
.89 .08867 Mdot
.89 .0892 Mdot
.89 .08981 Mdot
.89 .08989 Mdot
.89 .09051 Mdot
.89 .09065 Mdot
.89 .0909 Mdot
.89 .09136 Mdot
.89 .09161 Mdot
.89 .09179 Mdot
.89 .09229 Mdot
.89 .09344 Mdot
.89 .09363 Mdot
.89 .09398 Mdot
.89 .09406 Mdot
.89 .0945 Mdot
.89 .09463 Mdot
.89 .09521 Mdot
.89 .09552 Mdot
.89 .09555 Mdot
.89 .09588 Mdot
.89 .09595 Mdot
.89 .09599 Mdot
.89 .09606 Mdot
.89 .09617 Mdot
.89 .09622 Mdot
.89 .09742 Mdot
.89 .09755 Mdot
.89 .09788 Mdot
.89 .09824 Mdot
.89 .09862 Mdot
.89 .09875 Mdot
.89 .09913 Mdot
.89 .09944 Mdot
.89 .09956 Mdot
.89 .09958 Mdot
.89 .10009 Mdot
.89 .10021 Mdot
.89 .10094 Mdot
.89 .10103 Mdot
.89 .10189 Mdot
.89 .10204 Mdot
.89 .10218 Mdot
.89 .10265 Mdot
.89 .10288 Mdot
.89 .10361 Mdot
.89 .10499 Mdot
.89 .10513 Mdot
.89 .10588 Mdot
.89 .10699 Mdot
.89 .1072 Mdot
.89 .10801 Mdot
.89 .11168 Mdot
.89 .11234 Mdot
.89 .11277 Mdot
.89 .11419 Mdot
.89 .1158 Mdot
.89 .1192 Mdot
.89 .12032 Mdot
.89 .12059 Mdot
.89 .12385 Mdot
.89 .1272 Mdot
.89 .12805 Mdot
.89 .1287 Mdot
.89 .12925 Mdot
.89 .13083 Mdot
.89 .13089 Mdot
.89 .13111 Mdot
.89 .1326 Mdot
.89 .13297 Mdot
.89 .14385 Mdot
.89 .1439 Mdot
.89 .14576 Mdot
.89 .14736 Mdot
.89 .15151 Mdot
.89 .15404 Mdot
.89 .15449 Mdot
.89 .15599 Mdot
.89 .15735 Mdot
.89 .1575 Mdot
.89 .16026 Mdot
.89 .1614 Mdot
.89 .16165 Mdot
.89 .16281 Mdot
.89 .16328 Mdot
.89 .16441 Mdot
.89 .1648 Mdot
.89 .16524 Mdot
.89 .16863 Mdot
.89 .16905 Mdot
.89 .16938 Mdot
.89 .17025 Mdot
.89 .17155 Mdot
.89 .17362 Mdot
.89 .1741 Mdot
.89 .17433 Mdot
.89 .17753 Mdot
.89 .17837 Mdot
.89 .1795 Mdot
.89 .18005 Mdot
.89 .18047 Mdot
.89 .18182 Mdot
.89 .18207 Mdot
.89 .1834 Mdot
.89 .18361 Mdot
.89 .18415 Mdot
.89 .18463 Mdot
.89 .18496 Mdot
.89 .1865 Mdot
.89 .18763 Mdot
.89 .19004 Mdot
.89 .19222 Mdot
.89 .19228 Mdot
.89 .1923 Mdot
.89 .19232 Mdot
.89 .19244 Mdot
.89 .19266 Mdot
.89 .19278 Mdot
.89 .19288 Mdot
.89 .19293 Mdot
.89 .19295 Mdot
.89 .19312 Mdot
.89 .19313 Mdot
.89 .19315 Mdot
.89 .19322 Mdot
.89 .19335 Mdot
.89 .19337 Mdot
.89 .19344 Mdot
.89 .19351 Mdot
.89 .19371 Mdot
.89 .19382 Mdot
.89 .19393 Mdot
.89 .19399 Mdot
.89 .19409 Mdot
.89 .19421 Mdot
.89 .19429 Mdot
.89 .19435 Mdot
.89 .19527 Mdot
.89 .19551 Mdot
.89 .19588 Mdot
.89 .19597 Mdot
.89 .19625 Mdot
.89 .19627 Mdot
.89 .1964 Mdot
.89 .19682 Mdot
.89 .197 Mdot
.89 .19793 Mdot
.89 .19838 Mdot
.89 .19876 Mdot
.89 .19935 Mdot
.89 .20038 Mdot
.89 .20041 Mdot
.89 .20051 Mdot
.89 .20062 Mdot
.89 .20117 Mdot
.89 .20125 Mdot
.89 .20133 Mdot
.89 .20224 Mdot
.89 .20228 Mdot
.89 .20266 Mdot
.89 .2031 Mdot
.89 .20323 Mdot
.89 .20324 Mdot
.89 .20351 Mdot
.89 .20364 Mdot
.89 .20469 Mdot
.89 .20538 Mdot
.89 .20545 Mdot
.89 .20675 Mdot
.89 .20732 Mdot
.89 .2077 Mdot
.89 .20787 Mdot
.89 .20862 Mdot
.89 .20911 Mdot
.89 .20986 Mdot
.89 .20996 Mdot
.89 .20998 Mdot
.89 .21042 Mdot
.89 .21139 Mdot
.89 .21171 Mdot
.89 .21177 Mdot
.89 .21212 Mdot
.89 .2122 Mdot
.89 .21232 Mdot
.89 .2124 Mdot
.89 .2129 Mdot
.89 .21309 Mdot
.89 .21311 Mdot
.89 .21491 Mdot
.89 .21546 Mdot
.89 .21585 Mdot
.89 .21626 Mdot
.89 .21901 Mdot
.89 .21969 Mdot
.89 .22099 Mdot
.89 .22258 Mdot
.89 .22294 Mdot
.89 .22319 Mdot
.89 .22349 Mdot
.89 .22391 Mdot
.89 .22396 Mdot
.89 .22397 Mdot
.89 .22452 Mdot
.89 .22493 Mdot
.89 .22532 Mdot
.89 .22546 Mdot
.89 .22555 Mdot
.89 .22656 Mdot
.89 .22676 Mdot
.89 .22756 Mdot
.89 .22779 Mdot
.89 .22855 Mdot
.89 .22869 Mdot
.89 .22872 Mdot
.89 .22878 Mdot
.89 .22888 Mdot
.89 .2289 Mdot
.89 .22928 Mdot
.89 .22981 Mdot
.89 .23021 Mdot
.89 .23038 Mdot
.89 .23135 Mdot
.89 .23144 Mdot
.89 .23172 Mdot
.89 .23203 Mdot
.89 .23229 Mdot
.89 .23356 Mdot
.89 .23446 Mdot
.89 .23459 Mdot
.89 .23625 Mdot
.89 .23661 Mdot
.89 .2372 Mdot
.89 .23736 Mdot
.89 .23753 Mdot
.89 .2381 Mdot
.89 .23886 Mdot
.89 .23922 Mdot
.89 .24055 Mdot
.89 .24062 Mdot
.89 .2419 Mdot
.89 .2422 Mdot
.89 .24231 Mdot
.89 .2436 Mdot
.89 .24389 Mdot
.89 .24428 Mdot
.89 .24444 Mdot
.89 .24484 Mdot
.89 .24493 Mdot
.89 .24635 Mdot
.89 .24753 Mdot
.89 .24844 Mdot
.89 .25056 Mdot
.89 .25128 Mdot
.89 .25567 Mdot
.89 .25637 Mdot
.89 .2564 Mdot
.89 .25705 Mdot
.89 .25727 Mdot
.89 .25754 Mdot
.89 .2579 Mdot
.89 .25932 Mdot
.89 .26086 Mdot
.89 .26136 Mdot
.89 .26451 Mdot
.89 .26482 Mdot
.89 .26661 Mdot
.89 .26701 Mdot
.89 .26768 Mdot
.89 .26806 Mdot
.89 .26813 Mdot
.89 .26884 Mdot
.89 .26922 Mdot
.89 .27071 Mdot
.89 .27099 Mdot
.89 .271 Mdot
.89 .27124 Mdot
.89 .27145 Mdot
.89 .27173 Mdot
.89 .27297 Mdot
.89 .27303 Mdot
.89 .27307 Mdot
.89 .27328 Mdot
.89 .27346 Mdot
.89 .27418 Mdot
.89 .27451 Mdot
.89 .27551 Mdot
.89 .27622 Mdot
.89 .27676 Mdot
.89 .27813 Mdot
.89 .2782 Mdot
.89 .27982 Mdot
.89 .27988 Mdot
.89 .28026 Mdot
.89 .28151 Mdot
.89 .28203 Mdot
.89 .28306 Mdot
.89 .2831 Mdot
.89 .28328 Mdot
.89 .28364 Mdot
.89 .28408 Mdot
.89 .28454 Mdot
.89 .28491 Mdot
.89 .28495 Mdot
.89 .28656 Mdot
.89 .28713 Mdot
.89 .28744 Mdot
.89 .28751 Mdot
.89 .28781 Mdot
.89 .28844 Mdot
.89 .28847 Mdot
.89 .28864 Mdot
.89 .28877 Mdot
.89 .28897 Mdot
.89 .28928 Mdot
.89 .2894 Mdot
.89 .28993 Mdot
.89 .29211 Mdot
.89 .29281 Mdot
.89 .29317 Mdot
.89 .2941 Mdot
.89 .29509 Mdot
.89 .29615 Mdot
.89 .29653 Mdot
.89 .29707 Mdot
.89 .29736 Mdot
.89 .2976 Mdot
.89 .29845 Mdot
.89 .29878 Mdot
.89 .29886 Mdot
.89 .2996 Mdot
.89 .29999 Mdot
.89 .30027 Mdot
.89 .30059 Mdot
.89 .30262 Mdot
.89 .30286 Mdot
.89 .30405 Mdot
.89 .30456 Mdot
.89 .30523 Mdot
.89 .30561 Mdot
.89 .30565 Mdot
.89 .30567 Mdot
.89 .30604 Mdot
.89 .30614 Mdot
.89 .30734 Mdot
.89 .30784 Mdot
.89 .30796 Mdot
.89 .30933 Mdot
.89 .30995 Mdot
.89 .31165 Mdot
.89 .31291 Mdot
.89 .31302 Mdot
.89 .31332 Mdot
.89 .31363 Mdot
.89 .31371 Mdot
.89 .31409 Mdot
.89 .31417 Mdot
.89 .31576 Mdot
.89 .31611 Mdot
.89 .31622 Mdot
.89 .31658 Mdot
.89 .31673 Mdot
.89 .3191 Mdot
.89 .31967 Mdot
.89 .3202 Mdot
.89 .32074 Mdot
.89 .32184 Mdot
.89 .32302 Mdot
.89 .32357 Mdot
.89 .32453 Mdot
.89 .32627 Mdot
.89 .32991 Mdot
.89 .33063 Mdot
.89 .33075 Mdot
.89 .33156 Mdot
.89 .33226 Mdot
.89 .33277 Mdot
.89 .33287 Mdot
.89 .33328 Mdot
.89 .33397 Mdot
.89 .33431 Mdot
.89 .33442 Mdot
.89 .33577 Mdot
.89 .3367 Mdot
.89 .3381 Mdot
.89 .3403 Mdot
.89 .34054 Mdot
.89 .34088 Mdot
.89 .34133 Mdot
.89 .34172 Mdot
.89 .34197 Mdot
.89 .34226 Mdot
.89 .34241 Mdot
.89 .34283 Mdot
.89 .34364 Mdot
.89 .3439 Mdot
.89 .34416 Mdot
.89 .34423 Mdot
.89 .34477 Mdot
.89 .34503 Mdot
.89 .34513 Mdot
.89 .34515 Mdot
.89 .34584 Mdot
.89 .34591 Mdot
.89 .3461 Mdot
.89 .34651 Mdot
.89 .34696 Mdot
.89 .34738 Mdot
.89 .34778 Mdot
.89 .34783 Mdot
.89 .34828 Mdot
.89 .34837 Mdot
.89 .34844 Mdot
.89 .34869 Mdot
.89 .35091 Mdot
.89 .35373 Mdot
.89 .35439 Mdot
.89 .35514 Mdot
.89 .35729 Mdot
.89 .36175 Mdot
.89 .3625 Mdot
.89 .36677 Mdot
.89 .36807 Mdot
.89 .37067 Mdot
.89 .3712 Mdot
.89 .37174 Mdot
.89 .37271 Mdot
.89 .37428 Mdot
.89 .37558 Mdot
.89 .37656 Mdot
.89 .37725 Mdot
.89 .37854 Mdot
.89 .37935 Mdot
.89 .37949 Mdot
.89 .38001 Mdot
.89 .38044 Mdot
.89 .38093 Mdot
.89 .38254 Mdot
.89 .38336 Mdot
.89 .38353 Mdot
.89 .3838 Mdot
.89 .38438 Mdot
.89 .38859 Mdot
.89 .38862 Mdot
.89 .38954 Mdot
.89 .39381 Mdot
.89 .3945 Mdot
.89 .39482 Mdot
.89 .39574 Mdot
.89 .39647 Mdot
.89 .3986 Mdot
.89 .39863 Mdot
.89 .40178 Mdot
.89 .40299 Mdot
.89 .40465 Mdot
.89 .40624 Mdot
.89 .40907 Mdot
.89 .40918 Mdot
.89 .40998 Mdot
.89 .41324 Mdot
.89 .41635 Mdot
.89 .41668 Mdot
.89 .417 Mdot
.89 .41855 Mdot
.89 .41941 Mdot
.89 .42124 Mdot
.89 .42548 Mdot
.89 .42558 Mdot
.89 .42745 Mdot
.89 .42913 Mdot
.89 .43073 Mdot
.89 .43167 Mdot
.89 .4329 Mdot
.89 .43401 Mdot
.89 .43474 Mdot
.89 .43597 Mdot
.89 .4373 Mdot
.89 .43748 Mdot
.89 .4378 Mdot
.89 .43854 Mdot
.89 .43935 Mdot
.89 .44009 Mdot
.89 .44147 Mdot
.89 .44313 Mdot
.89 .4433 Mdot
.89 .44555 Mdot
.89 .44604 Mdot
.89 .44748 Mdot
.89 .4483 Mdot
.89 .4492 Mdot
.89 .44977 Mdot
.89 .45022 Mdot
.89 .45139 Mdot
.89 .45202 Mdot
.89 .45214 Mdot
.89 .45263 Mdot
.89 .45298 Mdot
.89 .4533 Mdot
.89 .45423 Mdot
.89 .45446 Mdot
.89 .45564 Mdot
.89 .45786 Mdot
.89 .45869 Mdot
.89 .45939 Mdot
.89 .45976 Mdot
.89 .46016 Mdot
.89 .46077 Mdot
.89 .46143 Mdot
.89 .4624 Mdot
.89 .46294 Mdot
.89 .46477 Mdot
.89 .46558 Mdot
.89 .46648 Mdot
.89 .46854 Mdot
.89 .4694 Mdot
.89 .4698 Mdot
.89 .47053 Mdot
.89 .47083 Mdot
.89 .47376 Mdot
.89 .47546 Mdot
.89 .47618 Mdot
.89 .47693 Mdot
.89 .47747 Mdot
.89 .47887 Mdot
.89 .47888 Mdot
.89 .47982 Mdot
.89 .48014 Mdot
.89 .48055 Mdot
.89 .48069 Mdot
.89 .48099 Mdot
.89 .48285 Mdot
.89 .48324 Mdot
.89 .48326 Mdot
.89 .48531 Mdot
.89 .4855 Mdot
.89 .48585 Mdot
.89 .48653 Mdot
.89 .48674 Mdot
.89 .48755 Mdot
.89 .48809 Mdot
.89 .48838 Mdot
.89 .49039 Mdot
.89 .49061 Mdot
.89 .49191 Mdot
.89 .49244 Mdot
.89 .49448 Mdot
.89 .49628 Mdot
.89 .49715 Mdot
.89 .49971 Mdot
.89 .49981 Mdot
.89 .49984 Mdot
.89 .49987 Mdot
.89 .50005 Mdot
.89 .50007 Mdot
.89 .50022 Mdot
.89 .50039 Mdot
.89 .50057 Mdot
.89 .50073 Mdot
.89 .5008 Mdot
.89 .50083 Mdot
.89 .5011 Mdot
.89 .50111 Mdot
.89 .50115 Mdot
.89 .50125 Mdot
.89 .50146 Mdot
.89 .50149 Mdot
.89 .50159 Mdot
.89 .50169 Mdot
.89 .50201 Mdot
.89 .50217 Mdot
.89 .50234 Mdot
.89 .50244 Mdot
.89 .50259 Mdot
.89 .50276 Mdot
.89 .5029 Mdot
.89 .50299 Mdot
.89 .50438 Mdot
.89 .50474 Mdot
.89 .5053 Mdot
.89 .50543 Mdot
.89 .50585 Mdot
.89 .50589 Mdot
.89 .50608 Mdot
.89 .50666 Mdot
.89 .50671 Mdot
.89 .50698 Mdot
.89 .50836 Mdot
.89 .50901 Mdot
.89 .50937 Mdot
.89 .50958 Mdot
.89 .51043 Mdot
.89 .51064 Mdot
.89 .51193 Mdot
.89 .51198 Mdot
.89 .51211 Mdot
.89 .51229 Mdot
.89 .51287 Mdot
.89 .51307 Mdot
.89 .51319 Mdot
.89 .5133 Mdot
.89 .51334 Mdot
.89 .5138 Mdot
.89 .5146 Mdot
.89 .51465 Mdot
.89 .51519 Mdot
.89 .51581 Mdot
.89 .51599 Mdot
.89 .51601 Mdot
.89 .51639 Mdot
.89 .51657 Mdot
.89 .51804 Mdot
.89 .51818 Mdot
.89 .51898 Mdot
.89 .51909 Mdot
.89 .52086 Mdot
.89 .52163 Mdot
.89 .52215 Mdot
.89 .52238 Mdot
.89 .52262 Mdot
.89 .52338 Mdot
.89 .52369 Mdot
.89 .52384 Mdot
.89 .52403 Mdot
.89 .52502 Mdot
.89 .52516 Mdot
.89 .52518 Mdot
.89 .52576 Mdot
.89 .52702 Mdot
.89 .52744 Mdot
.89 .52751 Mdot
.89 .52755 Mdot
.89 .52797 Mdot
.89 .52807 Mdot
.89 .52823 Mdot
.89 .52832 Mdot
.89 .52897 Mdot
.89 .52921 Mdot
.89 .52923 Mdot
.89 .52959 Mdot
.89 .53151 Mdot
.89 .53168 Mdot
.89 .5322 Mdot
.89 .53268 Mdot
.89 .53318 Mdot
.89 .53319 Mdot
.89 .53653 Mdot
.89 .537 Mdot
.89 .53703 Mdot
.89 .53734 Mdot
.89 .53887 Mdot
.89 .53953 Mdot
.89 .54039 Mdot
.89 .54072 Mdot
.89 .54113 Mdot
.89 .54141 Mdot
.89 .54144 Mdot
.89 .54175 Mdot
.89 .54181 Mdot
.89 .54223 Mdot
.89 .54229 Mdot
.89 .54229 Mdot
.89 .54258 Mdot
.89 .54292 Mdot
.89 .54338 Mdot
.89 .54381 Mdot
.89 .54382 Mdot
.89 .54397 Mdot
.89 .54406 Mdot
.89 .54518 Mdot
.89 .5454 Mdot
.89 .54627 Mdot
.89 .54652 Mdot
.89 .54727 Mdot
.89 .54733 Mdot
.89 .54749 Mdot
.89 .54752 Mdot
.89 .54758 Mdot
.89 .54769 Mdot
.89 .54771 Mdot
.89 .54811 Mdot
.89 .54825 Mdot
.89 .54829 Mdot
.89 .54868 Mdot
.89 .54909 Mdot
.89 .54927 Mdot
.89 .55028 Mdot
.89 .55037 Mdot
.89 .55066 Mdot
.89 .55098 Mdot
.89 .55124 Mdot
.89 .55253 Mdot
.89 .55262 Mdot
.89 .5532 Mdot
.89 .55343 Mdot
.89 .55347 Mdot
.89 .55355 Mdot
.89 .55364 Mdot
.89 .55444 Mdot
.89 .55518 Mdot
.89 .55553 Mdot
.89 .556 Mdot
.89 .55609 Mdot
.89 .55624 Mdot
.89 .55641 Mdot
.89 .55647 Mdot
.89 .55687 Mdot
.89 .55695 Mdot
.89 .55736 Mdot
.89 .55749 Mdot
.89 .55765 Mdot
.89 .558 Mdot
.89 .55825 Mdot
.89 .55921 Mdot
.89 .55928 Mdot
.89 .55942 Mdot
.89 .56005 Mdot
.89 .56043 Mdot
.89 .5607 Mdot
.89 .5608 Mdot
.89 .56092 Mdot
.89 .56193 Mdot
.89 .56206 Mdot
.89 .56218 Mdot
.89 .56251 Mdot
.89 .56265 Mdot
.89 .563 Mdot
.89 .56307 Mdot
.89 .56341 Mdot
.89 .56422 Mdot
.89 .56427 Mdot
.89 .56467 Mdot
.89 .56511 Mdot
.89 .56524 Mdot
.89 .56598 Mdot
.89 .5672 Mdot
.89 .56766 Mdot
.89 .5682 Mdot
.89 .56821 Mdot
.89 .57136 Mdot
.89 .57146 Mdot
.89 .57189 Mdot
.89 .57195 Mdot
.89 .57197 Mdot
.89 .57242 Mdot
.89 .57258 Mdot
.89 .57276 Mdot
.89 .573 Mdot
.89 .57396 Mdot
.89 .57488 Mdot
.89 .57496 Mdot
.89 .57527 Mdot
.89 .57623 Mdot
.89 .57669 Mdot
.89 .57708 Mdot
.89 .57721 Mdot
.89 .57739 Mdot
.89 .57842 Mdot
.89 .57864 Mdot
.89 .5787 Mdot
.89 .57901 Mdot
.89 .57922 Mdot
.89 .57926 Mdot
.89 .57964 Mdot
.89 .57985 Mdot
.89 .57991 Mdot
.89 .58004 Mdot
.89 .58008 Mdot
.89 .58012 Mdot
.89 .58036 Mdot
.89 .58038 Mdot
.89 .58059 Mdot
.89 .58062 Mdot
.89 .58076 Mdot
.89 .58077 Mdot
.89 .5808 Mdot
.89 .58088 Mdot
.89 .58099 Mdot
.89 .58103 Mdot
.89 .58113 Mdot
.89 .58123 Mdot
.89 .58132 Mdot
.89 .58136 Mdot
.89 .58169 Mdot
.89 .5817 Mdot
.89 .58173 Mdot
.89 .58175 Mdot
.89 .58177 Mdot
.89 .58178 Mdot
.89 .58187 Mdot
.89 .58188 Mdot
.89 .58197 Mdot
.89 .58213 Mdot
.89 .58216 Mdot
.89 .58228 Mdot
.89 .58231 Mdot
.89 .5824 Mdot
.89 .58245 Mdot
.89 .58277 Mdot
.89 .58291 Mdot
.89 .58296 Mdot
.89 .58303 Mdot
.89 .58315 Mdot
.89 .58322 Mdot
.89 .58326 Mdot
.89 .58343 Mdot
.89 .58345 Mdot
.89 .58362 Mdot
.89 .58376 Mdot
.89 .58386 Mdot
.89 .58403 Mdot
.89 .58406 Mdot
.89 .5847 Mdot
.89 .58473 Mdot
.89 .58475 Mdot
.89 .58487 Mdot
.89 .58527 Mdot
.89 .58534 Mdot
.89 .58553 Mdot
.89 .58561 Mdot
.89 .58589 Mdot
.89 .58591 Mdot
.89 .58597 Mdot
.89 .58608 Mdot
.89 .58609 Mdot
.89 .58612 Mdot
.89 .58623 Mdot
.89 .58624 Mdot
.89 .58639 Mdot
.89 .58646 Mdot
.89 .58651 Mdot
.89 .58652 Mdot
.89 .58659 Mdot
.89 .58662 Mdot
.89 .58678 Mdot
.89 .58699 Mdot
.89 .58702 Mdot
.89 .58719 Mdot
.89 .58723 Mdot
.89 .58727 Mdot
.89 .58728 Mdot
.89 .5873 Mdot
.89 .58738 Mdot
.89 .58747 Mdot
.89 .58756 Mdot
.89 .58756 Mdot
.89 .58761 Mdot
.89 .58765 Mdot
.89 .5877 Mdot
.89 .58778 Mdot
.89 .58781 Mdot
.89 .58795 Mdot
.89 .58839 Mdot
.89 .58847 Mdot
.89 .58862 Mdot
.89 .5887 Mdot
.89 .58877 Mdot
.89 .58889 Mdot
.89 .58896 Mdot
.89 .58907 Mdot
.89 .58908 Mdot
.89 .58927 Mdot
.89 .58928 Mdot
.89 .58933 Mdot
.89 .58942 Mdot
.89 .58946 Mdot
.89 .58947 Mdot
.89 .5895 Mdot
.89 .58954 Mdot
.89 .58962 Mdot
.89 .58963 Mdot
.89 .58967 Mdot
.89 .58968 Mdot
.89 .58969 Mdot
.89 .58978 Mdot
.89 .58983 Mdot
.89 .58986 Mdot
.89 .5899 Mdot
.89 .58997 Mdot
.89 .58999 Mdot
.89 .59002 Mdot
.89 .59004 Mdot
.89 .59007 Mdot
.89 .5901 Mdot
.89 .59012 Mdot
.89 .59019 Mdot
.89 .5902 Mdot
.89 .59021 Mdot
.89 .59022 Mdot
.89 .59023 Mdot
.89 .59024 Mdot
.89 .59025 Mdot
.89 .59026 Mdot
.89 .59027 Mdot
.89 .59027 Mdot
.89 .59029 Mdot
.89 .59029 Mdot
.89 .5903 Mdot
.89 .59031 Mdot
.89 .59032 Mdot
.89 .59032 Mdot
.89 .59035 Mdot
.89 .59036 Mdot
.89 .59036 Mdot
.89 .59036 Mdot
.89 .59037 Mdot
.892 .06343 Mdot
.892 .06344 Mdot
.892 .06344 Mdot
.892 .06344 Mdot
.892 .06345 Mdot
.892 .06347 Mdot
.892 .06348 Mdot
.892 .06356 Mdot
.892 .06361 Mdot
.892 .06362 Mdot
.892 .06362 Mdot
.892 .06363 Mdot
.892 .06371 Mdot
.892 .06373 Mdot
.892 .0638 Mdot
.892 .06388 Mdot
.892 .06389 Mdot
.892 .06398 Mdot
.892 .06404 Mdot
.892 .06405 Mdot
.892 .06413 Mdot
.892 .06424 Mdot
.892 .06431 Mdot
.892 .06454 Mdot
.892 .06465 Mdot
.892 .06472 Mdot
.892 .06477 Mdot
.892 .06478 Mdot
.892 .06479 Mdot
.892 .06487 Mdot
.892 .06498 Mdot
.892 .065 Mdot
.892 .06589 Mdot
.892 .06604 Mdot
.892 .06615 Mdot
.892 .06637 Mdot
.892 .06639 Mdot
.892 .06674 Mdot
.892 .06675 Mdot
.892 .06679 Mdot
.892 .06687 Mdot
.892 .06693 Mdot
.892 .06695 Mdot
.892 .06701 Mdot
.892 .06704 Mdot
.892 .0671 Mdot
.892 .0672 Mdot
.892 .06743 Mdot
.892 .06748 Mdot
.892 .06796 Mdot
.892 .06828 Mdot
.892 .06833 Mdot
.892 .06874 Mdot
.892 .06875 Mdot
.892 .06889 Mdot
.892 .0689 Mdot
.892 .06906 Mdot
.892 .0697 Mdot
.892 .06998 Mdot
.892 .07084 Mdot
.892 .07088 Mdot
.892 .071 Mdot
.892 .07115 Mdot
.892 .07143 Mdot
.892 .07145 Mdot
.892 .07153 Mdot
.892 .07154 Mdot
.892 .07157 Mdot
.892 .07184 Mdot
.892 .07196 Mdot
.892 .07251 Mdot
.892 .07265 Mdot
.892 .07269 Mdot
.892 .07272 Mdot
.892 .0738 Mdot
.892 .07462 Mdot
.892 .07463 Mdot
.892 .07489 Mdot
.892 .07601 Mdot
.892 .07603 Mdot
.892 .07637 Mdot
.892 .07743 Mdot
.892 .0785 Mdot
.892 .07852 Mdot
.892 .07934 Mdot
.892 .08044 Mdot
.892 .08191 Mdot
.892 .08195 Mdot
.892 .08281 Mdot
.892 .08417 Mdot
.892 .0843 Mdot
.892 .08483 Mdot
.892 .08518 Mdot
.892 .08535 Mdot
.892 .08645 Mdot
.892 .08705 Mdot
.892 .08732 Mdot
.892 .08815 Mdot
.892 .08887 Mdot
.892 .08888 Mdot
.892 .08916 Mdot
.892 .08916 Mdot
.892 .08931 Mdot
.892 .0898 Mdot
.892 .09013 Mdot
.892 .09019 Mdot
.892 .09038 Mdot
.892 .09093 Mdot
.892 .0915 Mdot
.892 .09178 Mdot
.892 .09284 Mdot
.892 .09321 Mdot
.892 .09414 Mdot
.892 .09559 Mdot
.892 .09586 Mdot
.892 .09658 Mdot
.892 .09671 Mdot
.892 .09675 Mdot
.892 .09686 Mdot
.892 .09748 Mdot
.892 .09816 Mdot
.892 .09859 Mdot
.892 .09895 Mdot
.892 .09949 Mdot
.892 .10052 Mdot
.892 .10102 Mdot
.892 .10125 Mdot
.892 .10161 Mdot
.892 .1021 Mdot
.892 .10212 Mdot
.892 .10369 Mdot
.892 .10372 Mdot
.892 .10374 Mdot
.892 .10375 Mdot
.892 .10431 Mdot
.892 .10453 Mdot
.892 .10583 Mdot
.892 .10598 Mdot
.892 .10618 Mdot
.892 .10692 Mdot
.892 .10751 Mdot
.892 .10768 Mdot
.892 .10773 Mdot
.892 .10793 Mdot
.892 .10874 Mdot
.892 .10967 Mdot
.892 .10996 Mdot
.892 .11013 Mdot
.892 .11164 Mdot
.892 .11177 Mdot
.892 .11247 Mdot
.892 .11306 Mdot
.892 .11349 Mdot
.892 .11444 Mdot
.892 .11473 Mdot
.892 .11557 Mdot
.892 .11598 Mdot
.892 .11717 Mdot
.892 .11734 Mdot
.892 .11749 Mdot
.892 .11766 Mdot
.892 .11799 Mdot
.892 .11822 Mdot
.892 .11866 Mdot
.892 .11877 Mdot
.892 .11882 Mdot
.892 .11929 Mdot
.892 .11944 Mdot
.892 .121 Mdot
.892 .12141 Mdot
.892 .12162 Mdot
.892 .1219 Mdot
.892 .12197 Mdot
.892 .12253 Mdot
.892 .12261 Mdot
.892 .12273 Mdot
.892 .12288 Mdot
.892 .12293 Mdot
.892 .12305 Mdot
.892 .12347 Mdot
.892 .12416 Mdot
.892 .12463 Mdot
.892 .12511 Mdot
.892 .1256 Mdot
.892 .12583 Mdot
.892 .12601 Mdot
.892 .12625 Mdot
.892 .12671 Mdot
.892 .12673 Mdot
.892 .12699 Mdot
.892 .12744 Mdot
.892 .12772 Mdot
.892 .13 Mdot
.892 .13021 Mdot
.892 .13229 Mdot
.892 .13232 Mdot
.892 .13389 Mdot
.892 .13445 Mdot
.892 .13453 Mdot
.892 .13491 Mdot
.892 .13737 Mdot
.892 .13792 Mdot
.892 .14045 Mdot
.892 .14359 Mdot
.892 .14506 Mdot
.892 .14548 Mdot
.892 .14626 Mdot
.892 .14782 Mdot
.892 .14829 Mdot
.892 .15088 Mdot
.892 .15105 Mdot
.892 .15257 Mdot
.892 .15279 Mdot
.892 .1529 Mdot
.892 .15489 Mdot
.892 .15581 Mdot
.892 .15775 Mdot
.892 .15956 Mdot
.892 .1607 Mdot
.892 .16186 Mdot
.892 .16566 Mdot
.892 .16713 Mdot
.892 .16858 Mdot
.892 .17378 Mdot
.892 .17401 Mdot
.892 .17529 Mdot
.892 .17572 Mdot
.892 .18348 Mdot
.892 .18372 Mdot
.892 .18706 Mdot
.892 .18959 Mdot
.892 .18961 Mdot
.892 .18963 Mdot
.892 .18964 Mdot
.892 .18965 Mdot
.892 .18972 Mdot
.892 .18975 Mdot
.892 .19001 Mdot
.892 .19006 Mdot
.892 .19007 Mdot
.892 .19019 Mdot
.892 .19021 Mdot
.892 .19023 Mdot
.892 .19025 Mdot
.892 .19051 Mdot
.892 .19056 Mdot
.892 .19067 Mdot
.892 .19079 Mdot
.892 .19089 Mdot
.892 .19108 Mdot
.892 .1911 Mdot
.892 .1914 Mdot
.892 .19157 Mdot
.892 .19159 Mdot
.892 .19161 Mdot
.892 .19188 Mdot
.892 .19224 Mdot
.892 .19245 Mdot
.892 .19321 Mdot
.892 .19357 Mdot
.892 .19379 Mdot
.892 .19396 Mdot
.892 .19398 Mdot
.892 .19403 Mdot
.892 .19415 Mdot
.892 .19428 Mdot
.892 .19465 Mdot
.892 .19471 Mdot
.892 .1976 Mdot
.892 .19808 Mdot
.892 .19844 Mdot
.892 .19914 Mdot
.892 .19919 Mdot
.892 .19944 Mdot
.892 .20033 Mdot
.892 .20037 Mdot
.892 .2005 Mdot
.892 .20075 Mdot
.892 .20093 Mdot
.892 .201 Mdot
.892 .20121 Mdot
.892 .20131 Mdot
.892 .20148 Mdot
.892 .20181 Mdot
.892 .20255 Mdot
.892 .20272 Mdot
.892 .2029 Mdot
.892 .20423 Mdot
.892 .20497 Mdot
.892 .20527 Mdot
.892 .20544 Mdot
.892 .20575 Mdot
.892 .20604 Mdot
.892 .20673 Mdot
.892 .20678 Mdot
.892 .20722 Mdot
.892 .20726 Mdot
.892 .20727 Mdot
.892 .20777 Mdot
.892 .20784 Mdot
.892 .20811 Mdot
.892 .20843 Mdot
.892 .20867 Mdot
.892 .2098 Mdot
.892 .21068 Mdot
.892 .21086 Mdot
.892 .21342 Mdot
.892 .21356 Mdot
.892 .21395 Mdot
.892 .21442 Mdot
.892 .2153 Mdot
.892 .21536 Mdot
.892 .21561 Mdot
.892 .21565 Mdot
.892 .21574 Mdot
.892 .2166 Mdot
.892 .21696 Mdot
.892 .21869 Mdot
.892 .21914 Mdot
.892 .21925 Mdot
.892 .21936 Mdot
.892 .2205 Mdot
.892 .22275 Mdot
.892 .22329 Mdot
.892 .22349 Mdot
.892 .22529 Mdot
.892 .22535 Mdot
.892 .22615 Mdot
.892 .22962 Mdot
.892 .22969 Mdot
.892 .22978 Mdot
.892 .2304 Mdot
.892 .23049 Mdot
.892 .23072 Mdot
.892 .23239 Mdot
.892 .23401 Mdot
.892 .23481 Mdot
.892 .23728 Mdot
.892 .23736 Mdot
.892 .23987 Mdot
.892 .24043 Mdot
.892 .24224 Mdot
.892 .24322 Mdot
.892 .24453 Mdot
.892 .24493 Mdot
.892 .24532 Mdot
.892 .24697 Mdot
.892 .24768 Mdot
.892 .2478 Mdot
.892 .2504 Mdot
.892 .25327 Mdot
.892 .25445 Mdot
.892 .25461 Mdot
.892 .25486 Mdot
.892 .2555 Mdot
.892 .25643 Mdot
.892 .25748 Mdot
.892 .25778 Mdot
.892 .25798 Mdot
.892 .25808 Mdot
.892 .25825 Mdot
.892 .25916 Mdot
.892 .25939 Mdot
.892 .26126 Mdot
.892 .26265 Mdot
.892 .26303 Mdot
.892 .26381 Mdot
.892 .26441 Mdot
.892 .26541 Mdot
.892 .26586 Mdot
.892 .26626 Mdot
.892 .26636 Mdot
.892 .26838 Mdot
.892 .26839 Mdot
.892 .26921 Mdot
.892 .26921 Mdot
.892 .26966 Mdot
.892 .2711 Mdot
.892 .27206 Mdot
.892 .27221 Mdot
.892 .27278 Mdot
.892 .27438 Mdot
.892 .276 Mdot
.892 .27603 Mdot
.892 .27665 Mdot
.892 .27683 Mdot
.892 .27801 Mdot
.892 .27989 Mdot
.892 .27999 Mdot
.892 .28096 Mdot
.892 .28159 Mdot
.892 .28361 Mdot
.892 .2843 Mdot
.892 .28519 Mdot
.892 .28642 Mdot
.892 .28747 Mdot
.892 .28771 Mdot
.892 .28773 Mdot
.892 .28852 Mdot
.892 .28966 Mdot
.892 .28969 Mdot
.892 .28984 Mdot
.892 .29056 Mdot
.892 .29091 Mdot
.892 .29102 Mdot
.892 .29133 Mdot
.892 .2915 Mdot
.892 .29169 Mdot
.892 .29308 Mdot
.892 .29391 Mdot
.892 .29435 Mdot
.892 .29492 Mdot
.892 .295 Mdot
.892 .29547 Mdot
.892 .29619 Mdot
.892 .29664 Mdot
.892 .29719 Mdot
.892 .29732 Mdot
.892 .29739 Mdot
.892 .29805 Mdot
.892 .29848 Mdot
.892 .2987 Mdot
.892 .30131 Mdot
.892 .30158 Mdot
.892 .30297 Mdot
.892 .30358 Mdot
.892 .30391 Mdot
.892 .30455 Mdot
.892 .30458 Mdot
.892 .30594 Mdot
.892 .30598 Mdot
.892 .30647 Mdot
.892 .3072 Mdot
.892 .30784 Mdot
.892 .31029 Mdot
.892 .31036 Mdot
.892 .31042 Mdot
.892 .31046 Mdot
.892 .31073 Mdot
.892 .31198 Mdot
.892 .31202 Mdot
.892 .31258 Mdot
.892 .31267 Mdot
.892 .31304 Mdot
.892 .31388 Mdot
.892 .31414 Mdot
.892 .31485 Mdot
.892 .3158 Mdot
.892 .31612 Mdot
.892 .31631 Mdot
.892 .31647 Mdot
.892 .31651 Mdot
.892 .31701 Mdot
.892 .31706 Mdot
.892 .31904 Mdot
.892 .31996 Mdot
.892 .32062 Mdot
.892 .32094 Mdot
.892 .32097 Mdot
.892 .32108 Mdot
.892 .32113 Mdot
.892 .32122 Mdot
.892 .32176 Mdot
.892 .3237 Mdot
.892 .32389 Mdot
.892 .3239 Mdot
.892 .3253 Mdot
.892 .32639 Mdot
.892 .32704 Mdot
.892 .32714 Mdot
.892 .32717 Mdot
.892 .3276 Mdot
.892 .32841 Mdot
.892 .33159 Mdot
.892 .33191 Mdot
.892 .33375 Mdot
.892 .33529 Mdot
.892 .33641 Mdot
.892 .33851 Mdot
.892 .33875 Mdot
.892 .33887 Mdot
.892 .33962 Mdot
.892 .34019 Mdot
.892 .34074 Mdot
.892 .3412 Mdot
.892 .34138 Mdot
.892 .34148 Mdot
.892 .34179 Mdot
.892 .34215 Mdot
.892 .3425 Mdot
.892 .34285 Mdot
.892 .34301 Mdot
.892 .34387 Mdot
.892 .34442 Mdot
.892 .34541 Mdot
.892 .34589 Mdot
.892 .34591 Mdot
.892 .34632 Mdot
.892 .3467 Mdot
.892 .34713 Mdot
.892 .34743 Mdot
.892 .34798 Mdot
.892 .34825 Mdot
.892 .34856 Mdot
.892 .34967 Mdot
.892 .34968 Mdot
.892 .34996 Mdot
.892 .35007 Mdot
.892 .35073 Mdot
.892 .35081 Mdot
.892 .35091 Mdot
.892 .35127 Mdot
.892 .35157 Mdot
.892 .35165 Mdot
.892 .35276 Mdot
.892 .35284 Mdot
.892 .35356 Mdot
.892 .35395 Mdot
.892 .35443 Mdot
.892 .35487 Mdot
.892 .35507 Mdot
.892 .35557 Mdot
.892 .35611 Mdot
.892 .35619 Mdot
.892 .35625 Mdot
.892 .35633 Mdot
.892 .35648 Mdot
.892 .35658 Mdot
.892 .35683 Mdot
.892 .35685 Mdot
.892 .35706 Mdot
.892 .35712 Mdot
.892 .35781 Mdot
.892 .35798 Mdot
.892 .35808 Mdot
.892 .3582 Mdot
.892 .35823 Mdot
.892 .35847 Mdot
.892 .35851 Mdot
.892 .35856 Mdot
.892 .35862 Mdot
.892 .3587 Mdot
.892 .35917 Mdot
.892 .35937 Mdot
.892 .35957 Mdot
.892 .35987 Mdot
.892 .36024 Mdot
.892 .36036 Mdot
.892 .36067 Mdot
.892 .36169 Mdot
.892 .36254 Mdot
.892 .3634 Mdot
.892 .36455 Mdot
.892 .36574 Mdot
.892 .36693 Mdot
.892 .36748 Mdot
.892 .36793 Mdot
.892 .3685 Mdot
.892 .36868 Mdot
.892 .36962 Mdot
.892 .36968 Mdot
.892 .37031 Mdot
.892 .37139 Mdot
.892 .37207 Mdot
.892 .37531 Mdot
.892 .37753 Mdot
.892 .37802 Mdot
.892 .38181 Mdot
.892 .38275 Mdot
.892 .38275 Mdot
.892 .38294 Mdot
.892 .38301 Mdot
.892 .38669 Mdot
.892 .388 Mdot
.892 .38817 Mdot
.892 .38906 Mdot
.892 .39472 Mdot
.892 .39596 Mdot
.892 .39804 Mdot
.892 .40168 Mdot
.892 .40435 Mdot
.892 .40865 Mdot
.892 .41188 Mdot
.892 .41214 Mdot
.892 .41278 Mdot
.892 .41295 Mdot
.892 .41447 Mdot
.892 .41463 Mdot
.892 .41784 Mdot
.892 .41885 Mdot
.892 .41955 Mdot
.892 .4204 Mdot
.892 .42075 Mdot
.892 .42433 Mdot
.892 .42468 Mdot
.892 .42507 Mdot
.892 .4252 Mdot
.892 .42788 Mdot
.892 .42832 Mdot
.892 .42856 Mdot
.892 .42942 Mdot
.892 .43266 Mdot
.892 .43455 Mdot
.892 .43846 Mdot
.892 .44008 Mdot
.892 .4421 Mdot
.892 .44434 Mdot
.892 .44547 Mdot
.892 .44551 Mdot
.892 .44662 Mdot
.892 .4509 Mdot
.892 .45397 Mdot
.892 .45674 Mdot
.892 .45676 Mdot
.892 .45948 Mdot
.892 .46472 Mdot
.892 .46674 Mdot
.892 .4668 Mdot
.892 .46885 Mdot
.892 .46901 Mdot
.892 .46941 Mdot
.892 .4717 Mdot
.892 .47248 Mdot
.892 .47285 Mdot
.892 .47638 Mdot
.892 .4792 Mdot
.892 .48583 Mdot
.892 .48583 Mdot
.892 .48623 Mdot
.892 .48896 Mdot
.892 .49171 Mdot
.892 .49422 Mdot
.892 .49559 Mdot
.892 .49578 Mdot
.892 .49581 Mdot
.892 .49583 Mdot
.892 .49585 Mdot
.892 .49587 Mdot
.892 .49596 Mdot
.892 .49598 Mdot
.892 .49602 Mdot
.892 .49643 Mdot
.892 .49652 Mdot
.892 .49653 Mdot
.892 .49667 Mdot
.892 .49673 Mdot
.892 .49676 Mdot
.892 .49678 Mdot
.892 .49681 Mdot
.892 .49723 Mdot
.892 .49731 Mdot
.892 .49749 Mdot
.892 .49768 Mdot
.892 .49783 Mdot
.892 .49812 Mdot
.892 .49815 Mdot
.892 .49863 Mdot
.892 .49889 Mdot
.892 .49893 Mdot
.892 .49896 Mdot
.892 .49937 Mdot
.892 .49994 Mdot
.892 .50026 Mdot
.892 .50085 Mdot
.892 .50105 Mdot
.892 .50144 Mdot
.892 .50165 Mdot
.892 .50199 Mdot
.892 .50219 Mdot
.892 .50232 Mdot
.892 .50258 Mdot
.892 .50262 Mdot
.892 .50269 Mdot
.892 .50287 Mdot
.892 .50308 Mdot
.892 .50364 Mdot
.892 .50374 Mdot
.892 .5076 Mdot
.892 .50807 Mdot
.892 .50812 Mdot
.892 .50877 Mdot
.892 .5093 Mdot
.892 .50937 Mdot
.892 .51033 Mdot
.892 .51039 Mdot
.892 .51041 Mdot
.892 .51077 Mdot
.892 .51187 Mdot
.892 .51207 Mdot
.892 .51213 Mdot
.892 .51232 Mdot
.892 .51267 Mdot
.892 .51293 Mdot
.892 .51303 Mdot
.892 .51333 Mdot
.892 .51347 Mdot
.892 .51371 Mdot
.892 .51418 Mdot
.892 .51524 Mdot
.892 .51547 Mdot
.892 .51574 Mdot
.892 .51643 Mdot
.892 .51667 Mdot
.892 .51761 Mdot
.892 .51862 Mdot
.892 .51878 Mdot
.892 .51901 Mdot
.892 .51904 Mdot
.892 .51928 Mdot
.892 .5197 Mdot
.892 .5199 Mdot
.892 .5201 Mdot
.892 .52026 Mdot
.892 .52105 Mdot
.892 .52111 Mdot
.892 .5217 Mdot
.892 .52175 Mdot
.892 .52177 Mdot
.892 .52245 Mdot
.892 .52254 Mdot
.892 .52291 Mdot
.892 .52334 Mdot
.892 .52365 Mdot
.892 .5246 Mdot
.892 .52516 Mdot
.892 .52632 Mdot
.892 .52654 Mdot
.892 .52985 Mdot
.892 .53002 Mdot
.892 .53017 Mdot
.892 .53051 Mdot
.892 .53111 Mdot
.892 .53221 Mdot
.892 .53229 Mdot
.892 .53259 Mdot
.892 .53265 Mdot
.892 .53275 Mdot
.892 .53352 Mdot
.892 .53381 Mdot
.892 .53426 Mdot
.892 .53636 Mdot
.892 .5369 Mdot
.892 .53703 Mdot
.892 .53716 Mdot
.892 .53792 Mdot
.892 .53851 Mdot
.892 .54034 Mdot
.892 .54113 Mdot
.892 .54174 Mdot
.892 .54177 Mdot
.892 .54197 Mdot
.892 .54399 Mdot
.892 .54406 Mdot
.892 .54495 Mdot
.892 .548 Mdot
.892 .54869 Mdot
.892 .54876 Mdot
.892 .54886 Mdot
.892 .54895 Mdot
.892 .54913 Mdot
.892 .54951 Mdot
.892 .5496 Mdot
.892 .54985 Mdot
.892 .55049 Mdot
.892 .55157 Mdot
.892 .5532 Mdot
.892 .554 Mdot
.892 .5542 Mdot
.892 .55427 Mdot
.892 .55446 Mdot
.892 .55446 Mdot
.892 .55538 Mdot
.892 .55639 Mdot
.892 .55647 Mdot
.892 .55881 Mdot
.892 .55894 Mdot
.892 .55933 Mdot
.892 .5594 Mdot
.892 .56095 Mdot
.892 .56139 Mdot
.892 .56182 Mdot
.892 .56295 Mdot
.892 .5633 Mdot
.892 .56363 Mdot
.892 .56417 Mdot
.892 .56474 Mdot
.892 .56501 Mdot
.892 .56559 Mdot
.892 .56562 Mdot
.892 .56569 Mdot
.892 .56613 Mdot
.892 .56618 Mdot
.892 .56694 Mdot
.892 .56708 Mdot
.892 .56753 Mdot
.892 .56776 Mdot
.892 .56788 Mdot
.892 .56831 Mdot
.892 .56922 Mdot
.892 .56995 Mdot
.892 .5701 Mdot
.892 .57081 Mdot
.892 .57092 Mdot
.892 .57094 Mdot
.892 .5711 Mdot
.892 .57156 Mdot
.892 .57156 Mdot
.892 .57216 Mdot
.892 .57222 Mdot
.892 .57287 Mdot
.892 .57295 Mdot
.892 .57308 Mdot
.892 .57315 Mdot
.892 .57316 Mdot
.892 .57329 Mdot
.892 .57336 Mdot
.892 .57341 Mdot
.892 .57347 Mdot
.892 .57361 Mdot
.892 .57375 Mdot
.892 .57388 Mdot
.892 .57408 Mdot
.892 .5742 Mdot
.892 .57423 Mdot
.892 .57424 Mdot
.892 .57429 Mdot
.892 .57432 Mdot
.892 .57434 Mdot
.892 .5745 Mdot
.892 .57452 Mdot
.892 .5746 Mdot
.892 .57466 Mdot
.892 .57478 Mdot
.892 .57522 Mdot
.892 .57526 Mdot
.892 .57539 Mdot
.892 .57541 Mdot
.892 .57544 Mdot
.892 .57556 Mdot
.892 .57563 Mdot
.892 .57572 Mdot
.892 .57577 Mdot
.892 .57581 Mdot
.892 .57586 Mdot
.892 .57619 Mdot
.892 .57631 Mdot
.892 .57655 Mdot
.892 .57663 Mdot
.892 .57689 Mdot
.892 .57701 Mdot
.892 .57718 Mdot
.892 .57738 Mdot
.892 .57741 Mdot
.892 .57784 Mdot
.892 .57788 Mdot
.892 .57796 Mdot
.892 .57822 Mdot
.892 .57845 Mdot
.892 .57851 Mdot
.892 .57852 Mdot
.892 .57857 Mdot
.892 .57873 Mdot
.892 .57894 Mdot
.892 .57899 Mdot
.892 .57903 Mdot
.892 .5794 Mdot
.892 .57946 Mdot
.892 .57961 Mdot
.892 .57962 Mdot
.892 .57962 Mdot
.892 .57963 Mdot
.892 .58007 Mdot
.892 .58007 Mdot
.892 .58021 Mdot
.892 .58031 Mdot
.892 .58037 Mdot
.892 .58051 Mdot
.892 .5808 Mdot
.892 .58095 Mdot
.892 .58104 Mdot
.892 .58116 Mdot
.892 .58135 Mdot
.892 .58152 Mdot
.892 .58155 Mdot
.892 .58156 Mdot
.892 .5816 Mdot
.892 .5818 Mdot
.892 .58187 Mdot
.892 .58227 Mdot
.892 .58253 Mdot
.892 .58263 Mdot
.892 .58292 Mdot
.892 .583 Mdot
.892 .58315 Mdot
.892 .5833 Mdot
.892 .58336 Mdot
.892 .58337 Mdot
.892 .58346 Mdot
.892 .5836 Mdot
.892 .58364 Mdot
.892 .58364 Mdot
.892 .58372 Mdot
.892 .58372 Mdot
.892 .58392 Mdot
.892 .58414 Mdot
.892 .58421 Mdot
.892 .58438 Mdot
.892 .58468 Mdot
.892 .58473 Mdot
.892 .58482 Mdot
.892 .58497 Mdot
.892 .585 Mdot
.892 .58537 Mdot
.892 .58561 Mdot
.892 .58562 Mdot
.892 .58602 Mdot
.892 .58631 Mdot
.892 .58654 Mdot
.892 .58654 Mdot
.892 .58683 Mdot
.892 .58712 Mdot
.892 .58721 Mdot
.892 .58722 Mdot
.892 .58752 Mdot
.892 .58759 Mdot
.892 .58759 Mdot
.892 .58781 Mdot
.892 .5881 Mdot
.892 .58811 Mdot
.892 .58812 Mdot
.892 .58816 Mdot
.892 .58831 Mdot
.892 .58834 Mdot
.892 .58841 Mdot
.892 .58842 Mdot
.892 .58842 Mdot
.892 .58845 Mdot
.892 .58845 Mdot
.892 .58853 Mdot
.892 .58857 Mdot
.892 .5886 Mdot
.892 .58861 Mdot
.892 .58884 Mdot
.892 .58892 Mdot
.892 .58909 Mdot
.892 .58913 Mdot
.892 .58913 Mdot
.892 .58917 Mdot
.892 .58918 Mdot
.892 .58928 Mdot
.892 .5893 Mdot
.892 .58939 Mdot
.892 .58951 Mdot
.892 .58953 Mdot
.892 .58959 Mdot
.892 .58962 Mdot
.892 .58963 Mdot
.892 .58964 Mdot
.892 .58966 Mdot
.892 .58966 Mdot
.892 .58968 Mdot
.892 .5897 Mdot
.892 .58971 Mdot
.892 .58971 Mdot
.892 .58981 Mdot
.892 .58981 Mdot
.892 .58987 Mdot
.892 .5899 Mdot
.892 .58994 Mdot
.892 .59018 Mdot
.892 .59018 Mdot
.892 .59021 Mdot
.892 .59023 Mdot
.892 .59024 Mdot
.892 .59024 Mdot
.892 .59025 Mdot
.892 .59027 Mdot
.892 .5903 Mdot
.892 .59036 Mdot
.892 .59038 Mdot
.892 .59041 Mdot
.892 .59043 Mdot
.892 .59043 Mdot
.892 .59045 Mdot
.892 .59047 Mdot
.892 .59047 Mdot
.892 .5905 Mdot
.892 .59052 Mdot
.892 .59052 Mdot
.892 .59054 Mdot
.892 .59054 Mdot
.892 .59055 Mdot
.892 .59055 Mdot
.892 .59056 Mdot
.892 .59058 Mdot
.892 .59059 Mdot
.892 .59059 Mdot
.892 .59059 Mdot
.892 .59059 Mdot
.892 .59059 Mdot
.892 .5906 Mdot
.894 .06254 Mdot
.894 .06254 Mdot
.894 .06255 Mdot
.894 .06255 Mdot
.894 .06256 Mdot
.894 .06256 Mdot
.894 .06258 Mdot
.894 .06259 Mdot
.894 .0626 Mdot
.894 .06261 Mdot
.894 .06265 Mdot
.894 .06271 Mdot
.894 .06272 Mdot
.894 .06275 Mdot
.894 .06276 Mdot
.894 .0628 Mdot
.894 .06288 Mdot
.894 .06302 Mdot
.894 .06331 Mdot
.894 .06343 Mdot
.894 .06349 Mdot
.894 .06357 Mdot
.894 .06363 Mdot
.894 .06384 Mdot
.894 .06392 Mdot
.894 .06395 Mdot
.894 .0641 Mdot
.894 .06417 Mdot
.894 .06421 Mdot
.894 .06456 Mdot
.894 .06487 Mdot
.894 .06488 Mdot
.894 .06524 Mdot
.894 .06528 Mdot
.894 .06528 Mdot
.894 .06573 Mdot
.894 .06665 Mdot
.894 .06668 Mdot
.894 .0667 Mdot
.894 .06706 Mdot
.894 .0672 Mdot
.894 .06727 Mdot
.894 .06736 Mdot
.894 .06772 Mdot
.894 .06819 Mdot
.894 .06855 Mdot
.894 .06877 Mdot
.894 .06899 Mdot
.894 .06951 Mdot
.894 .06984 Mdot
.894 .07104 Mdot
.894 .0711 Mdot
.894 .07196 Mdot
.894 .07225 Mdot
.894 .07254 Mdot
.894 .07343 Mdot
.894 .0737 Mdot
.894 .07439 Mdot
.894 .07506 Mdot
.894 .07509 Mdot
.894 .07663 Mdot
.894 .07757 Mdot
.894 .07768 Mdot
.894 .0783 Mdot
.894 .07839 Mdot
.894 .0784 Mdot
.894 .0784 Mdot
.894 .07896 Mdot
.894 .07905 Mdot
.894 .07999 Mdot
.894 .08049 Mdot
.894 .08101 Mdot
.894 .08113 Mdot
.894 .08119 Mdot
.894 .08141 Mdot
.894 .08197 Mdot
.894 .08201 Mdot
.894 .08251 Mdot
.894 .08354 Mdot
.894 .0854 Mdot
.894 .08542 Mdot
.894 .08591 Mdot
.894 .08678 Mdot
.894 .0871 Mdot
.894 .08782 Mdot
.894 .08798 Mdot
.894 .08898 Mdot
.894 .089 Mdot
.894 .091 Mdot
.894 .09153 Mdot
.894 .09176 Mdot
.894 .09356 Mdot
.894 .09369 Mdot
.894 .09464 Mdot
.894 .09534 Mdot
.894 .09607 Mdot
.894 .09797 Mdot
.894 .0982 Mdot
.894 .09852 Mdot
.894 .09854 Mdot
.894 .09967 Mdot
.894 .10077 Mdot
.894 .10093 Mdot
.894 .10198 Mdot
.894 .1021 Mdot
.894 .10252 Mdot
.894 .10256 Mdot
.894 .10266 Mdot
.894 .10295 Mdot
.894 .10351 Mdot
.894 .10539 Mdot
.894 .1062 Mdot
.894 .10705 Mdot
.894 .10796 Mdot
.894 .10894 Mdot
.894 .10915 Mdot
.894 .11157 Mdot
.894 .11342 Mdot
.894 .11345 Mdot
.894 .11353 Mdot
.894 .11384 Mdot
.894 .11497 Mdot
.894 .11523 Mdot
.894 .11552 Mdot
.894 .11684 Mdot
.894 .11757 Mdot
.894 .11819 Mdot
.894 .11909 Mdot
.894 .1207 Mdot
.894 .12137 Mdot
.894 .12346 Mdot
.894 .12445 Mdot
.894 .12471 Mdot
.894 .12478 Mdot
.894 .12488 Mdot
.894 .12974 Mdot
.894 .1301 Mdot
.894 .13147 Mdot
.894 .13354 Mdot
.894 .13382 Mdot
.894 .13587 Mdot
.894 .1366 Mdot
.894 .13752 Mdot
.894 .13774 Mdot
.894 .13794 Mdot
.894 .1383 Mdot
.894 .1386 Mdot
.894 .13873 Mdot
.894 .13927 Mdot
.894 .14045 Mdot
.894 .14085 Mdot
.894 .14248 Mdot
.894 .14261 Mdot
.894 .14317 Mdot
.894 .14384 Mdot
.894 .14391 Mdot
.894 .14608 Mdot
.894 .14665 Mdot
.894 .14693 Mdot
.894 .1471 Mdot
.894 .14728 Mdot
.894 .14737 Mdot
.894 .14773 Mdot
.894 .14808 Mdot
.894 .14845 Mdot
.894 .14847 Mdot
.894 .1485 Mdot
.894 .14924 Mdot
.894 .14934 Mdot
.894 .14952 Mdot
.894 .14979 Mdot
.894 .14992 Mdot
.894 .15019 Mdot
.894 .1511 Mdot
.894 .15143 Mdot
.894 .15175 Mdot
.894 .15616 Mdot
.894 .1569 Mdot
.894 .15748 Mdot
.894 .15753 Mdot
.894 .1578 Mdot
.894 .15806 Mdot
.894 .15862 Mdot
.894 .15965 Mdot
.894 .16098 Mdot
.894 .16398 Mdot
.894 .16422 Mdot
.894 .16873 Mdot
.894 .17019 Mdot
.894 .1704 Mdot
.894 .17171 Mdot
.894 .17366 Mdot
.894 .17376 Mdot
.894 .1743 Mdot
.894 .17747 Mdot
.894 .17763 Mdot
.894 .17834 Mdot
.894 .17994 Mdot
.894 .18122 Mdot
.894 .18186 Mdot
.894 .18271 Mdot
.894 .18367 Mdot
.894 .18367 Mdot
.894 .18384 Mdot
.894 .18394 Mdot
.894 .18401 Mdot
.894 .18436 Mdot
.894 .18468 Mdot
.894 .18607 Mdot
.894 .18613 Mdot
.894 .18673 Mdot
.894 .18676 Mdot
.894 .18677 Mdot
.894 .1868 Mdot
.894 .18681 Mdot
.894 .18682 Mdot
.894 .18689 Mdot
.894 .18693 Mdot
.894 .18696 Mdot
.894 .18699 Mdot
.894 .18712 Mdot
.894 .18732 Mdot
.894 .18733 Mdot
.894 .18744 Mdot
.894 .18745 Mdot
.894 .18761 Mdot
.894 .18786 Mdot
.894 .18803 Mdot
.894 .1883 Mdot
.894 .18833 Mdot
.894 .18868 Mdot
.894 .18927 Mdot
.894 .18968 Mdot
.894 .18985 Mdot
.894 .19011 Mdot
.894 .19032 Mdot
.894 .1905 Mdot
.894 .19072 Mdot
.894 .19101 Mdot
.894 .19127 Mdot
.894 .19137 Mdot
.894 .19184 Mdot
.894 .19184 Mdot
.894 .19207 Mdot
.894 .19222 Mdot
.894 .19335 Mdot
.894 .19437 Mdot
.894 .19437 Mdot
.894 .19554 Mdot
.894 .19567 Mdot
.894 .19567 Mdot
.894 .19568 Mdot
.894 .19716 Mdot
.894 .19785 Mdot
.894 .19828 Mdot
.894 .19965 Mdot
.894 .20006 Mdot
.894 .2001 Mdot
.894 .2002 Mdot
.894 .20028 Mdot
.894 .20137 Mdot
.894 .20144 Mdot
.894 .20144 Mdot
.894 .20187 Mdot
.894 .20209 Mdot
.894 .20221 Mdot
.894 .20241 Mdot
.894 .20357 Mdot
.894 .20506 Mdot
.894 .20622 Mdot
.894 .20692 Mdot
.894 .20763 Mdot
.894 .20927 Mdot
.894 .20942 Mdot
.894 .21034 Mdot
.894 .21213 Mdot
.894 .21413 Mdot
.894 .21433 Mdot
.894 .21703 Mdot
.894 .21744 Mdot
.894 .21779 Mdot
.894 .21784 Mdot
.894 .21797 Mdot
.894 .21798 Mdot
.894 .2183 Mdot
.894 .21889 Mdot
.894 .21948 Mdot
.894 .22166 Mdot
.894 .22251 Mdot
.894 .22371 Mdot
.894 .22419 Mdot
.894 .22467 Mdot
.894 .22505 Mdot
.894 .22675 Mdot
.894 .22676 Mdot
.894 .22686 Mdot
.894 .22841 Mdot
.894 .2316 Mdot
.894 .23162 Mdot
.894 .23268 Mdot
.894 .23335 Mdot
.894 .23453 Mdot
.894 .23488 Mdot
.894 .23495 Mdot
.894 .23551 Mdot
.894 .23563 Mdot
.894 .23572 Mdot
.894 .23677 Mdot
.894 .237 Mdot
.894 .23704 Mdot
.894 .23709 Mdot
.894 .23709 Mdot
.894 .23787 Mdot
.894 .2388 Mdot
.894 .23908 Mdot
.894 .24032 Mdot
.894 .2414 Mdot
.894 .24196 Mdot
.894 .24348 Mdot
.894 .24356 Mdot
.894 .24459 Mdot
.894 .24505 Mdot
.894 .24541 Mdot
.894 .2456 Mdot
.894 .24569 Mdot
.894 .2458 Mdot
.894 .24627 Mdot
.894 .24784 Mdot
.894 .24795 Mdot
.894 .24807 Mdot
.894 .24901 Mdot
.894 .24903 Mdot
.894 .24953 Mdot
.894 .24959 Mdot
.894 .24969 Mdot
.894 .25099 Mdot
.894 .25202 Mdot
.894 .25247 Mdot
.894 .25268 Mdot
.894 .25306 Mdot
.894 .25553 Mdot
.894 .25824 Mdot
.894 .25828 Mdot
.894 .25831 Mdot
.894 .25884 Mdot
.894 .25973 Mdot
.894 .26232 Mdot
.894 .26245 Mdot
.894 .26322 Mdot
.894 .26328 Mdot
.894 .26539 Mdot
.894 .26586 Mdot
.894 .26836 Mdot
.894 .26851 Mdot
.894 .2688 Mdot
.894 .26886 Mdot
.894 .2707 Mdot
.894 .27087 Mdot
.894 .27246 Mdot
.894 .27348 Mdot
.894 .27467 Mdot
.894 .27623 Mdot
.894 .27688 Mdot
.894 .27744 Mdot
.894 .27823 Mdot
.894 .28094 Mdot
.894 .28154 Mdot
.894 .28206 Mdot
.894 .28244 Mdot
.894 .28378 Mdot
.894 .28437 Mdot
.894 .28516 Mdot
.894 .28715 Mdot
.894 .2878 Mdot
.894 .28923 Mdot
.894 .29051 Mdot
.894 .29318 Mdot
.894 .29457 Mdot
.894 .29523 Mdot
.894 .29611 Mdot
.894 .29616 Mdot
.894 .29768 Mdot
.894 .29852 Mdot
.894 .29932 Mdot
.894 .30238 Mdot
.894 .30258 Mdot
.894 .30282 Mdot
.894 .30343 Mdot
.894 .30573 Mdot
.894 .30606 Mdot
.894 .30721 Mdot
.894 .30732 Mdot
.894 .30745 Mdot
.894 .30759 Mdot
.894 .30794 Mdot
.894 .30839 Mdot
.894 .30873 Mdot
.894 .30917 Mdot
.894 .30974 Mdot
.894 .30993 Mdot
.894 .31004 Mdot
.894 .3112 Mdot
.894 .31171 Mdot
.894 .31172 Mdot
.894 .312 Mdot
.894 .31274 Mdot
.894 .31345 Mdot
.894 .31503 Mdot
.894 .31626 Mdot
.894 .31648 Mdot
.894 .31657 Mdot
.894 .31694 Mdot
.894 .31712 Mdot
.894 .31723 Mdot
.894 .31804 Mdot
.894 .31871 Mdot
.894 .31943 Mdot
.894 .31951 Mdot
.894 .32196 Mdot
.894 .32251 Mdot
.894 .32271 Mdot
.894 .32295 Mdot
.894 .3241 Mdot
.894 .32457 Mdot
.894 .32513 Mdot
.894 .32576 Mdot
.894 .32617 Mdot
.894 .32759 Mdot
.894 .3285 Mdot
.894 .3291 Mdot
.894 .32997 Mdot
.894 .3315 Mdot
.894 .33153 Mdot
.894 .33375 Mdot
.894 .33432 Mdot
.894 .33434 Mdot
.894 .33434 Mdot
.894 .33478 Mdot
.894 .33486 Mdot
.894 .33636 Mdot
.894 .33645 Mdot
.894 .33666 Mdot
.894 .33707 Mdot
.894 .33746 Mdot
.894 .33819 Mdot
.894 .33947 Mdot
.894 .33948 Mdot
.894 .34038 Mdot
.894 .34105 Mdot
.894 .34179 Mdot
.894 .34303 Mdot
.894 .34349 Mdot
.894 .34463 Mdot
.894 .34518 Mdot
.894 .34704 Mdot
.894 .34735 Mdot
.894 .34795 Mdot
.894 .34854 Mdot
.894 .34862 Mdot
.894 .34945 Mdot
.894 .34947 Mdot
.894 .34996 Mdot
.894 .35091 Mdot
.894 .35131 Mdot
.894 .35173 Mdot
.894 .35275 Mdot
.894 .3539 Mdot
.894 .35477 Mdot
.894 .35495 Mdot
.894 .35547 Mdot
.894 .35631 Mdot
.894 .35663 Mdot
.894 .35691 Mdot
.894 .35731 Mdot
.894 .35801 Mdot
.894 .35961 Mdot
.894 .36181 Mdot
.894 .36195 Mdot
.894 .36333 Mdot
.894 .36344 Mdot
.894 .36425 Mdot
.894 .36453 Mdot
.894 .36489 Mdot
.894 .36505 Mdot
.894 .36519 Mdot
.894 .36531 Mdot
.894 .36617 Mdot
.894 .36679 Mdot
.894 .36683 Mdot
.894 .36729 Mdot
.894 .36732 Mdot
.894 .36813 Mdot
.894 .36857 Mdot
.894 .3686 Mdot
.894 .36874 Mdot
.894 .36886 Mdot
.894 .36901 Mdot
.894 .36929 Mdot
.894 .36932 Mdot
.894 .36939 Mdot
.894 .36949 Mdot
.894 .36953 Mdot
.894 .36963 Mdot
.894 .37202 Mdot
.894 .37224 Mdot
.894 .37656 Mdot
.894 .37707 Mdot
.894 .37774 Mdot
.894 .37792 Mdot
.894 .37901 Mdot
.894 .37975 Mdot
.894 .38037 Mdot
.894 .38064 Mdot
.894 .38105 Mdot
.894 .38116 Mdot
.894 .3817 Mdot
.894 .38172 Mdot
.894 .38548 Mdot
.894 .3859 Mdot
.894 .38602 Mdot
.894 .38667 Mdot
.894 .38882 Mdot
.894 .39132 Mdot
.894 .39142 Mdot
.894 .39176 Mdot
.894 .39311 Mdot
.894 .39522 Mdot
.894 .39571 Mdot
.894 .39616 Mdot
.894 .39632 Mdot
.894 .39635 Mdot
.894 .39674 Mdot
.894 .39698 Mdot
.894 .39766 Mdot
.894 .39796 Mdot
.894 .39884 Mdot
.894 .39918 Mdot
.894 .40088 Mdot
.894 .40116 Mdot
.894 .40183 Mdot
.894 .40258 Mdot
.894 .40273 Mdot
.894 .40528 Mdot
.894 .40532 Mdot
.894 .40595 Mdot
.894 .40637 Mdot
.894 .40664 Mdot
.894 .4079 Mdot
.894 .40935 Mdot
.894 .40951 Mdot
.894 .41319 Mdot
.894 .41424 Mdot
.894 .4155 Mdot
.894 .41609 Mdot
.894 .41646 Mdot
.894 .41685 Mdot
.894 .41703 Mdot
.894 .41781 Mdot
.894 .41821 Mdot
.894 .41857 Mdot
.894 .41935 Mdot
.894 .4194 Mdot
.894 .41946 Mdot
.894 .42028 Mdot
.894 .42064 Mdot
.894 .42103 Mdot
.894 .42125 Mdot
.894 .42164 Mdot
.894 .42221 Mdot
.894 .42247 Mdot
.894 .42305 Mdot
.894 .42334 Mdot
.894 .42456 Mdot
.894 .42497 Mdot
.894 .42566 Mdot
.894 .42632 Mdot
.894 .42808 Mdot
.894 .43103 Mdot
.894 .43306 Mdot
.894 .43387 Mdot
.894 .43543 Mdot
.894 .43692 Mdot
.894 .4381 Mdot
.894 .4382 Mdot
.894 .43874 Mdot
.894 .43926 Mdot
.894 .43933 Mdot
.894 .44039 Mdot
.894 .44243 Mdot
.894 .44507 Mdot
.894 .4454 Mdot
.894 .4471 Mdot
.894 .45093 Mdot
.894 .45138 Mdot
.894 .45602 Mdot
.894 .45689 Mdot
.894 .45994 Mdot
.894 .46264 Mdot
.894 .46303 Mdot
.894 .46402 Mdot
.894 .46544 Mdot
.894 .46712 Mdot
.894 .46771 Mdot
.894 .46898 Mdot
.894 .46915 Mdot
.894 .47012 Mdot
.894 .47244 Mdot
.894 .47574 Mdot
.894 .47602 Mdot
.894 .47604 Mdot
.894 .47725 Mdot
.894 .47788 Mdot
.894 .47801 Mdot
.894 .47891 Mdot
.894 .47984 Mdot
.894 .48001 Mdot
.894 .48003 Mdot
.894 .48202 Mdot
.894 .48221 Mdot
.894 .48329 Mdot
.894 .48455 Mdot
.894 .48473 Mdot
.894 .48633 Mdot
.894 .48633 Mdot
.894 .48661 Mdot
.894 .48679 Mdot
.894 .4869 Mdot
.894 .48716 Mdot
.894 .48747 Mdot
.894 .48801 Mdot
.894 .4885 Mdot
.894 .4903 Mdot
.894 .49039 Mdot
.894 .49138 Mdot
.894 .49142 Mdot
.894 .49144 Mdot
.894 .49148 Mdot
.894 .49151 Mdot
.894 .49152 Mdot
.894 .49164 Mdot
.894 .4917 Mdot
.894 .49175 Mdot
.894 .4918 Mdot
.894 .49182 Mdot
.894 .492 Mdot
.894 .49233 Mdot
.894 .49234 Mdot
.894 .49253 Mdot
.894 .49255 Mdot
.894 .4928 Mdot
.894 .4932 Mdot
.894 .49347 Mdot
.894 .49391 Mdot
.894 .49396 Mdot
.894 .49452 Mdot
.894 .49546 Mdot
.894 .49611 Mdot
.894 .49639 Mdot
.894 .49655 Mdot
.894 .49679 Mdot
.894 .49713 Mdot
.894 .49741 Mdot
.894 .49775 Mdot
.894 .49821 Mdot
.894 .49862 Mdot
.894 .49878 Mdot
.894 .49932 Mdot
.894 .49951 Mdot
.894 .49952 Mdot
.894 .49988 Mdot
.894 .50011 Mdot
.894 .50035 Mdot
.894 .50141 Mdot
.894 .50185 Mdot
.894 .50203 Mdot
.894 .50341 Mdot
.894 .50342 Mdot
.894 .50391 Mdot
.894 .50434 Mdot
.894 .50519 Mdot
.894 .50522 Mdot
.894 .50539 Mdot
.894 .50539 Mdot
.894 .50539 Mdot
.894 .50561 Mdot
.894 .50647 Mdot
.894 .50705 Mdot
.894 .50738 Mdot
.894 .50761 Mdot
.894 .50796 Mdot
.894 .50849 Mdot
.894 .50864 Mdot
.894 .50927 Mdot
.894 .5097 Mdot
.894 .50979 Mdot
.894 .50987 Mdot
.894 .51101 Mdot
.894 .51128 Mdot
.894 .51153 Mdot
.894 .51187 Mdot
.894 .51194 Mdot
.894 .51208 Mdot
.894 .51211 Mdot
.894 .51219 Mdot
.894 .51323 Mdot
.894 .51349 Mdot
.894 .51376 Mdot
.894 .51386 Mdot
.894 .51387 Mdot
.894 .51406 Mdot
.894 .51448 Mdot
.894 .51459 Mdot
.894 .5148 Mdot
.894 .51496 Mdot
.894 .51525 Mdot
.894 .51543 Mdot
.894 .51688 Mdot
.894 .51719 Mdot
.894 .51865 Mdot
.894 .51895 Mdot
.894 .52056 Mdot
.894 .5215 Mdot
.894 .52246 Mdot
.894 .52367 Mdot
.894 .52387 Mdot
.894 .52466 Mdot
.894 .52486 Mdot
.894 .52581 Mdot
.894 .52608 Mdot
.894 .52745 Mdot
.894 .5278 Mdot
.894 .52834 Mdot
.894 .5284 Mdot
.894 .52915 Mdot
.894 .5292 Mdot
.894 .53095 Mdot
.894 .53121 Mdot
.894 .53243 Mdot
.894 .53261 Mdot
.894 .53354 Mdot
.894 .53436 Mdot
.894 .53456 Mdot
.894 .53471 Mdot
.894 .53505 Mdot
.894 .53548 Mdot
.894 .53554 Mdot
.894 .5357 Mdot
.894 .53571 Mdot
.894 .5361 Mdot
.894 .53677 Mdot
.894 .53681 Mdot
.894 .53717 Mdot
.894 .53751 Mdot
.894 .53822 Mdot
.894 .53857 Mdot
.894 .53937 Mdot
.894 .53966 Mdot
.894 .54008 Mdot
.894 .5401 Mdot
.894 .54014 Mdot
.894 .54033 Mdot
.894 .54085 Mdot
.894 .54106 Mdot
.894 .54141 Mdot
.894 .54244 Mdot
.894 .54298 Mdot
.894 .54352 Mdot
.894 .5438 Mdot
.894 .54395 Mdot
.894 .5453 Mdot
.894 .54568 Mdot
.894 .54578 Mdot
.894 .54582 Mdot
.894 .54584 Mdot
.894 .54595 Mdot
.894 .54763 Mdot
.894 .54848 Mdot
.894 .55073 Mdot
.894 .55097 Mdot
.894 .55099 Mdot
.894 .5514 Mdot
.894 .55153 Mdot
.894 .55195 Mdot
.894 .55208 Mdot
.894 .55276 Mdot
.894 .55394 Mdot
.894 .55428 Mdot
.894 .55435 Mdot
.894 .5549 Mdot
.894 .55502 Mdot
.894 .5551 Mdot
.894 .55568 Mdot
.894 .5557 Mdot
.894 .55612 Mdot
.894 .55622 Mdot
.894 .55633 Mdot
.894 .55635 Mdot
.894 .55638 Mdot
.894 .55643 Mdot
.894 .55643 Mdot
.894 .55672 Mdot
.894 .55698 Mdot
.894 .55717 Mdot
.894 .55756 Mdot
.894 .55805 Mdot
.894 .55826 Mdot
.894 .55831 Mdot
.894 .55926 Mdot
.894 .55942 Mdot
.894 .55945 Mdot
.894 .56004 Mdot
.894 .56043 Mdot
.894 .56049 Mdot
.894 .56093 Mdot
.894 .56227 Mdot
.894 .56234 Mdot
.894 .56323 Mdot
.894 .56362 Mdot
.894 .56393 Mdot
.894 .56409 Mdot
.894 .56417 Mdot
.894 .56425 Mdot
.894 .56426 Mdot
.894 .56443 Mdot
.894 .56465 Mdot
.894 .56595 Mdot
.894 .56604 Mdot
.894 .56613 Mdot
.894 .5664 Mdot
.894 .56648 Mdot
.894 .56652 Mdot
.894 .5666 Mdot
.894 .56665 Mdot
.894 .56668 Mdot
.894 .56689 Mdot
.894 .5669 Mdot
.894 .56691 Mdot
.894 .56702 Mdot
.894 .56712 Mdot
.894 .56722 Mdot
.894 .56725 Mdot
.894 .5673 Mdot
.894 .56735 Mdot
.894 .56743 Mdot
.894 .5676 Mdot
.894 .56823 Mdot
.894 .56825 Mdot
.894 .56844 Mdot
.894 .56861 Mdot
.894 .56864 Mdot
.894 .56912 Mdot
.894 .56923 Mdot
.894 .56957 Mdot
.894 .56973 Mdot
.894 .56976 Mdot
.894 .56985 Mdot
.894 .56995 Mdot
.894 .57001 Mdot
.894 .57007 Mdot
.894 .57034 Mdot
.894 .57055 Mdot
.894 .57114 Mdot
.894 .57122 Mdot
.894 .57181 Mdot
.894 .5722 Mdot
.894 .5723 Mdot
.894 .57369 Mdot
.894 .57372 Mdot
.894 .57374 Mdot
.894 .57381 Mdot
.894 .57409 Mdot
.894 .57468 Mdot
.894 .57487 Mdot
.894 .57533 Mdot
.894 .57558 Mdot
.894 .57576 Mdot
.894 .57596 Mdot
.894 .57634 Mdot
.894 .57642 Mdot
.894 .57649 Mdot
.894 .57681 Mdot
.894 .57689 Mdot
.894 .57692 Mdot
.894 .57693 Mdot
.894 .57744 Mdot
.894 .57812 Mdot
.894 .57818 Mdot
.894 .57845 Mdot
.894 .57871 Mdot
.894 .57894 Mdot
.894 .57917 Mdot
.894 .57969 Mdot
.894 .57985 Mdot
.894 .57993 Mdot
.894 .57995 Mdot
.894 .57997 Mdot
.894 .58008 Mdot
.894 .58012 Mdot
.894 .58041 Mdot
.894 .58045 Mdot
.894 .58076 Mdot
.894 .58107 Mdot
.894 .58107 Mdot
.894 .58116 Mdot
.894 .58123 Mdot
.894 .58195 Mdot
.894 .58214 Mdot
.894 .5824 Mdot
.894 .58244 Mdot
.894 .58293 Mdot
.894 .583 Mdot
.894 .58314 Mdot
.894 .58369 Mdot
.894 .5837 Mdot
.894 .58397 Mdot
.894 .58401 Mdot
.894 .58421 Mdot
.894 .5843 Mdot
.894 .58454 Mdot
.894 .58467 Mdot
.894 .58467 Mdot
.894 .58518 Mdot
.894 .58546 Mdot
.894 .5856 Mdot
.894 .58561 Mdot
.894 .58576 Mdot
.894 .58582 Mdot
.894 .58584 Mdot
.894 .58587 Mdot
.894 .58601 Mdot
.894 .58614 Mdot
.894 .5864 Mdot
.894 .58642 Mdot
.894 .58658 Mdot
.894 .58658 Mdot
.894 .58658 Mdot
.894 .5866 Mdot
.894 .58677 Mdot
.894 .5868 Mdot
.894 .58706 Mdot
.894 .58747 Mdot
.894 .58748 Mdot
.894 .58766 Mdot
.894 .58785 Mdot
.894 .58792 Mdot
.894 .58816 Mdot
.894 .58824 Mdot
.894 .58832 Mdot
.894 .58855 Mdot
.894 .58856 Mdot
.894 .58888 Mdot
.894 .58898 Mdot
.894 .58911 Mdot
.894 .58917 Mdot
.894 .58923 Mdot
.894 .58933 Mdot
.894 .58945 Mdot
.894 .58955 Mdot
.894 .58958 Mdot
.894 .58959 Mdot
.894 .58963 Mdot
.894 .58973 Mdot
.894 .58973 Mdot
.894 .58974 Mdot
.894 .58999 Mdot
.894 .59011 Mdot
.894 .59011 Mdot
.894 .59012 Mdot
.894 .59022 Mdot
.894 .59022 Mdot
.894 .5903 Mdot
.894 .59039 Mdot
.894 .5904 Mdot
.894 .59042 Mdot
.894 .59046 Mdot
.894 .59047 Mdot
.894 .59049 Mdot
.894 .59055 Mdot
.894 .59057 Mdot
.894 .59059 Mdot
.894 .5906 Mdot
.894 .59063 Mdot
.894 .59071 Mdot
.894 .59075 Mdot
.894 .59077 Mdot
.894 .59078 Mdot
.894 .59078 Mdot
.894 .59079 Mdot
.894 .59079 Mdot
.894 .59081 Mdot
.894 .59082 Mdot
.894 .59082 Mdot
.894 .59082 Mdot
.894 .59083 Mdot
.894 .59083 Mdot
.894 .59083 Mdot
.894 .59084 Mdot
.894 .59084 Mdot
.894 .59084 Mdot
.894 .59084 Mdot
.894 .59084 Mdot
.896 .06167 Mdot
.896 .06167 Mdot
.896 .06167 Mdot
.896 .06168 Mdot
.896 .06181 Mdot
.896 .06184 Mdot
.896 .06191 Mdot
.896 .06195 Mdot
.896 .06203 Mdot
.896 .06219 Mdot
.896 .06223 Mdot
.896 .0624 Mdot
.896 .06249 Mdot
.896 .06257 Mdot
.896 .0626 Mdot
.896 .06264 Mdot
.896 .06264 Mdot
.896 .06278 Mdot
.896 .06303 Mdot
.896 .06308 Mdot
.896 .06318 Mdot
.896 .06352 Mdot
.896 .06353 Mdot
.896 .06365 Mdot
.896 .06382 Mdot
.896 .06408 Mdot
.896 .06427 Mdot
.896 .06477 Mdot
.896 .06484 Mdot
.896 .0652 Mdot
.896 .06527 Mdot
.896 .06535 Mdot
.896 .06538 Mdot
.896 .06599 Mdot
.896 .06633 Mdot
.896 .06686 Mdot
.896 .06723 Mdot
.896 .06723 Mdot
.896 .06752 Mdot
.896 .06771 Mdot
.896 .06781 Mdot
.896 .06863 Mdot
.896 .06877 Mdot
.896 .06882 Mdot
.896 .06898 Mdot
.896 .06936 Mdot
.896 .07038 Mdot
.896 .07053 Mdot
.896 .0709 Mdot
.896 .0715 Mdot
.896 .07269 Mdot
.896 .07277 Mdot
.896 .07328 Mdot
.896 .0735 Mdot
.896 .07365 Mdot
.896 .07446 Mdot
.896 .07482 Mdot
.896 .07523 Mdot
.896 .07555 Mdot
.896 .07594 Mdot
.896 .07631 Mdot
.896 .07649 Mdot
.896 .07659 Mdot
.896 .07677 Mdot
.896 .07799 Mdot
.896 .07842 Mdot
.896 .07886 Mdot
.896 .07895 Mdot
.896 .07906 Mdot
.896 .07927 Mdot
.896 .0796 Mdot
.896 .08053 Mdot
.896 .08266 Mdot
.896 .08279 Mdot
.896 .08291 Mdot
.896 .08417 Mdot
.896 .08523 Mdot
.896 .08555 Mdot
.896 .08556 Mdot
.896 .08701 Mdot
.896 .08805 Mdot
.896 .08865 Mdot
.896 .08984 Mdot
.896 .09068 Mdot
.896 .09208 Mdot
.896 .0927 Mdot
.896 .09276 Mdot
.896 .09527 Mdot
.896 .09636 Mdot
.896 .09641 Mdot
.896 .09712 Mdot
.896 .09748 Mdot
.896 .09875 Mdot
.896 .09991 Mdot
.896 .10041 Mdot
.896 .10087 Mdot
.896 .10095 Mdot
.896 .10218 Mdot
.896 .10301 Mdot
.896 .10655 Mdot
.896 .10757 Mdot
.896 .10819 Mdot
.896 .10942 Mdot
.896 .11097 Mdot
.896 .11229 Mdot
.896 .11301 Mdot
.896 .11558 Mdot
.896 .11587 Mdot
.896 .1183 Mdot
.896 .11973 Mdot
.896 .11997 Mdot
.896 .12233 Mdot
.896 .1226 Mdot
.896 .12274 Mdot
.896 .12287 Mdot
.896 .1239 Mdot
.896 .12422 Mdot
.896 .12504 Mdot
.896 .12507 Mdot
.896 .12582 Mdot
.896 .12624 Mdot
.896 .12707 Mdot
.896 .12727 Mdot
.896 .12829 Mdot
.896 .1294 Mdot
.896 .13015 Mdot
.896 .13099 Mdot
.896 .13205 Mdot
.896 .13292 Mdot
.896 .134 Mdot
.896 .13409 Mdot
.896 .136 Mdot
.896 .1368 Mdot
.896 .13925 Mdot
.896 .1393 Mdot
.896 .13949 Mdot
.896 .14274 Mdot
.896 .14369 Mdot
.896 .14397 Mdot
.896 .14412 Mdot
.896 .14431 Mdot
.896 .14478 Mdot
.896 .14511 Mdot
.896 .14526 Mdot
.896 .14565 Mdot
.896 .14645 Mdot
.896 .1471 Mdot
.896 .14784 Mdot
.896 .14864 Mdot
.896 .14956 Mdot
.896 .15153 Mdot
.896 .15267 Mdot
.896 .15269 Mdot
.896 .15403 Mdot
.896 .15598 Mdot
.896 .1572 Mdot
.896 .15914 Mdot
.896 .16046 Mdot
.896 .16115 Mdot
.896 .16283 Mdot
.896 .16295 Mdot
.896 .16406 Mdot
.896 .16469 Mdot
.896 .16553 Mdot
.896 .16558 Mdot
.896 .16674 Mdot
.896 .16707 Mdot
.896 .16898 Mdot
.896 .16909 Mdot
.896 .1695 Mdot
.896 .1711 Mdot
.896 .17136 Mdot
.896 .17228 Mdot
.896 .174 Mdot
.896 .17413 Mdot
.896 .17439 Mdot
.896 .17445 Mdot
.896 .17503 Mdot
.896 .17644 Mdot
.896 .17748 Mdot
.896 .17836 Mdot
.896 .17857 Mdot
.896 .17947 Mdot
.896 .17962 Mdot
.896 .18051 Mdot
.896 .18061 Mdot
.896 .18076 Mdot
.896 .18084 Mdot
.896 .18086 Mdot
.896 .18252 Mdot
.896 .18396 Mdot
.896 .18396 Mdot
.896 .18397 Mdot
.896 .18399 Mdot
.896 .18444 Mdot
.896 .18452 Mdot
.896 .18476 Mdot
.896 .1849 Mdot
.896 .18493 Mdot
.896 .18513 Mdot
.896 .18536 Mdot
.896 .18567 Mdot
.896 .18579 Mdot
.896 .18636 Mdot
.896 .18664 Mdot
.896 .18673 Mdot
.896 .18693 Mdot
.896 .187 Mdot
.896 .18705 Mdot
.896 .18715 Mdot
.896 .18716 Mdot
.896 .18761 Mdot
.896 .18812 Mdot
.896 .18843 Mdot
.896 .18851 Mdot
.896 .18859 Mdot
.896 .18891 Mdot
.896 .19004 Mdot
.896 .19007 Mdot
.896 .19045 Mdot
.896 .19101 Mdot
.896 .19186 Mdot
.896 .19247 Mdot
.896 .19299 Mdot
.896 .19411 Mdot
.896 .19434 Mdot
.896 .19517 Mdot
.896 .1954 Mdot
.896 .19549 Mdot
.896 .19574 Mdot
.896 .196 Mdot
.896 .19607 Mdot
.896 .19805 Mdot
.896 .19821 Mdot
.896 .19898 Mdot
.896 .19914 Mdot
.896 .19917 Mdot
.896 .20003 Mdot
.896 .20081 Mdot
.896 .20085 Mdot
.896 .20187 Mdot
.896 .20206 Mdot
.896 .20207 Mdot
.896 .20299 Mdot
.896 .20349 Mdot
.896 .20359 Mdot
.896 .20373 Mdot
.896 .20392 Mdot
.896 .20424 Mdot
.896 .20638 Mdot
.896 .20655 Mdot
.896 .20699 Mdot
.896 .20715 Mdot
.896 .20761 Mdot
.896 .20766 Mdot
.896 .20888 Mdot
.896 .20892 Mdot
.896 .21003 Mdot
.896 .21051 Mdot
.896 .21164 Mdot
.896 .21214 Mdot
.896 .21262 Mdot
.896 .21376 Mdot
.896 .21512 Mdot
.896 .21568 Mdot
.896 .21928 Mdot
.896 .21944 Mdot
.896 .21945 Mdot
.896 .21953 Mdot
.896 .21954 Mdot
.896 .21967 Mdot
.896 .22032 Mdot
.896 .2208 Mdot
.896 .22128 Mdot
.896 .22132 Mdot
.896 .22156 Mdot
.896 .22198 Mdot
.896 .22243 Mdot
.896 .22259 Mdot
.896 .22343 Mdot
.896 .22421 Mdot
.896 .22474 Mdot
.896 .22497 Mdot
.896 .22572 Mdot
.896 .22586 Mdot
.896 .22608 Mdot
.896 .22608 Mdot
.896 .22611 Mdot
.896 .22736 Mdot
.896 .22838 Mdot
.896 .22871 Mdot
.896 .22885 Mdot
.896 .22957 Mdot
.896 .22993 Mdot
.896 .23072 Mdot
.896 .23128 Mdot
.896 .23159 Mdot
.896 .23183 Mdot
.896 .23215 Mdot
.896 .23238 Mdot
.896 .23397 Mdot
.896 .23548 Mdot
.896 .23582 Mdot
.896 .23592 Mdot
.896 .23635 Mdot
.896 .23648 Mdot
.896 .23725 Mdot
.896 .23817 Mdot
.896 .23822 Mdot
.896 .23851 Mdot
.896 .23858 Mdot
.896 .23886 Mdot
.896 .2392 Mdot
.896 .23984 Mdot
.896 .23995 Mdot
.896 .24055 Mdot
.896 .24086 Mdot
.896 .24228 Mdot
.896 .24278 Mdot
.896 .2428 Mdot
.896 .24308 Mdot
.896 .24313 Mdot
.896 .24367 Mdot
.896 .24372 Mdot
.896 .24566 Mdot
.896 .24608 Mdot
.896 .24766 Mdot
.896 .25012 Mdot
.896 .25052 Mdot
.896 .25088 Mdot
.896 .25345 Mdot
.896 .25465 Mdot
.896 .25651 Mdot
.896 .25693 Mdot
.896 .25784 Mdot
.896 .25876 Mdot
.896 .25882 Mdot
.896 .25899 Mdot
.896 .26311 Mdot
.896 .26405 Mdot
.896 .26616 Mdot
.896 .26792 Mdot
.896 .26835 Mdot
.896 .26926 Mdot
.896 .27014 Mdot
.896 .27141 Mdot
.896 .27204 Mdot
.896 .27387 Mdot
.896 .2747 Mdot
.896 .27631 Mdot
.896 .27791 Mdot
.896 .27813 Mdot
.896 .27971 Mdot
.896 .27988 Mdot
.896 .28236 Mdot
.896 .28252 Mdot
.896 .28268 Mdot
.896 .28457 Mdot
.896 .28472 Mdot
.896 .28504 Mdot
.896 .28632 Mdot
.896 .28706 Mdot
.896 .28719 Mdot
.896 .2874 Mdot
.896 .28788 Mdot
.896 .28913 Mdot
.896 .28976 Mdot
.896 .29014 Mdot
.896 .2903 Mdot
.896 .29144 Mdot
.896 .29188 Mdot
.896 .29213 Mdot
.896 .29229 Mdot
.896 .29332 Mdot
.896 .29459 Mdot
.896 .29586 Mdot
.896 .29686 Mdot
.896 .29918 Mdot
.896 .30011 Mdot
.896 .3004 Mdot
.896 .3015 Mdot
.896 .30163 Mdot
.896 .30235 Mdot
.896 .30278 Mdot
.896 .30292 Mdot
.896 .303 Mdot
.896 .3033 Mdot
.896 .30524 Mdot
.896 .30564 Mdot
.896 .30589 Mdot
.896 .3064 Mdot
.896 .30868 Mdot
.896 .30881 Mdot
.896 .30886 Mdot
.896 .30962 Mdot
.896 .31143 Mdot
.896 .31358 Mdot
.896 .31373 Mdot
.896 .31443 Mdot
.896 .31526 Mdot
.896 .31679 Mdot
.896 .31766 Mdot
.896 .3183 Mdot
.896 .31922 Mdot
.896 .32017 Mdot
.896 .3203 Mdot
.896 .32091 Mdot
.896 .32104 Mdot
.896 .32121 Mdot
.896 .3227 Mdot
.896 .32396 Mdot
.896 .32396 Mdot
.896 .32434 Mdot
.896 .32458 Mdot
.896 .32596 Mdot
.896 .33008 Mdot
.896 .33204 Mdot
.896 .33239 Mdot
.896 .33267 Mdot
.896 .33354 Mdot
.896 .33369 Mdot
.896 .33468 Mdot
.896 .33502 Mdot
.896 .33543 Mdot
.896 .33593 Mdot
.896 .33662 Mdot
.896 .33824 Mdot
.896 .33919 Mdot
.896 .34011 Mdot
.896 .34106 Mdot
.896 .34209 Mdot
.896 .34283 Mdot
.896 .34453 Mdot
.896 .34456 Mdot
.896 .34659 Mdot
.896 .34701 Mdot
.896 .34721 Mdot
.896 .34851 Mdot
.896 .34901 Mdot
.896 .34905 Mdot
.896 .35237 Mdot
.896 .35266 Mdot
.896 .35325 Mdot
.896 .35459 Mdot
.896 .35609 Mdot
.896 .35622 Mdot
.896 .3573 Mdot
.896 .35792 Mdot
.896 .35802 Mdot
.896 .35916 Mdot
.896 .3597 Mdot
.896 .35984 Mdot
.896 .36018 Mdot
.896 .3605 Mdot
.896 .36068 Mdot
.896 .36102 Mdot
.896 .36197 Mdot
.896 .36227 Mdot
.896 .36261 Mdot
.896 .36303 Mdot
.896 .3638 Mdot
.896 .36384 Mdot
.896 .3649 Mdot
.896 .36584 Mdot
.896 .36586 Mdot
.896 .36593 Mdot
.896 .36762 Mdot
.896 .36767 Mdot
.896 .36774 Mdot
.896 .36804 Mdot
.896 .36824 Mdot
.896 .36853 Mdot
.896 .36877 Mdot
.896 .36904 Mdot
.896 .36933 Mdot
.896 .36966 Mdot
.896 .37078 Mdot
.896 .37078 Mdot
.896 .37126 Mdot
.896 .37305 Mdot
.896 .37351 Mdot
.896 .37374 Mdot
.896 .37474 Mdot
.896 .37564 Mdot
.896 .37639 Mdot
.896 .37642 Mdot
.896 .37656 Mdot
.896 .37709 Mdot
.896 .37804 Mdot
.896 .37817 Mdot
.896 .37838 Mdot
.896 .38015 Mdot
.896 .38018 Mdot
.896 .38023 Mdot
.896 .38025 Mdot
.896 .38026 Mdot
.896 .38267 Mdot
.896 .38473 Mdot
.896 .3848 Mdot
.896 .38593 Mdot
.896 .38724 Mdot
.896 .38746 Mdot
.896 .38885 Mdot
.896 .39188 Mdot
.896 .39246 Mdot
.896 .39253 Mdot
.896 .39282 Mdot
.896 .39344 Mdot
.896 .39372 Mdot
.896 .39376 Mdot
.896 .39382 Mdot
.896 .39457 Mdot
.896 .39491 Mdot
.896 .39656 Mdot
.896 .39722 Mdot
.896 .39731 Mdot
.896 .39788 Mdot
.896 .39929 Mdot
.896 .3994 Mdot
.896 .39984 Mdot
.896 .40141 Mdot
.896 .40224 Mdot
.896 .40566 Mdot
.896 .4071 Mdot
.896 .40919 Mdot
.896 .40969 Mdot
.896 .40973 Mdot
.896 .40981 Mdot
.896 .41015 Mdot
.896 .41055 Mdot
.896 .41159 Mdot
.896 .4123 Mdot
.896 .41262 Mdot
.896 .41348 Mdot
.896 .41514 Mdot
.896 .41521 Mdot
.896 .41663 Mdot
.896 .4174 Mdot
.896 .41761 Mdot
.896 .41822 Mdot
.896 .41862 Mdot
.896 .41912 Mdot
.896 .41982 Mdot
.896 .41992 Mdot
.896 .42188 Mdot
.896 .42304 Mdot
.896 .42345 Mdot
.896 .42416 Mdot
.896 .42505 Mdot
.896 .42567 Mdot
.896 .42572 Mdot
.896 .42604 Mdot
.896 .42827 Mdot
.896 .42842 Mdot
.896 .42845 Mdot
.896 .42887 Mdot
.896 .4292 Mdot
.896 .43018 Mdot
.896 .43123 Mdot
.896 .43522 Mdot
.896 .43626 Mdot
.896 .43751 Mdot
.896 .43771 Mdot
.896 .4378 Mdot
.896 .43822 Mdot
.896 .43839 Mdot
.896 .4416 Mdot
.896 .44422 Mdot
.896 .44506 Mdot
.896 .44516 Mdot
.896 .44535 Mdot
.896 .44558 Mdot
.896 .44574 Mdot
.896 .44642 Mdot
.896 .44658 Mdot
.896 .44887 Mdot
.896 .4491 Mdot
.896 .45088 Mdot
.896 .45091 Mdot
.896 .45107 Mdot
.896 .45125 Mdot
.896 .45246 Mdot
.896 .45407 Mdot
.896 .45415 Mdot
.896 .45416 Mdot
.896 .45637 Mdot
.896 .45645 Mdot
.896 .4568 Mdot
.896 .457 Mdot
.896 .4571 Mdot
.896 .45715 Mdot
.896 .46049 Mdot
.896 .46058 Mdot
.896 .46079 Mdot
.896 .46093 Mdot
.896 .46155 Mdot
.896 .46451 Mdot
.896 .46498 Mdot
.896 .46514 Mdot
.896 .46544 Mdot
.896 .46665 Mdot
.896 .46668 Mdot
.896 .46697 Mdot
.896 .46739 Mdot
.896 .46773 Mdot
.896 .46793 Mdot
.896 .46944 Mdot
.896 .46977 Mdot
.896 .47 Mdot
.896 .47047 Mdot
.896 .47057 Mdot
.896 .47162 Mdot
.896 .4741 Mdot
.896 .47412 Mdot
.896 .47594 Mdot
.896 .47747 Mdot
.896 .47784 Mdot
.896 .47941 Mdot
.896 .47966 Mdot
.896 .4797 Mdot
.896 .47999 Mdot
.896 .48071 Mdot
.896 .48086 Mdot
.896 .48119 Mdot
.896 .48122 Mdot
.896 .48135 Mdot
.896 .48162 Mdot
.896 .48175 Mdot
.896 .48178 Mdot
.896 .48334 Mdot
.896 .4846 Mdot
.896 .48508 Mdot
.896 .48701 Mdot
.896 .48701 Mdot
.896 .48702 Mdot
.896 .48706 Mdot
.896 .4878 Mdot
.896 .48794 Mdot
.896 .48834 Mdot
.896 .48856 Mdot
.896 .48862 Mdot
.896 .48895 Mdot
.896 .48932 Mdot
.896 .48984 Mdot
.896 .49003 Mdot
.896 .49097 Mdot
.896 .49143 Mdot
.896 .49156 Mdot
.896 .49168 Mdot
.896 .49189 Mdot
.896 .49201 Mdot
.896 .4921 Mdot
.896 .49224 Mdot
.896 .49227 Mdot
.896 .49299 Mdot
.896 .49338 Mdot
.896 .49382 Mdot
.896 .49431 Mdot
.896 .49445 Mdot
.896 .49457 Mdot
.896 .49495 Mdot
.896 .49509 Mdot
.896 .49548 Mdot
.896 .49616 Mdot
.896 .4962 Mdot
.896 .49645 Mdot
.896 .49688 Mdot
.896 .49693 Mdot
.896 .49753 Mdot
.896 .49842 Mdot
.896 .49974 Mdot
.896 .49994 Mdot
.896 .50045 Mdot
.896 .50053 Mdot
.896 .50069 Mdot
.896 .50149 Mdot
.896 .5015 Mdot
.896 .50285 Mdot
.896 .50322 Mdot
.896 .50357 Mdot
.896 .50394 Mdot
.896 .50457 Mdot
.896 .50483 Mdot
.896 .50518 Mdot
.896 .50531 Mdot
.896 .50569 Mdot
.896 .50608 Mdot
.896 .50618 Mdot
.896 .50632 Mdot
.896 .50914 Mdot
.896 .50923 Mdot
.896 .50937 Mdot
.896 .50937 Mdot
.896 .5104 Mdot
.896 .51051 Mdot
.896 .51074 Mdot
.896 .51079 Mdot
.896 .51114 Mdot
.896 .51172 Mdot
.896 .51204 Mdot
.896 .5126 Mdot
.896 .51291 Mdot
.896 .51317 Mdot
.896 .51322 Mdot
.896 .51402 Mdot
.896 .51468 Mdot
.896 .51495 Mdot
.896 .51497 Mdot
.896 .51604 Mdot
.896 .51613 Mdot
.896 .51627 Mdot
.896 .51697 Mdot
.896 .51711 Mdot
.896 .51732 Mdot
.896 .51758 Mdot
.896 .51802 Mdot
.896 .51846 Mdot
.896 .51965 Mdot
.896 .5201 Mdot
.896 .52097 Mdot
.896 .52106 Mdot
.896 .52122 Mdot
.896 .52181 Mdot
.896 .52203 Mdot
.896 .52247 Mdot
.896 .52264 Mdot
.896 .52272 Mdot
.896 .52302 Mdot
.896 .52347 Mdot
.896 .52358 Mdot
.896 .52363 Mdot
.896 .5243 Mdot
.896 .52435 Mdot
.896 .52441 Mdot
.896 .52588 Mdot
.896 .52651 Mdot
.896 .52706 Mdot
.896 .52798 Mdot
.896 .52863 Mdot
.896 .52893 Mdot
.896 .52924 Mdot
.896 .5307 Mdot
.896 .53241 Mdot
.896 .5331 Mdot
.896 .53324 Mdot
.896 .53427 Mdot
.896 .53619 Mdot
.896 .53671 Mdot
.896 .53685 Mdot
.896 .53749 Mdot
.896 .53768 Mdot
.896 .5377 Mdot
.896 .53779 Mdot
.896 .5378 Mdot
.896 .53796 Mdot
.896 .53853 Mdot
.896 .53873 Mdot
.896 .5392 Mdot
.896 .53929 Mdot
.896 .53931 Mdot
.896 .53986 Mdot
.896 .5399 Mdot
.896 .54007 Mdot
.896 .54018 Mdot
.896 .54067 Mdot
.896 .54119 Mdot
.896 .54137 Mdot
.896 .54198 Mdot
.896 .54233 Mdot
.896 .54237 Mdot
.896 .54322 Mdot
.896 .54322 Mdot
.896 .54329 Mdot
.896 .54333 Mdot
.896 .54365 Mdot
.896 .54382 Mdot
.896 .54407 Mdot
.896 .54434 Mdot
.896 .54466 Mdot
.896 .54474 Mdot
.896 .54491 Mdot
.896 .54506 Mdot
.896 .54531 Mdot
.896 .54531 Mdot
.896 .54533 Mdot
.896 .54539 Mdot
.896 .54671 Mdot
.896 .54781 Mdot
.896 .54816 Mdot
.896 .54831 Mdot
.896 .54866 Mdot
.896 .54907 Mdot
.896 .54946 Mdot
.896 .55012 Mdot
.896 .55028 Mdot
.896 .55036 Mdot
.896 .55086 Mdot
.896 .55119 Mdot
.896 .55143 Mdot
.896 .55171 Mdot
.896 .55176 Mdot
.896 .552 Mdot
.896 .55286 Mdot
.896 .55293 Mdot
.896 .5536 Mdot
.896 .55498 Mdot
.896 .55509 Mdot
.896 .55542 Mdot
.896 .55552 Mdot
.896 .55594 Mdot
.896 .55607 Mdot
.896 .5568 Mdot
.896 .5573 Mdot
.896 .55731 Mdot
.896 .55733 Mdot
.896 .55738 Mdot
.896 .55741 Mdot
.896 .55768 Mdot
.896 .55772 Mdot
.896 .558 Mdot
.896 .55806 Mdot
.896 .55832 Mdot
.896 .55864 Mdot
.896 .55906 Mdot
.896 .55924 Mdot
.896 .55925 Mdot
.896 .55933 Mdot
.896 .55937 Mdot
.896 .55989 Mdot
.896 .56016 Mdot
.896 .56024 Mdot
.896 .56072 Mdot
.896 .56084 Mdot
.896 .56087 Mdot
.896 .56144 Mdot
.896 .56154 Mdot
.896 .56189 Mdot
.896 .5619 Mdot
.896 .56215 Mdot
.896 .56219 Mdot
.896 .56234 Mdot
.896 .56267 Mdot
.896 .5627 Mdot
.896 .5632 Mdot
.896 .5634 Mdot
.896 .56379 Mdot
.896 .56436 Mdot
.896 .56472 Mdot
.896 .56529 Mdot
.896 .56569 Mdot
.896 .56569 Mdot
.896 .56602 Mdot
.896 .5666 Mdot
.896 .56687 Mdot
.896 .5671 Mdot
.896 .56732 Mdot
.896 .56751 Mdot
.896 .56774 Mdot
.896 .5679 Mdot
.896 .56799 Mdot
.896 .56813 Mdot
.896 .56818 Mdot
.896 .56823 Mdot
.896 .56831 Mdot
.896 .56858 Mdot
.896 .56952 Mdot
.896 .56958 Mdot
.896 .56959 Mdot
.896 .5703 Mdot
.896 .57053 Mdot
.896 .57107 Mdot
.896 .5711 Mdot
.896 .57141 Mdot
.896 .57166 Mdot
.896 .57196 Mdot
.896 .5722 Mdot
.896 .57242 Mdot
.896 .57273 Mdot
.896 .57302 Mdot
.896 .57308 Mdot
.896 .57332 Mdot
.896 .57344 Mdot
.896 .57365 Mdot
.896 .57366 Mdot
.896 .57389 Mdot
.896 .57398 Mdot
.896 .57427 Mdot
.896 .57431 Mdot
.896 .57435 Mdot
.896 .57443 Mdot
.896 .57509 Mdot
.896 .57516 Mdot
.896 .57556 Mdot
.896 .57625 Mdot
.896 .57633 Mdot
.896 .57705 Mdot
.896 .57725 Mdot
.896 .57762 Mdot
.896 .57806 Mdot
.896 .5784 Mdot
.896 .57857 Mdot
.896 .57885 Mdot
.896 .57984 Mdot
.896 .58007 Mdot
.896 .58041 Mdot
.896 .58043 Mdot
.896 .58056 Mdot
.896 .5807 Mdot
.896 .58102 Mdot
.896 .58137 Mdot
.896 .58147 Mdot
.896 .58166 Mdot
.896 .58168 Mdot
.896 .58198 Mdot
.896 .58267 Mdot
.896 .58268 Mdot
.896 .58286 Mdot
.896 .58324 Mdot
.896 .58347 Mdot
.896 .5838 Mdot
.896 .58396 Mdot
.896 .58424 Mdot
.896 .58464 Mdot
.896 .58464 Mdot
.896 .58473 Mdot
.896 .58502 Mdot
.896 .58536 Mdot
.896 .58539 Mdot
.896 .58543 Mdot
.896 .58601 Mdot
.896 .58626 Mdot
.896 .58635 Mdot
.896 .5864 Mdot
.896 .58643 Mdot
.896 .58646 Mdot
.896 .58658 Mdot
.896 .58669 Mdot
.896 .58702 Mdot
.896 .58707 Mdot
.896 .5871 Mdot
.896 .58715 Mdot
.896 .58725 Mdot
.896 .58735 Mdot
.896 .58744 Mdot
.896 .58755 Mdot
.896 .58765 Mdot
.896 .58787 Mdot
.896 .58791 Mdot
.896 .58797 Mdot
.896 .5881 Mdot
.896 .58812 Mdot
.896 .58845 Mdot
.896 .58861 Mdot
.896 .5887 Mdot
.896 .58875 Mdot
.896 .58902 Mdot
.896 .58912 Mdot
.896 .58917 Mdot
.896 .58918 Mdot
.896 .58922 Mdot
.896 .58944 Mdot
.896 .58946 Mdot
.896 .58951 Mdot
.896 .58959 Mdot
.896 .58959 Mdot
.896 .58969 Mdot
.896 .58983 Mdot
.896 .58992 Mdot
.896 .59009 Mdot
.896 .59009 Mdot
.896 .59011 Mdot
.896 .59014 Mdot
.896 .59023 Mdot
.896 .59025 Mdot
.896 .59038 Mdot
.896 .59043 Mdot
.896 .5905 Mdot
.896 .59055 Mdot
.896 .59058 Mdot
.896 .59058 Mdot
.896 .59067 Mdot
.896 .5907 Mdot
.896 .59071 Mdot
.896 .59078 Mdot
.896 .59082 Mdot
.896 .59082 Mdot
.896 .59083 Mdot
.896 .59084 Mdot
.896 .59086 Mdot
.896 .59088 Mdot
.896 .59093 Mdot
.896 .59094 Mdot
.896 .59098 Mdot
.896 .591 Mdot
.896 .59101 Mdot
.896 .59103 Mdot
.896 .59104 Mdot
.896 .59107 Mdot
.896 .59108 Mdot
.896 .59108 Mdot
.896 .59108 Mdot
.898 .0608 Mdot
.898 .06081 Mdot
.898 .06082 Mdot
.898 .06082 Mdot
.898 .06084 Mdot
.898 .06085 Mdot
.898 .06097 Mdot
.898 .06105 Mdot
.898 .0613 Mdot
.898 .06149 Mdot
.898 .06166 Mdot
.898 .06179 Mdot
.898 .06207 Mdot
.898 .06268 Mdot
.898 .06281 Mdot
.898 .06289 Mdot
.898 .06289 Mdot
.898 .06297 Mdot
.898 .06304 Mdot
.898 .06311 Mdot
.898 .0634 Mdot
.898 .0634 Mdot
.898 .06341 Mdot
.898 .06369 Mdot
.898 .06371 Mdot
.898 .06411 Mdot
.898 .06436 Mdot
.898 .06438 Mdot
.898 .06449 Mdot
.898 .06472 Mdot
.898 .06473 Mdot
.898 .06486 Mdot
.898 .06516 Mdot
.898 .06546 Mdot
.898 .06548 Mdot
.898 .06554 Mdot
.898 .06581 Mdot
.898 .06608 Mdot
.898 .06645 Mdot
.898 .06648 Mdot
.898 .06696 Mdot
.898 .0671 Mdot
.898 .06717 Mdot
.898 .06719 Mdot
.898 .06726 Mdot
.898 .06763 Mdot
.898 .06773 Mdot
.898 .06797 Mdot
.898 .06808 Mdot
.898 .06881 Mdot
.898 .06884 Mdot
.898 .06914 Mdot
.898 .0697 Mdot
.898 .07034 Mdot
.898 .07074 Mdot
.898 .07088 Mdot
.898 .07129 Mdot
.898 .07133 Mdot
.898 .07176 Mdot
.898 .07216 Mdot
.898 .07231 Mdot
.898 .07244 Mdot
.898 .07245 Mdot
.898 .0733 Mdot
.898 .0736 Mdot
.898 .07371 Mdot
.898 .07425 Mdot
.898 .0751 Mdot
.898 .07517 Mdot
.898 .07518 Mdot
.898 .0758 Mdot
.898 .07606 Mdot
.898 .07685 Mdot
.898 .07721 Mdot
.898 .07773 Mdot
.898 .07842 Mdot
.898 .08204 Mdot
.898 .0841 Mdot
.898 .08417 Mdot
.898 .08438 Mdot
.898 .08454 Mdot
.898 .08482 Mdot
.898 .08522 Mdot
.898 .08539 Mdot
.898 .08546 Mdot
.898 .08558 Mdot
.898 .08691 Mdot
.898 .08769 Mdot
.898 .08939 Mdot
.898 .08952 Mdot
.898 .09185 Mdot
.898 .09217 Mdot
.898 .09219 Mdot
.898 .09359 Mdot
.898 .09378 Mdot
.898 .09452 Mdot
.898 .09588 Mdot
.898 .09593 Mdot
.898 .0971 Mdot
.898 .09766 Mdot
.898 .09785 Mdot
.898 .09813 Mdot
.898 .09857 Mdot
.898 .09941 Mdot
.898 .09972 Mdot
.898 .10472 Mdot
.898 .10662 Mdot
.898 .10705 Mdot
.898 .10771 Mdot
.898 .10797 Mdot
.898 .10832 Mdot
.898 .10901 Mdot
.898 .10921 Mdot
.898 .10937 Mdot
.898 .10973 Mdot
.898 .11109 Mdot
.898 .11114 Mdot
.898 .11144 Mdot
.898 .11157 Mdot
.898 .11269 Mdot
.898 .11468 Mdot
.898 .11686 Mdot
.898 .1169 Mdot
.898 .11706 Mdot
.898 .11736 Mdot
.898 .11737 Mdot
.898 .11774 Mdot
.898 .1181 Mdot
.898 .11961 Mdot
.898 .12012 Mdot
.898 .12037 Mdot
.898 .12038 Mdot
.898 .12043 Mdot
.898 .12163 Mdot
.898 .12248 Mdot
.898 .12262 Mdot
.898 .12298 Mdot
.898 .12304 Mdot
.898 .12364 Mdot
.898 .12378 Mdot
.898 .1239 Mdot
.898 .12421 Mdot
.898 .12425 Mdot
.898 .12553 Mdot
.898 .12608 Mdot
.898 .12625 Mdot
.898 .12642 Mdot
.898 .1271 Mdot
.898 .12719 Mdot
.898 .12825 Mdot
.898 .12892 Mdot
.898 .12917 Mdot
.898 .13007 Mdot
.898 .13008 Mdot
.898 .13016 Mdot
.898 .1303 Mdot
.898 .13051 Mdot
.898 .13095 Mdot
.898 .13168 Mdot
.898 .13194 Mdot
.898 .13242 Mdot
.898 .13339 Mdot
.898 .13342 Mdot
.898 .13364 Mdot
.898 .13385 Mdot
.898 .13528 Mdot
.898 .1354 Mdot
.898 .13582 Mdot
.898 .13629 Mdot
.898 .13764 Mdot
.898 .13873 Mdot
.898 .14049 Mdot
.898 .14207 Mdot
.898 .14257 Mdot
.898 .14411 Mdot
.898 .14571 Mdot
.898 .14688 Mdot
.898 .148 Mdot
.898 .14823 Mdot
.898 .14869 Mdot
.898 .14892 Mdot
.898 .15257 Mdot
.898 .1532 Mdot
.898 .15356 Mdot
.898 .15794 Mdot
.898 .15804 Mdot
.898 .1583 Mdot
.898 .15833 Mdot
.898 .16023 Mdot
.898 .16057 Mdot
.898 .16242 Mdot
.898 .16534 Mdot
.898 .16713 Mdot
.898 .16895 Mdot
.898 .17365 Mdot
.898 .17368 Mdot
.898 .17372 Mdot
.898 .1743 Mdot
.898 .17532 Mdot
.898 .17689 Mdot
.898 .1787 Mdot
.898 .18012 Mdot
.898 .18117 Mdot
.898 .18119 Mdot
.898 .18122 Mdot
.898 .18122 Mdot
.898 .1813 Mdot
.898 .18131 Mdot
.898 .18157 Mdot
.898 .18172 Mdot
.898 .18197 Mdot
.898 .1828 Mdot
.898 .18344 Mdot
.898 .184 Mdot
.898 .18441 Mdot
.898 .18536 Mdot
.898 .18555 Mdot
.898 .18572 Mdot
.898 .18734 Mdot
.898 .1875 Mdot
.898 .18779 Mdot
.898 .18783 Mdot
.898 .18802 Mdot
.898 .18802 Mdot
.898 .18831 Mdot
.898 .18836 Mdot
.898 .18854 Mdot
.898 .18875 Mdot
.898 .18896 Mdot
.898 .1897 Mdot
.898 .1897 Mdot
.898 .18973 Mdot
.898 .19065 Mdot
.898 .19074 Mdot
.898 .19094 Mdot
.898 .19118 Mdot
.898 .19203 Mdot
.898 .19286 Mdot
.898 .19291 Mdot
.898 .19327 Mdot
.898 .19354 Mdot
.898 .1939 Mdot
.898 .194 Mdot
.898 .19405 Mdot
.898 .19447 Mdot
.898 .19545 Mdot
.898 .196 Mdot
.898 .19641 Mdot
.898 .19648 Mdot
.898 .19668 Mdot
.898 .1971 Mdot
.898 .19725 Mdot
.898 .19756 Mdot
.898 .19842 Mdot
.898 .19866 Mdot
.898 .19886 Mdot
.898 .19887 Mdot
.898 .19962 Mdot
.898 .1997 Mdot
.898 .20057 Mdot
.898 .20125 Mdot
.898 .20172 Mdot
.898 .20193 Mdot
.898 .20202 Mdot
.898 .20223 Mdot
.898 .20224 Mdot
.898 .20271 Mdot
.898 .20341 Mdot
.898 .20374 Mdot
.898 .20452 Mdot
.898 .20468 Mdot
.898 .20486 Mdot
.898 .20542 Mdot
.898 .20599 Mdot
.898 .2072 Mdot
.898 .20732 Mdot
.898 .20811 Mdot
.898 .20811 Mdot
.898 .20825 Mdot
.898 .21004 Mdot
.898 .21008 Mdot
.898 .21075 Mdot
.898 .21209 Mdot
.898 .21335 Mdot
.898 .2135 Mdot
.898 .21352 Mdot
.898 .21366 Mdot
.898 .2138 Mdot
.898 .21443 Mdot
.898 .21475 Mdot
.898 .21481 Mdot
.898 .21484 Mdot
.898 .21484 Mdot
.898 .2151 Mdot
.898 .21521 Mdot
.898 .21523 Mdot
.898 .21542 Mdot
.898 .21561 Mdot
.898 .21658 Mdot
.898 .21779 Mdot
.898 .21784 Mdot
.898 .21831 Mdot
.898 .21874 Mdot
.898 .21877 Mdot
.898 .22143 Mdot
.898 .22153 Mdot
.898 .22238 Mdot
.898 .2227 Mdot
.898 .22337 Mdot
.898 .2244 Mdot
.898 .22481 Mdot
.898 .22704 Mdot
.898 .22727 Mdot
.898 .22729 Mdot
.898 .22846 Mdot
.898 .22923 Mdot
.898 .22986 Mdot
.898 .23003 Mdot
.898 .23084 Mdot
.898 .23199 Mdot
.898 .23248 Mdot
.898 .23252 Mdot
.898 .23286 Mdot
.898 .23361 Mdot
.898 .23502 Mdot
.898 .23521 Mdot
.898 .23537 Mdot
.898 .23734 Mdot
.898 .24143 Mdot
.898 .24502 Mdot
.898 .24512 Mdot
.898 .24669 Mdot
.898 .24834 Mdot
.898 .24842 Mdot
.898 .24859 Mdot
.898 .2501 Mdot
.898 .25067 Mdot
.898 .25305 Mdot
.898 .25344 Mdot
.898 .25456 Mdot
.898 .25475 Mdot
.898 .2554 Mdot
.898 .25585 Mdot
.898 .25595 Mdot
.898 .25665 Mdot
.898 .25669 Mdot
.898 .25734 Mdot
.898 .25788 Mdot
.898 .25806 Mdot
.898 .25812 Mdot
.898 .25839 Mdot
.898 .25855 Mdot
.898 .25861 Mdot
.898 .25897 Mdot
.898 .2595 Mdot
.898 .2595 Mdot
.898 .25961 Mdot
.898 .25983 Mdot
.898 .26101 Mdot
.898 .26103 Mdot
.898 .262 Mdot
.898 .2629 Mdot
.898 .26341 Mdot
.898 .26443 Mdot
.898 .26451 Mdot
.898 .2651 Mdot
.898 .26522 Mdot
.898 .2692 Mdot
.898 .26981 Mdot
.898 .27019 Mdot
.898 .27059 Mdot
.898 .27334 Mdot
.898 .2749 Mdot
.898 .27651 Mdot
.898 .27736 Mdot
.898 .27744 Mdot
.898 .2776 Mdot
.898 .27829 Mdot
.898 .27833 Mdot
.898 .28237 Mdot
.898 .2829 Mdot
.898 .28445 Mdot
.898 .28497 Mdot
.898 .28497 Mdot
.898 .28503 Mdot
.898 .28633 Mdot
.898 .28804 Mdot
.898 .28849 Mdot
.898 .2889 Mdot
.898 .28904 Mdot
.898 .29235 Mdot
.898 .29313 Mdot
.898 .29394 Mdot
.898 .29448 Mdot
.898 .29524 Mdot
.898 .29536 Mdot
.898 .29648 Mdot
.898 .29751 Mdot
.898 .29822 Mdot
.898 .29883 Mdot
.898 .29883 Mdot
.898 .2997 Mdot
.898 .29989 Mdot
.898 .29989 Mdot
.898 .30189 Mdot
.898 .30316 Mdot
.898 .3059 Mdot
.898 .3077 Mdot
.898 .30776 Mdot
.898 .30858 Mdot
.898 .30895 Mdot
.898 .30974 Mdot
.898 .30976 Mdot
.898 .31158 Mdot
.898 .31345 Mdot
.898 .31426 Mdot
.898 .31528 Mdot
.898 .31767 Mdot
.898 .31798 Mdot
.898 .31848 Mdot
.898 .31861 Mdot
.898 .31922 Mdot
.898 .31976 Mdot
.898 .32096 Mdot
.898 .32098 Mdot
.898 .32117 Mdot
.898 .32153 Mdot
.898 .32176 Mdot
.898 .32223 Mdot
.898 .3227 Mdot
.898 .32318 Mdot
.898 .32406 Mdot
.898 .32472 Mdot
.898 .32499 Mdot
.898 .32502 Mdot
.898 .3251 Mdot
.898 .32556 Mdot
.898 .32597 Mdot
.898 .3261 Mdot
.898 .32694 Mdot
.898 .32698 Mdot
.898 .3273 Mdot
.898 .32791 Mdot
.898 .32859 Mdot
.898 .32958 Mdot
.898 .33038 Mdot
.898 .33052 Mdot
.898 .33065 Mdot
.898 .33065 Mdot
.898 .33143 Mdot
.898 .33179 Mdot
.898 .33227 Mdot
.898 .3338 Mdot
.898 .33444 Mdot
.898 .33473 Mdot
.898 .3383 Mdot
.898 .33989 Mdot
.898 .33999 Mdot
.898 .34017 Mdot
.898 .34055 Mdot
.898 .34201 Mdot
.898 .34305 Mdot
.898 .34451 Mdot
.898 .3447 Mdot
.898 .3455 Mdot
.898 .34561 Mdot
.898 .34603 Mdot
.898 .34678 Mdot
.898 .3468 Mdot
.898 .34774 Mdot
.898 .34799 Mdot
.898 .34867 Mdot
.898 .35136 Mdot
.898 .35229 Mdot
.898 .35249 Mdot
.898 .3531 Mdot
.898 .35343 Mdot
.898 .35377 Mdot
.898 .3544 Mdot
.898 .35442 Mdot
.898 .35456 Mdot
.898 .35709 Mdot
.898 .35722 Mdot
.898 .35723 Mdot
.898 .35739 Mdot
.898 .35755 Mdot
.898 .35966 Mdot
.898 .36002 Mdot
.898 .36017 Mdot
.898 .36092 Mdot
.898 .361 Mdot
.898 .36107 Mdot
.898 .36181 Mdot
.898 .36254 Mdot
.898 .36255 Mdot
.898 .36258 Mdot
.898 .36272 Mdot
.898 .3629 Mdot
.898 .36318 Mdot
.898 .36386 Mdot
.898 .36387 Mdot
.898 .36396 Mdot
.898 .36404 Mdot
.898 .36464 Mdot
.898 .3648 Mdot
.898 .36551 Mdot
.898 .36592 Mdot
.898 .36658 Mdot
.898 .36718 Mdot
.898 .36853 Mdot
.898 .36895 Mdot
.898 .36936 Mdot
.898 .371 Mdot
.898 .37122 Mdot
.898 .37288 Mdot
.898 .373 Mdot
.898 .37367 Mdot
.898 .37378 Mdot
.898 .37442 Mdot
.898 .3754 Mdot
.898 .376 Mdot
.898 .37815 Mdot
.898 .37816 Mdot
.898 .37817 Mdot
.898 .37836 Mdot
.898 .37869 Mdot
.898 .3792 Mdot
.898 .37978 Mdot
.898 .38024 Mdot
.898 .38195 Mdot
.898 .382 Mdot
.898 .38256 Mdot
.898 .38363 Mdot
.898 .3837 Mdot
.898 .38454 Mdot
.898 .38598 Mdot
.898 .38604 Mdot
.898 .38655 Mdot
.898 .38706 Mdot
.898 .38778 Mdot
.898 .3888 Mdot
.898 .38938 Mdot
.898 .39038 Mdot
.898 .39038 Mdot
.898 .39042 Mdot
.898 .39065 Mdot
.898 .39076 Mdot
.898 .39077 Mdot
.898 .39087 Mdot
.898 .39093 Mdot
.898 .39162 Mdot
.898 .39269 Mdot
.898 .39506 Mdot
.898 .3958 Mdot
.898 .3959 Mdot
.898 .39828 Mdot
.898 .40065 Mdot
.898 .40081 Mdot
.898 .40156 Mdot
.898 .40223 Mdot
.898 .40359 Mdot
.898 .40386 Mdot
.898 .40578 Mdot
.898 .40687 Mdot
.898 .40771 Mdot
.898 .41027 Mdot
.898 .41378 Mdot
.898 .41378 Mdot
.898 .41631 Mdot
.898 .41772 Mdot
.898 .41854 Mdot
.898 .41873 Mdot
.898 .41922 Mdot
.898 .41996 Mdot
.898 .42012 Mdot
.898 .42019 Mdot
.898 .42022 Mdot
.898 .4207 Mdot
.898 .4211 Mdot
.898 .42242 Mdot
.898 .42838 Mdot
.898 .42969 Mdot
.898 .43042 Mdot
.898 .43228 Mdot
.898 .435 Mdot
.898 .43812 Mdot
.898 .43938 Mdot
.898 .43957 Mdot
.898 .44009 Mdot
.898 .44016 Mdot
.898 .44394 Mdot
.898 .44461 Mdot
.898 .44495 Mdot
.898 .44754 Mdot
.898 .44826 Mdot
.898 .4516 Mdot
.898 .45389 Mdot
.898 .45598 Mdot
.898 .45729 Mdot
.898 .46071 Mdot
.898 .46225 Mdot
.898 .46358 Mdot
.898 .4683 Mdot
.898 .46892 Mdot
.898 .46933 Mdot
.898 .46938 Mdot
.898 .46945 Mdot
.898 .47012 Mdot
.898 .4705 Mdot
.898 .47232 Mdot
.898 .47509 Mdot
.898 .47682 Mdot
.898 .47694 Mdot
.898 .47785 Mdot
.898 .47818 Mdot
.898 .47825 Mdot
.898 .48035 Mdot
.898 .48072 Mdot
.898 .48251 Mdot
.898 .48254 Mdot
.898 .48258 Mdot
.898 .48259 Mdot
.898 .48273 Mdot
.898 .48275 Mdot
.898 .48318 Mdot
.898 .48343 Mdot
.898 .48387 Mdot
.898 .48526 Mdot
.898 .48565 Mdot
.898 .48633 Mdot
.898 .48727 Mdot
.898 .48795 Mdot
.898 .48952 Mdot
.898 .48983 Mdot
.898 .49011 Mdot
.898 .49016 Mdot
.898 .49275 Mdot
.898 .49302 Mdot
.898 .49319 Mdot
.898 .49347 Mdot
.898 .49354 Mdot
.898 .49386 Mdot
.898 .49386 Mdot
.898 .49432 Mdot
.898 .49438 Mdot
.898 .49439 Mdot
.898 .49469 Mdot
.898 .49502 Mdot
.898 .49535 Mdot
.898 .49647 Mdot
.898 .49653 Mdot
.898 .49654 Mdot
.898 .49659 Mdot
.898 .49805 Mdot
.898 .49818 Mdot
.898 .4985 Mdot
.898 .49887 Mdot
.898 .5002 Mdot
.898 .50149 Mdot
.898 .50156 Mdot
.898 .50213 Mdot
.898 .50253 Mdot
.898 .5031 Mdot
.898 .50325 Mdot
.898 .50332 Mdot
.898 .50397 Mdot
.898 .50545 Mdot
.898 .5057 Mdot
.898 .50628 Mdot
.898 .5069 Mdot
.898 .507 Mdot
.898 .5073 Mdot
.898 .50768 Mdot
.898 .50793 Mdot
.898 .50816 Mdot
.898 .50828 Mdot
.898 .50861 Mdot
.898 .50899 Mdot
.898 .50903 Mdot
.898 .50913 Mdot
.898 .50938 Mdot
.898 .50989 Mdot
.898 .51024 Mdot
.898 .51046 Mdot
.898 .51053 Mdot
.898 .51054 Mdot
.898 .51118 Mdot
.898 .51146 Mdot
.898 .51165 Mdot
.898 .51176 Mdot
.898 .51264 Mdot
.898 .51302 Mdot
.898 .514 Mdot
.898 .51467 Mdot
.898 .51468 Mdot
.898 .51497 Mdot
.898 .5151 Mdot
.898 .5154 Mdot
.898 .51542 Mdot
.898 .51607 Mdot
.898 .51707 Mdot
.898 .51753 Mdot
.898 .51824 Mdot
.898 .51824 Mdot
.898 .51862 Mdot
.898 .51884 Mdot
.898 .5191 Mdot
.898 .51986 Mdot
.898 .52066 Mdot
.898 .5223 Mdot
.898 .52246 Mdot
.898 .52306 Mdot
.898 .52353 Mdot
.898 .52353 Mdot
.898 .52372 Mdot
.898 .5261 Mdot
.898 .52615 Mdot
.898 .52647 Mdot
.898 .52703 Mdot
.898 .52757 Mdot
.898 .52878 Mdot
.898 .52898 Mdot
.898 .53038 Mdot
.898 .53058 Mdot
.898 .53061 Mdot
.898 .53078 Mdot
.898 .53095 Mdot
.898 .53143 Mdot
.898 .53176 Mdot
.898 .53176 Mdot
.898 .53216 Mdot
.898 .53224 Mdot
.898 .53227 Mdot
.898 .53227 Mdot
.898 .53259 Mdot
.898 .53274 Mdot
.898 .53276 Mdot
.898 .533 Mdot
.898 .53323 Mdot
.898 .53346 Mdot
.898 .5343 Mdot
.898 .53443 Mdot
.898 .53522 Mdot
.898 .53541 Mdot
.898 .53591 Mdot
.898 .53597 Mdot
.898 .53654 Mdot
.898 .53706 Mdot
.898 .53709 Mdot
.898 .53827 Mdot
.898 .54025 Mdot
.898 .54036 Mdot
.898 .54106 Mdot
.898 .54117 Mdot
.898 .54134 Mdot
.898 .54172 Mdot
.898 .54203 Mdot
.898 .54248 Mdot
.898 .54365 Mdot
.898 .54411 Mdot
.898 .5447 Mdot
.898 .54589 Mdot
.898 .54658 Mdot
.898 .54664 Mdot
.898 .54671 Mdot
.898 .54682 Mdot
.898 .54682 Mdot
.898 .54683 Mdot
.898 .54685 Mdot
.898 .54695 Mdot
.898 .5472 Mdot
.898 .54724 Mdot
.898 .54724 Mdot
.898 .54811 Mdot
.898 .54832 Mdot
.898 .54894 Mdot
.898 .54894 Mdot
.898 .5496 Mdot
.898 .54978 Mdot
.898 .55001 Mdot
.898 .55062 Mdot
.898 .55077 Mdot
.898 .55129 Mdot
.898 .55182 Mdot
.898 .55182 Mdot
.898 .55188 Mdot
.898 .55231 Mdot
.898 .55236 Mdot
.898 .5527 Mdot
.898 .55335 Mdot
.898 .55346 Mdot
.898 .55418 Mdot
.898 .55425 Mdot
.898 .55486 Mdot
.898 .55505 Mdot
.898 .55521 Mdot
.898 .55531 Mdot
.898 .55585 Mdot
.898 .5559 Mdot
.898 .55711 Mdot
.898 .55755 Mdot
.898 .55798 Mdot
.898 .55852 Mdot
.898 .55899 Mdot
.898 .5593 Mdot
.898 .55947 Mdot
.898 .55949 Mdot
.898 .55949 Mdot
.898 .5609 Mdot
.898 .56144 Mdot
.898 .56197 Mdot
.898 .56284 Mdot
.898 .56339 Mdot
.898 .56349 Mdot
.898 .56405 Mdot
.898 .56406 Mdot
.898 .56413 Mdot
.898 .56416 Mdot
.898 .56545 Mdot
.898 .56555 Mdot
.898 .56574 Mdot
.898 .5668 Mdot
.898 .56687 Mdot
.898 .567 Mdot
.898 .56707 Mdot
.898 .5674 Mdot
.898 .56774 Mdot
.898 .5682 Mdot
.898 .56865 Mdot
.898 .56879 Mdot
.898 .56925 Mdot
.898 .56976 Mdot
.898 .57007 Mdot
.898 .57046 Mdot
.898 .57059 Mdot
.898 .57071 Mdot
.898 .57075 Mdot
.898 .57116 Mdot
.898 .57122 Mdot
.898 .57128 Mdot
.898 .57129 Mdot
.898 .57157 Mdot
.898 .57171 Mdot
.898 .57178 Mdot
.898 .57199 Mdot
.898 .57211 Mdot
.898 .57217 Mdot
.898 .57221 Mdot
.898 .57224 Mdot
.898 .57224 Mdot
.898 .57249 Mdot
.898 .57257 Mdot
.898 .57276 Mdot
.898 .57306 Mdot
.898 .57309 Mdot
.898 .57328 Mdot
.898 .57332 Mdot
.898 .57337 Mdot
.898 .57353 Mdot
.898 .57389 Mdot
.898 .5739 Mdot
.898 .57399 Mdot
.898 .57403 Mdot
.898 .57407 Mdot
.898 .57424 Mdot
.898 .57425 Mdot
.898 .57436 Mdot
.898 .5744 Mdot
.898 .57464 Mdot
.898 .57499 Mdot
.898 .57499 Mdot
.898 .57506 Mdot
.898 .57521 Mdot
.898 .57563 Mdot
.898 .57573 Mdot
.898 .57584 Mdot
.898 .57584 Mdot
.898 .57592 Mdot
.898 .57597 Mdot
.898 .57598 Mdot
.898 .57659 Mdot
.898 .57715 Mdot
.898 .57746 Mdot
.898 .5775 Mdot
.898 .57759 Mdot
.898 .5776 Mdot
.898 .57798 Mdot
.898 .57808 Mdot
.898 .57812 Mdot
.898 .57818 Mdot
.898 .57837 Mdot
.898 .57847 Mdot
.898 .57854 Mdot
.898 .57873 Mdot
.898 .57885 Mdot
.898 .57938 Mdot
.898 .58076 Mdot
.898 .58085 Mdot
.898 .58108 Mdot
.898 .5812 Mdot
.898 .58128 Mdot
.898 .58133 Mdot
.898 .58148 Mdot
.898 .58181 Mdot
.898 .58182 Mdot
.898 .58219 Mdot
.898 .5824 Mdot
.898 .58245 Mdot
.898 .58283 Mdot
.898 .58284 Mdot
.898 .58293 Mdot
.898 .58356 Mdot
.898 .5836 Mdot
.898 .58406 Mdot
.898 .58428 Mdot
.898 .58464 Mdot
.898 .58467 Mdot
.898 .58469 Mdot
.898 .58474 Mdot
.898 .58485 Mdot
.898 .58493 Mdot
.898 .58497 Mdot
.898 .58503 Mdot
.898 .58504 Mdot
.898 .58561 Mdot
.898 .58658 Mdot
.898 .58677 Mdot
.898 .58691 Mdot
.898 .58701 Mdot
.898 .58722 Mdot
.898 .58729 Mdot
.898 .58746 Mdot
.898 .58746 Mdot
.898 .58748 Mdot
.898 .58771 Mdot
.898 .58786 Mdot
.898 .58789 Mdot
.898 .58797 Mdot
.898 .5882 Mdot
.898 .5882 Mdot
.898 .58823 Mdot
.898 .58827 Mdot
.898 .58838 Mdot
.898 .5885 Mdot
.898 .58851 Mdot
.898 .58862 Mdot
.898 .58866 Mdot
.898 .58876 Mdot
.898 .58894 Mdot
.898 .58909 Mdot
.898 .58916 Mdot
.898 .58917 Mdot
.898 .58937 Mdot
.898 .5894 Mdot
.898 .58946 Mdot
.898 .58949 Mdot
.898 .58959 Mdot
.898 .58961 Mdot
.898 .58961 Mdot
.898 .58963 Mdot
.898 .58967 Mdot
.898 .5898 Mdot
.898 .58981 Mdot
.898 .5899 Mdot
.898 .58998 Mdot
.898 .59005 Mdot
.898 .59007 Mdot
.898 .59007 Mdot
.898 .59015 Mdot
.898 .59023 Mdot
.898 .59027 Mdot
.898 .59027 Mdot
.898 .59033 Mdot
.898 .59036 Mdot
.898 .59036 Mdot
.898 .59043 Mdot
.898 .59054 Mdot
.898 .59054 Mdot
.898 .59062 Mdot
.898 .59062 Mdot
.898 .59062 Mdot
.898 .5907 Mdot
.898 .59072 Mdot
.898 .59073 Mdot
.898 .59076 Mdot
.898 .59076 Mdot
.898 .59078 Mdot
.898 .59081 Mdot
.898 .59097 Mdot
.898 .59105 Mdot
.898 .59108 Mdot
.898 .59113 Mdot
.898 .59118 Mdot
.898 .59125 Mdot
.898 .59127 Mdot
.898 .5913 Mdot
.898 .5913 Mdot
.898 .59131 Mdot
.898 .59131 Mdot
.898 .59131 Mdot
.898 .59131 Mdot
.9 .05994 Mdot
.9 .05996 Mdot
.9 .05996 Mdot
.9 .05998 Mdot
.9 .06 Mdot
.9 .06 Mdot
.9 .06001 Mdot
.9 .06004 Mdot
.9 .0601 Mdot
.9 .06027 Mdot
.9 .06032 Mdot
.9 .06034 Mdot
.9 .0604 Mdot
.9 .06042 Mdot
.9 .06064 Mdot
.9 .06077 Mdot
.9 .06083 Mdot
.9 .06095 Mdot
.9 .06105 Mdot
.9 .06114 Mdot
.9 .06129 Mdot
.9 .06131 Mdot
.9 .06209 Mdot
.9 .06249 Mdot
.9 .06273 Mdot
.9 .06277 Mdot
.9 .06306 Mdot
.9 .06346 Mdot
.9 .06356 Mdot
.9 .06369 Mdot
.9 .06391 Mdot
.9 .06411 Mdot
.9 .06455 Mdot
.9 .06478 Mdot
.9 .06478 Mdot
.9 .065 Mdot
.9 .06511 Mdot
.9 .06518 Mdot
.9 .0658 Mdot
.9 .06617 Mdot
.9 .0666 Mdot
.9 .06679 Mdot
.9 .06703 Mdot
.9 .06722 Mdot
.9 .06723 Mdot
.9 .06936 Mdot
.9 .06952 Mdot
.9 .06965 Mdot
.9 .07074 Mdot
.9 .07147 Mdot
.9 .07209 Mdot
.9 .07287 Mdot
.9 .07439 Mdot
.9 .07494 Mdot
.9 .07568 Mdot
.9 .07602 Mdot
.9 .07623 Mdot
.9 .07654 Mdot
.9 .07658 Mdot
.9 .07789 Mdot
.9 .07888 Mdot
.9 .07927 Mdot
.9 .07949 Mdot
.9 .0798 Mdot
.9 .08015 Mdot
.9 .08026 Mdot
.9 .08032 Mdot
.9 .08115 Mdot
.9 .08167 Mdot
.9 .08172 Mdot
.9 .08224 Mdot
.9 .08236 Mdot
.9 .08312 Mdot
.9 .08401 Mdot
.9 .08406 Mdot
.9 .08461 Mdot
.9 .08472 Mdot
.9 .08494 Mdot
.9 .08613 Mdot
.9 .08626 Mdot
.9 .08893 Mdot
.9 .08917 Mdot
.9 .08954 Mdot
.9 .0899 Mdot
.9 .09035 Mdot
.9 .09177 Mdot
.9 .09185 Mdot
.9 .09218 Mdot
.9 .09287 Mdot
.9 .09407 Mdot
.9 .09602 Mdot
.9 .09608 Mdot
.9 .09699 Mdot
.9 .09787 Mdot
.9 .09803 Mdot
.9 .09815 Mdot
.9 .0987 Mdot
.9 .0994 Mdot
.9 .10095 Mdot
.9 .1016 Mdot
.9 .10268 Mdot
.9 .10559 Mdot
.9 .10693 Mdot
.9 .10819 Mdot
.9 .10909 Mdot
.9 .11037 Mdot
.9 .11269 Mdot
.9 .11337 Mdot
.9 .11593 Mdot
.9 .11616 Mdot
.9 .11683 Mdot
.9 .11865 Mdot
.9 .12449 Mdot
.9 .1252 Mdot
.9 .1253 Mdot
.9 .12679 Mdot
.9 .12763 Mdot
.9 .12766 Mdot
.9 .1289 Mdot
.9 .12957 Mdot
.9 .13021 Mdot
.9 .13175 Mdot
.9 .13181 Mdot
.9 .13212 Mdot
.9 .13269 Mdot
.9 .13307 Mdot
.9 .13479 Mdot
.9 .13499 Mdot
.9 .1351 Mdot
.9 .13575 Mdot
.9 .13642 Mdot
.9 .13771 Mdot
.9 .13824 Mdot
.9 .13904 Mdot
.9 .1396 Mdot
.9 .13992 Mdot
.9 .14025 Mdot
.9 .14026 Mdot
.9 .14262 Mdot
.9 .14268 Mdot
.9 .14309 Mdot
.9 .14347 Mdot
.9 .14375 Mdot
.9 .14475 Mdot
.9 .14525 Mdot
.9 .14545 Mdot
.9 .14626 Mdot
.9 .14739 Mdot
.9 .14826 Mdot
.9 .14845 Mdot
.9 .14932 Mdot
.9 .15017 Mdot
.9 .15063 Mdot
.9 .15106 Mdot
.9 .15262 Mdot
.9 .1539 Mdot
.9 .15422 Mdot
.9 .15427 Mdot
.9 .15541 Mdot
.9 .15556 Mdot
.9 .15573 Mdot
.9 .15597 Mdot
.9 .15615 Mdot
.9 .15644 Mdot
.9 .15688 Mdot
.9 .15935 Mdot
.9 .16061 Mdot
.9 .16289 Mdot
.9 .16343 Mdot
.9 .1644 Mdot
.9 .16493 Mdot
.9 .16533 Mdot
.9 .16762 Mdot
.9 .16977 Mdot
.9 .17049 Mdot
.9 .17257 Mdot
.9 .1727 Mdot
.9 .17446 Mdot
.9 .17466 Mdot
.9 .17622 Mdot
.9 .17828 Mdot
.9 .17839 Mdot
.9 .17844 Mdot
.9 .17846 Mdot
.9 .1785 Mdot
.9 .17857 Mdot
.9 .17859 Mdot
.9 .1786 Mdot
.9 .17872 Mdot
.9 .17891 Mdot
.9 .17948 Mdot
.9 .17964 Mdot
.9 .17969 Mdot
.9 .17991 Mdot
.9 .17997 Mdot
.9 .18069 Mdot
.9 .18072 Mdot
.9 .18084 Mdot
.9 .18114 Mdot
.9 .18132 Mdot
.9 .18174 Mdot
.9 .18179 Mdot
.9 .18205 Mdot
.9 .18237 Mdot
.9 .18283 Mdot
.9 .18291 Mdot
.9 .18548 Mdot
.9 .1857 Mdot
.9 .18583 Mdot
.9 .18593 Mdot
.9 .18637 Mdot
.9 .18679 Mdot
.9 .18698 Mdot
.9 .18757 Mdot
.9 .18773 Mdot
.9 .18818 Mdot
.9 .18825 Mdot
.9 .18868 Mdot
.9 .18876 Mdot
.9 .18997 Mdot
.9 .19005 Mdot
.9 .19031 Mdot
.9 .19057 Mdot
.9 .19072 Mdot
.9 .19088 Mdot
.9 .19146 Mdot
.9 .19182 Mdot
.9 .1921 Mdot
.9 .19309 Mdot
.9 .19353 Mdot
.9 .19429 Mdot
.9 .1943 Mdot
.9 .19463 Mdot
.9 .19498 Mdot
.9 .19535 Mdot
.9 .19557 Mdot
.9 .19601 Mdot
.9 .19651 Mdot
.9 .19759 Mdot
.9 .1979 Mdot
.9 .19878 Mdot
.9 .19909 Mdot
.9 .19944 Mdot
.9 .19991 Mdot
.9 .20017 Mdot
.9 .20068 Mdot
.9 .2008 Mdot
.9 .20128 Mdot
.9 .20156 Mdot
.9 .20212 Mdot
.9 .20219 Mdot
.9 .20221 Mdot
.9 .20222 Mdot
.9 .20273 Mdot
.9 .2035 Mdot
.9 .20493 Mdot
.9 .20551 Mdot
.9 .20618 Mdot
.9 .20846 Mdot
.9 .20903 Mdot
.9 .20916 Mdot
.9 .20954 Mdot
.9 .20956 Mdot
.9 .20997 Mdot
.9 .2111 Mdot
.9 .21185 Mdot
.9 .21197 Mdot
.9 .21345 Mdot
.9 .2143 Mdot
.9 .21573 Mdot
.9 .21639 Mdot
.9 .21721 Mdot
.9 .21772 Mdot
.9 .21844 Mdot
.9 .22 Mdot
.9 .22018 Mdot
.9 .2205 Mdot
.9 .22136 Mdot
.9 .22236 Mdot
.9 .22255 Mdot
.9 .22493 Mdot
.9 .22664 Mdot
.9 .22895 Mdot
.9 .22999 Mdot
.9 .23042 Mdot
.9 .23064 Mdot
.9 .2308 Mdot
.9 .23126 Mdot
.9 .23149 Mdot
.9 .23163 Mdot
.9 .23173 Mdot
.9 .23308 Mdot
.9 .23432 Mdot
.9 .23504 Mdot
.9 .23506 Mdot
.9 .23579 Mdot
.9 .23736 Mdot
.9 .2374 Mdot
.9 .23817 Mdot
.9 .23883 Mdot
.9 .23934 Mdot
.9 .23997 Mdot
.9 .24001 Mdot
.9 .24069 Mdot
.9 .24164 Mdot
.9 .2424 Mdot
.9 .24271 Mdot
.9 .24304 Mdot
.9 .24322 Mdot
.9 .244 Mdot
.9 .24543 Mdot
.9 .24568 Mdot
.9 .24574 Mdot
.9 .24732 Mdot
.9 .24747 Mdot
.9 .24825 Mdot
.9 .24832 Mdot
.9 .24863 Mdot
.9 .24904 Mdot
.9 .24941 Mdot
.9 .24996 Mdot
.9 .25006 Mdot
.9 .25021 Mdot
.9 .25038 Mdot
.9 .25126 Mdot
.9 .25139 Mdot
.9 .25172 Mdot
.9 .25202 Mdot
.9 .25222 Mdot
.9 .25297 Mdot
.9 .25322 Mdot
.9 .25401 Mdot
.9 .25416 Mdot
.9 .25438 Mdot
.9 .2545 Mdot
.9 .25452 Mdot
.9 .25566 Mdot
.9 .25617 Mdot
.9 .25651 Mdot
.9 .25716 Mdot
.9 .2607 Mdot
.9 .261 Mdot
.9 .26109 Mdot
.9 .2642 Mdot
.9 .26729 Mdot
.9 .26895 Mdot
.9 .26932 Mdot
.9 .26967 Mdot
.9 .26975 Mdot
.9 .27022 Mdot
.9 .27074 Mdot
.9 .27181 Mdot
.9 .27306 Mdot
.9 .2731 Mdot
.9 .27393 Mdot
.9 .2744 Mdot
.9 .27724 Mdot
.9 .27738 Mdot
.9 .27746 Mdot
.9 .27784 Mdot
.9 .27843 Mdot
.9 .27894 Mdot
.9 .27903 Mdot
.9 .2804 Mdot
.9 .28048 Mdot
.9 .28095 Mdot
.9 .28112 Mdot
.9 .28315 Mdot
.9 .28342 Mdot
.9 .28386 Mdot
.9 .28492 Mdot
.9 .28942 Mdot
.9 .28958 Mdot
.9 .29193 Mdot
.9 .29194 Mdot
.9 .29217 Mdot
.9 .29323 Mdot
.9 .29454 Mdot
.9 .29463 Mdot
.9 .2951 Mdot
.9 .29543 Mdot
.9 .2961 Mdot
.9 .29677 Mdot
.9 .29698 Mdot
.9 .29784 Mdot
.9 .29892 Mdot
.9 .30168 Mdot
.9 .30236 Mdot
.9 .30324 Mdot
.9 .30471 Mdot
.9 .30502 Mdot
.9 .30537 Mdot
.9 .30736 Mdot
.9 .30738 Mdot
.9 .30747 Mdot
.9 .30777 Mdot
.9 .308 Mdot
.9 .30852 Mdot
.9 .30995 Mdot
.9 .31106 Mdot
.9 .31157 Mdot
.9 .31293 Mdot
.9 .31341 Mdot
.9 .3143 Mdot
.9 .31539 Mdot
.9 .31596 Mdot
.9 .31642 Mdot
.9 .31829 Mdot
.9 .31957 Mdot
.9 .31966 Mdot
.9 .32088 Mdot
.9 .32163 Mdot
.9 .32294 Mdot
.9 .32324 Mdot
.9 .32433 Mdot
.9 .32534 Mdot
.9 .32558 Mdot
.9 .32875 Mdot
.9 .32984 Mdot
.9 .33052 Mdot
.9 .3311 Mdot
.9 .33181 Mdot
.9 .33357 Mdot
.9 .33444 Mdot
.9 .33486 Mdot
.9 .3359 Mdot
.9 .33663 Mdot
.9 .3373 Mdot
.9 .33767 Mdot
.9 .33825 Mdot
.9 .33862 Mdot
.9 .33865 Mdot
.9 .34022 Mdot
.9 .34155 Mdot
.9 .34163 Mdot
.9 .34327 Mdot
.9 .34341 Mdot
.9 .34384 Mdot
.9 .34517 Mdot
.9 .34555 Mdot
.9 .34733 Mdot
.9 .34843 Mdot
.9 .34987 Mdot
.9 .3502 Mdot
.9 .35217 Mdot
.9 .35282 Mdot
.9 .35341 Mdot
.9 .35443 Mdot
.9 .35549 Mdot
.9 .3558 Mdot
.9 .35812 Mdot
.9 .36058 Mdot
.9 .36092 Mdot
.9 .36188 Mdot
.9 .36264 Mdot
.9 .3629 Mdot
.9 .36469 Mdot
.9 .36477 Mdot
.9 .36532 Mdot
.9 .36653 Mdot
.9 .36677 Mdot
.9 .36768 Mdot
.9 .36844 Mdot
.9 .3687 Mdot
.9 .37009 Mdot
.9 .3704 Mdot
.9 .37127 Mdot
.9 .37172 Mdot
.9 .37183 Mdot
.9 .37185 Mdot
.9 .37224 Mdot
.9 .37244 Mdot
.9 .3725 Mdot
.9 .37276 Mdot
.9 .3736 Mdot
.9 .3755 Mdot
.9 .3771 Mdot
.9 .37863 Mdot
.9 .38098 Mdot
.9 .3822 Mdot
.9 .38227 Mdot
.9 .38241 Mdot
.9 .3826 Mdot
.9 .38315 Mdot
.9 .38355 Mdot
.9 .38381 Mdot
.9 .3841 Mdot
.9 .38448 Mdot
.9 .38537 Mdot
.9 .38552 Mdot
.9 .38594 Mdot
.9 .38695 Mdot
.9 .38721 Mdot
.9 .38821 Mdot
.9 .38841 Mdot
.9 .38929 Mdot
.9 .3894 Mdot
.9 .38986 Mdot
.9 .39007 Mdot
.9 .39011 Mdot
.9 .39079 Mdot
.9 .39162 Mdot
.9 .39198 Mdot
.9 .39243 Mdot
.9 .39257 Mdot
.9 .39281 Mdot
.9 .39315 Mdot
.9 .39537 Mdot
.9 .39561 Mdot
.9 .39612 Mdot
.9 .39647 Mdot
.9 .39667 Mdot
.9 .39731 Mdot
.9 .39732 Mdot
.9 .3987 Mdot
.9 .39914 Mdot
.9 .39953 Mdot
.9 .4003 Mdot
.9 .4004 Mdot
.9 .40076 Mdot
.9 .40079 Mdot
.9 .40087 Mdot
.9 .40111 Mdot
.9 .40115 Mdot
.9 .40132 Mdot
.9 .40137 Mdot
.9 .40157 Mdot
.9 .40186 Mdot
.9 .4019 Mdot
.9 .40199 Mdot
.9 .40541 Mdot
.9 .40594 Mdot
.9 .40716 Mdot
.9 .40728 Mdot
.9 .40819 Mdot
.9 .40904 Mdot
.9 .40964 Mdot
.9 .41003 Mdot
.9 .41185 Mdot
.9 .41218 Mdot
.9 .41292 Mdot
.9 .41337 Mdot
.9 .41436 Mdot
.9 .41513 Mdot
.9 .41611 Mdot
.9 .41689 Mdot
.9 .41758 Mdot
.9 .41944 Mdot
.9 .41985 Mdot
.9 .42169 Mdot
.9 .42184 Mdot
.9 .4235 Mdot
.9 .42365 Mdot
.9 .42414 Mdot
.9 .42448 Mdot
.9 .42539 Mdot
.9 .42865 Mdot
.9 .42959 Mdot
.9 .43131 Mdot
.9 .43196 Mdot
.9 .43207 Mdot
.9 .43211 Mdot
.9 .43441 Mdot
.9 .43472 Mdot
.9 .43482 Mdot
.9 .43506 Mdot
.9 .43556 Mdot
.9 .43592 Mdot
.9 .43651 Mdot
.9 .43741 Mdot
.9 .43891 Mdot
.9 .44062 Mdot
.9 .44076 Mdot
.9 .44236 Mdot
.9 .44292 Mdot
.9 .44486 Mdot
.9 .44689 Mdot
.9 .44934 Mdot
.9 .4498 Mdot
.9 .44983 Mdot
.9 .4504 Mdot
.9 .45147 Mdot
.9 .45225 Mdot
.9 .45226 Mdot
.9 .45292 Mdot
.9 .45329 Mdot
.9 .45364 Mdot
.9 .45404 Mdot
.9 .45489 Mdot
.9 .45491 Mdot
.9 .4564 Mdot
.9 .4584 Mdot
.9 .45842 Mdot
.9 .45949 Mdot
.9 .45956 Mdot
.9 .46041 Mdot
.9 .46242 Mdot
.9 .46374 Mdot
.9 .46496 Mdot
.9 .46756 Mdot
.9 .4678 Mdot
.9 .46865 Mdot
.9 .47096 Mdot
.9 .47132 Mdot
.9 .47213 Mdot
.9 .47313 Mdot
.9 .47411 Mdot
.9 .47596 Mdot
.9 .4762 Mdot
.9 .47773 Mdot
.9 .47791 Mdot
.9 .478 Mdot
.9 .47802 Mdot
.9 .4781 Mdot
.9 .47822 Mdot
.9 .47826 Mdot
.9 .47827 Mdot
.9 .47848 Mdot
.9 .47882 Mdot
.9 .47918 Mdot
.9 .47979 Mdot
.9 .48008 Mdot
.9 .48017 Mdot
.9 .48054 Mdot
.9 .48064 Mdot
.9 .48176 Mdot
.9 .48187 Mdot
.9 .48193 Mdot
.9 .48212 Mdot
.9 .48264 Mdot
.9 .48295 Mdot
.9 .48329 Mdot
.9 .48366 Mdot
.9 .48375 Mdot
.9 .48418 Mdot
.9 .48429 Mdot
.9 .48472 Mdot
.9 .4849 Mdot
.9 .48551 Mdot
.9 .48563 Mdot
.9 .48574 Mdot
.9 .48614 Mdot
.9 .48631 Mdot
.9 .48683 Mdot
.9 .48992 Mdot
.9 .49027 Mdot
.9 .49048 Mdot
.9 .49065 Mdot
.9 .49065 Mdot
.9 .4907 Mdot
.9 .49088 Mdot
.9 .49137 Mdot
.9 .49194 Mdot
.9 .49205 Mdot
.9 .49236 Mdot
.9 .49332 Mdot
.9 .49358 Mdot
.9 .49431 Mdot
.9 .49441 Mdot
.9 .49472 Mdot
.9 .49511 Mdot
.9 .49524 Mdot
.9 .49623 Mdot
.9 .49716 Mdot
.9 .49728 Mdot
.9 .49771 Mdot
.9 .49811 Mdot
.9 .49835 Mdot
.9 .4986 Mdot
.9 .49951 Mdot
.9 .50008 Mdot
.9 .50051 Mdot
.9 .50136 Mdot
.9 .50204 Mdot
.9 .50273 Mdot
.9 .50276 Mdot
.9 .50328 Mdot
.9 .50388 Mdot
.9 .5039 Mdot
.9 .50404 Mdot
.9 .50426 Mdot
.9 .5044 Mdot
.9 .50494 Mdot
.9 .5055 Mdot
.9 .50583 Mdot
.9 .5065 Mdot
.9 .50677 Mdot
.9 .50699 Mdot
.9 .50725 Mdot
.9 .50886 Mdot
.9 .50933 Mdot
.9 .50973 Mdot
.9 .51034 Mdot
.9 .51062 Mdot
.9 .51107 Mdot
.9 .51158 Mdot
.9 .51227 Mdot
.9 .51265 Mdot
.9 .51305 Mdot
.9 .51338 Mdot
.9 .51355 Mdot
.9 .51405 Mdot
.9 .51424 Mdot
.9 .51465 Mdot
.9 .51517 Mdot
.9 .51544 Mdot
.9 .51555 Mdot
.9 .51558 Mdot
.9 .51559 Mdot
.9 .51631 Mdot
.9 .51655 Mdot
.9 .5174 Mdot
.9 .51764 Mdot
.9 .51902 Mdot
.9 .5194 Mdot
.9 .51964 Mdot
.9 .5202 Mdot
.9 .52066 Mdot
.9 .52112 Mdot
.9 .52112 Mdot
.9 .52359 Mdot
.9 .52411 Mdot
.9 .52421 Mdot
.9 .52492 Mdot
.9 .52497 Mdot
.9 .52514 Mdot
.9 .52564 Mdot
.9 .52567 Mdot
.9 .52605 Mdot
.9 .52621 Mdot
.9 .52724 Mdot
.9 .5274 Mdot
.9 .5277 Mdot
.9 .52867 Mdot
.9 .52883 Mdot
.9 .52898 Mdot
.9 .52967 Mdot
.9 .53072 Mdot
.9 .5318 Mdot
.9 .5336 Mdot
.9 .53398 Mdot
.9 .5341 Mdot
.9 .53415 Mdot
.9 .53441 Mdot
.9 .53449 Mdot
.9 .53474 Mdot
.9 .53481 Mdot
.9 .53502 Mdot
.9 .53506 Mdot
.9 .53535 Mdot
.9 .53541 Mdot
.9 .53546 Mdot
.9 .53549 Mdot
.9 .53593 Mdot
.9 .53603 Mdot
.9 .53606 Mdot
.9 .53691 Mdot
.9 .53699 Mdot
.9 .53746 Mdot
.9 .53798 Mdot
.9 .53878 Mdot
.9 .53899 Mdot
.9 .53937 Mdot
.9 .53962 Mdot
.9 .53963 Mdot
.9 .54038 Mdot
.9 .54038 Mdot
.9 .54062 Mdot
.9 .54102 Mdot
.9 .54153 Mdot
.9 .54161 Mdot
.9 .54176 Mdot
.9 .54188 Mdot
.9 .5444 Mdot
.9 .54446 Mdot
.9 .54478 Mdot
.9 .54506 Mdot
.9 .54521 Mdot
.9 .54571 Mdot
.9 .5461 Mdot
.9 .54636 Mdot
.9 .54702 Mdot
.9 .54775 Mdot
.9 .54779 Mdot
.9 .54803 Mdot
.9 .54852 Mdot
.9 .54864 Mdot
.9 .54885 Mdot
.9 .54957 Mdot
.9 .54978 Mdot
.9 .54996 Mdot
.9 .5504 Mdot
.9 .55064 Mdot
.9 .5508 Mdot
.9 .55083 Mdot
.9 .55109 Mdot
.9 .55128 Mdot
.9 .55152 Mdot
.9 .55166 Mdot
.9 .55177 Mdot
.9 .55214 Mdot
.9 .55257 Mdot
.9 .55272 Mdot
.9 .55315 Mdot
.9 .55362 Mdot
.9 .55401 Mdot
.9 .5543 Mdot
.9 .55439 Mdot
.9 .55455 Mdot
.9 .55494 Mdot
.9 .5551 Mdot
.9 .55512 Mdot
.9 .55549 Mdot
.9 .55567 Mdot
.9 .55581 Mdot
.9 .55584 Mdot
.9 .55588 Mdot
.9 .55706 Mdot
.9 .55735 Mdot
.9 .55739 Mdot
.9 .55812 Mdot
.9 .55874 Mdot
.9 .55921 Mdot
.9 .55927 Mdot
.9 .5598 Mdot
.9 .55984 Mdot
.9 .56046 Mdot
.9 .56067 Mdot
.9 .56131 Mdot
.9 .562 Mdot
.9 .56211 Mdot
.9 .56227 Mdot
.9 .56256 Mdot
.9 .56272 Mdot
.9 .56339 Mdot
.9 .56376 Mdot
.9 .56449 Mdot
.9 .56462 Mdot
.9 .5647 Mdot
.9 .56476 Mdot
.9 .56483 Mdot
.9 .56488 Mdot
.9 .56492 Mdot
.9 .56526 Mdot
.9 .56527 Mdot
.9 .56536 Mdot
.9 .56574 Mdot
.9 .5662 Mdot
.9 .56632 Mdot
.9 .56646 Mdot
.9 .5667 Mdot
.9 .56696 Mdot
.9 .56701 Mdot
.9 .56726 Mdot
.9 .56759 Mdot
.9 .56783 Mdot
.9 .56789 Mdot
.9 .56803 Mdot
.9 .56832 Mdot
.9 .5684 Mdot
.9 .56851 Mdot
.9 .56863 Mdot
.9 .56865 Mdot
.9 .56933 Mdot
.9 .56933 Mdot
.9 .56943 Mdot
.9 .56952 Mdot
.9 .56968 Mdot
.9 .56991 Mdot
.9 .57006 Mdot
.9 .57043 Mdot
.9 .57063 Mdot
.9 .57081 Mdot
.9 .57084 Mdot
.9 .5709 Mdot
.9 .5714 Mdot
.9 .5715 Mdot
.9 .57167 Mdot
.9 .57176 Mdot
.9 .57177 Mdot
.9 .57221 Mdot
.9 .57239 Mdot
.9 .57258 Mdot
.9 .57294 Mdot
.9 .57295 Mdot
.9 .57319 Mdot
.9 .57361 Mdot
.9 .57364 Mdot
.9 .57384 Mdot
.9 .57549 Mdot
.9 .576 Mdot
.9 .57619 Mdot
.9 .57625 Mdot
.9 .57697 Mdot
.9 .57716 Mdot
.9 .57781 Mdot
.9 .57817 Mdot
.9 .57842 Mdot
.9 .57877 Mdot
.9 .57914 Mdot
.9 .57995 Mdot
.9 .58025 Mdot
.9 .58043 Mdot
.9 .58086 Mdot
.9 .58105 Mdot
.9 .5812 Mdot
.9 .58124 Mdot
.9 .58128 Mdot
.9 .58152 Mdot
.9 .58177 Mdot
.9 .58179 Mdot
.9 .58233 Mdot
.9 .58266 Mdot
.9 .58284 Mdot
.9 .58294 Mdot
.9 .58296 Mdot
.9 .58335 Mdot
.9 .58347 Mdot
.9 .58357 Mdot
.9 .58367 Mdot
.9 .58374 Mdot
.9 .58446 Mdot
.9 .5845 Mdot
.9 .58482 Mdot
.9 .58488 Mdot
.9 .58491 Mdot
.9 .58506 Mdot
.9 .58508 Mdot
.9 .58532 Mdot
.9 .58552 Mdot
.9 .58556 Mdot
.9 .5857 Mdot
.9 .58571 Mdot
.9 .58585 Mdot
.9 .58608 Mdot
.9 .58609 Mdot
.9 .58612 Mdot
.9 .58622 Mdot
.9 .5863 Mdot
.9 .58636 Mdot
.9 .58647 Mdot
.9 .58674 Mdot
.9 .58709 Mdot
.9 .5871 Mdot
.9 .58719 Mdot
.9 .58724 Mdot
.9 .58733 Mdot
.9 .58753 Mdot
.9 .58768 Mdot
.9 .58809 Mdot
.9 .5883 Mdot
.9 .58847 Mdot
.9 .58866 Mdot
.9 .58895 Mdot
.9 .58899 Mdot
.9 .58903 Mdot
.9 .5896 Mdot
.9 .5896 Mdot
.9 .58966 Mdot
.9 .58972 Mdot
.9 .58977 Mdot
.9 .58989 Mdot
.9 .58999 Mdot
.9 .59015 Mdot
.9 .59017 Mdot
.9 .5902 Mdot
.9 .59026 Mdot
.9 .59026 Mdot
.9 .59032 Mdot
.9 .59044 Mdot
.9 .59049 Mdot
.9 .59055 Mdot
.9 .59058 Mdot
.9 .59061 Mdot
.9 .59071 Mdot
.9 .59079 Mdot
.9 .59081 Mdot
.9 .59087 Mdot
.9 .59097 Mdot
.9 .59118 Mdot
.9 .59119 Mdot
.9 .59123 Mdot
.9 .59125 Mdot
.9 .59128 Mdot
.9 .59131 Mdot
.9 .59133 Mdot
.9 .59136 Mdot
.9 .59142 Mdot
.9 .59142 Mdot
.9 .59144 Mdot
.9 .59145 Mdot
.9 .59146 Mdot
.9 .5915 Mdot
.9 .59152 Mdot
.9 .59153 Mdot
.9 .59153 Mdot
.9 .59153 Mdot
.9 .59154 Mdot
.9 .59154 Mdot
.9 .59154 Mdot
.9 .59155 Mdot
.902 .05907 Mdot
.902 .05908 Mdot
.902 .05909 Mdot
.902 .05909 Mdot
.902 .05912 Mdot
.902 .05913 Mdot
.902 .05922 Mdot
.902 .05928 Mdot
.902 .05944 Mdot
.902 .05949 Mdot
.902 .05969 Mdot
.902 .05974 Mdot
.902 .05977 Mdot
.902 .06001 Mdot
.902 .06008 Mdot
.902 .06009 Mdot
.902 .0601 Mdot
.902 .06024 Mdot
.902 .06037 Mdot
.902 .06038 Mdot
.902 .06057 Mdot
.902 .0611 Mdot
.902 .06153 Mdot
.902 .06178 Mdot
.902 .06195 Mdot
.902 .06211 Mdot
.902 .06217 Mdot
.902 .06228 Mdot
.902 .06229 Mdot
.902 .06319 Mdot
.902 .06326 Mdot
.902 .0644 Mdot
.902 .06465 Mdot
.902 .06506 Mdot
.902 .0652 Mdot
.902 .06552 Mdot
.902 .06572 Mdot
.902 .06581 Mdot
.902 .0659 Mdot
.902 .06617 Mdot
.902 .06663 Mdot
.902 .06697 Mdot
.902 .06761 Mdot
.902 .06766 Mdot
.902 .06787 Mdot
.902 .06834 Mdot
.902 .06854 Mdot
.902 .06874 Mdot
.902 .07033 Mdot
.902 .07143 Mdot
.902 .07157 Mdot
.902 .07215 Mdot
.902 .07232 Mdot
.902 .07287 Mdot
.902 .07315 Mdot
.902 .07327 Mdot
.902 .07349 Mdot
.902 .07351 Mdot
.902 .07385 Mdot
.902 .07388 Mdot
.902 .0744 Mdot
.902 .07465 Mdot
.902 .075 Mdot
.902 .07515 Mdot
.902 .07535 Mdot
.902 .07596 Mdot
.902 .07708 Mdot
.902 .07713 Mdot
.902 .07816 Mdot
.902 .07854 Mdot
.902 .07981 Mdot
.902 .08007 Mdot
.902 .08076 Mdot
.902 .08204 Mdot
.902 .08233 Mdot
.902 .08273 Mdot
.902 .08311 Mdot
.902 .08339 Mdot
.902 .08402 Mdot
.902 .08421 Mdot
.902 .08483 Mdot
.902 .08724 Mdot
.902 .08749 Mdot
.902 .08851 Mdot
.902 .08853 Mdot
.902 .0908 Mdot
.902 .09172 Mdot
.902 .09176 Mdot
.902 .09221 Mdot
.902 .09251 Mdot
.902 .09267 Mdot
.902 .09431 Mdot
.902 .09975 Mdot
.902 .10069 Mdot
.902 .10078 Mdot
.902 .10119 Mdot
.902 .10274 Mdot
.902 .10334 Mdot
.902 .1049 Mdot
.902 .10535 Mdot
.902 .10694 Mdot
.902 .10718 Mdot
.902 .10852 Mdot
.902 .11128 Mdot
.902 .11185 Mdot
.902 .11189 Mdot
.902 .11197 Mdot
.902 .11232 Mdot
.902 .11254 Mdot
.902 .11306 Mdot
.902 .11346 Mdot
.902 .11381 Mdot
.902 .11467 Mdot
.902 .11687 Mdot
.902 .11726 Mdot
.902 .11898 Mdot
.902 .1191 Mdot
.902 .12069 Mdot
.902 .1209 Mdot
.902 .12097 Mdot
.902 .12501 Mdot
.902 .12793 Mdot
.902 .12907 Mdot
.902 .12964 Mdot
.902 .13101 Mdot
.902 .13103 Mdot
.902 .13111 Mdot
.902 .13265 Mdot
.902 .13345 Mdot
.902 .13382 Mdot
.902 .13591 Mdot
.902 .13747 Mdot
.902 .13797 Mdot
.902 .13819 Mdot
.902 .14124 Mdot
.902 .14391 Mdot
.902 .14411 Mdot
.902 .14443 Mdot
.902 .14448 Mdot
.902 .14656 Mdot
.902 .14691 Mdot
.902 .14947 Mdot
.902 .14968 Mdot
.902 .15111 Mdot
.902 .1519 Mdot
.902 .15223 Mdot
.902 .15237 Mdot
.902 .15385 Mdot
.902 .15454 Mdot
.902 .15588 Mdot
.902 .15608 Mdot
.902 .15735 Mdot
.902 .15774 Mdot
.902 .15797 Mdot
.902 .15801 Mdot
.902 .15922 Mdot
.902 .16064 Mdot
.902 .16085 Mdot
.902 .1615 Mdot
.902 .16246 Mdot
.902 .16271 Mdot
.902 .1639 Mdot
.902 .16417 Mdot
.902 .16586 Mdot
.902 .16661 Mdot
.902 .16878 Mdot
.902 .17002 Mdot
.902 .17096 Mdot
.902 .17437 Mdot
.902 .17555 Mdot
.902 .17559 Mdot
.902 .17562 Mdot
.902 .17562 Mdot
.902 .17571 Mdot
.902 .17576 Mdot
.902 .17605 Mdot
.902 .17626 Mdot
.902 .17667 Mdot
.902 .17677 Mdot
.902 .17696 Mdot
.902 .17763 Mdot
.902 .17779 Mdot
.902 .17789 Mdot
.902 .17851 Mdot
.902 .17858 Mdot
.902 .17869 Mdot
.902 .17893 Mdot
.902 .17894 Mdot
.902 .17897 Mdot
.902 .179 Mdot
.902 .17924 Mdot
.902 .17945 Mdot
.902 .17986 Mdot
.902 .1799 Mdot
.902 .18018 Mdot
.902 .18028 Mdot
.902 .18053 Mdot
.902 .18089 Mdot
.902 .18147 Mdot
.902 .1822 Mdot
.902 .18229 Mdot
.902 .1837 Mdot
.902 .18372 Mdot
.902 .18455 Mdot
.902 .18508 Mdot
.902 .18546 Mdot
.902 .18563 Mdot
.902 .18582 Mdot
.902 .18595 Mdot
.902 .18619 Mdot
.902 .18621 Mdot
.902 .18669 Mdot
.902 .18732 Mdot
.902 .18917 Mdot
.902 .18941 Mdot
.902 .18989 Mdot
.902 .19124 Mdot
.902 .1925 Mdot
.902 .19263 Mdot
.902 .19297 Mdot
.902 .19312 Mdot
.902 .19377 Mdot
.902 .19394 Mdot
.902 .19467 Mdot
.902 .19525 Mdot
.902 .19573 Mdot
.902 .19675 Mdot
.902 .19728 Mdot
.902 .19741 Mdot
.902 .19771 Mdot
.902 .19798 Mdot
.902 .19843 Mdot
.902 .19886 Mdot
.902 .19889 Mdot
.902 .19917 Mdot
.902 .19995 Mdot
.902 .20007 Mdot
.902 .20034 Mdot
.902 .20071 Mdot
.902 .20146 Mdot
.902 .20174 Mdot
.902 .20243 Mdot
.902 .20273 Mdot
.902 .20352 Mdot
.902 .20353 Mdot
.902 .20366 Mdot
.902 .20434 Mdot
.902 .20458 Mdot
.902 .20499 Mdot
.902 .20586 Mdot
.902 .20649 Mdot
.902 .20713 Mdot
.902 .20818 Mdot
.902 .2086 Mdot
.902 .21107 Mdot
.902 .21221 Mdot
.902 .21288 Mdot
.902 .21317 Mdot
.902 .21408 Mdot
.902 .21458 Mdot
.902 .2148 Mdot
.902 .21557 Mdot
.902 .21569 Mdot
.902 .21607 Mdot
.902 .21615 Mdot
.902 .21799 Mdot
.902 .21824 Mdot
.902 .21837 Mdot
.902 .21851 Mdot
.902 .21868 Mdot
.902 .22026 Mdot
.902 .22103 Mdot
.902 .22113 Mdot
.902 .2214 Mdot
.902 .22152 Mdot
.902 .22219 Mdot
.902 .22226 Mdot
.902 .22332 Mdot
.902 .22342 Mdot
.902 .22346 Mdot
.902 .22445 Mdot
.902 .22504 Mdot
.902 .22581 Mdot
.902 .22594 Mdot
.902 .22671 Mdot
.902 .22693 Mdot
.902 .22699 Mdot
.902 .22714 Mdot
.902 .2274 Mdot
.902 .22748 Mdot
.902 .22801 Mdot
.902 .22873 Mdot
.902 .22979 Mdot
.902 .22991 Mdot
.902 .23046 Mdot
.902 .23106 Mdot
.902 .23125 Mdot
.902 .23152 Mdot
.902 .23315 Mdot
.902 .23339 Mdot
.902 .23353 Mdot
.902 .23392 Mdot
.902 .23433 Mdot
.902 .23512 Mdot
.902 .23532 Mdot
.902 .23555 Mdot
.902 .2357 Mdot
.902 .23624 Mdot
.902 .23672 Mdot
.902 .23695 Mdot
.902 .23786 Mdot
.902 .23788 Mdot
.902 .23847 Mdot
.902 .23921 Mdot
.902 .24175 Mdot
.902 .24256 Mdot
.902 .24265 Mdot
.902 .24305 Mdot
.902 .24346 Mdot
.902 .24368 Mdot
.902 .24423 Mdot
.902 .24465 Mdot
.902 .24487 Mdot
.902 .24538 Mdot
.902 .24584 Mdot
.902 .24665 Mdot
.902 .24677 Mdot
.902 .24705 Mdot
.902 .24855 Mdot
.902 .24867 Mdot
.902 .24943 Mdot
.902 .24963 Mdot
.902 .25062 Mdot
.902 .25176 Mdot
.902 .25262 Mdot
.902 .25343 Mdot
.902 .25357 Mdot
.902 .25388 Mdot
.902 .25452 Mdot
.902 .25452 Mdot
.902 .25506 Mdot
.902 .25529 Mdot
.902 .25575 Mdot
.902 .25693 Mdot
.902 .2586 Mdot
.902 .25872 Mdot
.902 .25944 Mdot
.902 .26018 Mdot
.902 .26131 Mdot
.902 .26236 Mdot
.902 .26257 Mdot
.902 .2641 Mdot
.902 .26473 Mdot
.902 .26484 Mdot
.902 .26581 Mdot
.902 .26784 Mdot
.902 .26788 Mdot
.902 .26836 Mdot
.902 .27239 Mdot
.902 .27267 Mdot
.902 .27452 Mdot
.902 .27529 Mdot
.902 .27678 Mdot
.902 .27718 Mdot
.902 .2773 Mdot
.902 .2786 Mdot
.902 .27947 Mdot
.902 .27995 Mdot
.902 .28211 Mdot
.902 .28297 Mdot
.902 .28373 Mdot
.902 .28464 Mdot
.902 .28497 Mdot
.902 .28611 Mdot
.902 .28663 Mdot
.902 .28778 Mdot
.902 .28934 Mdot
.902 .28975 Mdot
.902 .29025 Mdot
.902 .29048 Mdot
.902 .29053 Mdot
.902 .29124 Mdot
.902 .2925 Mdot
.902 .2926 Mdot
.902 .29271 Mdot
.902 .29296 Mdot
.902 .29355 Mdot
.902 .29608 Mdot
.902 .29769 Mdot
.902 .29861 Mdot
.902 .30002 Mdot
.902 .30128 Mdot
.902 .30179 Mdot
.902 .30183 Mdot
.902 .30264 Mdot
.902 .30288 Mdot
.902 .30403 Mdot
.902 .3049 Mdot
.902 .30611 Mdot
.902 .30744 Mdot
.902 .30831 Mdot
.902 .30881 Mdot
.902 .30991 Mdot
.902 .30995 Mdot
.902 .31038 Mdot
.902 .31145 Mdot
.902 .31284 Mdot
.902 .3142 Mdot
.902 .31431 Mdot
.902 .31538 Mdot
.902 .31542 Mdot
.902 .31585 Mdot
.902 .31892 Mdot
.902 .31973 Mdot
.902 .32004 Mdot
.902 .32014 Mdot
.902 .32035 Mdot
.902 .32184 Mdot
.902 .32361 Mdot
.902 .32395 Mdot
.902 .32467 Mdot
.902 .32586 Mdot
.902 .3264 Mdot
.902 .32848 Mdot
.902 .33127 Mdot
.902 .33206 Mdot
.902 .33254 Mdot
.902 .33278 Mdot
.902 .33289 Mdot
.902 .33308 Mdot
.902 .33337 Mdot
.902 .33382 Mdot
.902 .33402 Mdot
.902 .33443 Mdot
.902 .33458 Mdot
.902 .33596 Mdot
.902 .33672 Mdot
.902 .33699 Mdot
.902 .3379 Mdot
.902 .33963 Mdot
.902 .33989 Mdot
.902 .34014 Mdot
.902 .34033 Mdot
.902 .3429 Mdot
.902 .34351 Mdot
.902 .34484 Mdot
.902 .34539 Mdot
.902 .34581 Mdot
.902 .3459 Mdot
.902 .3468 Mdot
.902 .3504 Mdot
.902 .35117 Mdot
.902 .35147 Mdot
.902 .35244 Mdot
.902 .3552 Mdot
.902 .35548 Mdot
.902 .35552 Mdot
.902 .35577 Mdot
.902 .35601 Mdot
.902 .35619 Mdot
.902 .35634 Mdot
.902 .35769 Mdot
.902 .35864 Mdot
.902 .3594 Mdot
.902 .36355 Mdot
.902 .366 Mdot
.902 .36619 Mdot
.902 .36847 Mdot
.902 .36859 Mdot
.902 .3704 Mdot
.902 .37048 Mdot
.902 .37143 Mdot
.902 .37195 Mdot
.902 .37272 Mdot
.902 .37329 Mdot
.902 .37337 Mdot
.902 .37428 Mdot
.902 .3749 Mdot
.902 .37604 Mdot
.902 .377 Mdot
.902 .37741 Mdot
.902 .37772 Mdot
.902 .3803 Mdot
.902 .38038 Mdot
.902 .38068 Mdot
.902 .38071 Mdot
.902 .3809 Mdot
.902 .38454 Mdot
.902 .38516 Mdot
.902 .38595 Mdot
.902 .38629 Mdot
.902 .38643 Mdot
.902 .38675 Mdot
.902 .38728 Mdot
.902 .38748 Mdot
.902 .38781 Mdot
.902 .38918 Mdot
.902 .39147 Mdot
.902 .39213 Mdot
.902 .39289 Mdot
.902 .39386 Mdot
.902 .39428 Mdot
.902 .39506 Mdot
.902 .39536 Mdot
.902 .39555 Mdot
.902 .39572 Mdot
.902 .3963 Mdot
.902 .39685 Mdot
.902 .39696 Mdot
.902 .39716 Mdot
.902 .39735 Mdot
.902 .39761 Mdot
.902 .39798 Mdot
.902 .39892 Mdot
.902 .39903 Mdot
.902 .39914 Mdot
.902 .3992 Mdot
.902 .40001 Mdot
.902 .40012 Mdot
.902 .40056 Mdot
.902 .40082 Mdot
.902 .40184 Mdot
.902 .40214 Mdot
.902 .40326 Mdot
.902 .40365 Mdot
.902 .40423 Mdot
.902 .40429 Mdot
.902 .40689 Mdot
.902 .40765 Mdot
.902 .40804 Mdot
.902 .40965 Mdot
.902 .41017 Mdot
.902 .41047 Mdot
.902 .4106 Mdot
.902 .4113 Mdot
.902 .41141 Mdot
.902 .4116 Mdot
.902 .41161 Mdot
.902 .41179 Mdot
.902 .41212 Mdot
.902 .41214 Mdot
.902 .41224 Mdot
.902 .41239 Mdot
.902 .41595 Mdot
.902 .4167 Mdot
.902 .41697 Mdot
.902 .42218 Mdot
.902 .42251 Mdot
.902 .42263 Mdot
.902 .42416 Mdot
.902 .42567 Mdot
.902 .42731 Mdot
.902 .428 Mdot
.902 .42808 Mdot
.902 .42829 Mdot
.902 .42906 Mdot
.902 .4301 Mdot
.902 .43137 Mdot
.902 .4328 Mdot
.902 .43367 Mdot
.902 .43554 Mdot
.902 .43595 Mdot
.902 .43613 Mdot
.902 .43621 Mdot
.902 .43805 Mdot
.902 .43837 Mdot
.902 .43854 Mdot
.902 .4387 Mdot
.902 .43931 Mdot
.902 .43978 Mdot
.902 .43985 Mdot
.902 .44228 Mdot
.902 .4451 Mdot
.902 .44552 Mdot
.902 .44655 Mdot
.902 .4468 Mdot
.902 .44866 Mdot
.902 .44868 Mdot
.902 .44917 Mdot
.902 .44934 Mdot
.902 .45148 Mdot
.902 .45199 Mdot
.902 .45524 Mdot
.902 .45558 Mdot
.902 .45666 Mdot
.902 .4606 Mdot
.902 .46076 Mdot
.902 .46092 Mdot
.902 .46182 Mdot
.902 .46186 Mdot
.902 .46307 Mdot
.902 .4648 Mdot
.902 .4653 Mdot
.902 .46577 Mdot
.902 .46763 Mdot
.902 .46841 Mdot
.902 .471 Mdot
.902 .47311 Mdot
.902 .47318 Mdot
.902 .47322 Mdot
.902 .47323 Mdot
.902 .47338 Mdot
.902 .47346 Mdot
.902 .47347 Mdot
.902 .47398 Mdot
.902 .47435 Mdot
.902 .47508 Mdot
.902 .47526 Mdot
.902 .4756 Mdot
.902 .47677 Mdot
.902 .47705 Mdot
.902 .47723 Mdot
.902 .47773 Mdot
.902 .47786 Mdot
.902 .47832 Mdot
.902 .47843 Mdot
.902 .47863 Mdot
.902 .47867 Mdot
.902 .47903 Mdot
.902 .47906 Mdot
.902 .47911 Mdot
.902 .47916 Mdot
.902 .47957 Mdot
.902 .47973 Mdot
.902 .47993 Mdot
.902 .48002 Mdot
.902 .48031 Mdot
.902 .48064 Mdot
.902 .48072 Mdot
.902 .48085 Mdot
.902 .48119 Mdot
.902 .48137 Mdot
.902 .4818 Mdot
.902 .48241 Mdot
.902 .4834 Mdot
.902 .48399 Mdot
.902 .48413 Mdot
.902 .48444 Mdot
.902 .48464 Mdot
.902 .48479 Mdot
.902 .48512 Mdot
.902 .48715 Mdot
.902 .48718 Mdot
.902 .48826 Mdot
.902 .48856 Mdot
.902 .48944 Mdot
.902 .4897 Mdot
.902 .49007 Mdot
.902 .49034 Mdot
.902 .49066 Mdot
.902 .49088 Mdot
.902 .49127 Mdot
.902 .4913 Mdot
.902 .49205 Mdot
.902 .49209 Mdot
.902 .4931 Mdot
.902 .4941 Mdot
.902 .49577 Mdot
.902 .49608 Mdot
.902 .49646 Mdot
.902 .497 Mdot
.902 .49723 Mdot
.902 .49733 Mdot
.902 .49745 Mdot
.902 .49855 Mdot
.902 .49936 Mdot
.902 .50112 Mdot
.902 .50132 Mdot
.902 .50154 Mdot
.902 .50206 Mdot
.902 .50229 Mdot
.902 .50329 Mdot
.902 .50346 Mdot
.902 .50356 Mdot
.902 .50468 Mdot
.902 .50556 Mdot
.902 .50579 Mdot
.902 .50596 Mdot
.902 .50627 Mdot
.902 .50646 Mdot
.902 .50781 Mdot
.902 .5086 Mdot
.902 .5088 Mdot
.902 .50925 Mdot
.902 .50964 Mdot
.902 .5103 Mdot
.902 .51094 Mdot
.902 .51098 Mdot
.902 .51139 Mdot
.902 .51252 Mdot
.902 .5127 Mdot
.902 .51309 Mdot
.902 .51363 Mdot
.902 .51414 Mdot
.902 .51453 Mdot
.902 .5147 Mdot
.902 .5151 Mdot
.902 .5156 Mdot
.902 .51609 Mdot
.902 .51652 Mdot
.902 .51763 Mdot
.902 .51765 Mdot
.902 .51783 Mdot
.902 .51879 Mdot
.902 .51911 Mdot
.902 .51969 Mdot
.902 .52059 Mdot
.902 .5208 Mdot
.902 .52089 Mdot
.902 .52093 Mdot
.902 .52096 Mdot
.902 .52141 Mdot
.902 .52166 Mdot
.902 .52167 Mdot
.902 .52175 Mdot
.902 .52193 Mdot
.902 .52207 Mdot
.902 .52262 Mdot
.902 .52303 Mdot
.902 .52321 Mdot
.902 .52361 Mdot
.902 .52404 Mdot
.902 .52431 Mdot
.902 .52461 Mdot
.902 .52645 Mdot
.902 .52697 Mdot
.902 .52787 Mdot
.902 .52796 Mdot
.902 .52934 Mdot
.902 .53021 Mdot
.902 .53058 Mdot
.902 .53131 Mdot
.902 .53138 Mdot
.902 .53173 Mdot
.902 .53211 Mdot
.902 .53236 Mdot
.902 .5326 Mdot
.902 .53264 Mdot
.902 .5336 Mdot
.902 .53375 Mdot
.902 .53401 Mdot
.902 .53422 Mdot
.902 .53432 Mdot
.902 .53437 Mdot
.902 .53563 Mdot
.902 .53595 Mdot
.902 .53649 Mdot
.902 .53658 Mdot
.902 .53662 Mdot
.902 .53688 Mdot
.902 .53704 Mdot
.902 .5372 Mdot
.902 .53741 Mdot
.902 .5376 Mdot
.902 .53767 Mdot
.902 .5378 Mdot
.902 .53793 Mdot
.902 .53906 Mdot
.902 .5393 Mdot
.902 .53949 Mdot
.902 .53979 Mdot
.902 .54002 Mdot
.902 .5402 Mdot
.902 .54025 Mdot
.902 .54032 Mdot
.902 .54039 Mdot
.902 .54064 Mdot
.902 .54078 Mdot
.902 .54103 Mdot
.902 .54155 Mdot
.902 .54164 Mdot
.902 .5417 Mdot
.902 .5419 Mdot
.902 .54211 Mdot
.902 .54245 Mdot
.902 .54285 Mdot
.902 .54296 Mdot
.902 .54301 Mdot
.902 .5431 Mdot
.902 .54335 Mdot
.902 .54382 Mdot
.902 .54414 Mdot
.902 .54479 Mdot
.902 .54491 Mdot
.902 .54566 Mdot
.902 .54576 Mdot
.902 .5458 Mdot
.902 .54649 Mdot
.902 .54665 Mdot
.902 .54689 Mdot
.902 .54696 Mdot
.902 .54712 Mdot
.902 .5474 Mdot
.902 .54749 Mdot
.902 .54806 Mdot
.902 .54883 Mdot
.902 .54897 Mdot
.902 .54996 Mdot
.902 .55009 Mdot
.902 .55042 Mdot
.902 .55066 Mdot
.902 .55076 Mdot
.902 .55097 Mdot
.902 .55129 Mdot
.902 .55149 Mdot
.902 .55153 Mdot
.902 .55177 Mdot
.902 .55186 Mdot
.902 .552 Mdot
.902 .55235 Mdot
.902 .55315 Mdot
.902 .55343 Mdot
.902 .55368 Mdot
.902 .55378 Mdot
.902 .55382 Mdot
.902 .55421 Mdot
.902 .55462 Mdot
.902 .55541 Mdot
.902 .55559 Mdot
.902 .55582 Mdot
.902 .55597 Mdot
.902 .5565 Mdot
.902 .55696 Mdot
.902 .55718 Mdot
.902 .55735 Mdot
.902 .55754 Mdot
.902 .55757 Mdot
.902 .55785 Mdot
.902 .55793 Mdot
.902 .55805 Mdot
.902 .55807 Mdot
.902 .55863 Mdot
.902 .55932 Mdot
.902 .56034 Mdot
.902 .56062 Mdot
.902 .56099 Mdot
.902 .56164 Mdot
.902 .56186 Mdot
.902 .56236 Mdot
.902 .56244 Mdot
.902 .56279 Mdot
.902 .56286 Mdot
.902 .56315 Mdot
.902 .56334 Mdot
.902 .5634 Mdot
.902 .56382 Mdot
.902 .56418 Mdot
.902 .56419 Mdot
.902 .56426 Mdot
.902 .56437 Mdot
.902 .56474 Mdot
.902 .5648 Mdot
.902 .56519 Mdot
.902 .5654 Mdot
.902 .56583 Mdot
.902 .56587 Mdot
.902 .56597 Mdot
.902 .5662 Mdot
.902 .56662 Mdot
.902 .56668 Mdot
.902 .56742 Mdot
.902 .56752 Mdot
.902 .56813 Mdot
.902 .56814 Mdot
.902 .56823 Mdot
.902 .56829 Mdot
.902 .56906 Mdot
.902 .56994 Mdot
.902 .57 Mdot
.902 .57015 Mdot
.902 .5706 Mdot
.902 .57119 Mdot
.902 .5713 Mdot
.902 .57153 Mdot
.902 .57197 Mdot
.902 .57199 Mdot
.902 .572 Mdot
.902 .57239 Mdot
.902 .57255 Mdot
.902 .57288 Mdot
.902 .57371 Mdot
.902 .57485 Mdot
.902 .57487 Mdot
.902 .57493 Mdot
.902 .57538 Mdot
.902 .57541 Mdot
.902 .57589 Mdot
.902 .576 Mdot
.902 .57662 Mdot
.902 .57686 Mdot
.902 .57696 Mdot
.902 .57707 Mdot
.902 .57722 Mdot
.902 .57728 Mdot
.902 .57738 Mdot
.902 .5774 Mdot
.902 .57741 Mdot
.902 .57757 Mdot
.902 .57834 Mdot
.902 .57871 Mdot
.902 .57878 Mdot
.902 .57922 Mdot
.902 .57935 Mdot
.902 .57978 Mdot
.902 .57994 Mdot
.902 .58037 Mdot
.902 .58049 Mdot
.902 .58051 Mdot
.902 .58077 Mdot
.902 .58227 Mdot
.902 .58272 Mdot
.902 .58276 Mdot
.902 .58285 Mdot
.902 .58297 Mdot
.902 .58298 Mdot
.902 .58323 Mdot
.902 .58385 Mdot
.902 .58386 Mdot
.902 .58414 Mdot
.902 .5842 Mdot
.902 .58486 Mdot
.902 .58503 Mdot
.902 .58508 Mdot
.902 .58525 Mdot
.902 .58533 Mdot
.902 .58543 Mdot
.902 .58554 Mdot
.902 .58562 Mdot
.902 .58597 Mdot
.902 .58615 Mdot
.902 .58622 Mdot
.902 .58657 Mdot
.902 .58667 Mdot
.902 .58695 Mdot
.902 .58696 Mdot
.902 .58726 Mdot
.902 .58743 Mdot
.902 .58748 Mdot
.902 .58752 Mdot
.902 .58762 Mdot
.902 .58768 Mdot
.902 .58782 Mdot
.902 .58783 Mdot
.902 .58792 Mdot
.902 .58793 Mdot
.902 .58799 Mdot
.902 .58802 Mdot
.902 .58809 Mdot
.902 .58824 Mdot
.902 .58829 Mdot
.902 .58844 Mdot
.902 .58848 Mdot
.902 .58878 Mdot
.902 .5892 Mdot
.902 .58926 Mdot
.902 .58931 Mdot
.902 .58944 Mdot
.902 .58949 Mdot
.902 .58951 Mdot
.902 .58968 Mdot
.902 .58977 Mdot
.902 .58989 Mdot
.902 .58996 Mdot
.902 .58999 Mdot
.902 .59001 Mdot
.902 .59007 Mdot
.902 .59015 Mdot
.902 .59019 Mdot
.902 .5903 Mdot
.902 .59036 Mdot
.902 .59067 Mdot
.902 .59069 Mdot
.902 .59093 Mdot
.902 .59093 Mdot
.902 .59096 Mdot
.902 .59097 Mdot
.902 .59102 Mdot
.902 .59106 Mdot
.902 .59113 Mdot
.902 .59124 Mdot
.902 .59138 Mdot
.902 .59143 Mdot
.902 .59144 Mdot
.902 .59147 Mdot
.902 .59151 Mdot
.902 .59151 Mdot
.902 .59151 Mdot
.902 .59153 Mdot
.902 .5916 Mdot
.902 .5916 Mdot
.902 .59162 Mdot
.902 .59167 Mdot
.902 .59169 Mdot
.902 .59173 Mdot
.902 .59174 Mdot
.902 .59177 Mdot
.902 .59177 Mdot
.902 .59178 Mdot
.902 .59178 Mdot
.902 .59178 Mdot
.902 .59178 Mdot
.904 .0582 Mdot
.904 .0582 Mdot
.904 .05823 Mdot
.904 .05826 Mdot
.904 .05827 Mdot
.904 .05839 Mdot
.904 .05862 Mdot
.904 .05884 Mdot
.904 .05889 Mdot
.904 .0589 Mdot
.904 .05898 Mdot
.904 .05918 Mdot
.904 .05923 Mdot
.904 .05929 Mdot
.904 .05984 Mdot
.904 .05991 Mdot
.904 .06015 Mdot
.904 .06042 Mdot
.904 .06046 Mdot
.904 .0606 Mdot
.904 .061 Mdot
.904 .06113 Mdot
.904 .06122 Mdot
.904 .06148 Mdot
.904 .06221 Mdot
.904 .0626 Mdot
.904 .06379 Mdot
.904 .06385 Mdot
.904 .06404 Mdot
.904 .06405 Mdot
.904 .0643 Mdot
.904 .06468 Mdot
.904 .06517 Mdot
.904 .06539 Mdot
.904 .06568 Mdot
.904 .06614 Mdot
.904 .06647 Mdot
.904 .06655 Mdot
.904 .06666 Mdot
.904 .06686 Mdot
.904 .06818 Mdot
.904 .0682 Mdot
.904 .06858 Mdot
.904 .06869 Mdot
.904 .06914 Mdot
.904 .06933 Mdot
.904 .06949 Mdot
.904 .06965 Mdot
.904 .07112 Mdot
.904 .07122 Mdot
.904 .07131 Mdot
.904 .07146 Mdot
.904 .07169 Mdot
.904 .07169 Mdot
.904 .07174 Mdot
.904 .07181 Mdot
.904 .07391 Mdot
.904 .07502 Mdot
.904 .07526 Mdot
.904 .07527 Mdot
.904 .07548 Mdot
.904 .07551 Mdot
.904 .07566 Mdot
.904 .07571 Mdot
.904 .07629 Mdot
.904 .07636 Mdot
.904 .07672 Mdot
.904 .07762 Mdot
.904 .07767 Mdot
.904 .0777 Mdot
.904 .0781 Mdot
.904 .07838 Mdot
.904 .07921 Mdot
.904 .07953 Mdot
.904 .08007 Mdot
.904 .08045 Mdot
.904 .08053 Mdot
.904 .0808 Mdot
.904 .08246 Mdot
.904 .08284 Mdot
.904 .08288 Mdot
.904 .08361 Mdot
.904 .08448 Mdot
.904 .08486 Mdot
.904 .08486 Mdot
.904 .08569 Mdot
.904 .08632 Mdot
.904 .08634 Mdot
.904 .08634 Mdot
.904 .0868 Mdot
.904 .08766 Mdot
.904 .08968 Mdot
.904 .09095 Mdot
.904 .09104 Mdot
.904 .09104 Mdot
.904 .09136 Mdot
.904 .09235 Mdot
.904 .09291 Mdot
.904 .09326 Mdot
.904 .09359 Mdot
.904 .09364 Mdot
.904 .09542 Mdot
.904 .09645 Mdot
.904 .09676 Mdot
.904 .09747 Mdot
.904 .09841 Mdot
.904 .09884 Mdot
.904 .099 Mdot
.904 .09998 Mdot
.904 .10064 Mdot
.904 .10488 Mdot
.904 .10847 Mdot
.904 .10872 Mdot
.904 .11036 Mdot
.904 .11084 Mdot
.904 .11153 Mdot
.904 .11339 Mdot
.904 .1134 Mdot
.904 .11357 Mdot
.904 .11517 Mdot
.904 .11526 Mdot
.904 .1156 Mdot
.904 .11783 Mdot
.904 .11834 Mdot
.904 .12137 Mdot
.904 .12352 Mdot
.904 .12376 Mdot
.904 .12376 Mdot
.904 .12442 Mdot
.904 .12656 Mdot
.904 .1269 Mdot
.904 .12706 Mdot
.904 .12817 Mdot
.904 .12963 Mdot
.904 .12966 Mdot
.904 .13162 Mdot
.904 .13324 Mdot
.904 .13381 Mdot
.904 .13485 Mdot
.904 .13587 Mdot
.904 .13615 Mdot
.904 .13622 Mdot
.904 .13861 Mdot
.904 .13873 Mdot
.904 .13899 Mdot
.904 .13936 Mdot
.904 .14003 Mdot
.904 .14184 Mdot
.904 .14244 Mdot
.904 .14245 Mdot
.904 .1432 Mdot
.904 .14367 Mdot
.904 .14483 Mdot
.904 .14796 Mdot
.904 .14887 Mdot
.904 .15008 Mdot
.904 .15028 Mdot
.904 .15093 Mdot
.904 .15139 Mdot
.904 .15144 Mdot
.904 .15208 Mdot
.904 .15287 Mdot
.904 .15347 Mdot
.904 .15489 Mdot
.904 .15661 Mdot
.904 .15875 Mdot
.904 .15902 Mdot
.904 .15918 Mdot
.904 .15979 Mdot
.904 .16048 Mdot
.904 .16319 Mdot
.904 .16394 Mdot
.904 .16465 Mdot
.904 .16656 Mdot
.904 .16689 Mdot
.904 .1682 Mdot
.904 .1695 Mdot
.904 .1697 Mdot
.904 .16981 Mdot
.904 .16995 Mdot
.904 .1702 Mdot
.904 .17032 Mdot
.904 .1712 Mdot
.904 .17271 Mdot
.904 .17271 Mdot
.904 .1728 Mdot
.904 .17293 Mdot
.904 .17296 Mdot
.904 .17334 Mdot
.904 .1738 Mdot
.904 .17411 Mdot
.904 .17485 Mdot
.904 .17502 Mdot
.904 .17506 Mdot
.904 .17531 Mdot
.904 .17598 Mdot
.904 .17617 Mdot
.904 .17636 Mdot
.904 .17692 Mdot
.904 .17713 Mdot
.904 .17752 Mdot
.904 .1782 Mdot
.904 .17842 Mdot
.904 .17869 Mdot
.904 .17913 Mdot
.904 .17921 Mdot
.904 .1801 Mdot
.904 .18022 Mdot
.904 .18071 Mdot
.904 .18186 Mdot
.904 .18189 Mdot
.904 .18202 Mdot
.904 .18244 Mdot
.904 .18277 Mdot
.904 .18361 Mdot
.904 .1846 Mdot
.904 .18475 Mdot
.904 .18583 Mdot
.904 .18601 Mdot
.904 .18612 Mdot
.904 .18663 Mdot
.904 .18731 Mdot
.904 .18942 Mdot
.904 .1912 Mdot
.904 .1914 Mdot
.904 .19179 Mdot
.904 .19203 Mdot
.904 .19203 Mdot
.904 .19288 Mdot
.904 .19363 Mdot
.904 .19409 Mdot
.904 .19569 Mdot
.904 .1958 Mdot
.904 .19642 Mdot
.904 .19707 Mdot
.904 .19735 Mdot
.904 .19884 Mdot
.904 .19917 Mdot
.904 .19952 Mdot
.904 .1999 Mdot
.904 .20016 Mdot
.904 .20023 Mdot
.904 .20054 Mdot
.904 .20088 Mdot
.904 .20117 Mdot
.904 .20131 Mdot
.904 .20153 Mdot
.904 .20541 Mdot
.904 .20547 Mdot
.904 .20633 Mdot
.904 .20669 Mdot
.904 .20681 Mdot
.904 .20705 Mdot
.904 .20849 Mdot
.904 .2085 Mdot
.904 .20876 Mdot
.904 .20909 Mdot
.904 .20961 Mdot
.904 .2098 Mdot
.904 .21014 Mdot
.904 .21096 Mdot
.904 .21115 Mdot
.904 .21366 Mdot
.904 .21479 Mdot
.904 .21512 Mdot
.904 .21539 Mdot
.904 .21541 Mdot
.904 .21589 Mdot
.904 .21661 Mdot
.904 .21662 Mdot
.904 .21675 Mdot
.904 .21693 Mdot
.904 .21699 Mdot
.904 .21782 Mdot
.904 .218 Mdot
.904 .21903 Mdot
.904 .2196 Mdot
.904 .22024 Mdot
.904 .22086 Mdot
.904 .2236 Mdot
.904 .2237 Mdot
.904 .22538 Mdot
.904 .22554 Mdot
.904 .22589 Mdot
.904 .22708 Mdot
.904 .22781 Mdot
.904 .22786 Mdot
.904 .2285 Mdot
.904 .22858 Mdot
.904 .22907 Mdot
.904 .22921 Mdot
.904 .23101 Mdot
.904 .23122 Mdot
.904 .23234 Mdot
.904 .23514 Mdot
.904 .23529 Mdot
.904 .23538 Mdot
.904 .23572 Mdot
.904 .23661 Mdot
.904 .23748 Mdot
.904 .23799 Mdot
.904 .23811 Mdot
.904 .23918 Mdot
.904 .24002 Mdot
.904 .2403 Mdot
.904 .24047 Mdot
.904 .241 Mdot
.904 .24143 Mdot
.904 .2424 Mdot
.904 .24265 Mdot
.904 .24357 Mdot
.904 .2438 Mdot
.904 .24406 Mdot
.904 .24488 Mdot
.904 .24548 Mdot
.904 .24618 Mdot
.904 .24668 Mdot
.904 .24686 Mdot
.904 .24946 Mdot
.904 .2499 Mdot
.904 .24991 Mdot
.904 .25013 Mdot
.904 .2508 Mdot
.904 .25104 Mdot
.904 .25118 Mdot
.904 .25128 Mdot
.904 .25132 Mdot
.904 .25225 Mdot
.904 .25275 Mdot
.904 .25336 Mdot
.904 .25399 Mdot
.904 .25579 Mdot
.904 .25586 Mdot
.904 .25599 Mdot
.904 .25686 Mdot
.904 .25712 Mdot
.904 .25713 Mdot
.904 .25811 Mdot
.904 .2596 Mdot
.904 .26056 Mdot
.904 .26145 Mdot
.904 .26153 Mdot
.904 .26153 Mdot
.904 .26236 Mdot
.904 .26267 Mdot
.904 .26289 Mdot
.904 .26544 Mdot
.904 .26751 Mdot
.904 .26842 Mdot
.904 .27136 Mdot
.904 .27155 Mdot
.904 .27186 Mdot
.904 .27259 Mdot
.904 .27259 Mdot
.904 .27264 Mdot
.904 .27506 Mdot
.904 .27534 Mdot
.904 .27534 Mdot
.904 .27573 Mdot
.904 .27624 Mdot
.904 .27703 Mdot
.904 .2775 Mdot
.904 .27777 Mdot
.904 .27905 Mdot
.904 .27911 Mdot
.904 .27974 Mdot
.904 .27997 Mdot
.904 .28075 Mdot
.904 .28104 Mdot
.904 .28176 Mdot
.904 .28203 Mdot
.904 .28208 Mdot
.904 .28269 Mdot
.904 .28285 Mdot
.904 .28286 Mdot
.904 .28305 Mdot
.904 .28567 Mdot
.904 .28578 Mdot
.904 .28611 Mdot
.904 .28761 Mdot
.904 .28792 Mdot
.904 .28854 Mdot
.904 .28903 Mdot
.904 .29042 Mdot
.904 .29063 Mdot
.904 .29085 Mdot
.904 .29174 Mdot
.904 .29294 Mdot
.904 .29375 Mdot
.904 .29375 Mdot
.904 .294 Mdot
.904 .29577 Mdot
.904 .29638 Mdot
.904 .29759 Mdot
.904 .29804 Mdot
.904 .29961 Mdot
.904 .30021 Mdot
.904 .30076 Mdot
.904 .3026 Mdot
.904 .30277 Mdot
.904 .30906 Mdot
.904 .30919 Mdot
.904 .31006 Mdot
.904 .31061 Mdot
.904 .31073 Mdot
.904 .31174 Mdot
.904 .3131 Mdot
.904 .31406 Mdot
.904 .31426 Mdot
.904 .3143 Mdot
.904 .31458 Mdot
.904 .31561 Mdot
.904 .31711 Mdot
.904 .3185 Mdot
.904 .3188 Mdot
.904 .31958 Mdot
.904 .31981 Mdot
.904 .32395 Mdot
.904 .32462 Mdot
.904 .32569 Mdot
.904 .32596 Mdot
.904 .32682 Mdot
.904 .32727 Mdot
.904 .32898 Mdot
.904 .32938 Mdot
.904 .32993 Mdot
.904 .33026 Mdot
.904 .33175 Mdot
.904 .33184 Mdot
.904 .33206 Mdot
.904 .33225 Mdot
.904 .33229 Mdot
.904 .33411 Mdot
.904 .33536 Mdot
.904 .33548 Mdot
.904 .33551 Mdot
.904 .33694 Mdot
.904 .33697 Mdot
.904 .33741 Mdot
.904 .33748 Mdot
.904 .33866 Mdot
.904 .33916 Mdot
.904 .3405 Mdot
.904 .34155 Mdot
.904 .34179 Mdot
.904 .34268 Mdot
.904 .34349 Mdot
.904 .34467 Mdot
.904 .34562 Mdot
.904 .34685 Mdot
.904 .34688 Mdot
.904 .34784 Mdot
.904 .34838 Mdot
.904 .34854 Mdot
.904 .34891 Mdot
.904 .34939 Mdot
.904 .3497 Mdot
.904 .35019 Mdot
.904 .35428 Mdot
.904 .35439 Mdot
.904 .35728 Mdot
.904 .35732 Mdot
.904 .35865 Mdot
.904 .36081 Mdot
.904 .36269 Mdot
.904 .36326 Mdot
.904 .36328 Mdot
.904 .36489 Mdot
.904 .36568 Mdot
.904 .36581 Mdot
.904 .3684 Mdot
.904 .369 Mdot
.904 .37012 Mdot
.904 .37045 Mdot
.904 .37087 Mdot
.904 .37094 Mdot
.904 .37134 Mdot
.904 .37158 Mdot
.904 .37206 Mdot
.904 .37388 Mdot
.904 .37403 Mdot
.904 .37586 Mdot
.904 .3765 Mdot
.904 .37746 Mdot
.904 .37753 Mdot
.904 .37761 Mdot
.904 .37769 Mdot
.904 .37985 Mdot
.904 .38042 Mdot
.904 .38142 Mdot
.904 .38227 Mdot
.904 .38376 Mdot
.904 .38448 Mdot
.904 .38504 Mdot
.904 .38607 Mdot
.904 .3867 Mdot
.904 .38721 Mdot
.904 .38734 Mdot
.904 .38741 Mdot
.904 .38983 Mdot
.904 .39145 Mdot
.904 .39189 Mdot
.904 .3922 Mdot
.904 .39283 Mdot
.904 .39301 Mdot
.904 .39381 Mdot
.904 .39429 Mdot
.904 .39783 Mdot
.904 .39812 Mdot
.904 .39848 Mdot
.904 .39874 Mdot
.904 .39932 Mdot
.904 .39984 Mdot
.904 .40017 Mdot
.904 .40092 Mdot
.904 .40167 Mdot
.904 .40181 Mdot
.904 .4039 Mdot
.904 .40446 Mdot
.904 .40574 Mdot
.904 .40598 Mdot
.904 .4068 Mdot
.904 .40707 Mdot
.904 .40709 Mdot
.904 .40836 Mdot
.904 .40876 Mdot
.904 .409 Mdot
.904 .40975 Mdot
.904 .4098 Mdot
.904 .41048 Mdot
.904 .4105 Mdot
.904 .41059 Mdot
.904 .41176 Mdot
.904 .41235 Mdot
.904 .41308 Mdot
.904 .41406 Mdot
.904 .41421 Mdot
.904 .41487 Mdot
.904 .41647 Mdot
.904 .41689 Mdot
.904 .41774 Mdot
.904 .41894 Mdot
.904 .41914 Mdot
.904 .42075 Mdot
.904 .42108 Mdot
.904 .42175 Mdot
.904 .42221 Mdot
.904 .42233 Mdot
.904 .4228 Mdot
.904 .42311 Mdot
.904 .42314 Mdot
.904 .42315 Mdot
.904 .42365 Mdot
.904 .42407 Mdot
.904 .42545 Mdot
.904 .42642 Mdot
.904 .42652 Mdot
.904 .42786 Mdot
.904 .42789 Mdot
.904 .42896 Mdot
.904 .4295 Mdot
.904 .43075 Mdot
.904 .43155 Mdot
.904 .43232 Mdot
.904 .43278 Mdot
.904 .43368 Mdot
.904 .43374 Mdot
.904 .43428 Mdot
.904 .43468 Mdot
.904 .43545 Mdot
.904 .43721 Mdot
.904 .44037 Mdot
.904 .44151 Mdot
.904 .44206 Mdot
.904 .44208 Mdot
.904 .44238 Mdot
.904 .44359 Mdot
.904 .4437 Mdot
.904 .44496 Mdot
.904 .44531 Mdot
.904 .44655 Mdot
.904 .44751 Mdot
.904 .45029 Mdot
.904 .45072 Mdot
.904 .45173 Mdot
.904 .45259 Mdot
.904 .4531 Mdot
.904 .45365 Mdot
.904 .45462 Mdot
.904 .45626 Mdot
.904 .45675 Mdot
.904 .45738 Mdot
.904 .45819 Mdot
.904 .459 Mdot
.904 .45985 Mdot
.904 .46228 Mdot
.904 .46266 Mdot
.904 .46285 Mdot
.904 .46312 Mdot
.904 .46358 Mdot
.904 .4638 Mdot
.904 .46418 Mdot
.904 .46543 Mdot
.904 .46594 Mdot
.904 .46819 Mdot
.904 .46819 Mdot
.904 .46821 Mdot
.904 .46835 Mdot
.904 .46857 Mdot
.904 .46863 Mdot
.904 .46885 Mdot
.904 .46932 Mdot
.904 .47016 Mdot
.904 .47072 Mdot
.904 .47111 Mdot
.904 .4713 Mdot
.904 .47204 Mdot
.904 .47234 Mdot
.904 .47241 Mdot
.904 .47287 Mdot
.904 .47347 Mdot
.904 .474 Mdot
.904 .47404 Mdot
.904 .47405 Mdot
.904 .47438 Mdot
.904 .47472 Mdot
.904 .47501 Mdot
.904 .47572 Mdot
.904 .47609 Mdot
.904 .47677 Mdot
.904 .47702 Mdot
.904 .47795 Mdot
.904 .47834 Mdot
.904 .47882 Mdot
.904 .47958 Mdot
.904 .47971 Mdot
.904 .48125 Mdot
.904 .48146 Mdot
.904 .4823 Mdot
.904 .48248 Mdot
.904 .48425 Mdot
.904 .48431 Mdot
.904 .48453 Mdot
.904 .48524 Mdot
.904 .48547 Mdot
.904 .48578 Mdot
.904 .48677 Mdot
.904 .48719 Mdot
.904 .48743 Mdot
.904 .48834 Mdot
.904 .48843 Mdot
.904 .48884 Mdot
.904 .4891 Mdot
.904 .48992 Mdot
.904 .49068 Mdot
.904 .49088 Mdot
.904 .49117 Mdot
.904 .49134 Mdot
.904 .49194 Mdot
.904 .49218 Mdot
.904 .49324 Mdot
.904 .49329 Mdot
.904 .49526 Mdot
.904 .49613 Mdot
.904 .49668 Mdot
.904 .49783 Mdot
.904 .49788 Mdot
.904 .49949 Mdot
.904 .49981 Mdot
.904 .5 Mdot
.904 .50014 Mdot
.904 .50042 Mdot
.904 .50079 Mdot
.904 .5008 Mdot
.904 .50166 Mdot
.904 .50212 Mdot
.904 .50327 Mdot
.904 .50379 Mdot
.904 .50398 Mdot
.904 .50443 Mdot
.904 .50519 Mdot
.904 .5052 Mdot
.904 .50525 Mdot
.904 .50573 Mdot
.904 .50642 Mdot
.904 .50643 Mdot
.904 .50659 Mdot
.904 .50662 Mdot
.904 .50731 Mdot
.904 .50752 Mdot
.904 .50832 Mdot
.904 .50849 Mdot
.904 .50881 Mdot
.904 .50891 Mdot
.904 .5111 Mdot
.904 .51119 Mdot
.904 .51148 Mdot
.904 .51159 Mdot
.904 .51211 Mdot
.904 .51266 Mdot
.904 .51304 Mdot
.904 .51314 Mdot
.904 .51323 Mdot
.904 .51358 Mdot
.904 .51408 Mdot
.904 .51445 Mdot
.904 .51449 Mdot
.904 .51469 Mdot
.904 .51501 Mdot
.904 .51506 Mdot
.904 .51733 Mdot
.904 .51826 Mdot
.904 .51847 Mdot
.904 .51984 Mdot
.904 .52047 Mdot
.904 .52056 Mdot
.904 .52084 Mdot
.904 .52166 Mdot
.904 .52174 Mdot
.904 .52223 Mdot
.904 .5224 Mdot
.904 .52272 Mdot
.904 .52325 Mdot
.904 .52337 Mdot
.904 .5234 Mdot
.904 .52432 Mdot
.904 .52438 Mdot
.904 .52466 Mdot
.904 .52467 Mdot
.904 .52502 Mdot
.904 .52539 Mdot
.904 .52547 Mdot
.904 .52571 Mdot
.904 .52615 Mdot
.904 .52624 Mdot
.904 .5264 Mdot
.904 .52685 Mdot
.904 .52791 Mdot
.904 .52793 Mdot
.904 .52793 Mdot
.904 .52818 Mdot
.904 .52829 Mdot
.904 .52936 Mdot
.904 .52967 Mdot
.904 .53131 Mdot
.904 .53141 Mdot
.904 .53202 Mdot
.904 .53284 Mdot
.904 .53326 Mdot
.904 .53359 Mdot
.904 .53362 Mdot
.904 .53422 Mdot
.904 .53463 Mdot
.904 .53479 Mdot
.904 .5351 Mdot
.904 .53512 Mdot
.904 .53528 Mdot
.904 .5355 Mdot
.904 .53557 Mdot
.904 .53572 Mdot
.904 .53658 Mdot
.904 .53664 Mdot
.904 .5368 Mdot
.904 .53703 Mdot
.904 .53766 Mdot
.904 .53804 Mdot
.904 .53836 Mdot
.904 .53868 Mdot
.904 .53873 Mdot
.904 .5391 Mdot
.904 .53945 Mdot
.904 .53949 Mdot
.904 .54022 Mdot
.904 .54339 Mdot
.904 .5435 Mdot
.904 .54355 Mdot
.904 .54409 Mdot
.904 .54499 Mdot
.904 .54519 Mdot
.904 .54539 Mdot
.904 .54558 Mdot
.904 .5459 Mdot
.904 .54596 Mdot
.904 .54624 Mdot
.904 .54672 Mdot
.904 .54727 Mdot
.904 .54806 Mdot
.904 .54812 Mdot
.904 .54848 Mdot
.904 .54881 Mdot
.904 .5489 Mdot
.904 .54942 Mdot
.904 .54957 Mdot
.904 .55106 Mdot
.904 .55113 Mdot
.904 .55126 Mdot
.904 .55146 Mdot
.904 .55168 Mdot
.904 .55179 Mdot
.904 .55244 Mdot
.904 .55283 Mdot
.904 .5535 Mdot
.904 .55406 Mdot
.904 .55479 Mdot
.904 .55564 Mdot
.904 .55579 Mdot
.904 .55588 Mdot
.904 .55621 Mdot
.904 .55625 Mdot
.904 .55707 Mdot
.904 .55708 Mdot
.904 .55791 Mdot
.904 .55804 Mdot
.904 .55839 Mdot
.904 .55851 Mdot
.904 .55857 Mdot
.904 .55951 Mdot
.904 .56028 Mdot
.904 .56055 Mdot
.904 .56058 Mdot
.904 .56066 Mdot
.904 .5607 Mdot
.904 .56073 Mdot
.904 .56079 Mdot
.904 .56118 Mdot
.904 .56157 Mdot
.904 .56167 Mdot
.904 .56223 Mdot
.904 .56244 Mdot
.904 .56266 Mdot
.904 .56347 Mdot
.904 .56367 Mdot
.904 .56385 Mdot
.904 .5639 Mdot
.904 .56398 Mdot
.904 .5646 Mdot
.904 .56511 Mdot
.904 .56552 Mdot
.904 .5657 Mdot
.904 .56593 Mdot
.904 .56612 Mdot
.904 .56613 Mdot
.904 .56627 Mdot
.904 .56646 Mdot
.904 .56651 Mdot
.904 .56687 Mdot
.904 .56713 Mdot
.904 .56804 Mdot
.904 .56837 Mdot
.904 .56851 Mdot
.904 .56873 Mdot
.904 .56873 Mdot
.904 .5689 Mdot
.904 .56943 Mdot
.904 .56962 Mdot
.904 .56973 Mdot
.904 .5698 Mdot
.904 .56983 Mdot
.904 .57052 Mdot
.904 .57054 Mdot
.904 .57062 Mdot
.904 .57091 Mdot
.904 .57121 Mdot
.904 .57137 Mdot
.904 .57184 Mdot
.904 .5724 Mdot
.904 .5724 Mdot
.904 .57282 Mdot
.904 .57314 Mdot
.904 .57318 Mdot
.904 .57328 Mdot
.904 .57388 Mdot
.904 .57407 Mdot
.904 .57407 Mdot
.904 .57414 Mdot
.904 .57475 Mdot
.904 .5756 Mdot
.904 .57574 Mdot
.904 .57637 Mdot
.904 .57647 Mdot
.904 .57649 Mdot
.904 .57694 Mdot
.904 .57699 Mdot
.904 .57699 Mdot
.904 .57751 Mdot
.904 .5777 Mdot
.904 .57784 Mdot
.904 .57829 Mdot
.904 .57836 Mdot
.904 .57936 Mdot
.904 .58054 Mdot
.904 .58072 Mdot
.904 .58099 Mdot
.904 .58103 Mdot
.904 .58115 Mdot
.904 .58141 Mdot
.904 .5816 Mdot
.904 .58169 Mdot
.904 .58197 Mdot
.904 .58246 Mdot
.904 .58248 Mdot
.904 .58257 Mdot
.904 .58266 Mdot
.904 .58282 Mdot
.904 .58309 Mdot
.904 .58317 Mdot
.904 .58317 Mdot
.904 .5832 Mdot
.904 .58355 Mdot
.904 .5841 Mdot
.904 .58433 Mdot
.904 .58446 Mdot
.904 .58446 Mdot
.904 .58446 Mdot
.904 .58463 Mdot
.904 .58486 Mdot
.904 .58486 Mdot
.904 .58496 Mdot
.904 .5852 Mdot
.904 .5854 Mdot
.904 .58541 Mdot
.904 .58551 Mdot
.904 .58596 Mdot
.904 .58603 Mdot
.904 .58606 Mdot
.904 .58616 Mdot
.904 .58631 Mdot
.904 .58639 Mdot
.904 .58662 Mdot
.904 .58665 Mdot
.904 .58669 Mdot
.904 .5868 Mdot
.904 .58681 Mdot
.904 .58682 Mdot
.904 .58707 Mdot
.904 .58716 Mdot
.904 .58718 Mdot
.904 .58734 Mdot
.904 .58735 Mdot
.904 .58739 Mdot
.904 .5874 Mdot
.904 .58746 Mdot
.904 .58746 Mdot
.904 .58752 Mdot
.904 .58782 Mdot
.904 .58839 Mdot
.904 .58841 Mdot
.904 .58842 Mdot
.904 .58842 Mdot
.904 .58848 Mdot
.904 .58852 Mdot
.904 .58854 Mdot
.904 .58857 Mdot
.904 .58897 Mdot
.904 .58901 Mdot
.904 .58905 Mdot
.904 .5891 Mdot
.904 .58922 Mdot
.904 .58925 Mdot
.904 .58936 Mdot
.904 .58936 Mdot
.904 .58971 Mdot
.904 .58977 Mdot
.904 .5898 Mdot
.904 .58982 Mdot
.904 .58991 Mdot
.904 .59003 Mdot
.904 .5901 Mdot
.904 .59016 Mdot
.904 .5903 Mdot
.904 .5904 Mdot
.904 .59046 Mdot
.904 .59046 Mdot
.904 .59052 Mdot
.904 .59053 Mdot
.904 .59085 Mdot
.904 .59095 Mdot
.904 .59115 Mdot
.904 .59122 Mdot
.904 .59124 Mdot
.904 .59127 Mdot
.904 .59138 Mdot
.904 .59142 Mdot
.904 .59143 Mdot
.904 .5915 Mdot
.904 .59156 Mdot
.904 .59158 Mdot
.904 .59173 Mdot
.904 .59174 Mdot
.904 .59176 Mdot
.904 .59181 Mdot
.904 .59183 Mdot
.904 .59183 Mdot
.904 .59185 Mdot
.904 .59191 Mdot
.904 .59197 Mdot
.904 .592 Mdot
.904 .592 Mdot
.904 .59201 Mdot
.904 .59202 Mdot
.904 .59202 Mdot
.906 .05734 Mdot
.906 .05735 Mdot
.906 .05738 Mdot
.906 .05739 Mdot
.906 .0574 Mdot
.906 .05742 Mdot
.906 .05742 Mdot
.906 .05755 Mdot
.906 .05757 Mdot
.906 .05763 Mdot
.906 .05767 Mdot
.906 .05769 Mdot
.906 .0577 Mdot
.906 .05793 Mdot
.906 .05798 Mdot
.906 .05812 Mdot
.906 .0582 Mdot
.906 .05853 Mdot
.906 .05857 Mdot
.906 .05866 Mdot
.906 .0587 Mdot
.906 .05881 Mdot
.906 .05898 Mdot
.906 .0593 Mdot
.906 .05935 Mdot
.906 .05969 Mdot
.906 .05969 Mdot
.906 .05972 Mdot
.906 .05983 Mdot
.906 .05987 Mdot
.906 .06177 Mdot
.906 .06191 Mdot
.906 .062 Mdot
.906 .06214 Mdot
.906 .06235 Mdot
.906 .0628 Mdot
.906 .06312 Mdot
.906 .06361 Mdot
.906 .06362 Mdot
.906 .06446 Mdot
.906 .06469 Mdot
.906 .06488 Mdot
.906 .06511 Mdot
.906 .06614 Mdot
.906 .06616 Mdot
.906 .06637 Mdot
.906 .06707 Mdot
.906 .06769 Mdot
.906 .06769 Mdot
.906 .06826 Mdot
.906 .07099 Mdot
.906 .07186 Mdot
.906 .07256 Mdot
.906 .07267 Mdot
.906 .07287 Mdot
.906 .07389 Mdot
.906 .07468 Mdot
.906 .07507 Mdot
.906 .07685 Mdot
.906 .07757 Mdot
.906 .07759 Mdot
.906 .07803 Mdot
.906 .07908 Mdot
.906 .07913 Mdot
.906 .08188 Mdot
.906 .0821 Mdot
.906 .08251 Mdot
.906 .08272 Mdot
.906 .08303 Mdot
.906 .08364 Mdot
.906 .08637 Mdot
.906 .0866 Mdot
.906 .08667 Mdot
.906 .08836 Mdot
.906 .08871 Mdot
.906 .08887 Mdot
.906 .08896 Mdot
.906 .08996 Mdot
.906 .09011 Mdot
.906 .09077 Mdot
.906 .09279 Mdot
.906 .0928 Mdot
.906 .09621 Mdot
.906 .0967 Mdot
.906 .09724 Mdot
.906 .09761 Mdot
.906 .09784 Mdot
.906 .09802 Mdot
.906 .09968 Mdot
.906 .10088 Mdot
.906 .10224 Mdot
.906 .10234 Mdot
.906 .10258 Mdot
.906 .10406 Mdot
.906 .10558 Mdot
.906 .10572 Mdot
.906 .10658 Mdot
.906 .10986 Mdot
.906 .11022 Mdot
.906 .11066 Mdot
.906 .1122 Mdot
.906 .11396 Mdot
.906 .11397 Mdot
.906 .11468 Mdot
.906 .11511 Mdot
.906 .11633 Mdot
.906 .11635 Mdot
.906 .1166 Mdot
.906 .11822 Mdot
.906 .11908 Mdot
.906 .11971 Mdot
.906 .1199 Mdot
.906 .12122 Mdot
.906 .12142 Mdot
.906 .12163 Mdot
.906 .12312 Mdot
.906 .12424 Mdot
.906 .12424 Mdot
.906 .12524 Mdot
.906 .12529 Mdot
.906 .12697 Mdot
.906 .12716 Mdot
.906 .13023 Mdot
.906 .13201 Mdot
.906 .13227 Mdot
.906 .13232 Mdot
.906 .13338 Mdot
.906 .13391 Mdot
.906 .13426 Mdot
.906 .1368 Mdot
.906 .13817 Mdot
.906 .13825 Mdot
.906 .13879 Mdot
.906 .13887 Mdot
.906 .13915 Mdot
.906 .13932 Mdot
.906 .13933 Mdot
.906 .14101 Mdot
.906 .14226 Mdot
.906 .14253 Mdot
.906 .14381 Mdot
.906 .14447 Mdot
.906 .14575 Mdot
.906 .14626 Mdot
.906 .14626 Mdot
.906 .14629 Mdot
.906 .14715 Mdot
.906 .14909 Mdot
.906 .14999 Mdot
.906 .15048 Mdot
.906 .15144 Mdot
.906 .15149 Mdot
.906 .15184 Mdot
.906 .15459 Mdot
.906 .1556 Mdot
.906 .15561 Mdot
.906 .1566 Mdot
.906 .15693 Mdot
.906 .15788 Mdot
.906 .15893 Mdot
.906 .15908 Mdot
.906 .16018 Mdot
.906 .16062 Mdot
.906 .16262 Mdot
.906 .16263 Mdot
.906 .16269 Mdot
.906 .16277 Mdot
.906 .16461 Mdot
.906 .16465 Mdot
.906 .16698 Mdot
.906 .16843 Mdot
.906 .16855 Mdot
.906 .16952 Mdot
.906 .1699 Mdot
.906 .16993 Mdot
.906 .17002 Mdot
.906 .17002 Mdot
.906 .17007 Mdot
.906 .17011 Mdot
.906 .17015 Mdot
.906 .17016 Mdot
.906 .17059 Mdot
.906 .17069 Mdot
.906 .17087 Mdot
.906 .17097 Mdot
.906 .17102 Mdot
.906 .17106 Mdot
.906 .17111 Mdot
.906 .17147 Mdot
.906 .17189 Mdot
.906 .17205 Mdot
.906 .17252 Mdot
.906 .17278 Mdot
.906 .17336 Mdot
.906 .17378 Mdot
.906 .17387 Mdot
.906 .17397 Mdot
.906 .17403 Mdot
.906 .17431 Mdot
.906 .17444 Mdot
.906 .1748 Mdot
.906 .17539 Mdot
.906 .17645 Mdot
.906 .17661 Mdot
.906 .17774 Mdot
.906 .17775 Mdot
.906 .17785 Mdot
.906 .17821 Mdot
.906 .17834 Mdot
.906 .1784 Mdot
.906 .17924 Mdot
.906 .17991 Mdot
.906 .1806 Mdot
.906 .1808 Mdot
.906 .18163 Mdot
.906 .18305 Mdot
.906 .18417 Mdot
.906 .18462 Mdot
.906 .18508 Mdot
.906 .18538 Mdot
.906 .18587 Mdot
.906 .18595 Mdot
.906 .1862 Mdot
.906 .18654 Mdot
.906 .18683 Mdot
.906 .1874 Mdot
.906 .18802 Mdot
.906 .1883 Mdot
.906 .18876 Mdot
.906 .18909 Mdot
.906 .18938 Mdot
.906 .18983 Mdot
.906 .19068 Mdot
.906 .19071 Mdot
.906 .19345 Mdot
.906 .19352 Mdot
.906 .1942 Mdot
.906 .19482 Mdot
.906 .19557 Mdot
.906 .19805 Mdot
.906 .19892 Mdot
.906 .19899 Mdot
.906 .19968 Mdot
.906 .20102 Mdot
.906 .20194 Mdot
.906 .20221 Mdot
.906 .20276 Mdot
.906 .20392 Mdot
.906 .20393 Mdot
.906 .20499 Mdot
.906 .20576 Mdot
.906 .20595 Mdot
.906 .2123 Mdot
.906 .21417 Mdot
.906 .21448 Mdot
.906 .21505 Mdot
.906 .21568 Mdot
.906 .2165 Mdot
.906 .2169 Mdot
.906 .21724 Mdot
.906 .21838 Mdot
.906 .21934 Mdot
.906 .21944 Mdot
.906 .21978 Mdot
.906 .21981 Mdot
.906 .22042 Mdot
.906 .22361 Mdot
.906 .22515 Mdot
.906 .22528 Mdot
.906 .22556 Mdot
.906 .22609 Mdot
.906 .22651 Mdot
.906 .2273 Mdot
.906 .22914 Mdot
.906 .23059 Mdot
.906 .23283 Mdot
.906 .23506 Mdot
.906 .23514 Mdot
.906 .23604 Mdot
.906 .23648 Mdot
.906 .23674 Mdot
.906 .23681 Mdot
.906 .23702 Mdot
.906 .23723 Mdot
.906 .2375 Mdot
.906 .23897 Mdot
.906 .2391 Mdot
.906 .23971 Mdot
.906 .23987 Mdot
.906 .24034 Mdot
.906 .2407 Mdot
.906 .24194 Mdot
.906 .24261 Mdot
.906 .24343 Mdot
.906 .24421 Mdot
.906 .24499 Mdot
.906 .24533 Mdot
.906 .24641 Mdot
.906 .24643 Mdot
.906 .24825 Mdot
.906 .24826 Mdot
.906 .24844 Mdot
.906 .2489 Mdot
.906 .24914 Mdot
.906 .24971 Mdot
.906 .25016 Mdot
.906 .25078 Mdot
.906 .25095 Mdot
.906 .25118 Mdot
.906 .25172 Mdot
.906 .25282 Mdot
.906 .25355 Mdot
.906 .25424 Mdot
.906 .25622 Mdot
.906 .25662 Mdot
.906 .25769 Mdot
.906 .25785 Mdot
.906 .25875 Mdot
.906 .25991 Mdot
.906 .26063 Mdot
.906 .26171 Mdot
.906 .2624 Mdot
.906 .2626 Mdot
.906 .26699 Mdot
.906 .26759 Mdot
.906 .26863 Mdot
.906 .2691 Mdot
.906 .26936 Mdot
.906 .27117 Mdot
.906 .27229 Mdot
.906 .27274 Mdot
.906 .27345 Mdot
.906 .27465 Mdot
.906 .27469 Mdot
.906 .27707 Mdot
.906 .28051 Mdot
.906 .28053 Mdot
.906 .28328 Mdot
.906 .28425 Mdot
.906 .28434 Mdot
.906 .28868 Mdot
.906 .29002 Mdot
.906 .29027 Mdot
.906 .29141 Mdot
.906 .29167 Mdot
.906 .29216 Mdot
.906 .29319 Mdot
.906 .2932 Mdot
.906 .29426 Mdot
.906 .29488 Mdot
.906 .29517 Mdot
.906 .29539 Mdot
.906 .29932 Mdot
.906 .29933 Mdot
.906 .30006 Mdot
.906 .30091 Mdot
.906 .30212 Mdot
.906 .3034 Mdot
.906 .30392 Mdot
.906 .30524 Mdot
.906 .30531 Mdot
.906 .30556 Mdot
.906 .30607 Mdot
.906 .30713 Mdot
.906 .30715 Mdot
.906 .30743 Mdot
.906 .30762 Mdot
.906 .30809 Mdot
.906 .3097 Mdot
.906 .31073 Mdot
.906 .31215 Mdot
.906 .31286 Mdot
.906 .31392 Mdot
.906 .31491 Mdot
.906 .31605 Mdot
.906 .31628 Mdot
.906 .31639 Mdot
.906 .31668 Mdot
.906 .31787 Mdot
.906 .31877 Mdot
.906 .31899 Mdot
.906 .31906 Mdot
.906 .3223 Mdot
.906 .32251 Mdot
.906 .32421 Mdot
.906 .32614 Mdot
.906 .32778 Mdot
.906 .32873 Mdot
.906 .32935 Mdot
.906 .32991 Mdot
.906 .33238 Mdot
.906 .33312 Mdot
.906 .33395 Mdot
.906 .33537 Mdot
.906 .33567 Mdot
.906 .33698 Mdot
.906 .33783 Mdot
.906 .33856 Mdot
.906 .33859 Mdot
.906 .34042 Mdot
.906 .34056 Mdot
.906 .34083 Mdot
.906 .34116 Mdot
.906 .34154 Mdot
.906 .34321 Mdot
.906 .34438 Mdot
.906 .34467 Mdot
.906 .34472 Mdot
.906 .34538 Mdot
.906 .34687 Mdot
.906 .34921 Mdot
.906 .34951 Mdot
.906 .3496 Mdot
.906 .3517 Mdot
.906 .35175 Mdot
.906 .35187 Mdot
.906 .35258 Mdot
.906 .3533 Mdot
.906 .35337 Mdot
.906 .35377 Mdot
.906 .35527 Mdot
.906 .35709 Mdot
.906 .3571 Mdot
.906 .35759 Mdot
.906 .35812 Mdot
.906 .35823 Mdot
.906 .35892 Mdot
.906 .35955 Mdot
.906 .35963 Mdot
.906 .36026 Mdot
.906 .36096 Mdot
.906 .36141 Mdot
.906 .36184 Mdot
.906 .36251 Mdot
.906 .36259 Mdot
.906 .36458 Mdot
.906 .3646 Mdot
.906 .36501 Mdot
.906 .36534 Mdot
.906 .36682 Mdot
.906 .36705 Mdot
.906 .36718 Mdot
.906 .36725 Mdot
.906 .36843 Mdot
.906 .36977 Mdot
.906 .37078 Mdot
.906 .3711 Mdot
.906 .37127 Mdot
.906 .37174 Mdot
.906 .37305 Mdot
.906 .37339 Mdot
.906 .3735 Mdot
.906 .37418 Mdot
.906 .37423 Mdot
.906 .37475 Mdot
.906 .37542 Mdot
.906 .37544 Mdot
.906 .37547 Mdot
.906 .37608 Mdot
.906 .37686 Mdot
.906 .37737 Mdot
.906 .37786 Mdot
.906 .37913 Mdot
.906 .38234 Mdot
.906 .38316 Mdot
.906 .38334 Mdot
.906 .38361 Mdot
.906 .38375 Mdot
.906 .38394 Mdot
.906 .38408 Mdot
.906 .38656 Mdot
.906 .38779 Mdot
.906 .38795 Mdot
.906 .38861 Mdot
.906 .39127 Mdot
.906 .39171 Mdot
.906 .39205 Mdot
.906 .39439 Mdot
.906 .3945 Mdot
.906 .39477 Mdot
.906 .3955 Mdot
.906 .39591 Mdot
.906 .39742 Mdot
.906 .39763 Mdot
.906 .39769 Mdot
.906 .39774 Mdot
.906 .39782 Mdot
.906 .39903 Mdot
.906 .39921 Mdot
.906 .39944 Mdot
.906 .39986 Mdot
.906 .39995 Mdot
.906 .40025 Mdot
.906 .40025 Mdot
.906 .40075 Mdot
.906 .40098 Mdot
.906 .40147 Mdot
.906 .40197 Mdot
.906 .40288 Mdot
.906 .40327 Mdot
.906 .40332 Mdot
.906 .40405 Mdot
.906 .40683 Mdot
.906 .40743 Mdot
.906 .40775 Mdot
.906 .40837 Mdot
.906 .40998 Mdot
.906 .41023 Mdot
.906 .41026 Mdot
.906 .41138 Mdot
.906 .41172 Mdot
.906 .41254 Mdot
.906 .41451 Mdot
.906 .41482 Mdot
.906 .41561 Mdot
.906 .41563 Mdot
.906 .41569 Mdot
.906 .41622 Mdot
.906 .41675 Mdot
.906 .41755 Mdot
.906 .41782 Mdot
.906 .41806 Mdot
.906 .41844 Mdot
.906 .41881 Mdot
.906 .41993 Mdot
.906 .42041 Mdot
.906 .4209 Mdot
.906 .4217 Mdot
.906 .42265 Mdot
.906 .42329 Mdot
.906 .42362 Mdot
.906 .42467 Mdot
.906 .42518 Mdot
.906 .42547 Mdot
.906 .4261 Mdot
.906 .42668 Mdot
.906 .42678 Mdot
.906 .42753 Mdot
.906 .42772 Mdot
.906 .42911 Mdot
.906 .42929 Mdot
.906 .42945 Mdot
.906 .42962 Mdot
.906 .43003 Mdot
.906 .43072 Mdot
.906 .43109 Mdot
.906 .43274 Mdot
.906 .43276 Mdot
.906 .43294 Mdot
.906 .43308 Mdot
.906 .43325 Mdot
.906 .43325 Mdot
.906 .43326 Mdot
.906 .43361 Mdot
.906 .43374 Mdot
.906 .43519 Mdot
.906 .43531 Mdot
.906 .43534 Mdot
.906 .43735 Mdot
.906 .43802 Mdot
.906 .43831 Mdot
.906 .43841 Mdot
.906 .43886 Mdot
.906 .43887 Mdot
.906 .4393 Mdot
.906 .43943 Mdot
.906 .43995 Mdot
.906 .44199 Mdot
.906 .44205 Mdot
.906 .44235 Mdot
.906 .44455 Mdot
.906 .4448 Mdot
.906 .44541 Mdot
.906 .4459 Mdot
.906 .44934 Mdot
.906 .44936 Mdot
.906 .44948 Mdot
.906 .44963 Mdot
.906 .45031 Mdot
.906 .45135 Mdot
.906 .45253 Mdot
.906 .45281 Mdot
.906 .45313 Mdot
.906 .4532 Mdot
.906 .45329 Mdot
.906 .45346 Mdot
.906 .45363 Mdot
.906 .45377 Mdot
.906 .45438 Mdot
.906 .45492 Mdot
.906 .45717 Mdot
.906 .45773 Mdot
.906 .45913 Mdot
.906 .4604 Mdot
.906 .46047 Mdot
.906 .46068 Mdot
.906 .46069 Mdot
.906 .46091 Mdot
.906 .46096 Mdot
.906 .46249 Mdot
.906 .4632 Mdot
.906 .46326 Mdot
.906 .46343 Mdot
.906 .46344 Mdot
.906 .46352 Mdot
.906 .46359 Mdot
.906 .46367 Mdot
.906 .46369 Mdot
.906 .46448 Mdot
.906 .46466 Mdot
.906 .46499 Mdot
.906 .46519 Mdot
.906 .46527 Mdot
.906 .46535 Mdot
.906 .46543 Mdot
.906 .4661 Mdot
.906 .46687 Mdot
.906 .46717 Mdot
.906 .46731 Mdot
.906 .46801 Mdot
.906 .4682 Mdot
.906 .4685 Mdot
.906 .46932 Mdot
.906 .46955 Mdot
.906 .46978 Mdot
.906 .4703 Mdot
.906 .47047 Mdot
.906 .47064 Mdot
.906 .47076 Mdot
.906 .47125 Mdot
.906 .4715 Mdot
.906 .47214 Mdot
.906 .47319 Mdot
.906 .47372 Mdot
.906 .47424 Mdot
.906 .47435 Mdot
.906 .47508 Mdot
.906 .47536 Mdot
.906 .47735 Mdot
.906 .47737 Mdot
.906 .47754 Mdot
.906 .47794 Mdot
.906 .47817 Mdot
.906 .47838 Mdot
.906 .47849 Mdot
.906 .47884 Mdot
.906 .47907 Mdot
.906 .47981 Mdot
.906 .47984 Mdot
.906 .47996 Mdot
.906 .48061 Mdot
.906 .48079 Mdot
.906 .48111 Mdot
.906 .48128 Mdot
.906 .48229 Mdot
.906 .48244 Mdot
.906 .48263 Mdot
.906 .48406 Mdot
.906 .48585 Mdot
.906 .48591 Mdot
.906 .4861 Mdot
.906 .48644 Mdot
.906 .48833 Mdot
.906 .48853 Mdot
.906 .48875 Mdot
.906 .48907 Mdot
.906 .48933 Mdot
.906 .48934 Mdot
.906 .48934 Mdot
.906 .48962 Mdot
.906 .48984 Mdot
.906 .48986 Mdot
.906 .49014 Mdot
.906 .49019 Mdot
.906 .49033 Mdot
.906 .49114 Mdot
.906 .49127 Mdot
.906 .49168 Mdot
.906 .49223 Mdot
.906 .49271 Mdot
.906 .49289 Mdot
.906 .49349 Mdot
.906 .49362 Mdot
.906 .49461 Mdot
.906 .49464 Mdot
.906 .49508 Mdot
.906 .49526 Mdot
.906 .49554 Mdot
.906 .4958 Mdot
.906 .49583 Mdot
.906 .49608 Mdot
.906 .49636 Mdot
.906 .49681 Mdot
.906 .49754 Mdot
.906 .49829 Mdot
.906 .49861 Mdot
.906 .49889 Mdot
.906 .49893 Mdot
.906 .49978 Mdot
.906 .49993 Mdot
.906 .50085 Mdot
.906 .50182 Mdot
.906 .50228 Mdot
.906 .50307 Mdot
.906 .5032 Mdot
.906 .5033 Mdot
.906 .50435 Mdot
.906 .50468 Mdot
.906 .50518 Mdot
.906 .50529 Mdot
.906 .50615 Mdot
.906 .50643 Mdot
.906 .50758 Mdot
.906 .50879 Mdot
.906 .50951 Mdot
.906 .51015 Mdot
.906 .51022 Mdot
.906 .51143 Mdot
.906 .51154 Mdot
.906 .51187 Mdot
.906 .51241 Mdot
.906 .51254 Mdot
.906 .51296 Mdot
.906 .51332 Mdot
.906 .51371 Mdot
.906 .51449 Mdot
.906 .51487 Mdot
.906 .51562 Mdot
.906 .5158 Mdot
.906 .51618 Mdot
.906 .51637 Mdot
.906 .51646 Mdot
.906 .51648 Mdot
.906 .51696 Mdot
.906 .51761 Mdot
.906 .51804 Mdot
.906 .51861 Mdot
.906 .51861 Mdot
.906 .52009 Mdot
.906 .5208 Mdot
.906 .52116 Mdot
.906 .52143 Mdot
.906 .52191 Mdot
.906 .52239 Mdot
.906 .52391 Mdot
.906 .52394 Mdot
.906 .52428 Mdot
.906 .52643 Mdot
.906 .52725 Mdot
.906 .52767 Mdot
.906 .52845 Mdot
.906 .52988 Mdot
.906 .53203 Mdot
.906 .53227 Mdot
.906 .53266 Mdot
.906 .53296 Mdot
.906 .53301 Mdot
.906 .53337 Mdot
.906 .53351 Mdot
.906 .53417 Mdot
.906 .53464 Mdot
.906 .53518 Mdot
.906 .53526 Mdot
.906 .53567 Mdot
.906 .53586 Mdot
.906 .53609 Mdot
.906 .53615 Mdot
.906 .53675 Mdot
.906 .53676 Mdot
.906 .53711 Mdot
.906 .53723 Mdot
.906 .53748 Mdot
.906 .53774 Mdot
.906 .538 Mdot
.906 .53823 Mdot
.906 .53863 Mdot
.906 .53875 Mdot
.906 .53915 Mdot
.906 .5392 Mdot
.906 .53967 Mdot
.906 .53976 Mdot
.906 .53983 Mdot
.906 .5399 Mdot
.906 .53992 Mdot
.906 .54015 Mdot
.906 .54191 Mdot
.906 .54238 Mdot
.906 .54322 Mdot
.906 .54352 Mdot
.906 .54361 Mdot
.906 .54365 Mdot
.906 .54535 Mdot
.906 .5455 Mdot
.906 .54581 Mdot
.906 .54628 Mdot
.906 .5464 Mdot
.906 .54666 Mdot
.906 .54686 Mdot
.906 .54714 Mdot
.906 .54773 Mdot
.906 .54971 Mdot
.906 .55001 Mdot
.906 .5507 Mdot
.906 .55087 Mdot
.906 .55124 Mdot
.906 .55216 Mdot
.906 .55355 Mdot
.906 .55468 Mdot
.906 .55482 Mdot
.906 .55501 Mdot
.906 .55515 Mdot
.906 .55542 Mdot
.906 .55559 Mdot
.906 .55579 Mdot
.906 .55586 Mdot
.906 .5564 Mdot
.906 .55674 Mdot
.906 .55717 Mdot
.906 .55742 Mdot
.906 .55748 Mdot
.906 .55769 Mdot
.906 .55789 Mdot
.906 .55815 Mdot
.906 .55948 Mdot
.906 .55953 Mdot
.906 .55966 Mdot
.906 .56022 Mdot
.906 .56037 Mdot
.906 .56066 Mdot
.906 .56081 Mdot
.906 .5611 Mdot
.906 .56113 Mdot
.906 .56156 Mdot
.906 .56225 Mdot
.906 .56226 Mdot
.906 .56281 Mdot
.906 .56283 Mdot
.906 .56285 Mdot
.906 .56285 Mdot
.906 .56344 Mdot
.906 .56357 Mdot
.906 .5639 Mdot
.906 .56394 Mdot
.906 .56425 Mdot
.906 .56453 Mdot
.906 .56463 Mdot
.906 .56491 Mdot
.906 .56492 Mdot
.906 .56521 Mdot
.906 .56602 Mdot
.906 .56612 Mdot
.906 .56613 Mdot
.906 .56641 Mdot
.906 .56656 Mdot
.906 .56682 Mdot
.906 .56763 Mdot
.906 .56764 Mdot
.906 .56764 Mdot
.906 .56779 Mdot
.906 .56816 Mdot
.906 .56835 Mdot
.906 .56872 Mdot
.906 .5688 Mdot
.906 .56916 Mdot
.906 .56964 Mdot
.906 .56964 Mdot
.906 .56969 Mdot
.906 .56977 Mdot
.906 .5698 Mdot
.906 .56995 Mdot
.906 .56997 Mdot
.906 .57037 Mdot
.906 .5711 Mdot
.906 .5712 Mdot
.906 .57135 Mdot
.906 .57165 Mdot
.906 .57167 Mdot
.906 .57174 Mdot
.906 .57225 Mdot
.906 .57312 Mdot
.906 .57317 Mdot
.906 .57365 Mdot
.906 .57366 Mdot
.906 .57395 Mdot
.906 .57395 Mdot
.906 .57426 Mdot
.906 .57469 Mdot
.906 .57474 Mdot
.906 .5748 Mdot
.906 .57517 Mdot
.906 .57523 Mdot
.906 .5754 Mdot
.906 .57565 Mdot
.906 .5761 Mdot
.906 .57617 Mdot
.906 .57618 Mdot
.906 .57652 Mdot
.906 .57664 Mdot
.906 .57684 Mdot
.906 .57684 Mdot
.906 .57733 Mdot
.906 .57776 Mdot
.906 .57789 Mdot
.906 .57799 Mdot
.906 .5789 Mdot
.906 .57914 Mdot
.906 .57918 Mdot
.906 .5796 Mdot
.906 .58001 Mdot
.906 .58007 Mdot
.906 .5801 Mdot
.906 .58048 Mdot
.906 .58081 Mdot
.906 .58127 Mdot
.906 .58132 Mdot
.906 .58138 Mdot
.906 .58148 Mdot
.906 .58163 Mdot
.906 .58177 Mdot
.906 .5827 Mdot
.906 .5827 Mdot
.906 .58326 Mdot
.906 .58344 Mdot
.906 .58348 Mdot
.906 .58375 Mdot
.906 .58378 Mdot
.906 .58382 Mdot
.906 .58392 Mdot
.906 .58438 Mdot
.906 .58439 Mdot
.906 .58446 Mdot
.906 .5852 Mdot
.906 .58537 Mdot
.906 .58545 Mdot
.906 .58551 Mdot
.906 .58562 Mdot
.906 .58568 Mdot
.906 .58642 Mdot
.906 .58644 Mdot
.906 .58672 Mdot
.906 .58684 Mdot
.906 .58684 Mdot
.906 .58704 Mdot
.906 .58752 Mdot
.906 .58762 Mdot
.906 .58784 Mdot
.906 .58811 Mdot
.906 .58816 Mdot
.906 .58819 Mdot
.906 .58838 Mdot
.906 .58861 Mdot
.906 .58934 Mdot
.906 .5895 Mdot
.906 .5895 Mdot
.906 .58966 Mdot
.906 .58985 Mdot
.906 .5899 Mdot
.906 .58991 Mdot
.906 .59019 Mdot
.906 .59025 Mdot
.906 .5903 Mdot
.906 .59036 Mdot
.906 .59058 Mdot
.906 .59059 Mdot
.906 .59071 Mdot
.906 .5908 Mdot
.906 .59092 Mdot
.906 .59098 Mdot
.906 .59102 Mdot
.906 .59104 Mdot
.906 .59108 Mdot
.906 .59158 Mdot
.906 .59159 Mdot
.906 .59162 Mdot
.906 .59163 Mdot
.906 .59163 Mdot
.906 .59172 Mdot
.906 .59173 Mdot
.906 .59182 Mdot
.906 .59186 Mdot
.906 .59189 Mdot
.906 .5919 Mdot
.906 .59192 Mdot
.906 .59194 Mdot
.906 .59202 Mdot
.906 .59204 Mdot
.906 .59208 Mdot
.906 .59209 Mdot
.906 .59216 Mdot
.906 .59216 Mdot
.906 .59216 Mdot
.906 .59217 Mdot
.906 .59219 Mdot
.906 .5922 Mdot
.906 .59223 Mdot
.906 .59223 Mdot
.906 .59223 Mdot
.906 .59224 Mdot
.906 .59224 Mdot
.906 .59225 Mdot
.906 .59225 Mdot
.908 .05653 Mdot
.908 .05653 Mdot
.908 .05659 Mdot
.908 .05662 Mdot
.908 .05663 Mdot
.908 .05668 Mdot
.908 .05673 Mdot
.908 .05676 Mdot
.908 .05678 Mdot
.908 .05683 Mdot
.908 .05686 Mdot
.908 .05695 Mdot
.908 .05699 Mdot
.908 .05723 Mdot
.908 .05731 Mdot
.908 .05736 Mdot
.908 .05751 Mdot
.908 .05754 Mdot
.908 .05759 Mdot
.908 .05765 Mdot
.908 .05777 Mdot
.908 .05801 Mdot
.908 .05825 Mdot
.908 .05833 Mdot
.908 .05851 Mdot
.908 .05859 Mdot
.908 .05906 Mdot
.908 .05924 Mdot
.908 .05932 Mdot
.908 .0598 Mdot
.908 .06001 Mdot
.908 .06048 Mdot
.908 .06051 Mdot
.908 .06077 Mdot
.908 .06079 Mdot
.908 .06215 Mdot
.908 .06219 Mdot
.908 .06242 Mdot
.908 .06264 Mdot
.908 .06295 Mdot
.908 .06305 Mdot
.908 .06314 Mdot
.908 .06324 Mdot
.908 .06363 Mdot
.908 .06467 Mdot
.908 .06485 Mdot
.908 .06538 Mdot
.908 .0654 Mdot
.908 .06546 Mdot
.908 .0656 Mdot
.908 .06561 Mdot
.908 .06651 Mdot
.908 .06655 Mdot
.908 .06714 Mdot
.908 .06722 Mdot
.908 .06738 Mdot
.908 .06758 Mdot
.908 .06759 Mdot
.908 .06771 Mdot
.908 .06854 Mdot
.908 .06876 Mdot
.908 .07004 Mdot
.908 .07024 Mdot
.908 .07063 Mdot
.908 .07064 Mdot
.908 .07069 Mdot
.908 .0707 Mdot
.908 .07098 Mdot
.908 .07156 Mdot
.908 .0719 Mdot
.908 .07211 Mdot
.908 .07282 Mdot
.908 .07347 Mdot
.908 .07352 Mdot
.908 .07384 Mdot
.908 .07387 Mdot
.908 .074 Mdot
.908 .07413 Mdot
.908 .07486 Mdot
.908 .07555 Mdot
.908 .07569 Mdot
.908 .07657 Mdot
.908 .07795 Mdot
.908 .07816 Mdot
.908 .07828 Mdot
.908 .07861 Mdot
.908 .08098 Mdot
.908 .08134 Mdot
.908 .08144 Mdot
.908 .08205 Mdot
.908 .08213 Mdot
.908 .0833 Mdot
.908 .08756 Mdot
.908 .08807 Mdot
.908 .08926 Mdot
.908 .08986 Mdot
.908 .09029 Mdot
.908 .09126 Mdot
.908 .09349 Mdot
.908 .09531 Mdot
.908 .09699 Mdot
.908 .09831 Mdot
.908 .09833 Mdot
.908 .09982 Mdot
.908 .10004 Mdot
.908 .10038 Mdot
.908 .10147 Mdot
.908 .10157 Mdot
.908 .10205 Mdot
.908 .10351 Mdot
.908 .10408 Mdot
.908 .1049 Mdot
.908 .10711 Mdot
.908 .10844 Mdot
.908 .11028 Mdot
.908 .1103 Mdot
.908 .11054 Mdot
.908 .11101 Mdot
.908 .11173 Mdot
.908 .11182 Mdot
.908 .112 Mdot
.908 .11389 Mdot
.908 .11667 Mdot
.908 .11816 Mdot
.908 .11842 Mdot
.908 .11905 Mdot
.908 .11968 Mdot
.908 .12008 Mdot
.908 .12417 Mdot
.908 .12572 Mdot
.908 .12885 Mdot
.908 .12979 Mdot
.908 .13148 Mdot
.908 .13265 Mdot
.908 .13333 Mdot
.908 .13362 Mdot
.908 .13616 Mdot
.908 .13621 Mdot
.908 .13631 Mdot
.908 .13758 Mdot
.908 .1376 Mdot
.908 .13995 Mdot
.908 .14164 Mdot
.908 .14168 Mdot
.908 .14322 Mdot
.908 .14358 Mdot
.908 .14362 Mdot
.908 .14389 Mdot
.908 .14583 Mdot
.908 .14744 Mdot
.908 .14851 Mdot
.908 .14909 Mdot
.908 .14967 Mdot
.908 .14993 Mdot
.908 .15311 Mdot
.908 .15576 Mdot
.908 .15888 Mdot
.908 .1603 Mdot
.908 .16059 Mdot
.908 .16358 Mdot
.908 .16392 Mdot
.908 .16675 Mdot
.908 .16724 Mdot
.908 .16724 Mdot
.908 .16738 Mdot
.908 .16743 Mdot
.908 .16753 Mdot
.908 .16756 Mdot
.908 .16775 Mdot
.908 .16792 Mdot
.908 .16802 Mdot
.908 .16808 Mdot
.908 .16825 Mdot
.908 .16836 Mdot
.908 .16866 Mdot
.908 .1688 Mdot
.908 .1696 Mdot
.908 .16985 Mdot
.908 .17002 Mdot
.908 .17045 Mdot
.908 .17054 Mdot
.908 .17061 Mdot
.908 .17063 Mdot
.908 .17081 Mdot
.908 .171 Mdot
.908 .17141 Mdot
.908 .17221 Mdot
.908 .17302 Mdot
.908 .17326 Mdot
.908 .17388 Mdot
.908 .17407 Mdot
.908 .17415 Mdot
.908 .17495 Mdot
.908 .17571 Mdot
.908 .17621 Mdot
.908 .17632 Mdot
.908 .17658 Mdot
.908 .17819 Mdot
.908 .17824 Mdot
.908 .17865 Mdot
.908 .17887 Mdot
.908 .1794 Mdot
.908 .18013 Mdot
.908 .18044 Mdot
.908 .18053 Mdot
.908 .18091 Mdot
.908 .18106 Mdot
.908 .18139 Mdot
.908 .18146 Mdot
.908 .18149 Mdot
.908 .18317 Mdot
.908 .18454 Mdot
.908 .18595 Mdot
.908 .18609 Mdot
.908 .18684 Mdot
.908 .18758 Mdot
.908 .1886 Mdot
.908 .18891 Mdot
.908 .18921 Mdot
.908 .18953 Mdot
.908 .18982 Mdot
.908 .19083 Mdot
.908 .19222 Mdot
.908 .19328 Mdot
.908 .19421 Mdot
.908 .1944 Mdot
.908 .19479 Mdot
.908 .1951 Mdot
.908 .19545 Mdot
.908 .19549 Mdot
.908 .19604 Mdot
.908 .19654 Mdot
.908 .1966 Mdot
.908 .19679 Mdot
.908 .19709 Mdot
.908 .19724 Mdot
.908 .19727 Mdot
.908 .19756 Mdot
.908 .19984 Mdot
.908 .20018 Mdot
.908 .20033 Mdot
.908 .20223 Mdot
.908 .20248 Mdot
.908 .20299 Mdot
.908 .20305 Mdot
.908 .20353 Mdot
.908 .20364 Mdot
.908 .20369 Mdot
.908 .20406 Mdot
.908 .20437 Mdot
.908 .20468 Mdot
.908 .20544 Mdot
.908 .20617 Mdot
.908 .20672 Mdot
.908 .20742 Mdot
.908 .20742 Mdot
.908 .20885 Mdot
.908 .21096 Mdot
.908 .21153 Mdot
.908 .21216 Mdot
.908 .21342 Mdot
.908 .21345 Mdot
.908 .21359 Mdot
.908 .2136 Mdot
.908 .21362 Mdot
.908 .21442 Mdot
.908 .21453 Mdot
.908 .21498 Mdot
.908 .21622 Mdot
.908 .21636 Mdot
.908 .21742 Mdot
.908 .21753 Mdot
.908 .2181 Mdot
.908 .21916 Mdot
.908 .21993 Mdot
.908 .22027 Mdot
.908 .22035 Mdot
.908 .22064 Mdot
.908 .22109 Mdot
.908 .22147 Mdot
.908 .22169 Mdot
.908 .22237 Mdot
.908 .22253 Mdot
.908 .22314 Mdot
.908 .22354 Mdot
.908 .22363 Mdot
.908 .22404 Mdot
.908 .22445 Mdot
.908 .22462 Mdot
.908 .22495 Mdot
.908 .22635 Mdot
.908 .22651 Mdot
.908 .22675 Mdot
.908 .22853 Mdot
.908 .22889 Mdot
.908 .22911 Mdot
.908 .22933 Mdot
.908 .23157 Mdot
.908 .23188 Mdot
.908 .23205 Mdot
.908 .23206 Mdot
.908 .23216 Mdot
.908 .23238 Mdot
.908 .23376 Mdot
.908 .23537 Mdot
.908 .23632 Mdot
.908 .23645 Mdot
.908 .23674 Mdot
.908 .23697 Mdot
.908 .23734 Mdot
.908 .23798 Mdot
.908 .23838 Mdot
.908 .23977 Mdot
.908 .24082 Mdot
.908 .24306 Mdot
.908 .24316 Mdot
.908 .24469 Mdot
.908 .2456 Mdot
.908 .24671 Mdot
.908 .2468 Mdot
.908 .247 Mdot
.908 .2472 Mdot
.908 .24885 Mdot
.908 .24895 Mdot
.908 .24896 Mdot
.908 .24909 Mdot
.908 .24966 Mdot
.908 .25116 Mdot
.908 .25167 Mdot
.908 .25169 Mdot
.908 .25265 Mdot
.908 .25634 Mdot
.908 .25801 Mdot
.908 .25844 Mdot
.908 .25881 Mdot
.908 .26146 Mdot
.908 .26153 Mdot
.908 .26158 Mdot
.908 .2621 Mdot
.908 .26221 Mdot
.908 .26222 Mdot
.908 .26534 Mdot
.908 .26604 Mdot
.908 .26631 Mdot
.908 .26684 Mdot
.908 .26702 Mdot
.908 .26786 Mdot
.908 .2694 Mdot
.908 .27036 Mdot
.908 .27156 Mdot
.908 .2721 Mdot
.908 .27335 Mdot
.908 .27364 Mdot
.908 .27618 Mdot
.908 .27742 Mdot
.908 .27766 Mdot
.908 .27922 Mdot
.908 .27945 Mdot
.908 .27968 Mdot
.908 .28244 Mdot
.908 .28254 Mdot
.908 .28264 Mdot
.908 .28291 Mdot
.908 .28401 Mdot
.908 .28518 Mdot
.908 .28522 Mdot
.908 .28523 Mdot
.908 .28687 Mdot
.908 .28784 Mdot
.908 .28796 Mdot
.908 .28816 Mdot
.908 .29008 Mdot
.908 .29014 Mdot
.908 .2926 Mdot
.908 .29294 Mdot
.908 .2959 Mdot
.908 .29593 Mdot
.908 .29633 Mdot
.908 .29637 Mdot
.908 .29714 Mdot
.908 .29835 Mdot
.908 .2985 Mdot
.908 .29885 Mdot
.908 .29981 Mdot
.908 .29998 Mdot
.908 .3004 Mdot
.908 .30057 Mdot
.908 .30116 Mdot
.908 .30179 Mdot
.908 .30213 Mdot
.908 .3023 Mdot
.908 .30254 Mdot
.908 .30457 Mdot
.908 .30515 Mdot
.908 .30543 Mdot
.908 .30553 Mdot
.908 .30641 Mdot
.908 .30649 Mdot
.908 .30674 Mdot
.908 .31076 Mdot
.908 .31076 Mdot
.908 .31201 Mdot
.908 .31233 Mdot
.908 .31304 Mdot
.908 .31364 Mdot
.908 .31456 Mdot
.908 .31482 Mdot
.908 .315 Mdot
.908 .31557 Mdot
.908 .32055 Mdot
.908 .32406 Mdot
.908 .32412 Mdot
.908 .32441 Mdot
.908 .3247 Mdot
.908 .32521 Mdot
.908 .32532 Mdot
.908 .32591 Mdot
.908 .3271 Mdot
.908 .32729 Mdot
.908 .32787 Mdot
.908 .3281 Mdot
.908 .3281 Mdot
.908 .32902 Mdot
.908 .32907 Mdot
.908 .32965 Mdot
.908 .32972 Mdot
.908 .33008 Mdot
.908 .33096 Mdot
.908 .3323 Mdot
.908 .33246 Mdot
.908 .33285 Mdot
.908 .3331 Mdot
.908 .33357 Mdot
.908 .33385 Mdot
.908 .33459 Mdot
.908 .33509 Mdot
.908 .33537 Mdot
.908 .33615 Mdot
.908 .33665 Mdot
.908 .33675 Mdot
.908 .33739 Mdot
.908 .3385 Mdot
.908 .34067 Mdot
.908 .34106 Mdot
.908 .34111 Mdot
.908 .34536 Mdot
.908 .3457 Mdot
.908 .34949 Mdot
.908 .35016 Mdot
.908 .35091 Mdot
.908 .35177 Mdot
.908 .35297 Mdot
.908 .35335 Mdot
.908 .35438 Mdot
.908 .35498 Mdot
.908 .35614 Mdot
.908 .3574 Mdot
.908 .35859 Mdot
.908 .35933 Mdot
.908 .35986 Mdot
.908 .36231 Mdot
.908 .36355 Mdot
.908 .36391 Mdot
.908 .36457 Mdot
.908 .36502 Mdot
.908 .36528 Mdot
.908 .3664 Mdot
.908 .36688 Mdot
.908 .36775 Mdot
.908 .36838 Mdot
.908 .36988 Mdot
.908 .37045 Mdot
.908 .3744 Mdot
.908 .37597 Mdot
.908 .37608 Mdot
.908 .37701 Mdot
.908 .37822 Mdot
.908 .37937 Mdot
.908 .38082 Mdot
.908 .38153 Mdot
.908 .38224 Mdot
.908 .385 Mdot
.908 .38532 Mdot
.908 .3866 Mdot
.908 .38728 Mdot
.908 .38823 Mdot
.908 .38837 Mdot
.908 .38861 Mdot
.908 .38992 Mdot
.908 .39053 Mdot
.908 .39203 Mdot
.908 .39241 Mdot
.908 .39287 Mdot
.908 .39318 Mdot
.908 .39329 Mdot
.908 .39352 Mdot
.908 .39494 Mdot
.908 .39643 Mdot
.908 .39647 Mdot
.908 .3965 Mdot
.908 .39859 Mdot
.908 .39949 Mdot
.908 .39951 Mdot
.908 .40108 Mdot
.908 .40108 Mdot
.908 .40127 Mdot
.908 .40181 Mdot
.908 .40371 Mdot
.908 .40461 Mdot
.908 .40562 Mdot
.908 .40569 Mdot
.908 .4061 Mdot
.908 .40761 Mdot
.908 .40859 Mdot
.908 .40865 Mdot
.908 .40906 Mdot
.908 .40912 Mdot
.908 .40989 Mdot
.908 .40992 Mdot
.908 .41001 Mdot
.908 .4103 Mdot
.908 .4106 Mdot
.908 .41104 Mdot
.908 .41137 Mdot
.908 .41188 Mdot
.908 .41336 Mdot
.908 .41401 Mdot
.908 .4141 Mdot
.908 .41485 Mdot
.908 .41602 Mdot
.908 .41604 Mdot
.908 .41712 Mdot
.908 .41744 Mdot
.908 .41815 Mdot
.908 .41834 Mdot
.908 .42057 Mdot
.908 .42064 Mdot
.908 .42129 Mdot
.908 .42149 Mdot
.908 .42188 Mdot
.908 .42312 Mdot
.908 .42331 Mdot
.908 .42351 Mdot
.908 .42366 Mdot
.908 .42464 Mdot
.908 .42474 Mdot
.908 .42771 Mdot
.908 .4293 Mdot
.908 .43005 Mdot
.908 .43036 Mdot
.908 .43072 Mdot
.908 .43079 Mdot
.908 .43107 Mdot
.908 .43141 Mdot
.908 .43307 Mdot
.908 .43373 Mdot
.908 .43432 Mdot
.908 .43468 Mdot
.908 .43581 Mdot
.908 .43771 Mdot
.908 .43823 Mdot
.908 .43939 Mdot
.908 .43979 Mdot
.908 .44046 Mdot
.908 .44069 Mdot
.908 .44106 Mdot
.908 .4417 Mdot
.908 .44214 Mdot
.908 .44241 Mdot
.908 .44254 Mdot
.908 .44292 Mdot
.908 .44311 Mdot
.908 .4436 Mdot
.908 .44361 Mdot
.908 .44496 Mdot
.908 .44548 Mdot
.908 .44553 Mdot
.908 .44585 Mdot
.908 .44834 Mdot
.908 .45138 Mdot
.908 .45205 Mdot
.908 .45602 Mdot
.908 .45728 Mdot
.908 .45747 Mdot
.908 .45841 Mdot
.908 .45841 Mdot
.908 .45866 Mdot
.908 .45876 Mdot
.908 .45895 Mdot
.908 .45901 Mdot
.908 .45936 Mdot
.908 .45968 Mdot
.908 .45987 Mdot
.908 .45998 Mdot
.908 .46031 Mdot
.908 .46051 Mdot
.908 .46108 Mdot
.908 .46134 Mdot
.908 .46282 Mdot
.908 .463 Mdot
.908 .46329 Mdot
.908 .46361 Mdot
.908 .46441 Mdot
.908 .46457 Mdot
.908 .46471 Mdot
.908 .46474 Mdot
.908 .46507 Mdot
.908 .46542 Mdot
.908 .46618 Mdot
.908 .4676 Mdot
.908 .46764 Mdot
.908 .46818 Mdot
.908 .46827 Mdot
.908 .46912 Mdot
.908 .46922 Mdot
.908 .46956 Mdot
.908 .47068 Mdot
.908 .47101 Mdot
.908 .47115 Mdot
.908 .47165 Mdot
.908 .47166 Mdot
.908 .47255 Mdot
.908 .47259 Mdot
.908 .47289 Mdot
.908 .47356 Mdot
.908 .4738 Mdot
.908 .47395 Mdot
.908 .47428 Mdot
.908 .47484 Mdot
.908 .47502 Mdot
.908 .47505 Mdot
.908 .47549 Mdot
.908 .47617 Mdot
.908 .47684 Mdot
.908 .47724 Mdot
.908 .47833 Mdot
.908 .47841 Mdot
.908 .47841 Mdot
.908 .4791 Mdot
.908 .47911 Mdot
.908 .47951 Mdot
.908 .48042 Mdot
.908 .48111 Mdot
.908 .48169 Mdot
.908 .48201 Mdot
.908 .48221 Mdot
.908 .48237 Mdot
.908 .48302 Mdot
.908 .48328 Mdot
.908 .48384 Mdot
.908 .48394 Mdot
.908 .48401 Mdot
.908 .48524 Mdot
.908 .48685 Mdot
.908 .48715 Mdot
.908 .48776 Mdot
.908 .48874 Mdot
.908 .48913 Mdot
.908 .48983 Mdot
.908 .49146 Mdot
.908 .4917 Mdot
.908 .49257 Mdot
.908 .49292 Mdot
.908 .49312 Mdot
.908 .49357 Mdot
.908 .49368 Mdot
.908 .49413 Mdot
.908 .49427 Mdot
.908 .49477 Mdot
.908 .49576 Mdot
.908 .49597 Mdot
.908 .49627 Mdot
.908 .49675 Mdot
.908 .49725 Mdot
.908 .49771 Mdot
.908 .49851 Mdot
.908 .49932 Mdot
.908 .50149 Mdot
.908 .50314 Mdot
.908 .50316 Mdot
.908 .50331 Mdot
.908 .50457 Mdot
.908 .50481 Mdot
.908 .50485 Mdot
.908 .50505 Mdot
.908 .50534 Mdot
.908 .50545 Mdot
.908 .50564 Mdot
.908 .50593 Mdot
.908 .50645 Mdot
.908 .50651 Mdot
.908 .50735 Mdot
.908 .50752 Mdot
.908 .5081 Mdot
.908 .5081 Mdot
.908 .50819 Mdot
.908 .50841 Mdot
.908 .50848 Mdot
.908 .50892 Mdot
.908 .50914 Mdot
.908 .50919 Mdot
.908 .50938 Mdot
.908 .50948 Mdot
.908 .50962 Mdot
.908 .51276 Mdot
.908 .51297 Mdot
.908 .51304 Mdot
.908 .51347 Mdot
.908 .51369 Mdot
.908 .51407 Mdot
.908 .51453 Mdot
.908 .51608 Mdot
.908 .5161 Mdot
.908 .51642 Mdot
.908 .51677 Mdot
.908 .5175 Mdot
.908 .51759 Mdot
.908 .51777 Mdot
.908 .51827 Mdot
.908 .51842 Mdot
.908 .51848 Mdot
.908 .51882 Mdot
.908 .51895 Mdot
.908 .519 Mdot
.908 .51943 Mdot
.908 .51987 Mdot
.908 .51988 Mdot
.908 .52092 Mdot
.908 .52191 Mdot
.908 .52193 Mdot
.908 .52261 Mdot
.908 .52268 Mdot
.908 .52306 Mdot
.908 .52363 Mdot
.908 .52364 Mdot
.908 .52365 Mdot
.908 .52406 Mdot
.908 .52445 Mdot
.908 .52457 Mdot
.908 .52461 Mdot
.908 .52556 Mdot
.908 .52564 Mdot
.908 .52572 Mdot
.908 .52626 Mdot
.908 .52634 Mdot
.908 .52764 Mdot
.908 .52836 Mdot
.908 .52909 Mdot
.908 .52962 Mdot
.908 .5299 Mdot
.908 .53014 Mdot
.908 .53024 Mdot
.908 .53153 Mdot
.908 .53153 Mdot
.908 .53157 Mdot
.908 .53174 Mdot
.908 .53176 Mdot
.908 .53178 Mdot
.908 .53267 Mdot
.908 .5328 Mdot
.908 .53294 Mdot
.908 .5335 Mdot
.908 .53505 Mdot
.908 .53505 Mdot
.908 .53522 Mdot
.908 .53572 Mdot
.908 .53595 Mdot
.908 .53595 Mdot
.908 .53653 Mdot
.908 .53666 Mdot
.908 .53735 Mdot
.908 .53786 Mdot
.908 .53789 Mdot
.908 .53862 Mdot
.908 .53897 Mdot
.908 .53955 Mdot
.908 .53995 Mdot
.908 .54004 Mdot
.908 .54039 Mdot
.908 .54092 Mdot
.908 .54136 Mdot
.908 .54143 Mdot
.908 .54147 Mdot
.908 .54152 Mdot
.908 .54162 Mdot
.908 .54241 Mdot
.908 .5426 Mdot
.908 .54325 Mdot
.908 .5433 Mdot
.908 .54375 Mdot
.908 .54385 Mdot
.908 .54432 Mdot
.908 .54478 Mdot
.908 .54485 Mdot
.908 .54498 Mdot
.908 .54512 Mdot
.908 .54524 Mdot
.908 .54534 Mdot
.908 .54559 Mdot
.908 .5461 Mdot
.908 .54652 Mdot
.908 .54691 Mdot
.908 .54708 Mdot
.908 .54735 Mdot
.908 .54817 Mdot
.908 .54883 Mdot
.908 .54928 Mdot
.908 .54967 Mdot
.908 .5499 Mdot
.908 .55013 Mdot
.908 .55023 Mdot
.908 .55049 Mdot
.908 .55064 Mdot
.908 .55163 Mdot
.908 .55234 Mdot
.908 .55248 Mdot
.908 .5528 Mdot
.908 .55297 Mdot
.908 .55298 Mdot
.908 .55309 Mdot
.908 .55331 Mdot
.908 .55365 Mdot
.908 .55397 Mdot
.908 .55471 Mdot
.908 .55631 Mdot
.908 .55673 Mdot
.908 .55724 Mdot
.908 .55736 Mdot
.908 .55741 Mdot
.908 .55764 Mdot
.908 .55787 Mdot
.908 .55809 Mdot
.908 .55821 Mdot
.908 .55882 Mdot
.908 .5592 Mdot
.908 .55947 Mdot
.908 .5605 Mdot
.908 .56055 Mdot
.908 .56146 Mdot
.908 .56165 Mdot
.908 .56249 Mdot
.908 .56259 Mdot
.908 .56347 Mdot
.908 .56355 Mdot
.908 .56397 Mdot
.908 .56489 Mdot
.908 .56566 Mdot
.908 .56659 Mdot
.908 .56666 Mdot
.908 .56683 Mdot
.908 .567 Mdot
.908 .56731 Mdot
.908 .56778 Mdot
.908 .56834 Mdot
.908 .56842 Mdot
.908 .56843 Mdot
.908 .56854 Mdot
.908 .56898 Mdot
.908 .56899 Mdot
.908 .56948 Mdot
.908 .57015 Mdot
.908 .57016 Mdot
.908 .57052 Mdot
.908 .57055 Mdot
.908 .57057 Mdot
.908 .57129 Mdot
.908 .57137 Mdot
.908 .57157 Mdot
.908 .5719 Mdot
.908 .57238 Mdot
.908 .57265 Mdot
.908 .57354 Mdot
.908 .57398 Mdot
.908 .57513 Mdot
.908 .57525 Mdot
.908 .57542 Mdot
.908 .5756 Mdot
.908 .57568 Mdot
.908 .57609 Mdot
.908 .57687 Mdot
.908 .5774 Mdot
.908 .57745 Mdot
.908 .57748 Mdot
.908 .57768 Mdot
.908 .57781 Mdot
.908 .57788 Mdot
.908 .57788 Mdot
.908 .57839 Mdot
.908 .57876 Mdot
.908 .57938 Mdot
.908 .5796 Mdot
.908 .57976 Mdot
.908 .58017 Mdot
.908 .5803 Mdot
.908 .58032 Mdot
.908 .58063 Mdot
.908 .58072 Mdot
.908 .58078 Mdot
.908 .58119 Mdot
.908 .5812 Mdot
.908 .58156 Mdot
.908 .58202 Mdot
.908 .58252 Mdot
.908 .58313 Mdot
.908 .5834 Mdot
.908 .58351 Mdot
.908 .58368 Mdot
.908 .584 Mdot
.908 .58414 Mdot
.908 .5853 Mdot
.908 .58562 Mdot
.908 .58564 Mdot
.908 .5858 Mdot
.908 .58583 Mdot
.908 .58593 Mdot
.908 .58657 Mdot
.908 .58666 Mdot
.908 .58669 Mdot
.908 .58675 Mdot
.908 .58712 Mdot
.908 .58736 Mdot
.908 .58739 Mdot
.908 .58758 Mdot
.908 .58778 Mdot
.908 .58781 Mdot
.908 .58785 Mdot
.908 .58786 Mdot
.908 .58794 Mdot
.908 .58795 Mdot
.908 .58813 Mdot
.908 .58832 Mdot
.908 .58838 Mdot
.908 .58847 Mdot
.908 .58862 Mdot
.908 .5887 Mdot
.908 .5887 Mdot
.908 .58871 Mdot
.908 .58871 Mdot
.908 .58882 Mdot
.908 .58887 Mdot
.908 .58922 Mdot
.908 .58928 Mdot
.908 .5895 Mdot
.908 .58953 Mdot
.908 .58953 Mdot
.908 .58959 Mdot
.908 .58963 Mdot
.908 .58965 Mdot
.908 .58981 Mdot
.908 .58982 Mdot
.908 .59006 Mdot
.908 .59006 Mdot
.908 .5901 Mdot
.908 .59011 Mdot
.908 .59012 Mdot
.908 .59026 Mdot
.908 .59031 Mdot
.908 .59058 Mdot
.908 .59069 Mdot
.908 .59072 Mdot
.908 .59074 Mdot
.908 .59077 Mdot
.908 .59085 Mdot
.908 .59091 Mdot
.908 .59097 Mdot
.908 .59098 Mdot
.908 .59134 Mdot
.908 .59135 Mdot
.908 .59142 Mdot
.908 .59142 Mdot
.908 .59155 Mdot
.908 .5916 Mdot
.908 .59173 Mdot
.908 .59175 Mdot
.908 .5918 Mdot
.908 .59192 Mdot
.908 .59194 Mdot
.908 .59199 Mdot
.908 .59201 Mdot
.908 .59208 Mdot
.908 .59214 Mdot
.908 .59217 Mdot
.908 .59219 Mdot
.908 .5922 Mdot
.908 .59221 Mdot
.908 .59225 Mdot
.908 .59226 Mdot
.908 .59228 Mdot
.908 .59235 Mdot
.908 .59236 Mdot
.908 .59238 Mdot
.908 .59239 Mdot
.908 .5924 Mdot
.908 .59241 Mdot
.908 .59242 Mdot
.908 .59243 Mdot
.908 .59244 Mdot
.908 .59245 Mdot
.908 .59245 Mdot
.908 .59247 Mdot
.908 .59247 Mdot
.91 .05559 Mdot
.91 .05559 Mdot
.91 .05563 Mdot
.91 .05564 Mdot
.91 .05564 Mdot
.91 .05568 Mdot
.91 .05574 Mdot
.91 .05577 Mdot
.91 .05586 Mdot
.91 .05594 Mdot
.91 .05596 Mdot
.91 .05606 Mdot
.91 .05614 Mdot
.91 .05617 Mdot
.91 .05664 Mdot
.91 .05704 Mdot
.91 .05718 Mdot
.91 .05731 Mdot
.91 .05745 Mdot
.91 .05768 Mdot
.91 .05796 Mdot
.91 .058 Mdot
.91 .05804 Mdot
.91 .0581 Mdot
.91 .05817 Mdot
.91 .05824 Mdot
.91 .05865 Mdot
.91 .05879 Mdot
.91 .05901 Mdot
.91 .05915 Mdot
.91 .05972 Mdot
.91 .0603 Mdot
.91 .06059 Mdot
.91 .0606 Mdot
.91 .06076 Mdot
.91 .06096 Mdot
.91 .06107 Mdot
.91 .06143 Mdot
.91 .06183 Mdot
.91 .06187 Mdot
.91 .0621 Mdot
.91 .06285 Mdot
.91 .06314 Mdot
.91 .06523 Mdot
.91 .06603 Mdot
.91 .06631 Mdot
.91 .06655 Mdot
.91 .06693 Mdot
.91 .06782 Mdot
.91 .06792 Mdot
.91 .06929 Mdot
.91 .06933 Mdot
.91 .07029 Mdot
.91 .07033 Mdot
.91 .07042 Mdot
.91 .0707 Mdot
.91 .07278 Mdot
.91 .07464 Mdot
.91 .07485 Mdot
.91 .075 Mdot
.91 .07554 Mdot
.91 .07586 Mdot
.91 .07594 Mdot
.91 .07621 Mdot
.91 .07671 Mdot
.91 .07782 Mdot
.91 .07893 Mdot
.91 .07898 Mdot
.91 .07957 Mdot
.91 .08001 Mdot
.91 .08002 Mdot
.91 .08071 Mdot
.91 .081 Mdot
.91 .08122 Mdot
.91 .08141 Mdot
.91 .08222 Mdot
.91 .08248 Mdot
.91 .08248 Mdot
.91 .08398 Mdot
.91 .08421 Mdot
.91 .08434 Mdot
.91 .08455 Mdot
.91 .08504 Mdot
.91 .08653 Mdot
.91 .08686 Mdot
.91 .08799 Mdot
.91 .09069 Mdot
.91 .09145 Mdot
.91 .09265 Mdot
.91 .09294 Mdot
.91 .0993 Mdot
.91 .09933 Mdot
.91 .09984 Mdot
.91 .10232 Mdot
.91 .10303 Mdot
.91 .10337 Mdot
.91 .10454 Mdot
.91 .10459 Mdot
.91 .10561 Mdot
.91 .10574 Mdot
.91 .10645 Mdot
.91 .10697 Mdot
.91 .10821 Mdot
.91 .10826 Mdot
.91 .10864 Mdot
.91 .1091 Mdot
.91 .11007 Mdot
.91 .1107 Mdot
.91 .1115 Mdot
.91 .11311 Mdot
.91 .11426 Mdot
.91 .11697 Mdot
.91 .11745 Mdot
.91 .11871 Mdot
.91 .11942 Mdot
.91 .12005 Mdot
.91 .12038 Mdot
.91 .1207 Mdot
.91 .12308 Mdot
.91 .12422 Mdot
.91 .12466 Mdot
.91 .12562 Mdot
.91 .12609 Mdot
.91 .12736 Mdot
.91 .12816 Mdot
.91 .12976 Mdot
.91 .13109 Mdot
.91 .13143 Mdot
.91 .13419 Mdot
.91 .13425 Mdot
.91 .13632 Mdot
.91 .13717 Mdot
.91 .13797 Mdot
.91 .13929 Mdot
.91 .13933 Mdot
.91 .14064 Mdot
.91 .14145 Mdot
.91 .14269 Mdot
.91 .14336 Mdot
.91 .14382 Mdot
.91 .14546 Mdot
.91 .14688 Mdot
.91 .1483 Mdot
.91 .14971 Mdot
.91 .14998 Mdot
.91 .1508 Mdot
.91 .15188 Mdot
.91 .15262 Mdot
.91 .15445 Mdot
.91 .15547 Mdot
.91 .15605 Mdot
.91 .15692 Mdot
.91 .15829 Mdot
.91 .15887 Mdot
.91 .15996 Mdot
.91 .1607 Mdot
.91 .16083 Mdot
.91 .16255 Mdot
.91 .16275 Mdot
.91 .16411 Mdot
.91 .16412 Mdot
.91 .16426 Mdot
.91 .16429 Mdot
.91 .16429 Mdot
.91 .16442 Mdot
.91 .16463 Mdot
.91 .16474 Mdot
.91 .16487 Mdot
.91 .16504 Mdot
.91 .1653 Mdot
.91 .16539 Mdot
.91 .1657 Mdot
.91 .16598 Mdot
.91 .16608 Mdot
.91 .16766 Mdot
.91 .16901 Mdot
.91 .16949 Mdot
.91 .16993 Mdot
.91 .16999 Mdot
.91 .17041 Mdot
.91 .1705 Mdot
.91 .17093 Mdot
.91 .17117 Mdot
.91 .1721 Mdot
.91 .17225 Mdot
.91 .17238 Mdot
.91 .17259 Mdot
.91 .17282 Mdot
.91 .17305 Mdot
.91 .17315 Mdot
.91 .17442 Mdot
.91 .17489 Mdot
.91 .17561 Mdot
.91 .17607 Mdot
.91 .17798 Mdot
.91 .17968 Mdot
.91 .1799 Mdot
.91 .17997 Mdot
.91 .18087 Mdot
.91 .18089 Mdot
.91 .18142 Mdot
.91 .18143 Mdot
.91 .18177 Mdot
.91 .18179 Mdot
.91 .18209 Mdot
.91 .18247 Mdot
.91 .18259 Mdot
.91 .18366 Mdot
.91 .18452 Mdot
.91 .18499 Mdot
.91 .18511 Mdot
.91 .18585 Mdot
.91 .18623 Mdot
.91 .18673 Mdot
.91 .18833 Mdot
.91 .18839 Mdot
.91 .1893 Mdot
.91 .193 Mdot
.91 .19304 Mdot
.91 .19339 Mdot
.91 .19408 Mdot
.91 .19605 Mdot
.91 .19611 Mdot
.91 .1974 Mdot
.91 .19763 Mdot
.91 .1983 Mdot
.91 .19872 Mdot
.91 .19961 Mdot
.91 .2004 Mdot
.91 .20112 Mdot
.91 .20161 Mdot
.91 .20187 Mdot
.91 .20193 Mdot
.91 .20222 Mdot
.91 .20233 Mdot
.91 .20381 Mdot
.91 .20425 Mdot
.91 .20449 Mdot
.91 .20471 Mdot
.91 .20481 Mdot
.91 .20532 Mdot
.91 .20688 Mdot
.91 .20743 Mdot
.91 .20923 Mdot
.91 .20934 Mdot
.91 .20963 Mdot
.91 .2099 Mdot
.91 .21114 Mdot
.91 .21241 Mdot
.91 .21254 Mdot
.91 .21282 Mdot
.91 .21283 Mdot
.91 .21342 Mdot
.91 .2137 Mdot
.91 .21383 Mdot
.91 .21413 Mdot
.91 .21512 Mdot
.91 .2155 Mdot
.91 .22028 Mdot
.91 .22031 Mdot
.91 .2215 Mdot
.91 .22242 Mdot
.91 .22345 Mdot
.91 .22468 Mdot
.91 .22614 Mdot
.91 .22651 Mdot
.91 .22663 Mdot
.91 .2268 Mdot
.91 .22728 Mdot
.91 .22835 Mdot
.91 .22851 Mdot
.91 .22896 Mdot
.91 .22995 Mdot
.91 .23019 Mdot
.91 .23102 Mdot
.91 .23169 Mdot
.91 .23228 Mdot
.91 .23259 Mdot
.91 .2326 Mdot
.91 .23518 Mdot
.91 .23602 Mdot
.91 .23603 Mdot
.91 .23613 Mdot
.91 .23944 Mdot
.91 .23958 Mdot
.91 .24141 Mdot
.91 .24274 Mdot
.91 .24279 Mdot
.91 .24489 Mdot
.91 .24578 Mdot
.91 .24615 Mdot
.91 .24644 Mdot
.91 .24653 Mdot
.91 .24703 Mdot
.91 .24878 Mdot
.91 .24947 Mdot
.91 .25024 Mdot
.91 .25026 Mdot
.91 .25135 Mdot
.91 .25333 Mdot
.91 .25384 Mdot
.91 .25446 Mdot
.91 .25477 Mdot
.91 .25527 Mdot
.91 .25546 Mdot
.91 .25584 Mdot
.91 .25647 Mdot
.91 .25757 Mdot
.91 .25796 Mdot
.91 .25898 Mdot
.91 .26013 Mdot
.91 .26063 Mdot
.91 .26169 Mdot
.91 .2624 Mdot
.91 .26336 Mdot
.91 .26392 Mdot
.91 .26398 Mdot
.91 .26445 Mdot
.91 .26502 Mdot
.91 .26552 Mdot
.91 .26672 Mdot
.91 .26697 Mdot
.91 .27038 Mdot
.91 .27102 Mdot
.91 .27376 Mdot
.91 .27463 Mdot
.91 .27505 Mdot
.91 .27513 Mdot
.91 .27618 Mdot
.91 .27685 Mdot
.91 .27729 Mdot
.91 .27774 Mdot
.91 .27803 Mdot
.91 .27845 Mdot
.91 .27995 Mdot
.91 .28031 Mdot
.91 .28078 Mdot
.91 .28116 Mdot
.91 .2847 Mdot
.91 .28477 Mdot
.91 .2848 Mdot
.91 .28686 Mdot
.91 .28695 Mdot
.91 .29293 Mdot
.91 .29492 Mdot
.91 .29534 Mdot
.91 .29621 Mdot
.91 .29713 Mdot
.91 .29799 Mdot
.91 .29875 Mdot
.91 .2988 Mdot
.91 .29888 Mdot
.91 .29922 Mdot
.91 .29931 Mdot
.91 .30074 Mdot
.91 .30468 Mdot
.91 .30512 Mdot
.91 .30526 Mdot
.91 .30628 Mdot
.91 .30651 Mdot
.91 .30753 Mdot
.91 .30763 Mdot
.91 .30948 Mdot
.91 .30956 Mdot
.91 .31051 Mdot
.91 .31095 Mdot
.91 .31234 Mdot
.91 .31371 Mdot
.91 .31384 Mdot
.91 .31548 Mdot
.91 .31661 Mdot
.91 .31697 Mdot
.91 .31763 Mdot
.91 .31814 Mdot
.91 .31889 Mdot
.91 .31901 Mdot
.91 .3203 Mdot
.91 .32067 Mdot
.91 .32312 Mdot
.91 .32334 Mdot
.91 .32362 Mdot
.91 .32378 Mdot
.91 .32425 Mdot
.91 .32477 Mdot
.91 .32482 Mdot
.91 .326 Mdot
.91 .32635 Mdot
.91 .3286 Mdot
.91 .3294 Mdot
.91 .32967 Mdot
.91 .32991 Mdot
.91 .33026 Mdot
.91 .33239 Mdot
.91 .33242 Mdot
.91 .33356 Mdot
.91 .33521 Mdot
.91 .3366 Mdot
.91 .33676 Mdot
.91 .33748 Mdot
.91 .33754 Mdot
.91 .33884 Mdot
.91 .33961 Mdot
.91 .3403 Mdot
.91 .34093 Mdot
.91 .34106 Mdot
.91 .34169 Mdot
.91 .34185 Mdot
.91 .34277 Mdot
.91 .34311 Mdot
.91 .34446 Mdot
.91 .34511 Mdot
.91 .3466 Mdot
.91 .34781 Mdot
.91 .35105 Mdot
.91 .35285 Mdot
.91 .35356 Mdot
.91 .35444 Mdot
.91 .35524 Mdot
.91 .35526 Mdot
.91 .35543 Mdot
.91 .35607 Mdot
.91 .3567 Mdot
.91 .35925 Mdot
.91 .35978 Mdot
.91 .36033 Mdot
.91 .36059 Mdot
.91 .36202 Mdot
.91 .36483 Mdot
.91 .36588 Mdot
.91 .3659 Mdot
.91 .367 Mdot
.91 .36729 Mdot
.91 .36827 Mdot
.91 .36901 Mdot
.91 .36942 Mdot
.91 .37 Mdot
.91 .37051 Mdot
.91 .37251 Mdot
.91 .37349 Mdot
.91 .37368 Mdot
.91 .37398 Mdot
.91 .37444 Mdot
.91 .37463 Mdot
.91 .375 Mdot
.91 .37586 Mdot
.91 .37593 Mdot
.91 .37829 Mdot
.91 .3793 Mdot
.91 .38136 Mdot
.91 .38145 Mdot
.91 .38226 Mdot
.91 .38338 Mdot
.91 .38353 Mdot
.91 .38404 Mdot
.91 .38555 Mdot
.91 .38674 Mdot
.91 .38681 Mdot
.91 .38806 Mdot
.91 .38817 Mdot
.91 .3882 Mdot
.91 .38863 Mdot
.91 .38876 Mdot
.91 .38889 Mdot
.91 .39032 Mdot
.91 .3904 Mdot
.91 .39161 Mdot
.91 .392 Mdot
.91 .3937 Mdot
.91 .39396 Mdot
.91 .39424 Mdot
.91 .3951 Mdot
.91 .39513 Mdot
.91 .39565 Mdot
.91 .3967 Mdot
.91 .39678 Mdot
.91 .39749 Mdot
.91 .40047 Mdot
.91 .40058 Mdot
.91 .40118 Mdot
.91 .40187 Mdot
.91 .4027 Mdot
.91 .40352 Mdot
.91 .40534 Mdot
.91 .406 Mdot
.91 .40706 Mdot
.91 .40777 Mdot
.91 .40811 Mdot
.91 .40888 Mdot
.91 .40899 Mdot
.91 .40938 Mdot
.91 .40959 Mdot
.91 .41062 Mdot
.91 .41063 Mdot
.91 .41118 Mdot
.91 .414 Mdot
.91 .41419 Mdot
.91 .41421 Mdot
.91 .41585 Mdot
.91 .41728 Mdot
.91 .41897 Mdot
.91 .41909 Mdot
.91 .42035 Mdot
.91 .42077 Mdot
.91 .42115 Mdot
.91 .42205 Mdot
.91 .42267 Mdot
.91 .42296 Mdot
.91 .42337 Mdot
.91 .42376 Mdot
.91 .42394 Mdot
.91 .42428 Mdot
.91 .4248 Mdot
.91 .42483 Mdot
.91 .42526 Mdot
.91 .42534 Mdot
.91 .42568 Mdot
.91 .42584 Mdot
.91 .42795 Mdot
.91 .42837 Mdot
.91 .42842 Mdot
.91 .42937 Mdot
.91 .4295 Mdot
.91 .43102 Mdot
.91 .43138 Mdot
.91 .43205 Mdot
.91 .43297 Mdot
.91 .43321 Mdot
.91 .4333 Mdot
.91 .43353 Mdot
.91 .43489 Mdot
.91 .4354 Mdot
.91 .43658 Mdot
.91 .43672 Mdot
.91 .43747 Mdot
.91 .43757 Mdot
.91 .43835 Mdot
.91 .43875 Mdot
.91 .43877 Mdot
.91 .43988 Mdot
.91 .44027 Mdot
.91 .44111 Mdot
.91 .44137 Mdot
.91 .44156 Mdot
.91 .44184 Mdot
.91 .44187 Mdot
.91 .44228 Mdot
.91 .44319 Mdot
.91 .44442 Mdot
.91 .44445 Mdot
.91 .44537 Mdot
.91 .44592 Mdot
.91 .44604 Mdot
.91 .44606 Mdot
.91 .44619 Mdot
.91 .44685 Mdot
.91 .4478 Mdot
.91 .44819 Mdot
.91 .44922 Mdot
.91 .44925 Mdot
.91 .44956 Mdot
.91 .44956 Mdot
.91 .44986 Mdot
.91 .44996 Mdot
.91 .45025 Mdot
.91 .4503 Mdot
.91 .45038 Mdot
.91 .45073 Mdot
.91 .45105 Mdot
.91 .45131 Mdot
.91 .45148 Mdot
.91 .45149 Mdot
.91 .4517 Mdot
.91 .45234 Mdot
.91 .45242 Mdot
.91 .4525 Mdot
.91 .45261 Mdot
.91 .45262 Mdot
.91 .45282 Mdot
.91 .45289 Mdot
.91 .45294 Mdot
.91 .45294 Mdot
.91 .45319 Mdot
.91 .45321 Mdot
.91 .45361 Mdot
.91 .45381 Mdot
.91 .45397 Mdot
.91 .45401 Mdot
.91 .45406 Mdot
.91 .45439 Mdot
.91 .45449 Mdot
.91 .4545 Mdot
.91 .45459 Mdot
.91 .45472 Mdot
.91 .45489 Mdot
.91 .45507 Mdot
.91 .45511 Mdot
.91 .45513 Mdot
.91 .45533 Mdot
.91 .45548 Mdot
.91 .45565 Mdot
.91 .45566 Mdot
.91 .45618 Mdot
.91 .45638 Mdot
.91 .45687 Mdot
.91 .45726 Mdot
.91 .45727 Mdot
.91 .45761 Mdot
.91 .45809 Mdot
.91 .45871 Mdot
.91 .45937 Mdot
.91 .45938 Mdot
.91 .45952 Mdot
.91 .45961 Mdot
.91 .46016 Mdot
.91 .46035 Mdot
.91 .4609 Mdot
.91 .46091 Mdot
.91 .4615 Mdot
.91 .46155 Mdot
.91 .46191 Mdot
.91 .46281 Mdot
.91 .46347 Mdot
.91 .46362 Mdot
.91 .46374 Mdot
.91 .46418 Mdot
.91 .46451 Mdot
.91 .46468 Mdot
.91 .46547 Mdot
.91 .46593 Mdot
.91 .46595 Mdot
.91 .46715 Mdot
.91 .46739 Mdot
.91 .46743 Mdot
.91 .46763 Mdot
.91 .46765 Mdot
.91 .46789 Mdot
.91 .46814 Mdot
.91 .46851 Mdot
.91 .46865 Mdot
.91 .46894 Mdot
.91 .46936 Mdot
.91 .46954 Mdot
.91 .47032 Mdot
.91 .47038 Mdot
.91 .47182 Mdot
.91 .47258 Mdot
.91 .47267 Mdot
.91 .47395 Mdot
.91 .4742 Mdot
.91 .47477 Mdot
.91 .47495 Mdot
.91 .475 Mdot
.91 .47549 Mdot
.91 .47582 Mdot
.91 .47629 Mdot
.91 .47776 Mdot
.91 .47813 Mdot
.91 .47844 Mdot
.91 .48037 Mdot
.91 .48041 Mdot
.91 .48109 Mdot
.91 .4811 Mdot
.91 .48148 Mdot
.91 .4816 Mdot
.91 .48245 Mdot
.91 .48262 Mdot
.91 .48314 Mdot
.91 .48317 Mdot
.91 .4839 Mdot
.91 .48408 Mdot
.91 .4841 Mdot
.91 .48414 Mdot
.91 .48467 Mdot
.91 .4847 Mdot
.91 .48521 Mdot
.91 .48585 Mdot
.91 .48607 Mdot
.91 .48613 Mdot
.91 .48699 Mdot
.91 .48785 Mdot
.91 .48926 Mdot
.91 .48929 Mdot
.91 .48964 Mdot
.91 .48979 Mdot
.91 .49007 Mdot
.91 .49019 Mdot
.91 .49027 Mdot
.91 .4915 Mdot
.91 .4917 Mdot
.91 .49211 Mdot
.91 .49281 Mdot
.91 .49293 Mdot
.91 .49339 Mdot
.91 .49552 Mdot
.91 .49563 Mdot
.91 .49585 Mdot
.91 .49606 Mdot
.91 .49708 Mdot
.91 .49759 Mdot
.91 .49766 Mdot
.91 .49833 Mdot
.91 .50164 Mdot
.91 .5019 Mdot
.91 .50242 Mdot
.91 .50255 Mdot
.91 .50291 Mdot
.91 .50297 Mdot
.91 .50321 Mdot
.91 .50326 Mdot
.91 .5035 Mdot
.91 .50407 Mdot
.91 .50457 Mdot
.91 .50459 Mdot
.91 .50486 Mdot
.91 .50545 Mdot
.91 .50608 Mdot
.91 .50652 Mdot
.91 .50747 Mdot
.91 .50756 Mdot
.91 .50766 Mdot
.91 .50881 Mdot
.91 .50938 Mdot
.91 .50959 Mdot
.91 .50993 Mdot
.91 .51001 Mdot
.91 .51092 Mdot
.91 .51154 Mdot
.91 .51186 Mdot
.91 .51205 Mdot
.91 .51284 Mdot
.91 .51399 Mdot
.91 .5145 Mdot
.91 .51503 Mdot
.91 .51574 Mdot
.91 .51611 Mdot
.91 .5162 Mdot
.91 .51656 Mdot
.91 .51661 Mdot
.91 .51677 Mdot
.91 .51885 Mdot
.91 .51888 Mdot
.91 .5189 Mdot
.91 .51917 Mdot
.91 .51948 Mdot
.91 .51981 Mdot
.91 .52012 Mdot
.91 .52026 Mdot
.91 .52097 Mdot
.91 .52307 Mdot
.91 .52311 Mdot
.91 .52382 Mdot
.91 .52383 Mdot
.91 .52386 Mdot
.91 .52522 Mdot
.91 .52551 Mdot
.91 .52603 Mdot
.91 .52617 Mdot
.91 .52627 Mdot
.91 .52643 Mdot
.91 .52681 Mdot
.91 .52717 Mdot
.91 .5272 Mdot
.91 .52764 Mdot
.91 .52858 Mdot
.91 .5288 Mdot
.91 .52996 Mdot
.91 .53045 Mdot
.91 .53061 Mdot
.91 .53081 Mdot
.91 .53097 Mdot
.91 .53099 Mdot
.91 .53174 Mdot
.91 .53209 Mdot
.91 .53226 Mdot
.91 .53265 Mdot
.91 .53312 Mdot
.91 .53389 Mdot
.91 .53416 Mdot
.91 .53436 Mdot
.91 .53519 Mdot
.91 .53604 Mdot
.91 .53678 Mdot
.91 .53691 Mdot
.91 .54018 Mdot
.91 .54021 Mdot
.91 .54049 Mdot
.91 .54132 Mdot
.91 .54142 Mdot
.91 .54161 Mdot
.91 .54263 Mdot
.91 .54269 Mdot
.91 .54324 Mdot
.91 .54327 Mdot
.91 .54386 Mdot
.91 .54425 Mdot
.91 .54458 Mdot
.91 .54487 Mdot
.91 .54526 Mdot
.91 .54677 Mdot
.91 .54689 Mdot
.91 .5472 Mdot
.91 .5473 Mdot
.91 .54742 Mdot
.91 .54761 Mdot
.91 .54814 Mdot
.91 .54853 Mdot
.91 .54861 Mdot
.91 .5493 Mdot
.91 .54947 Mdot
.91 .54996 Mdot
.91 .55015 Mdot
.91 .55029 Mdot
.91 .55043 Mdot
.91 .55088 Mdot
.91 .55092 Mdot
.91 .55101 Mdot
.91 .55103 Mdot
.91 .55126 Mdot
.91 .55213 Mdot
.91 .55234 Mdot
.91 .55241 Mdot
.91 .55282 Mdot
.91 .55343 Mdot
.91 .55364 Mdot
.91 .55374 Mdot
.91 .55376 Mdot
.91 .55516 Mdot
.91 .55567 Mdot
.91 .55582 Mdot
.91 .55634 Mdot
.91 .55692 Mdot
.91 .55717 Mdot
.91 .55717 Mdot
.91 .55727 Mdot
.91 .55771 Mdot
.91 .5578 Mdot
.91 .55976 Mdot
.91 .56042 Mdot
.91 .56055 Mdot
.91 .5607 Mdot
.91 .56222 Mdot
.91 .56285 Mdot
.91 .56291 Mdot
.91 .56341 Mdot
.91 .56345 Mdot
.91 .56367 Mdot
.91 .56399 Mdot
.91 .56416 Mdot
.91 .56456 Mdot
.91 .56482 Mdot
.91 .56499 Mdot
.91 .56529 Mdot
.91 .56582 Mdot
.91 .56604 Mdot
.91 .56635 Mdot
.91 .56659 Mdot
.91 .56667 Mdot
.91 .56708 Mdot
.91 .56749 Mdot
.91 .5679 Mdot
.91 .56838 Mdot
.91 .56851 Mdot
.91 .5687 Mdot
.91 .56906 Mdot
.91 .56929 Mdot
.91 .56967 Mdot
.91 .56968 Mdot
.91 .57006 Mdot
.91 .57029 Mdot
.91 .57053 Mdot
.91 .57113 Mdot
.91 .57114 Mdot
.91 .57193 Mdot
.91 .57203 Mdot
.91 .57241 Mdot
.91 .57286 Mdot
.91 .57309 Mdot
.91 .57345 Mdot
.91 .57358 Mdot
.91 .57385 Mdot
.91 .57398 Mdot
.91 .5743 Mdot
.91 .57497 Mdot
.91 .57506 Mdot
.91 .57515 Mdot
.91 .57533 Mdot
.91 .57553 Mdot
.91 .57589 Mdot
.91 .57602 Mdot
.91 .57678 Mdot
.91 .5771 Mdot
.91 .57755 Mdot
.91 .57777 Mdot
.91 .57795 Mdot
.91 .57822 Mdot
.91 .57835 Mdot
.91 .57845 Mdot
.91 .57847 Mdot
.91 .57881 Mdot
.91 .57896 Mdot
.91 .57915 Mdot
.91 .57919 Mdot
.91 .57947 Mdot
.91 .57949 Mdot
.91 .57981 Mdot
.91 .57991 Mdot
.91 .5801 Mdot
.91 .58078 Mdot
.91 .58093 Mdot
.91 .58093 Mdot
.91 .58268 Mdot
.91 .58276 Mdot
.91 .58309 Mdot
.91 .5833 Mdot
.91 .58403 Mdot
.91 .58434 Mdot
.91 .58443 Mdot
.91 .58483 Mdot
.91 .58497 Mdot
.91 .58503 Mdot
.91 .58506 Mdot
.91 .58512 Mdot
.91 .58553 Mdot
.91 .58553 Mdot
.91 .5856 Mdot
.91 .58582 Mdot
.91 .58587 Mdot
.91 .58593 Mdot
.91 .58601 Mdot
.91 .58619 Mdot
.91 .5862 Mdot
.91 .58632 Mdot
.91 .58648 Mdot
.91 .58649 Mdot
.91 .58679 Mdot
.91 .58709 Mdot
.91 .58722 Mdot
.91 .5873 Mdot
.91 .58732 Mdot
.91 .5874 Mdot
.91 .58755 Mdot
.91 .58759 Mdot
.91 .58765 Mdot
.91 .58814 Mdot
.91 .5887 Mdot
.91 .58878 Mdot
.91 .5888 Mdot
.91 .58881 Mdot
.91 .58907 Mdot
.91 .58908 Mdot
.91 .58945 Mdot
.91 .58947 Mdot
.91 .58971 Mdot
.91 .58981 Mdot
.91 .58988 Mdot
.91 .58995 Mdot
.91 .59016 Mdot
.91 .59072 Mdot
.91 .5908 Mdot
.91 .591 Mdot
.91 .59106 Mdot
.91 .59107 Mdot
.91 .59118 Mdot
.91 .59127 Mdot
.91 .5913 Mdot
.91 .59135 Mdot
.91 .5914 Mdot
.91 .5914 Mdot
.91 .59148 Mdot
.91 .59163 Mdot
.91 .59178 Mdot
.91 .59182 Mdot
.91 .59188 Mdot
.91 .59191 Mdot
.91 .59202 Mdot
.91 .59203 Mdot
.91 .59204 Mdot
.91 .59206 Mdot
.91 .59207 Mdot
.91 .59208 Mdot
.91 .5921 Mdot
.91 .59217 Mdot
.91 .59223 Mdot
.91 .59227 Mdot
.91 .5923 Mdot
.91 .59234 Mdot
.91 .59245 Mdot
.91 .59257 Mdot
.91 .59258 Mdot
.91 .5926 Mdot
.91 .59262 Mdot
.91 .59263 Mdot
.91 .59265 Mdot
.91 .59267 Mdot
.91 .59268 Mdot
.91 .5927 Mdot
.91 .59271 Mdot
.91 .59271 Mdot
.91 .59271 Mdot
.91 .59272 Mdot
.91 .59272 Mdot
.912 .05471 Mdot
.912 .05472 Mdot
.912 .05473 Mdot
.912 .0549 Mdot
.912 .05491 Mdot
.912 .05495 Mdot
.912 .05502 Mdot
.912 .05506 Mdot
.912 .0551 Mdot
.912 .05519 Mdot
.912 .05522 Mdot
.912 .05525 Mdot
.912 .05535 Mdot
.912 .05542 Mdot
.912 .05543 Mdot
.912 .05545 Mdot
.912 .05552 Mdot
.912 .05554 Mdot
.912 .05558 Mdot
.912 .05567 Mdot
.912 .0557 Mdot
.912 .05581 Mdot
.912 .05586 Mdot
.912 .05589 Mdot
.912 .056 Mdot
.912 .05641 Mdot
.912 .05666 Mdot
.912 .05668 Mdot
.912 .0568 Mdot
.912 .05757 Mdot
.912 .05827 Mdot
.912 .0583 Mdot
.912 .05843 Mdot
.912 .05847 Mdot
.912 .05896 Mdot
.912 .0593 Mdot
.912 .05932 Mdot
.912 .06025 Mdot
.912 .06039 Mdot
.912 .06066 Mdot
.912 .06075 Mdot
.912 .06108 Mdot
.912 .0611 Mdot
.912 .06134 Mdot
.912 .06342 Mdot
.912 .06344 Mdot
.912 .06369 Mdot
.912 .06418 Mdot
.912 .06488 Mdot
.912 .06504 Mdot
.912 .06552 Mdot
.912 .0656 Mdot
.912 .06639 Mdot
.912 .06673 Mdot
.912 .06681 Mdot
.912 .06683 Mdot
.912 .06703 Mdot
.912 .06911 Mdot
.912 .06945 Mdot
.912 .06956 Mdot
.912 .07135 Mdot
.912 .07176 Mdot
.912 .07177 Mdot
.912 .07277 Mdot
.912 .07337 Mdot
.912 .07372 Mdot
.912 .07376 Mdot
.912 .07377 Mdot
.912 .07377 Mdot
.912 .07463 Mdot
.912 .07572 Mdot
.912 .07687 Mdot
.912 .08205 Mdot
.912 .0827 Mdot
.912 .0835 Mdot
.912 .08432 Mdot
.912 .08504 Mdot
.912 .08522 Mdot
.912 .0858 Mdot
.912 .08621 Mdot
.912 .08786 Mdot
.912 .08797 Mdot
.912 .09049 Mdot
.912 .0911 Mdot
.912 .09279 Mdot
.912 .09353 Mdot
.912 .09417 Mdot
.912 .095 Mdot
.912 .09539 Mdot
.912 .09586 Mdot
.912 .09613 Mdot
.912 .09724 Mdot
.912 .09728 Mdot
.912 .09852 Mdot
.912 .09895 Mdot
.912 .0996 Mdot
.912 .09962 Mdot
.912 .09983 Mdot
.912 .10083 Mdot
.912 .10136 Mdot
.912 .10179 Mdot
.912 .1052 Mdot
.912 .10716 Mdot
.912 .10755 Mdot
.912 .10864 Mdot
.912 .11022 Mdot
.912 .11304 Mdot
.912 .11305 Mdot
.912 .1157 Mdot
.912 .1159 Mdot
.912 .11613 Mdot
.912 .11649 Mdot
.912 .11718 Mdot
.912 .11815 Mdot
.912 .11843 Mdot
.912 .11866 Mdot
.912 .11892 Mdot
.912 .12027 Mdot
.912 .12224 Mdot
.912 .1238 Mdot
.912 .12468 Mdot
.912 .12701 Mdot
.912 .12831 Mdot
.912 .13011 Mdot
.912 .13056 Mdot
.912 .13401 Mdot
.912 .13403 Mdot
.912 .13587 Mdot
.912 .13646 Mdot
.912 .14118 Mdot
.912 .14136 Mdot
.912 .14181 Mdot
.912 .14187 Mdot
.912 .14222 Mdot
.912 .14725 Mdot
.912 .14768 Mdot
.912 .14984 Mdot
.912 .15121 Mdot
.912 .15435 Mdot
.912 .15529 Mdot
.912 .15766 Mdot
.912 .15913 Mdot
.912 .15976 Mdot
.912 .1612 Mdot
.912 .16124 Mdot
.912 .16127 Mdot
.912 .16184 Mdot
.912 .16187 Mdot
.912 .16202 Mdot
.912 .16226 Mdot
.912 .16239 Mdot
.912 .16253 Mdot
.912 .16285 Mdot
.912 .16293 Mdot
.912 .16302 Mdot
.912 .16336 Mdot
.912 .16362 Mdot
.912 .16366 Mdot
.912 .16371 Mdot
.912 .16396 Mdot
.912 .16401 Mdot
.912 .16413 Mdot
.912 .16416 Mdot
.912 .16447 Mdot
.912 .16457 Mdot
.912 .16494 Mdot
.912 .16509 Mdot
.912 .16521 Mdot
.912 .16558 Mdot
.912 .16584 Mdot
.912 .16695 Mdot
.912 .16781 Mdot
.912 .16785 Mdot
.912 .16795 Mdot
.912 .16826 Mdot
.912 .16842 Mdot
.912 .16862 Mdot
.912 .17086 Mdot
.912 .17231 Mdot
.912 .1724 Mdot
.912 .17321 Mdot
.912 .1733 Mdot
.912 .17376 Mdot
.912 .17388 Mdot
.912 .1739 Mdot
.912 .17452 Mdot
.912 .17513 Mdot
.912 .1755 Mdot
.912 .17582 Mdot
.912 .17646 Mdot
.912 .17666 Mdot
.912 .17672 Mdot
.912 .17834 Mdot
.912 .17982 Mdot
.912 .18028 Mdot
.912 .18117 Mdot
.912 .18148 Mdot
.912 .18178 Mdot
.912 .18258 Mdot
.912 .18263 Mdot
.912 .18266 Mdot
.912 .18337 Mdot
.912 .18342 Mdot
.912 .18359 Mdot
.912 .18394 Mdot
.912 .18425 Mdot
.912 .18461 Mdot
.912 .18533 Mdot
.912 .18612 Mdot
.912 .1886 Mdot
.912 .19027 Mdot
.912 .19034 Mdot
.912 .19048 Mdot
.912 .19116 Mdot
.912 .19275 Mdot
.912 .19503 Mdot
.912 .19558 Mdot
.912 .19591 Mdot
.912 .19713 Mdot
.912 .1974 Mdot
.912 .19773 Mdot
.912 .19954 Mdot
.912 .19996 Mdot
.912 .19999 Mdot
.912 .20104 Mdot
.912 .20132 Mdot
.912 .20137 Mdot
.912 .20202 Mdot
.912 .20207 Mdot
.912 .20247 Mdot
.912 .20269 Mdot
.912 .20286 Mdot
.912 .2042 Mdot
.912 .2066 Mdot
.912 .20721 Mdot
.912 .20767 Mdot
.912 .20807 Mdot
.912 .2087 Mdot
.912 .20979 Mdot
.912 .21014 Mdot
.912 .21144 Mdot
.912 .21429 Mdot
.912 .21586 Mdot
.912 .21605 Mdot
.912 .21657 Mdot
.912 .21715 Mdot
.912 .21719 Mdot
.912 .2178 Mdot
.912 .21992 Mdot
.912 .22036 Mdot
.912 .22039 Mdot
.912 .22057 Mdot
.912 .22078 Mdot
.912 .22188 Mdot
.912 .22224 Mdot
.912 .22229 Mdot
.912 .22236 Mdot
.912 .22263 Mdot
.912 .223 Mdot
.912 .22335 Mdot
.912 .22345 Mdot
.912 .22348 Mdot
.912 .22349 Mdot
.912 .22393 Mdot
.912 .22395 Mdot
.912 .22406 Mdot
.912 .22437 Mdot
.912 .22443 Mdot
.912 .22571 Mdot
.912 .2262 Mdot
.912 .22702 Mdot
.912 .22799 Mdot
.912 .22823 Mdot
.912 .22841 Mdot
.912 .22961 Mdot
.912 .22973 Mdot
.912 .23047 Mdot
.912 .231 Mdot
.912 .23316 Mdot
.912 .23373 Mdot
.912 .23449 Mdot
.912 .23515 Mdot
.912 .23526 Mdot
.912 .23555 Mdot
.912 .23688 Mdot
.912 .23747 Mdot
.912 .24003 Mdot
.912 .24437 Mdot
.912 .24469 Mdot
.912 .24699 Mdot
.912 .24714 Mdot
.912 .24905 Mdot
.912 .24924 Mdot
.912 .2493 Mdot
.912 .25102 Mdot
.912 .25124 Mdot
.912 .25193 Mdot
.912 .25324 Mdot
.912 .25341 Mdot
.912 .25588 Mdot
.912 .2573 Mdot
.912 .25786 Mdot
.912 .25806 Mdot
.912 .25857 Mdot
.912 .26033 Mdot
.912 .26155 Mdot
.912 .26225 Mdot
.912 .26274 Mdot
.912 .2638 Mdot
.912 .2654 Mdot
.912 .26644 Mdot
.912 .26676 Mdot
.912 .2676 Mdot
.912 .26816 Mdot
.912 .26853 Mdot
.912 .26873 Mdot
.912 .26949 Mdot
.912 .27109 Mdot
.912 .27248 Mdot
.912 .27371 Mdot
.912 .27415 Mdot
.912 .27506 Mdot
.912 .27593 Mdot
.912 .27927 Mdot
.912 .28006 Mdot
.912 .28083 Mdot
.912 .28174 Mdot
.912 .28218 Mdot
.912 .28296 Mdot
.912 .28327 Mdot
.912 .2848 Mdot
.912 .28508 Mdot
.912 .28709 Mdot
.912 .28716 Mdot
.912 .28747 Mdot
.912 .28829 Mdot
.912 .28963 Mdot
.912 .29014 Mdot
.912 .2904 Mdot
.912 .29042 Mdot
.912 .2928 Mdot
.912 .29354 Mdot
.912 .29366 Mdot
.912 .29401 Mdot
.912 .29687 Mdot
.912 .29714 Mdot
.912 .29837 Mdot
.912 .30019 Mdot
.912 .30022 Mdot
.912 .30081 Mdot
.912 .30186 Mdot
.912 .30217 Mdot
.912 .30227 Mdot
.912 .30283 Mdot
.912 .30333 Mdot
.912 .30359 Mdot
.912 .30369 Mdot
.912 .30507 Mdot
.912 .30528 Mdot
.912 .30548 Mdot
.912 .30627 Mdot
.912 .30806 Mdot
.912 .30826 Mdot
.912 .30934 Mdot
.912 .31183 Mdot
.912 .31213 Mdot
.912 .31341 Mdot
.912 .31352 Mdot
.912 .31364 Mdot
.912 .31405 Mdot
.912 .31439 Mdot
.912 .31476 Mdot
.912 .3149 Mdot
.912 .3153 Mdot
.912 .31563 Mdot
.912 .31811 Mdot
.912 .32094 Mdot
.912 .32122 Mdot
.912 .32199 Mdot
.912 .32251 Mdot
.912 .32254 Mdot
.912 .32384 Mdot
.912 .32491 Mdot
.912 .32494 Mdot
.912 .32911 Mdot
.912 .32927 Mdot
.912 .32982 Mdot
.912 .33096 Mdot
.912 .33114 Mdot
.912 .33332 Mdot
.912 .33509 Mdot
.912 .33655 Mdot
.912 .33657 Mdot
.912 .33658 Mdot
.912 .33658 Mdot
.912 .3425 Mdot
.912 .34346 Mdot
.912 .34399 Mdot
.912 .34456 Mdot
.912 .3455 Mdot
.912 .34727 Mdot
.912 .34816 Mdot
.912 .34888 Mdot
.912 .34974 Mdot
.912 .35045 Mdot
.912 .35106 Mdot
.912 .35159 Mdot
.912 .3517 Mdot
.912 .35218 Mdot
.912 .35243 Mdot
.912 .35512 Mdot
.912 .35771 Mdot
.912 .35884 Mdot
.912 .35892 Mdot
.912 .35902 Mdot
.912 .35917 Mdot
.912 .35986 Mdot
.912 .36007 Mdot
.912 .3625 Mdot
.912 .36342 Mdot
.912 .36392 Mdot
.912 .36609 Mdot
.912 .36896 Mdot
.912 .36911 Mdot
.912 .3718 Mdot
.912 .37227 Mdot
.912 .37446 Mdot
.912 .37496 Mdot
.912 .37517 Mdot
.912 .37661 Mdot
.912 .37717 Mdot
.912 .37785 Mdot
.912 .37807 Mdot
.912 .37925 Mdot
.912 .37928 Mdot
.912 .37975 Mdot
.912 .37995 Mdot
.912 .38014 Mdot
.912 .38036 Mdot
.912 .38221 Mdot
.912 .3827 Mdot
.912 .38297 Mdot
.912 .38309 Mdot
.912 .38331 Mdot
.912 .38649 Mdot
.912 .3877 Mdot
.912 .38849 Mdot
.912 .38854 Mdot
.912 .38893 Mdot
.912 .38993 Mdot
.912 .39247 Mdot
.912 .39282 Mdot
.912 .39342 Mdot
.912 .39355 Mdot
.912 .39418 Mdot
.912 .39428 Mdot
.912 .39467 Mdot
.912 .39636 Mdot
.912 .3965 Mdot
.912 .39775 Mdot
.912 .39827 Mdot
.912 .39897 Mdot
.912 .40014 Mdot
.912 .40145 Mdot
.912 .40252 Mdot
.912 .40359 Mdot
.912 .4049 Mdot
.912 .40503 Mdot
.912 .40531 Mdot
.912 .40572 Mdot
.912 .4063 Mdot
.912 .40645 Mdot
.912 .40654 Mdot
.912 .40679 Mdot
.912 .40721 Mdot
.912 .40757 Mdot
.912 .40953 Mdot
.912 .41008 Mdot
.912 .41134 Mdot
.912 .41212 Mdot
.912 .41219 Mdot
.912 .4128 Mdot
.912 .41311 Mdot
.912 .4151 Mdot
.912 .4152 Mdot
.912 .41547 Mdot
.912 .41762 Mdot
.912 .41769 Mdot
.912 .41801 Mdot
.912 .41817 Mdot
.912 .41826 Mdot
.912 .41835 Mdot
.912 .41839 Mdot
.912 .41919 Mdot
.912 .41997 Mdot
.912 .4203 Mdot
.912 .42199 Mdot
.912 .42241 Mdot
.912 .42344 Mdot
.912 .42381 Mdot
.912 .42381 Mdot
.912 .4267 Mdot
.912 .42907 Mdot
.912 .42935 Mdot
.912 .42938 Mdot
.912 .4294 Mdot
.912 .42961 Mdot
.912 .43027 Mdot
.912 .43049 Mdot
.912 .43187 Mdot
.912 .43325 Mdot
.912 .43392 Mdot
.912 .43415 Mdot
.912 .43457 Mdot
.912 .43518 Mdot
.912 .43531 Mdot
.912 .43712 Mdot
.912 .43799 Mdot
.912 .43803 Mdot
.912 .43831 Mdot
.912 .43873 Mdot
.912 .43877 Mdot
.912 .43909 Mdot
.912 .43922 Mdot
.912 .43939 Mdot
.912 .44002 Mdot
.912 .44029 Mdot
.912 .44056 Mdot
.912 .44092 Mdot
.912 .4411 Mdot
.912 .44148 Mdot
.912 .44207 Mdot
.912 .44273 Mdot
.912 .44275 Mdot
.912 .44298 Mdot
.912 .44349 Mdot
.912 .44358 Mdot
.912 .44423 Mdot
.912 .44432 Mdot
.912 .44433 Mdot
.912 .44525 Mdot
.912 .44536 Mdot
.912 .44708 Mdot
.912 .44716 Mdot
.912 .44716 Mdot
.912 .44722 Mdot
.912 .44739 Mdot
.912 .44745 Mdot
.912 .44781 Mdot
.912 .44835 Mdot
.912 .4484 Mdot
.912 .44851 Mdot
.912 .44871 Mdot
.912 .44918 Mdot
.912 .44942 Mdot
.912 .44949 Mdot
.912 .4496 Mdot
.912 .4497 Mdot
.912 .44973 Mdot
.912 .45001 Mdot
.912 .45033 Mdot
.912 .45048 Mdot
.912 .45066 Mdot
.912 .45066 Mdot
.912 .45086 Mdot
.912 .45088 Mdot
.912 .45108 Mdot
.912 .45132 Mdot
.912 .45135 Mdot
.912 .45183 Mdot
.912 .45189 Mdot
.912 .45191 Mdot
.912 .452 Mdot
.912 .45248 Mdot
.912 .45251 Mdot
.912 .45259 Mdot
.912 .45276 Mdot
.912 .45281 Mdot
.912 .45287 Mdot
.912 .45326 Mdot
.912 .45332 Mdot
.912 .45348 Mdot
.912 .45364 Mdot
.912 .45367 Mdot
.912 .45393 Mdot
.912 .45406 Mdot
.912 .45438 Mdot
.912 .45466 Mdot
.912 .4548 Mdot
.912 .4549 Mdot
.912 .45491 Mdot
.912 .45501 Mdot
.912 .45534 Mdot
.912 .45549 Mdot
.912 .45555 Mdot
.912 .45561 Mdot
.912 .45611 Mdot
.912 .45647 Mdot
.912 .45665 Mdot
.912 .45668 Mdot
.912 .4568 Mdot
.912 .4577 Mdot
.912 .45776 Mdot
.912 .45822 Mdot
.912 .45823 Mdot
.912 .4586 Mdot
.912 .45865 Mdot
.912 .45902 Mdot
.912 .45903 Mdot
.912 .45935 Mdot
.912 .45965 Mdot
.912 .45984 Mdot
.912 .45992 Mdot
.912 .4601 Mdot
.912 .46024 Mdot
.912 .46068 Mdot
.912 .46077 Mdot
.912 .46083 Mdot
.912 .46099 Mdot
.912 .46101 Mdot
.912 .46122 Mdot
.912 .46135 Mdot
.912 .46137 Mdot
.912 .4618 Mdot
.912 .46269 Mdot
.912 .46305 Mdot
.912 .46325 Mdot
.912 .46336 Mdot
.912 .46435 Mdot
.912 .46501 Mdot
.912 .46512 Mdot
.912 .46544 Mdot
.912 .46554 Mdot
.912 .46555 Mdot
.912 .46556 Mdot
.912 .46569 Mdot
.912 .46819 Mdot
.912 .46837 Mdot
.912 .46885 Mdot
.912 .46905 Mdot
.912 .46984 Mdot
.912 .46999 Mdot
.912 .47072 Mdot
.912 .47074 Mdot
.912 .47082 Mdot
.912 .4709 Mdot
.912 .47104 Mdot
.912 .47108 Mdot
.912 .47207 Mdot
.912 .47219 Mdot
.912 .47224 Mdot
.912 .47315 Mdot
.912 .47329 Mdot
.912 .47357 Mdot
.912 .4736 Mdot
.912 .47396 Mdot
.912 .47453 Mdot
.912 .47477 Mdot
.912 .47566 Mdot
.912 .47582 Mdot
.912 .47601 Mdot
.912 .47612 Mdot
.912 .47648 Mdot
.912 .4768 Mdot
.912 .47743 Mdot
.912 .47791 Mdot
.912 .47839 Mdot
.912 .47896 Mdot
.912 .47948 Mdot
.912 .47978 Mdot
.912 .48001 Mdot
.912 .48056 Mdot
.912 .48062 Mdot
.912 .48136 Mdot
.912 .48153 Mdot
.912 .48184 Mdot
.912 .4819 Mdot
.912 .48231 Mdot
.912 .4834 Mdot
.912 .48384 Mdot
.912 .48436 Mdot
.912 .48488 Mdot
.912 .48623 Mdot
.912 .48632 Mdot
.912 .48637 Mdot
.912 .48648 Mdot
.912 .48669 Mdot
.912 .48756 Mdot
.912 .48764 Mdot
.912 .48772 Mdot
.912 .48793 Mdot
.912 .48843 Mdot
.912 .48852 Mdot
.912 .4888 Mdot
.912 .48904 Mdot
.912 .48963 Mdot
.912 .48993 Mdot
.912 .49083 Mdot
.912 .49213 Mdot
.912 .49219 Mdot
.912 .49444 Mdot
.912 .49481 Mdot
.912 .49587 Mdot
.912 .49615 Mdot
.912 .49621 Mdot
.912 .49625 Mdot
.912 .49628 Mdot
.912 .49673 Mdot
.912 .49883 Mdot
.912 .49893 Mdot
.912 .49916 Mdot
.912 .50022 Mdot
.912 .50051 Mdot
.912 .50271 Mdot
.912 .50498 Mdot
.912 .50498 Mdot
.912 .50555 Mdot
.912 .50622 Mdot
.912 .50705 Mdot
.912 .50712 Mdot
.912 .50755 Mdot
.912 .50775 Mdot
.912 .50938 Mdot
.912 .50979 Mdot
.912 .51028 Mdot
.912 .51029 Mdot
.912 .51077 Mdot
.912 .51192 Mdot
.912 .51295 Mdot
.912 .5131 Mdot
.912 .51315 Mdot
.912 .51329 Mdot
.912 .51341 Mdot
.912 .51356 Mdot
.912 .51361 Mdot
.912 .51364 Mdot
.912 .51411 Mdot
.912 .51422 Mdot
.912 .51513 Mdot
.912 .51552 Mdot
.912 .5156 Mdot
.912 .51653 Mdot
.912 .5166 Mdot
.912 .51717 Mdot
.912 .5173 Mdot
.912 .51748 Mdot
.912 .51768 Mdot
.912 .51772 Mdot
.912 .51783 Mdot
.912 .51961 Mdot
.912 .52063 Mdot
.912 .52105 Mdot
.912 .52189 Mdot
.912 .52199 Mdot
.912 .52293 Mdot
.912 .52306 Mdot
.912 .52376 Mdot
.912 .52439 Mdot
.912 .52477 Mdot
.912 .52493 Mdot
.912 .52551 Mdot
.912 .52578 Mdot
.912 .52723 Mdot
.912 .5277 Mdot
.912 .52812 Mdot
.912 .52859 Mdot
.912 .52914 Mdot
.912 .52939 Mdot
.912 .52946 Mdot
.912 .52959 Mdot
.912 .52978 Mdot
.912 .53052 Mdot
.912 .53106 Mdot
.912 .53142 Mdot
.912 .53158 Mdot
.912 .53306 Mdot
.912 .53324 Mdot
.912 .53459 Mdot
.912 .53503 Mdot
.912 .53526 Mdot
.912 .5359 Mdot
.912 .53592 Mdot
.912 .53661 Mdot
.912 .53666 Mdot
.912 .53742 Mdot
.912 .53752 Mdot
.912 .53894 Mdot
.912 .53977 Mdot
.912 .53996 Mdot
.912 .5404 Mdot
.912 .54049 Mdot
.912 .54052 Mdot
.912 .54074 Mdot
.912 .54098 Mdot
.912 .54186 Mdot
.912 .54203 Mdot
.912 .54227 Mdot
.912 .54269 Mdot
.912 .54275 Mdot
.912 .54283 Mdot
.912 .54314 Mdot
.912 .54356 Mdot
.912 .54397 Mdot
.912 .54398 Mdot
.912 .54408 Mdot
.912 .54412 Mdot
.912 .54413 Mdot
.912 .54442 Mdot
.912 .54454 Mdot
.912 .54462 Mdot
.912 .54465 Mdot
.912 .54478 Mdot
.912 .54513 Mdot
.912 .54519 Mdot
.912 .54525 Mdot
.912 .5454 Mdot
.912 .54607 Mdot
.912 .54646 Mdot
.912 .54662 Mdot
.912 .54718 Mdot
.912 .54807 Mdot
.912 .54913 Mdot
.912 .54925 Mdot
.912 .54939 Mdot
.912 .54958 Mdot
.912 .55033 Mdot
.912 .55074 Mdot
.912 .5508 Mdot
.912 .55086 Mdot
.912 .55099 Mdot
.912 .55163 Mdot
.912 .55177 Mdot
.912 .55233 Mdot
.912 .55289 Mdot
.912 .55455 Mdot
.912 .55512 Mdot
.912 .55588 Mdot
.912 .55611 Mdot
.912 .55633 Mdot
.912 .55644 Mdot
.912 .55654 Mdot
.912 .55664 Mdot
.912 .55671 Mdot
.912 .55692 Mdot
.912 .55719 Mdot
.912 .55822 Mdot
.912 .55879 Mdot
.912 .55898 Mdot
.912 .55919 Mdot
.912 .55937 Mdot
.912 .55956 Mdot
.912 .56 Mdot
.912 .56003 Mdot
.912 .56113 Mdot
.912 .56119 Mdot
.912 .56133 Mdot
.912 .56195 Mdot
.912 .56246 Mdot
.912 .56375 Mdot
.912 .56393 Mdot
.912 .56436 Mdot
.912 .56506 Mdot
.912 .56533 Mdot
.912 .56625 Mdot
.912 .56665 Mdot
.912 .56727 Mdot
.912 .5674 Mdot
.912 .56885 Mdot
.912 .56895 Mdot
.912 .56897 Mdot
.912 .5691 Mdot
.912 .56915 Mdot
.912 .57051 Mdot
.912 .57068 Mdot
.912 .5712 Mdot
.912 .57121 Mdot
.912 .57219 Mdot
.912 .57232 Mdot
.912 .57283 Mdot
.912 .5732 Mdot
.912 .57386 Mdot
.912 .57411 Mdot
.912 .57455 Mdot
.912 .57511 Mdot
.912 .57549 Mdot
.912 .57556 Mdot
.912 .57562 Mdot
.912 .5757 Mdot
.912 .57597 Mdot
.912 .57617 Mdot
.912 .57627 Mdot
.912 .57633 Mdot
.912 .57639 Mdot
.912 .57713 Mdot
.912 .57713 Mdot
.912 .57792 Mdot
.912 .57836 Mdot
.912 .57866 Mdot
.912 .57877 Mdot
.912 .57931 Mdot
.912 .58026 Mdot
.912 .58038 Mdot
.912 .58052 Mdot
.912 .5808 Mdot
.912 .58086 Mdot
.912 .58086 Mdot
.912 .58104 Mdot
.912 .58116 Mdot
.912 .5815 Mdot
.912 .58151 Mdot
.912 .58181 Mdot
.912 .58189 Mdot
.912 .58202 Mdot
.912 .58213 Mdot
.912 .58235 Mdot
.912 .58253 Mdot
.912 .58273 Mdot
.912 .58319 Mdot
.912 .58336 Mdot
.912 .58405 Mdot
.912 .58408 Mdot
.912 .58452 Mdot
.912 .58464 Mdot
.912 .5848 Mdot
.912 .58484 Mdot
.912 .58504 Mdot
.912 .58526 Mdot
.912 .58548 Mdot
.912 .58565 Mdot
.912 .58705 Mdot
.912 .58736 Mdot
.912 .58765 Mdot
.912 .58789 Mdot
.912 .58789 Mdot
.912 .58789 Mdot
.912 .5879 Mdot
.912 .58799 Mdot
.912 .58815 Mdot
.912 .58842 Mdot
.912 .58843 Mdot
.912 .58853 Mdot
.912 .58902 Mdot
.912 .58904 Mdot
.912 .58914 Mdot
.912 .58969 Mdot
.912 .58974 Mdot
.912 .58975 Mdot
.912 .58977 Mdot
.912 .58986 Mdot
.912 .59007 Mdot
.912 .59009 Mdot
.912 .59022 Mdot
.912 .59026 Mdot
.912 .59045 Mdot
.912 .59058 Mdot
.912 .59065 Mdot
.912 .59065 Mdot
.912 .59121 Mdot
.912 .59127 Mdot
.912 .59127 Mdot
.912 .59136 Mdot
.912 .59139 Mdot
.912 .59146 Mdot
.912 .59149 Mdot
.912 .59174 Mdot
.912 .59174 Mdot
.912 .59184 Mdot
.912 .59196 Mdot
.912 .59197 Mdot
.912 .59201 Mdot
.912 .59202 Mdot
.912 .5922 Mdot
.912 .59241 Mdot
.912 .59244 Mdot
.912 .59244 Mdot
.912 .59251 Mdot
.912 .59262 Mdot
.912 .59265 Mdot
.912 .59266 Mdot
.912 .59267 Mdot
.912 .5927 Mdot
.912 .5927 Mdot
.912 .59273 Mdot
.912 .59274 Mdot
.912 .59274 Mdot
.912 .59276 Mdot
.912 .59277 Mdot
.912 .59277 Mdot
.912 .59279 Mdot
.912 .59282 Mdot
.912 .59282 Mdot
.912 .59283 Mdot
.912 .59286 Mdot
.912 .59287 Mdot
.912 .59288 Mdot
.912 .5929 Mdot
.912 .59291 Mdot
.912 .59291 Mdot
.912 .59295 Mdot
.912 .59296 Mdot
.912 .59296 Mdot
.914 .05383 Mdot
.914 .05383 Mdot
.914 .05386 Mdot
.914 .05388 Mdot
.914 .05392 Mdot
.914 .05396 Mdot
.914 .05398 Mdot
.914 .0541 Mdot
.914 .05416 Mdot
.914 .05417 Mdot
.914 .05418 Mdot
.914 .05423 Mdot
.914 .05426 Mdot
.914 .05436 Mdot
.914 .05448 Mdot
.914 .05461 Mdot
.914 .05471 Mdot
.914 .05472 Mdot
.914 .05474 Mdot
.914 .0549 Mdot
.914 .05508 Mdot
.914 .05527 Mdot
.914 .05532 Mdot
.914 .05553 Mdot
.914 .05582 Mdot
.914 .05592 Mdot
.914 .05608 Mdot
.914 .05616 Mdot
.914 .05638 Mdot
.914 .05646 Mdot
.914 .05734 Mdot
.914 .05767 Mdot
.914 .0578 Mdot
.914 .05923 Mdot
.914 .05936 Mdot
.914 .05958 Mdot
.914 .05961 Mdot
.914 .05999 Mdot
.914 .06003 Mdot
.914 .06037 Mdot
.914 .06049 Mdot
.914 .06064 Mdot
.914 .06203 Mdot
.914 .06222 Mdot
.914 .06316 Mdot
.914 .06325 Mdot
.914 .06349 Mdot
.914 .06391 Mdot
.914 .06453 Mdot
.914 .06472 Mdot
.914 .06506 Mdot
.914 .06511 Mdot
.914 .06592 Mdot
.914 .06615 Mdot
.914 .06733 Mdot
.914 .06871 Mdot
.914 .06888 Mdot
.914 .07034 Mdot
.914 .07046 Mdot
.914 .07082 Mdot
.914 .07107 Mdot
.914 .07167 Mdot
.914 .07168 Mdot
.914 .07239 Mdot
.914 .07249 Mdot
.914 .07298 Mdot
.914 .07322 Mdot
.914 .0736 Mdot
.914 .07382 Mdot
.914 .07421 Mdot
.914 .07578 Mdot
.914 .07591 Mdot
.914 .07729 Mdot
.914 .07851 Mdot
.914 .07891 Mdot
.914 .08015 Mdot
.914 .0807 Mdot
.914 .08245 Mdot
.914 .08248 Mdot
.914 .08279 Mdot
.914 .08329 Mdot
.914 .08364 Mdot
.914 .08412 Mdot
.914 .08568 Mdot
.914 .08619 Mdot
.914 .08666 Mdot
.914 .08676 Mdot
.914 .08873 Mdot
.914 .08894 Mdot
.914 .08914 Mdot
.914 .09057 Mdot
.914 .09081 Mdot
.914 .09117 Mdot
.914 .09227 Mdot
.914 .09308 Mdot
.914 .09329 Mdot
.914 .09345 Mdot
.914 .09351 Mdot
.914 .09585 Mdot
.914 .09733 Mdot
.914 .09734 Mdot
.914 .09929 Mdot
.914 .10108 Mdot
.914 .10313 Mdot
.914 .10357 Mdot
.914 .10409 Mdot
.914 .10477 Mdot
.914 .1055 Mdot
.914 .10554 Mdot
.914 .10619 Mdot
.914 .10648 Mdot
.914 .10706 Mdot
.914 .10872 Mdot
.914 .10879 Mdot
.914 .10939 Mdot
.914 .10947 Mdot
.914 .11182 Mdot
.914 .11285 Mdot
.914 .11302 Mdot
.914 .11549 Mdot
.914 .11635 Mdot
.914 .11718 Mdot
.914 .1177 Mdot
.914 .11925 Mdot
.914 .12034 Mdot
.914 .12117 Mdot
.914 .12363 Mdot
.914 .12426 Mdot
.914 .12428 Mdot
.914 .12445 Mdot
.914 .12504 Mdot
.914 .12662 Mdot
.914 .12685 Mdot
.914 .12771 Mdot
.914 .12795 Mdot
.914 .12892 Mdot
.914 .12984 Mdot
.914 .13075 Mdot
.914 .13089 Mdot
.914 .13104 Mdot
.914 .13216 Mdot
.914 .13361 Mdot
.914 .13478 Mdot
.914 .1361 Mdot
.914 .13732 Mdot
.914 .13752 Mdot
.914 .13759 Mdot
.914 .13954 Mdot
.914 .14091 Mdot
.914 .14293 Mdot
.914 .14433 Mdot
.914 .14489 Mdot
.914 .14614 Mdot
.914 .14654 Mdot
.914 .14682 Mdot
.914 .14841 Mdot
.914 .15006 Mdot
.914 .15055 Mdot
.914 .1506 Mdot
.914 .15257 Mdot
.914 .15453 Mdot
.914 .15629 Mdot
.914 .15758 Mdot
.914 .15795 Mdot
.914 .15824 Mdot
.914 .15828 Mdot
.914 .15828 Mdot
.914 .15836 Mdot
.914 .15845 Mdot
.914 .15856 Mdot
.914 .15871 Mdot
.914 .15879 Mdot
.914 .15918 Mdot
.914 .15939 Mdot
.914 .15944 Mdot
.914 .15946 Mdot
.914 .15962 Mdot
.914 .15974 Mdot
.914 .16008 Mdot
.914 .16048 Mdot
.914 .16093 Mdot
.914 .16126 Mdot
.914 .1613 Mdot
.914 .16137 Mdot
.914 .16191 Mdot
.914 .16253 Mdot
.914 .16268 Mdot
.914 .16316 Mdot
.914 .1633 Mdot
.914 .16332 Mdot
.914 .16404 Mdot
.914 .16454 Mdot
.914 .16502 Mdot
.914 .16537 Mdot
.914 .16591 Mdot
.914 .16607 Mdot
.914 .16618 Mdot
.914 .16692 Mdot
.914 .16719 Mdot
.914 .16923 Mdot
.914 .17015 Mdot
.914 .17018 Mdot
.914 .17055 Mdot
.914 .17125 Mdot
.914 .17159 Mdot
.914 .1717 Mdot
.914 .17305 Mdot
.914 .17528 Mdot
.914 .17541 Mdot
.914 .17649 Mdot
.914 .17691 Mdot
.914 .17707 Mdot
.914 .17728 Mdot
.914 .17764 Mdot
.914 .17774 Mdot
.914 .17813 Mdot
.914 .179 Mdot
.914 .17915 Mdot
.914 .17928 Mdot
.914 .18029 Mdot
.914 .18068 Mdot
.914 .18117 Mdot
.914 .18396 Mdot
.914 .18524 Mdot
.914 .18579 Mdot
.914 .18639 Mdot
.914 .18795 Mdot
.914 .1895 Mdot
.914 .1897 Mdot
.914 .18977 Mdot
.914 .19057 Mdot
.914 .19194 Mdot
.914 .19389 Mdot
.914 .19396 Mdot
.914 .19458 Mdot
.914 .19572 Mdot
.914 .19573 Mdot
.914 .19586 Mdot
.914 .19698 Mdot
.914 .1985 Mdot
.914 .19925 Mdot
.914 .19938 Mdot
.914 .19951 Mdot
.914 .2009 Mdot
.914 .20164 Mdot
.914 .20251 Mdot
.914 .20308 Mdot
.914 .20325 Mdot
.914 .20331 Mdot
.914 .20752 Mdot
.914 .20807 Mdot
.914 .20879 Mdot
.914 .20927 Mdot
.914 .21019 Mdot
.914 .21061 Mdot
.914 .21272 Mdot
.914 .2131 Mdot
.914 .21427 Mdot
.914 .2148 Mdot
.914 .21505 Mdot
.914 .21696 Mdot
.914 .217 Mdot
.914 .21804 Mdot
.914 .21807 Mdot
.914 .21924 Mdot
.914 .21956 Mdot
.914 .21957 Mdot
.914 .22108 Mdot
.914 .22187 Mdot
.914 .22245 Mdot
.914 .22304 Mdot
.914 .22374 Mdot
.914 .22496 Mdot
.914 .22497 Mdot
.914 .22708 Mdot
.914 .22918 Mdot
.914 .2292 Mdot
.914 .22967 Mdot
.914 .22988 Mdot
.914 .23029 Mdot
.914 .23103 Mdot
.914 .2314 Mdot
.914 .23195 Mdot
.914 .23321 Mdot
.914 .23455 Mdot
.914 .23759 Mdot
.914 .23763 Mdot
.914 .23833 Mdot
.914 .2388 Mdot
.914 .23955 Mdot
.914 .24107 Mdot
.914 .24314 Mdot
.914 .24324 Mdot
.914 .24336 Mdot
.914 .24505 Mdot
.914 .24591 Mdot
.914 .24713 Mdot
.914 .24728 Mdot
.914 .24772 Mdot
.914 .24841 Mdot
.914 .25036 Mdot
.914 .25044 Mdot
.914 .25137 Mdot
.914 .25181 Mdot
.914 .25288 Mdot
.914 .25323 Mdot
.914 .25395 Mdot
.914 .25405 Mdot
.914 .25447 Mdot
.914 .25539 Mdot
.914 .2554 Mdot
.914 .2574 Mdot
.914 .25825 Mdot
.914 .2586 Mdot
.914 .25896 Mdot
.914 .26 Mdot
.914 .26007 Mdot
.914 .26157 Mdot
.914 .26184 Mdot
.914 .26186 Mdot
.914 .26299 Mdot
.914 .26329 Mdot
.914 .26331 Mdot
.914 .26419 Mdot
.914 .2679 Mdot
.914 .26908 Mdot
.914 .26911 Mdot
.914 .26919 Mdot
.914 .26972 Mdot
.914 .27029 Mdot
.914 .27049 Mdot
.914 .27138 Mdot
.914 .27149 Mdot
.914 .27302 Mdot
.914 .2742 Mdot
.914 .27448 Mdot
.914 .27519 Mdot
.914 .27625 Mdot
.914 .27659 Mdot
.914 .27738 Mdot
.914 .27763 Mdot
.914 .27843 Mdot
.914 .27944 Mdot
.914 .28123 Mdot
.914 .28176 Mdot
.914 .28237 Mdot
.914 .28238 Mdot
.914 .28283 Mdot
.914 .28302 Mdot
.914 .2834 Mdot
.914 .2847 Mdot
.914 .28712 Mdot
.914 .28824 Mdot
.914 .28903 Mdot
.914 .28945 Mdot
.914 .2897 Mdot
.914 .2939 Mdot
.914 .29394 Mdot
.914 .29423 Mdot
.914 .29649 Mdot
.914 .2967 Mdot
.914 .29942 Mdot
.914 .29992 Mdot
.914 .30016 Mdot
.914 .30082 Mdot
.914 .30308 Mdot
.914 .30312 Mdot
.914 .30443 Mdot
.914 .30488 Mdot
.914 .30505 Mdot
.914 .30541 Mdot
.914 .30655 Mdot
.914 .30852 Mdot
.914 .30947 Mdot
.914 .31007 Mdot
.914 .31048 Mdot
.914 .31087 Mdot
.914 .3113 Mdot
.914 .31227 Mdot
.914 .31271 Mdot
.914 .31274 Mdot
.914 .31408 Mdot
.914 .31457 Mdot
.914 .31502 Mdot
.914 .31552 Mdot
.914 .31605 Mdot
.914 .31656 Mdot
.914 .31668 Mdot
.914 .31845 Mdot
.914 .31905 Mdot
.914 .31921 Mdot
.914 .32079 Mdot
.914 .32364 Mdot
.914 .32462 Mdot
.914 .32468 Mdot
.914 .32511 Mdot
.914 .32525 Mdot
.914 .32543 Mdot
.914 .32704 Mdot
.914 .32724 Mdot
.914 .32825 Mdot
.914 .32961 Mdot
.914 .33012 Mdot
.914 .33016 Mdot
.914 .33112 Mdot
.914 .33217 Mdot
.914 .33347 Mdot
.914 .33473 Mdot
.914 .33619 Mdot
.914 .33662 Mdot
.914 .33707 Mdot
.914 .33723 Mdot
.914 .33751 Mdot
.914 .33869 Mdot
.914 .34286 Mdot
.914 .34305 Mdot
.914 .34334 Mdot
.914 .34473 Mdot
.914 .34529 Mdot
.914 .34534 Mdot
.914 .34643 Mdot
.914 .34742 Mdot
.914 .34873 Mdot
.914 .35087 Mdot
.914 .35088 Mdot
.914 .35182 Mdot
.914 .35268 Mdot
.914 .35408 Mdot
.914 .35439 Mdot
.914 .35517 Mdot
.914 .35543 Mdot
.914 .3565 Mdot
.914 .35752 Mdot
.914 .35999 Mdot
.914 .36107 Mdot
.914 .36141 Mdot
.914 .36239 Mdot
.914 .36271 Mdot
.914 .36295 Mdot
.914 .36365 Mdot
.914 .36445 Mdot
.914 .3652 Mdot
.914 .36526 Mdot
.914 .36568 Mdot
.914 .36715 Mdot
.914 .36769 Mdot
.914 .36841 Mdot
.914 .3689 Mdot
.914 .37012 Mdot
.914 .37099 Mdot
.914 .37155 Mdot
.914 .37229 Mdot
.914 .37231 Mdot
.914 .37365 Mdot
.914 .37424 Mdot
.914 .37636 Mdot
.914 .37656 Mdot
.914 .37746 Mdot
.914 .37879 Mdot
.914 .3789 Mdot
.914 .38096 Mdot
.914 .38103 Mdot
.914 .38129 Mdot
.914 .38165 Mdot
.914 .38309 Mdot
.914 .3843 Mdot
.914 .3877 Mdot
.914 .38862 Mdot
.914 .39043 Mdot
.914 .39057 Mdot
.914 .39083 Mdot
.914 .39215 Mdot
.914 .39349 Mdot
.914 .39616 Mdot
.914 .3963 Mdot
.914 .39667 Mdot
.914 .39677 Mdot
.914 .39692 Mdot
.914 .39727 Mdot
.914 .3994 Mdot
.914 .40071 Mdot
.914 .40119 Mdot
.914 .40137 Mdot
.914 .40228 Mdot
.914 .40266 Mdot
.914 .40287 Mdot
.914 .40399 Mdot
.914 .40408 Mdot
.914 .40417 Mdot
.914 .40445 Mdot
.914 .40493 Mdot
.914 .40554 Mdot
.914 .40651 Mdot
.914 .40682 Mdot
.914 .40685 Mdot
.914 .40719 Mdot
.914 .40745 Mdot
.914 .40815 Mdot
.914 .40897 Mdot
.914 .40903 Mdot
.914 .41025 Mdot
.914 .41085 Mdot
.914 .41147 Mdot
.914 .41176 Mdot
.914 .41196 Mdot
.914 .41206 Mdot
.914 .41328 Mdot
.914 .41385 Mdot
.914 .41391 Mdot
.914 .41553 Mdot
.914 .41598 Mdot
.914 .41602 Mdot
.914 .41611 Mdot
.914 .41689 Mdot
.914 .41739 Mdot
.914 .41748 Mdot
.914 .41784 Mdot
.914 .41795 Mdot
.914 .41829 Mdot
.914 .42068 Mdot
.914 .42093 Mdot
.914 .42094 Mdot
.914 .42183 Mdot
.914 .42255 Mdot
.914 .42281 Mdot
.914 .42403 Mdot
.914 .42443 Mdot
.914 .42547 Mdot
.914 .42559 Mdot
.914 .42594 Mdot
.914 .42636 Mdot
.914 .42746 Mdot
.914 .4277 Mdot
.914 .42886 Mdot
.914 .42973 Mdot
.914 .43 Mdot
.914 .43032 Mdot
.914 .4304 Mdot
.914 .43046 Mdot
.914 .43084 Mdot
.914 .43182 Mdot
.914 .43194 Mdot
.914 .43279 Mdot
.914 .4338 Mdot
.914 .43443 Mdot
.914 .43496 Mdot
.914 .43548 Mdot
.914 .43742 Mdot
.914 .43957 Mdot
.914 .44002 Mdot
.914 .44045 Mdot
.914 .44073 Mdot
.914 .44078 Mdot
.914 .44137 Mdot
.914 .44145 Mdot
.914 .44145 Mdot
.914 .4416 Mdot
.914 .44178 Mdot
.914 .44201 Mdot
.914 .44232 Mdot
.914 .44247 Mdot
.914 .4427 Mdot
.914 .44323 Mdot
.914 .44325 Mdot
.914 .44366 Mdot
.914 .44377 Mdot
.914 .44381 Mdot
.914 .44413 Mdot
.914 .44425 Mdot
.914 .44428 Mdot
.914 .44437 Mdot
.914 .44505 Mdot
.914 .44527 Mdot
.914 .44546 Mdot
.914 .44552 Mdot
.914 .44584 Mdot
.914 .44672 Mdot
.914 .44708 Mdot
.914 .44738 Mdot
.914 .44746 Mdot
.914 .4475 Mdot
.914 .4476 Mdot
.914 .4481 Mdot
.914 .44853 Mdot
.914 .44867 Mdot
.914 .44988 Mdot
.914 .45011 Mdot
.914 .45018 Mdot
.914 .4507 Mdot
.914 .45111 Mdot
.914 .45138 Mdot
.914 .45143 Mdot
.914 .45144 Mdot
.914 .45224 Mdot
.914 .45282 Mdot
.914 .45323 Mdot
.914 .45378 Mdot
.914 .45429 Mdot
.914 .4547 Mdot
.914 .45508 Mdot
.914 .45539 Mdot
.914 .45619 Mdot
.914 .45641 Mdot
.914 .45671 Mdot
.914 .45692 Mdot
.914 .45771 Mdot
.914 .45775 Mdot
.914 .45784 Mdot
.914 .45834 Mdot
.914 .45835 Mdot
.914 .45886 Mdot
.914 .45913 Mdot
.914 .46011 Mdot
.914 .46025 Mdot
.914 .46068 Mdot
.914 .46269 Mdot
.914 .46294 Mdot
.914 .46319 Mdot
.914 .46399 Mdot
.914 .4644 Mdot
.914 .46446 Mdot
.914 .46493 Mdot
.914 .46511 Mdot
.914 .46514 Mdot
.914 .46518 Mdot
.914 .46533 Mdot
.914 .46588 Mdot
.914 .46643 Mdot
.914 .46654 Mdot
.914 .46707 Mdot
.914 .46727 Mdot
.914 .46817 Mdot
.914 .46874 Mdot
.914 .46886 Mdot
.914 .4692 Mdot
.914 .46961 Mdot
.914 .46973 Mdot
.914 .47084 Mdot
.914 .471 Mdot
.914 .47105 Mdot
.914 .47126 Mdot
.914 .47185 Mdot
.914 .47191 Mdot
.914 .47211 Mdot
.914 .47286 Mdot
.914 .47288 Mdot
.914 .47375 Mdot
.914 .47384 Mdot
.914 .47397 Mdot
.914 .47425 Mdot
.914 .47452 Mdot
.914 .47507 Mdot
.914 .47547 Mdot
.914 .47578 Mdot
.914 .4759 Mdot
.914 .47605 Mdot
.914 .47607 Mdot
.914 .4762 Mdot
.914 .47664 Mdot
.914 .47691 Mdot
.914 .47725 Mdot
.914 .47729 Mdot
.914 .47733 Mdot
.914 .47782 Mdot
.914 .47792 Mdot
.914 .47809 Mdot
.914 .47857 Mdot
.914 .47878 Mdot
.914 .47936 Mdot
.914 .48029 Mdot
.914 .48055 Mdot
.914 .48078 Mdot
.914 .48252 Mdot
.914 .48308 Mdot
.914 .4832 Mdot
.914 .48403 Mdot
.914 .48638 Mdot
.914 .48725 Mdot
.914 .48814 Mdot
.914 .48874 Mdot
.914 .4892 Mdot
.914 .49088 Mdot
.914 .49088 Mdot
.914 .49177 Mdot
.914 .49227 Mdot
.914 .49247 Mdot
.914 .49276 Mdot
.914 .49408 Mdot
.914 .49469 Mdot
.914 .49478 Mdot
.914 .49491 Mdot
.914 .49531 Mdot
.914 .49544 Mdot
.914 .49588 Mdot
.914 .49727 Mdot
.914 .4978 Mdot
.914 .49811 Mdot
.914 .49823 Mdot
.914 .49912 Mdot
.914 .49949 Mdot
.914 .4995 Mdot
.914 .50123 Mdot
.914 .50166 Mdot
.914 .50189 Mdot
.914 .50243 Mdot
.914 .50262 Mdot
.914 .50423 Mdot
.914 .50468 Mdot
.914 .50478 Mdot
.914 .50485 Mdot
.914 .50574 Mdot
.914 .50671 Mdot
.914 .5071 Mdot
.914 .50747 Mdot
.914 .50748 Mdot
.914 .50768 Mdot
.914 .50819 Mdot
.914 .50937 Mdot
.914 .50953 Mdot
.914 .50955 Mdot
.914 .50991 Mdot
.914 .51161 Mdot
.914 .51272 Mdot
.914 .51292 Mdot
.914 .5131 Mdot
.914 .51344 Mdot
.914 .51394 Mdot
.914 .51411 Mdot
.914 .51462 Mdot
.914 .51476 Mdot
.914 .51513 Mdot
.914 .51547 Mdot
.914 .51619 Mdot
.914 .5166 Mdot
.914 .51673 Mdot
.914 .51679 Mdot
.914 .51742 Mdot
.914 .51743 Mdot
.914 .51824 Mdot
.914 .51848 Mdot
.914 .51856 Mdot
.914 .51971 Mdot
.914 .51979 Mdot
.914 .52059 Mdot
.914 .52227 Mdot
.914 .52242 Mdot
.914 .5227 Mdot
.914 .52309 Mdot
.914 .52393 Mdot
.914 .52439 Mdot
.914 .52475 Mdot
.914 .52514 Mdot
.914 .52611 Mdot
.914 .52638 Mdot
.914 .52647 Mdot
.914 .52674 Mdot
.914 .52756 Mdot
.914 .52797 Mdot
.914 .52849 Mdot
.914 .52852 Mdot
.914 .52883 Mdot
.914 .52927 Mdot
.914 .52931 Mdot
.914 .52971 Mdot
.914 .53096 Mdot
.914 .53126 Mdot
.914 .53175 Mdot
.914 .53176 Mdot
.914 .53237 Mdot
.914 .53272 Mdot
.914 .53284 Mdot
.914 .53296 Mdot
.914 .53324 Mdot
.914 .53391 Mdot
.914 .53422 Mdot
.914 .53436 Mdot
.914 .53463 Mdot
.914 .5351 Mdot
.914 .53622 Mdot
.914 .53645 Mdot
.914 .5366 Mdot
.914 .53664 Mdot
.914 .53705 Mdot
.914 .53792 Mdot
.914 .53795 Mdot
.914 .53863 Mdot
.914 .53937 Mdot
.914 .53975 Mdot
.914 .53976 Mdot
.914 .54118 Mdot
.914 .54155 Mdot
.914 .54158 Mdot
.914 .54176 Mdot
.914 .54188 Mdot
.914 .54232 Mdot
.914 .54247 Mdot
.914 .54247 Mdot
.914 .54315 Mdot
.914 .54382 Mdot
.914 .54462 Mdot
.914 .54554 Mdot
.914 .54601 Mdot
.914 .54602 Mdot
.914 .54704 Mdot
.914 .54835 Mdot
.914 .54849 Mdot
.914 .54878 Mdot
.914 .54892 Mdot
.914 .55063 Mdot
.914 .55065 Mdot
.914 .55088 Mdot
.914 .55115 Mdot
.914 .55137 Mdot
.914 .5518 Mdot
.914 .55184 Mdot
.914 .55258 Mdot
.914 .55297 Mdot
.914 .55353 Mdot
.914 .55481 Mdot
.914 .55534 Mdot
.914 .55616 Mdot
.914 .55655 Mdot
.914 .55796 Mdot
.914 .55831 Mdot
.914 .55856 Mdot
.914 .55863 Mdot
.914 .55912 Mdot
.914 .55916 Mdot
.914 .55983 Mdot
.914 .56026 Mdot
.914 .56057 Mdot
.914 .56068 Mdot
.914 .56097 Mdot
.914 .56191 Mdot
.914 .56236 Mdot
.914 .56272 Mdot
.914 .5629 Mdot
.914 .56421 Mdot
.914 .5643 Mdot
.914 .56441 Mdot
.914 .56478 Mdot
.914 .5653 Mdot
.914 .56587 Mdot
.914 .56644 Mdot
.914 .56646 Mdot
.914 .5666 Mdot
.914 .56708 Mdot
.914 .56754 Mdot
.914 .56762 Mdot
.914 .56774 Mdot
.914 .5681 Mdot
.914 .56826 Mdot
.914 .56866 Mdot
.914 .56925 Mdot
.914 .56964 Mdot
.914 .5702 Mdot
.914 .57022 Mdot
.914 .57028 Mdot
.914 .57063 Mdot
.914 .571 Mdot
.914 .57134 Mdot
.914 .57175 Mdot
.914 .57207 Mdot
.914 .57211 Mdot
.914 .57215 Mdot
.914 .57241 Mdot
.914 .57267 Mdot
.914 .57295 Mdot
.914 .57302 Mdot
.914 .57326 Mdot
.914 .57333 Mdot
.914 .57377 Mdot
.914 .57394 Mdot
.914 .57399 Mdot
.914 .57399 Mdot
.914 .57417 Mdot
.914 .57486 Mdot
.914 .5751 Mdot
.914 .5754 Mdot
.914 .57584 Mdot
.914 .57598 Mdot
.914 .57622 Mdot
.914 .57646 Mdot
.914 .57715 Mdot
.914 .5772 Mdot
.914 .57748 Mdot
.914 .57814 Mdot
.914 .57816 Mdot
.914 .57833 Mdot
.914 .57835 Mdot
.914 .57881 Mdot
.914 .57897 Mdot
.914 .57905 Mdot
.914 .57923 Mdot
.914 .57924 Mdot
.914 .57944 Mdot
.914 .57963 Mdot
.914 .57977 Mdot
.914 .58046 Mdot
.914 .58096 Mdot
.914 .58149 Mdot
.914 .5815 Mdot
.914 .5819 Mdot
.914 .58254 Mdot
.914 .58256 Mdot
.914 .5826 Mdot
.914 .58266 Mdot
.914 .58288 Mdot
.914 .58318 Mdot
.914 .58328 Mdot
.914 .58335 Mdot
.914 .58374 Mdot
.914 .58379 Mdot
.914 .58385 Mdot
.914 .58438 Mdot
.914 .58441 Mdot
.914 .58454 Mdot
.914 .58468 Mdot
.914 .5851 Mdot
.914 .58523 Mdot
.914 .58533 Mdot
.914 .58546 Mdot
.914 .58555 Mdot
.914 .58555 Mdot
.914 .58602 Mdot
.914 .58617 Mdot
.914 .58651 Mdot
.914 .58662 Mdot
.914 .58695 Mdot
.914 .58732 Mdot
.914 .58735 Mdot
.914 .58777 Mdot
.914 .58788 Mdot
.914 .58794 Mdot
.914 .58804 Mdot
.914 .58811 Mdot
.914 .58824 Mdot
.914 .58826 Mdot
.914 .58845 Mdot
.914 .58846 Mdot
.914 .58862 Mdot
.914 .58868 Mdot
.914 .58878 Mdot
.914 .58881 Mdot
.914 .5892 Mdot
.914 .58925 Mdot
.914 .58962 Mdot
.914 .58993 Mdot
.914 .58999 Mdot
.914 .59021 Mdot
.914 .59022 Mdot
.914 .59031 Mdot
.914 .59036 Mdot
.914 .59053 Mdot
.914 .59064 Mdot
.914 .5907 Mdot
.914 .59073 Mdot
.914 .59098 Mdot
.914 .59103 Mdot
.914 .5914 Mdot
.914 .59143 Mdot
.914 .59147 Mdot
.914 .59156 Mdot
.914 .59157 Mdot
.914 .59167 Mdot
.914 .59168 Mdot
.914 .59173 Mdot
.914 .59177 Mdot
.914 .59215 Mdot
.914 .59218 Mdot
.914 .59227 Mdot
.914 .5925 Mdot
.914 .59252 Mdot
.914 .59258 Mdot
.914 .5926 Mdot
.914 .59264 Mdot
.914 .59267 Mdot
.914 .59275 Mdot
.914 .5928 Mdot
.914 .59282 Mdot
.914 .59286 Mdot
.914 .59291 Mdot
.914 .59295 Mdot
.914 .59296 Mdot
.914 .59296 Mdot
.914 .59299 Mdot
.914 .59302 Mdot
.914 .59305 Mdot
.914 .59308 Mdot
.914 .59309 Mdot
.914 .5931 Mdot
.914 .5931 Mdot
.914 .59311 Mdot
.914 .59312 Mdot
.914 .59315 Mdot
.914 .59316 Mdot
.914 .59317 Mdot
.914 .59318 Mdot
.914 .59319 Mdot
.914 .59319 Mdot
.914 .59319 Mdot
.916 .053 Mdot
.916 .05305 Mdot
.916 .05308 Mdot
.916 .05311 Mdot
.916 .05315 Mdot
.916 .05315 Mdot
.916 .05329 Mdot
.916 .05338 Mdot
.916 .05347 Mdot
.916 .05351 Mdot
.916 .05353 Mdot
.916 .05354 Mdot
.916 .05373 Mdot
.916 .05375 Mdot
.916 .05378 Mdot
.916 .05386 Mdot
.916 .05387 Mdot
.916 .05398 Mdot
.916 .05416 Mdot
.916 .05421 Mdot
.916 .05443 Mdot
.916 .05505 Mdot
.916 .05569 Mdot
.916 .05604 Mdot
.916 .05644 Mdot
.916 .05654 Mdot
.916 .05755 Mdot
.916 .05768 Mdot
.916 .05781 Mdot
.916 .05782 Mdot
.916 .05807 Mdot
.916 .05835 Mdot
.916 .05871 Mdot
.916 .05879 Mdot
.916 .05888 Mdot
.916 .05957 Mdot
.916 .05959 Mdot
.916 .05968 Mdot
.916 .05992 Mdot
.916 .0604 Mdot
.916 .06066 Mdot
.916 .06152 Mdot
.916 .06197 Mdot
.916 .06202 Mdot
.916 .06252 Mdot
.916 .06329 Mdot
.916 .06339 Mdot
.916 .06365 Mdot
.916 .06423 Mdot
.916 .06495 Mdot
.916 .06508 Mdot
.916 .06557 Mdot
.916 .0662 Mdot
.916 .0679 Mdot
.916 .06952 Mdot
.916 .06989 Mdot
.916 .07034 Mdot
.916 .0714 Mdot
.916 .07208 Mdot
.916 .07239 Mdot
.916 .07353 Mdot
.916 .07458 Mdot
.916 .07477 Mdot
.916 .07674 Mdot
.916 .07746 Mdot
.916 .07764 Mdot
.916 .0778 Mdot
.916 .07793 Mdot
.916 .07984 Mdot
.916 .07996 Mdot
.916 .08049 Mdot
.916 .08074 Mdot
.916 .08149 Mdot
.916 .08215 Mdot
.916 .08217 Mdot
.916 .08381 Mdot
.916 .08485 Mdot
.916 .08619 Mdot
.916 .08621 Mdot
.916 .08689 Mdot
.916 .0872 Mdot
.916 .08744 Mdot
.916 .09096 Mdot
.916 .09162 Mdot
.916 .09182 Mdot
.916 .09227 Mdot
.916 .09257 Mdot
.916 .09285 Mdot
.916 .09293 Mdot
.916 .0935 Mdot
.916 .0936 Mdot
.916 .09494 Mdot
.916 .09677 Mdot
.916 .09773 Mdot
.916 .0978 Mdot
.916 .09848 Mdot
.916 .1002 Mdot
.916 .10063 Mdot
.916 .10097 Mdot
.916 .10168 Mdot
.916 .10351 Mdot
.916 .10373 Mdot
.916 .1044 Mdot
.916 .10472 Mdot
.916 .10503 Mdot
.916 .10651 Mdot
.916 .10674 Mdot
.916 .10824 Mdot
.916 .10833 Mdot
.916 .10865 Mdot
.916 .10913 Mdot
.916 .11436 Mdot
.916 .11533 Mdot
.916 .11665 Mdot
.916 .11778 Mdot
.916 .12001 Mdot
.916 .12167 Mdot
.916 .12184 Mdot
.916 .1226 Mdot
.916 .12302 Mdot
.916 .12459 Mdot
.916 .12563 Mdot
.916 .12669 Mdot
.916 .12959 Mdot
.916 .1327 Mdot
.916 .13283 Mdot
.916 .13555 Mdot
.916 .13625 Mdot
.916 .13682 Mdot
.916 .13749 Mdot
.916 .13816 Mdot
.916 .13867 Mdot
.916 .13886 Mdot
.916 .1389 Mdot
.916 .13905 Mdot
.916 .13911 Mdot
.916 .13952 Mdot
.916 .13967 Mdot
.916 .14044 Mdot
.916 .14229 Mdot
.916 .14263 Mdot
.916 .1442 Mdot
.916 .14469 Mdot
.916 .147 Mdot
.916 .14972 Mdot
.916 .15066 Mdot
.916 .15128 Mdot
.916 .15277 Mdot
.916 .15353 Mdot
.916 .1542 Mdot
.916 .15485 Mdot
.916 .15548 Mdot
.916 .15568 Mdot
.916 .15576 Mdot
.916 .15589 Mdot
.916 .15598 Mdot
.916 .156 Mdot
.916 .15602 Mdot
.916 .15647 Mdot
.916 .1568 Mdot
.916 .15711 Mdot
.916 .15723 Mdot
.916 .15731 Mdot
.916 .15733 Mdot
.916 .15799 Mdot
.916 .15805 Mdot
.916 .15807 Mdot
.916 .15816 Mdot
.916 .15834 Mdot
.916 .15843 Mdot
.916 .15848 Mdot
.916 .15885 Mdot
.916 .15915 Mdot
.916 .15947 Mdot
.916 .15949 Mdot
.916 .15961 Mdot
.916 .16038 Mdot
.916 .1618 Mdot
.916 .16182 Mdot
.916 .1622 Mdot
.916 .16247 Mdot
.916 .16294 Mdot
.916 .16389 Mdot
.916 .16466 Mdot
.916 .16487 Mdot
.916 .16583 Mdot
.916 .1672 Mdot
.916 .16729 Mdot
.916 .16753 Mdot
.916 .16769 Mdot
.916 .16807 Mdot
.916 .17092 Mdot
.916 .17117 Mdot
.916 .17122 Mdot
.916 .17135 Mdot
.916 .17179 Mdot
.916 .17181 Mdot
.916 .17266 Mdot
.916 .1727 Mdot
.916 .17304 Mdot
.916 .17359 Mdot
.916 .17361 Mdot
.916 .17482 Mdot
.916 .17509 Mdot
.916 .17538 Mdot
.916 .17755 Mdot
.916 .1777 Mdot
.916 .17775 Mdot
.916 .17782 Mdot
.916 .17804 Mdot
.916 .17883 Mdot
.916 .17916 Mdot
.916 .18044 Mdot
.916 .18072 Mdot
.916 .18131 Mdot
.916 .18227 Mdot
.916 .18256 Mdot
.916 .18373 Mdot
.916 .18417 Mdot
.916 .18565 Mdot
.916 .18582 Mdot
.916 .18607 Mdot
.916 .18636 Mdot
.916 .18746 Mdot
.916 .18825 Mdot
.916 .18995 Mdot
.916 .18999 Mdot
.916 .19033 Mdot
.916 .19101 Mdot
.916 .19118 Mdot
.916 .192 Mdot
.916 .19304 Mdot
.916 .19306 Mdot
.916 .19359 Mdot
.916 .19543 Mdot
.916 .19582 Mdot
.916 .19585 Mdot
.916 .19617 Mdot
.916 .19744 Mdot
.916 .19899 Mdot
.916 .19939 Mdot
.916 .1995 Mdot
.916 .20194 Mdot
.916 .20241 Mdot
.916 .20267 Mdot
.916 .20319 Mdot
.916 .20459 Mdot
.916 .20499 Mdot
.916 .20707 Mdot
.916 .21018 Mdot
.916 .21094 Mdot
.916 .21096 Mdot
.916 .21106 Mdot
.916 .21137 Mdot
.916 .21279 Mdot
.916 .21304 Mdot
.916 .21461 Mdot
.916 .21499 Mdot
.916 .2156 Mdot
.916 .21613 Mdot
.916 .21619 Mdot
.916 .21778 Mdot
.916 .21833 Mdot
.916 .21932 Mdot
.916 .22077 Mdot
.916 .2229 Mdot
.916 .22488 Mdot
.916 .22549 Mdot
.916 .22577 Mdot
.916 .22621 Mdot
.916 .2268 Mdot
.916 .22863 Mdot
.916 .22926 Mdot
.916 .23109 Mdot
.916 .23262 Mdot
.916 .23293 Mdot
.916 .23401 Mdot
.916 .23481 Mdot
.916 .23517 Mdot
.916 .23573 Mdot
.916 .23622 Mdot
.916 .23663 Mdot
.916 .23671 Mdot
.916 .23795 Mdot
.916 .23823 Mdot
.916 .24073 Mdot
.916 .24105 Mdot
.916 .24136 Mdot
.916 .2416 Mdot
.916 .24173 Mdot
.916 .24249 Mdot
.916 .2426 Mdot
.916 .24287 Mdot
.916 .24296 Mdot
.916 .24366 Mdot
.916 .24426 Mdot
.916 .24448 Mdot
.916 .24474 Mdot
.916 .24525 Mdot
.916 .24578 Mdot
.916 .24753 Mdot
.916 .24826 Mdot
.916 .24904 Mdot
.916 .24952 Mdot
.916 .24954 Mdot
.916 .24959 Mdot
.916 .24961 Mdot
.916 .24986 Mdot
.916 .25011 Mdot
.916 .25035 Mdot
.916 .25082 Mdot
.916 .25182 Mdot
.916 .25304 Mdot
.916 .25415 Mdot
.916 .25456 Mdot
.916 .25558 Mdot
.916 .25612 Mdot
.916 .25769 Mdot
.916 .26134 Mdot
.916 .26155 Mdot
.916 .26169 Mdot
.916 .26173 Mdot
.916 .2625 Mdot
.916 .26316 Mdot
.916 .26344 Mdot
.916 .26375 Mdot
.916 .26385 Mdot
.916 .26469 Mdot
.916 .26539 Mdot
.916 .26654 Mdot
.916 .26795 Mdot
.916 .26914 Mdot
.916 .26953 Mdot
.916 .26963 Mdot
.916 .27199 Mdot
.916 .27216 Mdot
.916 .27254 Mdot
.916 .27255 Mdot
.916 .27486 Mdot
.916 .27487 Mdot
.916 .27572 Mdot
.916 .27619 Mdot
.916 .27765 Mdot
.916 .27824 Mdot
.916 .27955 Mdot
.916 .28041 Mdot
.916 .28122 Mdot
.916 .28145 Mdot
.916 .28308 Mdot
.916 .28337 Mdot
.916 .28467 Mdot
.916 .2861 Mdot
.916 .28666 Mdot
.916 .28721 Mdot
.916 .28789 Mdot
.916 .28844 Mdot
.916 .29061 Mdot
.916 .29186 Mdot
.916 .29243 Mdot
.916 .29272 Mdot
.916 .29282 Mdot
.916 .29383 Mdot
.916 .29441 Mdot
.916 .2948 Mdot
.916 .29516 Mdot
.916 .29536 Mdot
.916 .29711 Mdot
.916 .29728 Mdot
.916 .29992 Mdot
.916 .30198 Mdot
.916 .3021 Mdot
.916 .30303 Mdot
.916 .30329 Mdot
.916 .30423 Mdot
.916 .30488 Mdot
.916 .30622 Mdot
.916 .30699 Mdot
.916 .30765 Mdot
.916 .31126 Mdot
.916 .31157 Mdot
.916 .31185 Mdot
.916 .31266 Mdot
.916 .31356 Mdot
.916 .3137 Mdot
.916 .31383 Mdot
.916 .31457 Mdot
.916 .31463 Mdot
.916 .31505 Mdot
.916 .3154 Mdot
.916 .31666 Mdot
.916 .31942 Mdot
.916 .32006 Mdot
.916 .32249 Mdot
.916 .32286 Mdot
.916 .3241 Mdot
.916 .32432 Mdot
.916 .32519 Mdot
.916 .32647 Mdot
.916 .32791 Mdot
.916 .32796 Mdot
.916 .32847 Mdot
.916 .32924 Mdot
.916 .32935 Mdot
.916 .33094 Mdot
.916 .33529 Mdot
.916 .33609 Mdot
.916 .33835 Mdot
.916 .34026 Mdot
.916 .34048 Mdot
.916 .34057 Mdot
.916 .34176 Mdot
.916 .34216 Mdot
.916 .34277 Mdot
.916 .34413 Mdot
.916 .34473 Mdot
.916 .34617 Mdot
.916 .34805 Mdot
.916 .34874 Mdot
.916 .34903 Mdot
.916 .34907 Mdot
.916 .34936 Mdot
.916 .34941 Mdot
.916 .35099 Mdot
.916 .35146 Mdot
.916 .35182 Mdot
.916 .35285 Mdot
.916 .353 Mdot
.916 .35473 Mdot
.916 .35564 Mdot
.916 .35893 Mdot
.916 .35933 Mdot
.916 .35988 Mdot
.916 .36125 Mdot
.916 .36198 Mdot
.916 .36228 Mdot
.916 .36306 Mdot
.916 .36616 Mdot
.916 .36747 Mdot
.916 .36836 Mdot
.916 .36866 Mdot
.916 .36872 Mdot
.916 .36966 Mdot
.916 .37033 Mdot
.916 .37131 Mdot
.916 .37257 Mdot
.916 .37399 Mdot
.916 .37631 Mdot
.916 .37808 Mdot
.916 .37833 Mdot
.916 .37932 Mdot
.916 .37933 Mdot
.916 .37991 Mdot
.916 .38277 Mdot
.916 .38393 Mdot
.916 .38459 Mdot
.916 .38571 Mdot
.916 .38602 Mdot
.916 .38618 Mdot
.916 .38684 Mdot
.916 .38777 Mdot
.916 .38789 Mdot
.916 .38864 Mdot
.916 .38885 Mdot
.916 .389 Mdot
.916 .39012 Mdot
.916 .39122 Mdot
.916 .39126 Mdot
.916 .39237 Mdot
.916 .39269 Mdot
.916 .39399 Mdot
.916 .3953 Mdot
.916 .39538 Mdot
.916 .39617 Mdot
.916 .39634 Mdot
.916 .39684 Mdot
.916 .39764 Mdot
.916 .39786 Mdot
.916 .39838 Mdot
.916 .39879 Mdot
.916 .39946 Mdot
.916 .39955 Mdot
.916 .39963 Mdot
.916 .39973 Mdot
.916 .39997 Mdot
.916 .40006 Mdot
.916 .40041 Mdot
.916 .40054 Mdot
.916 .40082 Mdot
.916 .40148 Mdot
.916 .40169 Mdot
.916 .40182 Mdot
.916 .40197 Mdot
.916 .40204 Mdot
.916 .40216 Mdot
.916 .40275 Mdot
.916 .40356 Mdot
.916 .40494 Mdot
.916 .40541 Mdot
.916 .40549 Mdot
.916 .40559 Mdot
.916 .40629 Mdot
.916 .40771 Mdot
.916 .40775 Mdot
.916 .40785 Mdot
.916 .40845 Mdot
.916 .40845 Mdot
.916 .40879 Mdot
.916 .41133 Mdot
.916 .41147 Mdot
.916 .41179 Mdot
.916 .41193 Mdot
.916 .41248 Mdot
.916 .4128 Mdot
.916 .41302 Mdot
.916 .4133 Mdot
.916 .41354 Mdot
.916 .41413 Mdot
.916 .41662 Mdot
.916 .41679 Mdot
.916 .41777 Mdot
.916 .41804 Mdot
.916 .41827 Mdot
.916 .41834 Mdot
.916 .4205 Mdot
.916 .42185 Mdot
.916 .42199 Mdot
.916 .42369 Mdot
.916 .42389 Mdot
.916 .42529 Mdot
.916 .42539 Mdot
.916 .42588 Mdot
.916 .4271 Mdot
.916 .42718 Mdot
.916 .42719 Mdot
.916 .42758 Mdot
.916 .42779 Mdot
.916 .42873 Mdot
.916 .43031 Mdot
.916 .43189 Mdot
.916 .43294 Mdot
.916 .43329 Mdot
.916 .43462 Mdot
.916 .43462 Mdot
.916 .43476 Mdot
.916 .43593 Mdot
.916 .43633 Mdot
.916 .43649 Mdot
.916 .43675 Mdot
.916 .43694 Mdot
.916 .43699 Mdot
.916 .43703 Mdot
.916 .43759 Mdot
.916 .43796 Mdot
.916 .43863 Mdot
.916 .43883 Mdot
.916 .43925 Mdot
.916 .43949 Mdot
.916 .43962 Mdot
.916 .43966 Mdot
.916 .4397 Mdot
.916 .43972 Mdot
.916 .4403 Mdot
.916 .44103 Mdot
.916 .44116 Mdot
.916 .44117 Mdot
.916 .4412 Mdot
.916 .44138 Mdot
.916 .44175 Mdot
.916 .44177 Mdot
.916 .44192 Mdot
.916 .44201 Mdot
.916 .44269 Mdot
.916 .44277 Mdot
.916 .44303 Mdot
.916 .44315 Mdot
.916 .44337 Mdot
.916 .444 Mdot
.916 .44404 Mdot
.916 .44429 Mdot
.916 .44581 Mdot
.916 .44671 Mdot
.916 .4482 Mdot
.916 .44863 Mdot
.916 .44867 Mdot
.916 .44941 Mdot
.916 .44973 Mdot
.916 .44994 Mdot
.916 .45012 Mdot
.916 .45087 Mdot
.916 .45181 Mdot
.916 .45261 Mdot
.916 .45271 Mdot
.916 .45419 Mdot
.916 .45461 Mdot
.916 .45547 Mdot
.916 .45567 Mdot
.916 .45645 Mdot
.916 .4572 Mdot
.916 .45899 Mdot
.916 .45905 Mdot
.916 .45922 Mdot
.916 .45968 Mdot
.916 .45997 Mdot
.916 .4604 Mdot
.916 .46069 Mdot
.916 .46074 Mdot
.916 .46113 Mdot
.916 .46174 Mdot
.916 .46312 Mdot
.916 .46319 Mdot
.916 .464 Mdot
.916 .46602 Mdot
.916 .46647 Mdot
.916 .46657 Mdot
.916 .46675 Mdot
.916 .4668 Mdot
.916 .4676 Mdot
.916 .46765 Mdot
.916 .46841 Mdot
.916 .4692 Mdot
.916 .46927 Mdot
.916 .46989 Mdot
.916 .4709 Mdot
.916 .47093 Mdot
.916 .47116 Mdot
.916 .47161 Mdot
.916 .47169 Mdot
.916 .47283 Mdot
.916 .4731 Mdot
.916 .47321 Mdot
.916 .47344 Mdot
.916 .47358 Mdot
.916 .4739 Mdot
.916 .47404 Mdot
.916 .4741 Mdot
.916 .47525 Mdot
.916 .47541 Mdot
.916 .47567 Mdot
.916 .47572 Mdot
.916 .47637 Mdot
.916 .47669 Mdot
.916 .47673 Mdot
.916 .47677 Mdot
.916 .47698 Mdot
.916 .47795 Mdot
.916 .47821 Mdot
.916 .47826 Mdot
.916 .47829 Mdot
.916 .47842 Mdot
.916 .4788 Mdot
.916 .47928 Mdot
.916 .47932 Mdot
.916 .4794 Mdot
.916 .47947 Mdot
.916 .4797 Mdot
.916 .4801 Mdot
.916 .4802 Mdot
.916 .48076 Mdot
.916 .48084 Mdot
.916 .48118 Mdot
.916 .48235 Mdot
.916 .48297 Mdot
.916 .48298 Mdot
.916 .48346 Mdot
.916 .48394 Mdot
.916 .484 Mdot
.916 .48409 Mdot
.916 .48441 Mdot
.916 .48446 Mdot
.916 .48485 Mdot
.916 .48514 Mdot
.916 .48581 Mdot
.916 .48609 Mdot
.916 .48658 Mdot
.916 .48778 Mdot
.916 .48802 Mdot
.916 .48803 Mdot
.916 .48855 Mdot
.916 .48928 Mdot
.916 .49024 Mdot
.916 .49083 Mdot
.916 .49175 Mdot
.916 .49202 Mdot
.916 .49243 Mdot
.916 .49255 Mdot
.916 .49291 Mdot
.916 .4947 Mdot
.916 .49514 Mdot
.916 .49598 Mdot
.916 .49767 Mdot
.916 .49871 Mdot
.916 .49877 Mdot
.916 .49917 Mdot
.916 .49932 Mdot
.916 .4995 Mdot
.916 .50012 Mdot
.916 .50014 Mdot
.916 .50027 Mdot
.916 .50039 Mdot
.916 .50065 Mdot
.916 .50195 Mdot
.916 .50218 Mdot
.916 .50294 Mdot
.916 .50309 Mdot
.916 .50356 Mdot
.916 .50359 Mdot
.916 .50441 Mdot
.916 .50527 Mdot
.916 .50557 Mdot
.916 .50722 Mdot
.916 .50782 Mdot
.916 .50786 Mdot
.916 .50815 Mdot
.916 .50835 Mdot
.916 .50837 Mdot
.916 .51025 Mdot
.916 .51039 Mdot
.916 .51254 Mdot
.916 .51313 Mdot
.916 .51329 Mdot
.916 .51358 Mdot
.916 .51368 Mdot
.916 .51401 Mdot
.916 .51441 Mdot
.916 .51583 Mdot
.916 .51607 Mdot
.916 .51683 Mdot
.916 .5175 Mdot
.916 .51787 Mdot
.916 .51861 Mdot
.916 .51961 Mdot
.916 .52043 Mdot
.916 .52057 Mdot
.916 .52077 Mdot
.916 .52113 Mdot
.916 .52116 Mdot
.916 .52147 Mdot
.916 .52191 Mdot
.916 .52267 Mdot
.916 .52286 Mdot
.916 .52329 Mdot
.916 .52349 Mdot
.916 .52398 Mdot
.916 .52691 Mdot
.916 .52737 Mdot
.916 .52737 Mdot
.916 .52816 Mdot
.916 .52816 Mdot
.916 .52829 Mdot
.916 .52835 Mdot
.916 .52916 Mdot
.916 .52919 Mdot
.916 .52932 Mdot
.916 .52973 Mdot
.916 .53021 Mdot
.916 .53111 Mdot
.916 .53125 Mdot
.916 .53135 Mdot
.916 .53157 Mdot
.916 .53189 Mdot
.916 .53196 Mdot
.916 .5337 Mdot
.916 .53388 Mdot
.916 .53436 Mdot
.916 .53473 Mdot
.916 .53513 Mdot
.916 .53546 Mdot
.916 .53562 Mdot
.916 .5357 Mdot
.916 .53578 Mdot
.916 .53586 Mdot
.916 .53589 Mdot
.916 .53605 Mdot
.916 .53631 Mdot
.916 .53712 Mdot
.916 .53746 Mdot
.916 .53762 Mdot
.916 .53781 Mdot
.916 .53804 Mdot
.916 .53816 Mdot
.916 .53844 Mdot
.916 .53849 Mdot
.916 .53857 Mdot
.916 .53867 Mdot
.916 .53877 Mdot
.916 .53958 Mdot
.916 .53968 Mdot
.916 .54008 Mdot
.916 .54069 Mdot
.916 .54095 Mdot
.916 .5414 Mdot
.916 .54189 Mdot
.916 .54248 Mdot
.916 .54268 Mdot
.916 .54359 Mdot
.916 .54368 Mdot
.916 .54388 Mdot
.916 .54518 Mdot
.916 .54613 Mdot
.916 .54665 Mdot
.916 .54681 Mdot
.916 .54701 Mdot
.916 .54713 Mdot
.916 .54762 Mdot
.916 .54824 Mdot
.916 .54827 Mdot
.916 .54828 Mdot
.916 .54949 Mdot
.916 .55026 Mdot
.916 .55069 Mdot
.916 .55085 Mdot
.916 .55093 Mdot
.916 .55108 Mdot
.916 .55186 Mdot
.916 .55199 Mdot
.916 .55285 Mdot
.916 .55296 Mdot
.916 .55364 Mdot
.916 .55381 Mdot
.916 .55413 Mdot
.916 .55443 Mdot
.916 .55475 Mdot
.916 .55527 Mdot
.916 .55584 Mdot
.916 .55593 Mdot
.916 .55664 Mdot
.916 .557 Mdot
.916 .55708 Mdot
.916 .55755 Mdot
.916 .55802 Mdot
.916 .55842 Mdot
.916 .5585 Mdot
.916 .55969 Mdot
.916 .55985 Mdot
.916 .55995 Mdot
.916 .56039 Mdot
.916 .56041 Mdot
.916 .56133 Mdot
.916 .56156 Mdot
.916 .56228 Mdot
.916 .56257 Mdot
.916 .56285 Mdot
.916 .56306 Mdot
.916 .56318 Mdot
.916 .56318 Mdot
.916 .56386 Mdot
.916 .56396 Mdot
.916 .5642 Mdot
.916 .56428 Mdot
.916 .56489 Mdot
.916 .56522 Mdot
.916 .56541 Mdot
.916 .56561 Mdot
.916 .56583 Mdot
.916 .56626 Mdot
.916 .56644 Mdot
.916 .56671 Mdot
.916 .5675 Mdot
.916 .56817 Mdot
.916 .56831 Mdot
.916 .56877 Mdot
.916 .56886 Mdot
.916 .56939 Mdot
.916 .56962 Mdot
.916 .56966 Mdot
.916 .56978 Mdot
.916 .56979 Mdot
.916 .56984 Mdot
.916 .56985 Mdot
.916 .5699 Mdot
.916 .57005 Mdot
.916 .57024 Mdot
.916 .57043 Mdot
.916 .5706 Mdot
.916 .5708 Mdot
.916 .57157 Mdot
.916 .57161 Mdot
.916 .57249 Mdot
.916 .57332 Mdot
.916 .57362 Mdot
.916 .57391 Mdot
.916 .57435 Mdot
.916 .57447 Mdot
.916 .57469 Mdot
.916 .57473 Mdot
.916 .5752 Mdot
.916 .57583 Mdot
.916 .57615 Mdot
.916 .57652 Mdot
.916 .57679 Mdot
.916 .57824 Mdot
.916 .57838 Mdot
.916 .57847 Mdot
.916 .57849 Mdot
.916 .57891 Mdot
.916 .57897 Mdot
.916 .57938 Mdot
.916 .57947 Mdot
.916 .57955 Mdot
.916 .57974 Mdot
.916 .5798 Mdot
.916 .58031 Mdot
.916 .5805 Mdot
.916 .5806 Mdot
.916 .58071 Mdot
.916 .58119 Mdot
.916 .58137 Mdot
.916 .58139 Mdot
.916 .58166 Mdot
.916 .58216 Mdot
.916 .58253 Mdot
.916 .58255 Mdot
.916 .58271 Mdot
.916 .58273 Mdot
.916 .58281 Mdot
.916 .58289 Mdot
.916 .58301 Mdot
.916 .58307 Mdot
.916 .58325 Mdot
.916 .58421 Mdot
.916 .58427 Mdot
.916 .58436 Mdot
.916 .58454 Mdot
.916 .58455 Mdot
.916 .58491 Mdot
.916 .58519 Mdot
.916 .58564 Mdot
.916 .58564 Mdot
.916 .58582 Mdot
.916 .58602 Mdot
.916 .58609 Mdot
.916 .58623 Mdot
.916 .58627 Mdot
.916 .58678 Mdot
.916 .58682 Mdot
.916 .58686 Mdot
.916 .58691 Mdot
.916 .5871 Mdot
.916 .58763 Mdot
.916 .58768 Mdot
.916 .58796 Mdot
.916 .58827 Mdot
.916 .58835 Mdot
.916 .58853 Mdot
.916 .58882 Mdot
.916 .58894 Mdot
.916 .58904 Mdot
.916 .58947 Mdot
.916 .58992 Mdot
.916 .59009 Mdot
.916 .59022 Mdot
.916 .59026 Mdot
.916 .59045 Mdot
.916 .5906 Mdot
.916 .59067 Mdot
.916 .5907 Mdot
.916 .5909 Mdot
.916 .59103 Mdot
.916 .59105 Mdot
.916 .59117 Mdot
.916 .59139 Mdot
.916 .59146 Mdot
.916 .59159 Mdot
.916 .59166 Mdot
.916 .59168 Mdot
.916 .59168 Mdot
.916 .59187 Mdot
.916 .59189 Mdot
.916 .59191 Mdot
.916 .59201 Mdot
.916 .59208 Mdot
.916 .59215 Mdot
.916 .59215 Mdot
.916 .59218 Mdot
.916 .59222 Mdot
.916 .59248 Mdot
.916 .59251 Mdot
.916 .59262 Mdot
.916 .59271 Mdot
.916 .59288 Mdot
.916 .59304 Mdot
.916 .5931 Mdot
.916 .59311 Mdot
.916 .59316 Mdot
.916 .59319 Mdot
.916 .59319 Mdot
.916 .59321 Mdot
.916 .59322 Mdot
.916 .59323 Mdot
.916 .59328 Mdot
.916 .59328 Mdot
.916 .59328 Mdot
.916 .59329 Mdot
.916 .59332 Mdot
.916 .59334 Mdot
.916 .59338 Mdot
.916 .59338 Mdot
.916 .59339 Mdot
.916 .5934 Mdot
.916 .5934 Mdot
.916 .59342 Mdot
.918 .05207 Mdot
.918 .05209 Mdot
.918 .05209 Mdot
.918 .05216 Mdot
.918 .05221 Mdot
.918 .05226 Mdot
.918 .05231 Mdot
.918 .05232 Mdot
.918 .0526 Mdot
.918 .0528 Mdot
.918 .05294 Mdot
.918 .05296 Mdot
.918 .05306 Mdot
.918 .05325 Mdot
.918 .05334 Mdot
.918 .05368 Mdot
.918 .05389 Mdot
.918 .05399 Mdot
.918 .05399 Mdot
.918 .0541 Mdot
.918 .0543 Mdot
.918 .0544 Mdot
.918 .05459 Mdot
.918 .05508 Mdot
.918 .05562 Mdot
.918 .0558 Mdot
.918 .05704 Mdot
.918 .05718 Mdot
.918 .05737 Mdot
.918 .0574 Mdot
.918 .05821 Mdot
.918 .05823 Mdot
.918 .05823 Mdot
.918 .05851 Mdot
.918 .05916 Mdot
.918 .05918 Mdot
.918 .05949 Mdot
.918 .05964 Mdot
.918 .05996 Mdot
.918 .06056 Mdot
.918 .06104 Mdot
.918 .06224 Mdot
.918 .06434 Mdot
.918 .06549 Mdot
.918 .06567 Mdot
.918 .06581 Mdot
.918 .06591 Mdot
.918 .06676 Mdot
.918 .06767 Mdot
.918 .0677 Mdot
.918 .06788 Mdot
.918 .06805 Mdot
.918 .06868 Mdot
.918 .06901 Mdot
.918 .06924 Mdot
.918 .06978 Mdot
.918 .07003 Mdot
.918 .0702 Mdot
.918 .07026 Mdot
.918 .07047 Mdot
.918 .07086 Mdot
.918 .07133 Mdot
.918 .07153 Mdot
.918 .07201 Mdot
.918 .07214 Mdot
.918 .07253 Mdot
.918 .07348 Mdot
.918 .07372 Mdot
.918 .07501 Mdot
.918 .07557 Mdot
.918 .07625 Mdot
.918 .07683 Mdot
.918 .07774 Mdot
.918 .07789 Mdot
.918 .0784 Mdot
.918 .07853 Mdot
.918 .07962 Mdot
.918 .07996 Mdot
.918 .08006 Mdot
.918 .08073 Mdot
.918 .08272 Mdot
.918 .08508 Mdot
.918 .0854 Mdot
.918 .08815 Mdot
.918 .08837 Mdot
.918 .08911 Mdot
.918 .08928 Mdot
.918 .08932 Mdot
.918 .09158 Mdot
.918 .09314 Mdot
.918 .09326 Mdot
.918 .09356 Mdot
.918 .09409 Mdot
.918 .09482 Mdot
.918 .09929 Mdot
.918 .1004 Mdot
.918 .10235 Mdot
.918 .10378 Mdot
.918 .10432 Mdot
.918 .10478 Mdot
.918 .10514 Mdot
.918 .10556 Mdot
.918 .10902 Mdot
.918 .11118 Mdot
.918 .11129 Mdot
.918 .11193 Mdot
.918 .11256 Mdot
.918 .1128 Mdot
.918 .11312 Mdot
.918 .11315 Mdot
.918 .11351 Mdot
.918 .11478 Mdot
.918 .11503 Mdot
.918 .11514 Mdot
.918 .11626 Mdot
.918 .11712 Mdot
.918 .11715 Mdot
.918 .11931 Mdot
.918 .12017 Mdot
.918 .12206 Mdot
.918 .12221 Mdot
.918 .12302 Mdot
.918 .12365 Mdot
.918 .1241 Mdot
.918 .12429 Mdot
.918 .1262 Mdot
.918 .12747 Mdot
.918 .12868 Mdot
.918 .12914 Mdot
.918 .12924 Mdot
.918 .12985 Mdot
.918 .13035 Mdot
.918 .13057 Mdot
.918 .1313 Mdot
.918 .13168 Mdot
.918 .13197 Mdot
.918 .13203 Mdot
.918 .13333 Mdot
.918 .137 Mdot
.918 .13816 Mdot
.918 .13824 Mdot
.918 .14303 Mdot
.918 .14327 Mdot
.918 .14476 Mdot
.918 .14946 Mdot
.918 .15026 Mdot
.918 .15042 Mdot
.918 .15079 Mdot
.918 .15225 Mdot
.918 .15236 Mdot
.918 .15242 Mdot
.918 .15244 Mdot
.918 .15268 Mdot
.918 .15285 Mdot
.918 .15302 Mdot
.918 .1531 Mdot
.918 .15319 Mdot
.918 .15322 Mdot
.918 .15418 Mdot
.918 .15463 Mdot
.918 .15465 Mdot
.918 .15486 Mdot
.918 .15533 Mdot
.918 .15541 Mdot
.918 .15576 Mdot
.918 .15641 Mdot
.918 .15646 Mdot
.918 .15673 Mdot
.918 .15738 Mdot
.918 .15789 Mdot
.918 .1586 Mdot
.918 .15893 Mdot
.918 .15894 Mdot
.918 .15932 Mdot
.918 .15999 Mdot
.918 .16032 Mdot
.918 .16051 Mdot
.918 .16097 Mdot
.918 .16108 Mdot
.918 .16153 Mdot
.918 .16263 Mdot
.918 .16376 Mdot
.918 .16446 Mdot
.918 .1645 Mdot
.918 .16481 Mdot
.918 .16508 Mdot
.918 .16521 Mdot
.918 .166 Mdot
.918 .16644 Mdot
.918 .16669 Mdot
.918 .16928 Mdot
.918 .16975 Mdot
.918 .16975 Mdot
.918 .17036 Mdot
.918 .17049 Mdot
.918 .17089 Mdot
.918 .17223 Mdot
.918 .17223 Mdot
.918 .1728 Mdot
.918 .17289 Mdot
.918 .1732 Mdot
.918 .17326 Mdot
.918 .17327 Mdot
.918 .17361 Mdot
.918 .17419 Mdot
.918 .17459 Mdot
.918 .1753 Mdot
.918 .1756 Mdot
.918 .17638 Mdot
.918 .17646 Mdot
.918 .17692 Mdot
.918 .17727 Mdot
.918 .17749 Mdot
.918 .17797 Mdot
.918 .17876 Mdot
.918 .17904 Mdot
.918 .17967 Mdot
.918 .18086 Mdot
.918 .18093 Mdot
.918 .18106 Mdot
.918 .18263 Mdot
.918 .18387 Mdot
.918 .18475 Mdot
.918 .18603 Mdot
.918 .18614 Mdot
.918 .1866 Mdot
.918 .18663 Mdot
.918 .18691 Mdot
.918 .18733 Mdot
.918 .18803 Mdot
.918 .19328 Mdot
.918 .19349 Mdot
.918 .19407 Mdot
.918 .19661 Mdot
.918 .1969 Mdot
.918 .19725 Mdot
.918 .19784 Mdot
.918 .19831 Mdot
.918 .19862 Mdot
.918 .20077 Mdot
.918 .20127 Mdot
.918 .20138 Mdot
.918 .20148 Mdot
.918 .20257 Mdot
.918 .20353 Mdot
.918 .20432 Mdot
.918 .20443 Mdot
.918 .205 Mdot
.918 .20541 Mdot
.918 .20554 Mdot
.918 .20739 Mdot
.918 .20757 Mdot
.918 .20865 Mdot
.918 .20936 Mdot
.918 .20966 Mdot
.918 .21111 Mdot
.918 .21189 Mdot
.918 .21243 Mdot
.918 .21264 Mdot
.918 .21329 Mdot
.918 .21455 Mdot
.918 .21524 Mdot
.918 .21605 Mdot
.918 .21651 Mdot
.918 .21667 Mdot
.918 .21819 Mdot
.918 .21847 Mdot
.918 .21861 Mdot
.918 .21916 Mdot
.918 .21983 Mdot
.918 .22026 Mdot
.918 .22085 Mdot
.918 .22182 Mdot
.918 .22283 Mdot
.918 .22358 Mdot
.918 .22432 Mdot
.918 .22451 Mdot
.918 .227 Mdot
.918 .22765 Mdot
.918 .22821 Mdot
.918 .22935 Mdot
.918 .22941 Mdot
.918 .23152 Mdot
.918 .23175 Mdot
.918 .23331 Mdot
.918 .23353 Mdot
.918 .23392 Mdot
.918 .23549 Mdot
.918 .23613 Mdot
.918 .23659 Mdot
.918 .2367 Mdot
.918 .23743 Mdot
.918 .23799 Mdot
.918 .23816 Mdot
.918 .23859 Mdot
.918 .24 Mdot
.918 .24053 Mdot
.918 .24159 Mdot
.918 .24192 Mdot
.918 .24296 Mdot
.918 .24326 Mdot
.918 .24387 Mdot
.918 .24517 Mdot
.918 .24533 Mdot
.918 .24725 Mdot
.918 .24786 Mdot
.918 .2496 Mdot
.918 .25136 Mdot
.918 .25238 Mdot
.918 .25266 Mdot
.918 .25528 Mdot
.918 .25566 Mdot
.918 .25846 Mdot
.918 .2593 Mdot
.918 .25943 Mdot
.918 .2598 Mdot
.918 .26007 Mdot
.918 .26105 Mdot
.918 .26256 Mdot
.918 .26337 Mdot
.918 .26402 Mdot
.918 .26544 Mdot
.918 .2676 Mdot
.918 .26796 Mdot
.918 .26823 Mdot
.918 .26844 Mdot
.918 .26923 Mdot
.918 .27041 Mdot
.918 .27092 Mdot
.918 .27103 Mdot
.918 .27405 Mdot
.918 .27522 Mdot
.918 .27763 Mdot
.918 .27801 Mdot
.918 .27845 Mdot
.918 .28052 Mdot
.918 .28123 Mdot
.918 .28137 Mdot
.918 .28216 Mdot
.918 .28221 Mdot
.918 .28252 Mdot
.918 .28293 Mdot
.918 .28336 Mdot
.918 .2849 Mdot
.918 .28582 Mdot
.918 .28699 Mdot
.918 .28898 Mdot
.918 .2902 Mdot
.918 .29071 Mdot
.918 .29137 Mdot
.918 .2919 Mdot
.918 .29229 Mdot
.918 .29343 Mdot
.918 .29457 Mdot
.918 .29502 Mdot
.918 .2969 Mdot
.918 .29813 Mdot
.918 .29965 Mdot
.918 .30194 Mdot
.918 .30277 Mdot
.918 .3031 Mdot
.918 .30366 Mdot
.918 .30626 Mdot
.918 .30666 Mdot
.918 .30709 Mdot
.918 .30808 Mdot
.918 .30816 Mdot
.918 .30912 Mdot
.918 .31211 Mdot
.918 .31216 Mdot
.918 .31358 Mdot
.918 .31485 Mdot
.918 .31584 Mdot
.918 .31699 Mdot
.918 .31749 Mdot
.918 .3177 Mdot
.918 .31772 Mdot
.918 .31796 Mdot
.918 .31859 Mdot
.918 .31897 Mdot
.918 .32083 Mdot
.918 .32321 Mdot
.918 .32351 Mdot
.918 .32458 Mdot
.918 .3246 Mdot
.918 .32495 Mdot
.918 .32577 Mdot
.918 .32629 Mdot
.918 .33206 Mdot
.918 .33234 Mdot
.918 .33242 Mdot
.918 .33387 Mdot
.918 .3339 Mdot
.918 .33404 Mdot
.918 .33417 Mdot
.918 .33493 Mdot
.918 .3357 Mdot
.918 .33603 Mdot
.918 .33632 Mdot
.918 .33714 Mdot
.918 .33724 Mdot
.918 .33817 Mdot
.918 .33834 Mdot
.918 .33921 Mdot
.918 .34098 Mdot
.918 .34107 Mdot
.918 .34139 Mdot
.918 .34147 Mdot
.918 .34214 Mdot
.918 .34235 Mdot
.918 .34241 Mdot
.918 .34532 Mdot
.918 .3455 Mdot
.918 .34751 Mdot
.918 .3476 Mdot
.918 .34966 Mdot
.918 .35311 Mdot
.918 .35491 Mdot
.918 .35512 Mdot
.918 .35528 Mdot
.918 .35792 Mdot
.918 .3585 Mdot
.918 .35875 Mdot
.918 .3589 Mdot
.918 .35943 Mdot
.918 .35953 Mdot
.918 .36004 Mdot
.918 .36039 Mdot
.918 .3604 Mdot
.918 .36128 Mdot
.918 .36162 Mdot
.918 .36243 Mdot
.918 .363 Mdot
.918 .36317 Mdot
.918 .36324 Mdot
.918 .36398 Mdot
.918 .36447 Mdot
.918 .36493 Mdot
.918 .36511 Mdot
.918 .36515 Mdot
.918 .36556 Mdot
.918 .36592 Mdot
.918 .36606 Mdot
.918 .36617 Mdot
.918 .36619 Mdot
.918 .36802 Mdot
.918 .36847 Mdot
.918 .37026 Mdot
.918 .37241 Mdot
.918 .37268 Mdot
.918 .37273 Mdot
.918 .37336 Mdot
.918 .37364 Mdot
.918 .37416 Mdot
.918 .37629 Mdot
.918 .37717 Mdot
.918 .3774 Mdot
.918 .37763 Mdot
.918 .37789 Mdot
.918 .37811 Mdot
.918 .37909 Mdot
.918 .37987 Mdot
.918 .38007 Mdot
.918 .3803 Mdot
.918 .38083 Mdot
.918 .38092 Mdot
.918 .38218 Mdot
.918 .38257 Mdot
.918 .38346 Mdot
.918 .38373 Mdot
.918 .38415 Mdot
.918 .3843 Mdot
.918 .38438 Mdot
.918 .38726 Mdot
.918 .38735 Mdot
.918 .38848 Mdot
.918 .389 Mdot
.918 .38928 Mdot
.918 .39261 Mdot
.918 .39297 Mdot
.918 .39402 Mdot
.918 .39418 Mdot
.918 .39514 Mdot
.918 .39588 Mdot
.918 .39653 Mdot
.918 .39767 Mdot
.918 .39853 Mdot
.918 .39872 Mdot
.918 .40046 Mdot
.918 .4008 Mdot
.918 .40272 Mdot
.918 .40358 Mdot
.918 .40454 Mdot
.918 .40467 Mdot
.918 .405 Mdot
.918 .40577 Mdot
.918 .4068 Mdot
.918 .40713 Mdot
.918 .4095 Mdot
.918 .41003 Mdot
.918 .41021 Mdot
.918 .41025 Mdot
.918 .41138 Mdot
.918 .41219 Mdot
.918 .41279 Mdot
.918 .41293 Mdot
.918 .41332 Mdot
.918 .41419 Mdot
.918 .41576 Mdot
.918 .4159 Mdot
.918 .41701 Mdot
.918 .41803 Mdot
.918 .41936 Mdot
.918 .41941 Mdot
.918 .41948 Mdot
.918 .41963 Mdot
.918 .42086 Mdot
.918 .42112 Mdot
.918 .42122 Mdot
.918 .42307 Mdot
.918 .42343 Mdot
.918 .42344 Mdot
.918 .42351 Mdot
.918 .42369 Mdot
.918 .42519 Mdot
.918 .42522 Mdot
.918 .4253 Mdot
.918 .42553 Mdot
.918 .42631 Mdot
.918 .42734 Mdot
.918 .42864 Mdot
.918 .42869 Mdot
.918 .42939 Mdot
.918 .42953 Mdot
.918 .42959 Mdot
.918 .42963 Mdot
.918 .42976 Mdot
.918 .42979 Mdot
.918 .43022 Mdot
.918 .4303 Mdot
.918 .43064 Mdot
.918 .43069 Mdot
.918 .43101 Mdot
.918 .43118 Mdot
.918 .43137 Mdot
.918 .43143 Mdot
.918 .43298 Mdot
.918 .43304 Mdot
.918 .43306 Mdot
.918 .43341 Mdot
.918 .43434 Mdot
.918 .43439 Mdot
.918 .43483 Mdot
.918 .43488 Mdot
.918 .43579 Mdot
.918 .43595 Mdot
.918 .43667 Mdot
.918 .43801 Mdot
.918 .4381 Mdot
.918 .4384 Mdot
.918 .43864 Mdot
.918 .43997 Mdot
.918 .441 Mdot
.918 .44103 Mdot
.918 .44131 Mdot
.918 .44244 Mdot
.918 .44293 Mdot
.918 .44309 Mdot
.918 .44312 Mdot
.918 .44388 Mdot
.918 .44416 Mdot
.918 .44479 Mdot
.918 .44521 Mdot
.918 .44571 Mdot
.918 .44587 Mdot
.918 .44626 Mdot
.918 .44628 Mdot
.918 .44681 Mdot
.918 .44715 Mdot
.918 .44737 Mdot
.918 .44739 Mdot
.918 .44826 Mdot
.918 .44967 Mdot
.918 .45036 Mdot
.918 .45043 Mdot
.918 .45086 Mdot
.918 .45118 Mdot
.918 .45174 Mdot
.918 .45188 Mdot
.918 .45264 Mdot
.918 .45304 Mdot
.918 .45319 Mdot
.918 .45399 Mdot
.918 .45406 Mdot
.918 .45466 Mdot
.918 .45473 Mdot
.918 .45502 Mdot
.918 .45518 Mdot
.918 .45544 Mdot
.918 .45579 Mdot
.918 .45696 Mdot
.918 .45724 Mdot
.918 .45751 Mdot
.918 .4578 Mdot
.918 .45826 Mdot
.918 .45857 Mdot
.918 .45918 Mdot
.918 .45999 Mdot
.918 .46013 Mdot
.918 .46143 Mdot
.918 .46314 Mdot
.918 .46403 Mdot
.918 .46403 Mdot
.918 .46406 Mdot
.918 .46516 Mdot
.918 .46539 Mdot
.918 .46569 Mdot
.918 .46572 Mdot
.918 .46612 Mdot
.918 .46614 Mdot
.918 .46676 Mdot
.918 .46773 Mdot
.918 .46776 Mdot
.918 .46848 Mdot
.918 .4686 Mdot
.918 .4686 Mdot
.918 .46877 Mdot
.918 .46964 Mdot
.918 .46968 Mdot
.918 .4698 Mdot
.918 .47037 Mdot
.918 .47045 Mdot
.918 .47048 Mdot
.918 .4705 Mdot
.918 .47112 Mdot
.918 .47159 Mdot
.918 .4721 Mdot
.918 .47216 Mdot
.918 .47288 Mdot
.918 .47345 Mdot
.918 .47351 Mdot
.918 .47379 Mdot
.918 .47415 Mdot
.918 .47467 Mdot
.918 .47468 Mdot
.918 .47607 Mdot
.918 .47622 Mdot
.918 .47668 Mdot
.918 .47702 Mdot
.918 .47717 Mdot
.918 .47723 Mdot
.918 .47765 Mdot
.918 .47803 Mdot
.918 .47888 Mdot
.918 .47903 Mdot
.918 .48025 Mdot
.918 .48075 Mdot
.918 .48135 Mdot
.918 .48177 Mdot
.918 .48184 Mdot
.918 .48229 Mdot
.918 .48245 Mdot
.918 .48388 Mdot
.918 .484 Mdot
.918 .48422 Mdot
.918 .48474 Mdot
.918 .48596 Mdot
.918 .48624 Mdot
.918 .48689 Mdot
.918 .48777 Mdot
.918 .48786 Mdot
.918 .4886 Mdot
.918 .48869 Mdot
.918 .48899 Mdot
.918 .49023 Mdot
.918 .49044 Mdot
.918 .49082 Mdot
.918 .49084 Mdot
.918 .49095 Mdot
.918 .49257 Mdot
.918 .49275 Mdot
.918 .49349 Mdot
.918 .4935 Mdot
.918 .49354 Mdot
.918 .4936 Mdot
.918 .49392 Mdot
.918 .494 Mdot
.918 .49419 Mdot
.918 .49468 Mdot
.918 .49471 Mdot
.918 .49478 Mdot
.918 .49534 Mdot
.918 .49547 Mdot
.918 .49583 Mdot
.918 .49617 Mdot
.918 .49622 Mdot
.918 .49643 Mdot
.918 .49649 Mdot
.918 .49658 Mdot
.918 .49682 Mdot
.918 .49793 Mdot
.918 .49801 Mdot
.918 .50008 Mdot
.918 .5017 Mdot
.918 .50292 Mdot
.918 .50329 Mdot
.918 .50341 Mdot
.918 .50345 Mdot
.918 .50413 Mdot
.918 .50446 Mdot
.918 .50534 Mdot
.918 .50576 Mdot
.918 .50605 Mdot
.918 .50615 Mdot
.918 .50616 Mdot
.918 .50671 Mdot
.918 .50921 Mdot
.918 .50952 Mdot
.918 .50965 Mdot
.918 .50966 Mdot
.918 .51005 Mdot
.918 .51017 Mdot
.918 .51105 Mdot
.918 .51174 Mdot
.918 .51188 Mdot
.918 .51211 Mdot
.918 .5122 Mdot
.918 .5122 Mdot
.918 .51228 Mdot
.918 .51423 Mdot
.918 .51534 Mdot
.918 .51572 Mdot
.918 .51607 Mdot
.918 .51623 Mdot
.918 .51637 Mdot
.918 .51731 Mdot
.918 .51751 Mdot
.918 .51793 Mdot
.918 .51929 Mdot
.918 .51973 Mdot
.918 .52039 Mdot
.918 .52055 Mdot
.918 .52095 Mdot
.918 .52135 Mdot
.918 .52149 Mdot
.918 .52168 Mdot
.918 .52191 Mdot
.918 .52209 Mdot
.918 .52252 Mdot
.918 .52362 Mdot
.918 .52463 Mdot
.918 .52488 Mdot
.918 .52517 Mdot
.918 .52522 Mdot
.918 .52546 Mdot
.918 .52618 Mdot
.918 .52633 Mdot
.918 .52729 Mdot
.918 .52768 Mdot
.918 .52933 Mdot
.918 .5296 Mdot
.918 .52976 Mdot
.918 .53061 Mdot
.918 .53109 Mdot
.918 .53131 Mdot
.918 .53158 Mdot
.918 .53209 Mdot
.918 .53242 Mdot
.918 .53251 Mdot
.918 .53267 Mdot
.918 .53389 Mdot
.918 .53401 Mdot
.918 .53488 Mdot
.918 .53498 Mdot
.918 .5359 Mdot
.918 .53647 Mdot
.918 .53667 Mdot
.918 .53735 Mdot
.918 .53778 Mdot
.918 .53852 Mdot
.918 .53887 Mdot
.918 .53904 Mdot
.918 .53969 Mdot
.918 .53987 Mdot
.918 .54011 Mdot
.918 .5405 Mdot
.918 .54101 Mdot
.918 .54113 Mdot
.918 .54171 Mdot
.918 .54248 Mdot
.918 .54284 Mdot
.918 .54323 Mdot
.918 .54402 Mdot
.918 .54408 Mdot
.918 .54488 Mdot
.918 .54518 Mdot
.918 .54537 Mdot
.918 .54572 Mdot
.918 .54594 Mdot
.918 .54655 Mdot
.918 .54695 Mdot
.918 .5487 Mdot
.918 .54941 Mdot
.918 .55003 Mdot
.918 .55061 Mdot
.918 .5509 Mdot
.918 .55124 Mdot
.918 .5513 Mdot
.918 .55146 Mdot
.918 .55265 Mdot
.918 .55274 Mdot
.918 .55352 Mdot
.918 .55376 Mdot
.918 .55536 Mdot
.918 .55557 Mdot
.918 .5557 Mdot
.918 .55579 Mdot
.918 .55593 Mdot
.918 .55597 Mdot
.918 .55635 Mdot
.918 .55662 Mdot
.918 .55751 Mdot
.918 .55753 Mdot
.918 .55788 Mdot
.918 .55816 Mdot
.918 .55861 Mdot
.918 .55871 Mdot
.918 .55911 Mdot
.918 .5592 Mdot
.918 .55941 Mdot
.918 .5597 Mdot
.918 .55992 Mdot
.918 .55994 Mdot
.918 .56011 Mdot
.918 .56011 Mdot
.918 .56051 Mdot
.918 .56085 Mdot
.918 .56176 Mdot
.918 .56183 Mdot
.918 .56196 Mdot
.918 .56219 Mdot
.918 .56231 Mdot
.918 .5624 Mdot
.918 .56262 Mdot
.918 .56328 Mdot
.918 .56341 Mdot
.918 .56358 Mdot
.918 .5645 Mdot
.918 .56477 Mdot
.918 .56529 Mdot
.918 .5653 Mdot
.918 .56575 Mdot
.918 .566 Mdot
.918 .56642 Mdot
.918 .56653 Mdot
.918 .56657 Mdot
.918 .5668 Mdot
.918 .56817 Mdot
.918 .5686 Mdot
.918 .56867 Mdot
.918 .57004 Mdot
.918 .57007 Mdot
.918 .5704 Mdot
.918 .57144 Mdot
.918 .57181 Mdot
.918 .57183 Mdot
.918 .57191 Mdot
.918 .57202 Mdot
.918 .57223 Mdot
.918 .57229 Mdot
.918 .57244 Mdot
.918 .57261 Mdot
.918 .57263 Mdot
.918 .57277 Mdot
.918 .57311 Mdot
.918 .57347 Mdot
.918 .57401 Mdot
.918 .57406 Mdot
.918 .57419 Mdot
.918 .57437 Mdot
.918 .5746 Mdot
.918 .57464 Mdot
.918 .57517 Mdot
.918 .57541 Mdot
.918 .57602 Mdot
.918 .57603 Mdot
.918 .57626 Mdot
.918 .57658 Mdot
.918 .57661 Mdot
.918 .57668 Mdot
.918 .57703 Mdot
.918 .57713 Mdot
.918 .57714 Mdot
.918 .57723 Mdot
.918 .5773 Mdot
.918 .57747 Mdot
.918 .57765 Mdot
.918 .57768 Mdot
.918 .57829 Mdot
.918 .57924 Mdot
.918 .57936 Mdot
.918 .57946 Mdot
.918 .57959 Mdot
.918 .57974 Mdot
.918 .58013 Mdot
.918 .58067 Mdot
.918 .58098 Mdot
.918 .5822 Mdot
.918 .5824 Mdot
.918 .58255 Mdot
.918 .58263 Mdot
.918 .58266 Mdot
.918 .58309 Mdot
.918 .5837 Mdot
.918 .58371 Mdot
.918 .58376 Mdot
.918 .58396 Mdot
.918 .58402 Mdot
.918 .58477 Mdot
.918 .58486 Mdot
.918 .58549 Mdot
.918 .58603 Mdot
.918 .58621 Mdot
.918 .58624 Mdot
.918 .58633 Mdot
.918 .58662 Mdot
.918 .58666 Mdot
.918 .5868 Mdot
.918 .58684 Mdot
.918 .58708 Mdot
.918 .58724 Mdot
.918 .58742 Mdot
.918 .58757 Mdot
.918 .58792 Mdot
.918 .58798 Mdot
.918 .58824 Mdot
.918 .58834 Mdot
.918 .58838 Mdot
.918 .58851 Mdot
.918 .58856 Mdot
.918 .58868 Mdot
.918 .58879 Mdot
.918 .58884 Mdot
.918 .58886 Mdot
.918 .58891 Mdot
.918 .58897 Mdot
.918 .58912 Mdot
.918 .58918 Mdot
.918 .58927 Mdot
.918 .58944 Mdot
.918 .58948 Mdot
.918 .58953 Mdot
.918 .58954 Mdot
.918 .58978 Mdot
.918 .59001 Mdot
.918 .59003 Mdot
.918 .59007 Mdot
.918 .59012 Mdot
.918 .59042 Mdot
.918 .59098 Mdot
.918 .5913 Mdot
.918 .59143 Mdot
.918 .59159 Mdot
.918 .59167 Mdot
.918 .59171 Mdot
.918 .59179 Mdot
.918 .5918 Mdot
.918 .59197 Mdot
.918 .59204 Mdot
.918 .59204 Mdot
.918 .59205 Mdot
.918 .59226 Mdot
.918 .59227 Mdot
.918 .59232 Mdot
.918 .59236 Mdot
.918 .59268 Mdot
.918 .59273 Mdot
.918 .59287 Mdot
.918 .593 Mdot
.918 .59305 Mdot
.918 .59308 Mdot
.918 .59313 Mdot
.918 .59316 Mdot
.918 .59316 Mdot
.918 .59319 Mdot
.918 .59324 Mdot
.918 .59333 Mdot
.918 .59336 Mdot
.918 .59341 Mdot
.918 .59343 Mdot
.918 .59344 Mdot
.918 .59347 Mdot
.918 .59353 Mdot
.918 .5936 Mdot
.918 .5936 Mdot
.918 .59362 Mdot
.918 .59363 Mdot
.918 .59364 Mdot
.918 .59366 Mdot
.918 .59366 Mdot
.918 .59367 Mdot
.92 .0512 Mdot
.92 .05121 Mdot
.92 .05147 Mdot
.92 .05153 Mdot
.92 .05155 Mdot
.92 .05158 Mdot
.92 .05169 Mdot
.92 .05184 Mdot
.92 .05237 Mdot
.92 .05262 Mdot
.92 .05262 Mdot
.92 .05272 Mdot
.92 .05274 Mdot
.92 .05279 Mdot
.92 .05331 Mdot
.92 .05372 Mdot
.92 .05431 Mdot
.92 .05469 Mdot
.92 .05469 Mdot
.92 .05477 Mdot
.92 .05507 Mdot
.92 .05528 Mdot
.92 .05536 Mdot
.92 .05584 Mdot
.92 .05587 Mdot
.92 .0562 Mdot
.92 .05686 Mdot
.92 .057 Mdot
.92 .05701 Mdot
.92 .0574 Mdot
.92 .05754 Mdot
.92 .05754 Mdot
.92 .05765 Mdot
.92 .05791 Mdot
.92 .05793 Mdot
.92 .05806 Mdot
.92 .05806 Mdot
.92 .05966 Mdot
.92 .06095 Mdot
.92 .06145 Mdot
.92 .06148 Mdot
.92 .06156 Mdot
.92 .06231 Mdot
.92 .06232 Mdot
.92 .06253 Mdot
.92 .06332 Mdot
.92 .06341 Mdot
.92 .06358 Mdot
.92 .06423 Mdot
.92 .06484 Mdot
.92 .06485 Mdot
.92 .06492 Mdot
.92 .0671 Mdot
.92 .06723 Mdot
.92 .06744 Mdot
.92 .06775 Mdot
.92 .06809 Mdot
.92 .06829 Mdot
.92 .06934 Mdot
.92 .06971 Mdot
.92 .07016 Mdot
.92 .07173 Mdot
.92 .0729 Mdot
.92 .07387 Mdot
.92 .07393 Mdot
.92 .07397 Mdot
.92 .07419 Mdot
.92 .07427 Mdot
.92 .07529 Mdot
.92 .07655 Mdot
.92 .07689 Mdot
.92 .07705 Mdot
.92 .07747 Mdot
.92 .07888 Mdot
.92 .07892 Mdot
.92 .08164 Mdot
.92 .08226 Mdot
.92 .08226 Mdot
.92 .0828 Mdot
.92 .08284 Mdot
.92 .08354 Mdot
.92 .08442 Mdot
.92 .08575 Mdot
.92 .08632 Mdot
.92 .08695 Mdot
.92 .08858 Mdot
.92 .09024 Mdot
.92 .09122 Mdot
.92 .09131 Mdot
.92 .0917 Mdot
.92 .09202 Mdot
.92 .09252 Mdot
.92 .09303 Mdot
.92 .09541 Mdot
.92 .09673 Mdot
.92 .09691 Mdot
.92 .09702 Mdot
.92 .09759 Mdot
.92 .09802 Mdot
.92 .09903 Mdot
.92 .10119 Mdot
.92 .10125 Mdot
.92 .10129 Mdot
.92 .10383 Mdot
.92 .10544 Mdot
.92 .10546 Mdot
.92 .10859 Mdot
.92 .1086 Mdot
.92 .10934 Mdot
.92 .11004 Mdot
.92 .11042 Mdot
.92 .11195 Mdot
.92 .1122 Mdot
.92 .11279 Mdot
.92 .11445 Mdot
.92 .11897 Mdot
.92 .11956 Mdot
.92 .12031 Mdot
.92 .1211 Mdot
.92 .12116 Mdot
.92 .12439 Mdot
.92 .12569 Mdot
.92 .12683 Mdot
.92 .1269 Mdot
.92 .12881 Mdot
.92 .13064 Mdot
.92 .13134 Mdot
.92 .13163 Mdot
.92 .13216 Mdot
.92 .1336 Mdot
.92 .13614 Mdot
.92 .13615 Mdot
.92 .13615 Mdot
.92 .1374 Mdot
.92 .13821 Mdot
.92 .13943 Mdot
.92 .13972 Mdot
.92 .14042 Mdot
.92 .1408 Mdot
.92 .14136 Mdot
.92 .14305 Mdot
.92 .14739 Mdot
.92 .14788 Mdot
.92 .14942 Mdot
.92 .14946 Mdot
.92 .15037 Mdot
.92 .15056 Mdot
.92 .15064 Mdot
.92 .15074 Mdot
.92 .15111 Mdot
.92 .15116 Mdot
.92 .15161 Mdot
.92 .15345 Mdot
.92 .15349 Mdot
.92 .15429 Mdot
.92 .1543 Mdot
.92 .15465 Mdot
.92 .15473 Mdot
.92 .1549 Mdot
.92 .1552 Mdot
.92 .15666 Mdot
.92 .15791 Mdot
.92 .15808 Mdot
.92 .15815 Mdot
.92 .15824 Mdot
.92 .15862 Mdot
.92 .15961 Mdot
.92 .16007 Mdot
.92 .1603 Mdot
.92 .16137 Mdot
.92 .16138 Mdot
.92 .16166 Mdot
.92 .16178 Mdot
.92 .16192 Mdot
.92 .16268 Mdot
.92 .16339 Mdot
.92 .16364 Mdot
.92 .16529 Mdot
.92 .16539 Mdot
.92 .16587 Mdot
.92 .16614 Mdot
.92 .16623 Mdot
.92 .1665 Mdot
.92 .16657 Mdot
.92 .16715 Mdot
.92 .16871 Mdot
.92 .16915 Mdot
.92 .16921 Mdot
.92 .16924 Mdot
.92 .16925 Mdot
.92 .16987 Mdot
.92 .17051 Mdot
.92 .17056 Mdot
.92 .171 Mdot
.92 .17101 Mdot
.92 .17137 Mdot
.92 .17181 Mdot
.92 .17225 Mdot
.92 .17232 Mdot
.92 .17276 Mdot
.92 .17278 Mdot
.92 .17367 Mdot
.92 .17459 Mdot
.92 .17477 Mdot
.92 .17506 Mdot
.92 .1756 Mdot
.92 .17813 Mdot
.92 .17947 Mdot
.92 .1803 Mdot
.92 .18053 Mdot
.92 .18093 Mdot
.92 .18102 Mdot
.92 .18167 Mdot
.92 .18182 Mdot
.92 .18216 Mdot
.92 .1824 Mdot
.92 .18252 Mdot
.92 .18331 Mdot
.92 .18407 Mdot
.92 .18416 Mdot
.92 .18419 Mdot
.92 .18444 Mdot
.92 .18477 Mdot
.92 .18643 Mdot
.92 .18692 Mdot
.92 .18693 Mdot
.92 .18747 Mdot
.92 .18763 Mdot
.92 .18875 Mdot
.92 .18998 Mdot
.92 .19024 Mdot
.92 .19053 Mdot
.92 .19069 Mdot
.92 .19109 Mdot
.92 .19195 Mdot
.92 .19321 Mdot
.92 .19322 Mdot
.92 .19522 Mdot
.92 .19524 Mdot
.92 .19547 Mdot
.92 .19731 Mdot
.92 .19752 Mdot
.92 .1976 Mdot
.92 .19898 Mdot
.92 .19958 Mdot
.92 .20086 Mdot
.92 .20256 Mdot
.92 .20267 Mdot
.92 .20297 Mdot
.92 .20346 Mdot
.92 .20366 Mdot
.92 .20448 Mdot
.92 .20465 Mdot
.92 .20575 Mdot
.92 .2064 Mdot
.92 .20653 Mdot
.92 .20714 Mdot
.92 .20967 Mdot
.92 .20978 Mdot
.92 .21094 Mdot
.92 .21239 Mdot
.92 .21462 Mdot
.92 .21507 Mdot
.92 .21554 Mdot
.92 .21739 Mdot
.92 .21799 Mdot
.92 .2185 Mdot
.92 .21921 Mdot
.92 .21981 Mdot
.92 .21984 Mdot
.92 .21987 Mdot
.92 .22109 Mdot
.92 .22163 Mdot
.92 .22246 Mdot
.92 .22324 Mdot
.92 .22414 Mdot
.92 .22434 Mdot
.92 .22448 Mdot
.92 .22517 Mdot
.92 .2253 Mdot
.92 .22542 Mdot
.92 .2283 Mdot
.92 .2286 Mdot
.92 .22882 Mdot
.92 .23029 Mdot
.92 .23032 Mdot
.92 .23254 Mdot
.92 .2336 Mdot
.92 .2341 Mdot
.92 .23478 Mdot
.92 .23489 Mdot
.92 .23499 Mdot
.92 .23539 Mdot
.92 .23716 Mdot
.92 .23721 Mdot
.92 .23974 Mdot
.92 .23985 Mdot
.92 .23988 Mdot
.92 .24124 Mdot
.92 .24177 Mdot
.92 .24402 Mdot
.92 .24759 Mdot
.92 .24819 Mdot
.92 .25005 Mdot
.92 .25005 Mdot
.92 .25006 Mdot
.92 .25098 Mdot
.92 .25171 Mdot
.92 .25182 Mdot
.92 .25277 Mdot
.92 .25395 Mdot
.92 .25445 Mdot
.92 .25605 Mdot
.92 .25659 Mdot
.92 .25936 Mdot
.92 .26057 Mdot
.92 .26089 Mdot
.92 .26227 Mdot
.92 .26299 Mdot
.92 .26414 Mdot
.92 .26418 Mdot
.92 .26619 Mdot
.92 .26834 Mdot
.92 .26859 Mdot
.92 .26895 Mdot
.92 .27123 Mdot
.92 .27311 Mdot
.92 .27353 Mdot
.92 .27384 Mdot
.92 .27583 Mdot
.92 .2767 Mdot
.92 .27696 Mdot
.92 .27809 Mdot
.92 .27881 Mdot
.92 .27902 Mdot
.92 .27968 Mdot
.92 .28049 Mdot
.92 .28194 Mdot
.92 .283 Mdot
.92 .28342 Mdot
.92 .28573 Mdot
.92 .28579 Mdot
.92 .28632 Mdot
.92 .28806 Mdot
.92 .28879 Mdot
.92 .2889 Mdot
.92 .29256 Mdot
.92 .29257 Mdot
.92 .29307 Mdot
.92 .29321 Mdot
.92 .29337 Mdot
.92 .29389 Mdot
.92 .29497 Mdot
.92 .29544 Mdot
.92 .29621 Mdot
.92 .29714 Mdot
.92 .29794 Mdot
.92 .29904 Mdot
.92 .29989 Mdot
.92 .30108 Mdot
.92 .30152 Mdot
.92 .30508 Mdot
.92 .30524 Mdot
.92 .30536 Mdot
.92 .30832 Mdot
.92 .30993 Mdot
.92 .31237 Mdot
.92 .31345 Mdot
.92 .31406 Mdot
.92 .31583 Mdot
.92 .31651 Mdot
.92 .31678 Mdot
.92 .31683 Mdot
.92 .32075 Mdot
.92 .32075 Mdot
.92 .32138 Mdot
.92 .32171 Mdot
.92 .32255 Mdot
.92 .32395 Mdot
.92 .32416 Mdot
.92 .32483 Mdot
.92 .32528 Mdot
.92 .32531 Mdot
.92 .32729 Mdot
.92 .32863 Mdot
.92 .32916 Mdot
.92 .32997 Mdot
.92 .33017 Mdot
.92 .3309 Mdot
.92 .33098 Mdot
.92 .33114 Mdot
.92 .33224 Mdot
.92 .3341 Mdot
.92 .3342 Mdot
.92 .33437 Mdot
.92 .33487 Mdot
.92 .33582 Mdot
.92 .33643 Mdot
.92 .33905 Mdot
.92 .33908 Mdot
.92 .33928 Mdot
.92 .34076 Mdot
.92 .34097 Mdot
.92 .34223 Mdot
.92 .34384 Mdot
.92 .34419 Mdot
.92 .34453 Mdot
.92 .34542 Mdot
.92 .34615 Mdot
.92 .34646 Mdot
.92 .34766 Mdot
.92 .34853 Mdot
.92 .34903 Mdot
.92 .34927 Mdot
.92 .34994 Mdot
.92 .35112 Mdot
.92 .35176 Mdot
.92 .3519 Mdot
.92 .35216 Mdot
.92 .35237 Mdot
.92 .35285 Mdot
.92 .35387 Mdot
.92 .35578 Mdot
.92 .35714 Mdot
.92 .35776 Mdot
.92 .35793 Mdot
.92 .35857 Mdot
.92 .35892 Mdot
.92 .35961 Mdot
.92 .36168 Mdot
.92 .36229 Mdot
.92 .36232 Mdot
.92 .36452 Mdot
.92 .36454 Mdot
.92 .36595 Mdot
.92 .36652 Mdot
.92 .36843 Mdot
.92 .36872 Mdot
.92 .36916 Mdot
.92 .36926 Mdot
.92 .36951 Mdot
.92 .36965 Mdot
.92 .37194 Mdot
.92 .37211 Mdot
.92 .37323 Mdot
.92 .37459 Mdot
.92 .37548 Mdot
.92 .37556 Mdot
.92 .37559 Mdot
.92 .37572 Mdot
.92 .37604 Mdot
.92 .37675 Mdot
.92 .37807 Mdot
.92 .37848 Mdot
.92 .37911 Mdot
.92 .37914 Mdot
.92 .37934 Mdot
.92 .37954 Mdot
.92 .37995 Mdot
.92 .38053 Mdot
.92 .38096 Mdot
.92 .38113 Mdot
.92 .38162 Mdot
.92 .38232 Mdot
.92 .38258 Mdot
.92 .38277 Mdot
.92 .3828 Mdot
.92 .383 Mdot
.92 .38349 Mdot
.92 .38376 Mdot
.92 .38475 Mdot
.92 .38513 Mdot
.92 .38571 Mdot
.92 .38608 Mdot
.92 .38645 Mdot
.92 .38766 Mdot
.92 .38814 Mdot
.92 .38831 Mdot
.92 .38869 Mdot
.92 .39032 Mdot
.92 .39049 Mdot
.92 .39121 Mdot
.92 .39406 Mdot
.92 .39407 Mdot
.92 .39408 Mdot
.92 .39456 Mdot
.92 .39501 Mdot
.92 .39654 Mdot
.92 .39695 Mdot
.92 .39881 Mdot
.92 .3999 Mdot
.92 .4016 Mdot
.92 .40225 Mdot
.92 .40383 Mdot
.92 .40469 Mdot
.92 .40509 Mdot
.92 .40595 Mdot
.92 .40647 Mdot
.92 .40703 Mdot
.92 .40777 Mdot
.92 .40896 Mdot
.92 .40972 Mdot
.92 .40994 Mdot
.92 .41079 Mdot
.92 .41148 Mdot
.92 .41208 Mdot
.92 .41322 Mdot
.92 .41394 Mdot
.92 .41758 Mdot
.92 .41861 Mdot
.92 .41922 Mdot
.92 .42028 Mdot
.92 .42028 Mdot
.92 .42107 Mdot
.92 .42112 Mdot
.92 .42129 Mdot
.92 .42223 Mdot
.92 .42285 Mdot
.92 .42313 Mdot
.92 .42359 Mdot
.92 .42365 Mdot
.92 .42401 Mdot
.92 .42487 Mdot
.92 .42529 Mdot
.92 .4256 Mdot
.92 .426 Mdot
.92 .42617 Mdot
.92 .42639 Mdot
.92 .42657 Mdot
.92 .42664 Mdot
.92 .42716 Mdot
.92 .42728 Mdot
.92 .42795 Mdot
.92 .42799 Mdot
.92 .42822 Mdot
.92 .42964 Mdot
.92 .42972 Mdot
.92 .42989 Mdot
.92 .43056 Mdot
.92 .43207 Mdot
.92 .43215 Mdot
.92 .43228 Mdot
.92 .43234 Mdot
.92 .43237 Mdot
.92 .43382 Mdot
.92 .43384 Mdot
.92 .43446 Mdot
.92 .43456 Mdot
.92 .43473 Mdot
.92 .43478 Mdot
.92 .43483 Mdot
.92 .43493 Mdot
.92 .43507 Mdot
.92 .43518 Mdot
.92 .43534 Mdot
.92 .43568 Mdot
.92 .43645 Mdot
.92 .43654 Mdot
.92 .43684 Mdot
.92 .43755 Mdot
.92 .43868 Mdot
.92 .43906 Mdot
.92 .44121 Mdot
.92 .44155 Mdot
.92 .44169 Mdot
.92 .44188 Mdot
.92 .44218 Mdot
.92 .44264 Mdot
.92 .44282 Mdot
.92 .44463 Mdot
.92 .44505 Mdot
.92 .44531 Mdot
.92 .44555 Mdot
.92 .44601 Mdot
.92 .44633 Mdot
.92 .44668 Mdot
.92 .44745 Mdot
.92 .44769 Mdot
.92 .44813 Mdot
.92 .44815 Mdot
.92 .4487 Mdot
.92 .44893 Mdot
.92 .44922 Mdot
.92 .44924 Mdot
.92 .4495 Mdot
.92 .4499 Mdot
.92 .45071 Mdot
.92 .4521 Mdot
.92 .45257 Mdot
.92 .45577 Mdot
.92 .45597 Mdot
.92 .4561 Mdot
.92 .45689 Mdot
.92 .45701 Mdot
.92 .45739 Mdot
.92 .45757 Mdot
.92 .45808 Mdot
.92 .45821 Mdot
.92 .45933 Mdot
.92 .45964 Mdot
.92 .46119 Mdot
.92 .46193 Mdot
.92 .46227 Mdot
.92 .46242 Mdot
.92 .46246 Mdot
.92 .463 Mdot
.92 .46308 Mdot
.92 .4632 Mdot
.92 .46325 Mdot
.92 .46328 Mdot
.92 .46343 Mdot
.92 .46444 Mdot
.92 .46445 Mdot
.92 .46448 Mdot
.92 .46531 Mdot
.92 .46563 Mdot
.92 .46571 Mdot
.92 .46575 Mdot
.92 .46653 Mdot
.92 .46655 Mdot
.92 .46717 Mdot
.92 .46721 Mdot
.92 .46781 Mdot
.92 .46801 Mdot
.92 .46841 Mdot
.92 .46882 Mdot
.92 .46895 Mdot
.92 .46924 Mdot
.92 .46968 Mdot
.92 .46976 Mdot
.92 .46978 Mdot
.92 .47015 Mdot
.92 .47092 Mdot
.92 .4714 Mdot
.92 .47306 Mdot
.92 .4734 Mdot
.92 .47391 Mdot
.92 .47418 Mdot
.92 .4745 Mdot
.92 .47488 Mdot
.92 .47532 Mdot
.92 .47585 Mdot
.92 .47619 Mdot
.92 .47644 Mdot
.92 .47705 Mdot
.92 .47934 Mdot
.92 .48081 Mdot
.92 .48148 Mdot
.92 .48167 Mdot
.92 .48312 Mdot
.92 .48343 Mdot
.92 .4835 Mdot
.92 .4842 Mdot
.92 .48436 Mdot
.92 .48464 Mdot
.92 .48515 Mdot
.92 .48531 Mdot
.92 .48547 Mdot
.92 .48571 Mdot
.92 .48629 Mdot
.92 .48661 Mdot
.92 .48671 Mdot
.92 .48689 Mdot
.92 .48719 Mdot
.92 .48746 Mdot
.92 .48765 Mdot
.92 .48789 Mdot
.92 .48806 Mdot
.92 .48814 Mdot
.92 .48823 Mdot
.92 .48824 Mdot
.92 .4885 Mdot
.92 .48867 Mdot
.92 .48952 Mdot
.92 .48965 Mdot
.92 .4897 Mdot
.92 .48971 Mdot
.92 .48975 Mdot
.92 .49012 Mdot
.92 .49068 Mdot
.92 .49214 Mdot
.92 .4922 Mdot
.92 .4923 Mdot
.92 .49252 Mdot
.92 .49264 Mdot
.92 .49342 Mdot
.92 .49422 Mdot
.92 .49423 Mdot
.92 .49511 Mdot
.92 .49512 Mdot
.92 .49537 Mdot
.92 .4962 Mdot
.92 .49647 Mdot
.92 .49661 Mdot
.92 .49718 Mdot
.92 .49888 Mdot
.92 .49915 Mdot
.92 .49925 Mdot
.92 .49931 Mdot
.92 .49956 Mdot
.92 .50002 Mdot
.92 .50028 Mdot
.92 .50038 Mdot
.92 .50057 Mdot
.92 .50091 Mdot
.92 .50138 Mdot
.92 .5015 Mdot
.92 .50178 Mdot
.92 .50213 Mdot
.92 .50226 Mdot
.92 .5024 Mdot
.92 .50302 Mdot
.92 .5035 Mdot
.92 .50415 Mdot
.92 .50423 Mdot
.92 .50424 Mdot
.92 .50547 Mdot
.92 .50602 Mdot
.92 .50612 Mdot
.92 .50683 Mdot
.92 .50725 Mdot
.92 .5073 Mdot
.92 .50733 Mdot
.92 .50769 Mdot
.92 .50819 Mdot
.92 .50961 Mdot
.92 .50986 Mdot
.92 .50994 Mdot
.92 .51046 Mdot
.92 .51077 Mdot
.92 .51089 Mdot
.92 .51112 Mdot
.92 .51113 Mdot
.92 .51269 Mdot
.92 .51294 Mdot
.92 .51359 Mdot
.92 .51381 Mdot
.92 .51509 Mdot
.92 .51567 Mdot
.92 .51812 Mdot
.92 .51828 Mdot
.92 .5187 Mdot
.92 .51939 Mdot
.92 .51968 Mdot
.92 .52028 Mdot
.92 .52083 Mdot
.92 .52107 Mdot
.92 .5213 Mdot
.92 .52259 Mdot
.92 .52288 Mdot
.92 .52349 Mdot
.92 .52367 Mdot
.92 .52369 Mdot
.92 .52449 Mdot
.92 .52464 Mdot
.92 .52579 Mdot
.92 .52609 Mdot
.92 .52711 Mdot
.92 .5279 Mdot
.92 .52804 Mdot
.92 .52868 Mdot
.92 .52958 Mdot
.92 .52966 Mdot
.92 .53039 Mdot
.92 .53107 Mdot
.92 .53147 Mdot
.92 .53218 Mdot
.92 .53269 Mdot
.92 .53379 Mdot
.92 .53432 Mdot
.92 .53488 Mdot
.92 .53547 Mdot
.92 .53578 Mdot
.92 .53659 Mdot
.92 .53776 Mdot
.92 .53849 Mdot
.92 .53867 Mdot
.92 .53912 Mdot
.92 .53997 Mdot
.92 .53999 Mdot
.92 .54069 Mdot
.92 .54072 Mdot
.92 .54076 Mdot
.92 .54219 Mdot
.92 .5422 Mdot
.92 .54267 Mdot
.92 .54284 Mdot
.92 .5438 Mdot
.92 .54445 Mdot
.92 .5447 Mdot
.92 .54496 Mdot
.92 .54552 Mdot
.92 .54553 Mdot
.92 .54554 Mdot
.92 .54573 Mdot
.92 .54595 Mdot
.92 .54611 Mdot
.92 .54689 Mdot
.92 .54703 Mdot
.92 .54717 Mdot
.92 .54872 Mdot
.92 .54951 Mdot
.92 .5497 Mdot
.92 .55034 Mdot
.92 .55065 Mdot
.92 .5509 Mdot
.92 .55146 Mdot
.92 .55185 Mdot
.92 .55204 Mdot
.92 .55246 Mdot
.92 .55248 Mdot
.92 .55255 Mdot
.92 .5538 Mdot
.92 .55419 Mdot
.92 .55457 Mdot
.92 .55479 Mdot
.92 .55516 Mdot
.92 .55555 Mdot
.92 .55587 Mdot
.92 .55637 Mdot
.92 .55655 Mdot
.92 .55681 Mdot
.92 .55705 Mdot
.92 .55716 Mdot
.92 .55726 Mdot
.92 .5573 Mdot
.92 .5575 Mdot
.92 .55753 Mdot
.92 .55765 Mdot
.92 .55772 Mdot
.92 .55797 Mdot
.92 .55865 Mdot
.92 .55912 Mdot
.92 .55929 Mdot
.92 .55937 Mdot
.92 .55943 Mdot
.92 .5597 Mdot
.92 .56026 Mdot
.92 .56064 Mdot
.92 .56083 Mdot
.92 .56102 Mdot
.92 .56105 Mdot
.92 .56164 Mdot
.92 .56181 Mdot
.92 .56191 Mdot
.92 .56194 Mdot
.92 .56202 Mdot
.92 .56318 Mdot
.92 .56322 Mdot
.92 .56366 Mdot
.92 .56386 Mdot
.92 .56415 Mdot
.92 .56426 Mdot
.92 .56429 Mdot
.92 .56436 Mdot
.92 .56515 Mdot
.92 .56565 Mdot
.92 .56633 Mdot
.92 .56728 Mdot
.92 .56742 Mdot
.92 .56867 Mdot
.92 .56916 Mdot
.92 .56932 Mdot
.92 .56943 Mdot
.92 .56963 Mdot
.92 .56971 Mdot
.92 .57006 Mdot
.92 .5703 Mdot
.92 .57065 Mdot
.92 .57065 Mdot
.92 .57066 Mdot
.92 .57138 Mdot
.92 .57179 Mdot
.92 .57194 Mdot
.92 .57202 Mdot
.92 .57222 Mdot
.92 .57274 Mdot
.92 .57328 Mdot
.92 .5733 Mdot
.92 .57363 Mdot
.92 .57399 Mdot
.92 .5749 Mdot
.92 .57492 Mdot
.92 .57514 Mdot
.92 .57535 Mdot
.92 .57552 Mdot
.92 .57678 Mdot
.92 .57725 Mdot
.92 .57741 Mdot
.92 .57748 Mdot
.92 .57791 Mdot
.92 .57801 Mdot
.92 .57821 Mdot
.92 .57841 Mdot
.92 .57841 Mdot
.92 .57928 Mdot
.92 .57929 Mdot
.92 .57973 Mdot
.92 .58043 Mdot
.92 .58045 Mdot
.92 .58046 Mdot
.92 .58106 Mdot
.92 .58133 Mdot
.92 .58145 Mdot
.92 .58161 Mdot
.92 .58164 Mdot
.92 .58169 Mdot
.92 .58205 Mdot
.92 .5827 Mdot
.92 .58284 Mdot
.92 .58298 Mdot
.92 .58306 Mdot
.92 .58317 Mdot
.92 .58319 Mdot
.92 .58346 Mdot
.92 .58391 Mdot
.92 .58436 Mdot
.92 .58453 Mdot
.92 .58468 Mdot
.92 .58504 Mdot
.92 .58528 Mdot
.92 .58547 Mdot
.92 .58548 Mdot
.92 .58563 Mdot
.92 .58563 Mdot
.92 .58579 Mdot
.92 .58653 Mdot
.92 .58654 Mdot
.92 .58692 Mdot
.92 .58703 Mdot
.92 .58707 Mdot
.92 .58717 Mdot
.92 .5875 Mdot
.92 .58778 Mdot
.92 .5878 Mdot
.92 .58786 Mdot
.92 .58787 Mdot
.92 .58789 Mdot
.92 .58815 Mdot
.92 .58846 Mdot
.92 .58888 Mdot
.92 .589 Mdot
.92 .5891 Mdot
.92 .58938 Mdot
.92 .58943 Mdot
.92 .58952 Mdot
.92 .5896 Mdot
.92 .58966 Mdot
.92 .58969 Mdot
.92 .59027 Mdot
.92 .59029 Mdot
.92 .5903 Mdot
.92 .59046 Mdot
.92 .59063 Mdot
.92 .59068 Mdot
.92 .5907 Mdot
.92 .59091 Mdot
.92 .59097 Mdot
.92 .59097 Mdot
.92 .59117 Mdot
.92 .59119 Mdot
.92 .59119 Mdot
.92 .59133 Mdot
.92 .59167 Mdot
.92 .59209 Mdot
.92 .59209 Mdot
.92 .59213 Mdot
.92 .59213 Mdot
.92 .5922 Mdot
.92 .59223 Mdot
.92 .59223 Mdot
.92 .59227 Mdot
.92 .59237 Mdot
.92 .59237 Mdot
.92 .59241 Mdot
.92 .59258 Mdot
.92 .59267 Mdot
.92 .59268 Mdot
.92 .59281 Mdot
.92 .59282 Mdot
.92 .59288 Mdot
.92 .59296 Mdot
.92 .59298 Mdot
.92 .59298 Mdot
.92 .59308 Mdot
.92 .59324 Mdot
.92 .59334 Mdot
.92 .59348 Mdot
.92 .59349 Mdot
.92 .5935 Mdot
.92 .59353 Mdot
.92 .59353 Mdot
.92 .59359 Mdot
.92 .59373 Mdot
.92 .59377 Mdot
.92 .5938 Mdot
.92 .59381 Mdot
.92 .59381 Mdot
.92 .59383 Mdot
.92 .5939 Mdot
.92 .5939 Mdot
.922 .05031 Mdot
.922 .05033 Mdot
.922 .1464 Mdot
.922 .14646 Mdot
.922 .30809 Mdot
.922 .30864 Mdot
.922 .41723 Mdot
.922 .41737 Mdot
.922 .5156 Mdot
.922 .5158 Mdot
.922 .59413 Mdot
.922 .59414 Mdot
.924 .04944 Mdot
.924 .04945 Mdot
.924 .04945 Mdot
.924 .04951 Mdot
.924 .04957 Mdot
.924 .04958 Mdot
.924 .04965 Mdot
.924 .04986 Mdot
.924 .04989 Mdot
.924 .04995 Mdot
.924 .04999 Mdot
.924 .05001 Mdot
.924 .05004 Mdot
.924 .05011 Mdot
.924 .0504 Mdot
.924 .0508 Mdot
.924 .05084 Mdot
.924 .05103 Mdot
.924 .05115 Mdot
.924 .05119 Mdot
.924 .05127 Mdot
.924 .05143 Mdot
.924 .05156 Mdot
.924 .05158 Mdot
.924 .05169 Mdot
.924 .05178 Mdot
.924 .05187 Mdot
.924 .05191 Mdot
.924 .05193 Mdot
.924 .05193 Mdot
.924 .0525 Mdot
.924 .05255 Mdot
.924 .05281 Mdot
.924 .05352 Mdot
.924 .05377 Mdot
.924 .05379 Mdot
.924 .05382 Mdot
.924 .05406 Mdot
.924 .05414 Mdot
.924 .05422 Mdot
.924 .05429 Mdot
.924 .0543 Mdot
.924 .05447 Mdot
.924 .05474 Mdot
.924 .05528 Mdot
.924 .05541 Mdot
.924 .05576 Mdot
.924 .05579 Mdot
.924 .05683 Mdot
.924 .05687 Mdot
.924 .05692 Mdot
.924 .05746 Mdot
.924 .05827 Mdot
.924 .05844 Mdot
.924 .05893 Mdot
.924 .05982 Mdot
.924 .05987 Mdot
.924 .0603 Mdot
.924 .06099 Mdot
.924 .06102 Mdot
.924 .06217 Mdot
.924 .06232 Mdot
.924 .06235 Mdot
.924 .06245 Mdot
.924 .06253 Mdot
.924 .06374 Mdot
.924 .06401 Mdot
.924 .06417 Mdot
.924 .06459 Mdot
.924 .06469 Mdot
.924 .0652 Mdot
.924 .06536 Mdot
.924 .06565 Mdot
.924 .06622 Mdot
.924 .06673 Mdot
.924 .06673 Mdot
.924 .06678 Mdot
.924 .06704 Mdot
.924 .06709 Mdot
.924 .06738 Mdot
.924 .0679 Mdot
.924 .06801 Mdot
.924 .0701 Mdot
.924 .0714 Mdot
.924 .07144 Mdot
.924 .07195 Mdot
.924 .07397 Mdot
.924 .07433 Mdot
.924 .07453 Mdot
.924 .07466 Mdot
.924 .07518 Mdot
.924 .07532 Mdot
.924 .07612 Mdot
.924 .07629 Mdot
.924 .07754 Mdot
.924 .07924 Mdot
.924 .08063 Mdot
.924 .08112 Mdot
.924 .08203 Mdot
.924 .08417 Mdot
.924 .08488 Mdot
.924 .08506 Mdot
.924 .0851 Mdot
.924 .08544 Mdot
.924 .0877 Mdot
.924 .08788 Mdot
.924 .08885 Mdot
.924 .08932 Mdot
.924 .09139 Mdot
.924 .09154 Mdot
.924 .09341 Mdot
.924 .0941 Mdot
.924 .09452 Mdot
.924 .09495 Mdot
.924 .09619 Mdot
.924 .09644 Mdot
.924 .09749 Mdot
.924 .09766 Mdot
.924 .10065 Mdot
.924 .10216 Mdot
.924 .10319 Mdot
.924 .10418 Mdot
.924 .10424 Mdot
.924 .10596 Mdot
.924 .1073 Mdot
.924 .10733 Mdot
.924 .10746 Mdot
.924 .10809 Mdot
.924 .10945 Mdot
.924 .11144 Mdot
.924 .11189 Mdot
.924 .1122 Mdot
.924 .11348 Mdot
.924 .11422 Mdot
.924 .11469 Mdot
.924 .11664 Mdot
.924 .1174 Mdot
.924 .11882 Mdot
.924 .11886 Mdot
.924 .1208 Mdot
.924 .12194 Mdot
.924 .12373 Mdot
.924 .12555 Mdot
.924 .12651 Mdot
.924 .12722 Mdot
.924 .12809 Mdot
.924 .13059 Mdot
.924 .13181 Mdot
.924 .13256 Mdot
.924 .13599 Mdot
.924 .13783 Mdot
.924 .14254 Mdot
.924 .14339 Mdot
.924 .14343 Mdot
.924 .14346 Mdot
.924 .14346 Mdot
.924 .14367 Mdot
.924 .14388 Mdot
.924 .1439 Mdot
.924 .14392 Mdot
.924 .14416 Mdot
.924 .14452 Mdot
.924 .1449 Mdot
.924 .14498 Mdot
.924 .14521 Mdot
.924 .14536 Mdot
.924 .14543 Mdot
.924 .14551 Mdot
.924 .14563 Mdot
.924 .14577 Mdot
.924 .14676 Mdot
.924 .14704 Mdot
.924 .14814 Mdot
.924 .14824 Mdot
.924 .14829 Mdot
.924 .14893 Mdot
.924 .14934 Mdot
.924 .14948 Mdot
.924 .14959 Mdot
.924 .14976 Mdot
.924 .15032 Mdot
.924 .15076 Mdot
.924 .15084 Mdot
.924 .15108 Mdot
.924 .15121 Mdot
.924 .15154 Mdot
.924 .15171 Mdot
.924 .15184 Mdot
.924 .15199 Mdot
.924 .15205 Mdot
.924 .15206 Mdot
.924 .15283 Mdot
.924 .15402 Mdot
.924 .1542 Mdot
.924 .15508 Mdot
.924 .15594 Mdot
.924 .15625 Mdot
.924 .15751 Mdot
.924 .15835 Mdot
.924 .15842 Mdot
.924 .15854 Mdot
.924 .15911 Mdot
.924 .15913 Mdot
.924 .15934 Mdot
.924 .15962 Mdot
.924 .1599 Mdot
.924 .16013 Mdot
.924 .16015 Mdot
.924 .16075 Mdot
.924 .16104 Mdot
.924 .16118 Mdot
.924 .16165 Mdot
.924 .16351 Mdot
.924 .16395 Mdot
.924 .16512 Mdot
.924 .16524 Mdot
.924 .16568 Mdot
.924 .16819 Mdot
.924 .16875 Mdot
.924 .16888 Mdot
.924 .16904 Mdot
.924 .17026 Mdot
.924 .17086 Mdot
.924 .1715 Mdot
.924 .17285 Mdot
.924 .17361 Mdot
.924 .17415 Mdot
.924 .17417 Mdot
.924 .17417 Mdot
.924 .17483 Mdot
.924 .1758 Mdot
.924 .17789 Mdot
.924 .17829 Mdot
.924 .17833 Mdot
.924 .17879 Mdot
.924 .17896 Mdot
.924 .17961 Mdot
.924 .17968 Mdot
.924 .18008 Mdot
.924 .18039 Mdot
.924 .18266 Mdot
.924 .18276 Mdot
.924 .18384 Mdot
.924 .18435 Mdot
.924 .18658 Mdot
.924 .18665 Mdot
.924 .18708 Mdot
.924 .18719 Mdot
.924 .18752 Mdot
.924 .18779 Mdot
.924 .18812 Mdot
.924 .19035 Mdot
.924 .19079 Mdot
.924 .19176 Mdot
.924 .19262 Mdot
.924 .19266 Mdot
.924 .19316 Mdot
.924 .19452 Mdot
.924 .19485 Mdot
.924 .19654 Mdot
.924 .19706 Mdot
.924 .198 Mdot
.924 .19985 Mdot
.924 .2012 Mdot
.924 .2015 Mdot
.924 .20152 Mdot
.924 .20166 Mdot
.924 .20251 Mdot
.924 .20267 Mdot
.924 .20276 Mdot
.924 .20334 Mdot
.924 .20363 Mdot
.924 .20392 Mdot
.924 .20513 Mdot
.924 .2053 Mdot
.924 .20565 Mdot
.924 .2085 Mdot
.924 .20954 Mdot
.924 .20994 Mdot
.924 .21115 Mdot
.924 .21211 Mdot
.924 .21234 Mdot
.924 .21235 Mdot
.924 .21278 Mdot
.924 .21522 Mdot
.924 .21623 Mdot
.924 .21631 Mdot
.924 .21651 Mdot
.924 .21664 Mdot
.924 .217 Mdot
.924 .21827 Mdot
.924 .21848 Mdot
.924 .22463 Mdot
.924 .22572 Mdot
.924 .22578 Mdot
.924 .2264 Mdot
.924 .2268 Mdot
.924 .22827 Mdot
.924 .22844 Mdot
.924 .22888 Mdot
.924 .23136 Mdot
.924 .23191 Mdot
.924 .23398 Mdot
.924 .23512 Mdot
.924 .23565 Mdot
.924 .23566 Mdot
.924 .23578 Mdot
.924 .23814 Mdot
.924 .23879 Mdot
.924 .23958 Mdot
.924 .24102 Mdot
.924 .24169 Mdot
.924 .24435 Mdot
.924 .24531 Mdot
.924 .24571 Mdot
.924 .2462 Mdot
.924 .2468 Mdot
.924 .24697 Mdot
.924 .24726 Mdot
.924 .24957 Mdot
.924 .25082 Mdot
.924 .25109 Mdot
.924 .25603 Mdot
.924 .25818 Mdot
.924 .2587 Mdot
.924 .25883 Mdot
.924 .25985 Mdot
.924 .26043 Mdot
.924 .26209 Mdot
.924 .26212 Mdot
.924 .26302 Mdot
.924 .26656 Mdot
.924 .26676 Mdot
.924 .2671 Mdot
.924 .26997 Mdot
.924 .27136 Mdot
.924 .27146 Mdot
.924 .27302 Mdot
.924 .27354 Mdot
.924 .27462 Mdot
.924 .27699 Mdot
.924 .27708 Mdot
.924 .27741 Mdot
.924 .27785 Mdot
.924 .27917 Mdot
.924 .28201 Mdot
.924 .2824 Mdot
.924 .28262 Mdot
.924 .28265 Mdot
.924 .28285 Mdot
.924 .28328 Mdot
.924 .28449 Mdot
.924 .28527 Mdot
.924 .2863 Mdot
.924 .28646 Mdot
.924 .28649 Mdot
.924 .28662 Mdot
.924 .28769 Mdot
.924 .28833 Mdot
.924 .28874 Mdot
.924 .2888 Mdot
.924 .28969 Mdot
.924 .29037 Mdot
.924 .29125 Mdot
.924 .29186 Mdot
.924 .29196 Mdot
.924 .29494 Mdot
.924 .29519 Mdot
.924 .2952 Mdot
.924 .29541 Mdot
.924 .29593 Mdot
.924 .29634 Mdot
.924 .29749 Mdot
.924 .29794 Mdot
.924 .2991 Mdot
.924 .29914 Mdot
.924 .29922 Mdot
.924 .2994 Mdot
.924 .29982 Mdot
.924 .29987 Mdot
.924 .30015 Mdot
.924 .30051 Mdot
.924 .3008 Mdot
.924 .30109 Mdot
.924 .30156 Mdot
.924 .30168 Mdot
.924 .30283 Mdot
.924 .30381 Mdot
.924 .30419 Mdot
.924 .30475 Mdot
.924 .30487 Mdot
.924 .30603 Mdot
.924 .30799 Mdot
.924 .30802 Mdot
.924 .30817 Mdot
.924 .31086 Mdot
.924 .31146 Mdot
.924 .3115 Mdot
.924 .31357 Mdot
.924 .31375 Mdot
.924 .31392 Mdot
.924 .31733 Mdot
.924 .31843 Mdot
.924 .31894 Mdot
.924 .32 Mdot
.924 .32207 Mdot
.924 .32215 Mdot
.924 .3225 Mdot
.924 .32274 Mdot
.924 .32345 Mdot
.924 .32418 Mdot
.924 .32435 Mdot
.924 .32478 Mdot
.924 .32483 Mdot
.924 .32612 Mdot
.924 .32784 Mdot
.924 .33037 Mdot
.924 .33166 Mdot
.924 .33298 Mdot
.924 .33312 Mdot
.924 .33346 Mdot
.924 .33395 Mdot
.924 .33408 Mdot
.924 .33431 Mdot
.924 .33514 Mdot
.924 .33515 Mdot
.924 .3361 Mdot
.924 .33759 Mdot
.924 .33849 Mdot
.924 .33852 Mdot
.924 .34042 Mdot
.924 .34054 Mdot
.924 .34154 Mdot
.924 .34164 Mdot
.924 .3424 Mdot
.924 .34422 Mdot
.924 .34619 Mdot
.924 .34669 Mdot
.924 .34688 Mdot
.924 .34816 Mdot
.924 .34866 Mdot
.924 .3489 Mdot
.924 .34994 Mdot
.924 .35002 Mdot
.924 .35168 Mdot
.924 .35227 Mdot
.924 .35239 Mdot
.924 .35288 Mdot
.924 .35296 Mdot
.924 .35433 Mdot
.924 .35547 Mdot
.924 .35669 Mdot
.924 .35727 Mdot
.924 .35728 Mdot
.924 .35733 Mdot
.924 .35901 Mdot
.924 .36015 Mdot
.924 .36035 Mdot
.924 .36113 Mdot
.924 .36144 Mdot
.924 .36202 Mdot
.924 .36278 Mdot
.924 .36322 Mdot
.924 .36391 Mdot
.924 .36461 Mdot
.924 .36497 Mdot
.924 .36524 Mdot
.924 .36556 Mdot
.924 .36649 Mdot
.924 .36911 Mdot
.924 .37145 Mdot
.924 .37319 Mdot
.924 .3739 Mdot
.924 .37427 Mdot
.924 .3753 Mdot
.924 .3754 Mdot
.924 .37634 Mdot
.924 .37696 Mdot
.924 .38028 Mdot
.924 .3807 Mdot
.924 .3811 Mdot
.924 .38111 Mdot
.924 .38131 Mdot
.924 .38277 Mdot
.924 .3828 Mdot
.924 .38421 Mdot
.924 .38489 Mdot
.924 .38533 Mdot
.924 .38599 Mdot
.924 .38993 Mdot
.924 .39027 Mdot
.924 .39152 Mdot
.924 .39198 Mdot
.924 .39244 Mdot
.924 .39312 Mdot
.924 .39342 Mdot
.924 .39361 Mdot
.924 .39402 Mdot
.924 .39602 Mdot
.924 .39671 Mdot
.924 .39826 Mdot
.924 .39856 Mdot
.924 .39871 Mdot
.924 .39871 Mdot
.924 .40032 Mdot
.924 .40274 Mdot
.924 .40863 Mdot
.924 .4089 Mdot
.924 .40951 Mdot
.924 .41006 Mdot
.924 .41079 Mdot
.924 .41088 Mdot
.924 .41094 Mdot
.924 .41095 Mdot
.924 .411 Mdot
.924 .41142 Mdot
.924 .41187 Mdot
.924 .41192 Mdot
.924 .41195 Mdot
.924 .41249 Mdot
.924 .4125 Mdot
.924 .41328 Mdot
.924 .41412 Mdot
.924 .4143 Mdot
.924 .4148 Mdot
.924 .41509 Mdot
.924 .4151 Mdot
.924 .41513 Mdot
.924 .41517 Mdot
.924 .41529 Mdot
.924 .41545 Mdot
.924 .41559 Mdot
.924 .41571 Mdot
.924 .41574 Mdot
.924 .41603 Mdot
.924 .41732 Mdot
.924 .41736 Mdot
.924 .41819 Mdot
.924 .41879 Mdot
.924 .41964 Mdot
.924 .4203 Mdot
.924 .42115 Mdot
.924 .42138 Mdot
.924 .42148 Mdot
.924 .42181 Mdot
.924 .42286 Mdot
.924 .42363 Mdot
.924 .42375 Mdot
.924 .42378 Mdot
.924 .42404 Mdot
.924 .42428 Mdot
.924 .42464 Mdot
.924 .42562 Mdot
.924 .42583 Mdot
.924 .42676 Mdot
.924 .42693 Mdot
.924 .42743 Mdot
.924 .4277 Mdot
.924 .42811 Mdot
.924 .42841 Mdot
.924 .42843 Mdot
.924 .42877 Mdot
.924 .42905 Mdot
.924 .42935 Mdot
.924 .42949 Mdot
.924 .4295 Mdot
.924 .43044 Mdot
.924 .43066 Mdot
.924 .43112 Mdot
.924 .43153 Mdot
.924 .43176 Mdot
.924 .43359 Mdot
.924 .43396 Mdot
.924 .43434 Mdot
.924 .43516 Mdot
.924 .43537 Mdot
.924 .43578 Mdot
.924 .43579 Mdot
.924 .43631 Mdot
.924 .43641 Mdot
.924 .43756 Mdot
.924 .43806 Mdot
.924 .43818 Mdot
.924 .43847 Mdot
.924 .43974 Mdot
.924 .44075 Mdot
.924 .44245 Mdot
.924 .44259 Mdot
.924 .44283 Mdot
.924 .44399 Mdot
.924 .44402 Mdot
.924 .44443 Mdot
.924 .44501 Mdot
.924 .44556 Mdot
.924 .44603 Mdot
.924 .44606 Mdot
.924 .44725 Mdot
.924 .44783 Mdot
.924 .44805 Mdot
.924 .44811 Mdot
.924 .44878 Mdot
.924 .44904 Mdot
.924 .44931 Mdot
.924 .44974 Mdot
.924 .45018 Mdot
.924 .45254 Mdot
.924 .45268 Mdot
.924 .45354 Mdot
.924 .45459 Mdot
.924 .4558 Mdot
.924 .45602 Mdot
.924 .45624 Mdot
.924 .45651 Mdot
.924 .45688 Mdot
.924 .46102 Mdot
.924 .46164 Mdot
.924 .46184 Mdot
.924 .46265 Mdot
.924 .4627 Mdot
.924 .46295 Mdot
.924 .46316 Mdot
.924 .46325 Mdot
.924 .46365 Mdot
.924 .46489 Mdot
.924 .465 Mdot
.924 .46542 Mdot
.924 .46553 Mdot
.924 .46648 Mdot
.924 .46663 Mdot
.924 .46781 Mdot
.924 .46867 Mdot
.924 .46875 Mdot
.924 .46959 Mdot
.924 .47029 Mdot
.924 .4706 Mdot
.924 .47165 Mdot
.924 .47167 Mdot
.924 .47239 Mdot
.924 .47246 Mdot
.924 .47265 Mdot
.924 .47268 Mdot
.924 .47269 Mdot
.924 .47387 Mdot
.924 .47455 Mdot
.924 .47497 Mdot
.924 .47522 Mdot
.924 .47561 Mdot
.924 .47823 Mdot
.924 .4793 Mdot
.924 .48 Mdot
.924 .48 Mdot
.924 .48007 Mdot
.924 .48087 Mdot
.924 .48118 Mdot
.924 .48222 Mdot
.924 .4823 Mdot
.924 .48243 Mdot
.924 .48272 Mdot
.924 .48292 Mdot
.924 .48311 Mdot
.924 .48365 Mdot
.924 .4838 Mdot
.924 .48575 Mdot
.924 .48594 Mdot
.924 .48682 Mdot
.924 .48683 Mdot
.924 .48753 Mdot
.924 .48753 Mdot
.924 .4877 Mdot
.924 .48788 Mdot
.924 .48926 Mdot
.924 .48951 Mdot
.924 .4899 Mdot
.924 .49037 Mdot
.924 .49052 Mdot
.924 .49354 Mdot
.924 .49392 Mdot
.924 .49405 Mdot
.924 .49416 Mdot
.924 .49459 Mdot
.924 .49486 Mdot
.924 .49504 Mdot
.924 .49535 Mdot
.924 .49558 Mdot
.924 .4957 Mdot
.924 .49602 Mdot
.924 .49655 Mdot
.924 .49722 Mdot
.924 .49724 Mdot
.924 .49747 Mdot
.924 .49795 Mdot
.924 .4984 Mdot
.924 .49894 Mdot
.924 .49898 Mdot
.924 .49945 Mdot
.924 .5001 Mdot
.924 .50013 Mdot
.924 .50053 Mdot
.924 .50082 Mdot
.924 .50132 Mdot
.924 .50159 Mdot
.924 .50235 Mdot
.924 .50305 Mdot
.924 .50339 Mdot
.924 .50377 Mdot
.924 .50454 Mdot
.924 .5049 Mdot
.924 .50546 Mdot
.924 .50583 Mdot
.924 .50623 Mdot
.924 .50628 Mdot
.924 .50647 Mdot
.924 .50665 Mdot
.924 .50714 Mdot
.924 .50763 Mdot
.924 .50922 Mdot
.924 .50971 Mdot
.924 .50972 Mdot
.924 .50988 Mdot
.924 .51022 Mdot
.924 .51048 Mdot
.924 .51149 Mdot
.924 .51189 Mdot
.924 .51248 Mdot
.924 .51372 Mdot
.924 .51461 Mdot
.924 .51462 Mdot
.924 .51581 Mdot
.924 .51588 Mdot
.924 .51658 Mdot
.924 .517 Mdot
.924 .51704 Mdot
.924 .51725 Mdot
.924 .51773 Mdot
.924 .51814 Mdot
.924 .51819 Mdot
.924 .51836 Mdot
.924 .51846 Mdot
.924 .51856 Mdot
.924 .51869 Mdot
.924 .51879 Mdot
.924 .51881 Mdot
.924 .51896 Mdot
.924 .51902 Mdot
.924 .51905 Mdot
.924 .51906 Mdot
.924 .51948 Mdot
.924 .51964 Mdot
.924 .52005 Mdot
.924 .52019 Mdot
.924 .52045 Mdot
.924 .52045 Mdot
.924 .52162 Mdot
.924 .52215 Mdot
.924 .52239 Mdot
.924 .5227 Mdot
.924 .52272 Mdot
.924 .52286 Mdot
.924 .52346 Mdot
.924 .5235 Mdot
.924 .52357 Mdot
.924 .5242 Mdot
.924 .52477 Mdot
.924 .52484 Mdot
.924 .52485 Mdot
.924 .52492 Mdot
.924 .52506 Mdot
.924 .52604 Mdot
.924 .52676 Mdot
.924 .52679 Mdot
.924 .5276 Mdot
.924 .52797 Mdot
.924 .52814 Mdot
.924 .52868 Mdot
.924 .53027 Mdot
.924 .53153 Mdot
.924 .53183 Mdot
.924 .53184 Mdot
.924 .5324 Mdot
.924 .5355 Mdot
.924 .53559 Mdot
.924 .53676 Mdot
.924 .53685 Mdot
.924 .53711 Mdot
.924 .53727 Mdot
.924 .53771 Mdot
.924 .53858 Mdot
.924 .53926 Mdot
.924 .53952 Mdot
.924 .54053 Mdot
.924 .54054 Mdot
.924 .54071 Mdot
.924 .54107 Mdot
.924 .54291 Mdot
.924 .54372 Mdot
.924 .54601 Mdot
.924 .54648 Mdot
.924 .5467 Mdot
.924 .54672 Mdot
.924 .54704 Mdot
.924 .5478 Mdot
.924 .54794 Mdot
.924 .54801 Mdot
.924 .54831 Mdot
.924 .54869 Mdot
.924 .54881 Mdot
.924 .54914 Mdot
.924 .55018 Mdot
.924 .55056 Mdot
.924 .55074 Mdot
.924 .55092 Mdot
.924 .5514 Mdot
.924 .55402 Mdot
.924 .55459 Mdot
.924 .55472 Mdot
.924 .5554 Mdot
.924 .55584 Mdot
.924 .55654 Mdot
.924 .55669 Mdot
.924 .55782 Mdot
.924 .55794 Mdot
.924 .55796 Mdot
.924 .55835 Mdot
.924 .55836 Mdot
.924 .55848 Mdot
.924 .55939 Mdot
.924 .55959 Mdot
.924 .5596 Mdot
.924 .55998 Mdot
.924 .56039 Mdot
.924 .56075 Mdot
.924 .56137 Mdot
.924 .56211 Mdot
.924 .56343 Mdot
.924 .56348 Mdot
.924 .56404 Mdot
.924 .56404 Mdot
.924 .56488 Mdot
.924 .56497 Mdot
.924 .56587 Mdot
.924 .5662 Mdot
.924 .56638 Mdot
.924 .56682 Mdot
.924 .56721 Mdot
.924 .56755 Mdot
.924 .56796 Mdot
.924 .56828 Mdot
.924 .56847 Mdot
.924 .56861 Mdot
.924 .56885 Mdot
.924 .5702 Mdot
.924 .57073 Mdot
.924 .57171 Mdot
.924 .57192 Mdot
.924 .57226 Mdot
.924 .57297 Mdot
.924 .57322 Mdot
.924 .57342 Mdot
.924 .57369 Mdot
.924 .57421 Mdot
.924 .57471 Mdot
.924 .57503 Mdot
.924 .57557 Mdot
.924 .57558 Mdot
.924 .57598 Mdot
.924 .57619 Mdot
.924 .57674 Mdot
.924 .57687 Mdot
.924 .57708 Mdot
.924 .57743 Mdot
.924 .57752 Mdot
.924 .57765 Mdot
.924 .5782 Mdot
.924 .57858 Mdot
.924 .57875 Mdot
.924 .57878 Mdot
.924 .57879 Mdot
.924 .57916 Mdot
.924 .57964 Mdot
.924 .57966 Mdot
.924 .57993 Mdot
.924 .58021 Mdot
.924 .58063 Mdot
.924 .58145 Mdot
.924 .5815 Mdot
.924 .58178 Mdot
.924 .58185 Mdot
.924 .58219 Mdot
.924 .58231 Mdot
.924 .58242 Mdot
.924 .58261 Mdot
.924 .58312 Mdot
.924 .58316 Mdot
.924 .58373 Mdot
.924 .58386 Mdot
.924 .58412 Mdot
.924 .58417 Mdot
.924 .58478 Mdot
.924 .58487 Mdot
.924 .58488 Mdot
.924 .58493 Mdot
.924 .58512 Mdot
.924 .5857 Mdot
.924 .58595 Mdot
.924 .58608 Mdot
.924 .58646 Mdot
.924 .58691 Mdot
.924 .58725 Mdot
.924 .5873 Mdot
.924 .58751 Mdot
.924 .58755 Mdot
.924 .58769 Mdot
.924 .58772 Mdot
.924 .58777 Mdot
.924 .58787 Mdot
.924 .58841 Mdot
.924 .58855 Mdot
.924 .58856 Mdot
.924 .58891 Mdot
.924 .58946 Mdot
.924 .58949 Mdot
.924 .58963 Mdot
.924 .58971 Mdot
.924 .58972 Mdot
.924 .58979 Mdot
.924 .5898 Mdot
.924 .58981 Mdot
.924 .58994 Mdot
.924 .59009 Mdot
.924 .59017 Mdot
.924 .59021 Mdot
.924 .59035 Mdot
.924 .59037 Mdot
.924 .59048 Mdot
.924 .59053 Mdot
.924 .5906 Mdot
.924 .59092 Mdot
.924 .59094 Mdot
.924 .59097 Mdot
.924 .59098 Mdot
.924 .59101 Mdot
.924 .59132 Mdot
.924 .59133 Mdot
.924 .59151 Mdot
.924 .59162 Mdot
.924 .59164 Mdot
.924 .59187 Mdot
.924 .592 Mdot
.924 .59204 Mdot
.924 .59226 Mdot
.924 .5924 Mdot
.924 .59242 Mdot
.924 .59243 Mdot
.924 .5927 Mdot
.924 .59271 Mdot
.924 .5928 Mdot
.924 .59283 Mdot
.924 .59298 Mdot
.924 .59305 Mdot
.924 .59309 Mdot
.924 .59309 Mdot
.924 .59311 Mdot
.924 .59313 Mdot
.924 .59316 Mdot
.924 .59322 Mdot
.924 .59323 Mdot
.924 .59323 Mdot
.924 .5933 Mdot
.924 .59348 Mdot
.924 .59355 Mdot
.924 .59356 Mdot
.924 .59371 Mdot
.924 .59371 Mdot
.924 .59372 Mdot
.924 .59373 Mdot
.924 .59375 Mdot
.924 .59378 Mdot
.924 .59381 Mdot
.924 .59381 Mdot
.924 .59385 Mdot
.924 .59389 Mdot
.924 .59391 Mdot
.924 .59392 Mdot
.924 .59395 Mdot
.924 .594 Mdot
.924 .59401 Mdot
.924 .59412 Mdot
.924 .59419 Mdot
.924 .59421 Mdot
.924 .59422 Mdot
.924 .59422 Mdot
.924 .59423 Mdot
.924 .59425 Mdot
.924 .59426 Mdot
.924 .59431 Mdot
.924 .59433 Mdot
.924 .59433 Mdot
.924 .59435 Mdot
.924 .59437 Mdot
.924 .59437 Mdot
.924 .59437 Mdot
.926 .04854 Mdot
.926 .04856 Mdot
.926 .04856 Mdot
.926 .04858 Mdot
.926 .04865 Mdot
.926 .04866 Mdot
.926 .04872 Mdot
.926 .0488 Mdot
.926 .04895 Mdot
.926 .04917 Mdot
.926 .04936 Mdot
.926 .04966 Mdot
.926 .04966 Mdot
.926 .04982 Mdot
.926 .04994 Mdot
.926 .05006 Mdot
.926 .05061 Mdot
.926 .05078 Mdot
.926 .05093 Mdot
.926 .05103 Mdot
.926 .05105 Mdot
.926 .05131 Mdot
.926 .05133 Mdot
.926 .05143 Mdot
.926 .0515 Mdot
.926 .05165 Mdot
.926 .05214 Mdot
.926 .05224 Mdot
.926 .05232 Mdot
.926 .05379 Mdot
.926 .05381 Mdot
.926 .05383 Mdot
.926 .05394 Mdot
.926 .05404 Mdot
.926 .05405 Mdot
.926 .05452 Mdot
.926 .05459 Mdot
.926 .05484 Mdot
.926 .05503 Mdot
.926 .05574 Mdot
.926 .05729 Mdot
.926 .05745 Mdot
.926 .05762 Mdot
.926 .0579 Mdot
.926 .05801 Mdot
.926 .05802 Mdot
.926 .05812 Mdot
.926 .05863 Mdot
.926 .05866 Mdot
.926 .05936 Mdot
.926 .0599 Mdot
.926 .05999 Mdot
.926 .06051 Mdot
.926 .06056 Mdot
.926 .06065 Mdot
.926 .06123 Mdot
.926 .06126 Mdot
.926 .06172 Mdot
.926 .06266 Mdot
.926 .06307 Mdot
.926 .06317 Mdot
.926 .06542 Mdot
.926 .06592 Mdot
.926 .0661 Mdot
.926 .06637 Mdot
.926 .06645 Mdot
.926 .06745 Mdot
.926 .06858 Mdot
.926 .06904 Mdot
.926 .06944 Mdot
.926 .06962 Mdot
.926 .07131 Mdot
.926 .0715 Mdot
.926 .07221 Mdot
.926 .07233 Mdot
.926 .07242 Mdot
.926 .0728 Mdot
.926 .07319 Mdot
.926 .07347 Mdot
.926 .07713 Mdot
.926 .07748 Mdot
.926 .07802 Mdot
.926 .07804 Mdot
.926 .0788 Mdot
.926 .07883 Mdot
.926 .07952 Mdot
.926 .08085 Mdot
.926 .08147 Mdot
.926 .08164 Mdot
.926 .08301 Mdot
.926 .08553 Mdot
.926 .08589 Mdot
.926 .08796 Mdot
.926 .08801 Mdot
.926 .08905 Mdot
.926 .08951 Mdot
.926 .08992 Mdot
.926 .09018 Mdot
.926 .09031 Mdot
.926 .09058 Mdot
.926 .09065 Mdot
.926 .09158 Mdot
.926 .09191 Mdot
.926 .09256 Mdot
.926 .09318 Mdot
.926 .09413 Mdot
.926 .09516 Mdot
.926 .09583 Mdot
.926 .09734 Mdot
.926 .09823 Mdot
.926 .09982 Mdot
.926 .1001 Mdot
.926 .10394 Mdot
.926 .10529 Mdot
.926 .10577 Mdot
.926 .10781 Mdot
.926 .10825 Mdot
.926 .10943 Mdot
.926 .10982 Mdot
.926 .11048 Mdot
.926 .11599 Mdot
.926 .11692 Mdot
.926 .11734 Mdot
.926 .11764 Mdot
.926 .11872 Mdot
.926 .11912 Mdot
.926 .12405 Mdot
.926 .12636 Mdot
.926 .12693 Mdot
.926 .1273 Mdot
.926 .12813 Mdot
.926 .12985 Mdot
.926 .13069 Mdot
.926 .13121 Mdot
.926 .13428 Mdot
.926 .13518 Mdot
.926 .13784 Mdot
.926 .13798 Mdot
.926 .13836 Mdot
.926 .13842 Mdot
.926 .13984 Mdot
.926 .14035 Mdot
.926 .14041 Mdot
.926 .14043 Mdot
.926 .14049 Mdot
.926 .14075 Mdot
.926 .14078 Mdot
.926 .14098 Mdot
.926 .14107 Mdot
.926 .14128 Mdot
.926 .14158 Mdot
.926 .14178 Mdot
.926 .14256 Mdot
.926 .14316 Mdot
.926 .14321 Mdot
.926 .14404 Mdot
.926 .14426 Mdot
.926 .14427 Mdot
.926 .14463 Mdot
.926 .14482 Mdot
.926 .14523 Mdot
.926 .14532 Mdot
.926 .14565 Mdot
.926 .14615 Mdot
.926 .14721 Mdot
.926 .14756 Mdot
.926 .14813 Mdot
.926 .14866 Mdot
.926 .14901 Mdot
.926 .14906 Mdot
.926 .14991 Mdot
.926 .14996 Mdot
.926 .15004 Mdot
.926 .15038 Mdot
.926 .15062 Mdot
.926 .15112 Mdot
.926 .15115 Mdot
.926 .15284 Mdot
.926 .15316 Mdot
.926 .15333 Mdot
.926 .15346 Mdot
.926 .15519 Mdot
.926 .15596 Mdot
.926 .15752 Mdot
.926 .15849 Mdot
.926 .15856 Mdot
.926 .15864 Mdot
.926 .15898 Mdot
.926 .15935 Mdot
.926 .15939 Mdot
.926 .1598 Mdot
.926 .16018 Mdot
.926 .16097 Mdot
.926 .16113 Mdot
.926 .16123 Mdot
.926 .16207 Mdot
.926 .16271 Mdot
.926 .16272 Mdot
.926 .16415 Mdot
.926 .1643 Mdot
.926 .16442 Mdot
.926 .16514 Mdot
.926 .16687 Mdot
.926 .16787 Mdot
.926 .16848 Mdot
.926 .16893 Mdot
.926 .17035 Mdot
.926 .1709 Mdot
.926 .17149 Mdot
.926 .17184 Mdot
.926 .17209 Mdot
.926 .1724 Mdot
.926 .17276 Mdot
.926 .1728 Mdot
.926 .1728 Mdot
.926 .17287 Mdot
.926 .17314 Mdot
.926 .17487 Mdot
.926 .17497 Mdot
.926 .1754 Mdot
.926 .17732 Mdot
.926 .1774 Mdot
.926 .17748 Mdot
.926 .17896 Mdot
.926 .17912 Mdot
.926 .1794 Mdot
.926 .17948 Mdot
.926 .18028 Mdot
.926 .18108 Mdot
.926 .18116 Mdot
.926 .18133 Mdot
.926 .18161 Mdot
.926 .18207 Mdot
.926 .1833 Mdot
.926 .18355 Mdot
.926 .18362 Mdot
.926 .18516 Mdot
.926 .18579 Mdot
.926 .18651 Mdot
.926 .18828 Mdot
.926 .18963 Mdot
.926 .18994 Mdot
.926 .19044 Mdot
.926 .19278 Mdot
.926 .19389 Mdot
.926 .19513 Mdot
.926 .19671 Mdot
.926 .19733 Mdot
.926 .19894 Mdot
.926 .19955 Mdot
.926 .20042 Mdot
.926 .2006 Mdot
.926 .20067 Mdot
.926 .20088 Mdot
.926 .20393 Mdot
.926 .2042 Mdot
.926 .20498 Mdot
.926 .20533 Mdot
.926 .20756 Mdot
.926 .20906 Mdot
.926 .21034 Mdot
.926 .21068 Mdot
.926 .21092 Mdot
.926 .21161 Mdot
.926 .21386 Mdot
.926 .21629 Mdot
.926 .21648 Mdot
.926 .21692 Mdot
.926 .21712 Mdot
.926 .21728 Mdot
.926 .21768 Mdot
.926 .21793 Mdot
.926 .21836 Mdot
.926 .21915 Mdot
.926 .21953 Mdot
.926 .21983 Mdot
.926 .221 Mdot
.926 .22102 Mdot
.926 .22178 Mdot
.926 .22227 Mdot
.926 .22315 Mdot
.926 .22388 Mdot
.926 .22417 Mdot
.926 .22422 Mdot
.926 .22513 Mdot
.926 .22601 Mdot
.926 .22879 Mdot
.926 .22887 Mdot
.926 .23045 Mdot
.926 .2332 Mdot
.926 .23431 Mdot
.926 .23461 Mdot
.926 .23525 Mdot
.926 .2357 Mdot
.926 .23573 Mdot
.926 .23736 Mdot
.926 .23744 Mdot
.926 .23848 Mdot
.926 .23868 Mdot
.926 .23899 Mdot
.926 .23977 Mdot
.926 .23985 Mdot
.926 .24031 Mdot
.926 .24124 Mdot
.926 .24198 Mdot
.926 .24275 Mdot
.926 .24336 Mdot
.926 .24409 Mdot
.926 .24577 Mdot
.926 .24605 Mdot
.926 .24629 Mdot
.926 .24649 Mdot
.926 .24752 Mdot
.926 .24795 Mdot
.926 .24847 Mdot
.926 .24865 Mdot
.926 .25123 Mdot
.926 .25217 Mdot
.926 .25262 Mdot
.926 .25561 Mdot
.926 .25577 Mdot
.926 .25619 Mdot
.926 .25631 Mdot
.926 .25685 Mdot
.926 .25909 Mdot
.926 .25937 Mdot
.926 .26021 Mdot
.926 .26109 Mdot
.926 .26129 Mdot
.926 .26188 Mdot
.926 .26359 Mdot
.926 .26371 Mdot
.926 .26444 Mdot
.926 .26636 Mdot
.926 .26712 Mdot
.926 .26743 Mdot
.926 .2676 Mdot
.926 .26805 Mdot
.926 .26809 Mdot
.926 .26938 Mdot
.926 .27067 Mdot
.926 .27202 Mdot
.926 .27322 Mdot
.926 .27398 Mdot
.926 .27438 Mdot
.926 .27439 Mdot
.926 .27485 Mdot
.926 .27516 Mdot
.926 .27537 Mdot
.926 .27806 Mdot
.926 .2783 Mdot
.926 .27904 Mdot
.926 .28017 Mdot
.926 .2803 Mdot
.926 .28058 Mdot
.926 .28091 Mdot
.926 .28251 Mdot
.926 .28272 Mdot
.926 .28503 Mdot
.926 .28511 Mdot
.926 .28545 Mdot
.926 .28668 Mdot
.926 .28728 Mdot
.926 .28781 Mdot
.926 .2884 Mdot
.926 .28911 Mdot
.926 .28963 Mdot
.926 .28973 Mdot
.926 .28985 Mdot
.926 .29032 Mdot
.926 .29049 Mdot
.926 .29306 Mdot
.926 .29361 Mdot
.926 .29461 Mdot
.926 .29464 Mdot
.926 .29467 Mdot
.926 .29698 Mdot
.926 .29713 Mdot
.926 .29825 Mdot
.926 .29838 Mdot
.926 .2991 Mdot
.926 .29913 Mdot
.926 .30161 Mdot
.926 .30193 Mdot
.926 .30239 Mdot
.926 .30634 Mdot
.926 .30688 Mdot
.926 .30772 Mdot
.926 .30802 Mdot
.926 .30874 Mdot
.926 .30993 Mdot
.926 .31124 Mdot
.926 .31226 Mdot
.926 .31304 Mdot
.926 .314 Mdot
.926 .31469 Mdot
.926 .31566 Mdot
.926 .31674 Mdot
.926 .31803 Mdot
.926 .31838 Mdot
.926 .3187 Mdot
.926 .31943 Mdot
.926 .31947 Mdot
.926 .32006 Mdot
.926 .32119 Mdot
.926 .32356 Mdot
.926 .3237 Mdot
.926 .32372 Mdot
.926 .32433 Mdot
.926 .32474 Mdot
.926 .32582 Mdot
.926 .3279 Mdot
.926 .3283 Mdot
.926 .32895 Mdot
.926 .33014 Mdot
.926 .33071 Mdot
.926 .33083 Mdot
.926 .33137 Mdot
.926 .33178 Mdot
.926 .3348 Mdot
.926 .33518 Mdot
.926 .33558 Mdot
.926 .33632 Mdot
.926 .33913 Mdot
.926 .33959 Mdot
.926 .33967 Mdot
.926 .34023 Mdot
.926 .34041 Mdot
.926 .3432 Mdot
.926 .34516 Mdot
.926 .34525 Mdot
.926 .34755 Mdot
.926 .34862 Mdot
.926 .34918 Mdot
.926 .34941 Mdot
.926 .34962 Mdot
.926 .34974 Mdot
.926 .34981 Mdot
.926 .35122 Mdot
.926 .35216 Mdot
.926 .35248 Mdot
.926 .35318 Mdot
.926 .358 Mdot
.926 .3585 Mdot
.926 .36155 Mdot
.926 .36433 Mdot
.926 .3652 Mdot
.926 .36555 Mdot
.926 .3665 Mdot
.926 .36699 Mdot
.926 .36811 Mdot
.926 .36843 Mdot
.926 .36943 Mdot
.926 .36958 Mdot
.926 .37069 Mdot
.926 .37124 Mdot
.926 .37262 Mdot
.926 .37353 Mdot
.926 .37554 Mdot
.926 .37691 Mdot
.926 .37722 Mdot
.926 .37823 Mdot
.926 .37969 Mdot
.926 .38088 Mdot
.926 .38092 Mdot
.926 .38169 Mdot
.926 .38294 Mdot
.926 .38318 Mdot
.926 .38409 Mdot
.926 .38505 Mdot
.926 .38621 Mdot
.926 .38689 Mdot
.926 .38722 Mdot
.926 .38804 Mdot
.926 .39019 Mdot
.926 .39041 Mdot
.926 .39051 Mdot
.926 .39228 Mdot
.926 .39364 Mdot
.926 .39397 Mdot
.926 .39404 Mdot
.926 .3951 Mdot
.926 .39567 Mdot
.926 .39575 Mdot
.926 .39601 Mdot
.926 .39746 Mdot
.926 .39843 Mdot
.926 .39875 Mdot
.926 .39962 Mdot
.926 .39975 Mdot
.926 .40169 Mdot
.926 .40201 Mdot
.926 .40231 Mdot
.926 .40299 Mdot
.926 .40324 Mdot
.926 .40413 Mdot
.926 .40428 Mdot
.926 .40432 Mdot
.926 .40446 Mdot
.926 .40504 Mdot
.926 .40511 Mdot
.926 .40556 Mdot
.926 .40576 Mdot
.926 .4062 Mdot
.926 .40623 Mdot
.926 .40692 Mdot
.926 .40736 Mdot
.926 .40909 Mdot
.926 .40997 Mdot
.926 .41045 Mdot
.926 .41055 Mdot
.926 .41104 Mdot
.926 .41167 Mdot
.926 .41169 Mdot
.926 .41209 Mdot
.926 .41224 Mdot
.926 .41238 Mdot
.926 .41283 Mdot
.926 .41286 Mdot
.926 .41289 Mdot
.926 .4137 Mdot
.926 .41409 Mdot
.926 .41468 Mdot
.926 .415 Mdot
.926 .41503 Mdot
.926 .41521 Mdot
.926 .41522 Mdot
.926 .41592 Mdot
.926 .41702 Mdot
.926 .41791 Mdot
.926 .41823 Mdot
.926 .41892 Mdot
.926 .41933 Mdot
.926 .42 Mdot
.926 .42008 Mdot
.926 .42026 Mdot
.926 .42027 Mdot
.926 .42042 Mdot
.926 .42132 Mdot
.926 .42147 Mdot
.926 .42184 Mdot
.926 .42245 Mdot
.926 .42308 Mdot
.926 .42321 Mdot
.926 .42331 Mdot
.926 .42405 Mdot
.926 .42443 Mdot
.926 .42512 Mdot
.926 .42523 Mdot
.926 .42539 Mdot
.926 .42543 Mdot
.926 .42612 Mdot
.926 .42662 Mdot
.926 .4277 Mdot
.926 .42773 Mdot
.926 .42774 Mdot
.926 .42988 Mdot
.926 .43063 Mdot
.926 .43131 Mdot
.926 .43184 Mdot
.926 .43197 Mdot
.926 .43232 Mdot
.926 .43257 Mdot
.926 .4326 Mdot
.926 .43539 Mdot
.926 .4354 Mdot
.926 .43618 Mdot
.926 .43716 Mdot
.926 .43777 Mdot
.926 .43865 Mdot
.926 .43906 Mdot
.926 .43914 Mdot
.926 .4395 Mdot
.926 .44094 Mdot
.926 .44168 Mdot
.926 .4429 Mdot
.926 .44306 Mdot
.926 .4432 Mdot
.926 .44335 Mdot
.926 .44382 Mdot
.926 .4439 Mdot
.926 .44395 Mdot
.926 .44463 Mdot
.926 .44471 Mdot
.926 .44554 Mdot
.926 .44629 Mdot
.926 .44787 Mdot
.926 .44819 Mdot
.926 .44837 Mdot
.926 .4491 Mdot
.926 .44994 Mdot
.926 .45005 Mdot
.926 .45007 Mdot
.926 .45073 Mdot
.926 .45129 Mdot
.926 .45132 Mdot
.926 .45267 Mdot
.926 .45293 Mdot
.926 .4531 Mdot
.926 .45368 Mdot
.926 .4541 Mdot
.926 .4544 Mdot
.926 .45449 Mdot
.926 .45462 Mdot
.926 .45561 Mdot
.926 .45595 Mdot
.926 .45601 Mdot
.926 .45644 Mdot
.926 .45902 Mdot
.926 .45909 Mdot
.926 .45932 Mdot
.926 .46015 Mdot
.926 .46122 Mdot
.926 .4614 Mdot
.926 .46144 Mdot
.926 .46164 Mdot
.926 .46237 Mdot
.926 .46322 Mdot
.926 .46323 Mdot
.926 .46459 Mdot
.926 .46494 Mdot
.926 .46552 Mdot
.926 .46587 Mdot
.926 .46689 Mdot
.926 .46798 Mdot
.926 .46845 Mdot
.926 .46862 Mdot
.926 .46908 Mdot
.926 .46965 Mdot
.926 .46983 Mdot
.926 .47032 Mdot
.926 .47038 Mdot
.926 .47039 Mdot
.926 .47051 Mdot
.926 .47101 Mdot
.926 .47132 Mdot
.926 .47147 Mdot
.926 .47271 Mdot
.926 .47279 Mdot
.926 .47295 Mdot
.926 .47379 Mdot
.926 .47406 Mdot
.926 .47413 Mdot
.926 .47431 Mdot
.926 .47431 Mdot
.926 .4746 Mdot
.926 .47508 Mdot
.926 .47677 Mdot
.926 .47808 Mdot
.926 .47849 Mdot
.926 .47862 Mdot
.926 .47877 Mdot
.926 .48062 Mdot
.926 .48124 Mdot
.926 .48136 Mdot
.926 .48139 Mdot
.926 .48164 Mdot
.926 .4821 Mdot
.926 .48213 Mdot
.926 .48227 Mdot
.926 .48362 Mdot
.926 .48366 Mdot
.926 .48467 Mdot
.926 .48502 Mdot
.926 .48515 Mdot
.926 .48544 Mdot
.926 .48594 Mdot
.926 .48634 Mdot
.926 .48672 Mdot
.926 .48767 Mdot
.926 .48768 Mdot
.926 .48879 Mdot
.926 .48921 Mdot
.926 .48934 Mdot
.926 .4919 Mdot
.926 .49235 Mdot
.926 .49241 Mdot
.926 .49282 Mdot
.926 .49295 Mdot
.926 .4934 Mdot
.926 .4936 Mdot
.926 .49412 Mdot
.926 .49448 Mdot
.926 .49559 Mdot
.926 .49681 Mdot
.926 .49701 Mdot
.926 .49919 Mdot
.926 .49968 Mdot
.926 .50023 Mdot
.926 .50026 Mdot
.926 .50031 Mdot
.926 .50048 Mdot
.926 .502 Mdot
.926 .5028 Mdot
.926 .50387 Mdot
.926 .50394 Mdot
.926 .50415 Mdot
.926 .50418 Mdot
.926 .50436 Mdot
.926 .50543 Mdot
.926 .50586 Mdot
.926 .50601 Mdot
.926 .50715 Mdot
.926 .5073 Mdot
.926 .50751 Mdot
.926 .50777 Mdot
.926 .50846 Mdot
.926 .50938 Mdot
.926 .50994 Mdot
.926 .51016 Mdot
.926 .51017 Mdot
.926 .5111 Mdot
.926 .51152 Mdot
.926 .51174 Mdot
.926 .51175 Mdot
.926 .51202 Mdot
.926 .51214 Mdot
.926 .51313 Mdot
.926 .51349 Mdot
.926 .51374 Mdot
.926 .51437 Mdot
.926 .51475 Mdot
.926 .51522 Mdot
.926 .51565 Mdot
.926 .51591 Mdot
.926 .51602 Mdot
.926 .51632 Mdot
.926 .51652 Mdot
.926 .5181 Mdot
.926 .5191 Mdot
.926 .5191 Mdot
.926 .51936 Mdot
.926 .51941 Mdot
.926 .51986 Mdot
.926 .52067 Mdot
.926 .52069 Mdot
.926 .52105 Mdot
.926 .52124 Mdot
.926 .52214 Mdot
.926 .52237 Mdot
.926 .52241 Mdot
.926 .52245 Mdot
.926 .52263 Mdot
.926 .52308 Mdot
.926 .52327 Mdot
.926 .52348 Mdot
.926 .52402 Mdot
.926 .52405 Mdot
.926 .52492 Mdot
.926 .52559 Mdot
.926 .52569 Mdot
.926 .52573 Mdot
.926 .52637 Mdot
.926 .52756 Mdot
.926 .52771 Mdot
.926 .52942 Mdot
.926 .52986 Mdot
.926 .52987 Mdot
.926 .53018 Mdot
.926 .53044 Mdot
.926 .53109 Mdot
.926 .53133 Mdot
.926 .53137 Mdot
.926 .53194 Mdot
.926 .53221 Mdot
.926 .53278 Mdot
.926 .53288 Mdot
.926 .53362 Mdot
.926 .5338 Mdot
.926 .53384 Mdot
.926 .53398 Mdot
.926 .53404 Mdot
.926 .53517 Mdot
.926 .53548 Mdot
.926 .53633 Mdot
.926 .5367 Mdot
.926 .53704 Mdot
.926 .53711 Mdot
.926 .53728 Mdot
.926 .53783 Mdot
.926 .53806 Mdot
.926 .53826 Mdot
.926 .53875 Mdot
.926 .53906 Mdot
.926 .53948 Mdot
.926 .53959 Mdot
.926 .53965 Mdot
.926 .54054 Mdot
.926 .54069 Mdot
.926 .541 Mdot
.926 .54135 Mdot
.926 .54223 Mdot
.926 .54274 Mdot
.926 .54277 Mdot
.926 .54365 Mdot
.926 .54393 Mdot
.926 .54422 Mdot
.926 .54424 Mdot
.926 .54433 Mdot
.926 .545 Mdot
.926 .54524 Mdot
.926 .54607 Mdot
.926 .54621 Mdot
.926 .54629 Mdot
.926 .54642 Mdot
.926 .54647 Mdot
.926 .54667 Mdot
.926 .54749 Mdot
.926 .54819 Mdot
.926 .54848 Mdot
.926 .55015 Mdot
.926 .55025 Mdot
.926 .5505 Mdot
.926 .55152 Mdot
.926 .55161 Mdot
.926 .5528 Mdot
.926 .55329 Mdot
.926 .55366 Mdot
.926 .554 Mdot
.926 .55471 Mdot
.926 .55591 Mdot
.926 .55612 Mdot
.926 .55688 Mdot
.926 .55724 Mdot
.926 .55754 Mdot
.926 .55778 Mdot
.926 .55802 Mdot
.926 .55818 Mdot
.926 .55862 Mdot
.926 .55865 Mdot
.926 .55924 Mdot
.926 .56 Mdot
.926 .56003 Mdot
.926 .56023 Mdot
.926 .5603 Mdot
.926 .56117 Mdot
.926 .5613 Mdot
.926 .56148 Mdot
.926 .56178 Mdot
.926 .5625 Mdot
.926 .56253 Mdot
.926 .56258 Mdot
.926 .563 Mdot
.926 .56347 Mdot
.926 .56375 Mdot
.926 .56386 Mdot
.926 .56453 Mdot
.926 .56498 Mdot
.926 .5652 Mdot
.926 .56575 Mdot
.926 .56639 Mdot
.926 .56674 Mdot
.926 .56752 Mdot
.926 .56783 Mdot
.926 .56806 Mdot
.926 .56826 Mdot
.926 .56844 Mdot
.926 .56869 Mdot
.926 .56914 Mdot
.926 .56929 Mdot
.926 .56964 Mdot
.926 .57005 Mdot
.926 .57006 Mdot
.926 .57017 Mdot
.926 .57021 Mdot
.926 .57097 Mdot
.926 .57123 Mdot
.926 .5721 Mdot
.926 .57225 Mdot
.926 .57249 Mdot
.926 .57298 Mdot
.926 .57321 Mdot
.926 .57331 Mdot
.926 .57347 Mdot
.926 .57413 Mdot
.926 .57551 Mdot
.926 .57562 Mdot
.926 .57593 Mdot
.926 .57601 Mdot
.926 .57613 Mdot
.926 .57639 Mdot
.926 .57792 Mdot
.926 .57811 Mdot
.926 .57821 Mdot
.926 .57854 Mdot
.926 .57866 Mdot
.926 .57923 Mdot
.926 .57936 Mdot
.926 .57973 Mdot
.926 .58079 Mdot
.926 .58087 Mdot
.926 .5813 Mdot
.926 .58155 Mdot
.926 .58196 Mdot
.926 .58214 Mdot
.926 .58243 Mdot
.926 .58268 Mdot
.926 .58285 Mdot
.926 .58303 Mdot
.926 .58312 Mdot
.926 .58337 Mdot
.926 .58339 Mdot
.926 .58347 Mdot
.926 .5835 Mdot
.926 .58357 Mdot
.926 .58368 Mdot
.926 .58381 Mdot
.926 .58409 Mdot
.926 .58411 Mdot
.926 .58467 Mdot
.926 .58476 Mdot
.926 .58545 Mdot
.926 .58582 Mdot
.926 .58586 Mdot
.926 .58603 Mdot
.926 .58639 Mdot
.926 .58657 Mdot
.926 .58658 Mdot
.926 .58678 Mdot
.926 .58679 Mdot
.926 .58693 Mdot
.926 .58703 Mdot
.926 .58801 Mdot
.926 .58809 Mdot
.926 .58819 Mdot
.926 .58829 Mdot
.926 .58832 Mdot
.926 .58835 Mdot
.926 .58854 Mdot
.926 .58859 Mdot
.926 .58904 Mdot
.926 .58909 Mdot
.926 .58919 Mdot
.926 .58932 Mdot
.926 .58962 Mdot
.926 .58988 Mdot
.926 .58991 Mdot
.926 .58998 Mdot
.926 .59003 Mdot
.926 .59016 Mdot
.926 .59076 Mdot
.926 .59078 Mdot
.926 .59089 Mdot
.926 .59114 Mdot
.926 .59126 Mdot
.926 .59127 Mdot
.926 .59142 Mdot
.926 .59145 Mdot
.926 .59146 Mdot
.926 .5916 Mdot
.926 .59162 Mdot
.926 .59176 Mdot
.926 .59195 Mdot
.926 .59196 Mdot
.926 .59209 Mdot
.926 .59212 Mdot
.926 .59212 Mdot
.926 .59215 Mdot
.926 .59222 Mdot
.926 .59227 Mdot
.926 .59231 Mdot
.926 .59272 Mdot
.926 .5929 Mdot
.926 .59295 Mdot
.926 .59302 Mdot
.926 .59304 Mdot
.926 .59316 Mdot
.926 .59316 Mdot
.926 .59319 Mdot
.926 .59322 Mdot
.926 .59322 Mdot
.926 .59323 Mdot
.926 .59362 Mdot
.926 .59364 Mdot
.926 .59366 Mdot
.926 .59379 Mdot
.926 .59383 Mdot
.926 .59385 Mdot
.926 .59388 Mdot
.926 .59388 Mdot
.926 .59395 Mdot
.926 .59395 Mdot
.926 .59398 Mdot
.926 .59402 Mdot
.926 .59406 Mdot
.926 .59421 Mdot
.926 .59424 Mdot
.926 .59427 Mdot
.926 .59431 Mdot
.926 .59431 Mdot
.926 .59439 Mdot
.926 .59444 Mdot
.926 .5945 Mdot
.926 .59454 Mdot
.926 .59456 Mdot
.926 .59457 Mdot
.926 .59458 Mdot
.926 .5946 Mdot
.926 .5946 Mdot
.926 .5946 Mdot
.926 .59461 Mdot
.928 .04784 Mdot
.928 .04791 Mdot
.928 .04812 Mdot
.928 .04813 Mdot
.928 .04825 Mdot
.928 .04842 Mdot
.928 .04893 Mdot
.928 .04914 Mdot
.928 .04916 Mdot
.928 .04941 Mdot
.928 .04951 Mdot
.928 .04967 Mdot
.928 .05017 Mdot
.928 .05043 Mdot
.928 .05064 Mdot
.928 .05065 Mdot
.928 .05085 Mdot
.928 .05103 Mdot
.928 .05141 Mdot
.928 .05174 Mdot
.928 .05175 Mdot
.928 .05315 Mdot
.928 .05332 Mdot
.928 .05338 Mdot
.928 .0535 Mdot
.928 .05366 Mdot
.928 .05378 Mdot
.928 .05379 Mdot
.928 .05381 Mdot
.928 .05442 Mdot
.928 .05452 Mdot
.928 .05486 Mdot
.928 .05564 Mdot
.928 .05575 Mdot
.928 .05606 Mdot
.928 .05625 Mdot
.928 .05859 Mdot
.928 .05895 Mdot
.928 .05976 Mdot
.928 .05983 Mdot
.928 .06017 Mdot
.928 .06077 Mdot
.928 .06107 Mdot
.928 .06119 Mdot
.928 .06147 Mdot
.928 .06149 Mdot
.928 .06158 Mdot
.928 .06197 Mdot
.928 .06233 Mdot
.928 .06271 Mdot
.928 .06327 Mdot
.928 .06394 Mdot
.928 .06399 Mdot
.928 .06422 Mdot
.928 .06431 Mdot
.928 .06445 Mdot
.928 .06512 Mdot
.928 .06513 Mdot
.928 .06597 Mdot
.928 .06608 Mdot
.928 .06688 Mdot
.928 .06826 Mdot
.928 .06837 Mdot
.928 .06891 Mdot
.928 .06915 Mdot
.928 .0695 Mdot
.928 .06953 Mdot
.928 .07128 Mdot
.928 .07133 Mdot
.928 .07141 Mdot
.928 .07236 Mdot
.928 .07324 Mdot
.928 .0733 Mdot
.928 .07458 Mdot
.928 .07491 Mdot
.928 .07558 Mdot
.928 .0765 Mdot
.928 .07673 Mdot
.928 .07764 Mdot
.928 .07769 Mdot
.928 .07808 Mdot
.928 .07828 Mdot
.928 .07937 Mdot
.928 .07992 Mdot
.928 .08183 Mdot
.928 .08187 Mdot
.928 .08243 Mdot
.928 .08261 Mdot
.928 .08311 Mdot
.928 .08399 Mdot
.928 .08443 Mdot
.928 .08482 Mdot
.928 .08521 Mdot
.928 .08522 Mdot
.928 .08776 Mdot
.928 .08828 Mdot
.928 .08893 Mdot
.928 .08907 Mdot
.928 .0899 Mdot
.928 .09001 Mdot
.928 .09022 Mdot
.928 .09026 Mdot
.928 .09097 Mdot
.928 .09124 Mdot
.928 .09168 Mdot
.928 .09209 Mdot
.928 .09349 Mdot
.928 .09659 Mdot
.928 .09704 Mdot
.928 .09856 Mdot
.928 .09925 Mdot
.928 .09946 Mdot
.928 .10087 Mdot
.928 .10443 Mdot
.928 .10523 Mdot
.928 .10624 Mdot
.928 .10811 Mdot
.928 .10898 Mdot
.928 .1091 Mdot
.928 .1105 Mdot
.928 .11181 Mdot
.928 .11194 Mdot
.928 .11481 Mdot
.928 .11632 Mdot
.928 .11682 Mdot
.928 .1169 Mdot
.928 .11741 Mdot
.928 .11783 Mdot
.928 .11817 Mdot
.928 .1206 Mdot
.928 .12265 Mdot
.928 .12369 Mdot
.928 .12455 Mdot
.928 .12512 Mdot
.928 .12637 Mdot
.928 .12641 Mdot
.928 .12916 Mdot
.928 .1297 Mdot
.928 .13027 Mdot
.928 .13064 Mdot
.928 .13285 Mdot
.928 .13414 Mdot
.928 .13536 Mdot
.928 .1357 Mdot
.928 .13793 Mdot
.928 .13796 Mdot
.928 .13821 Mdot
.928 .1385 Mdot
.928 .13893 Mdot
.928 .13899 Mdot
.928 .1394 Mdot
.928 .13999 Mdot
.928 .1404 Mdot
.928 .14126 Mdot
.928 .14176 Mdot
.928 .14181 Mdot
.928 .14219 Mdot
.928 .14251 Mdot
.928 .14257 Mdot
.928 .14295 Mdot
.928 .14319 Mdot
.928 .14345 Mdot
.928 .14378 Mdot
.928 .14434 Mdot
.928 .14452 Mdot
.928 .14467 Mdot
.928 .14499 Mdot
.928 .14607 Mdot
.928 .1467 Mdot
.928 .14698 Mdot
.928 .14756 Mdot
.928 .14771 Mdot
.928 .14774 Mdot
.928 .14814 Mdot
.928 .14845 Mdot
.928 .14892 Mdot
.928 .14902 Mdot
.928 .14906 Mdot
.928 .14976 Mdot
.928 .15019 Mdot
.928 .15037 Mdot
.928 .15078 Mdot
.928 .1515 Mdot
.928 .15153 Mdot
.928 .15253 Mdot
.928 .15282 Mdot
.928 .15634 Mdot
.928 .1566 Mdot
.928 .15692 Mdot
.928 .15713 Mdot
.928 .15756 Mdot
.928 .15798 Mdot
.928 .1581 Mdot
.928 .15852 Mdot
.928 .15855 Mdot
.928 .15862 Mdot
.928 .1595 Mdot
.928 .16017 Mdot
.928 .16069 Mdot
.928 .16105 Mdot
.928 .16221 Mdot
.928 .16342 Mdot
.928 .16397 Mdot
.928 .16485 Mdot
.928 .16523 Mdot
.928 .16546 Mdot
.928 .16627 Mdot
.928 .16692 Mdot
.928 .16754 Mdot
.928 .16854 Mdot
.928 .17048 Mdot
.928 .17182 Mdot
.928 .17198 Mdot
.928 .17439 Mdot
.928 .17481 Mdot
.928 .17486 Mdot
.928 .17498 Mdot
.928 .17601 Mdot
.928 .17859 Mdot
.928 .17871 Mdot
.928 .17883 Mdot
.928 .17896 Mdot
.928 .17963 Mdot
.928 .17965 Mdot
.928 .18009 Mdot
.928 .18208 Mdot
.928 .18308 Mdot
.928 .18349 Mdot
.928 .18429 Mdot
.928 .1844 Mdot
.928 .18446 Mdot
.928 .18475 Mdot
.928 .18476 Mdot
.928 .18577 Mdot
.928 .18605 Mdot
.928 .1867 Mdot
.928 .18725 Mdot
.928 .18851 Mdot
.928 .18904 Mdot
.928 .19035 Mdot
.928 .19241 Mdot
.928 .19255 Mdot
.928 .19272 Mdot
.928 .19346 Mdot
.928 .19378 Mdot
.928 .19424 Mdot
.928 .1964 Mdot
.928 .19645 Mdot
.928 .19656 Mdot
.928 .19813 Mdot
.928 .19918 Mdot
.928 .19956 Mdot
.928 .20214 Mdot
.928 .20293 Mdot
.928 .20326 Mdot
.928 .20389 Mdot
.928 .20541 Mdot
.928 .20608 Mdot
.928 .20662 Mdot
.928 .20698 Mdot
.928 .20749 Mdot
.928 .20759 Mdot
.928 .20871 Mdot
.928 .20948 Mdot
.928 .20949 Mdot
.928 .2106 Mdot
.928 .21069 Mdot
.928 .21248 Mdot
.928 .21268 Mdot
.928 .21294 Mdot
.928 .21308 Mdot
.928 .21565 Mdot
.928 .2157 Mdot
.928 .21596 Mdot
.928 .21601 Mdot
.928 .21629 Mdot
.928 .21645 Mdot
.928 .21672 Mdot
.928 .21732 Mdot
.928 .21973 Mdot
.928 .22126 Mdot
.928 .22204 Mdot
.928 .22207 Mdot
.928 .22246 Mdot
.928 .22252 Mdot
.928 .22269 Mdot
.928 .2227 Mdot
.928 .22291 Mdot
.928 .22436 Mdot
.928 .22444 Mdot
.928 .22446 Mdot
.928 .22521 Mdot
.928 .22618 Mdot
.928 .22674 Mdot
.928 .22732 Mdot
.928 .22775 Mdot
.928 .22793 Mdot
.928 .22985 Mdot
.928 .23274 Mdot
.928 .23301 Mdot
.928 .23345 Mdot
.928 .23484 Mdot
.928 .23485 Mdot
.928 .23509 Mdot
.928 .23626 Mdot
.928 .23644 Mdot
.928 .23723 Mdot
.928 .23764 Mdot
.928 .23825 Mdot
.928 .23969 Mdot
.928 .24112 Mdot
.928 .2416 Mdot
.928 .24205 Mdot
.928 .24329 Mdot
.928 .24339 Mdot
.928 .24397 Mdot
.928 .24431 Mdot
.928 .24455 Mdot
.928 .24505 Mdot
.928 .24534 Mdot
.928 .24592 Mdot
.928 .24701 Mdot
.928 .2472 Mdot
.928 .2475 Mdot
.928 .24816 Mdot
.928 .24836 Mdot
.928 .24915 Mdot
.928 .24927 Mdot
.928 .25097 Mdot
.928 .25151 Mdot
.928 .25254 Mdot
.928 .25302 Mdot
.928 .25474 Mdot
.928 .25568 Mdot
.928 .25618 Mdot
.928 .25701 Mdot
.928 .25817 Mdot
.928 .25822 Mdot
.928 .25876 Mdot
.928 .25934 Mdot
.928 .25939 Mdot
.928 .25975 Mdot
.928 .26055 Mdot
.928 .26361 Mdot
.928 .26628 Mdot
.928 .26695 Mdot
.928 .26736 Mdot
.928 .26749 Mdot
.928 .26784 Mdot
.928 .26786 Mdot
.928 .26797 Mdot
.928 .26843 Mdot
.928 .26851 Mdot
.928 .2704 Mdot
.928 .27082 Mdot
.928 .27152 Mdot
.928 .27179 Mdot
.928 .27219 Mdot
.928 .27221 Mdot
.928 .27328 Mdot
.928 .27359 Mdot
.928 .27421 Mdot
.928 .27432 Mdot
.928 .27455 Mdot
.928 .27511 Mdot
.928 .27525 Mdot
.928 .2764 Mdot
.928 .2772 Mdot
.928 .2784 Mdot
.928 .27846 Mdot
.928 .27966 Mdot
.928 .27968 Mdot
.928 .28008 Mdot
.928 .28053 Mdot
.928 .28209 Mdot
.928 .28218 Mdot
.928 .28281 Mdot
.928 .28343 Mdot
.928 .2835 Mdot
.928 .28372 Mdot
.928 .28501 Mdot
.928 .28531 Mdot
.928 .28563 Mdot
.928 .28571 Mdot
.928 .28573 Mdot
.928 .28607 Mdot
.928 .28797 Mdot
.928 .2883 Mdot
.928 .29066 Mdot
.928 .29221 Mdot
.928 .29261 Mdot
.928 .29274 Mdot
.928 .29352 Mdot
.928 .29388 Mdot
.928 .29435 Mdot
.928 .29636 Mdot
.928 .29689 Mdot
.928 .29819 Mdot
.928 .29821 Mdot
.928 .30013 Mdot
.928 .30072 Mdot
.928 .30138 Mdot
.928 .30466 Mdot
.928 .30581 Mdot
.928 .31175 Mdot
.928 .31329 Mdot
.928 .31387 Mdot
.928 .3145 Mdot
.928 .31608 Mdot
.928 .3167 Mdot
.928 .31754 Mdot
.928 .31893 Mdot
.928 .31944 Mdot
.928 .32021 Mdot
.928 .32051 Mdot
.928 .32166 Mdot
.928 .3239 Mdot
.928 .32398 Mdot
.928 .32435 Mdot
.928 .32451 Mdot
.928 .32454 Mdot
.928 .3267 Mdot
.928 .32683 Mdot
.928 .32716 Mdot
.928 .33081 Mdot
.928 .33088 Mdot
.928 .33118 Mdot
.928 .3317 Mdot
.928 .33207 Mdot
.928 .33334 Mdot
.928 .33379 Mdot
.928 .33436 Mdot
.928 .33472 Mdot
.928 .33523 Mdot
.928 .33652 Mdot
.928 .33758 Mdot
.928 .33812 Mdot
.928 .33954 Mdot
.928 .34024 Mdot
.928 .3408 Mdot
.928 .34183 Mdot
.928 .34223 Mdot
.928 .34345 Mdot
.928 .34615 Mdot
.928 .34698 Mdot
.928 .34742 Mdot
.928 .34762 Mdot
.928 .34894 Mdot
.928 .3492 Mdot
.928 .35001 Mdot
.928 .35088 Mdot
.928 .35321 Mdot
.928 .35342 Mdot
.928 .35411 Mdot
.928 .35452 Mdot
.928 .35515 Mdot
.928 .35671 Mdot
.928 .35706 Mdot
.928 .36182 Mdot
.928 .36205 Mdot
.928 .36222 Mdot
.928 .36408 Mdot
.928 .36448 Mdot
.928 .3648 Mdot
.928 .3655 Mdot
.928 .36672 Mdot
.928 .36693 Mdot
.928 .36786 Mdot
.928 .36832 Mdot
.928 .37116 Mdot
.928 .37142 Mdot
.928 .3715 Mdot
.928 .37195 Mdot
.928 .37201 Mdot
.928 .37318 Mdot
.928 .37344 Mdot
.928 .37387 Mdot
.928 .37713 Mdot
.928 .37817 Mdot
.928 .37882 Mdot
.928 .37947 Mdot
.928 .38085 Mdot
.928 .38174 Mdot
.928 .38287 Mdot
.928 .38472 Mdot
.928 .38599 Mdot
.928 .38698 Mdot
.928 .38863 Mdot
.928 .39 Mdot
.928 .3909 Mdot
.928 .39132 Mdot
.928 .39269 Mdot
.928 .39275 Mdot
.928 .39286 Mdot
.928 .39366 Mdot
.928 .39403 Mdot
.928 .39545 Mdot
.928 .39599 Mdot
.928 .3962 Mdot
.928 .39646 Mdot
.928 .39694 Mdot
.928 .3988 Mdot
.928 .3988 Mdot
.928 .39886 Mdot
.928 .39944 Mdot
.928 .40009 Mdot
.928 .40047 Mdot
.928 .40107 Mdot
.928 .40122 Mdot
.928 .40138 Mdot
.928 .40151 Mdot
.928 .40215 Mdot
.928 .40348 Mdot
.928 .40405 Mdot
.928 .40442 Mdot
.928 .40634 Mdot
.928 .40703 Mdot
.928 .40731 Mdot
.928 .40744 Mdot
.928 .40746 Mdot
.928 .40758 Mdot
.928 .40837 Mdot
.928 .40844 Mdot
.928 .40914 Mdot
.928 .40929 Mdot
.928 .41012 Mdot
.928 .41066 Mdot
.928 .41108 Mdot
.928 .41124 Mdot
.928 .41139 Mdot
.928 .41179 Mdot
.928 .41187 Mdot
.928 .41197 Mdot
.928 .41197 Mdot
.928 .41206 Mdot
.928 .41254 Mdot
.928 .41321 Mdot
.928 .4136 Mdot
.928 .41374 Mdot
.928 .41393 Mdot
.928 .41464 Mdot
.928 .417 Mdot
.928 .41838 Mdot
.928 .41899 Mdot
.928 .41954 Mdot
.928 .42024 Mdot
.928 .42056 Mdot
.928 .42064 Mdot
.928 .42092 Mdot
.928 .42149 Mdot
.928 .42216 Mdot
.928 .42317 Mdot
.928 .42326 Mdot
.928 .42339 Mdot
.928 .42348 Mdot
.928 .4239 Mdot
.928 .42483 Mdot
.928 .42497 Mdot
.928 .42588 Mdot
.928 .42627 Mdot
.928 .42714 Mdot
.928 .42867 Mdot
.928 .42872 Mdot
.928 .42889 Mdot
.928 .42914 Mdot
.928 .43084 Mdot
.928 .43143 Mdot
.928 .43168 Mdot
.928 .43307 Mdot
.928 .43641 Mdot
.928 .43673 Mdot
.928 .43738 Mdot
.928 .43805 Mdot
.928 .43872 Mdot
.928 .43926 Mdot
.928 .4399 Mdot
.928 .44032 Mdot
.928 .44055 Mdot
.928 .44058 Mdot
.928 .44121 Mdot
.928 .44196 Mdot
.928 .44206 Mdot
.928 .44229 Mdot
.928 .44297 Mdot
.928 .44315 Mdot
.928 .4432 Mdot
.928 .44334 Mdot
.928 .44511 Mdot
.928 .44545 Mdot
.928 .44645 Mdot
.928 .44748 Mdot
.928 .4482 Mdot
.928 .44856 Mdot
.928 .44942 Mdot
.928 .44967 Mdot
.928 .44984 Mdot
.928 .45049 Mdot
.928 .45085 Mdot
.928 .45287 Mdot
.928 .45291 Mdot
.928 .45373 Mdot
.928 .45394 Mdot
.928 .45417 Mdot
.928 .45459 Mdot
.928 .45564 Mdot
.928 .45615 Mdot
.928 .45624 Mdot
.928 .45637 Mdot
.928 .4568 Mdot
.928 .45836 Mdot
.928 .4596 Mdot
.928 .4601 Mdot
.928 .46078 Mdot
.928 .4608 Mdot
.928 .46202 Mdot
.928 .46234 Mdot
.928 .46266 Mdot
.928 .46281 Mdot
.928 .46443 Mdot
.928 .46509 Mdot
.928 .4663 Mdot
.928 .46642 Mdot
.928 .46834 Mdot
.928 .46877 Mdot
.928 .46907 Mdot
.928 .47016 Mdot
.928 .4708 Mdot
.928 .47345 Mdot
.928 .474 Mdot
.928 .47421 Mdot
.928 .47425 Mdot
.928 .4743 Mdot
.928 .47433 Mdot
.928 .47451 Mdot
.928 .47466 Mdot
.928 .47587 Mdot
.928 .47629 Mdot
.928 .47635 Mdot
.928 .47647 Mdot
.928 .4778 Mdot
.928 .47891 Mdot
.928 .47897 Mdot
.928 .47937 Mdot
.928 .4801 Mdot
.928 .48091 Mdot
.928 .48112 Mdot
.928 .48123 Mdot
.928 .48132 Mdot
.928 .48156 Mdot
.928 .48217 Mdot
.928 .48272 Mdot
.928 .48274 Mdot
.928 .48333 Mdot
.928 .48351 Mdot
.928 .48448 Mdot
.928 .4856 Mdot
.928 .48614 Mdot
.928 .48691 Mdot
.928 .48861 Mdot
.928 .48931 Mdot
.928 .49065 Mdot
.928 .49083 Mdot
.928 .49094 Mdot
.928 .49142 Mdot
.928 .49144 Mdot
.928 .49176 Mdot
.928 .49311 Mdot
.928 .49357 Mdot
.928 .49406 Mdot
.928 .49447 Mdot
.928 .49463 Mdot
.928 .49545 Mdot
.928 .49554 Mdot
.928 .49757 Mdot
.928 .49819 Mdot
.928 .49844 Mdot
.928 .4986 Mdot
.928 .49887 Mdot
.928 .49895 Mdot
.928 .50052 Mdot
.928 .50139 Mdot
.928 .50275 Mdot
.928 .50338 Mdot
.928 .50377 Mdot
.928 .50399 Mdot
.928 .50425 Mdot
.928 .50479 Mdot
.928 .505 Mdot
.928 .5054 Mdot
.928 .50589 Mdot
.928 .50644 Mdot
.928 .50661 Mdot
.928 .50709 Mdot
.928 .50723 Mdot
.928 .50742 Mdot
.928 .50756 Mdot
.928 .5091 Mdot
.928 .50991 Mdot
.928 .50998 Mdot
.928 .51011 Mdot
.928 .51014 Mdot
.928 .51097 Mdot
.928 .5114 Mdot
.928 .51151 Mdot
.928 .51198 Mdot
.928 .51249 Mdot
.928 .51303 Mdot
.928 .51383 Mdot
.928 .51404 Mdot
.928 .5146 Mdot
.928 .51474 Mdot
.928 .51675 Mdot
.928 .51834 Mdot
.928 .51946 Mdot
.928 .51993 Mdot
.928 .52012 Mdot
.928 .52083 Mdot
.928 .52112 Mdot
.928 .52139 Mdot
.928 .52158 Mdot
.928 .52212 Mdot
.928 .52295 Mdot
.928 .52307 Mdot
.928 .52373 Mdot
.928 .52385 Mdot
.928 .52385 Mdot
.928 .52388 Mdot
.928 .52399 Mdot
.928 .5241 Mdot
.928 .52462 Mdot
.928 .52464 Mdot
.928 .52486 Mdot
.928 .52508 Mdot
.928 .52511 Mdot
.928 .52564 Mdot
.928 .5258 Mdot
.928 .52594 Mdot
.928 .52637 Mdot
.928 .52746 Mdot
.928 .5275 Mdot
.928 .5277 Mdot
.928 .52849 Mdot
.928 .5285 Mdot
.928 .52864 Mdot
.928 .52873 Mdot
.928 .52977 Mdot
.928 .52993 Mdot
.928 .52997 Mdot
.928 .52997 Mdot
.928 .53009 Mdot
.928 .53014 Mdot
.928 .5305 Mdot
.928 .5314 Mdot
.928 .53242 Mdot
.928 .53269 Mdot
.928 .53302 Mdot
.928 .5332 Mdot
.928 .53388 Mdot
.928 .53436 Mdot
.928 .53508 Mdot
.928 .53646 Mdot
.928 .53652 Mdot
.928 .53674 Mdot
.928 .53684 Mdot
.928 .5369 Mdot
.928 .53726 Mdot
.928 .53745 Mdot
.928 .53754 Mdot
.928 .53771 Mdot
.928 .53779 Mdot
.928 .5379 Mdot
.928 .53809 Mdot
.928 .53852 Mdot
.928 .53883 Mdot
.928 .53929 Mdot
.928 .54008 Mdot
.928 .54077 Mdot
.928 .54085 Mdot
.928 .54085 Mdot
.928 .54144 Mdot
.928 .54307 Mdot
.928 .54326 Mdot
.928 .54363 Mdot
.928 .54393 Mdot
.928 .54417 Mdot
.928 .54418 Mdot
.928 .54421 Mdot
.928 .54466 Mdot
.928 .54473 Mdot
.928 .54481 Mdot
.928 .54493 Mdot
.928 .54494 Mdot
.928 .54519 Mdot
.928 .54643 Mdot
.928 .54684 Mdot
.928 .54686 Mdot
.928 .54694 Mdot
.928 .54695 Mdot
.928 .54776 Mdot
.928 .5478 Mdot
.928 .54788 Mdot
.928 .54795 Mdot
.928 .54888 Mdot
.928 .54947 Mdot
.928 .5495 Mdot
.928 .54994 Mdot
.928 .55014 Mdot
.928 .55061 Mdot
.928 .55081 Mdot
.928 .55091 Mdot
.928 .55239 Mdot
.928 .55287 Mdot
.928 .55414 Mdot
.928 .55516 Mdot
.928 .55587 Mdot
.928 .55615 Mdot
.928 .55646 Mdot
.928 .5566 Mdot
.928 .55799 Mdot
.928 .558 Mdot
.928 .55824 Mdot
.928 .55831 Mdot
.928 .55939 Mdot
.928 .55942 Mdot
.928 .55956 Mdot
.928 .56028 Mdot
.928 .56033 Mdot
.928 .56073 Mdot
.928 .5613 Mdot
.928 .5616 Mdot
.928 .56221 Mdot
.928 .56265 Mdot
.928 .56281 Mdot
.928 .56377 Mdot
.928 .56396 Mdot
.928 .56441 Mdot
.928 .56481 Mdot
.928 .56591 Mdot
.928 .56599 Mdot
.928 .5665 Mdot
.928 .56668 Mdot
.928 .5668 Mdot
.928 .56701 Mdot
.928 .56704 Mdot
.928 .56727 Mdot
.928 .56743 Mdot
.928 .56768 Mdot
.928 .56818 Mdot
.928 .56827 Mdot
.928 .56831 Mdot
.928 .56869 Mdot
.928 .56876 Mdot
.928 .56898 Mdot
.928 .56909 Mdot
.928 .56925 Mdot
.928 .56949 Mdot
.928 .57004 Mdot
.928 .5702 Mdot
.928 .57084 Mdot
.928 .57094 Mdot
.928 .57128 Mdot
.928 .57165 Mdot
.928 .57228 Mdot
.928 .57238 Mdot
.928 .57254 Mdot
.928 .5727 Mdot
.928 .57347 Mdot
.928 .57348 Mdot
.928 .57384 Mdot
.928 .574 Mdot
.928 .57424 Mdot
.928 .57453 Mdot
.928 .57511 Mdot
.928 .57579 Mdot
.928 .57589 Mdot
.928 .576 Mdot
.928 .57615 Mdot
.928 .57617 Mdot
.928 .57673 Mdot
.928 .57753 Mdot
.928 .57756 Mdot
.928 .57793 Mdot
.928 .57831 Mdot
.928 .57835 Mdot
.928 .57859 Mdot
.928 .57911 Mdot
.928 .57939 Mdot
.928 .57961 Mdot
.928 .58059 Mdot
.928 .58097 Mdot
.928 .58103 Mdot
.928 .58122 Mdot
.928 .58164 Mdot
.928 .58176 Mdot
.928 .58261 Mdot
.928 .58299 Mdot
.928 .5831 Mdot
.928 .58322 Mdot
.928 .5833 Mdot
.928 .58349 Mdot
.928 .5835 Mdot
.928 .58356 Mdot
.928 .58359 Mdot
.928 .58381 Mdot
.928 .58385 Mdot
.928 .58403 Mdot
.928 .58417 Mdot
.928 .58486 Mdot
.928 .58486 Mdot
.928 .58497 Mdot
.928 .58507 Mdot
.928 .58519 Mdot
.928 .58543 Mdot
.928 .58556 Mdot
.928 .58561 Mdot
.928 .58576 Mdot
.928 .58577 Mdot
.928 .58629 Mdot
.928 .58644 Mdot
.928 .58673 Mdot
.928 .58678 Mdot
.928 .58689 Mdot
.928 .5869 Mdot
.928 .58714 Mdot
.928 .58721 Mdot
.928 .58745 Mdot
.928 .58763 Mdot
.928 .58772 Mdot
.928 .58806 Mdot
.928 .58808 Mdot
.928 .58831 Mdot
.928 .58857 Mdot
.928 .58859 Mdot
.928 .5886 Mdot
.928 .58907 Mdot
.928 .58908 Mdot
.928 .58917 Mdot
.928 .58923 Mdot
.928 .58938 Mdot
.928 .58941 Mdot
.928 .58978 Mdot
.928 .58999 Mdot
.928 .59002 Mdot
.928 .59024 Mdot
.928 .59024 Mdot
.928 .59042 Mdot
.928 .59046 Mdot
.928 .59048 Mdot
.928 .59054 Mdot
.928 .59056 Mdot
.928 .59073 Mdot
.928 .59088 Mdot
.928 .59098 Mdot
.928 .59108 Mdot
.928 .59118 Mdot
.928 .59121 Mdot
.928 .59121 Mdot
.928 .59128 Mdot
.928 .59132 Mdot
.928 .5914 Mdot
.928 .59155 Mdot
.928 .59164 Mdot
.928 .59166 Mdot
.928 .59188 Mdot
.928 .59197 Mdot
.928 .59259 Mdot
.928 .59264 Mdot
.928 .59272 Mdot
.928 .59275 Mdot
.928 .59295 Mdot
.928 .59304 Mdot
.928 .59307 Mdot
.928 .59323 Mdot
.928 .59323 Mdot
.928 .59324 Mdot
.928 .59327 Mdot
.928 .59331 Mdot
.928 .59334 Mdot
.928 .59336 Mdot
.928 .5934 Mdot
.928 .59377 Mdot
.928 .59377 Mdot
.928 .59386 Mdot
.928 .59396 Mdot
.928 .594 Mdot
.928 .59406 Mdot
.928 .59406 Mdot
.928 .59412 Mdot
.928 .59418 Mdot
.928 .59431 Mdot
.928 .59436 Mdot
.928 .59438 Mdot
.928 .59445 Mdot
.928 .59445 Mdot
.928 .59451 Mdot
.928 .59464 Mdot
.928 .59469 Mdot
.928 .59472 Mdot
.928 .59472 Mdot
.928 .59477 Mdot
.928 .59479 Mdot
.93 .04676 Mdot
.93 .04677 Mdot
.93 .04678 Mdot
.93 .04683 Mdot
.93 .04691 Mdot
.93 .04693 Mdot
.93 .04696 Mdot
.93 .04699 Mdot
.93 .04703 Mdot
.93 .04721 Mdot
.93 .04724 Mdot
.93 .04735 Mdot
.93 .04749 Mdot
.93 .04751 Mdot
.93 .04759 Mdot
.93 .04771 Mdot
.93 .04779 Mdot
.93 .04796 Mdot
.93 .04841 Mdot
.93 .0485 Mdot
.93 .04869 Mdot
.93 .04881 Mdot
.93 .04885 Mdot
.93 .04921 Mdot
.93 .04947 Mdot
.93 .0496 Mdot
.93 .04988 Mdot
.93 .04989 Mdot
.93 .05003 Mdot
.93 .05006 Mdot
.93 .05028 Mdot
.93 .05052 Mdot
.93 .05104 Mdot
.93 .05126 Mdot
.93 .05154 Mdot
.93 .05202 Mdot
.93 .05226 Mdot
.93 .05261 Mdot
.93 .05272 Mdot
.93 .05301 Mdot
.93 .05322 Mdot
.93 .05355 Mdot
.93 .05417 Mdot
.93 .05428 Mdot
.93 .05461 Mdot
.93 .05569 Mdot
.93 .05685 Mdot
.93 .05696 Mdot
.93 .05802 Mdot
.93 .05853 Mdot
.93 .05888 Mdot
.93 .0594 Mdot
.93 .0596 Mdot
.93 .05977 Mdot
.93 .06017 Mdot
.93 .06064 Mdot
.93 .06105 Mdot
.93 .06139 Mdot
.93 .06139 Mdot
.93 .06149 Mdot
.93 .06215 Mdot
.93 .06219 Mdot
.93 .06224 Mdot
.93 .06261 Mdot
.93 .06303 Mdot
.93 .06495 Mdot
.93 .06555 Mdot
.93 .06599 Mdot
.93 .06603 Mdot
.93 .06605 Mdot
.93 .06618 Mdot
.93 .06636 Mdot
.93 .0671 Mdot
.93 .07063 Mdot
.93 .0707 Mdot
.93 .07147 Mdot
.93 .07228 Mdot
.93 .07244 Mdot
.93 .07487 Mdot
.93 .07502 Mdot
.93 .07549 Mdot
.93 .07571 Mdot
.93 .07719 Mdot
.93 .07795 Mdot
.93 .07826 Mdot
.93 .07859 Mdot
.93 .08006 Mdot
.93 .08039 Mdot
.93 .08342 Mdot
.93 .08437 Mdot
.93 .08522 Mdot
.93 .08586 Mdot
.93 .08656 Mdot
.93 .08685 Mdot
.93 .08693 Mdot
.93 .08728 Mdot
.93 .08809 Mdot
.93 .08851 Mdot
.93 .08863 Mdot
.93 .08906 Mdot
.93 .09067 Mdot
.93 .09159 Mdot
.93 .09261 Mdot
.93 .0927 Mdot
.93 .09296 Mdot
.93 .09368 Mdot
.93 .09402 Mdot
.93 .09534 Mdot
.93 .0963 Mdot
.93 .09683 Mdot
.93 .09807 Mdot
.93 .09821 Mdot
.93 .09863 Mdot
.93 .09872 Mdot
.93 .10067 Mdot
.93 .10243 Mdot
.93 .10348 Mdot
.93 .10396 Mdot
.93 .10433 Mdot
.93 .10531 Mdot
.93 .10798 Mdot
.93 .10822 Mdot
.93 .11072 Mdot
.93 .11084 Mdot
.93 .11245 Mdot
.93 .11422 Mdot
.93 .11532 Mdot
.93 .11734 Mdot
.93 .11769 Mdot
.93 .11808 Mdot
.93 .11944 Mdot
.93 .11954 Mdot
.93 .12052 Mdot
.93 .12161 Mdot
.93 .12375 Mdot
.93 .12454 Mdot
.93 .12458 Mdot
.93 .12536 Mdot
.93 .12662 Mdot
.93 .12983 Mdot
.93 .13016 Mdot
.93 .13351 Mdot
.93 .13422 Mdot
.93 .13426 Mdot
.93 .1343 Mdot
.93 .13447 Mdot
.93 .13475 Mdot
.93 .13483 Mdot
.93 .13491 Mdot
.93 .13502 Mdot
.93 .13518 Mdot
.93 .13551 Mdot
.93 .13581 Mdot
.93 .13591 Mdot
.93 .13628 Mdot
.93 .1366 Mdot
.93 .13679 Mdot
.93 .13686 Mdot
.93 .13754 Mdot
.93 .13785 Mdot
.93 .13843 Mdot
.93 .13999 Mdot
.93 .14024 Mdot
.93 .14031 Mdot
.93 .14097 Mdot
.93 .14141 Mdot
.93 .14155 Mdot
.93 .14257 Mdot
.93 .14281 Mdot
.93 .1432 Mdot
.93 .14369 Mdot
.93 .14402 Mdot
.93 .14414 Mdot
.93 .14442 Mdot
.93 .14512 Mdot
.93 .14515 Mdot
.93 .14542 Mdot
.93 .14563 Mdot
.93 .14576 Mdot
.93 .14651 Mdot
.93 .14734 Mdot
.93 .14742 Mdot
.93 .14913 Mdot
.93 .14954 Mdot
.93 .14955 Mdot
.93 .1499 Mdot
.93 .15046 Mdot
.93 .15055 Mdot
.93 .15087 Mdot
.93 .15181 Mdot
.93 .15253 Mdot
.93 .15336 Mdot
.93 .15361 Mdot
.93 .15457 Mdot
.93 .15492 Mdot
.93 .15593 Mdot
.93 .15666 Mdot
.93 .15762 Mdot
.93 .15778 Mdot
.93 .1599 Mdot
.93 .16 Mdot
.93 .16027 Mdot
.93 .16139 Mdot
.93 .16149 Mdot
.93 .16178 Mdot
.93 .16357 Mdot
.93 .16383 Mdot
.93 .16445 Mdot
.93 .16488 Mdot
.93 .16509 Mdot
.93 .16738 Mdot
.93 .16776 Mdot
.93 .16833 Mdot
.93 .16901 Mdot
.93 .16936 Mdot
.93 .17079 Mdot
.93 .17088 Mdot
.93 .17175 Mdot
.93 .17294 Mdot
.93 .17468 Mdot
.93 .17485 Mdot
.93 .17585 Mdot
.93 .1772 Mdot
.93 .17758 Mdot
.93 .17823 Mdot
.93 .17854 Mdot
.93 .17868 Mdot
.93 .17881 Mdot
.93 .18014 Mdot
.93 .18131 Mdot
.93 .1817 Mdot
.93 .18194 Mdot
.93 .18307 Mdot
.93 .18421 Mdot
.93 .18421 Mdot
.93 .18455 Mdot
.93 .18466 Mdot
.93 .18674 Mdot
.93 .18684 Mdot
.93 .18701 Mdot
.93 .18724 Mdot
.93 .18824 Mdot
.93 .18952 Mdot
.93 .18964 Mdot
.93 .19018 Mdot
.93 .19146 Mdot
.93 .19333 Mdot
.93 .19421 Mdot
.93 .19552 Mdot
.93 .19594 Mdot
.93 .1966 Mdot
.93 .19772 Mdot
.93 .1979 Mdot
.93 .19909 Mdot
.93 .19932 Mdot
.93 .19945 Mdot
.93 .19953 Mdot
.93 .19996 Mdot
.93 .20054 Mdot
.93 .20077 Mdot
.93 .20164 Mdot
.93 .20171 Mdot
.93 .20287 Mdot
.93 .20295 Mdot
.93 .20334 Mdot
.93 .20342 Mdot
.93 .20353 Mdot
.93 .20377 Mdot
.93 .20389 Mdot
.93 .20418 Mdot
.93 .20556 Mdot
.93 .20572 Mdot
.93 .20594 Mdot
.93 .20793 Mdot
.93 .20856 Mdot
.93 .20927 Mdot
.93 .2102 Mdot
.93 .21074 Mdot
.93 .21153 Mdot
.93 .21264 Mdot
.93 .21291 Mdot
.93 .21423 Mdot
.93 .21431 Mdot
.93 .21451 Mdot
.93 .21681 Mdot
.93 .21697 Mdot
.93 .21764 Mdot
.93 .21875 Mdot
.93 .21954 Mdot
.93 .22007 Mdot
.93 .22022 Mdot
.93 .22079 Mdot
.93 .22303 Mdot
.93 .22344 Mdot
.93 .22505 Mdot
.93 .22512 Mdot
.93 .22565 Mdot
.93 .22706 Mdot
.93 .22771 Mdot
.93 .22773 Mdot
.93 .22787 Mdot
.93 .2282 Mdot
.93 .22846 Mdot
.93 .22966 Mdot
.93 .23035 Mdot
.93 .2306 Mdot
.93 .23115 Mdot
.93 .23152 Mdot
.93 .23171 Mdot
.93 .23314 Mdot
.93 .23414 Mdot
.93 .23497 Mdot
.93 .23609 Mdot
.93 .23734 Mdot
.93 .23828 Mdot
.93 .23918 Mdot
.93 .23932 Mdot
.93 .23959 Mdot
.93 .24025 Mdot
.93 .24149 Mdot
.93 .2428 Mdot
.93 .24339 Mdot
.93 .24381 Mdot
.93 .24384 Mdot
.93 .24485 Mdot
.93 .2473 Mdot
.93 .24966 Mdot
.93 .25217 Mdot
.93 .25264 Mdot
.93 .25295 Mdot
.93 .25324 Mdot
.93 .25406 Mdot
.93 .25485 Mdot
.93 .25541 Mdot
.93 .25693 Mdot
.93 .25765 Mdot
.93 .25835 Mdot
.93 .25938 Mdot
.93 .25948 Mdot
.93 .26118 Mdot
.93 .26139 Mdot
.93 .26261 Mdot
.93 .26349 Mdot
.93 .26372 Mdot
.93 .26434 Mdot
.93 .26459 Mdot
.93 .26503 Mdot
.93 .26564 Mdot
.93 .26614 Mdot
.93 .26627 Mdot
.93 .2668 Mdot
.93 .26803 Mdot
.93 .2683 Mdot
.93 .26892 Mdot
.93 .26928 Mdot
.93 .26964 Mdot
.93 .27091 Mdot
.93 .27255 Mdot
.93 .27522 Mdot
.93 .27535 Mdot
.93 .27563 Mdot
.93 .27731 Mdot
.93 .27782 Mdot
.93 .27832 Mdot
.93 .28074 Mdot
.93 .28127 Mdot
.93 .28153 Mdot
.93 .28229 Mdot
.93 .28375 Mdot
.93 .28408 Mdot
.93 .28438 Mdot
.93 .28507 Mdot
.93 .28535 Mdot
.93 .2857 Mdot
.93 .2866 Mdot
.93 .28677 Mdot
.93 .28723 Mdot
.93 .28803 Mdot
.93 .28904 Mdot
.93 .28915 Mdot
.93 .2915 Mdot
.93 .29188 Mdot
.93 .29273 Mdot
.93 .29339 Mdot
.93 .2939 Mdot
.93 .29436 Mdot
.93 .29536 Mdot
.93 .29576 Mdot
.93 .2961 Mdot
.93 .29691 Mdot
.93 .2973 Mdot
.93 .29767 Mdot
.93 .29773 Mdot
.93 .29797 Mdot
.93 .29798 Mdot
.93 .2985 Mdot
.93 .29874 Mdot
.93 .30035 Mdot
.93 .30217 Mdot
.93 .30267 Mdot
.93 .30294 Mdot
.93 .30331 Mdot
.93 .30423 Mdot
.93 .30642 Mdot
.93 .30736 Mdot
.93 .3091 Mdot
.93 .30972 Mdot
.93 .30996 Mdot
.93 .31144 Mdot
.93 .31179 Mdot
.93 .312 Mdot
.93 .31228 Mdot
.93 .31322 Mdot
.93 .31335 Mdot
.93 .31436 Mdot
.93 .31442 Mdot
.93 .31703 Mdot
.93 .31724 Mdot
.93 .31796 Mdot
.93 .31805 Mdot
.93 .3188 Mdot
.93 .32335 Mdot
.93 .32427 Mdot
.93 .3249 Mdot
.93 .32603 Mdot
.93 .32771 Mdot
.93 .33049 Mdot
.93 .33159 Mdot
.93 .33193 Mdot
.93 .33296 Mdot
.93 .33305 Mdot
.93 .33359 Mdot
.93 .33361 Mdot
.93 .33618 Mdot
.93 .33653 Mdot
.93 .33654 Mdot
.93 .33664 Mdot
.93 .33967 Mdot
.93 .34083 Mdot
.93 .34231 Mdot
.93 .34368 Mdot
.93 .34412 Mdot
.93 .34429 Mdot
.93 .34448 Mdot
.93 .3453 Mdot
.93 .34762 Mdot
.93 .34806 Mdot
.93 .34889 Mdot
.93 .34894 Mdot
.93 .34952 Mdot
.93 .34979 Mdot
.93 .35079 Mdot
.93 .35172 Mdot
.93 .35223 Mdot
.93 .35425 Mdot
.93 .35451 Mdot
.93 .35619 Mdot
.93 .35701 Mdot
.93 .35743 Mdot
.93 .35973 Mdot
.93 .36153 Mdot
.93 .36233 Mdot
.93 .36247 Mdot
.93 .36314 Mdot
.93 .36356 Mdot
.93 .3651 Mdot
.93 .36704 Mdot
.93 .36716 Mdot
.93 .36908 Mdot
.93 .36946 Mdot
.93 .37154 Mdot
.93 .37175 Mdot
.93 .37203 Mdot
.93 .37217 Mdot
.93 .37251 Mdot
.93 .37389 Mdot
.93 .37389 Mdot
.93 .3773 Mdot
.93 .37787 Mdot
.93 .37852 Mdot
.93 .37964 Mdot
.93 .37993 Mdot
.93 .38072 Mdot
.93 .38099 Mdot
.93 .38265 Mdot
.93 .3831 Mdot
.93 .38408 Mdot
.93 .38565 Mdot
.93 .38807 Mdot
.93 .3887 Mdot
.93 .38909 Mdot
.93 .38982 Mdot
.93 .39035 Mdot
.93 .39042 Mdot
.93 .39046 Mdot
.93 .39054 Mdot
.93 .39093 Mdot
.93 .39104 Mdot
.93 .39159 Mdot
.93 .39177 Mdot
.93 .39197 Mdot
.93 .39223 Mdot
.93 .3926 Mdot
.93 .39335 Mdot
.93 .39406 Mdot
.93 .39429 Mdot
.93 .39516 Mdot
.93 .39577 Mdot
.93 .39588 Mdot
.93 .39632 Mdot
.93 .39634 Mdot
.93 .39648 Mdot
.93 .39686 Mdot
.93 .39704 Mdot
.93 .39708 Mdot
.93 .39806 Mdot
.93 .39811 Mdot
.93 .39876 Mdot
.93 .40011 Mdot
.93 .40022 Mdot
.93 .40072 Mdot
.93 .40133 Mdot
.93 .40225 Mdot
.93 .40287 Mdot
.93 .40364 Mdot
.93 .40422 Mdot
.93 .40436 Mdot
.93 .40494 Mdot
.93 .40585 Mdot
.93 .40622 Mdot
.93 .40684 Mdot
.93 .40713 Mdot
.93 .40716 Mdot
.93 .40768 Mdot
.93 .40944 Mdot
.93 .40997 Mdot
.93 .41084 Mdot
.93 .4116 Mdot
.93 .41168 Mdot
.93 .41193 Mdot
.93 .41236 Mdot
.93 .41267 Mdot
.93 .41293 Mdot
.93 .41354 Mdot
.93 .4151 Mdot
.93 .41516 Mdot
.93 .41575 Mdot
.93 .4162 Mdot
.93 .41649 Mdot
.93 .41813 Mdot
.93 .41924 Mdot
.93 .41993 Mdot
.93 .42011 Mdot
.93 .42319 Mdot
.93 .4238 Mdot
.93 .42395 Mdot
.93 .42396 Mdot
.93 .42467 Mdot
.93 .42468 Mdot
.93 .42544 Mdot
.93 .42609 Mdot
.93 .42653 Mdot
.93 .42662 Mdot
.93 .42682 Mdot
.93 .42739 Mdot
.93 .4275 Mdot
.93 .42771 Mdot
.93 .42949 Mdot
.93 .43099 Mdot
.93 .43274 Mdot
.93 .43325 Mdot
.93 .4333 Mdot
.93 .43466 Mdot
.93 .4348 Mdot
.93 .43524 Mdot
.93 .43557 Mdot
.93 .43598 Mdot
.93 .43731 Mdot
.93 .43757 Mdot
.93 .43775 Mdot
.93 .43805 Mdot
.93 .43954 Mdot
.93 .43954 Mdot
.93 .44032 Mdot
.93 .4406 Mdot
.93 .44098 Mdot
.93 .4415 Mdot
.93 .44182 Mdot
.93 .44317 Mdot
.93 .44609 Mdot
.93 .44628 Mdot
.93 .44683 Mdot
.93 .44694 Mdot
.93 .44905 Mdot
.93 .44925 Mdot
.93 .44977 Mdot
.93 .44981 Mdot
.93 .45048 Mdot
.93 .45055 Mdot
.93 .45122 Mdot
.93 .4522 Mdot
.93 .45313 Mdot
.93 .45332 Mdot
.93 .45383 Mdot
.93 .45457 Mdot
.93 .45504 Mdot
.93 .45554 Mdot
.93 .45588 Mdot
.93 .45592 Mdot
.93 .45628 Mdot
.93 .45771 Mdot
.93 .45959 Mdot
.93 .46067 Mdot
.93 .46085 Mdot
.93 .46099 Mdot
.93 .46138 Mdot
.93 .46225 Mdot
.93 .46234 Mdot
.93 .46246 Mdot
.93 .46331 Mdot
.93 .46368 Mdot
.93 .46374 Mdot
.93 .4644 Mdot
.93 .46706 Mdot
.93 .46721 Mdot
.93 .46762 Mdot
.93 .46783 Mdot
.93 .46882 Mdot
.93 .46883 Mdot
.93 .46918 Mdot
.93 .47101 Mdot
.93 .47415 Mdot
.93 .47446 Mdot
.93 .47449 Mdot
.93 .47625 Mdot
.93 .4769 Mdot
.93 .47747 Mdot
.93 .47839 Mdot
.93 .47866 Mdot
.93 .47906 Mdot
.93 .47933 Mdot
.93 .47955 Mdot
.93 .48047 Mdot
.93 .48092 Mdot
.93 .48093 Mdot
.93 .48101 Mdot
.93 .48125 Mdot
.93 .48148 Mdot
.93 .48352 Mdot
.93 .48378 Mdot
.93 .48404 Mdot
.93 .48435 Mdot
.93 .48479 Mdot
.93 .48581 Mdot
.93 .48647 Mdot
.93 .48688 Mdot
.93 .48707 Mdot
.93 .48776 Mdot
.93 .48833 Mdot
.93 .48879 Mdot
.93 .48906 Mdot
.93 .4893 Mdot
.93 .4907 Mdot
.93 .4907 Mdot
.93 .49127 Mdot
.93 .49146 Mdot
.93 .49158 Mdot
.93 .49167 Mdot
.93 .49251 Mdot
.93 .4949 Mdot
.93 .49506 Mdot
.93 .49534 Mdot
.93 .49539 Mdot
.93 .49571 Mdot
.93 .49734 Mdot
.93 .49783 Mdot
.93 .49939 Mdot
.93 .49959 Mdot
.93 .50045 Mdot
.93 .50068 Mdot
.93 .50102 Mdot
.93 .50119 Mdot
.93 .50209 Mdot
.93 .5024 Mdot
.93 .50248 Mdot
.93 .50255 Mdot
.93 .50324 Mdot
.93 .50425 Mdot
.93 .50541 Mdot
.93 .50544 Mdot
.93 .50545 Mdot
.93 .50656 Mdot
.93 .50657 Mdot
.93 .50677 Mdot
.93 .5068 Mdot
.93 .50773 Mdot
.93 .50877 Mdot
.93 .5094 Mdot
.93 .5104 Mdot
.93 .51207 Mdot
.93 .51235 Mdot
.93 .51238 Mdot
.93 .51264 Mdot
.93 .51367 Mdot
.93 .51411 Mdot
.93 .51445 Mdot
.93 .51463 Mdot
.93 .51476 Mdot
.93 .5153 Mdot
.93 .51538 Mdot
.93 .51623 Mdot
.93 .51657 Mdot
.93 .51769 Mdot
.93 .51782 Mdot
.93 .51792 Mdot
.93 .51809 Mdot
.93 .51874 Mdot
.93 .51958 Mdot
.93 .51959 Mdot
.93 .51967 Mdot
.93 .5197 Mdot
.93 .52025 Mdot
.93 .52037 Mdot
.93 .52051 Mdot
.93 .52086 Mdot
.93 .52103 Mdot
.93 .52144 Mdot
.93 .52187 Mdot
.93 .52273 Mdot
.93 .52308 Mdot
.93 .52336 Mdot
.93 .52352 Mdot
.93 .52358 Mdot
.93 .52389 Mdot
.93 .52411 Mdot
.93 .52445 Mdot
.93 .52457 Mdot
.93 .52561 Mdot
.93 .52661 Mdot
.93 .52679 Mdot
.93 .52746 Mdot
.93 .5275 Mdot
.93 .52841 Mdot
.93 .52964 Mdot
.93 .52985 Mdot
.93 .53036 Mdot
.93 .53054 Mdot
.93 .53058 Mdot
.93 .53096 Mdot
.93 .5314 Mdot
.93 .53177 Mdot
.93 .53225 Mdot
.93 .53285 Mdot
.93 .53319 Mdot
.93 .53342 Mdot
.93 .53416 Mdot
.93 .53435 Mdot
.93 .53488 Mdot
.93 .53498 Mdot
.93 .53508 Mdot
.93 .53524 Mdot
.93 .53606 Mdot
.93 .53684 Mdot
.93 .53798 Mdot
.93 .53812 Mdot
.93 .53831 Mdot
.93 .53873 Mdot
.93 .53913 Mdot
.93 .53935 Mdot
.93 .53948 Mdot
.93 .54048 Mdot
.93 .54111 Mdot
.93 .54143 Mdot
.93 .54189 Mdot
.93 .54195 Mdot
.93 .54207 Mdot
.93 .54224 Mdot
.93 .54293 Mdot
.93 .54312 Mdot
.93 .54316 Mdot
.93 .54337 Mdot
.93 .54382 Mdot
.93 .54399 Mdot
.93 .54401 Mdot
.93 .54452 Mdot
.93 .54465 Mdot
.93 .54536 Mdot
.93 .54554 Mdot
.93 .54601 Mdot
.93 .54635 Mdot
.93 .54661 Mdot
.93 .54742 Mdot
.93 .54784 Mdot
.93 .54792 Mdot
.93 .54827 Mdot
.93 .54851 Mdot
.93 .54868 Mdot
.93 .54897 Mdot
.93 .54919 Mdot
.93 .54939 Mdot
.93 .55 Mdot
.93 .55007 Mdot
.93 .55012 Mdot
.93 .55055 Mdot
.93 .55064 Mdot
.93 .55067 Mdot
.93 .55075 Mdot
.93 .55078 Mdot
.93 .55081 Mdot
.93 .55095 Mdot
.93 .55131 Mdot
.93 .55133 Mdot
.93 .5516 Mdot
.93 .55212 Mdot
.93 .55254 Mdot
.93 .55288 Mdot
.93 .55321 Mdot
.93 .55361 Mdot
.93 .55388 Mdot
.93 .55445 Mdot
.93 .55484 Mdot
.93 .55504 Mdot
.93 .55573 Mdot
.93 .55651 Mdot
.93 .55732 Mdot
.93 .55751 Mdot
.93 .5583 Mdot
.93 .55834 Mdot
.93 .55874 Mdot
.93 .55945 Mdot
.93 .56037 Mdot
.93 .56063 Mdot
.93 .56065 Mdot
.93 .56138 Mdot
.93 .56155 Mdot
.93 .56166 Mdot
.93 .5624 Mdot
.93 .56253 Mdot
.93 .56271 Mdot
.93 .56279 Mdot
.93 .56331 Mdot
.93 .5634 Mdot
.93 .56383 Mdot
.93 .56453 Mdot
.93 .5657 Mdot
.93 .56622 Mdot
.93 .56658 Mdot
.93 .56661 Mdot
.93 .56688 Mdot
.93 .56688 Mdot
.93 .56749 Mdot
.93 .56807 Mdot
.93 .56836 Mdot
.93 .56847 Mdot
.93 .56871 Mdot
.93 .56889 Mdot
.93 .56955 Mdot
.93 .5706 Mdot
.93 .57091 Mdot
.93 .57147 Mdot
.93 .57243 Mdot
.93 .57252 Mdot
.93 .57343 Mdot
.93 .57378 Mdot
.93 .574 Mdot
.93 .57401 Mdot
.93 .57423 Mdot
.93 .57484 Mdot
.93 .57514 Mdot
.93 .57542 Mdot
.93 .57545 Mdot
.93 .57583 Mdot
.93 .57594 Mdot
.93 .57603 Mdot
.93 .5766 Mdot
.93 .5769 Mdot
.93 .5774 Mdot
.93 .57784 Mdot
.93 .57788 Mdot
.93 .57857 Mdot
.93 .57864 Mdot
.93 .57937 Mdot
.93 .57964 Mdot
.93 .57975 Mdot
.93 .57988 Mdot
.93 .58017 Mdot
.93 .58065 Mdot
.93 .58119 Mdot
.93 .58121 Mdot
.93 .58133 Mdot
.93 .58137 Mdot
.93 .58171 Mdot
.93 .58185 Mdot
.93 .58211 Mdot
.93 .58247 Mdot
.93 .58256 Mdot
.93 .58276 Mdot
.93 .58283 Mdot
.93 .58286 Mdot
.93 .58313 Mdot
.93 .58339 Mdot
.93 .58382 Mdot
.93 .58394 Mdot
.93 .58397 Mdot
.93 .58409 Mdot
.93 .5843 Mdot
.93 .5844 Mdot
.93 .58442 Mdot
.93 .5845 Mdot
.93 .58469 Mdot
.93 .58486 Mdot
.93 .58509 Mdot
.93 .58535 Mdot
.93 .58617 Mdot
.93 .58626 Mdot
.93 .58665 Mdot
.93 .58674 Mdot
.93 .58682 Mdot
.93 .58703 Mdot
.93 .58743 Mdot
.93 .58748 Mdot
.93 .58761 Mdot
.93 .58765 Mdot
.93 .5883 Mdot
.93 .58834 Mdot
.93 .58856 Mdot
.93 .58876 Mdot
.93 .58878 Mdot
.93 .58972 Mdot
.93 .58992 Mdot
.93 .58997 Mdot
.93 .59 Mdot
.93 .59001 Mdot
.93 .59002 Mdot
.93 .59013 Mdot
.93 .59029 Mdot
.93 .5908 Mdot
.93 .59091 Mdot
.93 .59101 Mdot
.93 .59103 Mdot
.93 .59103 Mdot
.93 .59121 Mdot
.93 .59124 Mdot
.93 .59124 Mdot
.93 .59133 Mdot
.93 .59144 Mdot
.93 .59156 Mdot
.93 .59166 Mdot
.93 .59171 Mdot
.93 .59176 Mdot
.93 .5919 Mdot
.93 .59199 Mdot
.93 .59213 Mdot
.93 .59241 Mdot
.93 .59243 Mdot
.93 .59274 Mdot
.93 .59302 Mdot
.93 .59311 Mdot
.93 .59314 Mdot
.93 .5933 Mdot
.93 .59339 Mdot
.93 .59344 Mdot
.93 .59352 Mdot
.93 .59355 Mdot
.93 .59364 Mdot
.93 .5937 Mdot
.93 .59383 Mdot
.93 .5939 Mdot
.93 .59396 Mdot
.93 .5941 Mdot
.93 .59416 Mdot
.93 .59422 Mdot
.93 .59423 Mdot
.93 .59426 Mdot
.93 .59426 Mdot
.93 .59434 Mdot
.93 .59437 Mdot
.93 .59444 Mdot
.93 .59453 Mdot
.93 .59454 Mdot
.93 .59458 Mdot
.93 .59463 Mdot
.93 .59465 Mdot
.93 .59477 Mdot
.93 .59481 Mdot
.93 .59483 Mdot
.93 .59486 Mdot
.93 .59488 Mdot
.93 .59489 Mdot
.93 .59493 Mdot
.93 .59495 Mdot
.93 .59496 Mdot
.93 .59501 Mdot
.93 .59502 Mdot
.93 .59503 Mdot
.93 .59503 Mdot
.93 .59504 Mdot
.93 .59506 Mdot
.93 .59507 Mdot
.93 .59508 Mdot
.93 .59508 Mdot
.932 .04587 Mdot
.932 .04589 Mdot
.932 .04591 Mdot
.932 .04593 Mdot
.932 .04597 Mdot
.932 .04601 Mdot
.932 .04602 Mdot
.932 .04612 Mdot
.932 .04616 Mdot
.932 .04618 Mdot
.932 .04619 Mdot
.932 .0462 Mdot
.932 .04622 Mdot
.932 .04637 Mdot
.932 .04641 Mdot
.932 .04667 Mdot
.932 .04668 Mdot
.932 .04681 Mdot
.932 .04684 Mdot
.932 .04714 Mdot
.932 .04715 Mdot
.932 .04719 Mdot
.932 .04758 Mdot
.932 .04773 Mdot
.932 .04787 Mdot
.932 .04838 Mdot
.932 .04853 Mdot
.932 .04858 Mdot
.932 .04907 Mdot
.932 .04925 Mdot
.932 .05027 Mdot
.932 .05046 Mdot
.932 .05104 Mdot
.932 .05128 Mdot
.932 .05135 Mdot
.932 .05195 Mdot
.932 .05247 Mdot
.932 .05291 Mdot
.932 .05299 Mdot
.932 .05353 Mdot
.932 .05364 Mdot
.932 .05374 Mdot
.932 .05393 Mdot
.932 .05434 Mdot
.932 .0546 Mdot
.932 .05599 Mdot
.932 .05679 Mdot
.932 .05705 Mdot
.932 .05799 Mdot
.932 .05834 Mdot
.932 .05863 Mdot
.932 .05932 Mdot
.932 .05932 Mdot
.932 .05995 Mdot
.932 .05996 Mdot
.932 .06121 Mdot
.932 .0614 Mdot
.932 .0614 Mdot
.932 .06181 Mdot
.932 .06188 Mdot
.932 .06195 Mdot
.932 .06255 Mdot
.932 .06259 Mdot
.932 .06279 Mdot
.932 .06283 Mdot
.932 .0635 Mdot
.932 .06481 Mdot
.932 .06502 Mdot
.932 .06618 Mdot
.932 .06696 Mdot
.932 .06789 Mdot
.932 .06829 Mdot
.932 .06882 Mdot
.932 .06885 Mdot
.932 .06969 Mdot
.932 .07163 Mdot
.932 .07212 Mdot
.932 .07326 Mdot
.932 .07443 Mdot
.932 .07502 Mdot
.932 .07541 Mdot
.932 .07565 Mdot
.932 .07625 Mdot
.932 .07748 Mdot
.932 .07749 Mdot
.932 .07794 Mdot
.932 .07837 Mdot
.932 .08314 Mdot
.932 .0834 Mdot
.932 .08354 Mdot
.932 .08496 Mdot
.932 .08998 Mdot
.932 .09386 Mdot
.932 .09405 Mdot
.932 .0958 Mdot
.932 .09616 Mdot
.932 .09646 Mdot
.932 .09714 Mdot
.932 .09758 Mdot
.932 .09768 Mdot
.932 .09825 Mdot
.932 .09836 Mdot
.932 .09882 Mdot
.932 .0993 Mdot
.932 .10018 Mdot
.932 .10267 Mdot
.932 .10293 Mdot
.932 .10322 Mdot
.932 .10369 Mdot
.932 .10491 Mdot
.932 .10495 Mdot
.932 .10846 Mdot
.932 .10869 Mdot
.932 .10878 Mdot
.932 .10885 Mdot
.932 .10995 Mdot
.932 .11145 Mdot
.932 .1116 Mdot
.932 .1118 Mdot
.932 .11207 Mdot
.932 .11301 Mdot
.932 .11335 Mdot
.932 .11497 Mdot
.932 .11707 Mdot
.932 .11805 Mdot
.932 .11956 Mdot
.932 .11966 Mdot
.932 .1207 Mdot
.932 .1218 Mdot
.932 .12282 Mdot
.932 .12543 Mdot
.932 .12554 Mdot
.932 .12803 Mdot
.932 .1307 Mdot
.932 .13113 Mdot
.932 .1312 Mdot
.932 .13127 Mdot
.932 .13136 Mdot
.932 .13148 Mdot
.932 .13165 Mdot
.932 .13166 Mdot
.932 .13202 Mdot
.932 .13217 Mdot
.932 .13223 Mdot
.932 .13226 Mdot
.932 .1323 Mdot
.932 .13237 Mdot
.932 .13286 Mdot
.932 .13289 Mdot
.932 .13304 Mdot
.932 .13354 Mdot
.932 .13364 Mdot
.932 .13394 Mdot
.932 .13399 Mdot
.932 .13443 Mdot
.932 .13454 Mdot
.932 .13496 Mdot
.932 .13561 Mdot
.932 .13565 Mdot
.932 .13567 Mdot
.932 .13578 Mdot
.932 .13638 Mdot
.932 .13669 Mdot
.932 .13716 Mdot
.932 .13768 Mdot
.932 .13816 Mdot
.932 .13901 Mdot
.932 .13995 Mdot
.932 .14048 Mdot
.932 .14063 Mdot
.932 .14098 Mdot
.932 .14235 Mdot
.932 .14298 Mdot
.932 .14652 Mdot
.932 .14665 Mdot
.932 .14676 Mdot
.932 .14718 Mdot
.932 .14864 Mdot
.932 .14899 Mdot
.932 .14918 Mdot
.932 .15004 Mdot
.932 .15027 Mdot
.932 .15147 Mdot
.932 .15211 Mdot
.932 .15232 Mdot
.932 .15412 Mdot
.932 .15446 Mdot
.932 .15453 Mdot
.932 .15563 Mdot
.932 .15591 Mdot
.932 .15592 Mdot
.932 .15775 Mdot
.932 .15815 Mdot
.932 .15848 Mdot
.932 .15913 Mdot
.932 .16055 Mdot
.932 .16141 Mdot
.932 .16151 Mdot
.932 .16333 Mdot
.932 .16496 Mdot
.932 .16571 Mdot
.932 .16617 Mdot
.932 .16704 Mdot
.932 .16735 Mdot
.932 .16852 Mdot
.932 .16878 Mdot
.932 .16886 Mdot
.932 .16975 Mdot
.932 .17001 Mdot
.932 .17023 Mdot
.932 .17182 Mdot
.932 .17292 Mdot
.932 .1741 Mdot
.932 .17455 Mdot
.932 .17466 Mdot
.932 .1749 Mdot
.932 .17507 Mdot
.932 .17736 Mdot
.932 .17738 Mdot
.932 .17817 Mdot
.932 .17835 Mdot
.932 .17891 Mdot
.932 .17947 Mdot
.932 .17949 Mdot
.932 .1795 Mdot
.932 .18019 Mdot
.932 .18077 Mdot
.932 .18085 Mdot
.932 .18108 Mdot
.932 .18245 Mdot
.932 .18256 Mdot
.932 .18367 Mdot
.932 .1843 Mdot
.932 .18431 Mdot
.932 .1854 Mdot
.932 .18541 Mdot
.932 .18566 Mdot
.932 .1859 Mdot
.932 .18612 Mdot
.932 .18668 Mdot
.932 .18711 Mdot
.932 .18739 Mdot
.932 .18742 Mdot
.932 .18772 Mdot
.932 .18811 Mdot
.932 .18824 Mdot
.932 .18829 Mdot
.932 .18881 Mdot
.932 .1889 Mdot
.932 .18905 Mdot
.932 .19057 Mdot
.932 .19124 Mdot
.932 .19136 Mdot
.932 .19196 Mdot
.932 .19221 Mdot
.932 .19251 Mdot
.932 .19309 Mdot
.932 .19369 Mdot
.932 .1937 Mdot
.932 .19386 Mdot
.932 .19555 Mdot
.932 .19623 Mdot
.932 .19653 Mdot
.932 .19785 Mdot
.932 .19801 Mdot
.932 .19865 Mdot
.932 .20002 Mdot
.932 .20079 Mdot
.932 .20088 Mdot
.932 .20089 Mdot
.932 .20091 Mdot
.932 .20116 Mdot
.932 .20141 Mdot
.932 .20154 Mdot
.932 .20256 Mdot
.932 .204 Mdot
.932 .20522 Mdot
.932 .20558 Mdot
.932 .20612 Mdot
.932 .20624 Mdot
.932 .20639 Mdot
.932 .20685 Mdot
.932 .20735 Mdot
.932 .20858 Mdot
.932 .20867 Mdot
.932 .20963 Mdot
.932 .21128 Mdot
.932 .21136 Mdot
.932 .21143 Mdot
.932 .21171 Mdot
.932 .21264 Mdot
.932 .21351 Mdot
.932 .21503 Mdot
.932 .21523 Mdot
.932 .21539 Mdot
.932 .2156 Mdot
.932 .21648 Mdot
.932 .21755 Mdot
.932 .21913 Mdot
.932 .2199 Mdot
.932 .22069 Mdot
.932 .22158 Mdot
.932 .22274 Mdot
.932 .22424 Mdot
.932 .22495 Mdot
.932 .22643 Mdot
.932 .22824 Mdot
.932 .22825 Mdot
.932 .22825 Mdot
.932 .22828 Mdot
.932 .22949 Mdot
.932 .23026 Mdot
.932 .23031 Mdot
.932 .23099 Mdot
.932 .23122 Mdot
.932 .23214 Mdot
.932 .23273 Mdot
.932 .23408 Mdot
.932 .23594 Mdot
.932 .23598 Mdot
.932 .23681 Mdot
.932 .23737 Mdot
.932 .2387 Mdot
.932 .24003 Mdot
.932 .24306 Mdot
.932 .24326 Mdot
.932 .24409 Mdot
.932 .2442 Mdot
.932 .24679 Mdot
.932 .24747 Mdot
.932 .24828 Mdot
.932 .24888 Mdot
.932 .24963 Mdot
.932 .25233 Mdot
.932 .25331 Mdot
.932 .25411 Mdot
.932 .25451 Mdot
.932 .2555 Mdot
.932 .25697 Mdot
.932 .25834 Mdot
.932 .25879 Mdot
.932 .25886 Mdot
.932 .26139 Mdot
.932 .26248 Mdot
.932 .26287 Mdot
.932 .26359 Mdot
.932 .26383 Mdot
.932 .26414 Mdot
.932 .26533 Mdot
.932 .27062 Mdot
.932 .27345 Mdot
.932 .2737 Mdot
.932 .27441 Mdot
.932 .27476 Mdot
.932 .27548 Mdot
.932 .27897 Mdot
.932 .27899 Mdot
.932 .27961 Mdot
.932 .28161 Mdot
.932 .28177 Mdot
.932 .28346 Mdot
.932 .28403 Mdot
.932 .28451 Mdot
.932 .28554 Mdot
.932 .28554 Mdot
.932 .28608 Mdot
.932 .28668 Mdot
.932 .28725 Mdot
.932 .28811 Mdot
.932 .29056 Mdot
.932 .2916 Mdot
.932 .29245 Mdot
.932 .29298 Mdot
.932 .2944 Mdot
.932 .29449 Mdot
.932 .29565 Mdot
.932 .29593 Mdot
.932 .29755 Mdot
.932 .29786 Mdot
.932 .29875 Mdot
.932 .29913 Mdot
.932 .3005 Mdot
.932 .30288 Mdot
.932 .30298 Mdot
.932 .3034 Mdot
.932 .30443 Mdot
.932 .30542 Mdot
.932 .30549 Mdot
.932 .30554 Mdot
.932 .3059 Mdot
.932 .30707 Mdot
.932 .30902 Mdot
.932 .3099 Mdot
.932 .31026 Mdot
.932 .31061 Mdot
.932 .3114 Mdot
.932 .31143 Mdot
.932 .3124 Mdot
.932 .31271 Mdot
.932 .31342 Mdot
.932 .31459 Mdot
.932 .31605 Mdot
.932 .31608 Mdot
.932 .31618 Mdot
.932 .31718 Mdot
.932 .31783 Mdot
.932 .31919 Mdot
.932 .3232 Mdot
.932 .32441 Mdot
.932 .32568 Mdot
.932 .3263 Mdot
.932 .32654 Mdot
.932 .32675 Mdot
.932 .3272 Mdot
.932 .3289 Mdot
.932 .32967 Mdot
.932 .3311 Mdot
.932 .33195 Mdot
.932 .33367 Mdot
.932 .33367 Mdot
.932 .33405 Mdot
.932 .33411 Mdot
.932 .33461 Mdot
.932 .33476 Mdot
.932 .33479 Mdot
.932 .3353 Mdot
.932 .33724 Mdot
.932 .33779 Mdot
.932 .33869 Mdot
.932 .33961 Mdot
.932 .34085 Mdot
.932 .34115 Mdot
.932 .34185 Mdot
.932 .3429 Mdot
.932 .34313 Mdot
.932 .34432 Mdot
.932 .34483 Mdot
.932 .34755 Mdot
.932 .34762 Mdot
.932 .34835 Mdot
.932 .35085 Mdot
.932 .35278 Mdot
.932 .35359 Mdot
.932 .35376 Mdot
.932 .3544 Mdot
.932 .3547 Mdot
.932 .35475 Mdot
.932 .35495 Mdot
.932 .35675 Mdot
.932 .35688 Mdot
.932 .35708 Mdot
.932 .35759 Mdot
.932 .35761 Mdot
.932 .35908 Mdot
.932 .35921 Mdot
.932 .3603 Mdot
.932 .36036 Mdot
.932 .36044 Mdot
.932 .36055 Mdot
.932 .36093 Mdot
.932 .3617 Mdot
.932 .36291 Mdot
.932 .36349 Mdot
.932 .36434 Mdot
.932 .36574 Mdot
.932 .36666 Mdot
.932 .36763 Mdot
.932 .36865 Mdot
.932 .36868 Mdot
.932 .3694 Mdot
.932 .36965 Mdot
.932 .37317 Mdot
.932 .37321 Mdot
.932 .37574 Mdot
.932 .37577 Mdot
.932 .37622 Mdot
.932 .37858 Mdot
.932 .37909 Mdot
.932 .37975 Mdot
.932 .37984 Mdot
.932 .3802 Mdot
.932 .38028 Mdot
.932 .38073 Mdot
.932 .38216 Mdot
.932 .38315 Mdot
.932 .3832 Mdot
.932 .38337 Mdot
.932 .38354 Mdot
.932 .38375 Mdot
.932 .38393 Mdot
.932 .38402 Mdot
.932 .38443 Mdot
.932 .38446 Mdot
.932 .3853 Mdot
.932 .38568 Mdot
.932 .38581 Mdot
.932 .38589 Mdot
.932 .38599 Mdot
.932 .38615 Mdot
.932 .3863 Mdot
.932 .38722 Mdot
.932 .38729 Mdot
.932 .38738 Mdot
.932 .38755 Mdot
.932 .38772 Mdot
.932 .38892 Mdot
.932 .38896 Mdot
.932 .38914 Mdot
.932 .38986 Mdot
.932 .38993 Mdot
.932 .38997 Mdot
.932 .39066 Mdot
.932 .39101 Mdot
.932 .39126 Mdot
.932 .39129 Mdot
.932 .39133 Mdot
.932 .39224 Mdot
.932 .3927 Mdot
.932 .39274 Mdot
.932 .39282 Mdot
.932 .39332 Mdot
.932 .39374 Mdot
.932 .39384 Mdot
.932 .39389 Mdot
.932 .39414 Mdot
.932 .39507 Mdot
.932 .39553 Mdot
.932 .39626 Mdot
.932 .39734 Mdot
.932 .39734 Mdot
.932 .39807 Mdot
.932 .39854 Mdot
.932 .39963 Mdot
.932 .40128 Mdot
.932 .40133 Mdot
.932 .40158 Mdot
.932 .40226 Mdot
.932 .4037 Mdot
.932 .4049 Mdot
.932 .40526 Mdot
.932 .40604 Mdot
.932 .40642 Mdot
.932 .40705 Mdot
.932 .40912 Mdot
.932 .40963 Mdot
.932 .41052 Mdot
.932 .41052 Mdot
.932 .41122 Mdot
.932 .41217 Mdot
.932 .41231 Mdot
.932 .4126 Mdot
.932 .41441 Mdot
.932 .41753 Mdot
.932 .41832 Mdot
.932 .4186 Mdot
.932 .41885 Mdot
.932 .4191 Mdot
.932 .41975 Mdot
.932 .42052 Mdot
.932 .4229 Mdot
.932 .42344 Mdot
.932 .42365 Mdot
.932 .42407 Mdot
.932 .4259 Mdot
.932 .42638 Mdot
.932 .42748 Mdot
.932 .42874 Mdot
.932 .42894 Mdot
.932 .42971 Mdot
.932 .43028 Mdot
.932 .43058 Mdot
.932 .43073 Mdot
.932 .43157 Mdot
.932 .43447 Mdot
.932 .43505 Mdot
.932 .43518 Mdot
.932 .43534 Mdot
.932 .43536 Mdot
.932 .43545 Mdot
.932 .43618 Mdot
.932 .43637 Mdot
.932 .43761 Mdot
.932 .43803 Mdot
.932 .43818 Mdot
.932 .43819 Mdot
.932 .43868 Mdot
.932 .4409 Mdot
.932 .44194 Mdot
.932 .44209 Mdot
.932 .44274 Mdot
.932 .44341 Mdot
.932 .44472 Mdot
.932 .44547 Mdot
.932 .44724 Mdot
.932 .44756 Mdot
.932 .44927 Mdot
.932 .44946 Mdot
.932 .44994 Mdot
.932 .45011 Mdot
.932 .45303 Mdot
.932 .4562 Mdot
.932 .45628 Mdot
.932 .45764 Mdot
.932 .45853 Mdot
.932 .4602 Mdot
.932 .46079 Mdot
.932 .46188 Mdot
.932 .4622 Mdot
.932 .463 Mdot
.932 .46309 Mdot
.932 .46344 Mdot
.932 .46349 Mdot
.932 .46364 Mdot
.932 .46531 Mdot
.932 .46578 Mdot
.932 .46619 Mdot
.932 .46665 Mdot
.932 .46725 Mdot
.932 .46914 Mdot
.932 .4705 Mdot
.932 .47115 Mdot
.932 .47187 Mdot
.932 .4733 Mdot
.932 .47412 Mdot
.932 .47425 Mdot
.932 .47431 Mdot
.932 .47474 Mdot
.932 .47505 Mdot
.932 .47545 Mdot
.932 .4766 Mdot
.932 .47688 Mdot
.932 .47872 Mdot
.932 .47913 Mdot
.932 .47915 Mdot
.932 .48055 Mdot
.932 .48087 Mdot
.932 .48185 Mdot
.932 .48261 Mdot
.932 .48282 Mdot
.932 .48286 Mdot
.932 .48287 Mdot
.932 .48346 Mdot
.932 .48348 Mdot
.932 .48374 Mdot
.932 .48406 Mdot
.932 .48447 Mdot
.932 .48507 Mdot
.932 .48521 Mdot
.932 .4856 Mdot
.932 .4866 Mdot
.932 .48692 Mdot
.932 .48793 Mdot
.932 .48812 Mdot
.932 .48815 Mdot
.932 .4883 Mdot
.932 .48834 Mdot
.932 .48862 Mdot
.932 .48883 Mdot
.932 .48981 Mdot
.932 .48999 Mdot
.932 .49104 Mdot
.932 .49106 Mdot
.932 .49289 Mdot
.932 .4929 Mdot
.932 .49332 Mdot
.932 .49371 Mdot
.932 .49408 Mdot
.932 .49464 Mdot
.932 .49498 Mdot
.932 .4957 Mdot
.932 .49601 Mdot
.932 .49616 Mdot
.932 .4962 Mdot
.932 .49626 Mdot
.932 .49669 Mdot
.932 .49674 Mdot
.932 .49732 Mdot
.932 .49754 Mdot
.932 .49762 Mdot
.932 .49767 Mdot
.932 .49846 Mdot
.932 .49859 Mdot
.932 .49885 Mdot
.932 .49891 Mdot
.932 .49923 Mdot
.932 .50124 Mdot
.932 .50127 Mdot
.932 .50232 Mdot
.932 .50252 Mdot
.932 .50298 Mdot
.932 .50347 Mdot
.932 .50374 Mdot
.932 .50385 Mdot
.932 .50433 Mdot
.932 .50523 Mdot
.932 .50616 Mdot
.932 .50617 Mdot
.932 .50642 Mdot
.932 .50658 Mdot
.932 .50723 Mdot
.932 .50755 Mdot
.932 .50837 Mdot
.932 .50901 Mdot
.932 .51005 Mdot
.932 .51049 Mdot
.932 .51197 Mdot
.932 .51247 Mdot
.932 .51271 Mdot
.932 .51311 Mdot
.932 .51366 Mdot
.932 .51408 Mdot
.932 .51445 Mdot
.932 .51482 Mdot
.932 .51523 Mdot
.932 .51568 Mdot
.932 .51638 Mdot
.932 .5168 Mdot
.932 .51693 Mdot
.932 .51695 Mdot
.932 .51697 Mdot
.932 .51733 Mdot
.932 .5177 Mdot
.932 .51788 Mdot
.932 .51935 Mdot
.932 .52086 Mdot
.932 .52139 Mdot
.932 .52309 Mdot
.932 .52339 Mdot
.932 .52359 Mdot
.932 .5238 Mdot
.932 .52399 Mdot
.932 .52434 Mdot
.932 .52451 Mdot
.932 .52471 Mdot
.932 .52529 Mdot
.932 .52534 Mdot
.932 .52603 Mdot
.932 .52625 Mdot
.932 .52625 Mdot
.932 .52745 Mdot
.932 .5277 Mdot
.932 .52781 Mdot
.932 .52814 Mdot
.932 .5291 Mdot
.932 .53089 Mdot
.932 .53129 Mdot
.932 .53139 Mdot
.932 .53147 Mdot
.932 .53172 Mdot
.932 .53185 Mdot
.932 .53221 Mdot
.932 .53305 Mdot
.932 .53322 Mdot
.932 .53368 Mdot
.932 .53417 Mdot
.932 .53522 Mdot
.932 .5361 Mdot
.932 .53635 Mdot
.932 .53655 Mdot
.932 .53681 Mdot
.932 .53704 Mdot
.932 .53788 Mdot
.932 .53792 Mdot
.932 .53819 Mdot
.932 .53825 Mdot
.932 .53924 Mdot
.932 .54028 Mdot
.932 .54116 Mdot
.932 .54159 Mdot
.932 .54208 Mdot
.932 .54215 Mdot
.932 .54302 Mdot
.932 .54302 Mdot
.932 .54302 Mdot
.932 .54407 Mdot
.932 .5443 Mdot
.932 .54514 Mdot
.932 .54542 Mdot
.932 .54567 Mdot
.932 .54674 Mdot
.932 .54702 Mdot
.932 .54709 Mdot
.932 .54714 Mdot
.932 .5472 Mdot
.932 .54768 Mdot
.932 .54795 Mdot
.932 .54824 Mdot
.932 .54832 Mdot
.932 .54837 Mdot
.932 .54888 Mdot
.932 .54959 Mdot
.932 .54989 Mdot
.932 .54994 Mdot
.932 .54997 Mdot
.932 .55025 Mdot
.932 .55063 Mdot
.932 .55139 Mdot
.932 .55143 Mdot
.932 .55151 Mdot
.932 .55158 Mdot
.932 .55159 Mdot
.932 .55159 Mdot
.932 .55162 Mdot
.932 .55228 Mdot
.932 .55247 Mdot
.932 .55252 Mdot
.932 .55292 Mdot
.932 .55374 Mdot
.932 .55379 Mdot
.932 .55379 Mdot
.932 .55397 Mdot
.932 .55415 Mdot
.932 .55424 Mdot
.932 .55432 Mdot
.932 .5545 Mdot
.932 .55474 Mdot
.932 .55527 Mdot
.932 .55543 Mdot
.932 .5556 Mdot
.932 .55569 Mdot
.932 .5557 Mdot
.932 .55579 Mdot
.932 .55592 Mdot
.932 .5563 Mdot
.932 .5563 Mdot
.932 .55716 Mdot
.932 .55719 Mdot
.932 .5576 Mdot
.932 .55767 Mdot
.932 .5577 Mdot
.932 .55787 Mdot
.932 .55809 Mdot
.932 .55825 Mdot
.932 .55842 Mdot
.932 .55847 Mdot
.932 .55945 Mdot
.932 .55952 Mdot
.932 .55955 Mdot
.932 .56037 Mdot
.932 .56084 Mdot
.932 .5609 Mdot
.932 .56127 Mdot
.932 .56134 Mdot
.932 .56169 Mdot
.932 .56178 Mdot
.932 .56217 Mdot
.932 .5624 Mdot
.932 .56287 Mdot
.932 .56341 Mdot
.932 .56504 Mdot
.932 .56545 Mdot
.932 .56547 Mdot
.932 .56615 Mdot
.932 .56633 Mdot
.932 .56705 Mdot
.932 .56715 Mdot
.932 .5677 Mdot
.932 .56773 Mdot
.932 .56936 Mdot
.932 .56992 Mdot
.932 .57058 Mdot
.932 .57067 Mdot
.932 .57087 Mdot
.932 .57108 Mdot
.932 .57145 Mdot
.932 .57148 Mdot
.932 .57168 Mdot
.932 .57229 Mdot
.932 .57304 Mdot
.932 .57375 Mdot
.932 .57377 Mdot
.932 .57451 Mdot
.932 .5748 Mdot
.932 .57511 Mdot
.932 .5754 Mdot
.932 .57543 Mdot
.932 .57585 Mdot
.932 .57612 Mdot
.932 .57671 Mdot
.932 .57716 Mdot
.932 .57725 Mdot
.932 .57751 Mdot
.932 .57759 Mdot
.932 .57764 Mdot
.932 .57768 Mdot
.932 .5781 Mdot
.932 .57841 Mdot
.932 .57843 Mdot
.932 .57845 Mdot
.932 .57852 Mdot
.932 .57948 Mdot
.932 .5795 Mdot
.932 .57983 Mdot
.932 .57996 Mdot
.932 .58004 Mdot
.932 .58011 Mdot
.932 .5808 Mdot
.932 .58104 Mdot
.932 .58117 Mdot
.932 .58129 Mdot
.932 .58132 Mdot
.932 .58148 Mdot
.932 .58151 Mdot
.932 .58163 Mdot
.932 .58182 Mdot
.932 .5819 Mdot
.932 .582 Mdot
.932 .58247 Mdot
.932 .58252 Mdot
.932 .58358 Mdot
.932 .58494 Mdot
.932 .58533 Mdot
.932 .58536 Mdot
.932 .58543 Mdot
.932 .58672 Mdot
.932 .58683 Mdot
.932 .58695 Mdot
.932 .58696 Mdot
.932 .58729 Mdot
.932 .58745 Mdot
.932 .58751 Mdot
.932 .58762 Mdot
.932 .58777 Mdot
.932 .58809 Mdot
.932 .58839 Mdot
.932 .58852 Mdot
.932 .58904 Mdot
.932 .58926 Mdot
.932 .58927 Mdot
.932 .58941 Mdot
.932 .58952 Mdot
.932 .58977 Mdot
.932 .58997 Mdot
.932 .59028 Mdot
.932 .59034 Mdot
.932 .59068 Mdot
.932 .59086 Mdot
.932 .59087 Mdot
.932 .59092 Mdot
.932 .59094 Mdot
.932 .59109 Mdot
.932 .59111 Mdot
.932 .59113 Mdot
.932 .59124 Mdot
.932 .59124 Mdot
.932 .59129 Mdot
.932 .59162 Mdot
.932 .59162 Mdot
.932 .59179 Mdot
.932 .59179 Mdot
.932 .59197 Mdot
.932 .59205 Mdot
.932 .59214 Mdot
.932 .59239 Mdot
.932 .59245 Mdot
.932 .59266 Mdot
.932 .59303 Mdot
.932 .5931 Mdot
.932 .59321 Mdot
.932 .59326 Mdot
.932 .59328 Mdot
.932 .59331 Mdot
.932 .59345 Mdot
.932 .59347 Mdot
.932 .59359 Mdot
.932 .59373 Mdot
.932 .59388 Mdot
.932 .5939 Mdot
.932 .59396 Mdot
.932 .59412 Mdot
.932 .59417 Mdot
.932 .59443 Mdot
.932 .59448 Mdot
.932 .59461 Mdot
.932 .59462 Mdot
.932 .59466 Mdot
.932 .59479 Mdot
.932 .59483 Mdot
.932 .59487 Mdot
.932 .59497 Mdot
.932 .59498 Mdot
.932 .59498 Mdot
.932 .59506 Mdot
.932 .59507 Mdot
.932 .5951 Mdot
.932 .59511 Mdot
.932 .59517 Mdot
.932 .59518 Mdot
.932 .59522 Mdot
.932 .59523 Mdot
.932 .59523 Mdot
.932 .59523 Mdot
.932 .59524 Mdot
.932 .59525 Mdot
.932 .59528 Mdot
.932 .59528 Mdot
.932 .59529 Mdot
.932 .5953 Mdot
.932 .5953 Mdot
.932 .59531 Mdot
.932 .59531 Mdot
.934 .04498 Mdot
.934 .04499 Mdot
.934 .04502 Mdot
.934 .04513 Mdot
.934 .04518 Mdot
.934 .04522 Mdot
.934 .04524 Mdot
.934 .04527 Mdot
.934 .04536 Mdot
.934 .04539 Mdot
.934 .04542 Mdot
.934 .04556 Mdot
.934 .04567 Mdot
.934 .04573 Mdot
.934 .04584 Mdot
.934 .04586 Mdot
.934 .04588 Mdot
.934 .04607 Mdot
.934 .04613 Mdot
.934 .04639 Mdot
.934 .04669 Mdot
.934 .04692 Mdot
.934 .04694 Mdot
.934 .04706 Mdot
.934 .04711 Mdot
.934 .04712 Mdot
.934 .04712 Mdot
.934 .0472 Mdot
.934 .04721 Mdot
.934 .0482 Mdot
.934 .04861 Mdot
.934 .04911 Mdot
.934 .04928 Mdot
.934 .04994 Mdot
.934 .0501 Mdot
.934 .05011 Mdot
.934 .05038 Mdot
.934 .05176 Mdot
.934 .05219 Mdot
.934 .05291 Mdot
.934 .05296 Mdot
.934 .05325 Mdot
.934 .05367 Mdot
.934 .05377 Mdot
.934 .0539 Mdot
.934 .05449 Mdot
.934 .05491 Mdot
.934 .0554 Mdot
.934 .0564 Mdot
.934 .05686 Mdot
.934 .0583 Mdot
.934 .059 Mdot
.934 .05973 Mdot
.934 .06117 Mdot
.934 .06241 Mdot
.934 .06263 Mdot
.934 .06266 Mdot
.934 .0628 Mdot
.934 .06312 Mdot
.934 .06344 Mdot
.934 .06542 Mdot
.934 .06556 Mdot
.934 .06678 Mdot
.934 .06711 Mdot
.934 .0674 Mdot
.934 .06753 Mdot
.934 .06901 Mdot
.934 .07058 Mdot
.934 .07121 Mdot
.934 .07142 Mdot
.934 .07163 Mdot
.934 .07171 Mdot
.934 .0737 Mdot
.934 .07543 Mdot
.934 .07773 Mdot
.934 .07796 Mdot
.934 .07855 Mdot
.934 .07889 Mdot
.934 .08065 Mdot
.934 .08212 Mdot
.934 .08422 Mdot
.934 .08585 Mdot
.934 .08856 Mdot
.934 .09483 Mdot
.934 .09533 Mdot
.934 .09569 Mdot
.934 .09899 Mdot
.934 .09905 Mdot
.934 .09998 Mdot
.934 .10087 Mdot
.934 .10144 Mdot
.934 .10446 Mdot
.934 .10558 Mdot
.934 .10664 Mdot
.934 .10694 Mdot
.934 .10738 Mdot
.934 .10877 Mdot
.934 .10938 Mdot
.934 .10971 Mdot
.934 .11159 Mdot
.934 .11202 Mdot
.934 .1133 Mdot
.934 .11333 Mdot
.934 .11433 Mdot
.934 .11587 Mdot
.934 .1223 Mdot
.934 .12597 Mdot
.934 .12618 Mdot
.934 .12751 Mdot
.934 .12806 Mdot
.934 .12806 Mdot
.934 .12819 Mdot
.934 .12856 Mdot
.934 .12873 Mdot
.934 .12888 Mdot
.934 .12896 Mdot
.934 .12897 Mdot
.934 .12905 Mdot
.934 .12939 Mdot
.934 .12948 Mdot
.934 .12961 Mdot
.934 .13003 Mdot
.934 .13009 Mdot
.934 .13025 Mdot
.934 .1305 Mdot
.934 .13052 Mdot
.934 .1307 Mdot
.934 .13107 Mdot
.934 .13115 Mdot
.934 .13124 Mdot
.934 .13132 Mdot
.934 .13188 Mdot
.934 .1321 Mdot
.934 .13302 Mdot
.934 .13392 Mdot
.934 .13408 Mdot
.934 .13489 Mdot
.934 .1349 Mdot
.934 .13495 Mdot
.934 .13538 Mdot
.934 .13556 Mdot
.934 .13557 Mdot
.934 .13559 Mdot
.934 .13585 Mdot
.934 .13592 Mdot
.934 .13694 Mdot
.934 .13775 Mdot
.934 .13859 Mdot
.934 .13916 Mdot
.934 .13937 Mdot
.934 .1406 Mdot
.934 .14079 Mdot
.934 .14085 Mdot
.934 .14256 Mdot
.934 .14306 Mdot
.934 .14315 Mdot
.934 .14339 Mdot
.934 .14393 Mdot
.934 .14433 Mdot
.934 .14543 Mdot
.934 .146 Mdot
.934 .14604 Mdot
.934 .14697 Mdot
.934 .14711 Mdot
.934 .14734 Mdot
.934 .14796 Mdot
.934 .15029 Mdot
.934 .15174 Mdot
.934 .15212 Mdot
.934 .15323 Mdot
.934 .15339 Mdot
.934 .15351 Mdot
.934 .15438 Mdot
.934 .15444 Mdot
.934 .1554 Mdot
.934 .1557 Mdot
.934 .15572 Mdot
.934 .15586 Mdot
.934 .15688 Mdot
.934 .15702 Mdot
.934 .15727 Mdot
.934 .15815 Mdot
.934 .15832 Mdot
.934 .15832 Mdot
.934 .15865 Mdot
.934 .15899 Mdot
.934 .15911 Mdot
.934 .15949 Mdot
.934 .15958 Mdot
.934 .16058 Mdot
.934 .16075 Mdot
.934 .16111 Mdot
.934 .1612 Mdot
.934 .16129 Mdot
.934 .16193 Mdot
.934 .16254 Mdot
.934 .16296 Mdot
.934 .16305 Mdot
.934 .16324 Mdot
.934 .16339 Mdot
.934 .16347 Mdot
.934 .16374 Mdot
.934 .16421 Mdot
.934 .16449 Mdot
.934 .16507 Mdot
.934 .16522 Mdot
.934 .16625 Mdot
.934 .16699 Mdot
.934 .16759 Mdot
.934 .16878 Mdot
.934 .16916 Mdot
.934 .16953 Mdot
.934 .16996 Mdot
.934 .17001 Mdot
.934 .17114 Mdot
.934 .1712 Mdot
.934 .17162 Mdot
.934 .17314 Mdot
.934 .17331 Mdot
.934 .17401 Mdot
.934 .17473 Mdot
.934 .1757 Mdot
.934 .17636 Mdot
.934 .17766 Mdot
.934 .17883 Mdot
.934 .17901 Mdot
.934 .17966 Mdot
.934 .18284 Mdot
.934 .18361 Mdot
.934 .18413 Mdot
.934 .18592 Mdot
.934 .18774 Mdot
.934 .18777 Mdot
.934 .18846 Mdot
.934 .18856 Mdot
.934 .18902 Mdot
.934 .19007 Mdot
.934 .19112 Mdot
.934 .19197 Mdot
.934 .19205 Mdot
.934 .19344 Mdot
.934 .19417 Mdot
.934 .19537 Mdot
.934 .19762 Mdot
.934 .19809 Mdot
.934 .20066 Mdot
.934 .20086 Mdot
.934 .20094 Mdot
.934 .20134 Mdot
.934 .20206 Mdot
.934 .20217 Mdot
.934 .20311 Mdot
.934 .20406 Mdot
.934 .20447 Mdot
.934 .20557 Mdot
.934 .20695 Mdot
.934 .20724 Mdot
.934 .20891 Mdot
.934 .20904 Mdot
.934 .20928 Mdot
.934 .20947 Mdot
.934 .21306 Mdot
.934 .21431 Mdot
.934 .2146 Mdot
.934 .2147 Mdot
.934 .21474 Mdot
.934 .21482 Mdot
.934 .21631 Mdot
.934 .21678 Mdot
.934 .21698 Mdot
.934 .21709 Mdot
.934 .21761 Mdot
.934 .21765 Mdot
.934 .21791 Mdot
.934 .21957 Mdot
.934 .22421 Mdot
.934 .22637 Mdot
.934 .22806 Mdot
.934 .22964 Mdot
.934 .22999 Mdot
.934 .23184 Mdot
.934 .23329 Mdot
.934 .23666 Mdot
.934 .23681 Mdot
.934 .23716 Mdot
.934 .23754 Mdot
.934 .23809 Mdot
.934 .2391 Mdot
.934 .23926 Mdot
.934 .23935 Mdot
.934 .24041 Mdot
.934 .2406 Mdot
.934 .24082 Mdot
.934 .24123 Mdot
.934 .24165 Mdot
.934 .24241 Mdot
.934 .24419 Mdot
.934 .24554 Mdot
.934 .24583 Mdot
.934 .24736 Mdot
.934 .24865 Mdot
.934 .24991 Mdot
.934 .2502 Mdot
.934 .2503 Mdot
.934 .25037 Mdot
.934 .25076 Mdot
.934 .25185 Mdot
.934 .25567 Mdot
.934 .25667 Mdot
.934 .25668 Mdot
.934 .25719 Mdot
.934 .25812 Mdot
.934 .25982 Mdot
.934 .26029 Mdot
.934 .26158 Mdot
.934 .26429 Mdot
.934 .26747 Mdot
.934 .26964 Mdot
.934 .27072 Mdot
.934 .2715 Mdot
.934 .27245 Mdot
.934 .27297 Mdot
.934 .27541 Mdot
.934 .27679 Mdot
.934 .27956 Mdot
.934 .27978 Mdot
.934 .28062 Mdot
.934 .28072 Mdot
.934 .28214 Mdot
.934 .28237 Mdot
.934 .28271 Mdot
.934 .2829 Mdot
.934 .28621 Mdot
.934 .28748 Mdot
.934 .28791 Mdot
.934 .28934 Mdot
.934 .29037 Mdot
.934 .29061 Mdot
.934 .29106 Mdot
.934 .29144 Mdot
.934 .29226 Mdot
.934 .29277 Mdot
.934 .29452 Mdot
.934 .29608 Mdot
.934 .29973 Mdot
.934 .29989 Mdot
.934 .2999 Mdot
.934 .29991 Mdot
.934 .30032 Mdot
.934 .30086 Mdot
.934 .30251 Mdot
.934 .30316 Mdot
.934 .30324 Mdot
.934 .30381 Mdot
.934 .30426 Mdot
.934 .30485 Mdot
.934 .30502 Mdot
.934 .30516 Mdot
.934 .30566 Mdot
.934 .30582 Mdot
.934 .30597 Mdot
.934 .30623 Mdot
.934 .30661 Mdot
.934 .30767 Mdot
.934 .30845 Mdot
.934 .30965 Mdot
.934 .31443 Mdot
.934 .31495 Mdot
.934 .3157 Mdot
.934 .31643 Mdot
.934 .31775 Mdot
.934 .31801 Mdot
.934 .31834 Mdot
.934 .32021 Mdot
.934 .32089 Mdot
.934 .3217 Mdot
.934 .32291 Mdot
.934 .32313 Mdot
.934 .32315 Mdot
.934 .32665 Mdot
.934 .32752 Mdot
.934 .32827 Mdot
.934 .32918 Mdot
.934 .33242 Mdot
.934 .33303 Mdot
.934 .33418 Mdot
.934 .3353 Mdot
.934 .33542 Mdot
.934 .33867 Mdot
.934 .33875 Mdot
.934 .33973 Mdot
.934 .34073 Mdot
.934 .34112 Mdot
.934 .34137 Mdot
.934 .34143 Mdot
.934 .34363 Mdot
.934 .34494 Mdot
.934 .34539 Mdot
.934 .34922 Mdot
.934 .35352 Mdot
.934 .35391 Mdot
.934 .35538 Mdot
.934 .35541 Mdot
.934 .35582 Mdot
.934 .35621 Mdot
.934 .35865 Mdot
.934 .35877 Mdot
.934 .35896 Mdot
.934 .35953 Mdot
.934 .35978 Mdot
.934 .36067 Mdot
.934 .36176 Mdot
.934 .36482 Mdot
.934 .36626 Mdot
.934 .36674 Mdot
.934 .36904 Mdot
.934 .3701 Mdot
.934 .37038 Mdot
.934 .37087 Mdot
.934 .37136 Mdot
.934 .37145 Mdot
.934 .37231 Mdot
.934 .37263 Mdot
.934 .37356 Mdot
.934 .37364 Mdot
.934 .37461 Mdot
.934 .37522 Mdot
.934 .37567 Mdot
.934 .37595 Mdot
.934 .37597 Mdot
.934 .37628 Mdot
.934 .37716 Mdot
.934 .37759 Mdot
.934 .37794 Mdot
.934 .37799 Mdot
.934 .37813 Mdot
.934 .37816 Mdot
.934 .37836 Mdot
.934 .37871 Mdot
.934 .37882 Mdot
.934 .37884 Mdot
.934 .37917 Mdot
.934 .37935 Mdot
.934 .37939 Mdot
.934 .37971 Mdot
.934 .38073 Mdot
.934 .38086 Mdot
.934 .38124 Mdot
.934 .38183 Mdot
.934 .38188 Mdot
.934 .38231 Mdot
.934 .38261 Mdot
.934 .3832 Mdot
.934 .3836 Mdot
.934 .3838 Mdot
.934 .38512 Mdot
.934 .38565 Mdot
.934 .38741 Mdot
.934 .38743 Mdot
.934 .38783 Mdot
.934 .3899 Mdot
.934 .38996 Mdot
.934 .39009 Mdot
.934 .39032 Mdot
.934 .39128 Mdot
.934 .39175 Mdot
.934 .39221 Mdot
.934 .39225 Mdot
.934 .39237 Mdot
.934 .39336 Mdot
.934 .39379 Mdot
.934 .39381 Mdot
.934 .39385 Mdot
.934 .39439 Mdot
.934 .39447 Mdot
.934 .39461 Mdot
.934 .39515 Mdot
.934 .39699 Mdot
.934 .39744 Mdot
.934 .39796 Mdot
.934 .39884 Mdot
.934 .39974 Mdot
.934 .39987 Mdot
.934 .40078 Mdot
.934 .40084 Mdot
.934 .40208 Mdot
.934 .40255 Mdot
.934 .40289 Mdot
.934 .40471 Mdot
.934 .4051 Mdot
.934 .40534 Mdot
.934 .40578 Mdot
.934 .4059 Mdot
.934 .40692 Mdot
.934 .40773 Mdot
.934 .40974 Mdot
.934 .41009 Mdot
.934 .41085 Mdot
.934 .41106 Mdot
.934 .41144 Mdot
.934 .4115 Mdot
.934 .41158 Mdot
.934 .41163 Mdot
.934 .41278 Mdot
.934 .41367 Mdot
.934 .41377 Mdot
.934 .4141 Mdot
.934 .41453 Mdot
.934 .41587 Mdot
.934 .4161 Mdot
.934 .41668 Mdot
.934 .41684 Mdot
.934 .41695 Mdot
.934 .41729 Mdot
.934 .41733 Mdot
.934 .41743 Mdot
.934 .41779 Mdot
.934 .41798 Mdot
.934 .41828 Mdot
.934 .41945 Mdot
.934 .41977 Mdot
.934 .42027 Mdot
.934 .42087 Mdot
.934 .42159 Mdot
.934 .42159 Mdot
.934 .42401 Mdot
.934 .42565 Mdot
.934 .42589 Mdot
.934 .4266 Mdot
.934 .4291 Mdot
.934 .42946 Mdot
.934 .42967 Mdot
.934 .43034 Mdot
.934 .43048 Mdot
.934 .43054 Mdot
.934 .43075 Mdot
.934 .43177 Mdot
.934 .43224 Mdot
.934 .4328 Mdot
.934 .43306 Mdot
.934 .43313 Mdot
.934 .43339 Mdot
.934 .4336 Mdot
.934 .43368 Mdot
.934 .43392 Mdot
.934 .43431 Mdot
.934 .43499 Mdot
.934 .43516 Mdot
.934 .4352 Mdot
.934 .43532 Mdot
.934 .43612 Mdot
.934 .4373 Mdot
.934 .43731 Mdot
.934 .43791 Mdot
.934 .43796 Mdot
.934 .43825 Mdot
.934 .43977 Mdot
.934 .4399 Mdot
.934 .44034 Mdot
.934 .44061 Mdot
.934 .44112 Mdot
.934 .44158 Mdot
.934 .44213 Mdot
.934 .44292 Mdot
.934 .44325 Mdot
.934 .44327 Mdot
.934 .44384 Mdot
.934 .44392 Mdot
.934 .44436 Mdot
.934 .44456 Mdot
.934 .44461 Mdot
.934 .44463 Mdot
.934 .44484 Mdot
.934 .44497 Mdot
.934 .44562 Mdot
.934 .4458 Mdot
.934 .44771 Mdot
.934 .4478 Mdot
.934 .44813 Mdot
.934 .44838 Mdot
.934 .44871 Mdot
.934 .44885 Mdot
.934 .44894 Mdot
.934 .44903 Mdot
.934 .44921 Mdot
.934 .4495 Mdot
.934 .4498 Mdot
.934 .45047 Mdot
.934 .4509 Mdot
.934 .45149 Mdot
.934 .45163 Mdot
.934 .45168 Mdot
.934 .4517 Mdot
.934 .4525 Mdot
.934 .45267 Mdot
.934 .45276 Mdot
.934 .45304 Mdot
.934 .45333 Mdot
.934 .45349 Mdot
.934 .45352 Mdot
.934 .45402 Mdot
.934 .45455 Mdot
.934 .45494 Mdot
.934 .45548 Mdot
.934 .45552 Mdot
.934 .45558 Mdot
.934 .45588 Mdot
.934 .45644 Mdot
.934 .45659 Mdot
.934 .45688 Mdot
.934 .45699 Mdot
.934 .45716 Mdot
.934 .4575 Mdot
.934 .45887 Mdot
.934 .45903 Mdot
.934 .45907 Mdot
.934 .45917 Mdot
.934 .45943 Mdot
.934 .46027 Mdot
.934 .46054 Mdot
.934 .46136 Mdot
.934 .46143 Mdot
.934 .46263 Mdot
.934 .46321 Mdot
.934 .46367 Mdot
.934 .46375 Mdot
.934 .46408 Mdot
.934 .46426 Mdot
.934 .46438 Mdot
.934 .46442 Mdot
.934 .46468 Mdot
.934 .46507 Mdot
.934 .4653 Mdot
.934 .46578 Mdot
.934 .46588 Mdot
.934 .46598 Mdot
.934 .46639 Mdot
.934 .46656 Mdot
.934 .46808 Mdot
.934 .46819 Mdot
.934 .46895 Mdot
.934 .47008 Mdot
.934 .47041 Mdot
.934 .4716 Mdot
.934 .47174 Mdot
.934 .47183 Mdot
.934 .47206 Mdot
.934 .47221 Mdot
.934 .47226 Mdot
.934 .47234 Mdot
.934 .4727 Mdot
.934 .47331 Mdot
.934 .47351 Mdot
.934 .47366 Mdot
.934 .47462 Mdot
.934 .47468 Mdot
.934 .47471 Mdot
.934 .47532 Mdot
.934 .47637 Mdot
.934 .47673 Mdot
.934 .47754 Mdot
.934 .47771 Mdot
.934 .47851 Mdot
.934 .47941 Mdot
.934 .47984 Mdot
.934 .47989 Mdot
.934 .48067 Mdot
.934 .48089 Mdot
.934 .48188 Mdot
.934 .48221 Mdot
.934 .48335 Mdot
.934 .48355 Mdot
.934 .48405 Mdot
.934 .48414 Mdot
.934 .48518 Mdot
.934 .48519 Mdot
.934 .48721 Mdot
.934 .48857 Mdot
.934 .48878 Mdot
.934 .48879 Mdot
.934 .48883 Mdot
.934 .48914 Mdot
.934 .49009 Mdot
.934 .49028 Mdot
.934 .49093 Mdot
.934 .49096 Mdot
.934 .49134 Mdot
.934 .49147 Mdot
.934 .49182 Mdot
.934 .49226 Mdot
.934 .49237 Mdot
.934 .4928 Mdot
.934 .49373 Mdot
.934 .49393 Mdot
.934 .49451 Mdot
.934 .49617 Mdot
.934 .49652 Mdot
.934 .49662 Mdot
.934 .49685 Mdot
.934 .49692 Mdot
.934 .49697 Mdot
.934 .49794 Mdot
.934 .49809 Mdot
.934 .49825 Mdot
.934 .49826 Mdot
.934 .49884 Mdot
.934 .49899 Mdot
.934 .50067 Mdot
.934 .50233 Mdot
.934 .50283 Mdot
.934 .50368 Mdot
.934 .5038 Mdot
.934 .50395 Mdot
.934 .50433 Mdot
.934 .50597 Mdot
.934 .50687 Mdot
.934 .5071 Mdot
.934 .50894 Mdot
.934 .51056 Mdot
.934 .51057 Mdot
.934 .51165 Mdot
.934 .51233 Mdot
.934 .51255 Mdot
.934 .51303 Mdot
.934 .5133 Mdot
.934 .51376 Mdot
.934 .51549 Mdot
.934 .51593 Mdot
.934 .51621 Mdot
.934 .51672 Mdot
.934 .51682 Mdot
.934 .51687 Mdot
.934 .51693 Mdot
.934 .51711 Mdot
.934 .51722 Mdot
.934 .51743 Mdot
.934 .51759 Mdot
.934 .5178 Mdot
.934 .51782 Mdot
.934 .51865 Mdot
.934 .51884 Mdot
.934 .51898 Mdot
.934 .51899 Mdot
.934 .52034 Mdot
.934 .52089 Mdot
.934 .5215 Mdot
.934 .52168 Mdot
.934 .52197 Mdot
.934 .5221 Mdot
.934 .52226 Mdot
.934 .52335 Mdot
.934 .52379 Mdot
.934 .52494 Mdot
.934 .525 Mdot
.934 .52512 Mdot
.934 .5252 Mdot
.934 .52569 Mdot
.934 .52572 Mdot
.934 .52601 Mdot
.934 .52609 Mdot
.934 .52704 Mdot
.934 .52751 Mdot
.934 .52834 Mdot
.934 .52852 Mdot
.934 .52884 Mdot
.934 .5291 Mdot
.934 .5302 Mdot
.934 .53127 Mdot
.934 .53261 Mdot
.934 .53277 Mdot
.934 .53333 Mdot
.934 .53364 Mdot
.934 .53381 Mdot
.934 .53414 Mdot
.934 .53541 Mdot
.934 .53577 Mdot
.934 .53589 Mdot
.934 .53595 Mdot
.934 .53604 Mdot
.934 .53646 Mdot
.934 .53688 Mdot
.934 .53748 Mdot
.934 .53792 Mdot
.934 .5385 Mdot
.934 .53874 Mdot
.934 .53888 Mdot
.934 .53901 Mdot
.934 .53908 Mdot
.934 .53952 Mdot
.934 .53957 Mdot
.934 .53989 Mdot
.934 .54019 Mdot
.934 .54035 Mdot
.934 .54144 Mdot
.934 .5419 Mdot
.934 .5425 Mdot
.934 .54311 Mdot
.934 .54365 Mdot
.934 .5458 Mdot
.934 .54642 Mdot
.934 .54658 Mdot
.934 .54668 Mdot
.934 .54729 Mdot
.934 .54731 Mdot
.934 .54733 Mdot
.934 .54736 Mdot
.934 .54784 Mdot
.934 .54896 Mdot
.934 .54909 Mdot
.934 .54913 Mdot
.934 .54965 Mdot
.934 .54974 Mdot
.934 .55017 Mdot
.934 .55122 Mdot
.934 .55147 Mdot
.934 .55159 Mdot
.934 .55162 Mdot
.934 .55168 Mdot
.934 .5533 Mdot
.934 .55367 Mdot
.934 .55389 Mdot
.934 .55431 Mdot
.934 .55434 Mdot
.934 .55561 Mdot
.934 .55617 Mdot
.934 .55671 Mdot
.934 .55709 Mdot
.934 .55805 Mdot
.934 .55824 Mdot
.934 .55865 Mdot
.934 .55923 Mdot
.934 .55952 Mdot
.934 .55994 Mdot
.934 .55999 Mdot
.934 .56045 Mdot
.934 .56057 Mdot
.934 .56059 Mdot
.934 .56092 Mdot
.934 .56094 Mdot
.934 .56106 Mdot
.934 .56129 Mdot
.934 .56182 Mdot
.934 .56203 Mdot
.934 .56234 Mdot
.934 .56238 Mdot
.934 .56255 Mdot
.934 .56277 Mdot
.934 .56285 Mdot
.934 .56287 Mdot
.934 .56292 Mdot
.934 .56297 Mdot
.934 .563 Mdot
.934 .5633 Mdot
.934 .56349 Mdot
.934 .56351 Mdot
.934 .56365 Mdot
.934 .5637 Mdot
.934 .56399 Mdot
.934 .56402 Mdot
.934 .56416 Mdot
.934 .56436 Mdot
.934 .56441 Mdot
.934 .56467 Mdot
.934 .56474 Mdot
.934 .56512 Mdot
.934 .56521 Mdot
.934 .56549 Mdot
.934 .56551 Mdot
.934 .56576 Mdot
.934 .5658 Mdot
.934 .56616 Mdot
.934 .56669 Mdot
.934 .56737 Mdot
.934 .56754 Mdot
.934 .56761 Mdot
.934 .56841 Mdot
.934 .56853 Mdot
.934 .56868 Mdot
.934 .56878 Mdot
.934 .56941 Mdot
.934 .56948 Mdot
.934 .56989 Mdot
.934 .57006 Mdot
.934 .5703 Mdot
.934 .57053 Mdot
.934 .57111 Mdot
.934 .57139 Mdot
.934 .57212 Mdot
.934 .57235 Mdot
.934 .57243 Mdot
.934 .57249 Mdot
.934 .57279 Mdot
.934 .5732 Mdot
.934 .57358 Mdot
.934 .57363 Mdot
.934 .57467 Mdot
.934 .57647 Mdot
.934 .5769 Mdot
.934 .57717 Mdot
.934 .57718 Mdot
.934 .57754 Mdot
.934 .57766 Mdot
.934 .57818 Mdot
.934 .57827 Mdot
.934 .57844 Mdot
.934 .57882 Mdot
.934 .57895 Mdot
.934 .57903 Mdot
.934 .57932 Mdot
.934 .57963 Mdot
.934 .58046 Mdot
.934 .58062 Mdot
.934 .58086 Mdot
.934 .58112 Mdot
.934 .58113 Mdot
.934 .58204 Mdot
.934 .58213 Mdot
.934 .58227 Mdot
.934 .58397 Mdot
.934 .58471 Mdot
.934 .58515 Mdot
.934 .58572 Mdot
.934 .58611 Mdot
.934 .58658 Mdot
.934 .58668 Mdot
.934 .58683 Mdot
.934 .5869 Mdot
.934 .58751 Mdot
.934 .58798 Mdot
.934 .58851 Mdot
.934 .58853 Mdot
.934 .58858 Mdot
.934 .58864 Mdot
.934 .58881 Mdot
.934 .58922 Mdot
.934 .58962 Mdot
.934 .58965 Mdot
.934 .58973 Mdot
.934 .58982 Mdot
.934 .59014 Mdot
.934 .59018 Mdot
.934 .59071 Mdot
.934 .59079 Mdot
.934 .59087 Mdot
.934 .59091 Mdot
.934 .59092 Mdot
.934 .59098 Mdot
.934 .5913 Mdot
.934 .59168 Mdot
.934 .59188 Mdot
.934 .59206 Mdot
.934 .59244 Mdot
.934 .59256 Mdot
.934 .59282 Mdot
.934 .59295 Mdot
.934 .59306 Mdot
.934 .59322 Mdot
.934 .59325 Mdot
.934 .59328 Mdot
.934 .59339 Mdot
.934 .59347 Mdot
.934 .59348 Mdot
.934 .59367 Mdot
.934 .59378 Mdot
.934 .59414 Mdot
.934 .59421 Mdot
.934 .59421 Mdot
.934 .59426 Mdot
.934 .59443 Mdot
.934 .59447 Mdot
.934 .5946 Mdot
.934 .59471 Mdot
.934 .59497 Mdot
.934 .59497 Mdot
.934 .59499 Mdot
.934 .59499 Mdot
.934 .59499 Mdot
.934 .59501 Mdot
.934 .59504 Mdot
.934 .59504 Mdot
.934 .5951 Mdot
.934 .59518 Mdot
.934 .59525 Mdot
.934 .59527 Mdot
.934 .59531 Mdot
.934 .59532 Mdot
.934 .59533 Mdot
.934 .59535 Mdot
.934 .59537 Mdot
.934 .5954 Mdot
.934 .59543 Mdot
.934 .59544 Mdot
.934 .59545 Mdot
.934 .59547 Mdot
.934 .59548 Mdot
.934 .59549 Mdot
.934 .5955 Mdot
.934 .59551 Mdot
.934 .59554 Mdot
.934 .59555 Mdot
.934 .59555 Mdot
.936 .04409 Mdot
.936 .04415 Mdot
.936 .04418 Mdot
.936 .04418 Mdot
.936 .04419 Mdot
.936 .04421 Mdot
.936 .04463 Mdot
.936 .04481 Mdot
.936 .04481 Mdot
.936 .04502 Mdot
.936 .04543 Mdot
.936 .04575 Mdot
.936 .04634 Mdot
.936 .04664 Mdot
.936 .04698 Mdot
.936 .0473 Mdot
.936 .04742 Mdot
.936 .04778 Mdot
.936 .04798 Mdot
.936 .04801 Mdot
.936 .04854 Mdot
.936 .04872 Mdot
.936 .04901 Mdot
.936 .05024 Mdot
.936 .05075 Mdot
.936 .05122 Mdot
.936 .05131 Mdot
.936 .05153 Mdot
.936 .05167 Mdot
.936 .05168 Mdot
.936 .05181 Mdot
.936 .05186 Mdot
.936 .05193 Mdot
.936 .05265 Mdot
.936 .05298 Mdot
.936 .05301 Mdot
.936 .05307 Mdot
.936 .05324 Mdot
.936 .05375 Mdot
.936 .05378 Mdot
.936 .0548 Mdot
.936 .05486 Mdot
.936 .05489 Mdot
.936 .05514 Mdot
.936 .0573 Mdot
.936 .05735 Mdot
.936 .0574 Mdot
.936 .05795 Mdot
.936 .05817 Mdot
.936 .05841 Mdot
.936 .05856 Mdot
.936 .05897 Mdot
.936 .05914 Mdot
.936 .05928 Mdot
.936 .0597 Mdot
.936 .06002 Mdot
.936 .06321 Mdot
.936 .06376 Mdot
.936 .06394 Mdot
.936 .06453 Mdot
.936 .06479 Mdot
.936 .06712 Mdot
.936 .06739 Mdot
.936 .06838 Mdot
.936 .06844 Mdot
.936 .06854 Mdot
.936 .06913 Mdot
.936 .06915 Mdot
.936 .06923 Mdot
.936 .06985 Mdot
.936 .07003 Mdot
.936 .07024 Mdot
.936 .0707 Mdot
.936 .07095 Mdot
.936 .07136 Mdot
.936 .07177 Mdot
.936 .0729 Mdot
.936 .07292 Mdot
.936 .07376 Mdot
.936 .07432 Mdot
.936 .0744 Mdot
.936 .07467 Mdot
.936 .07629 Mdot
.936 .07679 Mdot
.936 .07758 Mdot
.936 .07792 Mdot
.936 .07855 Mdot
.936 .07968 Mdot
.936 .08131 Mdot
.936 .08143 Mdot
.936 .08252 Mdot
.936 .08434 Mdot
.936 .08466 Mdot
.936 .08477 Mdot
.936 .08648 Mdot
.936 .08667 Mdot
.936 .08682 Mdot
.936 .08689 Mdot
.936 .08829 Mdot
.936 .09031 Mdot
.936 .09231 Mdot
.936 .09346 Mdot
.936 .09371 Mdot
.936 .09387 Mdot
.936 .09391 Mdot
.936 .09492 Mdot
.936 .09557 Mdot
.936 .09567 Mdot
.936 .09617 Mdot
.936 .09635 Mdot
.936 .09968 Mdot
.936 .1017 Mdot
.936 .10418 Mdot
.936 .10566 Mdot
.936 .10716 Mdot
.936 .10815 Mdot
.936 .10856 Mdot
.936 .10896 Mdot
.936 .10912 Mdot
.936 .10938 Mdot
.936 .10939 Mdot
.936 .11063 Mdot
.936 .11136 Mdot
.936 .11372 Mdot
.936 .11432 Mdot
.936 .11451 Mdot
.936 .116 Mdot
.936 .11659 Mdot
.936 .11765 Mdot
.936 .11868 Mdot
.936 .12491 Mdot
.936 .12513 Mdot
.936 .12523 Mdot
.936 .12524 Mdot
.936 .12529 Mdot
.936 .12534 Mdot
.936 .12536 Mdot
.936 .12588 Mdot
.936 .12684 Mdot
.936 .12747 Mdot
.936 .1275 Mdot
.936 .12821 Mdot
.936 .12968 Mdot
.936 .13081 Mdot
.936 .13135 Mdot
.936 .13165 Mdot
.936 .13288 Mdot
.936 .13288 Mdot
.936 .13357 Mdot
.936 .13363 Mdot
.936 .13374 Mdot
.936 .13394 Mdot
.936 .13396 Mdot
.936 .13432 Mdot
.936 .13448 Mdot
.936 .13513 Mdot
.936 .13513 Mdot
.936 .13614 Mdot
.936 .13627 Mdot
.936 .13669 Mdot
.936 .13795 Mdot
.936 .13813 Mdot
.936 .1385 Mdot
.936 .13862 Mdot
.936 .13864 Mdot
.936 .13877 Mdot
.936 .14057 Mdot
.936 .14061 Mdot
.936 .14123 Mdot
.936 .14224 Mdot
.936 .14514 Mdot
.936 .14655 Mdot
.936 .1483 Mdot
.936 .14973 Mdot
.936 .14993 Mdot
.936 .14996 Mdot
.936 .15024 Mdot
.936 .151 Mdot
.936 .15108 Mdot
.936 .15147 Mdot
.936 .15151 Mdot
.936 .15197 Mdot
.936 .15214 Mdot
.936 .15238 Mdot
.936 .1534 Mdot
.936 .15488 Mdot
.936 .1553 Mdot
.936 .15536 Mdot
.936 .156 Mdot
.936 .1561 Mdot
.936 .15631 Mdot
.936 .1569 Mdot
.936 .15694 Mdot
.936 .15743 Mdot
.936 .15863 Mdot
.936 .15874 Mdot
.936 .15973 Mdot
.936 .16065 Mdot
.936 .16078 Mdot
.936 .16196 Mdot
.936 .16224 Mdot
.936 .16231 Mdot
.936 .16234 Mdot
.936 .16245 Mdot
.936 .16254 Mdot
.936 .16337 Mdot
.936 .16639 Mdot
.936 .16656 Mdot
.936 .16816 Mdot
.936 .17071 Mdot
.936 .17081 Mdot
.936 .17088 Mdot
.936 .17105 Mdot
.936 .17133 Mdot
.936 .17162 Mdot
.936 .17289 Mdot
.936 .1729 Mdot
.936 .17363 Mdot
.936 .17447 Mdot
.936 .17496 Mdot
.936 .17544 Mdot
.936 .17624 Mdot
.936 .17632 Mdot
.936 .17691 Mdot
.936 .17736 Mdot
.936 .17738 Mdot
.936 .17771 Mdot
.936 .17798 Mdot
.936 .17877 Mdot
.936 .1795 Mdot
.936 .17971 Mdot
.936 .17978 Mdot
.936 .17984 Mdot
.936 .18151 Mdot
.936 .18215 Mdot
.936 .1851 Mdot
.936 .18811 Mdot
.936 .1898 Mdot
.936 .19044 Mdot
.936 .1911 Mdot
.936 .19158 Mdot
.936 .19158 Mdot
.936 .19213 Mdot
.936 .19214 Mdot
.936 .19226 Mdot
.936 .19284 Mdot
.936 .19478 Mdot
.936 .19524 Mdot
.936 .19563 Mdot
.936 .19783 Mdot
.936 .19833 Mdot
.936 .19925 Mdot
.936 .20094 Mdot
.936 .20111 Mdot
.936 .20261 Mdot
.936 .20285 Mdot
.936 .20305 Mdot
.936 .20322 Mdot
.936 .20395 Mdot
.936 .20409 Mdot
.936 .20412 Mdot
.936 .20486 Mdot
.936 .20545 Mdot
.936 .20584 Mdot
.936 .20672 Mdot
.936 .20731 Mdot
.936 .20749 Mdot
.936 .20783 Mdot
.936 .20794 Mdot
.936 .20974 Mdot
.936 .20978 Mdot
.936 .21004 Mdot
.936 .21048 Mdot
.936 .21089 Mdot
.936 .2109 Mdot
.936 .21206 Mdot
.936 .2126 Mdot
.936 .21313 Mdot
.936 .21328 Mdot
.936 .21354 Mdot
.936 .21418 Mdot
.936 .21477 Mdot
.936 .21558 Mdot
.936 .21686 Mdot
.936 .21817 Mdot
.936 .2183 Mdot
.936 .2187 Mdot
.936 .21898 Mdot
.936 .2195 Mdot
.936 .22005 Mdot
.936 .2206 Mdot
.936 .22177 Mdot
.936 .22182 Mdot
.936 .22288 Mdot
.936 .22307 Mdot
.936 .22419 Mdot
.936 .22448 Mdot
.936 .22626 Mdot
.936 .2265 Mdot
.936 .22734 Mdot
.936 .22741 Mdot
.936 .2295 Mdot
.936 .23068 Mdot
.936 .23155 Mdot
.936 .23243 Mdot
.936 .23349 Mdot
.936 .234 Mdot
.936 .23454 Mdot
.936 .23472 Mdot
.936 .23506 Mdot
.936 .23607 Mdot
.936 .23646 Mdot
.936 .23654 Mdot
.936 .23663 Mdot
.936 .23752 Mdot
.936 .23806 Mdot
.936 .23932 Mdot
.936 .23933 Mdot
.936 .23944 Mdot
.936 .23981 Mdot
.936 .23985 Mdot
.936 .24014 Mdot
.936 .24087 Mdot
.936 .24103 Mdot
.936 .24154 Mdot
.936 .24217 Mdot
.936 .24292 Mdot
.936 .24643 Mdot
.936 .24709 Mdot
.936 .24795 Mdot
.936 .2483 Mdot
.936 .24953 Mdot
.936 .25161 Mdot
.936 .25181 Mdot
.936 .25429 Mdot
.936 .25509 Mdot
.936 .25532 Mdot
.936 .2559 Mdot
.936 .25621 Mdot
.936 .25714 Mdot
.936 .25743 Mdot
.936 .25793 Mdot
.936 .25794 Mdot
.936 .25811 Mdot
.936 .25827 Mdot
.936 .25843 Mdot
.936 .26007 Mdot
.936 .262 Mdot
.936 .26354 Mdot
.936 .26377 Mdot
.936 .26411 Mdot
.936 .26456 Mdot
.936 .26458 Mdot
.936 .26466 Mdot
.936 .26477 Mdot
.936 .26624 Mdot
.936 .268 Mdot
.936 .26894 Mdot
.936 .26899 Mdot
.936 .26915 Mdot
.936 .27008 Mdot
.936 .27252 Mdot
.936 .27271 Mdot
.936 .27455 Mdot
.936 .27488 Mdot
.936 .27631 Mdot
.936 .27671 Mdot
.936 .27768 Mdot
.936 .27806 Mdot
.936 .2788 Mdot
.936 .28074 Mdot
.936 .28115 Mdot
.936 .28128 Mdot
.936 .28408 Mdot
.936 .28467 Mdot
.936 .28478 Mdot
.936 .28492 Mdot
.936 .28525 Mdot
.936 .28538 Mdot
.936 .28558 Mdot
.936 .28577 Mdot
.936 .28623 Mdot
.936 .28827 Mdot
.936 .28859 Mdot
.936 .29014 Mdot
.936 .29041 Mdot
.936 .29155 Mdot
.936 .29168 Mdot
.936 .29185 Mdot
.936 .29226 Mdot
.936 .29236 Mdot
.936 .29355 Mdot
.936 .29519 Mdot
.936 .29587 Mdot
.936 .29667 Mdot
.936 .29673 Mdot
.936 .29704 Mdot
.936 .29764 Mdot
.936 .29784 Mdot
.936 .29842 Mdot
.936 .29906 Mdot
.936 .30179 Mdot
.936 .30369 Mdot
.936 .30441 Mdot
.936 .30744 Mdot
.936 .30871 Mdot
.936 .3109 Mdot
.936 .31093 Mdot
.936 .31106 Mdot
.936 .31125 Mdot
.936 .31431 Mdot
.936 .31503 Mdot
.936 .31706 Mdot
.936 .31836 Mdot
.936 .32243 Mdot
.936 .32511 Mdot
.936 .32603 Mdot
.936 .3262 Mdot
.936 .3264 Mdot
.936 .32727 Mdot
.936 .32765 Mdot
.936 .32772 Mdot
.936 .32841 Mdot
.936 .32844 Mdot
.936 .3295 Mdot
.936 .32953 Mdot
.936 .33171 Mdot
.936 .33176 Mdot
.936 .3337 Mdot
.936 .33636 Mdot
.936 .33747 Mdot
.936 .33905 Mdot
.936 .33987 Mdot
.936 .3399 Mdot
.936 .34036 Mdot
.936 .34041 Mdot
.936 .3408 Mdot
.936 .34091 Mdot
.936 .34104 Mdot
.936 .34148 Mdot
.936 .34198 Mdot
.936 .34265 Mdot
.936 .34266 Mdot
.936 .34353 Mdot
.936 .34368 Mdot
.936 .3446 Mdot
.936 .34489 Mdot
.936 .34585 Mdot
.936 .34646 Mdot
.936 .34732 Mdot
.936 .34738 Mdot
.936 .34994 Mdot
.936 .35011 Mdot
.936 .35015 Mdot
.936 .35083 Mdot
.936 .35273 Mdot
.936 .35422 Mdot
.936 .35457 Mdot
.936 .35691 Mdot
.936 .35858 Mdot
.936 .35919 Mdot
.936 .35999 Mdot
.936 .36206 Mdot
.936 .36335 Mdot
.936 .3684 Mdot
.936 .36894 Mdot
.936 .36918 Mdot
.936 .3692 Mdot
.936 .36924 Mdot
.936 .36932 Mdot
.936 .36945 Mdot
.936 .3695 Mdot
.936 .37077 Mdot
.936 .3709 Mdot
.936 .37315 Mdot
.936 .37467 Mdot
.936 .37474 Mdot
.936 .37648 Mdot
.936 .38002 Mdot
.936 .38133 Mdot
.936 .38273 Mdot
.936 .38341 Mdot
.936 .38395 Mdot
.936 .38401 Mdot
.936 .38473 Mdot
.936 .38697 Mdot
.936 .38749 Mdot
.936 .38749 Mdot
.936 .38764 Mdot
.936 .38765 Mdot
.936 .38927 Mdot
.936 .38942 Mdot
.936 .38968 Mdot
.936 .39015 Mdot
.936 .3902 Mdot
.936 .39075 Mdot
.936 .391 Mdot
.936 .39104 Mdot
.936 .39126 Mdot
.936 .39142 Mdot
.936 .39211 Mdot
.936 .39282 Mdot
.936 .39293 Mdot
.936 .39294 Mdot
.936 .39366 Mdot
.936 .39508 Mdot
.936 .39529 Mdot
.936 .39544 Mdot
.936 .39559 Mdot
.936 .39656 Mdot
.936 .3983 Mdot
.936 .39938 Mdot
.936 .39947 Mdot
.936 .39988 Mdot
.936 .40026 Mdot
.936 .40059 Mdot
.936 .40059 Mdot
.936 .40072 Mdot
.936 .40073 Mdot
.936 .40081 Mdot
.936 .401 Mdot
.936 .40104 Mdot
.936 .40134 Mdot
.936 .40263 Mdot
.936 .4047 Mdot
.936 .40498 Mdot
.936 .4053 Mdot
.936 .40543 Mdot
.936 .40551 Mdot
.936 .40692 Mdot
.936 .40853 Mdot
.936 .40914 Mdot
.936 .40919 Mdot
.936 .40965 Mdot
.936 .41044 Mdot
.936 .41135 Mdot
.936 .41226 Mdot
.936 .41242 Mdot
.936 .41247 Mdot
.936 .41441 Mdot
.936 .4152 Mdot
.936 .41527 Mdot
.936 .41547 Mdot
.936 .41562 Mdot
.936 .41577 Mdot
.936 .41815 Mdot
.936 .41869 Mdot
.936 .4187 Mdot
.936 .41873 Mdot
.936 .42249 Mdot
.936 .42325 Mdot
.936 .42379 Mdot
.936 .42492 Mdot
.936 .42557 Mdot
.936 .426 Mdot
.936 .42603 Mdot
.936 .42606 Mdot
.936 .42667 Mdot
.936 .4267 Mdot
.936 .427 Mdot
.936 .42738 Mdot
.936 .42828 Mdot
.936 .42844 Mdot
.936 .42927 Mdot
.936 .42935 Mdot
.936 .43033 Mdot
.936 .43048 Mdot
.936 .43067 Mdot
.936 .43118 Mdot
.936 .43149 Mdot
.936 .43333 Mdot
.936 .43639 Mdot
.936 .43727 Mdot
.936 .43739 Mdot
.936 .43739 Mdot
.936 .4387 Mdot
.936 .43891 Mdot
.936 .43935 Mdot
.936 .44054 Mdot
.936 .44062 Mdot
.936 .44062 Mdot
.936 .44164 Mdot
.936 .44274 Mdot
.936 .44287 Mdot
.936 .44329 Mdot
.936 .44352 Mdot
.936 .44357 Mdot
.936 .44406 Mdot
.936 .44426 Mdot
.936 .44427 Mdot
.936 .44432 Mdot
.936 .445 Mdot
.936 .44628 Mdot
.936 .44811 Mdot
.936 .44837 Mdot
.936 .45071 Mdot
.936 .45126 Mdot
.936 .45129 Mdot
.936 .4514 Mdot
.936 .45146 Mdot
.936 .45167 Mdot
.936 .45184 Mdot
.936 .45348 Mdot
.936 .45578 Mdot
.936 .45894 Mdot
.936 .45927 Mdot
.936 .45931 Mdot
.936 .45964 Mdot
.936 .45967 Mdot
.936 .45978 Mdot
.936 .45999 Mdot
.936 .46005 Mdot
.936 .4611 Mdot
.936 .46267 Mdot
.936 .46551 Mdot
.936 .46599 Mdot
.936 .46745 Mdot
.936 .46763 Mdot
.936 .46777 Mdot
.936 .46809 Mdot
.936 .46861 Mdot
.936 .46914 Mdot
.936 .46939 Mdot
.936 .47147 Mdot
.936 .47149 Mdot
.936 .47174 Mdot
.936 .47282 Mdot
.936 .47296 Mdot
.936 .47305 Mdot
.936 .47309 Mdot
.936 .47344 Mdot
.936 .47432 Mdot
.936 .47434 Mdot
.936 .47441 Mdot
.936 .47482 Mdot
.936 .47523 Mdot
.936 .47558 Mdot
.936 .47581 Mdot
.936 .47609 Mdot
.936 .47752 Mdot
.936 .47766 Mdot
.936 .47779 Mdot
.936 .4787 Mdot
.936 .4795 Mdot
.936 .47953 Mdot
.936 .47959 Mdot
.936 .47959 Mdot
.936 .47973 Mdot
.936 .48012 Mdot
.936 .48059 Mdot
.936 .48183 Mdot
.936 .48198 Mdot
.936 .48259 Mdot
.936 .48295 Mdot
.936 .48325 Mdot
.936 .48362 Mdot
.936 .48373 Mdot
.936 .48384 Mdot
.936 .48522 Mdot
.936 .48522 Mdot
.936 .48544 Mdot
.936 .48671 Mdot
.936 .48694 Mdot
.936 .48781 Mdot
.936 .49211 Mdot
.936 .49278 Mdot
.936 .49515 Mdot
.936 .49567 Mdot
.936 .49649 Mdot
.936 .49681 Mdot
.936 .49705 Mdot
.936 .49771 Mdot
.936 .49864 Mdot
.936 .49877 Mdot
.936 .5001 Mdot
.936 .50037 Mdot
.936 .50044 Mdot
.936 .50146 Mdot
.936 .5018 Mdot
.936 .5024 Mdot
.936 .50251 Mdot
.936 .50287 Mdot
.936 .50293 Mdot
.936 .50326 Mdot
.936 .50326 Mdot
.936 .50388 Mdot
.936 .50393 Mdot
.936 .50397 Mdot
.936 .50412 Mdot
.936 .50414 Mdot
.936 .50433 Mdot
.936 .50464 Mdot
.936 .50524 Mdot
.936 .50566 Mdot
.936 .50742 Mdot
.936 .50824 Mdot
.936 .50824 Mdot
.936 .50894 Mdot
.936 .5094 Mdot
.936 .50954 Mdot
.936 .51285 Mdot
.936 .51359 Mdot
.936 .51496 Mdot
.936 .51503 Mdot
.936 .51508 Mdot
.936 .51508 Mdot
.936 .51588 Mdot
.936 .51742 Mdot
.936 .51768 Mdot
.936 .51932 Mdot
.936 .51955 Mdot
.936 .51976 Mdot
.936 .51983 Mdot
.936 .52004 Mdot
.936 .52015 Mdot
.936 .52017 Mdot
.936 .52045 Mdot
.936 .52069 Mdot
.936 .52127 Mdot
.936 .52172 Mdot
.936 .52192 Mdot
.936 .52197 Mdot
.936 .523 Mdot
.936 .52382 Mdot
.936 .52398 Mdot
.936 .52405 Mdot
.936 .52428 Mdot
.936 .52437 Mdot
.936 .52553 Mdot
.936 .52558 Mdot
.936 .52638 Mdot
.936 .52664 Mdot
.936 .52677 Mdot
.936 .5271 Mdot
.936 .52724 Mdot
.936 .52784 Mdot
.936 .52846 Mdot
.936 .52853 Mdot
.936 .52935 Mdot
.936 .52967 Mdot
.936 .52972 Mdot
.936 .53006 Mdot
.936 .53065 Mdot
.936 .53118 Mdot
.936 .53121 Mdot
.936 .53148 Mdot
.936 .53207 Mdot
.936 .53271 Mdot
.936 .53331 Mdot
.936 .53343 Mdot
.936 .53343 Mdot
.936 .53359 Mdot
.936 .534 Mdot
.936 .5341 Mdot
.936 .53429 Mdot
.936 .53437 Mdot
.936 .53463 Mdot
.936 .53545 Mdot
.936 .5362 Mdot
.936 .537 Mdot
.936 .53722 Mdot
.936 .5386 Mdot
.936 .53881 Mdot
.936 .53897 Mdot
.936 .53902 Mdot
.936 .53926 Mdot
.936 .53935 Mdot
.936 .53937 Mdot
.936 .53952 Mdot
.936 .53952 Mdot
.936 .53993 Mdot
.936 .54039 Mdot
.936 .54042 Mdot
.936 .54057 Mdot
.936 .5409 Mdot
.936 .54101 Mdot
.936 .54107 Mdot
.936 .5414 Mdot
.936 .54202 Mdot
.936 .5423 Mdot
.936 .54268 Mdot
.936 .54335 Mdot
.936 .54437 Mdot
.936 .54472 Mdot
.936 .54478 Mdot
.936 .5455 Mdot
.936 .54568 Mdot
.936 .54585 Mdot
.936 .54601 Mdot
.936 .5461 Mdot
.936 .54622 Mdot
.936 .54751 Mdot
.936 .54771 Mdot
.936 .54784 Mdot
.936 .54854 Mdot
.936 .54854 Mdot
.936 .54867 Mdot
.936 .54946 Mdot
.936 .54984 Mdot
.936 .55011 Mdot
.936 .55023 Mdot
.936 .55041 Mdot
.936 .55065 Mdot
.936 .55069 Mdot
.936 .55097 Mdot
.936 .55103 Mdot
.936 .5511 Mdot
.936 .55156 Mdot
.936 .55162 Mdot
.936 .55214 Mdot
.936 .55242 Mdot
.936 .55257 Mdot
.936 .55336 Mdot
.936 .55431 Mdot
.936 .55431 Mdot
.936 .55448 Mdot
.936 .55448 Mdot
.936 .55462 Mdot
.936 .55501 Mdot
.936 .55553 Mdot
.936 .55643 Mdot
.936 .55732 Mdot
.936 .55752 Mdot
.936 .55803 Mdot
.936 .55805 Mdot
.936 .55812 Mdot
.936 .55857 Mdot
.936 .55865 Mdot
.936 .55876 Mdot
.936 .55909 Mdot
.936 .55933 Mdot
.936 .56008 Mdot
.936 .56046 Mdot
.936 .56055 Mdot
.936 .56064 Mdot
.936 .56071 Mdot
.936 .56149 Mdot
.936 .56196 Mdot
.936 .56201 Mdot
.936 .5632 Mdot
.936 .56321 Mdot
.936 .56331 Mdot
.936 .56366 Mdot
.936 .56369 Mdot
.936 .56396 Mdot
.936 .56463 Mdot
.936 .56478 Mdot
.936 .56524 Mdot
.936 .56526 Mdot
.936 .56581 Mdot
.936 .56648 Mdot
.936 .5668 Mdot
.936 .56687 Mdot
.936 .56819 Mdot
.936 .56951 Mdot
.936 .57006 Mdot
.936 .5701 Mdot
.936 .5702 Mdot
.936 .57077 Mdot
.936 .57106 Mdot
.936 .57124 Mdot
.936 .57129 Mdot
.936 .57139 Mdot
.936 .57145 Mdot
.936 .57148 Mdot
.936 .5715 Mdot
.936 .5717 Mdot
.936 .57204 Mdot
.936 .57213 Mdot
.936 .57368 Mdot
.936 .57383 Mdot
.936 .5757 Mdot
.936 .57598 Mdot
.936 .57628 Mdot
.936 .57644 Mdot
.936 .57686 Mdot
.936 .57691 Mdot
.936 .57708 Mdot
.936 .57773 Mdot
.936 .57793 Mdot
.936 .57828 Mdot
.936 .57828 Mdot
.936 .57835 Mdot
.936 .5784 Mdot
.936 .57851 Mdot
.936 .57862 Mdot
.936 .57889 Mdot
.936 .57931 Mdot
.936 .57972 Mdot
.936 .5804 Mdot
.936 .58095 Mdot
.936 .58186 Mdot
.936 .58191 Mdot
.936 .58205 Mdot
.936 .58208 Mdot
.936 .58225 Mdot
.936 .58253 Mdot
.936 .58254 Mdot
.936 .58258 Mdot
.936 .58265 Mdot
.936 .58296 Mdot
.936 .58351 Mdot
.936 .58406 Mdot
.936 .58444 Mdot
.936 .58445 Mdot
.936 .5845 Mdot
.936 .58455 Mdot
.936 .58501 Mdot
.936 .58504 Mdot
.936 .58512 Mdot
.936 .58562 Mdot
.936 .58591 Mdot
.936 .58594 Mdot
.936 .58638 Mdot
.936 .58668 Mdot
.936 .58685 Mdot
.936 .58694 Mdot
.936 .58715 Mdot
.936 .58729 Mdot
.936 .58772 Mdot
.936 .58779 Mdot
.936 .58782 Mdot
.936 .58797 Mdot
.936 .58819 Mdot
.936 .58819 Mdot
.936 .5885 Mdot
.936 .58861 Mdot
.936 .58871 Mdot
.936 .58878 Mdot
.936 .58891 Mdot
.936 .58896 Mdot
.936 .58901 Mdot
.936 .58917 Mdot
.936 .5892 Mdot
.936 .5892 Mdot
.936 .58936 Mdot
.936 .58938 Mdot
.936 .5894 Mdot
.936 .58966 Mdot
.936 .58974 Mdot
.936 .59035 Mdot
.936 .59042 Mdot
.936 .59058 Mdot
.936 .59062 Mdot
.936 .59077 Mdot
.936 .59161 Mdot
.936 .5917 Mdot
.936 .59181 Mdot
.936 .59184 Mdot
.936 .59189 Mdot
.936 .592 Mdot
.936 .59204 Mdot
.936 .5921 Mdot
.936 .59216 Mdot
.936 .5923 Mdot
.936 .59232 Mdot
.936 .59233 Mdot
.936 .5929 Mdot
.936 .59296 Mdot
.936 .59297 Mdot
.936 .59299 Mdot
.936 .59325 Mdot
.936 .59326 Mdot
.936 .5934 Mdot
.936 .59344 Mdot
.936 .59346 Mdot
.936 .59346 Mdot
.936 .59355 Mdot
.936 .59374 Mdot
.936 .59376 Mdot
.936 .59377 Mdot
.936 .5938 Mdot
.936 .59381 Mdot
.936 .59384 Mdot
.936 .5939 Mdot
.936 .59392 Mdot
.936 .59405 Mdot
.936 .59418 Mdot
.936 .5945 Mdot
.936 .59458 Mdot
.936 .59462 Mdot
.936 .59476 Mdot
.936 .59477 Mdot
.936 .59482 Mdot
.936 .59492 Mdot
.936 .59495 Mdot
.936 .59503 Mdot
.936 .59512 Mdot
.936 .5952 Mdot
.936 .59535 Mdot
.936 .59543 Mdot
.936 .59554 Mdot
.936 .5956 Mdot
.936 .5956 Mdot
.936 .59564 Mdot
.936 .59575 Mdot
.936 .59576 Mdot
.936 .59576 Mdot
.936 .59576 Mdot
.936 .59577 Mdot
.936 .59578 Mdot
.938 .0432 Mdot
.938 .04325 Mdot
.938 .04327 Mdot
.938 .04329 Mdot
.938 .04343 Mdot
.938 .04394 Mdot
.938 .04407 Mdot
.938 .04442 Mdot
.938 .04448 Mdot
.938 .04458 Mdot
.938 .04462 Mdot
.938 .04484 Mdot
.938 .04485 Mdot
.938 .04509 Mdot
.938 .04526 Mdot
.938 .04535 Mdot
.938 .04556 Mdot
.938 .04577 Mdot
.938 .04599 Mdot
.938 .04601 Mdot
.938 .0461 Mdot
.938 .04641 Mdot
.938 .04652 Mdot
.938 .0468 Mdot
.938 .04723 Mdot
.938 .04752 Mdot
.938 .04756 Mdot
.938 .04807 Mdot
.938 .04814 Mdot
.938 .04877 Mdot
.938 .04923 Mdot
.938 .05033 Mdot
.938 .05047 Mdot
.938 .05081 Mdot
.938 .0513 Mdot
.938 .05141 Mdot
.938 .05239 Mdot
.938 .05284 Mdot
.938 .0535 Mdot
.938 .05353 Mdot
.938 .05395 Mdot
.938 .05412 Mdot
.938 .05468 Mdot
.938 .05509 Mdot
.938 .05565 Mdot
.938 .05585 Mdot
.938 .05599 Mdot
.938 .05639 Mdot
.938 .05683 Mdot
.938 .05712 Mdot
.938 .05835 Mdot
.938 .0587 Mdot
.938 .05954 Mdot
.938 .06036 Mdot
.938 .06046 Mdot
.938 .06159 Mdot
.938 .0618 Mdot
.938 .06216 Mdot
.938 .06256 Mdot
.938 .06308 Mdot
.938 .06371 Mdot
.938 .06418 Mdot
.938 .06456 Mdot
.938 .06491 Mdot
.938 .06521 Mdot
.938 .06589 Mdot
.938 .06764 Mdot
.938 .06872 Mdot
.938 .06982 Mdot
.938 .06985 Mdot
.938 .07101 Mdot
.938 .0728 Mdot
.938 .07312 Mdot
.938 .07415 Mdot
.938 .07424 Mdot
.938 .07517 Mdot
.938 .07551 Mdot
.938 .07559 Mdot
.938 .0761 Mdot
.938 .07622 Mdot
.938 .07715 Mdot
.938 .07763 Mdot
.938 .07838 Mdot
.938 .08032 Mdot
.938 .08043 Mdot
.938 .08201 Mdot
.938 .08224 Mdot
.938 .08251 Mdot
.938 .08278 Mdot
.938 .08374 Mdot
.938 .08554 Mdot
.938 .08631 Mdot
.938 .08654 Mdot
.938 .08712 Mdot
.938 .08773 Mdot
.938 .08937 Mdot
.938 .09001 Mdot
.938 .09029 Mdot
.938 .0909 Mdot
.938 .09254 Mdot
.938 .09274 Mdot
.938 .09365 Mdot
.938 .094 Mdot
.938 .09474 Mdot
.938 .09588 Mdot
.938 .09625 Mdot
.938 .09678 Mdot
.938 .09759 Mdot
.938 .09761 Mdot
.938 .09936 Mdot
.938 .1016 Mdot
.938 .10251 Mdot
.938 .10434 Mdot
.938 .10534 Mdot
.938 .10636 Mdot
.938 .11043 Mdot
.938 .1107 Mdot
.938 .11153 Mdot
.938 .11179 Mdot
.938 .11211 Mdot
.938 .11227 Mdot
.938 .11496 Mdot
.938 .1155 Mdot
.938 .11561 Mdot
.938 .11583 Mdot
.938 .11649 Mdot
.938 .11687 Mdot
.938 .11793 Mdot
.938 .11956 Mdot
.938 .12053 Mdot
.938 .12182 Mdot
.938 .12199 Mdot
.938 .12203 Mdot
.938 .12211 Mdot
.938 .12261 Mdot
.938 .12263 Mdot
.938 .12276 Mdot
.938 .12282 Mdot
.938 .12323 Mdot
.938 .12378 Mdot
.938 .12444 Mdot
.938 .12492 Mdot
.938 .12493 Mdot
.938 .12614 Mdot
.938 .12636 Mdot
.938 .12642 Mdot
.938 .1267 Mdot
.938 .12671 Mdot
.938 .12685 Mdot
.938 .12716 Mdot
.938 .12764 Mdot
.938 .12767 Mdot
.938 .12775 Mdot
.938 .12807 Mdot
.938 .12851 Mdot
.938 .12912 Mdot
.938 .12914 Mdot
.938 .12943 Mdot
.938 .13018 Mdot
.938 .13091 Mdot
.938 .13104 Mdot
.938 .13115 Mdot
.938 .13142 Mdot
.938 .13171 Mdot
.938 .13176 Mdot
.938 .13209 Mdot
.938 .1332 Mdot
.938 .13357 Mdot
.938 .13401 Mdot
.938 .13457 Mdot
.938 .13463 Mdot
.938 .13468 Mdot
.938 .13607 Mdot
.938 .13708 Mdot
.938 .13722 Mdot
.938 .13739 Mdot
.938 .13903 Mdot
.938 .13919 Mdot
.938 .13928 Mdot
.938 .13972 Mdot
.938 .14134 Mdot
.938 .14146 Mdot
.938 .14147 Mdot
.938 .14171 Mdot
.938 .14306 Mdot
.938 .14309 Mdot
.938 .14381 Mdot
.938 .14383 Mdot
.938 .14406 Mdot
.938 .14438 Mdot
.938 .1449 Mdot
.938 .1453 Mdot
.938 .14553 Mdot
.938 .14691 Mdot
.938 .14714 Mdot
.938 .14738 Mdot
.938 .14764 Mdot
.938 .14857 Mdot
.938 .15025 Mdot
.938 .15064 Mdot
.938 .15073 Mdot
.938 .15099 Mdot
.938 .15158 Mdot
.938 .15167 Mdot
.938 .15274 Mdot
.938 .1529 Mdot
.938 .15401 Mdot
.938 .15403 Mdot
.938 .15445 Mdot
.938 .15505 Mdot
.938 .15559 Mdot
.938 .15732 Mdot
.938 .15785 Mdot
.938 .15796 Mdot
.938 .159 Mdot
.938 .15938 Mdot
.938 .15996 Mdot
.938 .16186 Mdot
.938 .16199 Mdot
.938 .16212 Mdot
.938 .16257 Mdot
.938 .16329 Mdot
.938 .16411 Mdot
.938 .16439 Mdot
.938 .16518 Mdot
.938 .16585 Mdot
.938 .16634 Mdot
.938 .16642 Mdot
.938 .1677 Mdot
.938 .16919 Mdot
.938 .17017 Mdot
.938 .17018 Mdot
.938 .1703 Mdot
.938 .17433 Mdot
.938 .17514 Mdot
.938 .17549 Mdot
.938 .17605 Mdot
.938 .1771 Mdot
.938 .17796 Mdot
.938 .17833 Mdot
.938 .17927 Mdot
.938 .18011 Mdot
.938 .18031 Mdot
.938 .18106 Mdot
.938 .18107 Mdot
.938 .1814 Mdot
.938 .18253 Mdot
.938 .18292 Mdot
.938 .1834 Mdot
.938 .18381 Mdot
.938 .184 Mdot
.938 .18488 Mdot
.938 .18516 Mdot
.938 .18557 Mdot
.938 .18583 Mdot
.938 .18612 Mdot
.938 .18704 Mdot
.938 .18837 Mdot
.938 .1901 Mdot
.938 .19062 Mdot
.938 .19164 Mdot
.938 .19198 Mdot
.938 .19214 Mdot
.938 .19258 Mdot
.938 .19369 Mdot
.938 .19466 Mdot
.938 .19469 Mdot
.938 .19496 Mdot
.938 .19536 Mdot
.938 .19609 Mdot
.938 .1963 Mdot
.938 .19709 Mdot
.938 .19725 Mdot
.938 .19745 Mdot
.938 .19773 Mdot
.938 .19895 Mdot
.938 .1993 Mdot
.938 .20143 Mdot
.938 .2015 Mdot
.938 .20501 Mdot
.938 .2061 Mdot
.938 .20659 Mdot
.938 .2067 Mdot
.938 .20708 Mdot
.938 .20771 Mdot
.938 .20849 Mdot
.938 .20964 Mdot
.938 .21202 Mdot
.938 .21213 Mdot
.938 .21283 Mdot
.938 .21522 Mdot
.938 .21583 Mdot
.938 .21656 Mdot
.938 .21885 Mdot
.938 .21959 Mdot
.938 .22153 Mdot
.938 .22255 Mdot
.938 .22337 Mdot
.938 .22374 Mdot
.938 .22581 Mdot
.938 .22609 Mdot
.938 .22754 Mdot
.938 .22874 Mdot
.938 .22901 Mdot
.938 .22928 Mdot
.938 .23007 Mdot
.938 .23025 Mdot
.938 .23034 Mdot
.938 .23064 Mdot
.938 .23194 Mdot
.938 .2323 Mdot
.938 .23342 Mdot
.938 .23365 Mdot
.938 .23519 Mdot
.938 .23669 Mdot
.938 .23903 Mdot
.938 .2421 Mdot
.938 .2425 Mdot
.938 .24451 Mdot
.938 .2449 Mdot
.938 .245 Mdot
.938 .24533 Mdot
.938 .24587 Mdot
.938 .24665 Mdot
.938 .24726 Mdot
.938 .24843 Mdot
.938 .25016 Mdot
.938 .25054 Mdot
.938 .25087 Mdot
.938 .25168 Mdot
.938 .25247 Mdot
.938 .25252 Mdot
.938 .25542 Mdot
.938 .25653 Mdot
.938 .25884 Mdot
.938 .25926 Mdot
.938 .25967 Mdot
.938 .26083 Mdot
.938 .26315 Mdot
.938 .26331 Mdot
.938 .26382 Mdot
.938 .26473 Mdot
.938 .26482 Mdot
.938 .26558 Mdot
.938 .26586 Mdot
.938 .26599 Mdot
.938 .26737 Mdot
.938 .26777 Mdot
.938 .26815 Mdot
.938 .26904 Mdot
.938 .26952 Mdot
.938 .27223 Mdot
.938 .273 Mdot
.938 .2734 Mdot
.938 .27359 Mdot
.938 .27411 Mdot
.938 .27494 Mdot
.938 .27671 Mdot
.938 .27673 Mdot
.938 .27923 Mdot
.938 .28012 Mdot
.938 .28039 Mdot
.938 .28071 Mdot
.938 .28115 Mdot
.938 .28152 Mdot
.938 .28208 Mdot
.938 .28314 Mdot
.938 .28471 Mdot
.938 .28573 Mdot
.938 .28635 Mdot
.938 .28683 Mdot
.938 .287 Mdot
.938 .2875 Mdot
.938 .28788 Mdot
.938 .289 Mdot
.938 .29011 Mdot
.938 .29115 Mdot
.938 .29182 Mdot
.938 .29221 Mdot
.938 .29371 Mdot
.938 .29525 Mdot
.938 .296 Mdot
.938 .29606 Mdot
.938 .2965 Mdot
.938 .29784 Mdot
.938 .30005 Mdot
.938 .30102 Mdot
.938 .30168 Mdot
.938 .30194 Mdot
.938 .30212 Mdot
.938 .30707 Mdot
.938 .30729 Mdot
.938 .30981 Mdot
.938 .3106 Mdot
.938 .31205 Mdot
.938 .31441 Mdot
.938 .31487 Mdot
.938 .31646 Mdot
.938 .31704 Mdot
.938 .31759 Mdot
.938 .31816 Mdot
.938 .3186 Mdot
.938 .319 Mdot
.938 .31944 Mdot
.938 .31946 Mdot
.938 .31963 Mdot
.938 .32037 Mdot
.938 .32085 Mdot
.938 .32288 Mdot
.938 .32372 Mdot
.938 .32567 Mdot
.938 .32676 Mdot
.938 .32838 Mdot
.938 .32907 Mdot
.938 .32947 Mdot
.938 .32963 Mdot
.938 .33133 Mdot
.938 .33206 Mdot
.938 .3336 Mdot
.938 .33426 Mdot
.938 .33497 Mdot
.938 .33581 Mdot
.938 .33622 Mdot
.938 .33814 Mdot
.938 .33835 Mdot
.938 .33994 Mdot
.938 .34063 Mdot
.938 .34203 Mdot
.938 .34328 Mdot
.938 .34387 Mdot
.938 .34469 Mdot
.938 .34497 Mdot
.938 .34554 Mdot
.938 .34621 Mdot
.938 .34724 Mdot
.938 .3473 Mdot
.938 .34812 Mdot
.938 .34823 Mdot
.938 .34837 Mdot
.938 .35038 Mdot
.938 .35095 Mdot
.938 .35174 Mdot
.938 .35372 Mdot
.938 .35388 Mdot
.938 .35512 Mdot
.938 .35548 Mdot
.938 .35548 Mdot
.938 .35625 Mdot
.938 .35759 Mdot
.938 .36083 Mdot
.938 .36094 Mdot
.938 .36127 Mdot
.938 .36137 Mdot
.938 .36156 Mdot
.938 .36282 Mdot
.938 .36286 Mdot
.938 .3632 Mdot
.938 .36335 Mdot
.938 .36375 Mdot
.938 .36437 Mdot
.938 .36473 Mdot
.938 .36558 Mdot
.938 .36573 Mdot
.938 .36593 Mdot
.938 .3669 Mdot
.938 .367 Mdot
.938 .36738 Mdot
.938 .36788 Mdot
.938 .36855 Mdot
.938 .36859 Mdot
.938 .36869 Mdot
.938 .36981 Mdot
.938 .36983 Mdot
.938 .37157 Mdot
.938 .37211 Mdot
.938 .37224 Mdot
.938 .37295 Mdot
.938 .37295 Mdot
.938 .37331 Mdot
.938 .37344 Mdot
.938 .37405 Mdot
.938 .37422 Mdot
.938 .37523 Mdot
.938 .37531 Mdot
.938 .3755 Mdot
.938 .37588 Mdot
.938 .37629 Mdot
.938 .37643 Mdot
.938 .37662 Mdot
.938 .37735 Mdot
.938 .37788 Mdot
.938 .37882 Mdot
.938 .37886 Mdot
.938 .37948 Mdot
.938 .37957 Mdot
.938 .38019 Mdot
.938 .38138 Mdot
.938 .38312 Mdot
.938 .38343 Mdot
.938 .38369 Mdot
.938 .38408 Mdot
.938 .38433 Mdot
.938 .38504 Mdot
.938 .38516 Mdot
.938 .3853 Mdot
.938 .38542 Mdot
.938 .38547 Mdot
.938 .38593 Mdot
.938 .38855 Mdot
.938 .38856 Mdot
.938 .38935 Mdot
.938 .38943 Mdot
.938 .38977 Mdot
.938 .39047 Mdot
.938 .39178 Mdot
.938 .39191 Mdot
.938 .39205 Mdot
.938 .39276 Mdot
.938 .39364 Mdot
.938 .39528 Mdot
.938 .3966 Mdot
.938 .39762 Mdot
.938 .39794 Mdot
.938 .39809 Mdot
.938 .39834 Mdot
.938 .39925 Mdot
.938 .40157 Mdot
.938 .4021 Mdot
.938 .40245 Mdot
.938 .40265 Mdot
.938 .40312 Mdot
.938 .40366 Mdot
.938 .40416 Mdot
.938 .4058 Mdot
.938 .40694 Mdot
.938 .4073 Mdot
.938 .40732 Mdot
.938 .40759 Mdot
.938 .40762 Mdot
.938 .40807 Mdot
.938 .40817 Mdot
.938 .40851 Mdot
.938 .40939 Mdot
.938 .40949 Mdot
.938 .41118 Mdot
.938 .41125 Mdot
.938 .41274 Mdot
.938 .41285 Mdot
.938 .4129 Mdot
.938 .41339 Mdot
.938 .41367 Mdot
.938 .4141 Mdot
.938 .41495 Mdot
.938 .41526 Mdot
.938 .41559 Mdot
.938 .41613 Mdot
.938 .41664 Mdot
.938 .41786 Mdot
.938 .41966 Mdot
.938 .42016 Mdot
.938 .42069 Mdot
.938 .42089 Mdot
.938 .4209 Mdot
.938 .42124 Mdot
.938 .42241 Mdot
.938 .42324 Mdot
.938 .4255 Mdot
.938 .42684 Mdot
.938 .42767 Mdot
.938 .42787 Mdot
.938 .42842 Mdot
.938 .42875 Mdot
.938 .42923 Mdot
.938 .42927 Mdot
.938 .42966 Mdot
.938 .42985 Mdot
.938 .43167 Mdot
.938 .43212 Mdot
.938 .43244 Mdot
.938 .43268 Mdot
.938 .43315 Mdot
.938 .43476 Mdot
.938 .43481 Mdot
.938 .43568 Mdot
.938 .43693 Mdot
.938 .43803 Mdot
.938 .43898 Mdot
.938 .44036 Mdot
.938 .44131 Mdot
.938 .44157 Mdot
.938 .44226 Mdot
.938 .44235 Mdot
.938 .44265 Mdot
.938 .44287 Mdot
.938 .44394 Mdot
.938 .44425 Mdot
.938 .44441 Mdot
.938 .44498 Mdot
.938 .44574 Mdot
.938 .44575 Mdot
.938 .44613 Mdot
.938 .44691 Mdot
.938 .44847 Mdot
.938 .44873 Mdot
.938 .45069 Mdot
.938 .45094 Mdot
.938 .45118 Mdot
.938 .4512 Mdot
.938 .45174 Mdot
.938 .45208 Mdot
.938 .45279 Mdot
.938 .4535 Mdot
.938 .4551 Mdot
.938 .45564 Mdot
.938 .45592 Mdot
.938 .45716 Mdot
.938 .45729 Mdot
.938 .45846 Mdot
.938 .45865 Mdot
.938 .45931 Mdot
.938 .45939 Mdot
.938 .45955 Mdot
.938 .46033 Mdot
.938 .46038 Mdot
.938 .46084 Mdot
.938 .46131 Mdot
.938 .46199 Mdot
.938 .4648 Mdot
.938 .46502 Mdot
.938 .4655 Mdot
.938 .46664 Mdot
.938 .46666 Mdot
.938 .46689 Mdot
.938 .46841 Mdot
.938 .46985 Mdot
.938 .47055 Mdot
.938 .47055 Mdot
.938 .47194 Mdot
.938 .47298 Mdot
.938 .47327 Mdot
.938 .47385 Mdot
.938 .47427 Mdot
.938 .47573 Mdot
.938 .47577 Mdot
.938 .47616 Mdot
.938 .47636 Mdot
.938 .4767 Mdot
.938 .47687 Mdot
.938 .47737 Mdot
.938 .47809 Mdot
.938 .47855 Mdot
.938 .47923 Mdot
.938 .48025 Mdot
.938 .48075 Mdot
.938 .48139 Mdot
.938 .48267 Mdot
.938 .48304 Mdot
.938 .48432 Mdot
.938 .4845 Mdot
.938 .48484 Mdot
.938 .48614 Mdot
.938 .48616 Mdot
.938 .48621 Mdot
.938 .48672 Mdot
.938 .48834 Mdot
.938 .48864 Mdot
.938 .4893 Mdot
.938 .48982 Mdot
.938 .4899 Mdot
.938 .49013 Mdot
.938 .49081 Mdot
.938 .49113 Mdot
.938 .4926 Mdot
.938 .4926 Mdot
.938 .49306 Mdot
.938 .49339 Mdot
.938 .49374 Mdot
.938 .49378 Mdot
.938 .49417 Mdot
.938 .49431 Mdot
.938 .49466 Mdot
.938 .49505 Mdot
.938 .49617 Mdot
.938 .49803 Mdot
.938 .49833 Mdot
.938 .49833 Mdot
.938 .49896 Mdot
.938 .49902 Mdot
.938 .4998 Mdot
.938 .50033 Mdot
.938 .50111 Mdot
.938 .50121 Mdot
.938 .50153 Mdot
.938 .50194 Mdot
.938 .50285 Mdot
.938 .50355 Mdot
.938 .50409 Mdot
.938 .50435 Mdot
.938 .50496 Mdot
.938 .50503 Mdot
.938 .50676 Mdot
.938 .50825 Mdot
.938 .50831 Mdot
.938 .50846 Mdot
.938 .50871 Mdot
.938 .50932 Mdot
.938 .50972 Mdot
.938 .51044 Mdot
.938 .51075 Mdot
.938 .5115 Mdot
.938 .51195 Mdot
.938 .51201 Mdot
.938 .51202 Mdot
.938 .51218 Mdot
.938 .51233 Mdot
.938 .51249 Mdot
.938 .5129 Mdot
.938 .51311 Mdot
.938 .51386 Mdot
.938 .51471 Mdot
.938 .51524 Mdot
.938 .51651 Mdot
.938 .51828 Mdot
.938 .51834 Mdot
.938 .51843 Mdot
.938 .51901 Mdot
.938 .5198 Mdot
.938 .52027 Mdot
.938 .52071 Mdot
.938 .52192 Mdot
.938 .52251 Mdot
.938 .5229 Mdot
.938 .52342 Mdot
.938 .52359 Mdot
.938 .52365 Mdot
.938 .52382 Mdot
.938 .52493 Mdot
.938 .52562 Mdot
.938 .52577 Mdot
.938 .52588 Mdot
.938 .52597 Mdot
.938 .52628 Mdot
.938 .52714 Mdot
.938 .5282 Mdot
.938 .52827 Mdot
.938 .5284 Mdot
.938 .52958 Mdot
.938 .52974 Mdot
.938 .53004 Mdot
.938 .53017 Mdot
.938 .53077 Mdot
.938 .53081 Mdot
.938 .53116 Mdot
.938 .53119 Mdot
.938 .53167 Mdot
.938 .53288 Mdot
.938 .53302 Mdot
.938 .53316 Mdot
.938 .53392 Mdot
.938 .53526 Mdot
.938 .5359 Mdot
.938 .53659 Mdot
.938 .53697 Mdot
.938 .53717 Mdot
.938 .53743 Mdot
.938 .53775 Mdot
.938 .53787 Mdot
.938 .53852 Mdot
.938 .53865 Mdot
.938 .54138 Mdot
.938 .54145 Mdot
.938 .54234 Mdot
.938 .54247 Mdot
.938 .54278 Mdot
.938 .54295 Mdot
.938 .54333 Mdot
.938 .54454 Mdot
.938 .54465 Mdot
.938 .54585 Mdot
.938 .54608 Mdot
.938 .5468 Mdot
.938 .54722 Mdot
.938 .54796 Mdot
.938 .54895 Mdot
.938 .54955 Mdot
.938 .54975 Mdot
.938 .54986 Mdot
.938 .5499 Mdot
.938 .55005 Mdot
.938 .55147 Mdot
.938 .55149 Mdot
.938 .55225 Mdot
.938 .55263 Mdot
.938 .55271 Mdot
.938 .55277 Mdot
.938 .55306 Mdot
.938 .55335 Mdot
.938 .55355 Mdot
.938 .55356 Mdot
.938 .55419 Mdot
.938 .55438 Mdot
.938 .55448 Mdot
.938 .55479 Mdot
.938 .55615 Mdot
.938 .55632 Mdot
.938 .55652 Mdot
.938 .55679 Mdot
.938 .55684 Mdot
.938 .55697 Mdot
.938 .55711 Mdot
.938 .55723 Mdot
.938 .55767 Mdot
.938 .5579 Mdot
.938 .55795 Mdot
.938 .55821 Mdot
.938 .5586 Mdot
.938 .55885 Mdot
.938 .55917 Mdot
.938 .55944 Mdot
.938 .56087 Mdot
.938 .56091 Mdot
.938 .56202 Mdot
.938 .56262 Mdot
.938 .5627 Mdot
.938 .56315 Mdot
.938 .56328 Mdot
.938 .56332 Mdot
.938 .56419 Mdot
.938 .56468 Mdot
.938 .56534 Mdot
.938 .56552 Mdot
.938 .56565 Mdot
.938 .56597 Mdot
.938 .56601 Mdot
.938 .56633 Mdot
.938 .56635 Mdot
.938 .56652 Mdot
.938 .5666 Mdot
.938 .56749 Mdot
.938 .56763 Mdot
.938 .5681 Mdot
.938 .56816 Mdot
.938 .56828 Mdot
.938 .56843 Mdot
.938 .56852 Mdot
.938 .56858 Mdot
.938 .56859 Mdot
.938 .5688 Mdot
.938 .56919 Mdot
.938 .56926 Mdot
.938 .5693 Mdot
.938 .56976 Mdot
.938 .56991 Mdot
.938 .57043 Mdot
.938 .5712 Mdot
.938 .57121 Mdot
.938 .57139 Mdot
.938 .57212 Mdot
.938 .5722 Mdot
.938 .57223 Mdot
.938 .57277 Mdot
.938 .57307 Mdot
.938 .57316 Mdot
.938 .57333 Mdot
.938 .57345 Mdot
.938 .57354 Mdot
.938 .57395 Mdot
.938 .57428 Mdot
.938 .57443 Mdot
.938 .57455 Mdot
.938 .57456 Mdot
.938 .5746 Mdot
.938 .57519 Mdot
.938 .57546 Mdot
.938 .57592 Mdot
.938 .57621 Mdot
.938 .57632 Mdot
.938 .57656 Mdot
.938 .57659 Mdot
.938 .57674 Mdot
.938 .57749 Mdot
.938 .57753 Mdot
.938 .57762 Mdot
.938 .5777 Mdot
.938 .57793 Mdot
.938 .578 Mdot
.938 .57913 Mdot
.938 .57941 Mdot
.938 .57968 Mdot
.938 .58019 Mdot
.938 .58043 Mdot
.938 .58105 Mdot
.938 .58153 Mdot
.938 .58153 Mdot
.938 .58175 Mdot
.938 .5819 Mdot
.938 .582 Mdot
.938 .58231 Mdot
.938 .58251 Mdot
.938 .58261 Mdot
.938 .58286 Mdot
.938 .58291 Mdot
.938 .58336 Mdot
.938 .58352 Mdot
.938 .5836 Mdot
.938 .58377 Mdot
.938 .58422 Mdot
.938 .58438 Mdot
.938 .58454 Mdot
.938 .5846 Mdot
.938 .58481 Mdot
.938 .58529 Mdot
.938 .58555 Mdot
.938 .58563 Mdot
.938 .5857 Mdot
.938 .58576 Mdot
.938 .58619 Mdot
.938 .58621 Mdot
.938 .58673 Mdot
.938 .58694 Mdot
.938 .58707 Mdot
.938 .58731 Mdot
.938 .58735 Mdot
.938 .58748 Mdot
.938 .5875 Mdot
.938 .5876 Mdot
.938 .58784 Mdot
.938 .58787 Mdot
.938 .58814 Mdot
.938 .58823 Mdot
.938 .58871 Mdot
.938 .58901 Mdot
.938 .58902 Mdot
.938 .58931 Mdot
.938 .5896 Mdot
.938 .59007 Mdot
.938 .59025 Mdot
.938 .59033 Mdot
.938 .59042 Mdot
.938 .59052 Mdot
.938 .59064 Mdot
.938 .59081 Mdot
.938 .59095 Mdot
.938 .59105 Mdot
.938 .59115 Mdot
.938 .5912 Mdot
.938 .5915 Mdot
.938 .59153 Mdot
.938 .59174 Mdot
.938 .59197 Mdot
.938 .59206 Mdot
.938 .59238 Mdot
.938 .59246 Mdot
.938 .59257 Mdot
.938 .59268 Mdot
.938 .59272 Mdot
.938 .59277 Mdot
.938 .59291 Mdot
.938 .59302 Mdot
.938 .59317 Mdot
.938 .59321 Mdot
.938 .59332 Mdot
.938 .59333 Mdot
.938 .5935 Mdot
.938 .59362 Mdot
.938 .59388 Mdot
.938 .59391 Mdot
.938 .59404 Mdot
.938 .59412 Mdot
.938 .59416 Mdot
.938 .59445 Mdot
.938 .59457 Mdot
.938 .59473 Mdot
.938 .59475 Mdot
.938 .59488 Mdot
.938 .59489 Mdot
.938 .59497 Mdot
.938 .59508 Mdot
.938 .59515 Mdot
.938 .59518 Mdot
.938 .59526 Mdot
.938 .59529 Mdot
.938 .59529 Mdot
.938 .59535 Mdot
.938 .5954 Mdot
.938 .59546 Mdot
.938 .59548 Mdot
.938 .59553 Mdot
.938 .59559 Mdot
.938 .59559 Mdot
.938 .59565 Mdot
.938 .59566 Mdot
.938 .59568 Mdot
.938 .5957 Mdot
.938 .59579 Mdot
.938 .59583 Mdot
.938 .59596 Mdot
.938 .596 Mdot
.938 .596 Mdot
.938 .596 Mdot
.938 .59602 Mdot
.94 .0423 Mdot
.94 .0423 Mdot
.94 .04231 Mdot
.94 .04231 Mdot
.94 .04232 Mdot
.94 .04235 Mdot
.94 .04239 Mdot
.94 .04241 Mdot
.94 .04242 Mdot
.94 .04252 Mdot
.94 .04253 Mdot
.94 .04256 Mdot
.94 .0426 Mdot
.94 .04272 Mdot
.94 .04295 Mdot
.94 .04313 Mdot
.94 .04334 Mdot
.94 .04355 Mdot
.94 .04356 Mdot
.94 .04393 Mdot
.94 .04406 Mdot
.94 .04436 Mdot
.94 .04474 Mdot
.94 .04485 Mdot
.94 .04487 Mdot
.94 .04511 Mdot
.94 .04532 Mdot
.94 .04578 Mdot
.94 .04608 Mdot
.94 .04669 Mdot
.94 .04709 Mdot
.94 .04747 Mdot
.94 .04771 Mdot
.94 .04793 Mdot
.94 .04916 Mdot
.94 .04938 Mdot
.94 .04956 Mdot
.94 .0497 Mdot
.94 .04988 Mdot
.94 .05016 Mdot
.94 .05019 Mdot
.94 .05046 Mdot
.94 .05053 Mdot
.94 .05092 Mdot
.94 .05184 Mdot
.94 .05203 Mdot
.94 .05317 Mdot
.94 .0545 Mdot
.94 .05502 Mdot
.94 .05521 Mdot
.94 .05549 Mdot
.94 .05571 Mdot
.94 .05594 Mdot
.94 .05658 Mdot
.94 .05711 Mdot
.94 .0574 Mdot
.94 .05819 Mdot
.94 .05837 Mdot
.94 .05863 Mdot
.94 .05897 Mdot
.94 .0591 Mdot
.94 .05937 Mdot
.94 .05998 Mdot
.94 .06041 Mdot
.94 .06072 Mdot
.94 .06081 Mdot
.94 .06164 Mdot
.94 .06229 Mdot
.94 .0636 Mdot
.94 .06371 Mdot
.94 .06565 Mdot
.94 .06572 Mdot
.94 .06579 Mdot
.94 .06588 Mdot
.94 .06599 Mdot
.94 .06663 Mdot
.94 .06671 Mdot
.94 .06765 Mdot
.94 .0677 Mdot
.94 .06784 Mdot
.94 .06808 Mdot
.94 .06826 Mdot
.94 .06847 Mdot
.94 .06858 Mdot
.94 .06904 Mdot
.94 .06951 Mdot
.94 .07014 Mdot
.94 .07059 Mdot
.94 .07144 Mdot
.94 .07249 Mdot
.94 .07251 Mdot
.94 .07426 Mdot
.94 .07458 Mdot
.94 .07575 Mdot
.94 .07714 Mdot
.94 .07775 Mdot
.94 .08243 Mdot
.94 .08289 Mdot
.94 .08364 Mdot
.94 .08541 Mdot
.94 .08693 Mdot
.94 .08759 Mdot
.94 .08834 Mdot
.94 .08975 Mdot
.94 .09015 Mdot
.94 .09075 Mdot
.94 .09095 Mdot
.94 .09101 Mdot
.94 .0911 Mdot
.94 .09113 Mdot
.94 .09114 Mdot
.94 .09136 Mdot
.94 .09205 Mdot
.94 .09273 Mdot
.94 .09283 Mdot
.94 .09317 Mdot
.94 .09336 Mdot
.94 .0953 Mdot
.94 .09536 Mdot
.94 .0957 Mdot
.94 .09622 Mdot
.94 .0963 Mdot
.94 .09703 Mdot
.94 .09846 Mdot
.94 .09969 Mdot
.94 .10103 Mdot
.94 .10148 Mdot
.94 .10198 Mdot
.94 .10342 Mdot
.94 .10449 Mdot
.94 .10641 Mdot
.94 .10857 Mdot
.94 .11034 Mdot
.94 .11339 Mdot
.94 .11472 Mdot
.94 .11595 Mdot
.94 .11814 Mdot
.94 .1184 Mdot
.94 .11862 Mdot
.94 .11863 Mdot
.94 .11865 Mdot
.94 .11865 Mdot
.94 .11869 Mdot
.94 .11882 Mdot
.94 .11895 Mdot
.94 .11901 Mdot
.94 .11905 Mdot
.94 .1194 Mdot
.94 .11946 Mdot
.94 .11955 Mdot
.94 .11969 Mdot
.94 .12014 Mdot
.94 .12076 Mdot
.94 .12093 Mdot
.94 .12159 Mdot
.94 .12235 Mdot
.94 .12308 Mdot
.94 .12311 Mdot
.94 .12443 Mdot
.94 .12458 Mdot
.94 .12492 Mdot
.94 .12505 Mdot
.94 .12599 Mdot
.94 .12645 Mdot
.94 .12695 Mdot
.94 .12733 Mdot
.94 .12734 Mdot
.94 .12748 Mdot
.94 .12772 Mdot
.94 .12779 Mdot
.94 .12833 Mdot
.94 .12862 Mdot
.94 .12924 Mdot
.94 .12938 Mdot
.94 .1307 Mdot
.94 .13092 Mdot
.94 .13101 Mdot
.94 .13105 Mdot
.94 .1316 Mdot
.94 .13208 Mdot
.94 .13424 Mdot
.94 .13563 Mdot
.94 .136 Mdot
.94 .13696 Mdot
.94 .1371 Mdot
.94 .13781 Mdot
.94 .13832 Mdot
.94 .13859 Mdot
.94 .14166 Mdot
.94 .14289 Mdot
.94 .14364 Mdot
.94 .14429 Mdot
.94 .14476 Mdot
.94 .14535 Mdot
.94 .14539 Mdot
.94 .14603 Mdot
.94 .14637 Mdot
.94 .14645 Mdot
.94 .1474 Mdot
.94 .14764 Mdot
.94 .14819 Mdot
.94 .14825 Mdot
.94 .14901 Mdot
.94 .1493 Mdot
.94 .14976 Mdot
.94 .15037 Mdot
.94 .15106 Mdot
.94 .15162 Mdot
.94 .15219 Mdot
.94 .15283 Mdot
.94 .15569 Mdot
.94 .15667 Mdot
.94 .15675 Mdot
.94 .15794 Mdot
.94 .15825 Mdot
.94 .16133 Mdot
.94 .16134 Mdot
.94 .16269 Mdot
.94 .16282 Mdot
.94 .16308 Mdot
.94 .16373 Mdot
.94 .16382 Mdot
.94 .16434 Mdot
.94 .16471 Mdot
.94 .16532 Mdot
.94 .16545 Mdot
.94 .16622 Mdot
.94 .16799 Mdot
.94 .16839 Mdot
.94 .16878 Mdot
.94 .16986 Mdot
.94 .17018 Mdot
.94 .17116 Mdot
.94 .17315 Mdot
.94 .17384 Mdot
.94 .17418 Mdot
.94 .17424 Mdot
.94 .17425 Mdot
.94 .17443 Mdot
.94 .17446 Mdot
.94 .17531 Mdot
.94 .17598 Mdot
.94 .17646 Mdot
.94 .17653 Mdot
.94 .1767 Mdot
.94 .17689 Mdot
.94 .17698 Mdot
.94 .17747 Mdot
.94 .17781 Mdot
.94 .17867 Mdot
.94 .17883 Mdot
.94 .17909 Mdot
.94 .17975 Mdot
.94 .17983 Mdot
.94 .18129 Mdot
.94 .18141 Mdot
.94 .18205 Mdot
.94 .18231 Mdot
.94 .18261 Mdot
.94 .18535 Mdot
.94 .1854 Mdot
.94 .18753 Mdot
.94 .18894 Mdot
.94 .19171 Mdot
.94 .19185 Mdot
.94 .19218 Mdot
.94 .19223 Mdot
.94 .1954 Mdot
.94 .19859 Mdot
.94 .19884 Mdot
.94 .19907 Mdot
.94 .19934 Mdot
.94 .19969 Mdot
.94 .19977 Mdot
.94 .20031 Mdot
.94 .20098 Mdot
.94 .20178 Mdot
.94 .20198 Mdot
.94 .20204 Mdot
.94 .20279 Mdot
.94 .20322 Mdot
.94 .20465 Mdot
.94 .20511 Mdot
.94 .20526 Mdot
.94 .20551 Mdot
.94 .20572 Mdot
.94 .20587 Mdot
.94 .20648 Mdot
.94 .20673 Mdot
.94 .20709 Mdot
.94 .20776 Mdot
.94 .20782 Mdot
.94 .20811 Mdot
.94 .2096 Mdot
.94 .21069 Mdot
.94 .2111 Mdot
.94 .21315 Mdot
.94 .21456 Mdot
.94 .21457 Mdot
.94 .21502 Mdot
.94 .21692 Mdot
.94 .2173 Mdot
.94 .21823 Mdot
.94 .22063 Mdot
.94 .22069 Mdot
.94 .22591 Mdot
.94 .22614 Mdot
.94 .22625 Mdot
.94 .22649 Mdot
.94 .22723 Mdot
.94 .2277 Mdot
.94 .23 Mdot
.94 .23093 Mdot
.94 .23294 Mdot
.94 .23389 Mdot
.94 .2352 Mdot
.94 .23525 Mdot
.94 .23527 Mdot
.94 .23558 Mdot
.94 .23715 Mdot
.94 .23827 Mdot
.94 .23874 Mdot
.94 .24017 Mdot
.94 .24067 Mdot
.94 .24269 Mdot
.94 .24411 Mdot
.94 .24711 Mdot
.94 .24749 Mdot
.94 .24921 Mdot
.94 .24926 Mdot
.94 .24985 Mdot
.94 .25085 Mdot
.94 .25153 Mdot
.94 .25293 Mdot
.94 .25474 Mdot
.94 .25521 Mdot
.94 .2585 Mdot
.94 .26054 Mdot
.94 .26277 Mdot
.94 .26436 Mdot
.94 .26511 Mdot
.94 .26706 Mdot
.94 .2678 Mdot
.94 .26867 Mdot
.94 .26905 Mdot
.94 .26928 Mdot
.94 .27345 Mdot
.94 .27362 Mdot
.94 .27462 Mdot
.94 .27463 Mdot
.94 .27575 Mdot
.94 .27601 Mdot
.94 .2764 Mdot
.94 .27696 Mdot
.94 .27716 Mdot
.94 .27742 Mdot
.94 .27751 Mdot
.94 .27754 Mdot
.94 .27819 Mdot
.94 .27867 Mdot
.94 .27877 Mdot
.94 .28012 Mdot
.94 .28019 Mdot
.94 .2811 Mdot
.94 .28217 Mdot
.94 .28246 Mdot
.94 .28278 Mdot
.94 .28324 Mdot
.94 .28344 Mdot
.94 .28354 Mdot
.94 .28381 Mdot
.94 .28401 Mdot
.94 .28415 Mdot
.94 .28502 Mdot
.94 .28545 Mdot
.94 .28599 Mdot
.94 .28618 Mdot
.94 .28637 Mdot
.94 .28662 Mdot
.94 .28724 Mdot
.94 .28847 Mdot
.94 .28959 Mdot
.94 .28977 Mdot
.94 .29073 Mdot
.94 .29123 Mdot
.94 .29223 Mdot
.94 .29245 Mdot
.94 .2927 Mdot
.94 .29424 Mdot
.94 .29453 Mdot
.94 .29486 Mdot
.94 .29539 Mdot
.94 .29597 Mdot
.94 .29819 Mdot
.94 .29859 Mdot
.94 .29903 Mdot
.94 .29928 Mdot
.94 .30007 Mdot
.94 .30074 Mdot
.94 .30107 Mdot
.94 .30203 Mdot
.94 .30206 Mdot
.94 .30333 Mdot
.94 .30399 Mdot
.94 .30582 Mdot
.94 .30608 Mdot
.94 .30681 Mdot
.94 .30706 Mdot
.94 .30826 Mdot
.94 .30845 Mdot
.94 .30857 Mdot
.94 .30976 Mdot
.94 .31002 Mdot
.94 .31054 Mdot
.94 .31113 Mdot
.94 .31206 Mdot
.94 .31244 Mdot
.94 .31309 Mdot
.94 .31538 Mdot
.94 .31896 Mdot
.94 .32063 Mdot
.94 .32113 Mdot
.94 .32596 Mdot
.94 .32616 Mdot
.94 .32648 Mdot
.94 .32651 Mdot
.94 .32688 Mdot
.94 .33125 Mdot
.94 .33325 Mdot
.94 .3358 Mdot
.94 .33647 Mdot
.94 .33921 Mdot
.94 .3393 Mdot
.94 .33943 Mdot
.94 .33989 Mdot
.94 .34076 Mdot
.94 .341 Mdot
.94 .34135 Mdot
.94 .34279 Mdot
.94 .34524 Mdot
.94 .346 Mdot
.94 .34632 Mdot
.94 .35128 Mdot
.94 .35164 Mdot
.94 .3523 Mdot
.94 .35249 Mdot
.94 .35277 Mdot
.94 .35286 Mdot
.94 .35289 Mdot
.94 .35294 Mdot
.94 .35295 Mdot
.94 .35305 Mdot
.94 .35336 Mdot
.94 .35372 Mdot
.94 .35387 Mdot
.94 .35396 Mdot
.94 .35482 Mdot
.94 .35485 Mdot
.94 .355 Mdot
.94 .35523 Mdot
.94 .35558 Mdot
.94 .3562 Mdot
.94 .35673 Mdot
.94 .3573 Mdot
.94 .3577 Mdot
.94 .3583 Mdot
.94 .35875 Mdot
.94 .3604 Mdot
.94 .36111 Mdot
.94 .3623 Mdot
.94 .36412 Mdot
.94 .36422 Mdot
.94 .36668 Mdot
.94 .36736 Mdot
.94 .3675 Mdot
.94 .36756 Mdot
.94 .36786 Mdot
.94 .3687 Mdot
.94 .36901 Mdot
.94 .37134 Mdot
.94 .37247 Mdot
.94 .3737 Mdot
.94 .37463 Mdot
.94 .37465 Mdot
.94 .375 Mdot
.94 .37515 Mdot
.94 .37557 Mdot
.94 .37575 Mdot
.94 .37705 Mdot
.94 .37777 Mdot
.94 .37883 Mdot
.94 .37925 Mdot
.94 .37961 Mdot
.94 .38007 Mdot
.94 .38113 Mdot
.94 .38146 Mdot
.94 .38278 Mdot
.94 .3833 Mdot
.94 .38346 Mdot
.94 .38351 Mdot
.94 .3836 Mdot
.94 .38374 Mdot
.94 .3841 Mdot
.94 .38422 Mdot
.94 .38442 Mdot
.94 .38491 Mdot
.94 .38606 Mdot
.94 .3879 Mdot
.94 .38895 Mdot
.94 .39018 Mdot
.94 .39052 Mdot
.94 .39103 Mdot
.94 .39115 Mdot
.94 .39243 Mdot
.94 .39322 Mdot
.94 .39428 Mdot
.94 .3944 Mdot
.94 .39492 Mdot
.94 .39527 Mdot
.94 .3975 Mdot
.94 .39782 Mdot
.94 .39843 Mdot
.94 .39921 Mdot
.94 .39946 Mdot
.94 .39982 Mdot
.94 .39991 Mdot
.94 .40061 Mdot
.94 .40124 Mdot
.94 .40177 Mdot
.94 .40214 Mdot
.94 .40292 Mdot
.94 .40363 Mdot
.94 .40388 Mdot
.94 .40585 Mdot
.94 .40821 Mdot
.94 .40852 Mdot
.94 .40968 Mdot
.94 .41097 Mdot
.94 .41197 Mdot
.94 .41208 Mdot
.94 .41222 Mdot
.94 .41263 Mdot
.94 .41282 Mdot
.94 .41286 Mdot
.94 .41308 Mdot
.94 .41407 Mdot
.94 .41443 Mdot
.94 .41497 Mdot
.94 .4151 Mdot
.94 .41579 Mdot
.94 .41642 Mdot
.94 .4165 Mdot
.94 .41673 Mdot
.94 .41722 Mdot
.94 .41791 Mdot
.94 .41863 Mdot
.94 .41882 Mdot
.94 .42088 Mdot
.94 .42141 Mdot
.94 .42258 Mdot
.94 .42272 Mdot
.94 .42281 Mdot
.94 .42436 Mdot
.94 .42498 Mdot
.94 .42514 Mdot
.94 .42597 Mdot
.94 .42624 Mdot
.94 .42727 Mdot
.94 .42753 Mdot
.94 .42873 Mdot
.94 .42902 Mdot
.94 .42959 Mdot
.94 .42993 Mdot
.94 .43019 Mdot
.94 .43029 Mdot
.94 .43112 Mdot
.94 .43247 Mdot
.94 .43453 Mdot
.94 .43607 Mdot
.94 .43656 Mdot
.94 .43671 Mdot
.94 .43679 Mdot
.94 .43764 Mdot
.94 .4379 Mdot
.94 .43841 Mdot
.94 .43875 Mdot
.94 .44042 Mdot
.94 .44059 Mdot
.94 .443 Mdot
.94 .44364 Mdot
.94 .44432 Mdot
.94 .44453 Mdot
.94 .44476 Mdot
.94 .44715 Mdot
.94 .44747 Mdot
.94 .448 Mdot
.94 .44815 Mdot
.94 .44977 Mdot
.94 .44981 Mdot
.94 .44983 Mdot
.94 .45011 Mdot
.94 .45033 Mdot
.94 .45176 Mdot
.94 .45188 Mdot
.94 .45249 Mdot
.94 .45275 Mdot
.94 .45317 Mdot
.94 .45326 Mdot
.94 .45372 Mdot
.94 .45406 Mdot
.94 .45454 Mdot
.94 .45472 Mdot
.94 .455 Mdot
.94 .45566 Mdot
.94 .45572 Mdot
.94 .45644 Mdot
.94 .45655 Mdot
.94 .45672 Mdot
.94 .45754 Mdot
.94 .45762 Mdot
.94 .45788 Mdot
.94 .45804 Mdot
.94 .45923 Mdot
.94 .45934 Mdot
.94 .45945 Mdot
.94 .46218 Mdot
.94 .46259 Mdot
.94 .46272 Mdot
.94 .46313 Mdot
.94 .46317 Mdot
.94 .46324 Mdot
.94 .46348 Mdot
.94 .46422 Mdot
.94 .46624 Mdot
.94 .46628 Mdot
.94 .46657 Mdot
.94 .46684 Mdot
.94 .46754 Mdot
.94 .46815 Mdot
.94 .46866 Mdot
.94 .46974 Mdot
.94 .47231 Mdot
.94 .47253 Mdot
.94 .47296 Mdot
.94 .47334 Mdot
.94 .47358 Mdot
.94 .47419 Mdot
.94 .47429 Mdot
.94 .47431 Mdot
.94 .47457 Mdot
.94 .47464 Mdot
.94 .47469 Mdot
.94 .47572 Mdot
.94 .47623 Mdot
.94 .47742 Mdot
.94 .47828 Mdot
.94 .4784 Mdot
.94 .47871 Mdot
.94 .47905 Mdot
.94 .47921 Mdot
.94 .48002 Mdot
.94 .48006 Mdot
.94 .48033 Mdot
.94 .48067 Mdot
.94 .48218 Mdot
.94 .48246 Mdot
.94 .48291 Mdot
.94 .48325 Mdot
.94 .48385 Mdot
.94 .48406 Mdot
.94 .48421 Mdot
.94 .48473 Mdot
.94 .48518 Mdot
.94 .48664 Mdot
.94 .48672 Mdot
.94 .48678 Mdot
.94 .48693 Mdot
.94 .48704 Mdot
.94 .48788 Mdot
.94 .48802 Mdot
.94 .48846 Mdot
.94 .48897 Mdot
.94 .49049 Mdot
.94 .49358 Mdot
.94 .49365 Mdot
.94 .49393 Mdot
.94 .49616 Mdot
.94 .49716 Mdot
.94 .49751 Mdot
.94 .49767 Mdot
.94 .4981 Mdot
.94 .49864 Mdot
.94 .49945 Mdot
.94 .49956 Mdot
.94 .50003 Mdot
.94 .50195 Mdot
.94 .50237 Mdot
.94 .50386 Mdot
.94 .504 Mdot
.94 .50409 Mdot
.94 .50442 Mdot
.94 .5046 Mdot
.94 .50468 Mdot
.94 .50572 Mdot
.94 .50597 Mdot
.94 .50694 Mdot
.94 .50932 Mdot
.94 .50946 Mdot
.94 .50958 Mdot
.94 .50966 Mdot
.94 .51145 Mdot
.94 .51224 Mdot
.94 .51438 Mdot
.94 .51475 Mdot
.94 .51509 Mdot
.94 .5153 Mdot
.94 .51549 Mdot
.94 .51558 Mdot
.94 .51601 Mdot
.94 .51613 Mdot
.94 .51664 Mdot
.94 .51691 Mdot
.94 .51765 Mdot
.94 .51789 Mdot
.94 .51835 Mdot
.94 .51869 Mdot
.94 .51881 Mdot
.94 .51905 Mdot
.94 .51933 Mdot
.94 .51942 Mdot
.94 .51971 Mdot
.94 .5205 Mdot
.94 .5207 Mdot
.94 .52089 Mdot
.94 .52111 Mdot
.94 .52165 Mdot
.94 .52216 Mdot
.94 .52312 Mdot
.94 .52355 Mdot
.94 .52376 Mdot
.94 .52385 Mdot
.94 .52392 Mdot
.94 .52398 Mdot
.94 .52417 Mdot
.94 .52432 Mdot
.94 .52462 Mdot
.94 .52474 Mdot
.94 .52483 Mdot
.94 .52493 Mdot
.94 .52509 Mdot
.94 .52567 Mdot
.94 .52601 Mdot
.94 .52647 Mdot
.94 .5265 Mdot
.94 .52741 Mdot
.94 .5275 Mdot
.94 .52789 Mdot
.94 .52823 Mdot
.94 .52977 Mdot
.94 .5299 Mdot
.94 .53019 Mdot
.94 .53135 Mdot
.94 .53188 Mdot
.94 .5333 Mdot
.94 .53455 Mdot
.94 .53583 Mdot
.94 .53616 Mdot
.94 .53635 Mdot
.94 .53637 Mdot
.94 .53693 Mdot
.94 .53705 Mdot
.94 .53803 Mdot
.94 .53849 Mdot
.94 .53915 Mdot
.94 .53931 Mdot
.94 .53977 Mdot
.94 .53992 Mdot
.94 .54079 Mdot
.94 .54089 Mdot
.94 .54091 Mdot
.94 .54133 Mdot
.94 .54164 Mdot
.94 .54257 Mdot
.94 .54331 Mdot
.94 .54369 Mdot
.94 .5438 Mdot
.94 .54388 Mdot
.94 .5463 Mdot
.94 .54671 Mdot
.94 .5473 Mdot
.94 .54744 Mdot
.94 .54865 Mdot
.94 .54954 Mdot
.94 .54988 Mdot
.94 .55014 Mdot
.94 .55026 Mdot
.94 .55052 Mdot
.94 .55096 Mdot
.94 .55109 Mdot
.94 .55135 Mdot
.94 .55165 Mdot
.94 .55186 Mdot
.94 .55202 Mdot
.94 .55336 Mdot
.94 .55434 Mdot
.94 .55448 Mdot
.94 .55532 Mdot
.94 .5564 Mdot
.94 .55739 Mdot
.94 .55759 Mdot
.94 .55808 Mdot
.94 .55828 Mdot
.94 .55836 Mdot
.94 .5584 Mdot
.94 .55876 Mdot
.94 .55891 Mdot
.94 .55899 Mdot
.94 .55904 Mdot
.94 .55921 Mdot
.94 .55967 Mdot
.94 .55972 Mdot
.94 .55973 Mdot
.94 .55974 Mdot
.94 .56005 Mdot
.94 .56102 Mdot
.94 .56134 Mdot
.94 .56157 Mdot
.94 .56236 Mdot
.94 .56265 Mdot
.94 .5628 Mdot
.94 .56309 Mdot
.94 .56313 Mdot
.94 .56353 Mdot
.94 .56443 Mdot
.94 .56452 Mdot
.94 .56489 Mdot
.94 .56518 Mdot
.94 .56636 Mdot
.94 .56652 Mdot
.94 .56672 Mdot
.94 .56689 Mdot
.94 .56703 Mdot
.94 .56733 Mdot
.94 .56735 Mdot
.94 .56797 Mdot
.94 .56816 Mdot
.94 .56922 Mdot
.94 .57018 Mdot
.94 .57052 Mdot
.94 .57084 Mdot
.94 .57209 Mdot
.94 .57224 Mdot
.94 .57228 Mdot
.94 .57234 Mdot
.94 .57275 Mdot
.94 .57301 Mdot
.94 .57325 Mdot
.94 .57329 Mdot
.94 .5734 Mdot
.94 .57354 Mdot
.94 .57393 Mdot
.94 .57407 Mdot
.94 .57514 Mdot
.94 .5758 Mdot
.94 .57587 Mdot
.94 .57648 Mdot
.94 .57682 Mdot
.94 .57719 Mdot
.94 .57803 Mdot
.94 .57853 Mdot
.94 .57912 Mdot
.94 .57965 Mdot
.94 .57995 Mdot
.94 .58034 Mdot
.94 .58048 Mdot
.94 .5806 Mdot
.94 .58097 Mdot
.94 .58131 Mdot
.94 .5817 Mdot
.94 .5819 Mdot
.94 .58192 Mdot
.94 .58206 Mdot
.94 .58215 Mdot
.94 .58217 Mdot
.94 .5827 Mdot
.94 .58275 Mdot
.94 .58284 Mdot
.94 .58287 Mdot
.94 .58305 Mdot
.94 .58324 Mdot
.94 .5833 Mdot
.94 .5833 Mdot
.94 .58331 Mdot
.94 .58333 Mdot
.94 .58335 Mdot
.94 .58341 Mdot
.94 .58357 Mdot
.94 .58368 Mdot
.94 .58406 Mdot
.94 .58426 Mdot
.94 .58444 Mdot
.94 .58485 Mdot
.94 .58533 Mdot
.94 .58553 Mdot
.94 .58566 Mdot
.94 .58691 Mdot
.94 .58707 Mdot
.94 .58745 Mdot
.94 .58776 Mdot
.94 .58784 Mdot
.94 .58831 Mdot
.94 .58832 Mdot
.94 .5886 Mdot
.94 .58882 Mdot
.94 .58894 Mdot
.94 .58911 Mdot
.94 .58924 Mdot
.94 .58936 Mdot
.94 .58939 Mdot
.94 .58944 Mdot
.94 .58949 Mdot
.94 .58955 Mdot
.94 .58959 Mdot
.94 .5896 Mdot
.94 .58986 Mdot
.94 .58988 Mdot
.94 .59005 Mdot
.94 .59007 Mdot
.94 .5901 Mdot
.94 .59012 Mdot
.94 .59014 Mdot
.94 .59065 Mdot
.94 .59068 Mdot
.94 .59102 Mdot
.94 .59119 Mdot
.94 .59142 Mdot
.94 .59144 Mdot
.94 .59152 Mdot
.94 .59163 Mdot
.94 .59179 Mdot
.94 .59187 Mdot
.94 .5919 Mdot
.94 .59199 Mdot
.94 .59206 Mdot
.94 .5921 Mdot
.94 .59231 Mdot
.94 .59239 Mdot
.94 .59253 Mdot
.94 .5927 Mdot
.94 .59276 Mdot
.94 .59281 Mdot
.94 .59289 Mdot
.94 .59294 Mdot
.94 .59307 Mdot
.94 .59342 Mdot
.94 .59372 Mdot
.94 .59377 Mdot
.94 .59401 Mdot
.94 .59411 Mdot
.94 .59413 Mdot
.94 .5942 Mdot
.94 .59421 Mdot
.94 .59428 Mdot
.94 .59433 Mdot
.94 .59436 Mdot
.94 .59441 Mdot
.94 .59447 Mdot
.94 .59479 Mdot
.94 .59485 Mdot
.94 .59491 Mdot
.94 .59501 Mdot
.94 .59511 Mdot
.94 .59527 Mdot
.94 .59535 Mdot
.94 .59547 Mdot
.94 .59553 Mdot
.94 .59559 Mdot
.94 .59559 Mdot
.94 .59562 Mdot
.94 .59572 Mdot
.94 .5958 Mdot
.94 .59583 Mdot
.94 .59593 Mdot
.94 .59593 Mdot
.94 .59598 Mdot
.94 .59604 Mdot
.94 .59609 Mdot
.94 .59614 Mdot
.94 .59618 Mdot
.94 .59619 Mdot
.94 .59619 Mdot
.94 .5962 Mdot
.94 .59622 Mdot
.94 .59623 Mdot
.94 .59623 Mdot
.94 .59624 Mdot
.94 .59625 Mdot
.94 .59625 Mdot
.94 .59625 Mdot
.94 .59625 Mdot
.94 .59625 Mdot
.942 .04139 Mdot
.942 .0414 Mdot
.942 .0414 Mdot
.942 .04143 Mdot
.942 .04158 Mdot
.942 .04161 Mdot
.942 .04171 Mdot
.942 .04187 Mdot
.942 .04237 Mdot
.942 .04266 Mdot
.942 .04267 Mdot
.942 .04284 Mdot
.942 .04289 Mdot
.942 .04297 Mdot
.942 .04324 Mdot
.942 .04362 Mdot
.942 .04369 Mdot
.942 .04422 Mdot
.942 .04443 Mdot
.942 .04459 Mdot
.942 .04464 Mdot
.942 .04479 Mdot
.942 .04508 Mdot
.942 .04548 Mdot
.942 .04577 Mdot
.942 .046 Mdot
.942 .04626 Mdot
.942 .04627 Mdot
.942 .04658 Mdot
.942 .04722 Mdot
.942 .04763 Mdot
.942 .04794 Mdot
.942 .04807 Mdot
.942 .04818 Mdot
.942 .04828 Mdot
.942 .04829 Mdot
.942 .04908 Mdot
.942 .04959 Mdot
.942 .0496 Mdot
.942 .05046 Mdot
.942 .05172 Mdot
.942 .05453 Mdot
.942 .05493 Mdot
.942 .05494 Mdot
.942 .05546 Mdot
.942 .05621 Mdot
.942 .05683 Mdot
.942 .05685 Mdot
.942 .05712 Mdot
.942 .05866 Mdot
.942 .0589 Mdot
.942 .05901 Mdot
.942 .05928 Mdot
.942 .0603 Mdot
.942 .06045 Mdot
.942 .06093 Mdot
.942 .06231 Mdot
.942 .06275 Mdot
.942 .06318 Mdot
.942 .06331 Mdot
.942 .06385 Mdot
.942 .06408 Mdot
.942 .06457 Mdot
.942 .06684 Mdot
.942 .06789 Mdot
.942 .06814 Mdot
.942 .06841 Mdot
.942 .0688 Mdot
.942 .06926 Mdot
.942 .0698 Mdot
.942 .07139 Mdot
.942 .07187 Mdot
.942 .07265 Mdot
.942 .07401 Mdot
.942 .07408 Mdot
.942 .07412 Mdot
.942 .07428 Mdot
.942 .07436 Mdot
.942 .07462 Mdot
.942 .07528 Mdot
.942 .07551 Mdot
.942 .07587 Mdot
.942 .0763 Mdot
.942 .07724 Mdot
.942 .07738 Mdot
.942 .07764 Mdot
.942 .07826 Mdot
.942 .07957 Mdot
.942 .07995 Mdot
.942 .08003 Mdot
.942 .08004 Mdot
.942 .08101 Mdot
.942 .08112 Mdot
.942 .08249 Mdot
.942 .08255 Mdot
.942 .08327 Mdot
.942 .08406 Mdot
.942 .08597 Mdot
.942 .08633 Mdot
.942 .08668 Mdot
.942 .08758 Mdot
.942 .08838 Mdot
.942 .08857 Mdot
.942 .09048 Mdot
.942 .09077 Mdot
.942 .0917 Mdot
.942 .09211 Mdot
.942 .09256 Mdot
.942 .09405 Mdot
.942 .09405 Mdot
.942 .09649 Mdot
.942 .09662 Mdot
.942 .09681 Mdot
.942 .09789 Mdot
.942 .09818 Mdot
.942 .09842 Mdot
.942 .10088 Mdot
.942 .10171 Mdot
.942 .10195 Mdot
.942 .10213 Mdot
.942 .10228 Mdot
.942 .10317 Mdot
.942 .10484 Mdot
.942 .10496 Mdot
.942 .10555 Mdot
.942 .1062 Mdot
.942 .10687 Mdot
.942 .10713 Mdot
.942 .11043 Mdot
.942 .11072 Mdot
.942 .11095 Mdot
.942 .11115 Mdot
.942 .11279 Mdot
.942 .1138 Mdot
.942 .11542 Mdot
.942 .11543 Mdot
.942 .11544 Mdot
.942 .11555 Mdot
.942 .11574 Mdot
.942 .1159 Mdot
.942 .1161 Mdot
.942 .11618 Mdot
.942 .11657 Mdot
.942 .11664 Mdot
.942 .11714 Mdot
.942 .11744 Mdot
.942 .11825 Mdot
.942 .11828 Mdot
.942 .11892 Mdot
.942 .119 Mdot
.942 .11973 Mdot
.942 .11997 Mdot
.942 .12001 Mdot
.942 .1206 Mdot
.942 .12079 Mdot
.942 .12107 Mdot
.942 .12118 Mdot
.942 .12139 Mdot
.942 .122 Mdot
.942 .12204 Mdot
.942 .12248 Mdot
.942 .12303 Mdot
.942 .12316 Mdot
.942 .12326 Mdot
.942 .12337 Mdot
.942 .12362 Mdot
.942 .12434 Mdot
.942 .12467 Mdot
.942 .12551 Mdot
.942 .12629 Mdot
.942 .12635 Mdot
.942 .12685 Mdot
.942 .12701 Mdot
.942 .12736 Mdot
.942 .12755 Mdot
.942 .12857 Mdot
.942 .12864 Mdot
.942 .13001 Mdot
.942 .13063 Mdot
.942 .13101 Mdot
.942 .1313 Mdot
.942 .13182 Mdot
.942 .13257 Mdot
.942 .13275 Mdot
.942 .13279 Mdot
.942 .13325 Mdot
.942 .13355 Mdot
.942 .13388 Mdot
.942 .13457 Mdot
.942 .13485 Mdot
.942 .1349 Mdot
.942 .13578 Mdot
.942 .13612 Mdot
.942 .13759 Mdot
.942 .13868 Mdot
.942 .13911 Mdot
.942 .13952 Mdot
.942 .1398 Mdot
.942 .13984 Mdot
.942 .13989 Mdot
.942 .14016 Mdot
.942 .14053 Mdot
.942 .14063 Mdot
.942 .14076 Mdot
.942 .14172 Mdot
.942 .14266 Mdot
.942 .14334 Mdot
.942 .14433 Mdot
.942 .14443 Mdot
.942 .14446 Mdot
.942 .14468 Mdot
.942 .14477 Mdot
.942 .14547 Mdot
.942 .14548 Mdot
.942 .14747 Mdot
.942 .14807 Mdot
.942 .14903 Mdot
.942 .14953 Mdot
.942 .15153 Mdot
.942 .15178 Mdot
.942 .15181 Mdot
.942 .15322 Mdot
.942 .15344 Mdot
.942 .15386 Mdot
.942 .15731 Mdot
.942 .15758 Mdot
.942 .15779 Mdot
.942 .15793 Mdot
.942 .16041 Mdot
.942 .1615 Mdot
.942 .16182 Mdot
.942 .16285 Mdot
.942 .16289 Mdot
.942 .16301 Mdot
.942 .16467 Mdot
.942 .16665 Mdot
.942 .16722 Mdot
.942 .16808 Mdot
.942 .16853 Mdot
.942 .16904 Mdot
.942 .1693 Mdot
.942 .16937 Mdot
.942 .1703 Mdot
.942 .17076 Mdot
.942 .17167 Mdot
.942 .17219 Mdot
.942 .17345 Mdot
.942 .1746 Mdot
.942 .17548 Mdot
.942 .1763 Mdot
.942 .17647 Mdot
.942 .17667 Mdot
.942 .17757 Mdot
.942 .17884 Mdot
.942 .18098 Mdot
.942 .18149 Mdot
.942 .18171 Mdot
.942 .1819 Mdot
.942 .18208 Mdot
.942 .18255 Mdot
.942 .18305 Mdot
.942 .1831 Mdot
.942 .18469 Mdot
.942 .18477 Mdot
.942 .18545 Mdot
.942 .18668 Mdot
.942 .18769 Mdot
.942 .18912 Mdot
.942 .18926 Mdot
.942 .1899 Mdot
.942 .19055 Mdot
.942 .19062 Mdot
.942 .19076 Mdot
.942 .19098 Mdot
.942 .19109 Mdot
.942 .19277 Mdot
.942 .19318 Mdot
.942 .19352 Mdot
.942 .19491 Mdot
.942 .19514 Mdot
.942 .19742 Mdot
.942 .20014 Mdot
.942 .20053 Mdot
.942 .20134 Mdot
.942 .20256 Mdot
.942 .20285 Mdot
.942 .20348 Mdot
.942 .20439 Mdot
.942 .20592 Mdot
.942 .20597 Mdot
.942 .20616 Mdot
.942 .20668 Mdot
.942 .20677 Mdot
.942 .20746 Mdot
.942 .20763 Mdot
.942 .20836 Mdot
.942 .20877 Mdot
.942 .20889 Mdot
.942 .2104 Mdot
.942 .21211 Mdot
.942 .21277 Mdot
.942 .21558 Mdot
.942 .2163 Mdot
.942 .21722 Mdot
.942 .21876 Mdot
.942 .21923 Mdot
.942 .22123 Mdot
.942 .22331 Mdot
.942 .22553 Mdot
.942 .22575 Mdot
.942 .22589 Mdot
.942 .22638 Mdot
.942 .22663 Mdot
.942 .22746 Mdot
.942 .22953 Mdot
.942 .23026 Mdot
.942 .2308 Mdot
.942 .2314 Mdot
.942 .23175 Mdot
.942 .23195 Mdot
.942 .23197 Mdot
.942 .2326 Mdot
.942 .23273 Mdot
.942 .23566 Mdot
.942 .2361 Mdot
.942 .23691 Mdot
.942 .23846 Mdot
.942 .23883 Mdot
.942 .24015 Mdot
.942 .24147 Mdot
.942 .242 Mdot
.942 .24289 Mdot
.942 .24405 Mdot
.942 .24428 Mdot
.942 .24431 Mdot
.942 .24476 Mdot
.942 .2453 Mdot
.942 .24594 Mdot
.942 .24731 Mdot
.942 .24763 Mdot
.942 .24886 Mdot
.942 .24909 Mdot
.942 .25134 Mdot
.942 .25173 Mdot
.942 .25177 Mdot
.942 .25181 Mdot
.942 .25202 Mdot
.942 .25219 Mdot
.942 .25419 Mdot
.942 .25447 Mdot
.942 .25453 Mdot
.942 .25566 Mdot
.942 .25658 Mdot
.942 .25789 Mdot
.942 .25826 Mdot
.942 .25877 Mdot
.942 .25993 Mdot
.942 .26233 Mdot
.942 .2634 Mdot
.942 .26341 Mdot
.942 .26446 Mdot
.942 .26488 Mdot
.942 .26501 Mdot
.942 .26679 Mdot
.942 .26713 Mdot
.942 .26845 Mdot
.942 .26952 Mdot
.942 .27007 Mdot
.942 .27008 Mdot
.942 .27099 Mdot
.942 .27146 Mdot
.942 .2731 Mdot
.942 .27477 Mdot
.942 .27571 Mdot
.942 .27603 Mdot
.942 .27655 Mdot
.942 .27671 Mdot
.942 .27686 Mdot
.942 .27897 Mdot
.942 .27929 Mdot
.942 .27944 Mdot
.942 .2798 Mdot
.942 .28048 Mdot
.942 .28179 Mdot
.942 .2819 Mdot
.942 .28265 Mdot
.942 .28285 Mdot
.942 .28293 Mdot
.942 .28609 Mdot
.942 .2861 Mdot
.942 .28902 Mdot
.942 .29177 Mdot
.942 .29269 Mdot
.942 .2927 Mdot
.942 .29295 Mdot
.942 .2931 Mdot
.942 .29349 Mdot
.942 .29401 Mdot
.942 .29486 Mdot
.942 .29529 Mdot
.942 .29569 Mdot
.942 .29645 Mdot
.942 .29709 Mdot
.942 .29757 Mdot
.942 .2979 Mdot
.942 .29858 Mdot
.942 .30141 Mdot
.942 .30199 Mdot
.942 .30202 Mdot
.942 .30472 Mdot
.942 .30551 Mdot
.942 .30632 Mdot
.942 .30784 Mdot
.942 .30851 Mdot
.942 .30901 Mdot
.942 .30941 Mdot
.942 .31187 Mdot
.942 .31648 Mdot
.942 .31681 Mdot
.942 .31746 Mdot
.942 .31828 Mdot
.942 .31842 Mdot
.942 .31985 Mdot
.942 .32021 Mdot
.942 .32201 Mdot
.942 .32273 Mdot
.942 .32522 Mdot
.942 .32682 Mdot
.942 .32683 Mdot
.942 .32775 Mdot
.942 .33159 Mdot
.942 .33238 Mdot
.942 .333 Mdot
.942 .33349 Mdot
.942 .33351 Mdot
.942 .33373 Mdot
.942 .33491 Mdot
.942 .33658 Mdot
.942 .33785 Mdot
.942 .33814 Mdot
.942 .34052 Mdot
.942 .34172 Mdot
.942 .34354 Mdot
.942 .34398 Mdot
.942 .34474 Mdot
.942 .34478 Mdot
.942 .34481 Mdot
.942 .34489 Mdot
.942 .34508 Mdot
.942 .34544 Mdot
.942 .34557 Mdot
.942 .34577 Mdot
.942 .346 Mdot
.942 .3465 Mdot
.942 .34671 Mdot
.942 .34772 Mdot
.942 .34792 Mdot
.942 .34846 Mdot
.942 .3492 Mdot
.942 .34923 Mdot
.942 .34998 Mdot
.942 .35107 Mdot
.942 .35167 Mdot
.942 .35205 Mdot
.942 .35213 Mdot
.942 .35376 Mdot
.942 .35396 Mdot
.942 .35576 Mdot
.942 .35584 Mdot
.942 .35631 Mdot
.942 .35643 Mdot
.942 .35653 Mdot
.942 .35758 Mdot
.942 .35793 Mdot
.942 .35803 Mdot
.942 .35816 Mdot
.942 .35853 Mdot
.942 .35922 Mdot
.942 .3595 Mdot
.942 .36004 Mdot
.942 .36157 Mdot
.942 .36166 Mdot
.942 .36173 Mdot
.942 .36276 Mdot
.942 .36415 Mdot
.942 .36445 Mdot
.942 .36446 Mdot
.942 .36473 Mdot
.942 .36501 Mdot
.942 .36554 Mdot
.942 .36562 Mdot
.942 .36682 Mdot
.942 .36742 Mdot
.942 .36778 Mdot
.942 .36824 Mdot
.942 .36962 Mdot
.942 .36985 Mdot
.942 .36996 Mdot
.942 .37031 Mdot
.942 .37042 Mdot
.942 .37221 Mdot
.942 .37234 Mdot
.942 .37237 Mdot
.942 .37242 Mdot
.942 .3736 Mdot
.942 .37398 Mdot
.942 .37483 Mdot
.942 .37531 Mdot
.942 .37595 Mdot
.942 .37649 Mdot
.942 .3767 Mdot
.942 .37779 Mdot
.942 .37794 Mdot
.942 .37799 Mdot
.942 .37876 Mdot
.942 .38069 Mdot
.942 .38126 Mdot
.942 .38142 Mdot
.942 .38221 Mdot
.942 .38275 Mdot
.942 .38309 Mdot
.942 .38365 Mdot
.942 .38435 Mdot
.942 .38519 Mdot
.942 .38525 Mdot
.942 .38558 Mdot
.942 .38738 Mdot
.942 .38756 Mdot
.942 .38781 Mdot
.942 .3879 Mdot
.942 .38899 Mdot
.942 .3897 Mdot
.942 .39046 Mdot
.942 .3908 Mdot
.942 .39122 Mdot
.942 .39208 Mdot
.942 .39275 Mdot
.942 .39286 Mdot
.942 .39396 Mdot
.942 .39492 Mdot
.942 .39571 Mdot
.942 .39905 Mdot
.942 .3991 Mdot
.942 .39911 Mdot
.942 .40126 Mdot
.942 .4016 Mdot
.942 .40259 Mdot
.942 .40276 Mdot
.942 .40351 Mdot
.942 .40357 Mdot
.942 .40415 Mdot
.942 .40425 Mdot
.942 .40426 Mdot
.942 .40437 Mdot
.942 .40495 Mdot
.942 .40497 Mdot
.942 .40583 Mdot
.942 .40605 Mdot
.942 .40635 Mdot
.942 .40723 Mdot
.942 .4076 Mdot
.942 .40808 Mdot
.942 .4085 Mdot
.942 .40891 Mdot
.942 .41009 Mdot
.942 .41061 Mdot
.942 .41114 Mdot
.942 .41213 Mdot
.942 .41432 Mdot
.942 .41455 Mdot
.942 .41461 Mdot
.942 .41508 Mdot
.942 .41528 Mdot
.942 .41575 Mdot
.942 .41684 Mdot
.942 .41684 Mdot
.942 .42082 Mdot
.942 .4212 Mdot
.942 .4225 Mdot
.942 .4229 Mdot
.942 .42457 Mdot
.942 .42564 Mdot
.942 .42651 Mdot
.942 .42832 Mdot
.942 .4299 Mdot
.942 .43004 Mdot
.942 .43043 Mdot
.942 .43049 Mdot
.942 .43201 Mdot
.942 .43227 Mdot
.942 .43282 Mdot
.942 .43332 Mdot
.942 .43346 Mdot
.942 .43392 Mdot
.942 .43394 Mdot
.942 .4348 Mdot
.942 .4353 Mdot
.942 .43707 Mdot
.942 .43763 Mdot
.942 .43842 Mdot
.942 .43853 Mdot
.942 .44045 Mdot
.942 .44099 Mdot
.942 .4419 Mdot
.942 .44246 Mdot
.942 .44267 Mdot
.942 .44288 Mdot
.942 .44317 Mdot
.942 .44816 Mdot
.942 .44887 Mdot
.942 .44915 Mdot
.942 .45009 Mdot
.942 .4503 Mdot
.942 .45032 Mdot
.942 .45095 Mdot
.942 .45299 Mdot
.942 .45306 Mdot
.942 .45331 Mdot
.942 .45655 Mdot
.942 .45665 Mdot
.942 .45712 Mdot
.942 .45727 Mdot
.942 .46034 Mdot
.942 .46117 Mdot
.942 .46144 Mdot
.942 .46237 Mdot
.942 .46242 Mdot
.942 .4628 Mdot
.942 .46308 Mdot
.942 .46393 Mdot
.942 .46458 Mdot
.942 .46488 Mdot
.942 .46512 Mdot
.942 .46538 Mdot
.942 .4655 Mdot
.942 .46644 Mdot
.942 .46725 Mdot
.942 .4681 Mdot
.942 .46978 Mdot
.942 .47074 Mdot
.942 .47306 Mdot
.942 .47513 Mdot
.942 .4756 Mdot
.942 .47613 Mdot
.942 .4765 Mdot
.942 .47671 Mdot
.942 .47688 Mdot
.942 .47788 Mdot
.942 .47819 Mdot
.942 .47849 Mdot
.942 .47885 Mdot
.942 .47951 Mdot
.942 .48044 Mdot
.942 .48047 Mdot
.942 .48266 Mdot
.942 .48383 Mdot
.942 .48401 Mdot
.942 .48538 Mdot
.942 .48636 Mdot
.942 .48638 Mdot
.942 .48726 Mdot
.942 .48763 Mdot
.942 .48796 Mdot
.942 .48826 Mdot
.942 .48906 Mdot
.942 .48938 Mdot
.942 .48991 Mdot
.942 .48999 Mdot
.942 .49022 Mdot
.942 .49166 Mdot
.942 .49169 Mdot
.942 .49247 Mdot
.942 .49266 Mdot
.942 .4927 Mdot
.942 .4928 Mdot
.942 .49354 Mdot
.942 .49393 Mdot
.942 .49444 Mdot
.942 .49488 Mdot
.942 .49597 Mdot
.942 .49738 Mdot
.942 .49748 Mdot
.942 .49761 Mdot
.942 .49812 Mdot
.942 .49833 Mdot
.942 .49993 Mdot
.942 .50016 Mdot
.942 .50088 Mdot
.942 .50118 Mdot
.942 .50222 Mdot
.942 .50234 Mdot
.942 .50256 Mdot
.942 .50291 Mdot
.942 .50308 Mdot
.942 .50377 Mdot
.942 .50514 Mdot
.942 .50573 Mdot
.942 .50636 Mdot
.942 .5068 Mdot
.942 .50689 Mdot
.942 .50904 Mdot
.942 .50938 Mdot
.942 .50939 Mdot
.942 .50998 Mdot
.942 .51196 Mdot
.942 .51254 Mdot
.942 .51284 Mdot
.942 .51686 Mdot
.942 .51744 Mdot
.942 .5184 Mdot
.942 .51841 Mdot
.942 .51861 Mdot
.942 .51998 Mdot
.942 .52037 Mdot
.942 .52064 Mdot
.942 .52078 Mdot
.942 .52093 Mdot
.942 .5216 Mdot
.942 .52168 Mdot
.942 .52169 Mdot
.942 .52201 Mdot
.942 .52297 Mdot
.942 .52508 Mdot
.942 .52511 Mdot
.942 .52517 Mdot
.942 .52543 Mdot
.942 .52615 Mdot
.942 .52628 Mdot
.942 .52644 Mdot
.942 .52716 Mdot
.942 .52721 Mdot
.942 .52744 Mdot
.942 .52787 Mdot
.942 .52844 Mdot
.942 .52899 Mdot
.942 .52915 Mdot
.942 .52946 Mdot
.942 .53001 Mdot
.942 .53057 Mdot
.942 .53116 Mdot
.942 .53121 Mdot
.942 .5317 Mdot
.942 .53286 Mdot
.942 .53325 Mdot
.942 .53342 Mdot
.942 .53354 Mdot
.942 .53428 Mdot
.942 .53465 Mdot
.942 .53467 Mdot
.942 .53542 Mdot
.942 .53556 Mdot
.942 .53557 Mdot
.942 .5357 Mdot
.942 .53644 Mdot
.942 .53651 Mdot
.942 .53747 Mdot
.942 .53768 Mdot
.942 .53785 Mdot
.942 .53875 Mdot
.942 .53892 Mdot
.942 .53934 Mdot
.942 .53989 Mdot
.942 .54177 Mdot
.942 .54197 Mdot
.942 .54198 Mdot
.942 .54204 Mdot
.942 .54235 Mdot
.942 .54472 Mdot
.942 .54601 Mdot
.942 .54693 Mdot
.942 .54715 Mdot
.942 .54803 Mdot
.942 .54927 Mdot
.942 .5494 Mdot
.942 .54968 Mdot
.942 .54992 Mdot
.942 .55008 Mdot
.942 .55015 Mdot
.942 .55063 Mdot
.942 .55091 Mdot
.942 .5511 Mdot
.942 .55156 Mdot
.942 .55181 Mdot
.942 .55193 Mdot
.942 .55277 Mdot
.942 .55353 Mdot
.942 .55406 Mdot
.942 .55469 Mdot
.942 .55479 Mdot
.942 .55483 Mdot
.942 .55505 Mdot
.942 .55524 Mdot
.942 .55602 Mdot
.942 .55639 Mdot
.942 .5566 Mdot
.942 .55662 Mdot
.942 .55711 Mdot
.942 .55727 Mdot
.942 .55741 Mdot
.942 .55746 Mdot
.942 .55752 Mdot
.942 .55838 Mdot
.942 .55908 Mdot
.942 .55964 Mdot
.942 .55998 Mdot
.942 .56035 Mdot
.942 .56051 Mdot
.942 .56077 Mdot
.942 .56128 Mdot
.942 .56143 Mdot
.942 .56157 Mdot
.942 .56199 Mdot
.942 .56306 Mdot
.942 .5634 Mdot
.942 .56382 Mdot
.942 .56454 Mdot
.942 .56458 Mdot
.942 .56464 Mdot
.942 .56472 Mdot
.942 .56572 Mdot
.942 .56584 Mdot
.942 .56591 Mdot
.942 .56633 Mdot
.942 .5664 Mdot
.942 .56698 Mdot
.942 .56712 Mdot
.942 .5674 Mdot
.942 .56814 Mdot
.942 .56814 Mdot
.942 .56835 Mdot
.942 .56837 Mdot
.942 .56847 Mdot
.942 .56875 Mdot
.942 .56922 Mdot
.942 .56949 Mdot
.942 .56953 Mdot
.942 .56956 Mdot
.942 .56967 Mdot
.942 .56977 Mdot
.942 .57091 Mdot
.942 .57116 Mdot
.942 .57118 Mdot
.942 .57126 Mdot
.942 .57155 Mdot
.942 .57163 Mdot
.942 .57182 Mdot
.942 .57218 Mdot
.942 .57237 Mdot
.942 .57294 Mdot
.942 .5733 Mdot
.942 .57358 Mdot
.942 .57405 Mdot
.942 .57414 Mdot
.942 .57445 Mdot
.942 .57448 Mdot
.942 .57451 Mdot
.942 .57467 Mdot
.942 .5748 Mdot
.942 .57497 Mdot
.942 .57503 Mdot
.942 .57544 Mdot
.942 .57564 Mdot
.942 .57584 Mdot
.942 .57585 Mdot
.942 .57607 Mdot
.942 .5763 Mdot
.942 .5765 Mdot
.942 .57655 Mdot
.942 .57709 Mdot
.942 .57737 Mdot
.942 .57782 Mdot
.942 .57788 Mdot
.942 .57794 Mdot
.942 .57802 Mdot
.942 .57893 Mdot
.942 .57901 Mdot
.942 .57919 Mdot
.942 .57937 Mdot
.942 .57953 Mdot
.942 .57956 Mdot
.942 .58002 Mdot
.942 .58027 Mdot
.942 .58031 Mdot
.942 .58036 Mdot
.942 .58042 Mdot
.942 .58065 Mdot
.942 .58133 Mdot
.942 .58139 Mdot
.942 .58147 Mdot
.942 .58177 Mdot
.942 .58182 Mdot
.942 .58185 Mdot
.942 .58252 Mdot
.942 .58252 Mdot
.942 .58292 Mdot
.942 .58304 Mdot
.942 .58315 Mdot
.942 .58341 Mdot
.942 .58349 Mdot
.942 .584 Mdot
.942 .58405 Mdot
.942 .58427 Mdot
.942 .58452 Mdot
.942 .58461 Mdot
.942 .58471 Mdot
.942 .58522 Mdot
.942 .58544 Mdot
.942 .58563 Mdot
.942 .58565 Mdot
.942 .58602 Mdot
.942 .58604 Mdot
.942 .5863 Mdot
.942 .58631 Mdot
.942 .58633 Mdot
.942 .58643 Mdot
.942 .58678 Mdot
.942 .58695 Mdot
.942 .58702 Mdot
.942 .58705 Mdot
.942 .58731 Mdot
.942 .58742 Mdot
.942 .58752 Mdot
.942 .58758 Mdot
.942 .58776 Mdot
.942 .58782 Mdot
.942 .58785 Mdot
.942 .58789 Mdot
.942 .5879 Mdot
.942 .58792 Mdot
.942 .58828 Mdot
.942 .58849 Mdot
.942 .58862 Mdot
.942 .58904 Mdot
.942 .58918 Mdot
.942 .58931 Mdot
.942 .58941 Mdot
.942 .58948 Mdot
.942 .58955 Mdot
.942 .58982 Mdot
.942 .59043 Mdot
.942 .59056 Mdot
.942 .59062 Mdot
.942 .59076 Mdot
.942 .59079 Mdot
.942 .59091 Mdot
.942 .59102 Mdot
.942 .59139 Mdot
.942 .59151 Mdot
.942 .59155 Mdot
.942 .59182 Mdot
.942 .59189 Mdot
.942 .59192 Mdot
.942 .59199 Mdot
.942 .59239 Mdot
.942 .59246 Mdot
.942 .59247 Mdot
.942 .59263 Mdot
.942 .59282 Mdot
.942 .59296 Mdot
.942 .59297 Mdot
.942 .59307 Mdot
.942 .59381 Mdot
.942 .59413 Mdot
.942 .59436 Mdot
.942 .59436 Mdot
.942 .59449 Mdot
.942 .5947 Mdot
.942 .5947 Mdot
.942 .59473 Mdot
.942 .59476 Mdot
.942 .59479 Mdot
.942 .59487 Mdot
.942 .59498 Mdot
.942 .59515 Mdot
.942 .59523 Mdot
.942 .59523 Mdot
.942 .5953 Mdot
.942 .59536 Mdot
.942 .59543 Mdot
.942 .59554 Mdot
.942 .59561 Mdot
.942 .59565 Mdot
.942 .59566 Mdot
.942 .5957 Mdot
.942 .59576 Mdot
.942 .5959 Mdot
.942 .59592 Mdot
.942 .59601 Mdot
.942 .59608 Mdot
.942 .5961 Mdot
.942 .59612 Mdot
.942 .59616 Mdot
.942 .59616 Mdot
.942 .59637 Mdot
.942 .59641 Mdot
.942 .59644 Mdot
.942 .59644 Mdot
.942 .59648 Mdot
.942 .59649 Mdot
.942 .59649 Mdot
.942 .59649 Mdot
.944 .04051 Mdot
.944 .04052 Mdot
.944 .04055 Mdot
.944 .0406 Mdot
.944 .04072 Mdot
.944 .04072 Mdot
.944 .04084 Mdot
.944 .04086 Mdot
.944 .04117 Mdot
.944 .0414 Mdot
.944 .04142 Mdot
.944 .04179 Mdot
.944 .04196 Mdot
.944 .04202 Mdot
.944 .04204 Mdot
.944 .04235 Mdot
.944 .04253 Mdot
.944 .04258 Mdot
.944 .04272 Mdot
.944 .04279 Mdot
.944 .04359 Mdot
.944 .04375 Mdot
.944 .0439 Mdot
.944 .04422 Mdot
.944 .04433 Mdot
.944 .04452 Mdot
.944 .0448 Mdot
.944 .04593 Mdot
.944 .04641 Mdot
.944 .04682 Mdot
.944 .04713 Mdot
.944 .04774 Mdot
.944 .04778 Mdot
.944 .04795 Mdot
.944 .04826 Mdot
.944 .04856 Mdot
.944 .04872 Mdot
.944 .04968 Mdot
.944 .05028 Mdot
.944 .05058 Mdot
.944 .05139 Mdot
.944 .05147 Mdot
.944 .05151 Mdot
.944 .05209 Mdot
.944 .05276 Mdot
.944 .05336 Mdot
.944 .05377 Mdot
.944 .05383 Mdot
.944 .05425 Mdot
.944 .05459 Mdot
.944 .05478 Mdot
.944 .05492 Mdot
.944 .05635 Mdot
.944 .05665 Mdot
.944 .05666 Mdot
.944 .05743 Mdot
.944 .0592 Mdot
.944 .0593 Mdot
.944 .06004 Mdot
.944 .06006 Mdot
.944 .06009 Mdot
.944 .06031 Mdot
.944 .06067 Mdot
.944 .06117 Mdot
.944 .06136 Mdot
.944 .06234 Mdot
.944 .06282 Mdot
.944 .063 Mdot
.944 .06306 Mdot
.944 .06345 Mdot
.944 .06374 Mdot
.944 .06416 Mdot
.944 .06477 Mdot
.944 .06494 Mdot
.944 .06515 Mdot
.944 .06718 Mdot
.944 .0674 Mdot
.944 .06778 Mdot
.944 .06818 Mdot
.944 .06883 Mdot
.944 .0689 Mdot
.944 .06973 Mdot
.944 .06982 Mdot
.944 .06986 Mdot
.944 .07142 Mdot
.944 .07268 Mdot
.944 .07363 Mdot
.944 .07404 Mdot
.944 .07538 Mdot
.944 .07582 Mdot
.944 .07643 Mdot
.944 .07683 Mdot
.944 .07683 Mdot
.944 .0772 Mdot
.944 .07825 Mdot
.944 .0783 Mdot
.944 .07989 Mdot
.944 .08003 Mdot
.944 .08006 Mdot
.944 .08064 Mdot
.944 .08158 Mdot
.944 .08163 Mdot
.944 .08214 Mdot
.944 .08339 Mdot
.944 .08372 Mdot
.944 .08489 Mdot
.944 .08489 Mdot
.944 .08496 Mdot
.944 .08521 Mdot
.944 .08654 Mdot
.944 .08655 Mdot
.944 .08759 Mdot
.944 .08839 Mdot
.944 .08921 Mdot
.944 .09146 Mdot
.944 .09155 Mdot
.944 .09162 Mdot
.944 .0926 Mdot
.944 .09376 Mdot
.944 .09511 Mdot
.944 .09521 Mdot
.944 .09543 Mdot
.944 .09596 Mdot
.944 .09608 Mdot
.944 .09615 Mdot
.944 .09766 Mdot
.944 .0989 Mdot
.944 .09908 Mdot
.944 .09957 Mdot
.944 .10074 Mdot
.944 .10079 Mdot
.944 .10137 Mdot
.944 .10262 Mdot
.944 .10315 Mdot
.944 .10316 Mdot
.944 .10531 Mdot
.944 .10616 Mdot
.944 .1082 Mdot
.944 .10961 Mdot
.944 .11042 Mdot
.944 .11057 Mdot
.944 .1113 Mdot
.944 .11202 Mdot
.944 .11226 Mdot
.944 .11232 Mdot
.944 .11242 Mdot
.944 .1126 Mdot
.944 .11297 Mdot
.944 .11302 Mdot
.944 .11304 Mdot
.944 .11346 Mdot
.944 .11355 Mdot
.944 .11462 Mdot
.944 .11465 Mdot
.944 .11499 Mdot
.944 .11547 Mdot
.944 .11555 Mdot
.944 .11678 Mdot
.944 .11689 Mdot
.944 .11748 Mdot
.944 .1177 Mdot
.944 .11776 Mdot
.944 .11889 Mdot
.944 .11909 Mdot
.944 .11955 Mdot
.944 .1197 Mdot
.944 .1202 Mdot
.944 .12047 Mdot
.944 .12204 Mdot
.944 .12216 Mdot
.944 .12299 Mdot
.944 .12334 Mdot
.944 .12391 Mdot
.944 .12444 Mdot
.944 .12491 Mdot
.944 .12557 Mdot
.944 .12596 Mdot
.944 .12665 Mdot
.944 .12666 Mdot
.944 .12722 Mdot
.944 .12763 Mdot
.944 .12932 Mdot
.944 .12975 Mdot
.944 .12995 Mdot
.944 .13162 Mdot
.944 .13193 Mdot
.944 .13312 Mdot
.944 .13335 Mdot
.944 .13377 Mdot
.944 .13465 Mdot
.944 .13477 Mdot
.944 .13588 Mdot
.944 .13749 Mdot
.944 .13802 Mdot
.944 .13815 Mdot
.944 .13815 Mdot
.944 .13874 Mdot
.944 .13964 Mdot
.944 .13985 Mdot
.944 .14084 Mdot
.944 .14087 Mdot
.944 .14139 Mdot
.944 .14143 Mdot
.944 .14172 Mdot
.944 .14253 Mdot
.944 .14257 Mdot
.944 .14347 Mdot
.944 .14375 Mdot
.944 .1448 Mdot
.944 .14501 Mdot
.944 .1468 Mdot
.944 .14792 Mdot
.944 .14989 Mdot
.944 .15047 Mdot
.944 .15074 Mdot
.944 .15093 Mdot
.944 .15102 Mdot
.944 .15116 Mdot
.944 .15269 Mdot
.944 .15316 Mdot
.944 .15547 Mdot
.944 .15752 Mdot
.944 .15895 Mdot
.944 .15916 Mdot
.944 .16042 Mdot
.944 .16059 Mdot
.944 .16077 Mdot
.944 .16097 Mdot
.944 .16176 Mdot
.944 .16212 Mdot
.944 .16241 Mdot
.944 .16286 Mdot
.944 .16291 Mdot
.944 .163 Mdot
.944 .16624 Mdot
.944 .1665 Mdot
.944 .16752 Mdot
.944 .16753 Mdot
.944 .16774 Mdot
.944 .16788 Mdot
.944 .16878 Mdot
.944 .16881 Mdot
.944 .17125 Mdot
.944 .17141 Mdot
.944 .17169 Mdot
.944 .1722 Mdot
.944 .17303 Mdot
.944 .17555 Mdot
.944 .17555 Mdot
.944 .17592 Mdot
.944 .17738 Mdot
.944 .17771 Mdot
.944 .17838 Mdot
.944 .17927 Mdot
.944 .17976 Mdot
.944 .18017 Mdot
.944 .18026 Mdot
.944 .18034 Mdot
.944 .1811 Mdot
.944 .18127 Mdot
.944 .18229 Mdot
.944 .18387 Mdot
.944 .18394 Mdot
.944 .18458 Mdot
.944 .18635 Mdot
.944 .187 Mdot
.944 .18785 Mdot
.944 .18826 Mdot
.944 .18905 Mdot
.944 .18942 Mdot
.944 .19004 Mdot
.944 .19018 Mdot
.944 .19022 Mdot
.944 .19116 Mdot
.944 .19151 Mdot
.944 .19154 Mdot
.944 .19249 Mdot
.944 .19365 Mdot
.944 .19385 Mdot
.944 .19508 Mdot
.944 .19557 Mdot
.944 .19585 Mdot
.944 .19641 Mdot
.944 .19645 Mdot
.944 .19708 Mdot
.944 .19712 Mdot
.944 .19749 Mdot
.944 .19791 Mdot
.944 .19911 Mdot
.944 .20374 Mdot
.944 .20443 Mdot
.944 .20472 Mdot
.944 .20567 Mdot
.944 .20615 Mdot
.944 .20654 Mdot
.944 .20697 Mdot
.944 .20757 Mdot
.944 .20812 Mdot
.944 .20855 Mdot
.944 .20888 Mdot
.944 .20908 Mdot
.944 .2093 Mdot
.944 .21088 Mdot
.944 .21196 Mdot
.944 .21226 Mdot
.944 .2124 Mdot
.944 .21713 Mdot
.944 .21741 Mdot
.944 .21792 Mdot
.944 .21961 Mdot
.944 .2214 Mdot
.944 .22206 Mdot
.944 .22442 Mdot
.944 .22572 Mdot
.944 .22825 Mdot
.944 .22881 Mdot
.944 .22992 Mdot
.944 .23111 Mdot
.944 .2313 Mdot
.944 .23322 Mdot
.944 .23336 Mdot
.944 .23446 Mdot
.944 .23446 Mdot
.944 .23521 Mdot
.944 .23561 Mdot
.944 .23574 Mdot
.944 .23686 Mdot
.944 .23687 Mdot
.944 .23718 Mdot
.944 .23825 Mdot
.944 .23888 Mdot
.944 .23894 Mdot
.944 .23905 Mdot
.944 .24204 Mdot
.944 .24396 Mdot
.944 .24438 Mdot
.944 .24447 Mdot
.944 .24625 Mdot
.944 .24914 Mdot
.944 .24929 Mdot
.944 .25003 Mdot
.944 .25086 Mdot
.944 .25189 Mdot
.944 .25466 Mdot
.944 .25565 Mdot
.944 .25628 Mdot
.944 .25659 Mdot
.944 .25715 Mdot
.944 .2583 Mdot
.944 .25918 Mdot
.944 .25918 Mdot
.944 .2594 Mdot
.944 .26016 Mdot
.944 .26067 Mdot
.944 .26095 Mdot
.944 .26216 Mdot
.944 .26221 Mdot
.944 .26244 Mdot
.944 .26258 Mdot
.944 .26413 Mdot
.944 .26416 Mdot
.944 .2656 Mdot
.944 .26598 Mdot
.944 .26725 Mdot
.944 .26859 Mdot
.944 .26885 Mdot
.944 .26965 Mdot
.944 .26972 Mdot
.944 .27054 Mdot
.944 .27152 Mdot
.944 .27184 Mdot
.944 .27208 Mdot
.944 .27356 Mdot
.944 .27574 Mdot
.944 .27578 Mdot
.944 .27617 Mdot
.944 .27817 Mdot
.944 .27867 Mdot
.944 .27894 Mdot
.944 .27914 Mdot
.944 .27987 Mdot
.944 .28147 Mdot
.944 .282 Mdot
.944 .28339 Mdot
.944 .28398 Mdot
.944 .28423 Mdot
.944 .28538 Mdot
.944 .2867 Mdot
.944 .28723 Mdot
.944 .28783 Mdot
.944 .28837 Mdot
.944 .28927 Mdot
.944 .28957 Mdot
.944 .29018 Mdot
.944 .2912 Mdot
.944 .29169 Mdot
.944 .29205 Mdot
.944 .29225 Mdot
.944 .29613 Mdot
.944 .29655 Mdot
.944 .29809 Mdot
.944 .30006 Mdot
.944 .30056 Mdot
.944 .30195 Mdot
.944 .30313 Mdot
.944 .30525 Mdot
.944 .30538 Mdot
.944 .30701 Mdot
.944 .30969 Mdot
.944 .31007 Mdot
.944 .31047 Mdot
.944 .31194 Mdot
.944 .31197 Mdot
.944 .31411 Mdot
.944 .31499 Mdot
.944 .31652 Mdot
.944 .31668 Mdot
.944 .31672 Mdot
.944 .31788 Mdot
.944 .31826 Mdot
.944 .31842 Mdot
.944 .32022 Mdot
.944 .32048 Mdot
.944 .321 Mdot
.944 .32118 Mdot
.944 .32349 Mdot
.944 .32413 Mdot
.944 .32464 Mdot
.944 .32503 Mdot
.944 .32575 Mdot
.944 .32666 Mdot
.944 .32955 Mdot
.944 .32962 Mdot
.944 .33169 Mdot
.944 .33174 Mdot
.944 .3321 Mdot
.944 .33238 Mdot
.944 .33254 Mdot
.944 .33405 Mdot
.944 .33596 Mdot
.944 .3366 Mdot
.944 .33676 Mdot
.944 .33701 Mdot
.944 .33736 Mdot
.944 .33749 Mdot
.944 .33848 Mdot
.944 .3386 Mdot
.944 .33864 Mdot
.944 .33975 Mdot
.944 .34 Mdot
.944 .34126 Mdot
.944 .34139 Mdot
.944 .34162 Mdot
.944 .34278 Mdot
.944 .34284 Mdot
.944 .34286 Mdot
.944 .34376 Mdot
.944 .345 Mdot
.944 .34523 Mdot
.944 .34672 Mdot
.944 .34672 Mdot
.944 .34692 Mdot
.944 .34747 Mdot
.944 .3484 Mdot
.944 .34869 Mdot
.944 .34916 Mdot
.944 .35005 Mdot
.944 .35021 Mdot
.944 .35078 Mdot
.944 .35081 Mdot
.944 .35093 Mdot
.944 .35156 Mdot
.944 .35157 Mdot
.944 .35281 Mdot
.944 .35383 Mdot
.944 .35434 Mdot
.944 .35486 Mdot
.944 .3555 Mdot
.944 .3559 Mdot
.944 .35655 Mdot
.944 .35716 Mdot
.944 .35786 Mdot
.944 .35812 Mdot
.944 .36007 Mdot
.944 .36181 Mdot
.944 .3621 Mdot
.944 .36275 Mdot
.944 .36352 Mdot
.944 .36419 Mdot
.944 .36505 Mdot
.944 .36618 Mdot
.944 .36648 Mdot
.944 .3678 Mdot
.944 .36897 Mdot
.944 .36966 Mdot
.944 .37007 Mdot
.944 .37029 Mdot
.944 .37059 Mdot
.944 .37156 Mdot
.944 .37229 Mdot
.944 .37269 Mdot
.944 .37287 Mdot
.944 .37298 Mdot
.944 .37325 Mdot
.944 .37326 Mdot
.944 .37465 Mdot
.944 .37565 Mdot
.944 .37584 Mdot
.944 .37655 Mdot
.944 .37951 Mdot
.944 .37976 Mdot
.944 .38077 Mdot
.944 .38128 Mdot
.944 .38258 Mdot
.944 .38368 Mdot
.944 .38441 Mdot
.944 .38526 Mdot
.944 .38602 Mdot
.944 .38728 Mdot
.944 .38751 Mdot
.944 .38783 Mdot
.944 .38822 Mdot
.944 .38882 Mdot
.944 .38936 Mdot
.944 .38961 Mdot
.944 .3899 Mdot
.944 .39002 Mdot
.944 .39035 Mdot
.944 .39191 Mdot
.944 .39242 Mdot
.944 .3927 Mdot
.944 .39285 Mdot
.944 .39297 Mdot
.944 .39306 Mdot
.944 .3953 Mdot
.944 .39552 Mdot
.944 .39828 Mdot
.944 .39904 Mdot
.944 .39963 Mdot
.944 .40025 Mdot
.944 .40054 Mdot
.944 .40055 Mdot
.944 .40109 Mdot
.944 .40189 Mdot
.944 .40395 Mdot
.944 .40443 Mdot
.944 .40555 Mdot
.944 .40667 Mdot
.944 .40674 Mdot
.944 .40705 Mdot
.944 .40706 Mdot
.944 .40712 Mdot
.944 .40792 Mdot
.944 .40801 Mdot
.944 .40867 Mdot
.944 .4094 Mdot
.944 .41047 Mdot
.944 .41057 Mdot
.944 .41251 Mdot
.944 .41257 Mdot
.944 .41318 Mdot
.944 .41346 Mdot
.944 .41551 Mdot
.944 .41599 Mdot
.944 .41723 Mdot
.944 .41883 Mdot
.944 .41991 Mdot
.944 .42049 Mdot
.944 .42053 Mdot
.944 .42145 Mdot
.944 .42234 Mdot
.944 .42256 Mdot
.944 .42367 Mdot
.944 .42434 Mdot
.944 .42658 Mdot
.944 .42781 Mdot
.944 .4284 Mdot
.944 .4288 Mdot
.944 .42898 Mdot
.944 .42928 Mdot
.944 .43056 Mdot
.944 .43187 Mdot
.944 .43251 Mdot
.944 .43335 Mdot
.944 .43351 Mdot
.944 .43399 Mdot
.944 .43413 Mdot
.944 .43485 Mdot
.944 .43503 Mdot
.944 .43649 Mdot
.944 .43764 Mdot
.944 .4382 Mdot
.944 .4383 Mdot
.944 .439 Mdot
.944 .43902 Mdot
.944 .43905 Mdot
.944 .44101 Mdot
.944 .4425 Mdot
.944 .44307 Mdot
.944 .44384 Mdot
.944 .44407 Mdot
.944 .44541 Mdot
.944 .44582 Mdot
.944 .44606 Mdot
.944 .44835 Mdot
.944 .44868 Mdot
.944 .44906 Mdot
.944 .44944 Mdot
.944 .44948 Mdot
.944 .44986 Mdot
.944 .45049 Mdot
.944 .45101 Mdot
.944 .45174 Mdot
.944 .45231 Mdot
.944 .45319 Mdot
.944 .45329 Mdot
.944 .45346 Mdot
.944 .45654 Mdot
.944 .45686 Mdot
.944 .45705 Mdot
.944 .45875 Mdot
.944 .45974 Mdot
.944 .45986 Mdot
.944 .46024 Mdot
.944 .46124 Mdot
.944 .4622 Mdot
.944 .46221 Mdot
.944 .46223 Mdot
.944 .46261 Mdot
.944 .46289 Mdot
.944 .46344 Mdot
.944 .46414 Mdot
.944 .46423 Mdot
.944 .46457 Mdot
.944 .46464 Mdot
.944 .46494 Mdot
.944 .46565 Mdot
.944 .46627 Mdot
.944 .46919 Mdot
.944 .4695 Mdot
.944 .47001 Mdot
.944 .47052 Mdot
.944 .47095 Mdot
.944 .47096 Mdot
.944 .47173 Mdot
.944 .47246 Mdot
.944 .47416 Mdot
.944 .47459 Mdot
.944 .47598 Mdot
.944 .477 Mdot
.944 .47702 Mdot
.944 .47703 Mdot
.944 .47769 Mdot
.944 .47965 Mdot
.944 .48028 Mdot
.944 .48087 Mdot
.944 .48206 Mdot
.944 .48311 Mdot
.944 .48315 Mdot
.944 .4832 Mdot
.944 .4836 Mdot
.944 .48441 Mdot
.944 .48446 Mdot
.944 .48458 Mdot
.944 .48517 Mdot
.944 .48533 Mdot
.944 .48547 Mdot
.944 .48557 Mdot
.944 .48677 Mdot
.944 .48707 Mdot
.944 .48754 Mdot
.944 .48881 Mdot
.944 .49003 Mdot
.944 .49032 Mdot
.944 .49149 Mdot
.944 .49154 Mdot
.944 .49161 Mdot
.944 .49178 Mdot
.944 .49259 Mdot
.944 .49268 Mdot
.944 .49284 Mdot
.944 .49424 Mdot
.944 .49531 Mdot
.944 .49562 Mdot
.944 .49668 Mdot
.944 .49746 Mdot
.944 .49807 Mdot
.944 .49874 Mdot
.944 .49954 Mdot
.944 .50002 Mdot
.944 .50003 Mdot
.944 .50032 Mdot
.944 .50061 Mdot
.944 .50096 Mdot
.944 .50162 Mdot
.944 .50183 Mdot
.944 .5019 Mdot
.944 .5019 Mdot
.944 .5034 Mdot
.944 .50386 Mdot
.944 .50395 Mdot
.944 .504 Mdot
.944 .50548 Mdot
.944 .5073 Mdot
.944 .50736 Mdot
.944 .5076 Mdot
.944 .50839 Mdot
.944 .50949 Mdot
.944 .5101 Mdot
.944 .51024 Mdot
.944 .51043 Mdot
.944 .51067 Mdot
.944 .51152 Mdot
.944 .51158 Mdot
.944 .51177 Mdot
.944 .51253 Mdot
.944 .51259 Mdot
.944 .51315 Mdot
.944 .51317 Mdot
.944 .51322 Mdot
.944 .51378 Mdot
.944 .5141 Mdot
.944 .51556 Mdot
.944 .51569 Mdot
.944 .51805 Mdot
.944 .51983 Mdot
.944 .52052 Mdot
.944 .52225 Mdot
.944 .52323 Mdot
.944 .52342 Mdot
.944 .52363 Mdot
.944 .52381 Mdot
.944 .52467 Mdot
.944 .52475 Mdot
.944 .52496 Mdot
.944 .52562 Mdot
.944 .52616 Mdot
.944 .52675 Mdot
.944 .52743 Mdot
.944 .52756 Mdot
.944 .52758 Mdot
.944 .52832 Mdot
.944 .5289 Mdot
.944 .52901 Mdot
.944 .52934 Mdot
.944 .52962 Mdot
.944 .52991 Mdot
.944 .53 Mdot
.944 .53088 Mdot
.944 .531 Mdot
.944 .53201 Mdot
.944 .53206 Mdot
.944 .53213 Mdot
.944 .53215 Mdot
.944 .53255 Mdot
.944 .53265 Mdot
.944 .53343 Mdot
.944 .53382 Mdot
.944 .534 Mdot
.944 .53411 Mdot
.944 .53555 Mdot
.944 .53616 Mdot
.944 .53876 Mdot
.944 .53977 Mdot
.944 .53999 Mdot
.944 .54033 Mdot
.944 .54043 Mdot
.944 .54043 Mdot
.944 .54079 Mdot
.944 .54097 Mdot
.944 .54156 Mdot
.944 .54228 Mdot
.944 .54301 Mdot
.944 .54319 Mdot
.944 .54515 Mdot
.944 .54592 Mdot
.944 .54645 Mdot
.944 .5467 Mdot
.944 .54864 Mdot
.944 .54926 Mdot
.944 .54937 Mdot
.944 .5495 Mdot
.944 .54967 Mdot
.944 .54999 Mdot
.944 .55011 Mdot
.944 .55055 Mdot
.944 .55227 Mdot
.944 .55264 Mdot
.944 .55277 Mdot
.944 .55289 Mdot
.944 .55308 Mdot
.944 .55335 Mdot
.944 .5535 Mdot
.944 .55393 Mdot
.944 .55457 Mdot
.944 .55469 Mdot
.944 .55499 Mdot
.944 .55533 Mdot
.944 .55557 Mdot
.944 .55595 Mdot
.944 .55614 Mdot
.944 .55689 Mdot
.944 .55767 Mdot
.944 .55812 Mdot
.944 .55827 Mdot
.944 .55853 Mdot
.944 .55926 Mdot
.944 .55937 Mdot
.944 .55937 Mdot
.944 .56012 Mdot
.944 .56037 Mdot
.944 .56052 Mdot
.944 .56065 Mdot
.944 .56164 Mdot
.944 .56175 Mdot
.944 .56175 Mdot
.944 .56205 Mdot
.944 .56213 Mdot
.944 .56308 Mdot
.944 .5631 Mdot
.944 .56333 Mdot
.944 .56367 Mdot
.944 .56373 Mdot
.944 .56383 Mdot
.944 .56608 Mdot
.944 .56659 Mdot
.944 .56672 Mdot
.944 .56689 Mdot
.944 .56778 Mdot
.944 .56829 Mdot
.944 .56865 Mdot
.944 .56873 Mdot
.944 .56899 Mdot
.944 .569 Mdot
.944 .56923 Mdot
.944 .56933 Mdot
.944 .56949 Mdot
.944 .56983 Mdot
.944 .57025 Mdot
.944 .57044 Mdot
.944 .57125 Mdot
.944 .5715 Mdot
.944 .57168 Mdot
.944 .57202 Mdot
.944 .57258 Mdot
.944 .57264 Mdot
.944 .57275 Mdot
.944 .57335 Mdot
.944 .57351 Mdot
.944 .574 Mdot
.944 .57454 Mdot
.944 .57477 Mdot
.944 .5748 Mdot
.944 .57563 Mdot
.944 .57627 Mdot
.944 .57677 Mdot
.944 .57687 Mdot
.944 .57733 Mdot
.944 .57759 Mdot
.944 .57779 Mdot
.944 .57799 Mdot
.944 .57804 Mdot
.944 .57826 Mdot
.944 .57865 Mdot
.944 .57921 Mdot
.944 .57945 Mdot
.944 .58004 Mdot
.944 .58004 Mdot
.944 .58018 Mdot
.944 .58053 Mdot
.944 .58069 Mdot
.944 .5807 Mdot
.944 .58102 Mdot
.944 .58116 Mdot
.944 .5812 Mdot
.944 .58154 Mdot
.944 .58195 Mdot
.944 .58197 Mdot
.944 .58201 Mdot
.944 .58215 Mdot
.944 .58221 Mdot
.944 .58224 Mdot
.944 .5826 Mdot
.944 .58292 Mdot
.944 .58319 Mdot
.944 .58321 Mdot
.944 .58323 Mdot
.944 .58384 Mdot
.944 .58406 Mdot
.944 .58428 Mdot
.944 .58456 Mdot
.944 .58456 Mdot
.944 .58492 Mdot
.944 .58499 Mdot
.944 .58501 Mdot
.944 .58501 Mdot
.944 .58532 Mdot
.944 .58541 Mdot
.944 .58575 Mdot
.944 .58588 Mdot
.944 .5859 Mdot
.944 .58615 Mdot
.944 .58631 Mdot
.944 .58631 Mdot
.944 .58635 Mdot
.944 .58678 Mdot
.944 .58679 Mdot
.944 .58707 Mdot
.944 .58717 Mdot
.944 .58717 Mdot
.944 .58728 Mdot
.944 .58744 Mdot
.944 .58756 Mdot
.944 .58792 Mdot
.944 .58803 Mdot
.944 .58828 Mdot
.944 .58861 Mdot
.944 .58903 Mdot
.944 .58904 Mdot
.944 .58907 Mdot
.944 .58928 Mdot
.944 .5893 Mdot
.944 .58948 Mdot
.944 .58958 Mdot
.944 .58968 Mdot
.944 .58974 Mdot
.944 .59028 Mdot
.944 .59033 Mdot
.944 .59038 Mdot
.944 .59054 Mdot
.944 .59065 Mdot
.944 .59073 Mdot
.944 .59083 Mdot
.944 .59085 Mdot
.944 .5909 Mdot
.944 .59102 Mdot
.944 .59128 Mdot
.944 .59133 Mdot
.944 .59146 Mdot
.944 .59156 Mdot
.944 .59161 Mdot
.944 .59162 Mdot
.944 .59163 Mdot
.944 .59182 Mdot
.944 .59185 Mdot
.944 .59231 Mdot
.944 .59251 Mdot
.944 .59252 Mdot
.944 .5926 Mdot
.944 .59297 Mdot
.944 .59301 Mdot
.944 .59306 Mdot
.944 .59315 Mdot
.944 .59326 Mdot
.944 .59327 Mdot
.944 .59338 Mdot
.944 .59354 Mdot
.944 .59371 Mdot
.944 .59386 Mdot
.944 .59387 Mdot
.944 .5939 Mdot
.944 .59411 Mdot
.944 .59419 Mdot
.944 .59434 Mdot
.944 .59459 Mdot
.944 .59463 Mdot
.944 .59471 Mdot
.944 .59479 Mdot
.944 .59484 Mdot
.944 .59485 Mdot
.944 .595 Mdot
.944 .59509 Mdot
.944 .59519 Mdot
.944 .59532 Mdot
.944 .59561 Mdot
.944 .59568 Mdot
.944 .59573 Mdot
.944 .59576 Mdot
.944 .59584 Mdot
.944 .59588 Mdot
.944 .59592 Mdot
.944 .59613 Mdot
.944 .59615 Mdot
.944 .59619 Mdot
.944 .5962 Mdot
.944 .59625 Mdot
.944 .59633 Mdot
.944 .59633 Mdot
.944 .59635 Mdot
.944 .59639 Mdot
.944 .59649 Mdot
.944 .59649 Mdot
.944 .59655 Mdot
.944 .59663 Mdot
.944 .59664 Mdot
.944 .59667 Mdot
.944 .59667 Mdot
.944 .5967 Mdot
.944 .59671 Mdot
.944 .59672 Mdot
.944 .59672 Mdot
.946 .03962 Mdot
.946 .03973 Mdot
.946 .03977 Mdot
.946 .03979 Mdot
.946 .0398 Mdot
.946 .04005 Mdot
.946 .04013 Mdot
.946 .04017 Mdot
.946 .04028 Mdot
.946 .04035 Mdot
.946 .04067 Mdot
.946 .04068 Mdot
.946 .04071 Mdot
.946 .04097 Mdot
.946 .04119 Mdot
.946 .04141 Mdot
.946 .04153 Mdot
.946 .04197 Mdot
.946 .04205 Mdot
.946 .04206 Mdot
.946 .04226 Mdot
.946 .04246 Mdot
.946 .04299 Mdot
.946 .04344 Mdot
.946 .04424 Mdot
.946 .04427 Mdot
.946 .0453 Mdot
.946 .04599 Mdot
.946 .0461 Mdot
.946 .04611 Mdot
.946 .04617 Mdot
.946 .04627 Mdot
.946 .04654 Mdot
.946 .04698 Mdot
.946 .04739 Mdot
.946 .04764 Mdot
.946 .04783 Mdot
.946 .04803 Mdot
.946 .04818 Mdot
.946 .04827 Mdot
.946 .04853 Mdot
.946 .04925 Mdot
.946 .05016 Mdot
.946 .05028 Mdot
.946 .05046 Mdot
.946 .05073 Mdot
.946 .05093 Mdot
.946 .05097 Mdot
.946 .05112 Mdot
.946 .05141 Mdot
.946 .05141 Mdot
.946 .05255 Mdot
.946 .0527 Mdot
.946 .05323 Mdot
.946 .05362 Mdot
.946 .05365 Mdot
.946 .05381 Mdot
.946 .05389 Mdot
.946 .05466 Mdot
.946 .05468 Mdot
.946 .05521 Mdot
.946 .05527 Mdot
.946 .05655 Mdot
.946 .0566 Mdot
.946 .05678 Mdot
.946 .05714 Mdot
.946 .05735 Mdot
.946 .05744 Mdot
.946 .05747 Mdot
.946 .05814 Mdot
.946 .05876 Mdot
.946 .05997 Mdot
.946 .06043 Mdot
.946 .06117 Mdot
.946 .06146 Mdot
.946 .06167 Mdot
.946 .06177 Mdot
.946 .06189 Mdot
.946 .06245 Mdot
.946 .06345 Mdot
.946 .06429 Mdot
.946 .06462 Mdot
.946 .0654 Mdot
.946 .06599 Mdot
.946 .0661 Mdot
.946 .06614 Mdot
.946 .06627 Mdot
.946 .0669 Mdot
.946 .06697 Mdot
.946 .06716 Mdot
.946 .06833 Mdot
.946 .06869 Mdot
.946 .06947 Mdot
.946 .06983 Mdot
.946 .07025 Mdot
.946 .07141 Mdot
.946 .07163 Mdot
.946 .07263 Mdot
.946 .07303 Mdot
.946 .07334 Mdot
.946 .07336 Mdot
.946 .07339 Mdot
.946 .074 Mdot
.946 .07529 Mdot
.946 .07533 Mdot
.946 .07548 Mdot
.946 .07719 Mdot
.946 .07733 Mdot
.946 .07928 Mdot
.946 .07938 Mdot
.946 .08018 Mdot
.946 .08173 Mdot
.946 .0827 Mdot
.946 .08335 Mdot
.946 .08366 Mdot
.946 .08386 Mdot
.946 .08516 Mdot
.946 .08521 Mdot
.946 .08541 Mdot
.946 .08777 Mdot
.946 .08834 Mdot
.946 .08903 Mdot
.946 .08904 Mdot
.946 .0894 Mdot
.946 .09179 Mdot
.946 .0928 Mdot
.946 .0934 Mdot
.946 .09548 Mdot
.946 .09607 Mdot
.946 .09729 Mdot
.946 .09831 Mdot
.946 .09844 Mdot
.946 .09858 Mdot
.946 .09976 Mdot
.946 .10013 Mdot
.946 .10299 Mdot
.946 .10489 Mdot
.946 .10517 Mdot
.946 .10552 Mdot
.946 .10848 Mdot
.946 .10911 Mdot
.946 .10948 Mdot
.946 .10964 Mdot
.946 .10971 Mdot
.946 .10973 Mdot
.946 .10988 Mdot
.946 .10988 Mdot
.946 .11066 Mdot
.946 .11068 Mdot
.946 .11093 Mdot
.946 .1111 Mdot
.946 .11147 Mdot
.946 .11149 Mdot
.946 .11173 Mdot
.946 .11288 Mdot
.946 .11291 Mdot
.946 .11305 Mdot
.946 .1133 Mdot
.946 .11393 Mdot
.946 .11394 Mdot
.946 .11397 Mdot
.946 .11413 Mdot
.946 .1147 Mdot
.946 .11478 Mdot
.946 .11538 Mdot
.946 .11547 Mdot
.946 .11554 Mdot
.946 .11554 Mdot
.946 .11598 Mdot
.946 .11635 Mdot
.946 .11757 Mdot
.946 .11785 Mdot
.946 .1179 Mdot
.946 .11833 Mdot
.946 .11855 Mdot
.946 .11862 Mdot
.946 .11922 Mdot
.946 .11932 Mdot
.946 .11972 Mdot
.946 .11998 Mdot
.946 .12122 Mdot
.946 .12126 Mdot
.946 .12284 Mdot
.946 .12429 Mdot
.946 .12522 Mdot
.946 .12569 Mdot
.946 .12579 Mdot
.946 .12669 Mdot
.946 .12715 Mdot
.946 .12742 Mdot
.946 .12757 Mdot
.946 .12944 Mdot
.946 .13183 Mdot
.946 .13188 Mdot
.946 .13228 Mdot
.946 .13232 Mdot
.946 .13253 Mdot
.946 .1329 Mdot
.946 .13383 Mdot
.946 .13517 Mdot
.946 .1354 Mdot
.946 .13589 Mdot
.946 .13683 Mdot
.946 .13771 Mdot
.946 .138 Mdot
.946 .13838 Mdot
.946 .13909 Mdot
.946 .13961 Mdot
.946 .13991 Mdot
.946 .14063 Mdot
.946 .14084 Mdot
.946 .1413 Mdot
.946 .14257 Mdot
.946 .14334 Mdot
.946 .14371 Mdot
.946 .14595 Mdot
.946 .14652 Mdot
.946 .14694 Mdot
.946 .14748 Mdot
.946 .14756 Mdot
.946 .14803 Mdot
.946 .14849 Mdot
.946 .1489 Mdot
.946 .14914 Mdot
.946 .1492 Mdot
.946 .14935 Mdot
.946 .14979 Mdot
.946 .14985 Mdot
.946 .15085 Mdot
.946 .15088 Mdot
.946 .15148 Mdot
.946 .15243 Mdot
.946 .15481 Mdot
.946 .15531 Mdot
.946 .15716 Mdot
.946 .15849 Mdot
.946 .1586 Mdot
.946 .15914 Mdot
.946 .15942 Mdot
.946 .15995 Mdot
.946 .16009 Mdot
.946 .16205 Mdot
.946 .16213 Mdot
.946 .16319 Mdot
.946 .16359 Mdot
.946 .16393 Mdot
.946 .16412 Mdot
.946 .1649 Mdot
.946 .16832 Mdot
.946 .16849 Mdot
.946 .16864 Mdot
.946 .16928 Mdot
.946 .1693 Mdot
.946 .17012 Mdot
.946 .17049 Mdot
.946 .17082 Mdot
.946 .17117 Mdot
.946 .17119 Mdot
.946 .17149 Mdot
.946 .17161 Mdot
.946 .17162 Mdot
.946 .17386 Mdot
.946 .17596 Mdot
.946 .17714 Mdot
.946 .17914 Mdot
.946 .1796 Mdot
.946 .18 Mdot
.946 .18157 Mdot
.946 .18289 Mdot
.946 .18328 Mdot
.946 .18404 Mdot
.946 .18498 Mdot
.946 .18569 Mdot
.946 .18604 Mdot
.946 .18641 Mdot
.946 .18661 Mdot
.946 .1869 Mdot
.946 .18829 Mdot
.946 .18867 Mdot
.946 .18902 Mdot
.946 .19073 Mdot
.946 .19116 Mdot
.946 .19159 Mdot
.946 .19171 Mdot
.946 .19225 Mdot
.946 .19383 Mdot
.946 .19436 Mdot
.946 .19545 Mdot
.946 .19801 Mdot
.946 .19816 Mdot
.946 .19952 Mdot
.946 .19993 Mdot
.946 .20028 Mdot
.946 .20041 Mdot
.946 .20083 Mdot
.946 .20288 Mdot
.946 .20313 Mdot
.946 .20374 Mdot
.946 .20497 Mdot
.946 .20566 Mdot
.946 .20624 Mdot
.946 .20688 Mdot
.946 .20754 Mdot
.946 .20871 Mdot
.946 .21094 Mdot
.946 .21121 Mdot
.946 .21237 Mdot
.946 .21276 Mdot
.946 .21291 Mdot
.946 .21318 Mdot
.946 .21334 Mdot
.946 .21374 Mdot
.946 .21705 Mdot
.946 .21719 Mdot
.946 .21746 Mdot
.946 .21814 Mdot
.946 .22032 Mdot
.946 .22134 Mdot
.946 .22171 Mdot
.946 .22259 Mdot
.946 .22359 Mdot
.946 .22363 Mdot
.946 .22374 Mdot
.946 .22535 Mdot
.946 .22553 Mdot
.946 .22569 Mdot
.946 .22974 Mdot
.946 .22986 Mdot
.946 .23035 Mdot
.946 .23307 Mdot
.946 .23379 Mdot
.946 .23543 Mdot
.946 .23556 Mdot
.946 .23567 Mdot
.946 .23612 Mdot
.946 .23642 Mdot
.946 .23745 Mdot
.946 .23798 Mdot
.946 .23893 Mdot
.946 .24218 Mdot
.946 .24246 Mdot
.946 .24495 Mdot
.946 .24517 Mdot
.946 .24969 Mdot
.946 .24979 Mdot
.946 .25081 Mdot
.946 .2519 Mdot
.946 .25237 Mdot
.946 .25246 Mdot
.946 .25265 Mdot
.946 .25298 Mdot
.946 .25402 Mdot
.946 .25404 Mdot
.946 .25462 Mdot
.946 .25462 Mdot
.946 .25556 Mdot
.946 .25618 Mdot
.946 .25618 Mdot
.946 .25892 Mdot
.946 .2601 Mdot
.946 .26025 Mdot
.946 .26075 Mdot
.946 .26081 Mdot
.946 .26086 Mdot
.946 .26181 Mdot
.946 .26492 Mdot
.946 .26791 Mdot
.946 .26961 Mdot
.946 .27068 Mdot
.946 .27165 Mdot
.946 .27168 Mdot
.946 .27273 Mdot
.946 .27536 Mdot
.946 .27627 Mdot
.946 .27804 Mdot
.946 .27974 Mdot
.946 .28058 Mdot
.946 .28176 Mdot
.946 .2827 Mdot
.946 .28295 Mdot
.946 .28322 Mdot
.946 .28443 Mdot
.946 .28573 Mdot
.946 .28651 Mdot
.946 .28792 Mdot
.946 .29045 Mdot
.946 .29073 Mdot
.946 .29168 Mdot
.946 .29214 Mdot
.946 .29317 Mdot
.946 .2942 Mdot
.946 .2956 Mdot
.946 .29564 Mdot
.946 .29852 Mdot
.946 .29889 Mdot
.946 .29927 Mdot
.946 .2993 Mdot
.946 .30175 Mdot
.946 .30257 Mdot
.946 .3026 Mdot
.946 .30364 Mdot
.946 .3043 Mdot
.946 .30482 Mdot
.946 .30627 Mdot
.946 .30675 Mdot
.946 .30796 Mdot
.946 .31162 Mdot
.946 .31179 Mdot
.946 .31354 Mdot
.946 .31415 Mdot
.946 .31558 Mdot
.946 .31686 Mdot
.946 .31736 Mdot
.946 .31764 Mdot
.946 .31858 Mdot
.946 .32044 Mdot
.946 .32119 Mdot
.946 .32471 Mdot
.946 .32485 Mdot
.946 .32506 Mdot
.946 .32538 Mdot
.946 .32663 Mdot
.946 .32684 Mdot
.946 .32706 Mdot
.946 .32721 Mdot
.946 .32832 Mdot
.946 .32921 Mdot
.946 .32933 Mdot
.946 .3295 Mdot
.946 .32975 Mdot
.946 .32994 Mdot
.946 .32998 Mdot
.946 .33038 Mdot
.946 .33039 Mdot
.946 .3314 Mdot
.946 .33198 Mdot
.946 .33233 Mdot
.946 .33246 Mdot
.946 .33253 Mdot
.946 .33316 Mdot
.946 .33318 Mdot
.946 .33364 Mdot
.946 .33464 Mdot
.946 .33467 Mdot
.946 .33524 Mdot
.946 .33531 Mdot
.946 .33582 Mdot
.946 .33712 Mdot
.946 .33795 Mdot
.946 .33814 Mdot
.946 .33836 Mdot
.946 .33843 Mdot
.946 .33881 Mdot
.946 .33946 Mdot
.946 .34021 Mdot
.946 .34069 Mdot
.946 .34106 Mdot
.946 .34112 Mdot
.946 .34115 Mdot
.946 .34123 Mdot
.946 .34161 Mdot
.946 .34165 Mdot
.946 .34247 Mdot
.946 .34313 Mdot
.946 .34334 Mdot
.946 .34358 Mdot
.946 .34424 Mdot
.946 .34436 Mdot
.946 .34492 Mdot
.946 .34513 Mdot
.946 .34531 Mdot
.946 .34533 Mdot
.946 .34567 Mdot
.946 .34646 Mdot
.946 .34743 Mdot
.946 .34847 Mdot
.946 .34888 Mdot
.946 .34965 Mdot
.946 .35044 Mdot
.946 .35059 Mdot
.946 .35068 Mdot
.946 .3513 Mdot
.946 .35133 Mdot
.946 .35142 Mdot
.946 .35253 Mdot
.946 .35279 Mdot
.946 .35311 Mdot
.946 .35327 Mdot
.946 .35435 Mdot
.946 .3548 Mdot
.946 .35506 Mdot
.946 .35597 Mdot
.946 .35607 Mdot
.946 .35674 Mdot
.946 .35988 Mdot
.946 .35999 Mdot
.946 .36013 Mdot
.946 .36131 Mdot
.946 .36216 Mdot
.946 .36317 Mdot
.946 .36349 Mdot
.946 .3637 Mdot
.946 .36396 Mdot
.946 .36432 Mdot
.946 .36514 Mdot
.946 .36756 Mdot
.946 .36808 Mdot
.946 .36839 Mdot
.946 .36988 Mdot
.946 .37102 Mdot
.946 .37127 Mdot
.946 .37198 Mdot
.946 .3735 Mdot
.946 .37388 Mdot
.946 .37461 Mdot
.946 .37511 Mdot
.946 .37529 Mdot
.946 .37564 Mdot
.946 .37639 Mdot
.946 .3767 Mdot
.946 .37906 Mdot
.946 .38018 Mdot
.946 .38216 Mdot
.946 .38483 Mdot
.946 .38592 Mdot
.946 .38603 Mdot
.946 .387 Mdot
.946 .38708 Mdot
.946 .38759 Mdot
.946 .38845 Mdot
.946 .3886 Mdot
.946 .38905 Mdot
.946 .39027 Mdot
.946 .39065 Mdot
.946 .39216 Mdot
.946 .39379 Mdot
.946 .39433 Mdot
.946 .39548 Mdot
.946 .39767 Mdot
.946 .3997 Mdot
.946 .40032 Mdot
.946 .40035 Mdot
.946 .40123 Mdot
.946 .40285 Mdot
.946 .40403 Mdot
.946 .40457 Mdot
.946 .40472 Mdot
.946 .40511 Mdot
.946 .40636 Mdot
.946 .40684 Mdot
.946 .40788 Mdot
.946 .41072 Mdot
.946 .41208 Mdot
.946 .41244 Mdot
.946 .41326 Mdot
.946 .4136 Mdot
.946 .41453 Mdot
.946 .4155 Mdot
.946 .4164 Mdot
.946 .417 Mdot
.946 .41822 Mdot
.946 .41945 Mdot
.946 .42037 Mdot
.946 .4208 Mdot
.946 .42155 Mdot
.946 .42173 Mdot
.946 .42262 Mdot
.946 .42267 Mdot
.946 .42274 Mdot
.946 .4231 Mdot
.946 .42315 Mdot
.946 .42319 Mdot
.946 .42374 Mdot
.946 .42434 Mdot
.946 .42443 Mdot
.946 .42463 Mdot
.946 .42513 Mdot
.946 .42527 Mdot
.946 .42558 Mdot
.946 .42583 Mdot
.946 .42653 Mdot
.946 .42667 Mdot
.946 .42714 Mdot
.946 .42733 Mdot
.946 .42764 Mdot
.946 .42832 Mdot
.946 .42842 Mdot
.946 .4286 Mdot
.946 .4288 Mdot
.946 .42885 Mdot
.946 .43013 Mdot
.946 .43187 Mdot
.946 .43194 Mdot
.946 .43215 Mdot
.946 .43313 Mdot
.946 .43446 Mdot
.946 .43507 Mdot
.946 .43571 Mdot
.946 .43711 Mdot
.946 .43814 Mdot
.946 .44194 Mdot
.946 .44379 Mdot
.946 .4444 Mdot
.946 .44464 Mdot
.946 .44486 Mdot
.946 .44501 Mdot
.946 .44596 Mdot
.946 .44653 Mdot
.946 .44656 Mdot
.946 .44759 Mdot
.946 .44767 Mdot
.946 .44784 Mdot
.946 .44787 Mdot
.946 .44906 Mdot
.946 .45177 Mdot
.946 .45193 Mdot
.946 .45209 Mdot
.946 .45248 Mdot
.946 .45277 Mdot
.946 .45282 Mdot
.946 .45402 Mdot
.946 .45409 Mdot
.946 .4548 Mdot
.946 .45545 Mdot
.946 .45547 Mdot
.946 .45562 Mdot
.946 .45582 Mdot
.946 .45735 Mdot
.946 .45795 Mdot
.946 .45804 Mdot
.946 .4586 Mdot
.946 .45936 Mdot
.946 .45967 Mdot
.946 .45996 Mdot
.946 .4639 Mdot
.946 .4642 Mdot
.946 .4645 Mdot
.946 .46513 Mdot
.946 .46569 Mdot
.946 .46573 Mdot
.946 .46727 Mdot
.946 .46736 Mdot
.946 .4674 Mdot
.946 .46772 Mdot
.946 .46787 Mdot
.946 .46796 Mdot
.946 .46857 Mdot
.946 .46922 Mdot
.946 .46926 Mdot
.946 .4698 Mdot
.946 .46981 Mdot
.946 .46984 Mdot
.946 .47004 Mdot
.946 .47006 Mdot
.946 .4709 Mdot
.946 .47263 Mdot
.946 .47291 Mdot
.946 .47331 Mdot
.946 .47375 Mdot
.946 .47417 Mdot
.946 .47486 Mdot
.946 .47795 Mdot
.946 .47819 Mdot
.946 .48005 Mdot
.946 .48356 Mdot
.946 .48437 Mdot
.946 .48488 Mdot
.946 .48507 Mdot
.946 .48666 Mdot
.946 .48777 Mdot
.946 .48906 Mdot
.946 .49003 Mdot
.946 .49016 Mdot
.946 .49068 Mdot
.946 .49119 Mdot
.946 .49196 Mdot
.946 .49341 Mdot
.946 .49354 Mdot
.946 .49472 Mdot
.946 .49505 Mdot
.946 .4953 Mdot
.946 .49538 Mdot
.946 .49551 Mdot
.946 .49591 Mdot
.946 .49625 Mdot
.946 .49671 Mdot
.946 .49836 Mdot
.946 .49899 Mdot
.946 .4996 Mdot
.946 .50017 Mdot
.946 .50042 Mdot
.946 .50052 Mdot
.946 .50082 Mdot
.946 .50112 Mdot
.946 .50128 Mdot
.946 .50236 Mdot
.946 .50286 Mdot
.946 .50291 Mdot
.946 .50316 Mdot
.946 .50359 Mdot
.946 .50392 Mdot
.946 .50413 Mdot
.946 .50427 Mdot
.946 .50445 Mdot
.946 .50523 Mdot
.946 .50531 Mdot
.946 .50562 Mdot
.946 .50611 Mdot
.946 .50633 Mdot
.946 .50711 Mdot
.946 .50742 Mdot
.946 .50756 Mdot
.946 .50778 Mdot
.946 .50848 Mdot
.946 .50859 Mdot
.946 .50933 Mdot
.946 .50939 Mdot
.946 .50947 Mdot
.946 .51002 Mdot
.946 .51013 Mdot
.946 .51021 Mdot
.946 .51026 Mdot
.946 .51156 Mdot
.946 .51183 Mdot
.946 .51296 Mdot
.946 .51361 Mdot
.946 .51413 Mdot
.946 .51435 Mdot
.946 .51498 Mdot
.946 .51636 Mdot
.946 .51679 Mdot
.946 .51697 Mdot
.946 .51748 Mdot
.946 .51767 Mdot
.946 .51828 Mdot
.946 .51858 Mdot
.946 .51944 Mdot
.946 .52073 Mdot
.946 .52124 Mdot
.946 .5216 Mdot
.946 .52212 Mdot
.946 .52245 Mdot
.946 .52343 Mdot
.946 .52392 Mdot
.946 .52419 Mdot
.946 .52505 Mdot
.946 .52515 Mdot
.946 .52555 Mdot
.946 .52596 Mdot
.946 .52683 Mdot
.946 .52743 Mdot
.946 .52774 Mdot
.946 .52933 Mdot
.946 .53126 Mdot
.946 .5323 Mdot
.946 .53264 Mdot
.946 .53266 Mdot
.946 .53326 Mdot
.946 .53417 Mdot
.946 .53468 Mdot
.946 .53487 Mdot
.946 .53488 Mdot
.946 .53523 Mdot
.946 .53539 Mdot
.946 .53543 Mdot
.946 .53558 Mdot
.946 .53594 Mdot
.946 .53627 Mdot
.946 .53778 Mdot
.946 .5398 Mdot
.946 .54011 Mdot
.946 .54027 Mdot
.946 .54061 Mdot
.946 .54088 Mdot
.946 .54092 Mdot
.946 .54145 Mdot
.946 .54168 Mdot
.946 .54408 Mdot
.946 .54413 Mdot
.946 .54528 Mdot
.946 .54572 Mdot
.946 .5467 Mdot
.946 .54675 Mdot
.946 .5479 Mdot
.946 .54795 Mdot
.946 .54804 Mdot
.946 .54808 Mdot
.946 .54865 Mdot
.946 .54991 Mdot
.946 .5501 Mdot
.946 .55028 Mdot
.946 .5505 Mdot
.946 .55217 Mdot
.946 .55258 Mdot
.946 .5539 Mdot
.946 .55438 Mdot
.946 .55455 Mdot
.946 .55471 Mdot
.946 .55484 Mdot
.946 .55536 Mdot
.946 .55546 Mdot
.946 .556 Mdot
.946 .55608 Mdot
.946 .55709 Mdot
.946 .5572 Mdot
.946 .55819 Mdot
.946 .55833 Mdot
.946 .55892 Mdot
.946 .56056 Mdot
.946 .56069 Mdot
.946 .5608 Mdot
.946 .561 Mdot
.946 .56124 Mdot
.946 .56153 Mdot
.946 .56254 Mdot
.946 .56292 Mdot
.946 .56304 Mdot
.946 .56394 Mdot
.946 .56398 Mdot
.946 .56617 Mdot
.946 .56644 Mdot
.946 .56693 Mdot
.946 .56712 Mdot
.946 .56719 Mdot
.946 .56744 Mdot
.946 .5676 Mdot
.946 .56804 Mdot
.946 .56868 Mdot
.946 .56901 Mdot
.946 .56937 Mdot
.946 .56956 Mdot
.946 .57031 Mdot
.946 .57091 Mdot
.946 .57111 Mdot
.946 .57206 Mdot
.946 .57326 Mdot
.946 .5733 Mdot
.946 .57338 Mdot
.946 .57351 Mdot
.946 .57392 Mdot
.946 .57419 Mdot
.946 .57503 Mdot
.946 .57539 Mdot
.946 .57546 Mdot
.946 .5756 Mdot
.946 .57579 Mdot
.946 .57585 Mdot
.946 .5764 Mdot
.946 .57663 Mdot
.946 .57665 Mdot
.946 .57667 Mdot
.946 .57686 Mdot
.946 .57702 Mdot
.946 .57707 Mdot
.946 .57707 Mdot
.946 .57725 Mdot
.946 .57775 Mdot
.946 .57797 Mdot
.946 .5782 Mdot
.946 .5782 Mdot
.946 .57858 Mdot
.946 .5794 Mdot
.946 .57949 Mdot
.946 .57957 Mdot
.946 .58009 Mdot
.946 .58088 Mdot
.946 .58098 Mdot
.946 .5813 Mdot
.946 .58134 Mdot
.946 .58137 Mdot
.946 .58165 Mdot
.946 .58198 Mdot
.946 .58208 Mdot
.946 .58214 Mdot
.946 .58271 Mdot
.946 .58287 Mdot
.946 .58315 Mdot
.946 .5838 Mdot
.946 .58389 Mdot
.946 .5839 Mdot
.946 .58408 Mdot
.946 .58424 Mdot
.946 .58487 Mdot
.946 .58493 Mdot
.946 .58494 Mdot
.946 .58529 Mdot
.946 .58535 Mdot
.946 .58543 Mdot
.946 .5856 Mdot
.946 .58586 Mdot
.946 .58628 Mdot
.946 .5865 Mdot
.946 .58652 Mdot
.946 .58704 Mdot
.946 .58708 Mdot
.946 .58754 Mdot
.946 .58758 Mdot
.946 .58759 Mdot
.946 .58793 Mdot
.946 .5881 Mdot
.946 .58811 Mdot
.946 .58811 Mdot
.946 .58819 Mdot
.946 .5883 Mdot
.946 .58857 Mdot
.946 .58862 Mdot
.946 .58893 Mdot
.946 .58904 Mdot
.946 .58914 Mdot
.946 .58935 Mdot
.946 .58944 Mdot
.946 .58975 Mdot
.946 .5898 Mdot
.946 .58982 Mdot
.946 .58999 Mdot
.946 .59002 Mdot
.946 .59003 Mdot
.946 .59006 Mdot
.946 .59022 Mdot
.946 .59042 Mdot
.946 .59051 Mdot
.946 .59073 Mdot
.946 .591 Mdot
.946 .59115 Mdot
.946 .59118 Mdot
.946 .5912 Mdot
.946 .59126 Mdot
.946 .59133 Mdot
.946 .59153 Mdot
.946 .59165 Mdot
.946 .59197 Mdot
.946 .59213 Mdot
.946 .59231 Mdot
.946 .59232 Mdot
.946 .59234 Mdot
.946 .59239 Mdot
.946 .59249 Mdot
.946 .59254 Mdot
.946 .59255 Mdot
.946 .59289 Mdot
.946 .5929 Mdot
.946 .59304 Mdot
.946 .59304 Mdot
.946 .59324 Mdot
.946 .59327 Mdot
.946 .59331 Mdot
.946 .59332 Mdot
.946 .59342 Mdot
.946 .59356 Mdot
.946 .5936 Mdot
.946 .59389 Mdot
.946 .59389 Mdot
.946 .59397 Mdot
.946 .59401 Mdot
.946 .59402 Mdot
.946 .59407 Mdot
.946 .59414 Mdot
.946 .59419 Mdot
.946 .59422 Mdot
.946 .59446 Mdot
.946 .59464 Mdot
.946 .59471 Mdot
.946 .59474 Mdot
.946 .59477 Mdot
.946 .59483 Mdot
.946 .59488 Mdot
.946 .59494 Mdot
.946 .59505 Mdot
.946 .59516 Mdot
.946 .59523 Mdot
.946 .59526 Mdot
.946 .59527 Mdot
.946 .59528 Mdot
.946 .59531 Mdot
.946 .59549 Mdot
.946 .59575 Mdot
.946 .59576 Mdot
.946 .59597 Mdot
.946 .59608 Mdot
.946 .59622 Mdot
.946 .59627 Mdot
.946 .59632 Mdot
.946 .59633 Mdot
.946 .59635 Mdot
.946 .59646 Mdot
.946 .59649 Mdot
.946 .59655 Mdot
.946 .59661 Mdot
.946 .59667 Mdot
.946 .59668 Mdot
.946 .59669 Mdot
.946 .59677 Mdot
.946 .59678 Mdot
.946 .59681 Mdot
.946 .59683 Mdot
.946 .59684 Mdot
.946 .59691 Mdot
.946 .59691 Mdot
.946 .59692 Mdot
.946 .59693 Mdot
.946 .59695 Mdot
.948 .0387 Mdot
.948 .03871 Mdot
.948 .03873 Mdot
.948 .03882 Mdot
.948 .03883 Mdot
.948 .03883 Mdot
.948 .03907 Mdot
.948 .03917 Mdot
.948 .03923 Mdot
.948 .03929 Mdot
.948 .03963 Mdot
.948 .03968 Mdot
.948 .03977 Mdot
.948 .04019 Mdot
.948 .04021 Mdot
.948 .04031 Mdot
.948 .04034 Mdot
.948 .0405 Mdot
.948 .0407 Mdot
.948 .04092 Mdot
.948 .04117 Mdot
.948 .0415 Mdot
.948 .04153 Mdot
.948 .04157 Mdot
.948 .04169 Mdot
.948 .04222 Mdot
.948 .04227 Mdot
.948 .04229 Mdot
.948 .04318 Mdot
.948 .04387 Mdot
.948 .04438 Mdot
.948 .04455 Mdot
.948 .04459 Mdot
.948 .04463 Mdot
.948 .04469 Mdot
.948 .04485 Mdot
.948 .04509 Mdot
.948 .04554 Mdot
.948 .0461 Mdot
.948 .04643 Mdot
.948 .04674 Mdot
.948 .04794 Mdot
.948 .04805 Mdot
.948 .04865 Mdot
.948 .04867 Mdot
.948 .04878 Mdot
.948 .04914 Mdot
.948 .05003 Mdot
.948 .05034 Mdot
.948 .05072 Mdot
.948 .05145 Mdot
.948 .05186 Mdot
.948 .05232 Mdot
.948 .05443 Mdot
.948 .05491 Mdot
.948 .0551 Mdot
.948 .05538 Mdot
.948 .05599 Mdot
.948 .05605 Mdot
.948 .05622 Mdot
.948 .05643 Mdot
.948 .05674 Mdot
.948 .05711 Mdot
.948 .05785 Mdot
.948 .05798 Mdot
.948 .05895 Mdot
.948 .05985 Mdot
.948 .06039 Mdot
.948 .0604 Mdot
.948 .0606 Mdot
.948 .06102 Mdot
.948 .06148 Mdot
.948 .0615 Mdot
.948 .06179 Mdot
.948 .06181 Mdot
.948 .06459 Mdot
.948 .06464 Mdot
.948 .06508 Mdot
.948 .06528 Mdot
.948 .06545 Mdot
.948 .06715 Mdot
.948 .06816 Mdot
.948 .06846 Mdot
.948 .06903 Mdot
.948 .07056 Mdot
.948 .0719 Mdot
.948 .07196 Mdot
.948 .07224 Mdot
.948 .07314 Mdot
.948 .07319 Mdot
.948 .07454 Mdot
.948 .07466 Mdot
.948 .07512 Mdot
.948 .07588 Mdot
.948 .07779 Mdot
.948 .07784 Mdot
.948 .07796 Mdot
.948 .0781 Mdot
.948 .07839 Mdot
.948 .07886 Mdot
.948 .07897 Mdot
.948 .07964 Mdot
.948 .07985 Mdot
.948 .08134 Mdot
.948 .0825 Mdot
.948 .08368 Mdot
.948 .08381 Mdot
.948 .08471 Mdot
.948 .08619 Mdot
.948 .08633 Mdot
.948 .08658 Mdot
.948 .08674 Mdot
.948 .08685 Mdot
.948 .08693 Mdot
.948 .08696 Mdot
.948 .08703 Mdot
.948 .08744 Mdot
.948 .08782 Mdot
.948 .08822 Mdot
.948 .08824 Mdot
.948 .08923 Mdot
.948 .08924 Mdot
.948 .08946 Mdot
.948 .08972 Mdot
.948 .09091 Mdot
.948 .09159 Mdot
.948 .09184 Mdot
.948 .09185 Mdot
.948 .09603 Mdot
.948 .10121 Mdot
.948 .10228 Mdot
.948 .10243 Mdot
.948 .10355 Mdot
.948 .10365 Mdot
.948 .10486 Mdot
.948 .10579 Mdot
.948 .10582 Mdot
.948 .1059 Mdot
.948 .10623 Mdot
.948 .10626 Mdot
.948 .10628 Mdot
.948 .10678 Mdot
.948 .10714 Mdot
.948 .10749 Mdot
.948 .10751 Mdot
.948 .10772 Mdot
.948 .10792 Mdot
.948 .10917 Mdot
.948 .10918 Mdot
.948 .10921 Mdot
.948 .10935 Mdot
.948 .10966 Mdot
.948 .11027 Mdot
.948 .11106 Mdot
.948 .11121 Mdot
.948 .11126 Mdot
.948 .11164 Mdot
.948 .11173 Mdot
.948 .11183 Mdot
.948 .11232 Mdot
.948 .11305 Mdot
.948 .11384 Mdot
.948 .11389 Mdot
.948 .11432 Mdot
.948 .11474 Mdot
.948 .1159 Mdot
.948 .11593 Mdot
.948 .11602 Mdot
.948 .11618 Mdot
.948 .11657 Mdot
.948 .11659 Mdot
.948 .11787 Mdot
.948 .11826 Mdot
.948 .11851 Mdot
.948 .11868 Mdot
.948 .11877 Mdot
.948 .11985 Mdot
.948 .12159 Mdot
.948 .12196 Mdot
.948 .12268 Mdot
.948 .12308 Mdot
.948 .12442 Mdot
.948 .12578 Mdot
.948 .1258 Mdot
.948 .12621 Mdot
.948 .12683 Mdot
.948 .12699 Mdot
.948 .12712 Mdot
.948 .12734 Mdot
.948 .12789 Mdot
.948 .12876 Mdot
.948 .12902 Mdot
.948 .12977 Mdot
.948 .13028 Mdot
.948 .13034 Mdot
.948 .13232 Mdot
.948 .1335 Mdot
.948 .13458 Mdot
.948 .13551 Mdot
.948 .13566 Mdot
.948 .13566 Mdot
.948 .13709 Mdot
.948 .13729 Mdot
.948 .13729 Mdot
.948 .1387 Mdot
.948 .13881 Mdot
.948 .13919 Mdot
.948 .14002 Mdot
.948 .14055 Mdot
.948 .14062 Mdot
.948 .14131 Mdot
.948 .14137 Mdot
.948 .14174 Mdot
.948 .14181 Mdot
.948 .14301 Mdot
.948 .14331 Mdot
.948 .14337 Mdot
.948 .1445 Mdot
.948 .14534 Mdot
.948 .14547 Mdot
.948 .14612 Mdot
.948 .14711 Mdot
.948 .14721 Mdot
.948 .14727 Mdot
.948 .14854 Mdot
.948 .1502 Mdot
.948 .15105 Mdot
.948 .15129 Mdot
.948 .1513 Mdot
.948 .15186 Mdot
.948 .15249 Mdot
.948 .15295 Mdot
.948 .15406 Mdot
.948 .15551 Mdot
.948 .15755 Mdot
.948 .15807 Mdot
.948 .15832 Mdot
.948 .16009 Mdot
.948 .16011 Mdot
.948 .16042 Mdot
.948 .16133 Mdot
.948 .16186 Mdot
.948 .16253 Mdot
.948 .16297 Mdot
.948 .16305 Mdot
.948 .16361 Mdot
.948 .16365 Mdot
.948 .16456 Mdot
.948 .1653 Mdot
.948 .16543 Mdot
.948 .16606 Mdot
.948 .16665 Mdot
.948 .16685 Mdot
.948 .16742 Mdot
.948 .16814 Mdot
.948 .16902 Mdot
.948 .16918 Mdot
.948 .16949 Mdot
.948 .17012 Mdot
.948 .17044 Mdot
.948 .17058 Mdot
.948 .17295 Mdot
.948 .1734 Mdot
.948 .17665 Mdot
.948 .1797 Mdot
.948 .18149 Mdot
.948 .18152 Mdot
.948 .182 Mdot
.948 .18218 Mdot
.948 .18359 Mdot
.948 .18373 Mdot
.948 .18514 Mdot
.948 .18518 Mdot
.948 .18615 Mdot
.948 .18622 Mdot
.948 .1868 Mdot
.948 .19097 Mdot
.948 .19196 Mdot
.948 .19204 Mdot
.948 .19211 Mdot
.948 .1936 Mdot
.948 .19497 Mdot
.948 .19542 Mdot
.948 .19557 Mdot
.948 .19663 Mdot
.948 .19702 Mdot
.948 .19722 Mdot
.948 .19769 Mdot
.948 .19799 Mdot
.948 .19823 Mdot
.948 .19859 Mdot
.948 .19972 Mdot
.948 .20065 Mdot
.948 .20379 Mdot
.948 .20537 Mdot
.948 .20582 Mdot
.948 .20585 Mdot
.948 .20706 Mdot
.948 .20804 Mdot
.948 .20988 Mdot
.948 .2138 Mdot
.948 .21421 Mdot
.948 .21482 Mdot
.948 .21482 Mdot
.948 .2151 Mdot
.948 .2151 Mdot
.948 .21909 Mdot
.948 .21928 Mdot
.948 .22018 Mdot
.948 .22302 Mdot
.948 .22319 Mdot
.948 .22546 Mdot
.948 .22747 Mdot
.948 .22763 Mdot
.948 .22785 Mdot
.948 .22886 Mdot
.948 .22929 Mdot
.948 .2293 Mdot
.948 .22933 Mdot
.948 .22961 Mdot
.948 .23168 Mdot
.948 .23708 Mdot
.948 .23762 Mdot
.948 .23781 Mdot
.948 .23817 Mdot
.948 .23862 Mdot
.948 .2395 Mdot
.948 .24014 Mdot
.948 .24094 Mdot
.948 .24129 Mdot
.948 .24147 Mdot
.948 .24182 Mdot
.948 .24276 Mdot
.948 .24338 Mdot
.948 .24402 Mdot
.948 .24493 Mdot
.948 .24495 Mdot
.948 .24604 Mdot
.948 .24604 Mdot
.948 .24611 Mdot
.948 .24659 Mdot
.948 .24843 Mdot
.948 .2486 Mdot
.948 .25 Mdot
.948 .25213 Mdot
.948 .25272 Mdot
.948 .25358 Mdot
.948 .25572 Mdot
.948 .25613 Mdot
.948 .25833 Mdot
.948 .25882 Mdot
.948 .25888 Mdot
.948 .2633 Mdot
.948 .26371 Mdot
.948 .26436 Mdot
.948 .26446 Mdot
.948 .26492 Mdot
.948 .26511 Mdot
.948 .26528 Mdot
.948 .2655 Mdot
.948 .26552 Mdot
.948 .2656 Mdot
.948 .26568 Mdot
.948 .26579 Mdot
.948 .26586 Mdot
.948 .26704 Mdot
.948 .26817 Mdot
.948 .269 Mdot
.948 .26934 Mdot
.948 .2694 Mdot
.948 .26963 Mdot
.948 .26994 Mdot
.948 .27235 Mdot
.948 .27238 Mdot
.948 .27286 Mdot
.948 .27302 Mdot
.948 .27379 Mdot
.948 .27678 Mdot
.948 .27728 Mdot
.948 .27929 Mdot
.948 .28002 Mdot
.948 .28002 Mdot
.948 .28039 Mdot
.948 .28169 Mdot
.948 .28179 Mdot
.948 .28298 Mdot
.948 .28311 Mdot
.948 .28362 Mdot
.948 .28369 Mdot
.948 .28683 Mdot
.948 .29003 Mdot
.948 .29014 Mdot
.948 .29142 Mdot
.948 .29213 Mdot
.948 .29382 Mdot
.948 .29401 Mdot
.948 .30139 Mdot
.948 .30143 Mdot
.948 .3026 Mdot
.948 .30286 Mdot
.948 .30669 Mdot
.948 .3068 Mdot
.948 .30849 Mdot
.948 .30977 Mdot
.948 .31019 Mdot
.948 .31131 Mdot
.948 .31283 Mdot
.948 .31329 Mdot
.948 .31356 Mdot
.948 .31379 Mdot
.948 .31502 Mdot
.948 .3169 Mdot
.948 .31696 Mdot
.948 .31735 Mdot
.948 .3178 Mdot
.948 .31827 Mdot
.948 .31877 Mdot
.948 .31939 Mdot
.948 .31945 Mdot
.948 .31953 Mdot
.948 .31974 Mdot
.948 .32066 Mdot
.948 .32074 Mdot
.948 .32078 Mdot
.948 .32215 Mdot
.948 .32313 Mdot
.948 .3238 Mdot
.948 .32408 Mdot
.948 .32413 Mdot
.948 .3244 Mdot
.948 .32471 Mdot
.948 .32525 Mdot
.948 .32628 Mdot
.948 .32861 Mdot
.948 .32862 Mdot
.948 .32873 Mdot
.948 .32908 Mdot
.948 .32992 Mdot
.948 .33021 Mdot
.948 .33056 Mdot
.948 .33156 Mdot
.948 .33195 Mdot
.948 .33368 Mdot
.948 .33405 Mdot
.948 .3342 Mdot
.948 .33488 Mdot
.948 .33521 Mdot
.948 .33543 Mdot
.948 .33571 Mdot
.948 .33702 Mdot
.948 .33815 Mdot
.948 .33843 Mdot
.948 .33874 Mdot
.948 .33894 Mdot
.948 .33895 Mdot
.948 .34072 Mdot
.948 .34102 Mdot
.948 .34115 Mdot
.948 .34227 Mdot
.948 .34286 Mdot
.948 .34304 Mdot
.948 .34337 Mdot
.948 .34498 Mdot
.948 .34641 Mdot
.948 .34647 Mdot
.948 .34671 Mdot
.948 .34711 Mdot
.948 .34812 Mdot
.948 .34818 Mdot
.948 .34825 Mdot
.948 .34913 Mdot
.948 .35043 Mdot
.948 .35106 Mdot
.948 .35148 Mdot
.948 .35248 Mdot
.948 .35256 Mdot
.948 .35312 Mdot
.948 .35357 Mdot
.948 .35379 Mdot
.948 .35462 Mdot
.948 .35473 Mdot
.948 .35655 Mdot
.948 .35871 Mdot
.948 .35966 Mdot
.948 .36019 Mdot
.948 .36095 Mdot
.948 .36124 Mdot
.948 .36188 Mdot
.948 .36261 Mdot
.948 .36291 Mdot
.948 .36369 Mdot
.948 .36385 Mdot
.948 .36469 Mdot
.948 .36517 Mdot
.948 .36653 Mdot
.948 .36692 Mdot
.948 .36707 Mdot
.948 .36803 Mdot
.948 .36917 Mdot
.948 .37139 Mdot
.948 .37144 Mdot
.948 .37247 Mdot
.948 .37291 Mdot
.948 .3735 Mdot
.948 .37399 Mdot
.948 .37438 Mdot
.948 .37469 Mdot
.948 .37522 Mdot
.948 .37657 Mdot
.948 .37869 Mdot
.948 .37877 Mdot
.948 .37932 Mdot
.948 .37932 Mdot
.948 .38007 Mdot
.948 .38091 Mdot
.948 .38114 Mdot
.948 .38203 Mdot
.948 .38217 Mdot
.948 .38236 Mdot
.948 .3825 Mdot
.948 .38586 Mdot
.948 .38724 Mdot
.948 .38955 Mdot
.948 .39002 Mdot
.948 .39088 Mdot
.948 .39114 Mdot
.948 .39244 Mdot
.948 .39256 Mdot
.948 .39474 Mdot
.948 .39508 Mdot
.948 .39509 Mdot
.948 .39843 Mdot
.948 .39887 Mdot
.948 .39887 Mdot
.948 .4009 Mdot
.948 .40169 Mdot
.948 .40204 Mdot
.948 .40213 Mdot
.948 .40237 Mdot
.948 .40323 Mdot
.948 .40335 Mdot
.948 .40492 Mdot
.948 .40514 Mdot
.948 .40635 Mdot
.948 .40649 Mdot
.948 .40787 Mdot
.948 .40805 Mdot
.948 .4082 Mdot
.948 .40824 Mdot
.948 .40903 Mdot
.948 .40919 Mdot
.948 .40927 Mdot
.948 .41186 Mdot
.948 .41251 Mdot
.948 .41254 Mdot
.948 .41268 Mdot
.948 .41346 Mdot
.948 .41427 Mdot
.948 .41458 Mdot
.948 .41517 Mdot
.948 .41522 Mdot
.948 .41702 Mdot
.948 .41703 Mdot
.948 .41732 Mdot
.948 .41875 Mdot
.948 .4209 Mdot
.948 .42113 Mdot
.948 .42125 Mdot
.948 .42401 Mdot
.948 .4241 Mdot
.948 .42612 Mdot
.948 .42655 Mdot
.948 .4271 Mdot
.948 .42757 Mdot
.948 .42836 Mdot
.948 .42857 Mdot
.948 .42888 Mdot
.948 .42903 Mdot
.948 .4294 Mdot
.948 .42989 Mdot
.948 .42992 Mdot
.948 .43088 Mdot
.948 .43111 Mdot
.948 .43148 Mdot
.948 .43212 Mdot
.948 .43243 Mdot
.948 .43276 Mdot
.948 .4334 Mdot
.948 .43572 Mdot
.948 .43624 Mdot
.948 .43744 Mdot
.948 .43866 Mdot
.948 .43872 Mdot
.948 .43904 Mdot
.948 .4411 Mdot
.948 .4413 Mdot
.948 .44171 Mdot
.948 .44209 Mdot
.948 .44282 Mdot
.948 .44291 Mdot
.948 .44316 Mdot
.948 .44396 Mdot
.948 .44419 Mdot
.948 .4444 Mdot
.948 .44447 Mdot
.948 .44684 Mdot
.948 .44735 Mdot
.948 .44796 Mdot
.948 .44804 Mdot
.948 .44808 Mdot
.948 .44869 Mdot
.948 .4502 Mdot
.948 .45051 Mdot
.948 .45114 Mdot
.948 .45129 Mdot
.948 .45157 Mdot
.948 .45166 Mdot
.948 .45193 Mdot
.948 .45289 Mdot
.948 .45372 Mdot
.948 .45375 Mdot
.948 .45385 Mdot
.948 .45392 Mdot
.948 .45501 Mdot
.948 .45508 Mdot
.948 .45599 Mdot
.948 .45613 Mdot
.948 .45631 Mdot
.948 .45639 Mdot
.948 .45686 Mdot
.948 .45798 Mdot
.948 .45829 Mdot
.948 .45854 Mdot
.948 .45975 Mdot
.948 .45985 Mdot
.948 .46036 Mdot
.948 .46053 Mdot
.948 .46089 Mdot
.948 .46107 Mdot
.948 .46127 Mdot
.948 .46137 Mdot
.948 .46237 Mdot
.948 .46256 Mdot
.948 .46315 Mdot
.948 .46372 Mdot
.948 .46539 Mdot
.948 .46569 Mdot
.948 .46599 Mdot
.948 .46628 Mdot
.948 .46715 Mdot
.948 .46722 Mdot
.948 .46737 Mdot
.948 .46747 Mdot
.948 .46805 Mdot
.948 .46831 Mdot
.948 .46851 Mdot
.948 .46945 Mdot
.948 .4727 Mdot
.948 .47352 Mdot
.948 .4738 Mdot
.948 .47394 Mdot
.948 .47431 Mdot
.948 .47474 Mdot
.948 .47618 Mdot
.948 .47664 Mdot
.948 .47681 Mdot
.948 .47811 Mdot
.948 .47879 Mdot
.948 .47937 Mdot
.948 .47952 Mdot
.948 .47986 Mdot
.948 .48351 Mdot
.948 .48406 Mdot
.948 .48417 Mdot
.948 .48473 Mdot
.948 .48629 Mdot
.948 .48783 Mdot
.948 .48789 Mdot
.948 .48835 Mdot
.948 .4887 Mdot
.948 .48901 Mdot
.948 .48924 Mdot
.948 .4914 Mdot
.948 .49164 Mdot
.948 .49316 Mdot
.948 .494 Mdot
.948 .49406 Mdot
.948 .49422 Mdot
.948 .49476 Mdot
.948 .49529 Mdot
.948 .49567 Mdot
.948 .49578 Mdot
.948 .49633 Mdot
.948 .49675 Mdot
.948 .49696 Mdot
.948 .49733 Mdot
.948 .4989 Mdot
.948 .49894 Mdot
.948 .49974 Mdot
.948 .50033 Mdot
.948 .50057 Mdot
.948 .50108 Mdot
.948 .50142 Mdot
.948 .50268 Mdot
.948 .50342 Mdot
.948 .50349 Mdot
.948 .5043 Mdot
.948 .50498 Mdot
.948 .50506 Mdot
.948 .50517 Mdot
.948 .50528 Mdot
.948 .50762 Mdot
.948 .50814 Mdot
.948 .50827 Mdot
.948 .50973 Mdot
.948 .51042 Mdot
.948 .51064 Mdot
.948 .51226 Mdot
.948 .51249 Mdot
.948 .51267 Mdot
.948 .51284 Mdot
.948 .51301 Mdot
.948 .51315 Mdot
.948 .51386 Mdot
.948 .5143 Mdot
.948 .51465 Mdot
.948 .5152 Mdot
.948 .51621 Mdot
.948 .51686 Mdot
.948 .51822 Mdot
.948 .51832 Mdot
.948 .51873 Mdot
.948 .51875 Mdot
.948 .52135 Mdot
.948 .52141 Mdot
.948 .52225 Mdot
.948 .52269 Mdot
.948 .52273 Mdot
.948 .52384 Mdot
.948 .52493 Mdot
.948 .52495 Mdot
.948 .52513 Mdot
.948 .52517 Mdot
.948 .52558 Mdot
.948 .52561 Mdot
.948 .52606 Mdot
.948 .52729 Mdot
.948 .52862 Mdot
.948 .52961 Mdot
.948 .52972 Mdot
.948 .52993 Mdot
.948 .53098 Mdot
.948 .53104 Mdot
.948 .5311 Mdot
.948 .53124 Mdot
.948 .53148 Mdot
.948 .53331 Mdot
.948 .53349 Mdot
.948 .53506 Mdot
.948 .53534 Mdot
.948 .53623 Mdot
.948 .53675 Mdot
.948 .53735 Mdot
.948 .5375 Mdot
.948 .53753 Mdot
.948 .53753 Mdot
.948 .53788 Mdot
.948 .53789 Mdot
.948 .53859 Mdot
.948 .5389 Mdot
.948 .53901 Mdot
.948 .53944 Mdot
.948 .54042 Mdot
.948 .54281 Mdot
.948 .5429 Mdot
.948 .54291 Mdot
.948 .54305 Mdot
.948 .54344 Mdot
.948 .54413 Mdot
.948 .54738 Mdot
.948 .54738 Mdot
.948 .54747 Mdot
.948 .54766 Mdot
.948 .54778 Mdot
.948 .55025 Mdot
.948 .55026 Mdot
.948 .5504 Mdot
.948 .55185 Mdot
.948 .55213 Mdot
.948 .55247 Mdot
.948 .55266 Mdot
.948 .55289 Mdot
.948 .55307 Mdot
.948 .55358 Mdot
.948 .55399 Mdot
.948 .55445 Mdot
.948 .55447 Mdot
.948 .55449 Mdot
.948 .55479 Mdot
.948 .55605 Mdot
.948 .55697 Mdot
.948 .55749 Mdot
.948 .56088 Mdot
.948 .56102 Mdot
.948 .56121 Mdot
.948 .56135 Mdot
.948 .56222 Mdot
.948 .5624 Mdot
.948 .56244 Mdot
.948 .56292 Mdot
.948 .5631 Mdot
.948 .56325 Mdot
.948 .56344 Mdot
.948 .56387 Mdot
.948 .56396 Mdot
.948 .56396 Mdot
.948 .56448 Mdot
.948 .56455 Mdot
.948 .5647 Mdot
.948 .56529 Mdot
.948 .56604 Mdot
.948 .56635 Mdot
.948 .56651 Mdot
.948 .56652 Mdot
.948 .56683 Mdot
.948 .56767 Mdot
.948 .56772 Mdot
.948 .56819 Mdot
.948 .56823 Mdot
.948 .56847 Mdot
.948 .56879 Mdot
.948 .56881 Mdot
.948 .56924 Mdot
.948 .56958 Mdot
.948 .5696 Mdot
.948 .56975 Mdot
.948 .57012 Mdot
.948 .57053 Mdot
.948 .57053 Mdot
.948 .57058 Mdot
.948 .57099 Mdot
.948 .57099 Mdot
.948 .57103 Mdot
.948 .57251 Mdot
.948 .57265 Mdot
.948 .57287 Mdot
.948 .57377 Mdot
.948 .57378 Mdot
.948 .57454 Mdot
.948 .57465 Mdot
.948 .57495 Mdot
.948 .57544 Mdot
.948 .57588 Mdot
.948 .57599 Mdot
.948 .57635 Mdot
.948 .57653 Mdot
.948 .57698 Mdot
.948 .5771 Mdot
.948 .57767 Mdot
.948 .57788 Mdot
.948 .5781 Mdot
.948 .57839 Mdot
.948 .5784 Mdot
.948 .57886 Mdot
.948 .57906 Mdot
.948 .57959 Mdot
.948 .57992 Mdot
.948 .57995 Mdot
.948 .58026 Mdot
.948 .5803 Mdot
.948 .58059 Mdot
.948 .582 Mdot
.948 .58314 Mdot
.948 .58314 Mdot
.948 .58321 Mdot
.948 .5834 Mdot
.948 .58372 Mdot
.948 .58379 Mdot
.948 .58385 Mdot
.948 .58385 Mdot
.948 .58412 Mdot
.948 .58412 Mdot
.948 .58423 Mdot
.948 .58433 Mdot
.948 .58445 Mdot
.948 .58446 Mdot
.948 .58447 Mdot
.948 .58449 Mdot
.948 .58452 Mdot
.948 .58457 Mdot
.948 .58463 Mdot
.948 .58467 Mdot
.948 .58507 Mdot
.948 .58531 Mdot
.948 .58535 Mdot
.948 .58567 Mdot
.948 .58598 Mdot
.948 .58638 Mdot
.948 .58643 Mdot
.948 .58661 Mdot
.948 .58664 Mdot
.948 .58677 Mdot
.948 .58684 Mdot
.948 .58688 Mdot
.948 .58691 Mdot
.948 .58693 Mdot
.948 .58744 Mdot
.948 .58764 Mdot
.948 .58776 Mdot
.948 .5878 Mdot
.948 .58816 Mdot
.948 .58817 Mdot
.948 .58841 Mdot
.948 .58848 Mdot
.948 .5885 Mdot
.948 .58885 Mdot
.948 .58926 Mdot
.948 .58941 Mdot
.948 .58949 Mdot
.948 .58976 Mdot
.948 .59021 Mdot
.948 .59025 Mdot
.948 .59031 Mdot
.948 .59042 Mdot
.948 .59044 Mdot
.948 .59117 Mdot
.948 .59118 Mdot
.948 .59125 Mdot
.948 .59126 Mdot
.948 .59138 Mdot
.948 .59149 Mdot
.948 .59154 Mdot
.948 .59154 Mdot
.948 .59169 Mdot
.948 .59192 Mdot
.948 .59218 Mdot
.948 .59221 Mdot
.948 .59241 Mdot
.948 .5925 Mdot
.948 .59259 Mdot
.948 .59264 Mdot
.948 .59268 Mdot
.948 .5927 Mdot
.948 .59286 Mdot
.948 .59289 Mdot
.948 .59293 Mdot
.948 .59298 Mdot
.948 .59311 Mdot
.948 .59366 Mdot
.948 .59378 Mdot
.948 .59389 Mdot
.948 .59408 Mdot
.948 .59418 Mdot
.948 .59426 Mdot
.948 .59449 Mdot
.948 .59458 Mdot
.948 .59461 Mdot
.948 .59462 Mdot
.948 .59477 Mdot
.948 .5948 Mdot
.948 .59512 Mdot
.948 .59519 Mdot
.948 .59528 Mdot
.948 .59543 Mdot
.948 .59554 Mdot
.948 .59561 Mdot
.948 .59565 Mdot
.948 .59566 Mdot
.948 .59567 Mdot
.948 .59568 Mdot
.948 .59573 Mdot
.948 .59586 Mdot
.948 .59604 Mdot
.948 .59627 Mdot
.948 .59627 Mdot
.948 .59629 Mdot
.948 .59642 Mdot
.948 .59645 Mdot
.948 .59647 Mdot
.948 .59647 Mdot
.948 .59656 Mdot
.948 .59662 Mdot
.948 .59668 Mdot
.948 .59673 Mdot
.948 .59677 Mdot
.948 .59678 Mdot
.948 .59681 Mdot
.948 .59681 Mdot
.948 .59692 Mdot
.948 .59694 Mdot
.948 .59696 Mdot
.948 .59704 Mdot
.948 .59706 Mdot
.948 .59708 Mdot
.948 .5971 Mdot
.948 .59716 Mdot
.948 .59716 Mdot
.948 .59716 Mdot
.948 .59719 Mdot
.948 .59719 Mdot
.948 .5972 Mdot
.95 .03779 Mdot
.95 .03779 Mdot
.95 .0378 Mdot
.95 .03785 Mdot
.95 .03785 Mdot
.95 .03785 Mdot
.95 .03786 Mdot
.95 .03791 Mdot
.95 .03791 Mdot
.95 .03791 Mdot
.95 .03791 Mdot
.95 .03795 Mdot
.95 .03799 Mdot
.95 .03799 Mdot
.95 .03799 Mdot
.95 .03799 Mdot
.95 .03805 Mdot
.95 .03808 Mdot
.95 .03811 Mdot
.95 .03811 Mdot
.95 .03812 Mdot
.95 .03812 Mdot
.95 .03812 Mdot
.95 .03825 Mdot
.95 .03832 Mdot
.95 .03838 Mdot
.95 .03838 Mdot
.95 .03839 Mdot
.95 .03839 Mdot
.95 .03841 Mdot
.95 .03842 Mdot
.95 .03855 Mdot
.95 .03869 Mdot
.95 .03878 Mdot
.95 .03901 Mdot
.95 .03924 Mdot
.95 .03925 Mdot
.95 .0393 Mdot
.95 .0393 Mdot
.95 .03935 Mdot
.95 .03936 Mdot
.95 .0394 Mdot
.95 .03949 Mdot
.95 .03967 Mdot
.95 .0398 Mdot
.95 .03998 Mdot
.95 .04 Mdot
.95 .04033 Mdot
.95 .04068 Mdot
.95 .04092 Mdot
.95 .04117 Mdot
.95 .04119 Mdot
.95 .04137 Mdot
.95 .04164 Mdot
.95 .04241 Mdot
.95 .04274 Mdot
.95 .04358 Mdot
.95 .04372 Mdot
.95 .04381 Mdot
.95 .04406 Mdot
.95 .04412 Mdot
.95 .04441 Mdot
.95 .04448 Mdot
.95 .04455 Mdot
.95 .04498 Mdot
.95 .04498 Mdot
.95 .04507 Mdot
.95 .04515 Mdot
.95 .04537 Mdot
.95 .04543 Mdot
.95 .04548 Mdot
.95 .04553 Mdot
.95 .04586 Mdot
.95 .04622 Mdot
.95 .04636 Mdot
.95 .0465 Mdot
.95 .04662 Mdot
.95 .04769 Mdot
.95 .04844 Mdot
.95 .04934 Mdot
.95 .04977 Mdot
.95 .05001 Mdot
.95 .05176 Mdot
.95 .05198 Mdot
.95 .05208 Mdot
.95 .05259 Mdot
.95 .05419 Mdot
.95 .05432 Mdot
.95 .05577 Mdot
.95 .05612 Mdot
.95 .05706 Mdot
.95 .05725 Mdot
.95 .05761 Mdot
.95 .05798 Mdot
.95 .05901 Mdot
.95 .06004 Mdot
.95 .06095 Mdot
.95 .06262 Mdot
.95 .06297 Mdot
.95 .06434 Mdot
.95 .06443 Mdot
.95 .06457 Mdot
.95 .06649 Mdot
.95 .06683 Mdot
.95 .0683 Mdot
.95 .06863 Mdot
.95 .06864 Mdot
.95 .06884 Mdot
.95 .06888 Mdot
.95 .06908 Mdot
.95 .0696 Mdot
.95 .06968 Mdot
.95 .07142 Mdot
.95 .07197 Mdot
.95 .0729 Mdot
.95 .07453 Mdot
.95 .07501 Mdot
.95 .07529 Mdot
.95 .07669 Mdot
.95 .07704 Mdot
.95 .0773 Mdot
.95 .07747 Mdot
.95 .07963 Mdot
.95 .07994 Mdot
.95 .08132 Mdot
.95 .08161 Mdot
.95 .08244 Mdot
.95 .08277 Mdot
.95 .08282 Mdot
.95 .0837 Mdot
.95 .08466 Mdot
.95 .08538 Mdot
.95 .0855 Mdot
.95 .08766 Mdot
.95 .08937 Mdot
.95 .09025 Mdot
.95 .09193 Mdot
.95 .09239 Mdot
.95 .09309 Mdot
.95 .0956 Mdot
.95 .09644 Mdot
.95 .09792 Mdot
.95 .09894 Mdot
.95 .10021 Mdot
.95 .1014 Mdot
.95 .10176 Mdot
.95 .10253 Mdot
.95 .10253 Mdot
.95 .10254 Mdot
.95 .10274 Mdot
.95 .10274 Mdot
.95 .10275 Mdot
.95 .10276 Mdot
.95 .10287 Mdot
.95 .10295 Mdot
.95 .10296 Mdot
.95 .10296 Mdot
.95 .10297 Mdot
.95 .10311 Mdot
.95 .10323 Mdot
.95 .10323 Mdot
.95 .10324 Mdot
.95 .10325 Mdot
.95 .10348 Mdot
.95 .10359 Mdot
.95 .10368 Mdot
.95 .10368 Mdot
.95 .1037 Mdot
.95 .1037 Mdot
.95 .10372 Mdot
.95 .10419 Mdot
.95 .10444 Mdot
.95 .10466 Mdot
.95 .10467 Mdot
.95 .10472 Mdot
.95 .10472 Mdot
.95 .10477 Mdot
.95 .10481 Mdot
.95 .10514 Mdot
.95 .1053 Mdot
.95 .10578 Mdot
.95 .10611 Mdot
.95 .10697 Mdot
.95 .10777 Mdot
.95 .1078 Mdot
.95 .10783 Mdot
.95 .10802 Mdot
.95 .10802 Mdot
.95 .10819 Mdot
.95 .10823 Mdot
.95 .10839 Mdot
.95 .10864 Mdot
.95 .10869 Mdot
.95 .1091 Mdot
.95 .10936 Mdot
.95 .10982 Mdot
.95 .11047 Mdot
.95 .11054 Mdot
.95 .11057 Mdot
.95 .11175 Mdot
.95 .11225 Mdot
.95 .11301 Mdot
.95 .11388 Mdot
.95 .11479 Mdot
.95 .11479 Mdot
.95 .11484 Mdot
.95 .115 Mdot
.95 .1155 Mdot
.95 .11612 Mdot
.95 .11645 Mdot
.95 .11657 Mdot
.95 .11811 Mdot
.95 .11849 Mdot
.95 .11924 Mdot
.95 .11932 Mdot
.95 .12041 Mdot
.95 .12061 Mdot
.95 .12194 Mdot
.95 .12249 Mdot
.95 .12287 Mdot
.95 .12342 Mdot
.95 .12392 Mdot
.95 .12405 Mdot
.95 .12426 Mdot
.95 .12429 Mdot
.95 .12454 Mdot
.95 .12513 Mdot
.95 .12533 Mdot
.95 .12632 Mdot
.95 .12636 Mdot
.95 .12639 Mdot
.95 .12662 Mdot
.95 .12688 Mdot
.95 .1277 Mdot
.95 .1284 Mdot
.95 .12873 Mdot
.95 .12892 Mdot
.95 .129 Mdot
.95 .12933 Mdot
.95 .12978 Mdot
.95 .13001 Mdot
.95 .13018 Mdot
.95 .13035 Mdot
.95 .13053 Mdot
.95 .13152 Mdot
.95 .13194 Mdot
.95 .13279 Mdot
.95 .1333 Mdot
.95 .1338 Mdot
.95 .13423 Mdot
.95 .13682 Mdot
.95 .13783 Mdot
.95 .13799 Mdot
.95 .13916 Mdot
.95 .13951 Mdot
.95 .13972 Mdot
.95 .14061 Mdot
.95 .14142 Mdot
.95 .14151 Mdot
.95 .14158 Mdot
.95 .14197 Mdot
.95 .14261 Mdot
.95 .14337 Mdot
.95 .14376 Mdot
.95 .14449 Mdot
.95 .14526 Mdot
.95 .14576 Mdot
.95 .14611 Mdot
.95 .14961 Mdot
.95 .15183 Mdot
.95 .15217 Mdot
.95 .15295 Mdot
.95 .15328 Mdot
.95 .15498 Mdot
.95 .15504 Mdot
.95 .15759 Mdot
.95 .15908 Mdot
.95 .15973 Mdot
.95 .16056 Mdot
.95 .16084 Mdot
.95 .16099 Mdot
.95 .16233 Mdot
.95 .16237 Mdot
.95 .16587 Mdot
.95 .1659 Mdot
.95 .16595 Mdot
.95 .16714 Mdot
.95 .16715 Mdot
.95 .16769 Mdot
.95 .16773 Mdot
.95 .16907 Mdot
.95 .1696 Mdot
.95 .16981 Mdot
.95 .17032 Mdot
.95 .17034 Mdot
.95 .1704 Mdot
.95 .17047 Mdot
.95 .17097 Mdot
.95 .17194 Mdot
.95 .1722 Mdot
.95 .17314 Mdot
.95 .17344 Mdot
.95 .17406 Mdot
.95 .17473 Mdot
.95 .17692 Mdot
.95 .18005 Mdot
.95 .18038 Mdot
.95 .18314 Mdot
.95 .18339 Mdot
.95 .18344 Mdot
.95 .18347 Mdot
.95 .18521 Mdot
.95 .18543 Mdot
.95 .18732 Mdot
.95 .18811 Mdot
.95 .18897 Mdot
.95 .18926 Mdot
.95 .19013 Mdot
.95 .19055 Mdot
.95 .19236 Mdot
.95 .19465 Mdot
.95 .19487 Mdot
.95 .19498 Mdot
.95 .19544 Mdot
.95 .19665 Mdot
.95 .19773 Mdot
.95 .19915 Mdot
.95 .20171 Mdot
.95 .20275 Mdot
.95 .20282 Mdot
.95 .20622 Mdot
.95 .20759 Mdot
.95 .20865 Mdot
.95 .20871 Mdot
.95 .20935 Mdot
.95 .20946 Mdot
.95 .21012 Mdot
.95 .21178 Mdot
.95 .21204 Mdot
.95 .21668 Mdot
.95 .2168 Mdot
.95 .21743 Mdot
.95 .21764 Mdot
.95 .2194 Mdot
.95 .22236 Mdot
.95 .22519 Mdot
.95 .22753 Mdot
.95 .22783 Mdot
.95 .22903 Mdot
.95 .22991 Mdot
.95 .2341 Mdot
.95 .2343 Mdot
.95 .23457 Mdot
.95 .23538 Mdot
.95 .23541 Mdot
.95 .23556 Mdot
.95 .23562 Mdot
.95 .23619 Mdot
.95 .23674 Mdot
.95 .2378 Mdot
.95 .23827 Mdot
.95 .24342 Mdot
.95 .24439 Mdot
.95 .24595 Mdot
.95 .24864 Mdot
.95 .24906 Mdot
.95 .24952 Mdot
.95 .2509 Mdot
.95 .25205 Mdot
.95 .25305 Mdot
.95 .25322 Mdot
.95 .25587 Mdot
.95 .25639 Mdot
.95 .25742 Mdot
.95 .25877 Mdot
.95 .25892 Mdot
.95 .26097 Mdot
.95 .26132 Mdot
.95 .26404 Mdot
.95 .26619 Mdot
.95 .26664 Mdot
.95 .26705 Mdot
.95 .26708 Mdot
.95 .26763 Mdot
.95 .26777 Mdot
.95 .2686 Mdot
.95 .26967 Mdot
.95 .26989 Mdot
.95 .27079 Mdot
.95 .27118 Mdot
.95 .27285 Mdot
.95 .27415 Mdot
.95 .27544 Mdot
.95 .27694 Mdot
.95 .27968 Mdot
.95 .28037 Mdot
.95 .2816 Mdot
.95 .28173 Mdot
.95 .28376 Mdot
.95 .28386 Mdot
.95 .28732 Mdot
.95 .29102 Mdot
.95 .29188 Mdot
.95 .29229 Mdot
.95 .29343 Mdot
.95 .2935 Mdot
.95 .2938 Mdot
.95 .29392 Mdot
.95 .2957 Mdot
.95 .29687 Mdot
.95 .29729 Mdot
.95 .29762 Mdot
.95 .29806 Mdot
.95 .30052 Mdot
.95 .30095 Mdot
.95 .3041 Mdot
.95 .30548 Mdot
.95 .30743 Mdot
.95 .30843 Mdot
.95 .30859 Mdot
.95 .30861 Mdot
.95 .31058 Mdot
.95 .31058 Mdot
.95 .31062 Mdot
.95 .31117 Mdot
.95 .31118 Mdot
.95 .31119 Mdot
.95 .31121 Mdot
.95 .31153 Mdot
.95 .31176 Mdot
.95 .31176 Mdot
.95 .31178 Mdot
.95 .31181 Mdot
.95 .3122 Mdot
.95 .31238 Mdot
.95 .31252 Mdot
.95 .31253 Mdot
.95 .31255 Mdot
.95 .31259 Mdot
.95 .31321 Mdot
.95 .31352 Mdot
.95 .31377 Mdot
.95 .31378 Mdot
.95 .31383 Mdot
.95 .31383 Mdot
.95 .31389 Mdot
.95 .31443 Mdot
.95 .31517 Mdot
.95 .31587 Mdot
.95 .31648 Mdot
.95 .3165 Mdot
.95 .31663 Mdot
.95 .31663 Mdot
.95 .31675 Mdot
.95 .31678 Mdot
.95 .31688 Mdot
.95 .3178 Mdot
.95 .31818 Mdot
.95 .31822 Mdot
.95 .31889 Mdot
.95 .31955 Mdot
.95 .32044 Mdot
.95 .3228 Mdot
.95 .32393 Mdot
.95 .32496 Mdot
.95 .32505 Mdot
.95 .32513 Mdot
.95 .32564 Mdot
.95 .32564 Mdot
.95 .32583 Mdot
.95 .32608 Mdot
.95 .32621 Mdot
.95 .32626 Mdot
.95 .32663 Mdot
.95 .32717 Mdot
.95 .32732 Mdot
.95 .32745 Mdot
.95 .32854 Mdot
.95 .32926 Mdot
.95 .3301 Mdot
.95 .33049 Mdot
.95 .33222 Mdot
.95 .33241 Mdot
.95 .33249 Mdot
.95 .3329 Mdot
.95 .33536 Mdot
.95 .33562 Mdot
.95 .33669 Mdot
.95 .33695 Mdot
.95 .33896 Mdot
.95 .34003 Mdot
.95 .34025 Mdot
.95 .34116 Mdot
.95 .34124 Mdot
.95 .34239 Mdot
.95 .34344 Mdot
.95 .34363 Mdot
.95 .34364 Mdot
.95 .34375 Mdot
.95 .34377 Mdot
.95 .34417 Mdot
.95 .34422 Mdot
.95 .34548 Mdot
.95 .34598 Mdot
.95 .3471 Mdot
.95 .34796 Mdot
.95 .34827 Mdot
.95 .34959 Mdot
.95 .3508 Mdot
.95 .35218 Mdot
.95 .35224 Mdot
.95 .35323 Mdot
.95 .35439 Mdot
.95 .35513 Mdot
.95 .35533 Mdot
.95 .35563 Mdot
.95 .35768 Mdot
.95 .35811 Mdot
.95 .35863 Mdot
.95 .35971 Mdot
.95 .36198 Mdot
.95 .36272 Mdot
.95 .36336 Mdot
.95 .36432 Mdot
.95 .36439 Mdot
.95 .36554 Mdot
.95 .36569 Mdot
.95 .36646 Mdot
.95 .36693 Mdot
.95 .36727 Mdot
.95 .36769 Mdot
.95 .36777 Mdot
.95 .36786 Mdot
.95 .36848 Mdot
.95 .36954 Mdot
.95 .36995 Mdot
.95 .37043 Mdot
.95 .37242 Mdot
.95 .37286 Mdot
.95 .37298 Mdot
.95 .37305 Mdot
.95 .37361 Mdot
.95 .37366 Mdot
.95 .37379 Mdot
.95 .374 Mdot
.95 .37425 Mdot
.95 .37502 Mdot
.95 .37626 Mdot
.95 .37696 Mdot
.95 .37795 Mdot
.95 .37876 Mdot
.95 .37922 Mdot
.95 .37942 Mdot
.95 .38022 Mdot
.95 .3813 Mdot
.95 .38168 Mdot
.95 .38185 Mdot
.95 .38225 Mdot
.95 .38267 Mdot
.95 .38311 Mdot
.95 .38549 Mdot
.95 .38638 Mdot
.95 .38645 Mdot
.95 .38647 Mdot
.95 .38697 Mdot
.95 .38703 Mdot
.95 .38757 Mdot
.95 .3878 Mdot
.95 .38849 Mdot
.95 .38971 Mdot
.95 .3909 Mdot
.95 .39189 Mdot
.95 .3957 Mdot
.95 .39587 Mdot
.95 .39794 Mdot
.95 .40027 Mdot
.95 .40065 Mdot
.95 .40067 Mdot
.95 .40333 Mdot
.95 .40413 Mdot
.95 .4046 Mdot
.95 .40663 Mdot
.95 .40846 Mdot
.95 .40867 Mdot
.95 .40882 Mdot
.95 .40906 Mdot
.95 .40961 Mdot
.95 .4097 Mdot
.95 .41113 Mdot
.95 .41229 Mdot
.95 .41284 Mdot
.95 .4137 Mdot
.95 .41481 Mdot
.95 .41491 Mdot
.95 .41531 Mdot
.95 .41575 Mdot
.95 .41603 Mdot
.95 .41614 Mdot
.95 .41703 Mdot
.95 .41813 Mdot
.95 .41889 Mdot
.95 .41981 Mdot
.95 .42086 Mdot
.95 .42121 Mdot
.95 .42408 Mdot
.95 .42476 Mdot
.95 .42535 Mdot
.95 .42647 Mdot
.95 .42652 Mdot
.95 .42674 Mdot
.95 .42704 Mdot
.95 .42729 Mdot
.95 .42737 Mdot
.95 .42939 Mdot
.95 .43022 Mdot
.95 .4312 Mdot
.95 .43193 Mdot
.95 .43233 Mdot
.95 .43312 Mdot
.95 .43357 Mdot
.95 .43426 Mdot
.95 .43536 Mdot
.95 .4365 Mdot
.95 .43764 Mdot
.95 .43778 Mdot
.95 .4378 Mdot
.95 .43793 Mdot
.95 .4399 Mdot
.95 .43994 Mdot
.95 .44317 Mdot
.95 .44462 Mdot
.95 .44482 Mdot
.95 .44492 Mdot
.95 .44618 Mdot
.95 .44689 Mdot
.95 .44721 Mdot
.95 .4475 Mdot
.95 .44916 Mdot
.95 .44973 Mdot
.95 .45002 Mdot
.95 .45267 Mdot
.95 .45275 Mdot
.95 .45844 Mdot
.95 .4586 Mdot
.95 .45958 Mdot
.95 .45963 Mdot
.95 .45973 Mdot
.95 .46202 Mdot
.95 .46204 Mdot
.95 .46306 Mdot
.95 .46313 Mdot
.95 .46368 Mdot
.95 .46423 Mdot
.95 .46529 Mdot
.95 .46567 Mdot
.95 .46667 Mdot
.95 .46706 Mdot
.95 .46801 Mdot
.95 .46804 Mdot
.95 .46816 Mdot
.95 .4683 Mdot
.95 .4684 Mdot
.95 .46895 Mdot
.95 .46922 Mdot
.95 .46954 Mdot
.95 .47086 Mdot
.95 .47102 Mdot
.95 .4715 Mdot
.95 .47317 Mdot
.95 .47322 Mdot
.95 .47335 Mdot
.95 .47373 Mdot
.95 .47377 Mdot
.95 .47491 Mdot
.95 .4761 Mdot
.95 .47635 Mdot
.95 .48003 Mdot
.95 .4821 Mdot
.95 .48218 Mdot
.95 .48554 Mdot
.95 .48563 Mdot
.95 .48586 Mdot
.95 .48589 Mdot
.95 .4861 Mdot
.95 .48613 Mdot
.95 .4881 Mdot
.95 .49004 Mdot
.95 .49084 Mdot
.95 .49125 Mdot
.95 .49134 Mdot
.95 .49139 Mdot
.95 .4919 Mdot
.95 .49307 Mdot
.95 .49381 Mdot
.95 .49431 Mdot
.95 .49467 Mdot
.95 .49513 Mdot
.95 .4958 Mdot
.95 .49699 Mdot
.95 .49779 Mdot
.95 .4986 Mdot
.95 .49908 Mdot
.95 .49994 Mdot
.95 .50048 Mdot
.95 .50095 Mdot
.95 .50234 Mdot
.95 .50302 Mdot
.95 .5032 Mdot
.95 .50332 Mdot
.95 .50372 Mdot
.95 .50419 Mdot
.95 .50453 Mdot
.95 .50462 Mdot
.95 .50588 Mdot
.95 .50638 Mdot
.95 .50731 Mdot
.95 .50835 Mdot
.95 .50944 Mdot
.95 .50978 Mdot
.95 .50994 Mdot
.95 .51064 Mdot
.95 .51249 Mdot
.95 .51275 Mdot
.95 .51327 Mdot
.95 .51411 Mdot
.95 .51485 Mdot
.95 .51621 Mdot
.95 .51622 Mdot
.95 .51733 Mdot
.95 .51894 Mdot
.95 .51996 Mdot
.95 .52023 Mdot
.95 .52038 Mdot
.95 .52079 Mdot
.95 .52141 Mdot
.95 .52146 Mdot
.95 .52156 Mdot
.95 .52199 Mdot
.95 .52213 Mdot
.95 .52371 Mdot
.95 .52491 Mdot
.95 .52568 Mdot
.95 .52634 Mdot
.95 .52728 Mdot
.95 .52822 Mdot
.95 .52923 Mdot
.95 .52936 Mdot
.95 .52966 Mdot
.95 .52974 Mdot
.95 .5301 Mdot
.95 .53042 Mdot
.95 .53061 Mdot
.95 .53062 Mdot
.95 .53076 Mdot
.95 .53091 Mdot
.95 .53163 Mdot
.95 .53333 Mdot
.95 .53383 Mdot
.95 .53417 Mdot
.95 .53597 Mdot
.95 .53657 Mdot
.95 .53759 Mdot
.95 .54007 Mdot
.95 .54022 Mdot
.95 .54092 Mdot
.95 .54094 Mdot
.95 .541 Mdot
.95 .54126 Mdot
.95 .54141 Mdot
.95 .5434 Mdot
.95 .54424 Mdot
.95 .54668 Mdot
.95 .54688 Mdot
.95 .54691 Mdot
.95 .55016 Mdot
.95 .55123 Mdot
.95 .55233 Mdot
.95 .55276 Mdot
.95 .55309 Mdot
.95 .55363 Mdot
.95 .55439 Mdot
.95 .55494 Mdot
.95 .55533 Mdot
.95 .55568 Mdot
.95 .55591 Mdot
.95 .55648 Mdot
.95 .55655 Mdot
.95 .55707 Mdot
.95 .55709 Mdot
.95 .55717 Mdot
.95 .55809 Mdot
.95 .55968 Mdot
.95 .55987 Mdot
.95 .56015 Mdot
.95 .5605 Mdot
.95 .56093 Mdot
.95 .56096 Mdot
.95 .56098 Mdot
.95 .56113 Mdot
.95 .56119 Mdot
.95 .56135 Mdot
.95 .56174 Mdot
.95 .56175 Mdot
.95 .56191 Mdot
.95 .56228 Mdot
.95 .56229 Mdot
.95 .56331 Mdot
.95 .56333 Mdot
.95 .56376 Mdot
.95 .56408 Mdot
.95 .56427 Mdot
.95 .56471 Mdot
.95 .56546 Mdot
.95 .56638 Mdot
.95 .56702 Mdot
.95 .56812 Mdot
.95 .56849 Mdot
.95 .56881 Mdot
.95 .56902 Mdot
.95 .56921 Mdot
.95 .56932 Mdot
.95 .56934 Mdot
.95 .56936 Mdot
.95 .56985 Mdot
.95 .56991 Mdot
.95 .57001 Mdot
.95 .57039 Mdot
.95 .57067 Mdot
.95 .57206 Mdot
.95 .57245 Mdot
.95 .57279 Mdot
.95 .57291 Mdot
.95 .57325 Mdot
.95 .57362 Mdot
.95 .57364 Mdot
.95 .57414 Mdot
.95 .57421 Mdot
.95 .57428 Mdot
.95 .57461 Mdot
.95 .57471 Mdot
.95 .57487 Mdot
.95 .57524 Mdot
.95 .5756 Mdot
.95 .57583 Mdot
.95 .57594 Mdot
.95 .57636 Mdot
.95 .57649 Mdot
.95 .5768 Mdot
.95 .57686 Mdot
.95 .57756 Mdot
.95 .57803 Mdot
.95 .57843 Mdot
.95 .57856 Mdot
.95 .5788 Mdot
.95 .57952 Mdot
.95 .58014 Mdot
.95 .58045 Mdot
.95 .58055 Mdot
.95 .58087 Mdot
.95 .58122 Mdot
.95 .5815 Mdot
.95 .5819 Mdot
.95 .58213 Mdot
.95 .58281 Mdot
.95 .583 Mdot
.95 .58313 Mdot
.95 .58358 Mdot
.95 .58382 Mdot
.95 .58428 Mdot
.95 .58486 Mdot
.95 .5849 Mdot
.95 .58509 Mdot
.95 .58535 Mdot
.95 .58559 Mdot
.95 .5856 Mdot
.95 .58569 Mdot
.95 .58591 Mdot
.95 .58599 Mdot
.95 .58636 Mdot
.95 .58644 Mdot
.95 .58702 Mdot
.95 .58707 Mdot
.95 .58713 Mdot
.95 .58723 Mdot
.95 .5876 Mdot
.95 .58768 Mdot
.95 .5878 Mdot
.95 .58824 Mdot
.95 .58849 Mdot
.95 .58863 Mdot
.95 .5891 Mdot
.95 .58912 Mdot
.95 .58925 Mdot
.95 .58931 Mdot
.95 .58932 Mdot
.95 .58937 Mdot
.95 .58937 Mdot
.95 .58946 Mdot
.95 .58985 Mdot
.95 .58994 Mdot
.95 .59045 Mdot
.95 .59048 Mdot
.95 .59051 Mdot
.95 .59087 Mdot
.95 .59096 Mdot
.95 .5914 Mdot
.95 .59164 Mdot
.95 .59191 Mdot
.95 .59218 Mdot
.95 .59228 Mdot
.95 .59238 Mdot
.95 .59242 Mdot
.95 .59267 Mdot
.95 .59276 Mdot
.95 .59314 Mdot
.95 .59318 Mdot
.95 .59359 Mdot
.95 .59373 Mdot
.95 .59375 Mdot
.95 .59381 Mdot
.95 .59427 Mdot
.95 .59433 Mdot
.95 .59444 Mdot
.95 .59468 Mdot
.95 .59487 Mdot
.95 .59515 Mdot
.95 .59518 Mdot
.95 .59522 Mdot
.95 .59525 Mdot
.95 .59535 Mdot
.95 .59543 Mdot
.95 .59545 Mdot
.95 .59546 Mdot
.95 .59547 Mdot
.95 .59553 Mdot
.95 .59555 Mdot
.95 .59557 Mdot
.95 .59558 Mdot
.95 .59569 Mdot
.95 .5957 Mdot
.95 .59572 Mdot
.95 .5958 Mdot
.95 .59581 Mdot
.95 .59588 Mdot
.95 .5959 Mdot
.95 .59594 Mdot
.95 .59616 Mdot
.95 .59624 Mdot
.95 .59644 Mdot
.95 .59651 Mdot
.95 .59656 Mdot
.95 .59656 Mdot
.95 .59663 Mdot
.95 .59669 Mdot
.95 .59678 Mdot
.95 .59686 Mdot
.95 .59687 Mdot
.95 .59691 Mdot
.95 .59695 Mdot
.95 .597 Mdot
.95 .59702 Mdot
.95 .59703 Mdot
.95 .59703 Mdot
.95 .59704 Mdot
.95 .59704 Mdot
.95 .59706 Mdot
.95 .59706 Mdot
.95 .59712 Mdot
.95 .59718 Mdot
.95 .59724 Mdot
.95 .59727 Mdot
.95 .59727 Mdot
.95 .59728 Mdot
.95 .59728 Mdot
.95 .59728 Mdot
.95 .59728 Mdot
.95 .5973 Mdot
.95 .59731 Mdot
.95 .59735 Mdot
.95 .59735 Mdot
.95 .59735 Mdot
.95 .59735 Mdot
.95 .59735 Mdot
.95 .59736 Mdot
.95 .59736 Mdot
.95 .59738 Mdot
.95 .59738 Mdot
.95 .59738 Mdot
.95 .59738 Mdot
.95 .59739 Mdot
.95 .5974 Mdot
.95 .5974 Mdot
.95 .5974 Mdot
.95 .5974 Mdot
.95 .59742 Mdot
.95 .59742 Mdot
.95 .59742 Mdot
.95 .59742 Mdot
.95 .59743 Mdot
.95 .59743 Mdot
.95 .59743 Mdot
.952 .03688 Mdot
.952 .03688 Mdot
.952 .03688 Mdot
.952 .03688 Mdot
.952 .03688 Mdot
.952 .03689 Mdot
.952 .03689 Mdot
.952 .03689 Mdot
.952 .03689 Mdot
.952 .03689 Mdot
.952 .03689 Mdot
.952 .03689 Mdot
.952 .03689 Mdot
.952 .0369 Mdot
.952 .0369 Mdot
.952 .0369 Mdot
.952 .0369 Mdot
.952 .0369 Mdot
.952 .03691 Mdot
.952 .03691 Mdot
.952 .03693 Mdot
.952 .03693 Mdot
.952 .03694 Mdot
.952 .03694 Mdot
.952 .03694 Mdot
.952 .03695 Mdot
.952 .03696 Mdot
.952 .03696 Mdot
.952 .03696 Mdot
.952 .03697 Mdot
.952 .03697 Mdot
.952 .03697 Mdot
.952 .03698 Mdot
.952 .03699 Mdot
.952 .037 Mdot
.952 .03701 Mdot
.952 .03704 Mdot
.952 .03705 Mdot
.952 .03705 Mdot
.952 .03708 Mdot
.952 .03709 Mdot
.952 .03709 Mdot
.952 .0371 Mdot
.952 .03711 Mdot
.952 .03712 Mdot
.952 .03713 Mdot
.952 .03713 Mdot
.952 .03714 Mdot
.952 .03715 Mdot
.952 .03715 Mdot
.952 .03717 Mdot
.952 .03721 Mdot
.952 .03722 Mdot
.952 .03723 Mdot
.952 .03724 Mdot
.952 .03725 Mdot
.952 .03726 Mdot
.952 .03727 Mdot
.952 .0373 Mdot
.952 .03731 Mdot
.952 .03732 Mdot
.952 .03732 Mdot
.952 .03732 Mdot
.952 .03733 Mdot
.952 .03734 Mdot
.952 .03734 Mdot
.952 .03735 Mdot
.952 .03737 Mdot
.952 .03738 Mdot
.952 .0374 Mdot
.952 .03741 Mdot
.952 .03742 Mdot
.952 .03744 Mdot
.952 .03745 Mdot
.952 .03745 Mdot
.952 .03747 Mdot
.952 .03748 Mdot
.952 .03749 Mdot
.952 .03749 Mdot
.952 .03752 Mdot
.952 .03753 Mdot
.952 .03753 Mdot
.952 .03754 Mdot
.952 .03754 Mdot
.952 .03756 Mdot
.952 .03756 Mdot
.952 .03757 Mdot
.952 .03758 Mdot
.952 .03761 Mdot
.952 .03762 Mdot
.952 .03762 Mdot
.952 .03762 Mdot
.952 .03764 Mdot
.952 .03766 Mdot
.952 .03767 Mdot
.952 .03767 Mdot
.952 .03768 Mdot
.952 .03769 Mdot
.952 .03771 Mdot
.952 .03777 Mdot
.952 .03778 Mdot
.952 .03778 Mdot
.952 .0378 Mdot
.952 .0378 Mdot
.952 .03787 Mdot
.952 .03789 Mdot
.952 .03793 Mdot
.952 .03794 Mdot
.952 .03797 Mdot
.952 .03798 Mdot
.952 .03799 Mdot
.952 .03802 Mdot
.952 .03802 Mdot
.952 .03802 Mdot
.952 .03803 Mdot
.952 .03803 Mdot
.952 .03805 Mdot
.952 .03806 Mdot
.952 .03807 Mdot
.952 .03808 Mdot
.952 .03808 Mdot
.952 .03809 Mdot
.952 .0381 Mdot
.952 .03811 Mdot
.952 .03811 Mdot
.952 .03812 Mdot
.952 .03813 Mdot
.952 .03814 Mdot
.952 .03814 Mdot
.952 .03814 Mdot
.952 .03816 Mdot
.952 .03816 Mdot
.952 .03816 Mdot
.952 .03818 Mdot
.952 .03819 Mdot
.952 .0382 Mdot
.952 .03822 Mdot
.952 .03825 Mdot
.952 .03826 Mdot
.952 .03826 Mdot
.952 .03827 Mdot
.952 .03827 Mdot
.952 .03829 Mdot
.952 .03829 Mdot
.952 .0383 Mdot
.952 .0383 Mdot
.952 .0383 Mdot
.952 .03831 Mdot
.952 .03831 Mdot
.952 .03831 Mdot
.952 .03833 Mdot
.952 .03833 Mdot
.952 .03834 Mdot
.952 .03834 Mdot
.952 .03835 Mdot
.952 .03835 Mdot
.952 .03835 Mdot
.952 .03837 Mdot
.952 .03837 Mdot
.952 .03837 Mdot
.952 .03837 Mdot
.952 .03837 Mdot
.952 .03837 Mdot
.952 .03839 Mdot
.952 .03839 Mdot
.952 .03839 Mdot
.952 .03839 Mdot
.952 .0384 Mdot
.952 .03846 Mdot
.952 .03847 Mdot
.952 .03847 Mdot
.952 .03847 Mdot
.952 .03852 Mdot
.952 .03877 Mdot
.952 .0388 Mdot
.952 .03881 Mdot
.952 .03881 Mdot
.952 .03904 Mdot
.952 .03912 Mdot
.952 .03977 Mdot
.952 .04042 Mdot
.952 .0406 Mdot
.952 .04061 Mdot
.952 .04063 Mdot
.952 .04147 Mdot
.952 .04149 Mdot
.952 .0416 Mdot
.952 .04177 Mdot
.952 .04182 Mdot
.952 .04217 Mdot
.952 .04281 Mdot
.952 .04309 Mdot
.952 .04509 Mdot
.952 .04607 Mdot
.952 .04882 Mdot
.952 .05669 Mdot
.952 .05711 Mdot
.952 .05876 Mdot
.952 .05921 Mdot
.952 .05941 Mdot
.952 .0597 Mdot
.952 .06135 Mdot
.952 .06464 Mdot
.952 .07312 Mdot
.952 .07333 Mdot
.952 .07375 Mdot
.952 .07547 Mdot
.952 .07575 Mdot
.952 .07891 Mdot
.952 .0797 Mdot
.952 .07984 Mdot
.952 .08218 Mdot
.952 .08376 Mdot
.952 .08471 Mdot
.952 .08659 Mdot
.952 .0871 Mdot
.952 .09529 Mdot
.952 .09565 Mdot
.952 .09863 Mdot
.952 .09924 Mdot
.952 .09924 Mdot
.952 .09924 Mdot
.952 .09924 Mdot
.952 .09924 Mdot
.952 .09925 Mdot
.952 .09925 Mdot
.952 .09926 Mdot
.952 .09926 Mdot
.952 .09927 Mdot
.952 .09927 Mdot
.952 .09927 Mdot
.952 .09927 Mdot
.952 .09929 Mdot
.952 .09929 Mdot
.952 .0993 Mdot
.952 .09931 Mdot
.952 .09931 Mdot
.952 .09933 Mdot
.952 .09933 Mdot
.952 .09939 Mdot
.952 .0994 Mdot
.952 .09943 Mdot
.952 .09945 Mdot
.952 .09945 Mdot
.952 .09948 Mdot
.952 .0995 Mdot
.952 .09951 Mdot
.952 .09953 Mdot
.952 .09953 Mdot
.952 .09956 Mdot
.952 .09957 Mdot
.952 .09957 Mdot
.952 .09963 Mdot
.952 .09966 Mdot
.952 .09971 Mdot
.952 .09981 Mdot
.952 .09983 Mdot
.952 .09984 Mdot
.952 .09994 Mdot
.952 .09998 Mdot
.952 .10001 Mdot
.952 .10003 Mdot
.952 .10008 Mdot
.952 .10011 Mdot
.952 .10013 Mdot
.952 .10015 Mdot
.952 .10016 Mdot
.952 .1002 Mdot
.952 .10023 Mdot
.952 .10028 Mdot
.952 .10032 Mdot
.952 .10037 Mdot
.952 .10043 Mdot
.952 .10047 Mdot
.952 .10049 Mdot
.952 .10055 Mdot
.952 .10056 Mdot
.952 .10063 Mdot
.952 .10064 Mdot
.952 .10077 Mdot
.952 .10081 Mdot
.952 .10082 Mdot
.952 .10083 Mdot
.952 .10084 Mdot
.952 .10086 Mdot
.952 .1009 Mdot
.952 .10091 Mdot
.952 .10095 Mdot
.952 .10103 Mdot
.952 .10105 Mdot
.952 .10113 Mdot
.952 .10117 Mdot
.952 .1012 Mdot
.952 .10126 Mdot
.952 .10129 Mdot
.952 .1013 Mdot
.952 .10139 Mdot
.952 .10142 Mdot
.952 .10145 Mdot
.952 .10147 Mdot
.952 .10158 Mdot
.952 .1016 Mdot
.952 .10161 Mdot
.952 .10163 Mdot
.952 .10165 Mdot
.952 .10171 Mdot
.952 .10172 Mdot
.952 .10176 Mdot
.952 .10179 Mdot
.952 .1019 Mdot
.952 .10193 Mdot
.952 .10194 Mdot
.952 .10194 Mdot
.952 .102 Mdot
.952 .10208 Mdot
.952 .10209 Mdot
.952 .10213 Mdot
.952 .10215 Mdot
.952 .10219 Mdot
.952 .10227 Mdot
.952 .10246 Mdot
.952 .1025 Mdot
.952 .10252 Mdot
.952 .10254 Mdot
.952 .10259 Mdot
.952 .1026 Mdot
.952 .10283 Mdot
.952 .10292 Mdot
.952 .10307 Mdot
.952 .10311 Mdot
.952 .10319 Mdot
.952 .10326 Mdot
.952 .10326 Mdot
.952 .10339 Mdot
.952 .10339 Mdot
.952 .1034 Mdot
.952 .10341 Mdot
.952 .10342 Mdot
.952 .10345 Mdot
.952 .10348 Mdot
.952 .10353 Mdot
.952 .10356 Mdot
.952 .10359 Mdot
.952 .1036 Mdot
.952 .10364 Mdot
.952 .10366 Mdot
.952 .10372 Mdot
.952 .10373 Mdot
.952 .10376 Mdot
.952 .10377 Mdot
.952 .10382 Mdot
.952 .10384 Mdot
.952 .10384 Mdot
.952 .10389 Mdot
.952 .1039 Mdot
.952 .10391 Mdot
.952 .10396 Mdot
.952 .10402 Mdot
.952 .10406 Mdot
.952 .10413 Mdot
.952 .10422 Mdot
.952 .10426 Mdot
.952 .10427 Mdot
.952 .1043 Mdot
.952 .10431 Mdot
.952 .10436 Mdot
.952 .10438 Mdot
.952 .1044 Mdot
.952 .10441 Mdot
.952 .10441 Mdot
.952 .10444 Mdot
.952 .10445 Mdot
.952 .10446 Mdot
.952 .10451 Mdot
.952 .10453 Mdot
.952 .10454 Mdot
.952 .10454 Mdot
.952 .10458 Mdot
.952 .10458 Mdot
.952 .10459 Mdot
.952 .10465 Mdot
.952 .10466 Mdot
.952 .10466 Mdot
.952 .10466 Mdot
.952 .10466 Mdot
.952 .10468 Mdot
.952 .10473 Mdot
.952 .10474 Mdot
.952 .10474 Mdot
.952 .10474 Mdot
.952 .10478 Mdot
.952 .105 Mdot
.952 .10502 Mdot
.952 .10502 Mdot
.952 .10503 Mdot
.952 .10521 Mdot
.952 .10573 Mdot
.952 .10614 Mdot
.952 .10625 Mdot
.952 .10625 Mdot
.952 .10627 Mdot
.952 .10681 Mdot
.952 .10689 Mdot
.952 .10692 Mdot
.952 .10709 Mdot
.952 .1074 Mdot
.952 .10754 Mdot
.952 .10976 Mdot
.952 .11209 Mdot
.952 .11274 Mdot
.952 .11279 Mdot
.952 .11286 Mdot
.952 .1159 Mdot
.952 .11598 Mdot
.952 .11638 Mdot
.952 .11699 Mdot
.952 .11714 Mdot
.952 .11717 Mdot
.952 .1184 Mdot
.952 .11995 Mdot
.952 .12043 Mdot
.952 .12071 Mdot
.952 .12106 Mdot
.952 .12173 Mdot
.952 .12328 Mdot
.952 .12886 Mdot
.952 .13233 Mdot
.952 .13503 Mdot
.952 .14149 Mdot
.952 .14199 Mdot
.952 .14252 Mdot
.952 .14274 Mdot
.952 .15044 Mdot
.952 .15494 Mdot
.952 .15837 Mdot
.952 .16916 Mdot
.952 .17058 Mdot
.952 .17614 Mdot
.952 .17766 Mdot
.952 .17835 Mdot
.952 .17931 Mdot
.952 .18326 Mdot
.952 .18483 Mdot
.952 .18502 Mdot
.952 .18629 Mdot
.952 .18661 Mdot
.952 .19573 Mdot
.952 .19732 Mdot
.952 .20575 Mdot
.952 .20955 Mdot
.952 .21072 Mdot
.952 .21178 Mdot
.952 .21313 Mdot
.952 .21612 Mdot
.952 .22235 Mdot
.952 .22315 Mdot
.952 .2238 Mdot
.952 .22515 Mdot
.952 .23057 Mdot
.952 .23143 Mdot
.952 .23987 Mdot
.952 .24128 Mdot
.952 .24375 Mdot
.952 .24416 Mdot
.952 .2463 Mdot
.952 .25137 Mdot
.952 .25154 Mdot
.952 .25617 Mdot
.952 .25687 Mdot
.952 .25903 Mdot
.952 .26111 Mdot
.952 .26468 Mdot
.952 .26578 Mdot
.952 .26622 Mdot
.952 .26696 Mdot
.952 .27148 Mdot
.952 .27623 Mdot
.952 .27826 Mdot
.952 .28108 Mdot
.952 .29023 Mdot
.952 .29126 Mdot
.952 .29576 Mdot
.952 .29976 Mdot
.952 .30148 Mdot
.952 .30148 Mdot
.952 .30148 Mdot
.952 .30148 Mdot
.952 .30149 Mdot
.952 .30151 Mdot
.952 .30153 Mdot
.952 .30153 Mdot
.952 .30154 Mdot
.952 .30156 Mdot
.952 .30156 Mdot
.952 .30157 Mdot
.952 .30159 Mdot
.952 .30162 Mdot
.952 .30163 Mdot
.952 .30165 Mdot
.952 .30168 Mdot
.952 .30169 Mdot
.952 .30173 Mdot
.952 .30173 Mdot
.952 .30191 Mdot
.952 .30194 Mdot
.952 .30202 Mdot
.952 .30207 Mdot
.952 .30208 Mdot
.952 .30209 Mdot
.952 .30216 Mdot
.952 .30222 Mdot
.952 .30226 Mdot
.952 .30229 Mdot
.952 .30232 Mdot
.952 .3024 Mdot
.952 .30241 Mdot
.952 .30242 Mdot
.952 .30258 Mdot
.952 .30268 Mdot
.952 .30281 Mdot
.952 .30309 Mdot
.952 .30315 Mdot
.952 .30318 Mdot
.952 .30346 Mdot
.952 .30356 Mdot
.952 .30364 Mdot
.952 .3037 Mdot
.952 .30385 Mdot
.952 .30393 Mdot
.952 .30399 Mdot
.952 .30404 Mdot
.952 .30407 Mdot
.952 .3042 Mdot
.952 .30427 Mdot
.952 .30441 Mdot
.952 .30452 Mdot
.952 .30466 Mdot
.952 .30483 Mdot
.952 .30496 Mdot
.952 .30501 Mdot
.952 .30519 Mdot
.952 .3052 Mdot
.952 .30539 Mdot
.952 .30542 Mdot
.952 .3058 Mdot
.952 .30592 Mdot
.952 .30593 Mdot
.952 .30596 Mdot
.952 .306 Mdot
.952 .30605 Mdot
.952 .30614 Mdot
.952 .30618 Mdot
.952 .3063 Mdot
.952 .30652 Mdot
.952 .30657 Mdot
.952 .3068 Mdot
.952 .3069 Mdot
.952 .30699 Mdot
.952 .30717 Mdot
.952 .30725 Mdot
.952 .30728 Mdot
.952 .30753 Mdot
.952 .3076 Mdot
.952 .30771 Mdot
.952 .30775 Mdot
.952 .30805 Mdot
.952 .30813 Mdot
.952 .30815 Mdot
.952 .3082 Mdot
.952 .30826 Mdot
.952 .30843 Mdot
.952 .30845 Mdot
.952 .30855 Mdot
.952 .30865 Mdot
.952 .30894 Mdot
.952 .30904 Mdot
.952 .30905 Mdot
.952 .30905 Mdot
.952 .30922 Mdot
.952 .30946 Mdot
.952 .30949 Mdot
.952 .30958 Mdot
.952 .30965 Mdot
.952 .30975 Mdot
.952 .30999 Mdot
.952 .31052 Mdot
.952 .31061 Mdot
.952 .31068 Mdot
.952 .31072 Mdot
.952 .31088 Mdot
.952 .31089 Mdot
.952 .31153 Mdot
.952 .3118 Mdot
.952 .3122 Mdot
.952 .31232 Mdot
.952 .31255 Mdot
.952 .31273 Mdot
.952 .31274 Mdot
.952 .31309 Mdot
.952 .3131 Mdot
.952 .31312 Mdot
.952 .31314 Mdot
.952 .31318 Mdot
.952 .31325 Mdot
.952 .31335 Mdot
.952 .31346 Mdot
.952 .31355 Mdot
.952 .31365 Mdot
.952 .31366 Mdot
.952 .31379 Mdot
.952 .31385 Mdot
.952 .314 Mdot
.952 .31402 Mdot
.952 .31411 Mdot
.952 .31415 Mdot
.952 .31429 Mdot
.952 .31433 Mdot
.952 .31433 Mdot
.952 .31448 Mdot
.952 .31451 Mdot
.952 .31454 Mdot
.952 .31465 Mdot
.952 .31483 Mdot
.952 .31495 Mdot
.952 .31515 Mdot
.952 .31538 Mdot
.952 .31551 Mdot
.952 .31551 Mdot
.952 .31561 Mdot
.952 .31562 Mdot
.952 .31568 Mdot
.952 .31577 Mdot
.952 .31582 Mdot
.952 .31587 Mdot
.952 .3159 Mdot
.952 .31591 Mdot
.952 .316 Mdot
.952 .31601 Mdot
.952 .31605 Mdot
.952 .31618 Mdot
.952 .31624 Mdot
.952 .31627 Mdot
.952 .31627 Mdot
.952 .31637 Mdot
.952 .31638 Mdot
.952 .3164 Mdot
.952 .31656 Mdot
.952 .3166 Mdot
.952 .31661 Mdot
.952 .31661 Mdot
.952 .31661 Mdot
.952 .31664 Mdot
.952 .31679 Mdot
.952 .3168 Mdot
.952 .3168 Mdot
.952 .31681 Mdot
.952 .31693 Mdot
.952 .31752 Mdot
.952 .31759 Mdot
.952 .31759 Mdot
.952 .3176 Mdot
.952 .31809 Mdot
.952 .31953 Mdot
.952 .32065 Mdot
.952 .32094 Mdot
.952 .32096 Mdot
.952 .32099 Mdot
.952 .32231 Mdot
.952 .32247 Mdot
.952 .32271 Mdot
.952 .32277 Mdot
.952 .32325 Mdot
.952 .32409 Mdot
.952 .32445 Mdot
.952 .33044 Mdot
.952 .33666 Mdot
.952 .33808 Mdot
.952 .33838 Mdot
.952 .33852 Mdot
.952 .33871 Mdot
.952 .34666 Mdot
.952 .34688 Mdot
.952 .34777 Mdot
.952 .34791 Mdot
.952 .34949 Mdot
.952 .34988 Mdot
.952 .34994 Mdot
.952 .35312 Mdot
.952 .35707 Mdot
.952 .35831 Mdot
.952 .35902 Mdot
.952 .35989 Mdot
.952 .36026 Mdot
.952 .36158 Mdot
.952 .36161 Mdot
.952 .36162 Mdot
.952 .36548 Mdot
.952 .36689 Mdot
.952 .36768 Mdot
.952 .37421 Mdot
.952 .37922 Mdot
.952 .38711 Mdot
.952 .38756 Mdot
.952 .39057 Mdot
.952 .39392 Mdot
.952 .39452 Mdot
.952 .39734 Mdot
.952 .40357 Mdot
.952 .40878 Mdot
.952 .40991 Mdot
.952 .41108 Mdot
.952 .41158 Mdot
.952 .41588 Mdot
.952 .4261 Mdot
.952 .42842 Mdot
.952 .43174 Mdot
.952 .43789 Mdot
.952 .44492 Mdot
.952 .46603 Mdot
.952 .46868 Mdot
.952 .47336 Mdot
.952 .47884 Mdot
.952 .48154 Mdot
.952 .48275 Mdot
.952 .48443 Mdot
.952 .48589 Mdot
.952 .49123 Mdot
.952 .49387 Mdot
.952 .49419 Mdot
.952 .49629 Mdot
.952 .49629 Mdot
.952 .49683 Mdot
.952 .50171 Mdot
.952 .50541 Mdot
.952 .51128 Mdot
.952 .5137 Mdot
.952 .52081 Mdot
.952 .5259 Mdot
.952 .52686 Mdot
.952 .52755 Mdot
.952 .52916 Mdot
.952 .53068 Mdot
.952 .53108 Mdot
.952 .53263 Mdot
.952 .53404 Mdot
.952 .53579 Mdot
.952 .5375 Mdot
.952 .53958 Mdot
.952 .54516 Mdot
.952 .54711 Mdot
.952 .54804 Mdot
.952 .54846 Mdot
.952 .54879 Mdot
.952 .54915 Mdot
.952 .55033 Mdot
.952 .55291 Mdot
.952 .55615 Mdot
.952 .55625 Mdot
.952 .55663 Mdot
.952 .55715 Mdot
.952 .5645 Mdot
.952 .56549 Mdot
.952 .56679 Mdot
.952 .569 Mdot
.952 .56907 Mdot
.952 .56936 Mdot
.952 .5712 Mdot
.952 .5745 Mdot
.952 .57512 Mdot
.952 .5753 Mdot
.952 .57544 Mdot
.952 .57621 Mdot
.952 .57887 Mdot
.952 .57904 Mdot
.952 .57905 Mdot
.952 .57907 Mdot
.952 .57937 Mdot
.952 .58 Mdot
.952 .58025 Mdot
.952 .58084 Mdot
.952 .58085 Mdot
.952 .58131 Mdot
.952 .58213 Mdot
.952 .58222 Mdot
.952 .58444 Mdot
.952 .58458 Mdot
.952 .58509 Mdot
.952 .58534 Mdot
.952 .58576 Mdot
.952 .58639 Mdot
.952 .58643 Mdot
.952 .58664 Mdot
.952 .58749 Mdot
.952 .58756 Mdot
.952 .58802 Mdot
.952 .58813 Mdot
.952 .58819 Mdot
.952 .59043 Mdot
.952 .5913 Mdot
.952 .59174 Mdot
.952 .59181 Mdot
.952 .59186 Mdot
.952 .59198 Mdot
.952 .59242 Mdot
.952 .59252 Mdot
.952 .59458 Mdot
.952 .59529 Mdot
.952 .59555 Mdot
.952 .59607 Mdot
.952 .59614 Mdot
.952 .59631 Mdot
.952 .5964 Mdot
.952 .59641 Mdot
.952 .59645 Mdot
.952 .59648 Mdot
.952 .59649 Mdot
.952 .5967 Mdot
.952 .59671 Mdot
.952 .59671 Mdot
.952 .59676 Mdot
.952 .59692 Mdot
.952 .59709 Mdot
.952 .59711 Mdot
.952 .59717 Mdot
.952 .59717 Mdot
.952 .59717 Mdot
.952 .59718 Mdot
.952 .59725 Mdot
.952 .59726 Mdot
.952 .59726 Mdot
.952 .59726 Mdot
.952 .59726 Mdot
.952 .59728 Mdot
.952 .59728 Mdot
.952 .59728 Mdot
.952 .59728 Mdot
.952 .59728 Mdot
.952 .59729 Mdot
.952 .59729 Mdot
.952 .59729 Mdot
.952 .59729 Mdot
.952 .59729 Mdot
.952 .59729 Mdot
.952 .59729 Mdot
.952 .59729 Mdot
.952 .59729 Mdot
.952 .59729 Mdot
.952 .59729 Mdot
.952 .59729 Mdot
.952 .5973 Mdot
.952 .5973 Mdot
.952 .5973 Mdot
.952 .5973 Mdot
.952 .5973 Mdot
.952 .5973 Mdot
.952 .5973 Mdot
.952 .59731 Mdot
.952 .59731 Mdot
.952 .59731 Mdot
.952 .59731 Mdot
.952 .59731 Mdot
.952 .59731 Mdot
.952 .59731 Mdot
.952 .59732 Mdot
.952 .59732 Mdot
.952 .59733 Mdot
.952 .59733 Mdot
.952 .59734 Mdot
.952 .59734 Mdot
.952 .59734 Mdot
.952 .59734 Mdot
.952 .59734 Mdot
.952 .59734 Mdot
.952 .59735 Mdot
.952 .59735 Mdot
.952 .59735 Mdot
.952 .59735 Mdot
.952 .59735 Mdot
.952 .59736 Mdot
.952 .59736 Mdot
.952 .59736 Mdot
.952 .59736 Mdot
.952 .59736 Mdot
.952 .59737 Mdot
.952 .59737 Mdot
.952 .59737 Mdot
.952 .59737 Mdot
.952 .59738 Mdot
.952 .59738 Mdot
.952 .59738 Mdot
.952 .59739 Mdot
.952 .59739 Mdot
.952 .59739 Mdot
.952 .5974 Mdot
.952 .5974 Mdot
.952 .59741 Mdot
.952 .59742 Mdot
.952 .59743 Mdot
.952 .59743 Mdot
.952 .59744 Mdot
.952 .59744 Mdot
.952 .59744 Mdot
.952 .59745 Mdot
.952 .59746 Mdot
.952 .59746 Mdot
.952 .59747 Mdot
.952 .59747 Mdot
.952 .59747 Mdot
.952 .59747 Mdot
.952 .59748 Mdot
.952 .59748 Mdot
.952 .59748 Mdot
.952 .59748 Mdot
.952 .59749 Mdot
.952 .59749 Mdot
.952 .59749 Mdot
.952 .59749 Mdot
.952 .5975 Mdot
.952 .5975 Mdot
.952 .5975 Mdot
.952 .5975 Mdot
.952 .5975 Mdot
.952 .59751 Mdot
.952 .59751 Mdot
.952 .59752 Mdot
.952 .59752 Mdot
.952 .59752 Mdot
.952 .59752 Mdot
.952 .59753 Mdot
.952 .59753 Mdot
.952 .59753 Mdot
.952 .59754 Mdot
.952 .59754 Mdot
.952 .59754 Mdot
.952 .59755 Mdot
.952 .59755 Mdot
.952 .59755 Mdot
.952 .59755 Mdot
.952 .59756 Mdot
.952 .59756 Mdot
.952 .59756 Mdot
.952 .59756 Mdot
.952 .59756 Mdot
.952 .59757 Mdot
.952 .59757 Mdot
.952 .59758 Mdot
.952 .59758 Mdot
.952 .59758 Mdot
.952 .59758 Mdot
.952 .59758 Mdot
.952 .5976 Mdot
.952 .5976 Mdot
.952 .5976 Mdot
.952 .5976 Mdot
.952 .5976 Mdot
.952 .59761 Mdot
.952 .59761 Mdot
.952 .59761 Mdot
.952 .59761 Mdot
.952 .59761 Mdot
.952 .59762 Mdot
.952 .59762 Mdot
.952 .59763 Mdot
.952 .59763 Mdot
.952 .59763 Mdot
.952 .59764 Mdot
.952 .59764 Mdot
.952 .59764 Mdot
.952 .59765 Mdot
.952 .59765 Mdot
.952 .59765 Mdot
.952 .59765 Mdot
.952 .59765 Mdot
.952 .59765 Mdot
.952 .59765 Mdot
.952 .59765 Mdot
.952 .59765 Mdot
.952 .59765 Mdot
.952 .59766 Mdot
.952 .59766 Mdot
.952 .59766 Mdot
.952 .59766 Mdot
.952 .59766 Mdot
.952 .59766 Mdot
.952 .59766 Mdot
.952 .59766 Mdot
.952 .59766 Mdot
.952 .59767 Mdot
.952 .59767 Mdot
.952 .59767 Mdot
.952 .59767 Mdot
.952 .59767 Mdot
.952 .59767 Mdot
.952 .59767 Mdot
.952 .59767 Mdot
.952 .59767 Mdot
.952 .59767 Mdot
.952 .59767 Mdot
.952 .59767 Mdot
.952 .59767 Mdot
.952 .59767 Mdot
.954 .03598 Mdot
.954 .03599 Mdot
.954 .03599 Mdot
.954 .03599 Mdot
.954 .03599 Mdot
.954 .03599 Mdot
.954 .036 Mdot
.954 .03601 Mdot
.954 .03601 Mdot
.954 .03603 Mdot
.954 .03605 Mdot
.954 .03608 Mdot
.954 .03609 Mdot
.954 .0361 Mdot
.954 .03621 Mdot
.954 .03624 Mdot
.954 .03632 Mdot
.954 .03637 Mdot
.954 .03651 Mdot
.954 .03652 Mdot
.954 .03666 Mdot
.954 .03666 Mdot
.954 .03696 Mdot
.954 .037 Mdot
.954 .0371 Mdot
.954 .03716 Mdot
.954 .03722 Mdot
.954 .0373 Mdot
.954 .03745 Mdot
.954 .03752 Mdot
.954 .03754 Mdot
.954 .03758 Mdot
.954 .0378 Mdot
.954 .03781 Mdot
.954 .03805 Mdot
.954 .03834 Mdot
.954 .03837 Mdot
.954 .03842 Mdot
.954 .03842 Mdot
.954 .03863 Mdot
.954 .03865 Mdot
.954 .03887 Mdot
.954 .03889 Mdot
.954 .03893 Mdot
.954 .03909 Mdot
.954 .03918 Mdot
.954 .03928 Mdot
.954 .03942 Mdot
.954 .03964 Mdot
.954 .03993 Mdot
.954 .04015 Mdot
.954 .04017 Mdot
.954 .04028 Mdot
.954 .04039 Mdot
.954 .04039 Mdot
.954 .04056 Mdot
.954 .04069 Mdot
.954 .04086 Mdot
.954 .04109 Mdot
.954 .04125 Mdot
.954 .04132 Mdot
.954 .04136 Mdot
.954 .04148 Mdot
.954 .04185 Mdot
.954 .04215 Mdot
.954 .04229 Mdot
.954 .04237 Mdot
.954 .04243 Mdot
.954 .04256 Mdot
.954 .04274 Mdot
.954 .04283 Mdot
.954 .04307 Mdot
.954 .04309 Mdot
.954 .04316 Mdot
.954 .0432 Mdot
.954 .04322 Mdot
.954 .04322 Mdot
.954 .04324 Mdot
.954 .04326 Mdot
.954 .04334 Mdot
.954 .04342 Mdot
.954 .04371 Mdot
.954 .04373 Mdot
.954 .04398 Mdot
.954 .04431 Mdot
.954 .04462 Mdot
.954 .04556 Mdot
.954 .04604 Mdot
.954 .04621 Mdot
.954 .04677 Mdot
.954 .04693 Mdot
.954 .04735 Mdot
.954 .04737 Mdot
.954 .04743 Mdot
.954 .04905 Mdot
.954 .04938 Mdot
.954 .04974 Mdot
.954 .05 Mdot
.954 .05032 Mdot
.954 .0526 Mdot
.954 .05288 Mdot
.954 .05415 Mdot
.954 .05437 Mdot
.954 .05448 Mdot
.954 .05498 Mdot
.954 .05565 Mdot
.954 .05576 Mdot
.954 .05581 Mdot
.954 .05623 Mdot
.954 .05732 Mdot
.954 .05769 Mdot
.954 .05825 Mdot
.954 .05878 Mdot
.954 .06007 Mdot
.954 .06047 Mdot
.954 .06271 Mdot
.954 .06289 Mdot
.954 .06313 Mdot
.954 .06355 Mdot
.954 .06359 Mdot
.954 .06361 Mdot
.954 .06451 Mdot
.954 .06482 Mdot
.954 .0658 Mdot
.954 .06641 Mdot
.954 .06765 Mdot
.954 .06826 Mdot
.954 .06905 Mdot
.954 .06933 Mdot
.954 .07035 Mdot
.954 .07065 Mdot
.954 .07067 Mdot
.954 .07103 Mdot
.954 .07126 Mdot
.954 .07218 Mdot
.954 .07238 Mdot
.954 .07306 Mdot
.954 .07386 Mdot
.954 .07539 Mdot
.954 .07955 Mdot
.954 .07965 Mdot
.954 .07996 Mdot
.954 .08433 Mdot
.954 .08584 Mdot
.954 .08607 Mdot
.954 .08636 Mdot
.954 .08759 Mdot
.954 .0876 Mdot
.954 .08885 Mdot
.954 .08957 Mdot
.954 .09048 Mdot
.954 .09058 Mdot
.954 .09114 Mdot
.954 .09184 Mdot
.954 .09466 Mdot
.954 .09594 Mdot
.954 .09598 Mdot
.954 .09599 Mdot
.954 .096 Mdot
.954 .096 Mdot
.954 .096 Mdot
.954 .09602 Mdot
.954 .09605 Mdot
.954 .09605 Mdot
.954 .09615 Mdot
.954 .09619 Mdot
.954 .09632 Mdot
.954 .09635 Mdot
.954 .09638 Mdot
.954 .09681 Mdot
.954 .09692 Mdot
.954 .09718 Mdot
.954 .0974 Mdot
.954 .09789 Mdot
.954 .09795 Mdot
.954 .09829 Mdot
.954 .09844 Mdot
.954 .09844 Mdot
.954 .09848 Mdot
.954 .09935 Mdot
.954 .09955 Mdot
.954 .0997 Mdot
.954 .10006 Mdot
.954 .10027 Mdot
.954 .10049 Mdot
.954 .1006 Mdot
.954 .1008 Mdot
.954 .10135 Mdot
.954 .1016 Mdot
.954 .10166 Mdot
.954 .10182 Mdot
.954 .10212 Mdot
.954 .1022 Mdot
.954 .10262 Mdot
.954 .10265 Mdot
.954 .10353 Mdot
.954 .10459 Mdot
.954 .10471 Mdot
.954 .10489 Mdot
.954 .1049 Mdot
.954 .10565 Mdot
.954 .10569 Mdot
.954 .10573 Mdot
.954 .10617 Mdot
.954 .10634 Mdot
.954 .10653 Mdot
.954 .10659 Mdot
.954 .10659 Mdot
.954 .10675 Mdot
.954 .10733 Mdot
.954 .10765 Mdot
.954 .10803 Mdot
.954 .10815 Mdot
.954 .10815 Mdot
.954 .10826 Mdot
.954 .10839 Mdot
.954 .10851 Mdot
.954 .10911 Mdot
.954 .10931 Mdot
.954 .10951 Mdot
.954 .10954 Mdot
.954 .11007 Mdot
.954 .11029 Mdot
.954 .11038 Mdot
.954 .11048 Mdot
.954 .11115 Mdot
.954 .11123 Mdot
.954 .11165 Mdot
.954 .11203 Mdot
.954 .11204 Mdot
.954 .11253 Mdot
.954 .11267 Mdot
.954 .11312 Mdot
.954 .11374 Mdot
.954 .11444 Mdot
.954 .11457 Mdot
.954 .11514 Mdot
.954 .11541 Mdot
.954 .11555 Mdot
.954 .11596 Mdot
.954 .11612 Mdot
.954 .11729 Mdot
.954 .11809 Mdot
.954 .11836 Mdot
.954 .1184 Mdot
.954 .11888 Mdot
.954 .11916 Mdot
.954 .11939 Mdot
.954 .11986 Mdot
.954 .12048 Mdot
.954 .12082 Mdot
.954 .12162 Mdot
.954 .12169 Mdot
.954 .12176 Mdot
.954 .12201 Mdot
.954 .12203 Mdot
.954 .12214 Mdot
.954 .1222 Mdot
.954 .12221 Mdot
.954 .12229 Mdot
.954 .12235 Mdot
.954 .12265 Mdot
.954 .12294 Mdot
.954 .12318 Mdot
.954 .12398 Mdot
.954 .12404 Mdot
.954 .12492 Mdot
.954 .12611 Mdot
.954 .12646 Mdot
.954 .1272 Mdot
.954 .12818 Mdot
.954 .12833 Mdot
.954 .13057 Mdot
.954 .13142 Mdot
.954 .13228 Mdot
.954 .13285 Mdot
.954 .13471 Mdot
.954 .13484 Mdot
.954 .13542 Mdot
.954 .1369 Mdot
.954 .13696 Mdot
.954 .137 Mdot
.954 .13717 Mdot
.954 .13797 Mdot
.954 .1393 Mdot
.954 .13961 Mdot
.954 .14225 Mdot
.954 .14284 Mdot
.954 .1432 Mdot
.954 .144 Mdot
.954 .14526 Mdot
.954 .14526 Mdot
.954 .14589 Mdot
.954 .14619 Mdot
.954 .14628 Mdot
.954 .14686 Mdot
.954 .14715 Mdot
.954 .14731 Mdot
.954 .15281 Mdot
.954 .15401 Mdot
.954 .15519 Mdot
.954 .15617 Mdot
.954 .15775 Mdot
.954 .15869 Mdot
.954 .16052 Mdot
.954 .16129 Mdot
.954 .16167 Mdot
.954 .16171 Mdot
.954 .16337 Mdot
.954 .16569 Mdot
.954 .16604 Mdot
.954 .16623 Mdot
.954 .16764 Mdot
.954 .16904 Mdot
.954 .17131 Mdot
.954 .17137 Mdot
.954 .17193 Mdot
.954 .17261 Mdot
.954 .1745 Mdot
.954 .17628 Mdot
.954 .1763 Mdot
.954 .17887 Mdot
.954 .17911 Mdot
.954 .18063 Mdot
.954 .18197 Mdot
.954 .18601 Mdot
.954 .18618 Mdot
.954 .18943 Mdot
.954 .19002 Mdot
.954 .1908 Mdot
.954 .19085 Mdot
.954 .19221 Mdot
.954 .19232 Mdot
.954 .19241 Mdot
.954 .19337 Mdot
.954 .1938 Mdot
.954 .19537 Mdot
.954 .1964 Mdot
.954 .19857 Mdot
.954 .19908 Mdot
.954 .1996 Mdot
.954 .20045 Mdot
.954 .20161 Mdot
.954 .20214 Mdot
.954 .20227 Mdot
.954 .2036 Mdot
.954 .20563 Mdot
.954 .20679 Mdot
.954 .20761 Mdot
.954 .20779 Mdot
.954 .20787 Mdot
.954 .21017 Mdot
.954 .21109 Mdot
.954 .21138 Mdot
.954 .21217 Mdot
.954 .2129 Mdot
.954 .21292 Mdot
.954 .21436 Mdot
.954 .21464 Mdot
.954 .21533 Mdot
.954 .2154 Mdot
.954 .21656 Mdot
.954 .2173 Mdot
.954 .22024 Mdot
.954 .22047 Mdot
.954 .22088 Mdot
.954 .22103 Mdot
.954 .22258 Mdot
.954 .22304 Mdot
.954 .22346 Mdot
.954 .22442 Mdot
.954 .22556 Mdot
.954 .22593 Mdot
.954 .22642 Mdot
.954 .2268 Mdot
.954 .22827 Mdot
.954 .23041 Mdot
.954 .23471 Mdot
.954 .23538 Mdot
.954 .23758 Mdot
.954 .2421 Mdot
.954 .24219 Mdot
.954 .24238 Mdot
.954 .2425 Mdot
.954 .24337 Mdot
.954 .24367 Mdot
.954 .24464 Mdot
.954 .24508 Mdot
.954 .24616 Mdot
.954 .24727 Mdot
.954 .25011 Mdot
.954 .25184 Mdot
.954 .25193 Mdot
.954 .25482 Mdot
.954 .25795 Mdot
.954 .25798 Mdot
.954 .2591 Mdot
.954 .25953 Mdot
.954 .26254 Mdot
.954 .26278 Mdot
.954 .26322 Mdot
.954 .26409 Mdot
.954 .2641 Mdot
.954 .26465 Mdot
.954 .26777 Mdot
.954 .26782 Mdot
.954 .27142 Mdot
.954 .27153 Mdot
.954 .27202 Mdot
.954 .27233 Mdot
.954 .27306 Mdot
.954 .27365 Mdot
.954 .27399 Mdot
.954 .27633 Mdot
.954 .27635 Mdot
.954 .27637 Mdot
.954 .27662 Mdot
.954 .27677 Mdot
.954 .27827 Mdot
.954 .27936 Mdot
.954 .28033 Mdot
.954 .28109 Mdot
.954 .28257 Mdot
.954 .28851 Mdot
.954 .28937 Mdot
.954 .28984 Mdot
.954 .29222 Mdot
.954 .29232 Mdot
.954 .29234 Mdot
.954 .29236 Mdot
.954 .29237 Mdot
.954 .29239 Mdot
.954 .29243 Mdot
.954 .29251 Mdot
.954 .29253 Mdot
.954 .29282 Mdot
.954 .29293 Mdot
.954 .2933 Mdot
.954 .29338 Mdot
.954 .29347 Mdot
.954 .29471 Mdot
.954 .29481 Mdot
.954 .29503 Mdot
.954 .29534 Mdot
.954 .29577 Mdot
.954 .29639 Mdot
.954 .29755 Mdot
.954 .29777 Mdot
.954 .29795 Mdot
.954 .29847 Mdot
.954 .29891 Mdot
.954 .29934 Mdot
.954 .29935 Mdot
.954 .29945 Mdot
.954 .30012 Mdot
.954 .3013 Mdot
.954 .30134 Mdot
.954 .3019 Mdot
.954 .3023 Mdot
.954 .30247 Mdot
.954 .30277 Mdot
.954 .30289 Mdot
.954 .30392 Mdot
.954 .30452 Mdot
.954 .30512 Mdot
.954 .30542 Mdot
.954 .30582 Mdot
.954 .30601 Mdot
.954 .30704 Mdot
.954 .30754 Mdot
.954 .30798 Mdot
.954 .30823 Mdot
.954 .30828 Mdot
.954 .3084 Mdot
.954 .30885 Mdot
.954 .30969 Mdot
.954 .30976 Mdot
.954 .3099 Mdot
.954 .31009 Mdot
.954 .31063 Mdot
.954 .31107 Mdot
.954 .31115 Mdot
.954 .31359 Mdot
.954 .31412 Mdot
.954 .3159 Mdot
.954 .31652 Mdot
.954 .31684 Mdot
.954 .31736 Mdot
.954 .31738 Mdot
.954 .31852 Mdot
.954 .31909 Mdot
.954 .31944 Mdot
.954 .31954 Mdot
.954 .31965 Mdot
.954 .31993 Mdot
.954 .32085 Mdot
.954 .32131 Mdot
.954 .32168 Mdot
.954 .32185 Mdot
.954 .322 Mdot
.954 .32201 Mdot
.954 .32244 Mdot
.954 .32337 Mdot
.954 .32353 Mdot
.954 .32401 Mdot
.954 .32439 Mdot
.954 .32489 Mdot
.954 .3259 Mdot
.954 .32623 Mdot
.954 .32625 Mdot
.954 .32652 Mdot
.954 .32688 Mdot
.954 .32721 Mdot
.954 .32882 Mdot
.954 .32936 Mdot
.954 .32991 Mdot
.954 .32992 Mdot
.954 .32998 Mdot
.954 .33142 Mdot
.954 .3317 Mdot
.954 .33201 Mdot
.954 .33223 Mdot
.954 .3325 Mdot
.954 .3343 Mdot
.954 .33452 Mdot
.954 .33562 Mdot
.954 .33571 Mdot
.954 .33606 Mdot
.954 .33655 Mdot
.954 .33662 Mdot
.954 .33666 Mdot
.954 .33795 Mdot
.954 .33832 Mdot
.954 .33951 Mdot
.954 .34116 Mdot
.954 .34223 Mdot
.954 .34242 Mdot
.954 .34299 Mdot
.954 .34334 Mdot
.954 .34482 Mdot
.954 .34552 Mdot
.954 .34569 Mdot
.954 .34589 Mdot
.954 .34696 Mdot
.954 .34738 Mdot
.954 .34816 Mdot
.954 .35041 Mdot
.954 .35246 Mdot
.954 .35315 Mdot
.954 .35325 Mdot
.954 .3545 Mdot
.954 .35521 Mdot
.954 .3558 Mdot
.954 .357 Mdot
.954 .35858 Mdot
.954 .35944 Mdot
.954 .36145 Mdot
.954 .36164 Mdot
.954 .3617 Mdot
.954 .3618 Mdot
.954 .3624 Mdot
.954 .3624 Mdot
.954 .36244 Mdot
.954 .36249 Mdot
.954 .36277 Mdot
.954 .36292 Mdot
.954 .36293 Mdot
.954 .36313 Mdot
.954 .36329 Mdot
.954 .36406 Mdot
.954 .36477 Mdot
.954 .36538 Mdot
.954 .36737 Mdot
.954 .36751 Mdot
.954 .36906 Mdot
.954 .36966 Mdot
.954 .36971 Mdot
.954 .37264 Mdot
.954 .3735 Mdot
.954 .37533 Mdot
.954 .37772 Mdot
.954 .37809 Mdot
.954 .37925 Mdot
.954 .37954 Mdot
.954 .38351 Mdot
.954 .38478 Mdot
.954 .38553 Mdot
.954 .3856 Mdot
.954 .38758 Mdot
.954 .38894 Mdot
.954 .38965 Mdot
.954 .39109 Mdot
.954 .39207 Mdot
.954 .39334 Mdot
.954 .39363 Mdot
.954 .39479 Mdot
.954 .39499 Mdot
.954 .39805 Mdot
.954 .39844 Mdot
.954 .39857 Mdot
.954 .39867 Mdot
.954 .39905 Mdot
.954 .4009 Mdot
.954 .40266 Mdot
.954 .40274 Mdot
.954 .40395 Mdot
.954 .40468 Mdot
.954 .40705 Mdot
.954 .40819 Mdot
.954 .40833 Mdot
.954 .41002 Mdot
.954 .41065 Mdot
.954 .41124 Mdot
.954 .41134 Mdot
.954 .41198 Mdot
.954 .41277 Mdot
.954 .41455 Mdot
.954 .41705 Mdot
.954 .41734 Mdot
.954 .41735 Mdot
.954 .41769 Mdot
.954 .41873 Mdot
.954 .41903 Mdot
.954 .41939 Mdot
.954 .41959 Mdot
.954 .42044 Mdot
.954 .42087 Mdot
.954 .4215 Mdot
.954 .42184 Mdot
.954 .42226 Mdot
.954 .4227 Mdot
.954 .42291 Mdot
.954 .43202 Mdot
.954 .43362 Mdot
.954 .43376 Mdot
.954 .43613 Mdot
.954 .4376 Mdot
.954 .43857 Mdot
.954 .43982 Mdot
.954 .44061 Mdot
.954 .44281 Mdot
.954 .44309 Mdot
.954 .44312 Mdot
.954 .44384 Mdot
.954 .44386 Mdot
.954 .44527 Mdot
.954 .44576 Mdot
.954 .44656 Mdot
.954 .44943 Mdot
.954 .45096 Mdot
.954 .45172 Mdot
.954 .45179 Mdot
.954 .45268 Mdot
.954 .45425 Mdot
.954 .45508 Mdot
.954 .45588 Mdot
.954 .45894 Mdot
.954 .45958 Mdot
.954 .46027 Mdot
.954 .46063 Mdot
.954 .46065 Mdot
.954 .46079 Mdot
.954 .46224 Mdot
.954 .46332 Mdot
.954 .46515 Mdot
.954 .46598 Mdot
.954 .47023 Mdot
.954 .47033 Mdot
.954 .47053 Mdot
.954 .47137 Mdot
.954 .47201 Mdot
.954 .47262 Mdot
.954 .47291 Mdot
.954 .47547 Mdot
.954 .47552 Mdot
.954 .47606 Mdot
.954 .47681 Mdot
.954 .47687 Mdot
.954 .47738 Mdot
.954 .47927 Mdot
.954 .4793 Mdot
.954 .4813 Mdot
.954 .4827 Mdot
.954 .48386 Mdot
.954 .48428 Mdot
.954 .48489 Mdot
.954 .48659 Mdot
.954 .48693 Mdot
.954 .4891 Mdot
.954 .48922 Mdot
.954 .49313 Mdot
.954 .49337 Mdot
.954 .49604 Mdot
.954 .49604 Mdot
.954 .49631 Mdot
.954 .50161 Mdot
.954 .50256 Mdot
.954 .50381 Mdot
.954 .50388 Mdot
.954 .50603 Mdot
.954 .50622 Mdot
.954 .50635 Mdot
.954 .50785 Mdot
.954 .50852 Mdot
.954 .51056 Mdot
.954 .51088 Mdot
.954 .51094 Mdot
.954 .51156 Mdot
.954 .5122 Mdot
.954 .51251 Mdot
.954 .51272 Mdot
.954 .51367 Mdot
.954 .51431 Mdot
.954 .51557 Mdot
.954 .51577 Mdot
.954 .51588 Mdot
.954 .51642 Mdot
.954 .51652 Mdot
.954 .51686 Mdot
.954 .51729 Mdot
.954 .51838 Mdot
.954 .51855 Mdot
.954 .51889 Mdot
.954 .5189 Mdot
.954 .51932 Mdot
.954 .5199 Mdot
.954 .52022 Mdot
.954 .521 Mdot
.954 .52118 Mdot
.954 .52291 Mdot
.954 .52308 Mdot
.954 .52542 Mdot
.954 .52593 Mdot
.954 .52653 Mdot
.954 .52741 Mdot
.954 .52754 Mdot
.954 .52755 Mdot
.954 .52835 Mdot
.954 .52866 Mdot
.954 .52891 Mdot
.954 .52902 Mdot
.954 .52922 Mdot
.954 .53149 Mdot
.954 .53168 Mdot
.954 .53211 Mdot
.954 .53319 Mdot
.954 .53333 Mdot
.954 .53371 Mdot
.954 .53475 Mdot
.954 .53569 Mdot
.954 .53573 Mdot
.954 .53629 Mdot
.954 .53722 Mdot
.954 .53758 Mdot
.954 .53793 Mdot
.954 .53876 Mdot
.954 .5388 Mdot
.954 .53886 Mdot
.954 .53889 Mdot
.954 .54035 Mdot
.954 .54105 Mdot
.954 .54127 Mdot
.954 .54332 Mdot
.954 .54378 Mdot
.954 .5439 Mdot
.954 .54406 Mdot
.954 .54453 Mdot
.954 .54484 Mdot
.954 .54511 Mdot
.954 .5456 Mdot
.954 .54578 Mdot
.954 .5476 Mdot
.954 .54813 Mdot
.954 .54814 Mdot
.954 .54837 Mdot
.954 .54861 Mdot
.954 .5497 Mdot
.954 .54972 Mdot
.954 .55003 Mdot
.954 .55101 Mdot
.954 .55142 Mdot
.954 .55146 Mdot
.954 .55197 Mdot
.954 .55239 Mdot
.954 .55255 Mdot
.954 .554 Mdot
.954 .55413 Mdot
.954 .55489 Mdot
.954 .5563 Mdot
.954 .55635 Mdot
.954 .55841 Mdot
.954 .55848 Mdot
.954 .55925 Mdot
.954 .56054 Mdot
.954 .56072 Mdot
.954 .56139 Mdot
.954 .56354 Mdot
.954 .56442 Mdot
.954 .56469 Mdot
.954 .56578 Mdot
.954 .56612 Mdot
.954 .56775 Mdot
.954 .56784 Mdot
.954 .568 Mdot
.954 .56812 Mdot
.954 .5683 Mdot
.954 .56889 Mdot
.954 .56916 Mdot
.954 .56991 Mdot
.954 .57 Mdot
.954 .57038 Mdot
.954 .57065 Mdot
.954 .5713 Mdot
.954 .57223 Mdot
.954 .5731 Mdot
.954 .57314 Mdot
.954 .57363 Mdot
.954 .57454 Mdot
.954 .57486 Mdot
.954 .57498 Mdot
.954 .57589 Mdot
.954 .57596 Mdot
.954 .57651 Mdot
.954 .57698 Mdot
.954 .57751 Mdot
.954 .57807 Mdot
.954 .57812 Mdot
.954 .57818 Mdot
.954 .57833 Mdot
.954 .57834 Mdot
.954 .57845 Mdot
.954 .57865 Mdot
.954 .57869 Mdot
.954 .57871 Mdot
.954 .57872 Mdot
.954 .57914 Mdot
.954 .57921 Mdot
.954 .57926 Mdot
.954 .57939 Mdot
.954 .58035 Mdot
.954 .58037 Mdot
.954 .58079 Mdot
.954 .58113 Mdot
.954 .58136 Mdot
.954 .58142 Mdot
.954 .5824 Mdot
.954 .58317 Mdot
.954 .58336 Mdot
.954 .58351 Mdot
.954 .58354 Mdot
.954 .58378 Mdot
.954 .58398 Mdot
.954 .58431 Mdot
.954 .58432 Mdot
.954 .58465 Mdot
.954 .58473 Mdot
.954 .58479 Mdot
.954 .5852 Mdot
.954 .58637 Mdot
.954 .58645 Mdot
.954 .58648 Mdot
.954 .58759 Mdot
.954 .588 Mdot
.954 .58821 Mdot
.954 .58839 Mdot
.954 .58844 Mdot
.954 .58869 Mdot
.954 .58875 Mdot
.954 .58884 Mdot
.954 .58885 Mdot
.954 .58893 Mdot
.954 .5892 Mdot
.954 .58928 Mdot
.954 .58948 Mdot
.954 .58965 Mdot
.954 .58997 Mdot
.954 .59013 Mdot
.954 .59039 Mdot
.954 .59047 Mdot
.954 .59071 Mdot
.954 .59072 Mdot
.954 .59073 Mdot
.954 .59084 Mdot
.954 .5909 Mdot
.954 .59095 Mdot
.954 .59154 Mdot
.954 .59164 Mdot
.954 .59198 Mdot
.954 .59212 Mdot
.954 .59227 Mdot
.954 .59236 Mdot
.954 .59265 Mdot
.954 .59276 Mdot
.954 .59277 Mdot
.954 .5928 Mdot
.954 .59298 Mdot
.954 .59311 Mdot
.954 .59314 Mdot
.954 .5932 Mdot
.954 .59353 Mdot
.954 .5936 Mdot
.954 .59419 Mdot
.954 .59428 Mdot
.954 .59435 Mdot
.954 .59444 Mdot
.954 .59453 Mdot
.954 .59495 Mdot
.954 .59496 Mdot
.954 .59496 Mdot
.954 .59507 Mdot
.954 .59512 Mdot
.954 .59526 Mdot
.954 .5953 Mdot
.954 .59543 Mdot
.954 .59568 Mdot
.954 .59575 Mdot
.954 .59584 Mdot
.954 .5959 Mdot
.954 .59591 Mdot
.954 .59598 Mdot
.954 .596 Mdot
.954 .59603 Mdot
.954 .59603 Mdot
.954 .59604 Mdot
.954 .59604 Mdot
.954 .59604 Mdot
.954 .59605 Mdot
.954 .59607 Mdot
.954 .59607 Mdot
.954 .59614 Mdot
.954 .59616 Mdot
.954 .59621 Mdot
.954 .59624 Mdot
.954 .59626 Mdot
.954 .59628 Mdot
.954 .59631 Mdot
.954 .59639 Mdot
.954 .59649 Mdot
.954 .59652 Mdot
.954 .59653 Mdot
.954 .59655 Mdot
.954 .59659 Mdot
.954 .59665 Mdot
.954 .59669 Mdot
.954 .59672 Mdot
.954 .59677 Mdot
.954 .59677 Mdot
.954 .5968 Mdot
.954 .59682 Mdot
.954 .59683 Mdot
.954 .59689 Mdot
.954 .59696 Mdot
.954 .59702 Mdot
.954 .59705 Mdot
.954 .59708 Mdot
.954 .5971 Mdot
.954 .59714 Mdot
.954 .59715 Mdot
.954 .59716 Mdot
.954 .59717 Mdot
.954 .59722 Mdot
.954 .59722 Mdot
.954 .59727 Mdot
.954 .59727 Mdot
.954 .59729 Mdot
.954 .5973 Mdot
.954 .59737 Mdot
.954 .59743 Mdot
.954 .59744 Mdot
.954 .59749 Mdot
.954 .5975 Mdot
.954 .59751 Mdot
.954 .59752 Mdot
.954 .59756 Mdot
.954 .59759 Mdot
.954 .5976 Mdot
.954 .59762 Mdot
.954 .59764 Mdot
.954 .59765 Mdot
.954 .59773 Mdot
.954 .59773 Mdot
.954 .59776 Mdot
.954 .59777 Mdot
.954 .5978 Mdot
.954 .59782 Mdot
.954 .59784 Mdot
.954 .59784 Mdot
.954 .59787 Mdot
.954 .59788 Mdot
.954 .59788 Mdot
.954 .59789 Mdot
.954 .59789 Mdot
.954 .5979 Mdot
.954 .5979 Mdot
.954 .5979 Mdot
.954 .5979 Mdot
.954 .5979 Mdot
.954 .5979 Mdot
.954 .5979 Mdot
.954 .5979 Mdot
.954 .5979 Mdot
.956 .03508 Mdot
.956 .03508 Mdot
.956 .03509 Mdot
.956 .0351 Mdot
.956 .03511 Mdot
.956 .03511 Mdot
.956 .03531 Mdot
.956 .03532 Mdot
.956 .0354 Mdot
.956 .03553 Mdot
.956 .03553 Mdot
.956 .03572 Mdot
.956 .03588 Mdot
.956 .03592 Mdot
.956 .03595 Mdot
.956 .03607 Mdot
.956 .03611 Mdot
.956 .03625 Mdot
.956 .03626 Mdot
.956 .03641 Mdot
.956 .03644 Mdot
.956 .0367 Mdot
.956 .03675 Mdot
.956 .03687 Mdot
.956 .03692 Mdot
.956 .03698 Mdot
.956 .03703 Mdot
.956 .03717 Mdot
.956 .03723 Mdot
.956 .03751 Mdot
.956 .03764 Mdot
.956 .0377 Mdot
.956 .03788 Mdot
.956 .03815 Mdot
.956 .03837 Mdot
.956 .03856 Mdot
.956 .03865 Mdot
.956 .03889 Mdot
.956 .03914 Mdot
.956 .03963 Mdot
.956 .03991 Mdot
.956 .03993 Mdot
.956 .04002 Mdot
.956 .0402 Mdot
.956 .04102 Mdot
.956 .0411 Mdot
.956 .04147 Mdot
.956 .04149 Mdot
.956 .04231 Mdot
.956 .04249 Mdot
.956 .04276 Mdot
.956 .04277 Mdot
.956 .04321 Mdot
.956 .04367 Mdot
.956 .04374 Mdot
.956 .04401 Mdot
.956 .0448 Mdot
.956 .04542 Mdot
.956 .04558 Mdot
.956 .04565 Mdot
.956 .04578 Mdot
.956 .04606 Mdot
.956 .04696 Mdot
.956 .04697 Mdot
.956 .04732 Mdot
.956 .04809 Mdot
.956 .04841 Mdot
.956 .0485 Mdot
.956 .04913 Mdot
.956 .04933 Mdot
.956 .04959 Mdot
.956 .04965 Mdot
.956 .0505 Mdot
.956 .05082 Mdot
.956 .05083 Mdot
.956 .05109 Mdot
.956 .05109 Mdot
.956 .05198 Mdot
.956 .05247 Mdot
.956 .05248 Mdot
.956 .05255 Mdot
.956 .05271 Mdot
.956 .05278 Mdot
.956 .05287 Mdot
.956 .05289 Mdot
.956 .05315 Mdot
.956 .05319 Mdot
.956 .05335 Mdot
.956 .05432 Mdot
.956 .05475 Mdot
.956 .0548 Mdot
.956 .05481 Mdot
.956 .05619 Mdot
.956 .05823 Mdot
.956 .05889 Mdot
.956 .05977 Mdot
.956 .06055 Mdot
.956 .06138 Mdot
.956 .06232 Mdot
.956 .06311 Mdot
.956 .06323 Mdot
.956 .06357 Mdot
.956 .06468 Mdot
.956 .06477 Mdot
.956 .06544 Mdot
.956 .06603 Mdot
.956 .06733 Mdot
.956 .06776 Mdot
.956 .06781 Mdot
.956 .06806 Mdot
.956 .06885 Mdot
.956 .07019 Mdot
.956 .07065 Mdot
.956 .07259 Mdot
.956 .07272 Mdot
.956 .07291 Mdot
.956 .07362 Mdot
.956 .07442 Mdot
.956 .07449 Mdot
.956 .07561 Mdot
.956 .07874 Mdot
.956 .07896 Mdot
.956 .08137 Mdot
.956 .08443 Mdot
.956 .08462 Mdot
.956 .08592 Mdot
.956 .08842 Mdot
.956 .08894 Mdot
.956 .08941 Mdot
.956 .08955 Mdot
.956 .09037 Mdot
.956 .09267 Mdot
.956 .09267 Mdot
.956 .09271 Mdot
.956 .09275 Mdot
.956 .09277 Mdot
.956 .09277 Mdot
.956 .0929 Mdot
.956 .09353 Mdot
.956 .09355 Mdot
.956 .09386 Mdot
.956 .09432 Mdot
.956 .09433 Mdot
.956 .09504 Mdot
.956 .09561 Mdot
.956 .09578 Mdot
.956 .09589 Mdot
.956 .09631 Mdot
.956 .09647 Mdot
.956 .09697 Mdot
.956 .09702 Mdot
.956 .09742 Mdot
.956 .09756 Mdot
.956 .09769 Mdot
.956 .09861 Mdot
.956 .09876 Mdot
.956 .09881 Mdot
.956 .09885 Mdot
.956 .09889 Mdot
.956 .09904 Mdot
.956 .09926 Mdot
.956 .09944 Mdot
.956 .09959 Mdot
.956 .09964 Mdot
.956 .09986 Mdot
.956 .10006 Mdot
.956 .10034 Mdot
.956 .10034 Mdot
.956 .10056 Mdot
.956 .10143 Mdot
.956 .10161 Mdot
.956 .10208 Mdot
.956 .10228 Mdot
.956 .10293 Mdot
.956 .1039 Mdot
.956 .10393 Mdot
.956 .10473 Mdot
.956 .10542 Mdot
.956 .10576 Mdot
.956 .10662 Mdot
.956 .10753 Mdot
.956 .10918 Mdot
.956 .10923 Mdot
.956 .10932 Mdot
.956 .11011 Mdot
.956 .11033 Mdot
.956 .11039 Mdot
.956 .11075 Mdot
.956 .11092 Mdot
.956 .1114 Mdot
.956 .11433 Mdot
.956 .11435 Mdot
.956 .11463 Mdot
.956 .11599 Mdot
.956 .11605 Mdot
.956 .11717 Mdot
.956 .11721 Mdot
.956 .1182 Mdot
.956 .11899 Mdot
.956 .11965 Mdot
.956 .12062 Mdot
.956 .12065 Mdot
.956 .12222 Mdot
.956 .12235 Mdot
.956 .12298 Mdot
.956 .12354 Mdot
.956 .12386 Mdot
.956 .12413 Mdot
.956 .1243 Mdot
.956 .12441 Mdot
.956 .12509 Mdot
.956 .1254 Mdot
.956 .12789 Mdot
.956 .12907 Mdot
.956 .12923 Mdot
.956 .13009 Mdot
.956 .13067 Mdot
.956 .13069 Mdot
.956 .13091 Mdot
.956 .1314 Mdot
.956 .13149 Mdot
.956 .13232 Mdot
.956 .13236 Mdot
.956 .13238 Mdot
.956 .13439 Mdot
.956 .13556 Mdot
.956 .1356 Mdot
.956 .13682 Mdot
.956 .1372 Mdot
.956 .13813 Mdot
.956 .13901 Mdot
.956 .13953 Mdot
.956 .14007 Mdot
.956 .14065 Mdot
.956 .14098 Mdot
.956 .14319 Mdot
.956 .14388 Mdot
.956 .14443 Mdot
.956 .14481 Mdot
.956 .14502 Mdot
.956 .14791 Mdot
.956 .14797 Mdot
.956 .14808 Mdot
.956 .14827 Mdot
.956 .14908 Mdot
.956 .14912 Mdot
.956 .15001 Mdot
.956 .15001 Mdot
.956 .15008 Mdot
.956 .15031 Mdot
.956 .15114 Mdot
.956 .15167 Mdot
.956 .15311 Mdot
.956 .15481 Mdot
.956 .15483 Mdot
.956 .15508 Mdot
.956 .15564 Mdot
.956 .15587 Mdot
.956 .15619 Mdot
.956 .15625 Mdot
.956 .15707 Mdot
.956 .15716 Mdot
.956 .15731 Mdot
.956 .15786 Mdot
.956 .15961 Mdot
.956 .16086 Mdot
.956 .16118 Mdot
.956 .16266 Mdot
.956 .16281 Mdot
.956 .16287 Mdot
.956 .16327 Mdot
.956 .16402 Mdot
.956 .16732 Mdot
.956 .16759 Mdot
.956 .16782 Mdot
.956 .16827 Mdot
.956 .16862 Mdot
.956 .17255 Mdot
.956 .17268 Mdot
.956 .17413 Mdot
.956 .17449 Mdot
.956 .17449 Mdot
.956 .1766 Mdot
.956 .17673 Mdot
.956 .17716 Mdot
.956 .17856 Mdot
.956 .17928 Mdot
.956 .17967 Mdot
.956 .18229 Mdot
.956 .18256 Mdot
.956 .18284 Mdot
.956 .18326 Mdot
.956 .18506 Mdot
.956 .18625 Mdot
.956 .18662 Mdot
.956 .18674 Mdot
.956 .18819 Mdot
.956 .18854 Mdot
.956 .19081 Mdot
.956 .19094 Mdot
.956 .1912 Mdot
.956 .19188 Mdot
.956 .19236 Mdot
.956 .19281 Mdot
.956 .19427 Mdot
.956 .19434 Mdot
.956 .19535 Mdot
.956 .19602 Mdot
.956 .19623 Mdot
.956 .19631 Mdot
.956 .19843 Mdot
.956 .1985 Mdot
.956 .20044 Mdot
.956 .20201 Mdot
.956 .20397 Mdot
.956 .20414 Mdot
.956 .20469 Mdot
.956 .20474 Mdot
.956 .20512 Mdot
.956 .2054 Mdot
.956 .20609 Mdot
.956 .20623 Mdot
.956 .20706 Mdot
.956 .20771 Mdot
.956 .2084 Mdot
.956 .20961 Mdot
.956 .2138 Mdot
.956 .21394 Mdot
.956 .21408 Mdot
.956 .21449 Mdot
.956 .2154 Mdot
.956 .21564 Mdot
.956 .21611 Mdot
.956 .21761 Mdot
.956 .22163 Mdot
.956 .22203 Mdot
.956 .22264 Mdot
.956 .2249 Mdot
.956 .22524 Mdot
.956 .22582 Mdot
.956 .22681 Mdot
.956 .22741 Mdot
.956 .22766 Mdot
.956 .22795 Mdot
.956 .22862 Mdot
.956 .23117 Mdot
.956 .23296 Mdot
.956 .23368 Mdot
.956 .23569 Mdot
.956 .2369 Mdot
.956 .23878 Mdot
.956 .24061 Mdot
.956 .24095 Mdot
.956 .24151 Mdot
.956 .24163 Mdot
.956 .24478 Mdot
.956 .24508 Mdot
.956 .24669 Mdot
.956 .24671 Mdot
.956 .24727 Mdot
.956 .24781 Mdot
.956 .24907 Mdot
.956 .24942 Mdot
.956 .25428 Mdot
.956 .25492 Mdot
.956 .25794 Mdot
.956 .25837 Mdot
.956 .25896 Mdot
.956 .25956 Mdot
.956 .26252 Mdot
.956 .26287 Mdot
.956 .26293 Mdot
.956 .26447 Mdot
.956 .26934 Mdot
.956 .2699 Mdot
.956 .26994 Mdot
.956 .27034 Mdot
.956 .27189 Mdot
.956 .27214 Mdot
.956 .27329 Mdot
.956 .27369 Mdot
.956 .27476 Mdot
.956 .27584 Mdot
.956 .27612 Mdot
.956 .27816 Mdot
.956 .27872 Mdot
.956 .27915 Mdot
.956 .28146 Mdot
.956 .2815 Mdot
.956 .28262 Mdot
.956 .28266 Mdot
.956 .28285 Mdot
.956 .28287 Mdot
.956 .28298 Mdot
.956 .2831 Mdot
.956 .28316 Mdot
.956 .28316 Mdot
.956 .28353 Mdot
.956 .28422 Mdot
.956 .28443 Mdot
.956 .28536 Mdot
.956 .28541 Mdot
.956 .28632 Mdot
.956 .28668 Mdot
.956 .28735 Mdot
.956 .28766 Mdot
.956 .28767 Mdot
.956 .28895 Mdot
.956 .28972 Mdot
.956 .29137 Mdot
.956 .29186 Mdot
.956 .29217 Mdot
.956 .29337 Mdot
.956 .29384 Mdot
.956 .29394 Mdot
.956 .29526 Mdot
.956 .2954 Mdot
.956 .29542 Mdot
.956 .29655 Mdot
.956 .29694 Mdot
.956 .29732 Mdot
.956 .29748 Mdot
.956 .29936 Mdot
.956 .29994 Mdot
.956 .30007 Mdot
.956 .30036 Mdot
.956 .30049 Mdot
.956 .30061 Mdot
.956 .30072 Mdot
.956 .30114 Mdot
.956 .30177 Mdot
.956 .30187 Mdot
.956 .30227 Mdot
.956 .30231 Mdot
.956 .30271 Mdot
.956 .30285 Mdot
.956 .30346 Mdot
.956 .30403 Mdot
.956 .30483 Mdot
.956 .30483 Mdot
.956 .30545 Mdot
.956 .30788 Mdot
.956 .30839 Mdot
.956 .30968 Mdot
.956 .30994 Mdot
.956 .31023 Mdot
.956 .31024 Mdot
.956 .31207 Mdot
.956 .3121 Mdot
.956 .31473 Mdot
.956 .31482 Mdot
.956 .31702 Mdot
.956 .31892 Mdot
.956 .31903 Mdot
.956 .31937 Mdot
.956 .31986 Mdot
.956 .32024 Mdot
.956 .32222 Mdot
.956 .32302 Mdot
.956 .32468 Mdot
.956 .32565 Mdot
.956 .32618 Mdot
.956 .32715 Mdot
.956 .32723 Mdot
.956 .32751 Mdot
.956 .32892 Mdot
.956 .32914 Mdot
.956 .32927 Mdot
.956 .32953 Mdot
.956 .33163 Mdot
.956 .33224 Mdot
.956 .3324 Mdot
.956 .33335 Mdot
.956 .33361 Mdot
.956 .33381 Mdot
.956 .3351 Mdot
.956 .33552 Mdot
.956 .33622 Mdot
.956 .33656 Mdot
.956 .33753 Mdot
.956 .34036 Mdot
.956 .34087 Mdot
.956 .34144 Mdot
.956 .34198 Mdot
.956 .34284 Mdot
.956 .34289 Mdot
.956 .34361 Mdot
.956 .34458 Mdot
.956 .3446 Mdot
.956 .34518 Mdot
.956 .34716 Mdot
.956 .34722 Mdot
.956 .34732 Mdot
.956 .35022 Mdot
.956 .35033 Mdot
.956 .35147 Mdot
.956 .35288 Mdot
.956 .35297 Mdot
.956 .35467 Mdot
.956 .35489 Mdot
.956 .3566 Mdot
.956 .35902 Mdot
.956 .35906 Mdot
.956 .35913 Mdot
.956 .35936 Mdot
.956 .35954 Mdot
.956 .36106 Mdot
.956 .36309 Mdot
.956 .36344 Mdot
.956 .36501 Mdot
.956 .36605 Mdot
.956 .36606 Mdot
.956 .36642 Mdot
.956 .3679 Mdot
.956 .36812 Mdot
.956 .36831 Mdot
.956 .36858 Mdot
.956 .37028 Mdot
.956 .37104 Mdot
.956 .37202 Mdot
.956 .37354 Mdot
.956 .37389 Mdot
.956 .3753 Mdot
.956 .37646 Mdot
.956 .37716 Mdot
.956 .37759 Mdot
.956 .38003 Mdot
.956 .38041 Mdot
.956 .38136 Mdot
.956 .3825 Mdot
.956 .38263 Mdot
.956 .38273 Mdot
.956 .38389 Mdot
.956 .38393 Mdot
.956 .38446 Mdot
.956 .38523 Mdot
.956 .38564 Mdot
.956 .38584 Mdot
.956 .38678 Mdot
.956 .38698 Mdot
.956 .38783 Mdot
.956 .38793 Mdot
.956 .38797 Mdot
.956 .38848 Mdot
.956 .38915 Mdot
.956 .38967 Mdot
.956 .3901 Mdot
.956 .39274 Mdot
.956 .39295 Mdot
.956 .39306 Mdot
.956 .39376 Mdot
.956 .39394 Mdot
.956 .39547 Mdot
.956 .39558 Mdot
.956 .39588 Mdot
.956 .39842 Mdot
.956 .39857 Mdot
.956 .39883 Mdot
.956 .39913 Mdot
.956 .3993 Mdot
.956 .40061 Mdot
.956 .40113 Mdot
.956 .40144 Mdot
.956 .40346 Mdot
.956 .40395 Mdot
.956 .40464 Mdot
.956 .40587 Mdot
.956 .40603 Mdot
.956 .40679 Mdot
.956 .40719 Mdot
.956 .40793 Mdot
.956 .40804 Mdot
.956 .40977 Mdot
.956 .40978 Mdot
.956 .41124 Mdot
.956 .41205 Mdot
.956 .41262 Mdot
.956 .4129 Mdot
.956 .41445 Mdot
.956 .41566 Mdot
.956 .41652 Mdot
.956 .41698 Mdot
.956 .41715 Mdot
.956 .41769 Mdot
.956 .42006 Mdot
.956 .42331 Mdot
.956 .42344 Mdot
.956 .42367 Mdot
.956 .42409 Mdot
.956 .42584 Mdot
.956 .42592 Mdot
.956 .42695 Mdot
.956 .42784 Mdot
.956 .42785 Mdot
.956 .42798 Mdot
.956 .42847 Mdot
.956 .43025 Mdot
.956 .43137 Mdot
.956 .43297 Mdot
.956 .43347 Mdot
.956 .4344 Mdot
.956 .43485 Mdot
.956 .43665 Mdot
.956 .43698 Mdot
.956 .43758 Mdot
.956 .43796 Mdot
.956 .438 Mdot
.956 .43853 Mdot
.956 .43865 Mdot
.956 .43945 Mdot
.956 .43964 Mdot
.956 .43969 Mdot
.956 .44016 Mdot
.956 .44081 Mdot
.956 .44094 Mdot
.956 .44212 Mdot
.956 .44262 Mdot
.956 .44281 Mdot
.956 .44311 Mdot
.956 .4441 Mdot
.956 .44424 Mdot
.956 .44607 Mdot
.956 .44778 Mdot
.956 .44929 Mdot
.956 .45029 Mdot
.956 .45092 Mdot
.956 .45097 Mdot
.956 .45159 Mdot
.956 .4521 Mdot
.956 .4526 Mdot
.956 .45342 Mdot
.956 .45386 Mdot
.956 .45415 Mdot
.956 .45428 Mdot
.956 .45449 Mdot
.956 .45505 Mdot
.956 .45559 Mdot
.956 .45601 Mdot
.956 .45626 Mdot
.956 .45652 Mdot
.956 .45683 Mdot
.956 .45767 Mdot
.956 .45927 Mdot
.956 .46024 Mdot
.956 .46121 Mdot
.956 .46241 Mdot
.956 .46251 Mdot
.956 .46289 Mdot
.956 .46341 Mdot
.956 .4637 Mdot
.956 .46385 Mdot
.956 .46471 Mdot
.956 .46537 Mdot
.956 .46561 Mdot
.956 .46843 Mdot
.956 .47161 Mdot
.956 .47269 Mdot
.956 .47293 Mdot
.956 .47498 Mdot
.956 .47523 Mdot
.956 .47559 Mdot
.956 .47624 Mdot
.956 .47624 Mdot
.956 .47701 Mdot
.956 .47756 Mdot
.956 .4779 Mdot
.956 .47881 Mdot
.956 .48004 Mdot
.956 .48026 Mdot
.956 .4809 Mdot
.956 .48103 Mdot
.956 .48114 Mdot
.956 .4823 Mdot
.956 .48313 Mdot
.956 .48321 Mdot
.956 .48351 Mdot
.956 .48355 Mdot
.956 .48476 Mdot
.956 .48494 Mdot
.956 .48516 Mdot
.956 .48544 Mdot
.956 .48607 Mdot
.956 .48615 Mdot
.956 .4868 Mdot
.956 .48784 Mdot
.956 .48788 Mdot
.956 .48841 Mdot
.956 .48997 Mdot
.956 .49043 Mdot
.956 .4909 Mdot
.956 .49148 Mdot
.956 .49162 Mdot
.956 .49224 Mdot
.956 .49381 Mdot
.956 .49463 Mdot
.956 .49464 Mdot
.956 .49662 Mdot
.956 .49722 Mdot
.956 .4973 Mdot
.956 .49743 Mdot
.956 .49914 Mdot
.956 .4998 Mdot
.956 .50038 Mdot
.956 .50202 Mdot
.956 .50281 Mdot
.956 .50303 Mdot
.956 .50303 Mdot
.956 .50402 Mdot
.956 .50423 Mdot
.956 .50445 Mdot
.956 .50464 Mdot
.956 .50571 Mdot
.956 .50608 Mdot
.956 .50621 Mdot
.956 .50647 Mdot
.956 .50719 Mdot
.956 .50894 Mdot
.956 .50946 Mdot
.956 .50956 Mdot
.956 .50959 Mdot
.956 .50995 Mdot
.956 .51015 Mdot
.956 .51111 Mdot
.956 .51213 Mdot
.956 .51245 Mdot
.956 .51258 Mdot
.956 .51509 Mdot
.956 .51576 Mdot
.956 .51586 Mdot
.956 .51858 Mdot
.956 .51874 Mdot
.956 .51938 Mdot
.956 .51963 Mdot
.956 .52029 Mdot
.956 .52102 Mdot
.956 .52153 Mdot
.956 .52326 Mdot
.956 .52382 Mdot
.956 .52405 Mdot
.956 .52482 Mdot
.956 .5249 Mdot
.956 .52543 Mdot
.956 .52544 Mdot
.956 .52583 Mdot
.956 .52584 Mdot
.956 .52663 Mdot
.956 .52678 Mdot
.956 .52697 Mdot
.956 .52776 Mdot
.956 .52812 Mdot
.956 .52901 Mdot
.956 .52975 Mdot
.956 .52976 Mdot
.956 .52995 Mdot
.956 .53158 Mdot
.956 .5321 Mdot
.956 .53223 Mdot
.956 .53322 Mdot
.956 .53375 Mdot
.956 .53475 Mdot
.956 .53495 Mdot
.956 .53655 Mdot
.956 .53707 Mdot
.956 .53725 Mdot
.956 .53743 Mdot
.956 .53744 Mdot
.956 .53796 Mdot
.956 .53806 Mdot
.956 .53911 Mdot
.956 .5394 Mdot
.956 .53999 Mdot
.956 .5406 Mdot
.956 .54098 Mdot
.956 .54163 Mdot
.956 .54185 Mdot
.956 .54323 Mdot
.956 .54345 Mdot
.956 .54381 Mdot
.956 .54412 Mdot
.956 .5443 Mdot
.956 .5467 Mdot
.956 .54717 Mdot
.956 .54731 Mdot
.956 .54767 Mdot
.956 .5478 Mdot
.956 .54788 Mdot
.956 .54956 Mdot
.956 .54977 Mdot
.956 .55048 Mdot
.956 .55057 Mdot
.956 .55068 Mdot
.956 .55087 Mdot
.956 .55092 Mdot
.956 .55152 Mdot
.956 .55262 Mdot
.956 .55328 Mdot
.956 .55355 Mdot
.956 .55386 Mdot
.956 .55388 Mdot
.956 .55432 Mdot
.956 .5546 Mdot
.956 .55489 Mdot
.956 .55561 Mdot
.956 .55615 Mdot
.956 .55619 Mdot
.956 .5563 Mdot
.956 .55719 Mdot
.956 .55732 Mdot
.956 .5574 Mdot
.956 .55838 Mdot
.956 .5586 Mdot
.956 .55901 Mdot
.956 .55918 Mdot
.956 .5598 Mdot
.956 .55991 Mdot
.956 .56034 Mdot
.956 .56038 Mdot
.956 .56153 Mdot
.956 .56164 Mdot
.956 .56177 Mdot
.956 .56192 Mdot
.956 .56288 Mdot
.956 .5631 Mdot
.956 .5638 Mdot
.956 .56417 Mdot
.956 .56491 Mdot
.956 .56647 Mdot
.956 .56662 Mdot
.956 .56686 Mdot
.956 .56693 Mdot
.956 .56745 Mdot
.956 .5675 Mdot
.956 .56755 Mdot
.956 .56855 Mdot
.956 .56979 Mdot
.956 .57009 Mdot
.956 .57034 Mdot
.956 .57061 Mdot
.956 .5714 Mdot
.956 .57197 Mdot
.956 .57199 Mdot
.956 .57222 Mdot
.956 .57245 Mdot
.956 .57286 Mdot
.956 .5729 Mdot
.956 .57393 Mdot
.956 .57421 Mdot
.956 .57424 Mdot
.956 .57446 Mdot
.956 .57461 Mdot
.956 .57479 Mdot
.956 .57594 Mdot
.956 .57622 Mdot
.956 .57623 Mdot
.956 .57702 Mdot
.956 .57796 Mdot
.956 .57819 Mdot
.956 .57843 Mdot
.956 .57844 Mdot
.956 .57989 Mdot
.956 .58057 Mdot
.956 .58086 Mdot
.956 .58094 Mdot
.956 .58107 Mdot
.956 .58122 Mdot
.956 .58126 Mdot
.956 .58127 Mdot
.956 .5813 Mdot
.956 .58166 Mdot
.956 .58289 Mdot
.956 .58358 Mdot
.956 .5838 Mdot
.956 .58383 Mdot
.956 .58396 Mdot
.956 .5841 Mdot
.956 .58478 Mdot
.956 .58513 Mdot
.956 .58518 Mdot
.956 .586 Mdot
.956 .58664 Mdot
.956 .5867 Mdot
.956 .58754 Mdot
.956 .58783 Mdot
.956 .58785 Mdot
.956 .58807 Mdot
.956 .58826 Mdot
.956 .58831 Mdot
.956 .58834 Mdot
.956 .58886 Mdot
.956 .58898 Mdot
.956 .58933 Mdot
.956 .58954 Mdot
.956 .58961 Mdot
.956 .58962 Mdot
.956 .58973 Mdot
.956 .59008 Mdot
.956 .59023 Mdot
.956 .59041 Mdot
.956 .59043 Mdot
.956 .59073 Mdot
.956 .59082 Mdot
.956 .59085 Mdot
.956 .59106 Mdot
.956 .5913 Mdot
.956 .59152 Mdot
.956 .59173 Mdot
.956 .59196 Mdot
.956 .59213 Mdot
.956 .59266 Mdot
.956 .59303 Mdot
.956 .59303 Mdot
.956 .59304 Mdot
.956 .59315 Mdot
.956 .59341 Mdot
.956 .59345 Mdot
.956 .59346 Mdot
.956 .59353 Mdot
.956 .59353 Mdot
.956 .59356 Mdot
.956 .59357 Mdot
.956 .59362 Mdot
.956 .59364 Mdot
.956 .59364 Mdot
.956 .59377 Mdot
.956 .594 Mdot
.956 .594 Mdot
.956 .59406 Mdot
.956 .59407 Mdot
.956 .59415 Mdot
.956 .59437 Mdot
.956 .59439 Mdot
.956 .59446 Mdot
.956 .59451 Mdot
.956 .59467 Mdot
.956 .5947 Mdot
.956 .59478 Mdot
.956 .59498 Mdot
.956 .59507 Mdot
.956 .59507 Mdot
.956 .59531 Mdot
.956 .59538 Mdot
.956 .59541 Mdot
.956 .59543 Mdot
.956 .59547 Mdot
.956 .59563 Mdot
.956 .59583 Mdot
.956 .5959 Mdot
.956 .59592 Mdot
.956 .59604 Mdot
.956 .59616 Mdot
.956 .59616 Mdot
.956 .59623 Mdot
.956 .59628 Mdot
.956 .59649 Mdot
.956 .59649 Mdot
.956 .59659 Mdot
.956 .59661 Mdot
.956 .59682 Mdot
.956 .59686 Mdot
.956 .59689 Mdot
.956 .59689 Mdot
.956 .59697 Mdot
.956 .59709 Mdot
.956 .59716 Mdot
.956 .59722 Mdot
.956 .59724 Mdot
.956 .59729 Mdot
.956 .59735 Mdot
.956 .59742 Mdot
.956 .59746 Mdot
.956 .59748 Mdot
.956 .59751 Mdot
.956 .59758 Mdot
.956 .5976 Mdot
.956 .59763 Mdot
.956 .59765 Mdot
.956 .59766 Mdot
.956 .59768 Mdot
.956 .59771 Mdot
.956 .59772 Mdot
.956 .59779 Mdot
.956 .5978 Mdot
.956 .59783 Mdot
.956 .59784 Mdot
.956 .59787 Mdot
.956 .59788 Mdot
.956 .59791 Mdot
.956 .59792 Mdot
.956 .59793 Mdot
.956 .59797 Mdot
.956 .59802 Mdot
.956 .59802 Mdot
.956 .59805 Mdot
.956 .59808 Mdot
.956 .59808 Mdot
.956 .59813 Mdot
.956 .59813 Mdot
.956 .59813 Mdot
.956 .59813 Mdot
.956 .59814 Mdot
.956 .59814 Mdot
.958 .03416 Mdot
.958 .03416 Mdot
.958 .03416 Mdot
.958 .03418 Mdot
.958 .03422 Mdot
.958 .03423 Mdot
.958 .03428 Mdot
.958 .03429 Mdot
.958 .0343 Mdot
.958 .03431 Mdot
.958 .03436 Mdot
.958 .03437 Mdot
.958 .03441 Mdot
.958 .03449 Mdot
.958 .03449 Mdot
.958 .03462 Mdot
.958 .0347 Mdot
.958 .03472 Mdot
.958 .03474 Mdot
.958 .0348 Mdot
.958 .03496 Mdot
.958 .03499 Mdot
.958 .03502 Mdot
.958 .03528 Mdot
.958 .03546 Mdot
.958 .03557 Mdot
.958 .03574 Mdot
.958 .0358 Mdot
.958 .03607 Mdot
.958 .03637 Mdot
.958 .03638 Mdot
.958 .03666 Mdot
.958 .0371 Mdot
.958 .03753 Mdot
.958 .0377 Mdot
.958 .03778 Mdot
.958 .03783 Mdot
.958 .03786 Mdot
.958 .038 Mdot
.958 .03804 Mdot
.958 .0381 Mdot
.958 .03811 Mdot
.958 .03871 Mdot
.958 .03877 Mdot
.958 .03886 Mdot
.958 .0394 Mdot
.958 .03941 Mdot
.958 .03962 Mdot
.958 .04042 Mdot
.958 .04288 Mdot
.958 .04312 Mdot
.958 .04324 Mdot
.958 .04355 Mdot
.958 .04419 Mdot
.958 .04421 Mdot
.958 .04453 Mdot
.958 .0446 Mdot
.958 .04509 Mdot
.958 .04535 Mdot
.958 .04543 Mdot
.958 .04564 Mdot
.958 .04611 Mdot
.958 .04673 Mdot
.958 .04703 Mdot
.958 .04754 Mdot
.958 .04766 Mdot
.958 .0487 Mdot
.958 .04892 Mdot
.958 .04916 Mdot
.958 .05031 Mdot
.958 .05055 Mdot
.958 .05235 Mdot
.958 .05264 Mdot
.958 .05308 Mdot
.958 .05353 Mdot
.958 .05353 Mdot
.958 .054 Mdot
.958 .05426 Mdot
.958 .05453 Mdot
.958 .0548 Mdot
.958 .05481 Mdot
.958 .05521 Mdot
.958 .05557 Mdot
.958 .05596 Mdot
.958 .05613 Mdot
.958 .05633 Mdot
.958 .05707 Mdot
.958 .05736 Mdot
.958 .05773 Mdot
.958 .05907 Mdot
.958 .0602 Mdot
.958 .06132 Mdot
.958 .06139 Mdot
.958 .06165 Mdot
.958 .06194 Mdot
.958 .06269 Mdot
.958 .06342 Mdot
.958 .06353 Mdot
.958 .0638 Mdot
.958 .06459 Mdot
.958 .06483 Mdot
.958 .06503 Mdot
.958 .06571 Mdot
.958 .06623 Mdot
.958 .06629 Mdot
.958 .06649 Mdot
.958 .06713 Mdot
.958 .0672 Mdot
.958 .06754 Mdot
.958 .06758 Mdot
.958 .06761 Mdot
.958 .06762 Mdot
.958 .06981 Mdot
.958 .07007 Mdot
.958 .07097 Mdot
.958 .07155 Mdot
.958 .07157 Mdot
.958 .07211 Mdot
.958 .07355 Mdot
.958 .07416 Mdot
.958 .07506 Mdot
.958 .0763 Mdot
.958 .07717 Mdot
.958 .07882 Mdot
.958 .08011 Mdot
.958 .0802 Mdot
.958 .08085 Mdot
.958 .08092 Mdot
.958 .0828 Mdot
.958 .08453 Mdot
.958 .08559 Mdot
.958 .0859 Mdot
.958 .08602 Mdot
.958 .08779 Mdot
.958 .08859 Mdot
.958 .0893 Mdot
.958 .0893 Mdot
.958 .08931 Mdot
.958 .08938 Mdot
.958 .08951 Mdot
.958 .08955 Mdot
.958 .08956 Mdot
.958 .08976 Mdot
.958 .08978 Mdot
.958 .08982 Mdot
.958 .08987 Mdot
.958 .09002 Mdot
.958 .09008 Mdot
.958 .09024 Mdot
.958 .09051 Mdot
.958 .09052 Mdot
.958 .09075 Mdot
.958 .09099 Mdot
.958 .09128 Mdot
.958 .09136 Mdot
.958 .09143 Mdot
.958 .09168 Mdot
.958 .09225 Mdot
.958 .09236 Mdot
.958 .09247 Mdot
.958 .09345 Mdot
.958 .09409 Mdot
.958 .09443 Mdot
.958 .09449 Mdot
.958 .09512 Mdot
.958 .09536 Mdot
.958 .09633 Mdot
.958 .0971 Mdot
.958 .09745 Mdot
.958 .09748 Mdot
.958 .09853 Mdot
.958 .09854 Mdot
.958 .10013 Mdot
.958 .10147 Mdot
.958 .10172 Mdot
.958 .10232 Mdot
.958 .10258 Mdot
.958 .1026 Mdot
.958 .10263 Mdot
.958 .10281 Mdot
.958 .10292 Mdot
.958 .10342 Mdot
.958 .10345 Mdot
.958 .10358 Mdot
.958 .10378 Mdot
.958 .10382 Mdot
.958 .10443 Mdot
.958 .106 Mdot
.958 .10617 Mdot
.958 .10624 Mdot
.958 .10657 Mdot
.958 .10703 Mdot
.958 .10853 Mdot
.958 .10858 Mdot
.958 .10934 Mdot
.958 .1099 Mdot
.958 .11214 Mdot
.958 .11224 Mdot
.958 .11386 Mdot
.958 .11419 Mdot
.958 .11698 Mdot
.958 .11754 Mdot
.958 .11855 Mdot
.958 .11918 Mdot
.958 .1211 Mdot
.958 .12196 Mdot
.958 .12239 Mdot
.958 .1235 Mdot
.958 .12556 Mdot
.958 .12577 Mdot
.958 .12586 Mdot
.958 .12699 Mdot
.958 .12724 Mdot
.958 .12747 Mdot
.958 .12789 Mdot
.958 .1284 Mdot
.958 .12897 Mdot
.958 .12905 Mdot
.958 .12989 Mdot
.958 .1302 Mdot
.958 .13092 Mdot
.958 .13233 Mdot
.958 .13259 Mdot
.958 .13386 Mdot
.958 .13456 Mdot
.958 .13478 Mdot
.958 .13505 Mdot
.958 .13585 Mdot
.958 .13588 Mdot
.958 .13766 Mdot
.958 .13808 Mdot
.958 .14022 Mdot
.958 .14175 Mdot
.958 .14249 Mdot
.958 .14307 Mdot
.958 .14331 Mdot
.958 .14333 Mdot
.958 .14499 Mdot
.958 .14677 Mdot
.958 .14735 Mdot
.958 .14821 Mdot
.958 .14821 Mdot
.958 .15002 Mdot
.958 .15403 Mdot
.958 .15446 Mdot
.958 .15546 Mdot
.958 .156 Mdot
.958 .15697 Mdot
.958 .15851 Mdot
.958 .15853 Mdot
.958 .15856 Mdot
.958 .15923 Mdot
.958 .16016 Mdot
.958 .16034 Mdot
.958 .16104 Mdot
.958 .16195 Mdot
.958 .16288 Mdot
.958 .16291 Mdot
.958 .1637 Mdot
.958 .16416 Mdot
.958 .16428 Mdot
.958 .16442 Mdot
.958 .16478 Mdot
.958 .16488 Mdot
.958 .16509 Mdot
.958 .16551 Mdot
.958 .166 Mdot
.958 .16684 Mdot
.958 .16742 Mdot
.958 .16812 Mdot
.958 .16848 Mdot
.958 .16896 Mdot
.958 .16979 Mdot
.958 .17064 Mdot
.958 .1716 Mdot
.958 .17286 Mdot
.958 .1729 Mdot
.958 .17429 Mdot
.958 .17444 Mdot
.958 .17671 Mdot
.958 .17741 Mdot
.958 .1782 Mdot
.958 .1812 Mdot
.958 .18184 Mdot
.958 .18493 Mdot
.958 .18517 Mdot
.958 .18604 Mdot
.958 .18622 Mdot
.958 .187 Mdot
.958 .18791 Mdot
.958 .18802 Mdot
.958 .18841 Mdot
.958 .18842 Mdot
.958 .18951 Mdot
.958 .18958 Mdot
.958 .19191 Mdot
.958 .19228 Mdot
.958 .19319 Mdot
.958 .19384 Mdot
.958 .19576 Mdot
.958 .19579 Mdot
.958 .19657 Mdot
.958 .19724 Mdot
.958 .19823 Mdot
.958 .19927 Mdot
.958 .19947 Mdot
.958 .20116 Mdot
.958 .20135 Mdot
.958 .20203 Mdot
.958 .20345 Mdot
.958 .20412 Mdot
.958 .20433 Mdot
.958 .20531 Mdot
.958 .20535 Mdot
.958 .20544 Mdot
.958 .20557 Mdot
.958 .20566 Mdot
.958 .2057 Mdot
.958 .20729 Mdot
.958 .20891 Mdot
.958 .20922 Mdot
.958 .20958 Mdot
.958 .2128 Mdot
.958 .21359 Mdot
.958 .21362 Mdot
.958 .21653 Mdot
.958 .21658 Mdot
.958 .21662 Mdot
.958 .21693 Mdot
.958 .21834 Mdot
.958 .21838 Mdot
.958 .21846 Mdot
.958 .21986 Mdot
.958 .22017 Mdot
.958 .22087 Mdot
.958 .22127 Mdot
.958 .22253 Mdot
.958 .2237 Mdot
.958 .22475 Mdot
.958 .22669 Mdot
.958 .22908 Mdot
.958 .22941 Mdot
.958 .22952 Mdot
.958 .22955 Mdot
.958 .23231 Mdot
.958 .23274 Mdot
.958 .23344 Mdot
.958 .23499 Mdot
.958 .23614 Mdot
.958 .2362 Mdot
.958 .23634 Mdot
.958 .23642 Mdot
.958 .23656 Mdot
.958 .24131 Mdot
.958 .24527 Mdot
.958 .24555 Mdot
.958 .24756 Mdot
.958 .24778 Mdot
.958 .24796 Mdot
.958 .2481 Mdot
.958 .25121 Mdot
.958 .25291 Mdot
.958 .25354 Mdot
.958 .25578 Mdot
.958 .25878 Mdot
.958 .262 Mdot
.958 .26293 Mdot
.958 .26328 Mdot
.958 .26406 Mdot
.958 .26551 Mdot
.958 .26676 Mdot
.958 .26858 Mdot
.958 .2692 Mdot
.958 .26965 Mdot
.958 .26995 Mdot
.958 .27096 Mdot
.958 .27175 Mdot
.958 .27306 Mdot
.958 .27307 Mdot
.958 .2731 Mdot
.958 .27329 Mdot
.958 .27333 Mdot
.958 .27368 Mdot
.958 .2738 Mdot
.958 .27383 Mdot
.958 .27442 Mdot
.958 .2745 Mdot
.958 .27462 Mdot
.958 .27475 Mdot
.958 .2752 Mdot
.958 .27536 Mdot
.958 .27585 Mdot
.958 .27647 Mdot
.958 .27663 Mdot
.958 .27667 Mdot
.958 .27735 Mdot
.958 .27805 Mdot
.958 .27891 Mdot
.958 .27915 Mdot
.958 .27933 Mdot
.958 .27982 Mdot
.958 .27996 Mdot
.958 .28007 Mdot
.958 .28034 Mdot
.958 .28086 Mdot
.958 .28123 Mdot
.958 .28141 Mdot
.958 .28175 Mdot
.958 .28175 Mdot
.958 .28207 Mdot
.958 .28239 Mdot
.958 .28395 Mdot
.958 .28414 Mdot
.958 .28524 Mdot
.958 .28541 Mdot
.958 .28628 Mdot
.958 .28709 Mdot
.958 .28807 Mdot
.958 .28825 Mdot
.958 .28904 Mdot
.958 .29007 Mdot
.958 .29076 Mdot
.958 .29355 Mdot
.958 .29486 Mdot
.958 .29488 Mdot
.958 .29563 Mdot
.958 .29576 Mdot
.958 .29676 Mdot
.958 .29685 Mdot
.958 .29767 Mdot
.958 .29843 Mdot
.958 .29925 Mdot
.958 .29982 Mdot
.958 .29984 Mdot
.958 .30199 Mdot
.958 .30433 Mdot
.958 .30484 Mdot
.958 .30547 Mdot
.958 .30549 Mdot
.958 .30628 Mdot
.958 .30659 Mdot
.958 .30811 Mdot
.958 .30881 Mdot
.958 .30887 Mdot
.958 .30943 Mdot
.958 .31049 Mdot
.958 .31062 Mdot
.958 .31119 Mdot
.958 .31126 Mdot
.958 .31134 Mdot
.958 .31185 Mdot
.958 .31213 Mdot
.958 .31354 Mdot
.958 .31363 Mdot
.958 .31397 Mdot
.958 .31453 Mdot
.958 .31463 Mdot
.958 .31473 Mdot
.958 .31556 Mdot
.958 .31633 Mdot
.958 .31676 Mdot
.958 .31754 Mdot
.958 .32063 Mdot
.958 .32077 Mdot
.958 .32085 Mdot
.958 .32089 Mdot
.958 .32111 Mdot
.958 .32128 Mdot
.958 .32218 Mdot
.958 .32345 Mdot
.958 .32752 Mdot
.958 .32764 Mdot
.958 .32859 Mdot
.958 .32862 Mdot
.958 .32893 Mdot
.958 .32946 Mdot
.958 .3297 Mdot
.958 .33039 Mdot
.958 .33121 Mdot
.958 .33165 Mdot
.958 .33299 Mdot
.958 .33544 Mdot
.958 .33698 Mdot
.958 .33717 Mdot
.958 .33745 Mdot
.958 .34173 Mdot
.958 .34261 Mdot
.958 .34391 Mdot
.958 .34495 Mdot
.958 .34615 Mdot
.958 .34676 Mdot
.958 .34706 Mdot
.958 .34735 Mdot
.958 .34987 Mdot
.958 .35067 Mdot
.958 .35131 Mdot
.958 .35162 Mdot
.958 .35165 Mdot
.958 .3533 Mdot
.958 .35378 Mdot
.958 .35392 Mdot
.958 .35552 Mdot
.958 .35758 Mdot
.958 .35867 Mdot
.958 .36042 Mdot
.958 .36086 Mdot
.958 .36087 Mdot
.958 .3612 Mdot
.958 .36158 Mdot
.958 .36258 Mdot
.958 .36366 Mdot
.958 .36525 Mdot
.958 .36626 Mdot
.958 .36646 Mdot
.958 .36704 Mdot
.958 .36928 Mdot
.958 .37158 Mdot
.958 .37209 Mdot
.958 .37232 Mdot
.958 .37418 Mdot
.958 .3751 Mdot
.958 .37517 Mdot
.958 .37571 Mdot
.958 .37627 Mdot
.958 .37729 Mdot
.958 .37854 Mdot
.958 .37915 Mdot
.958 .37993 Mdot
.958 .38013 Mdot
.958 .38047 Mdot
.958 .3818 Mdot
.958 .38216 Mdot
.958 .3829 Mdot
.958 .38328 Mdot
.958 .38419 Mdot
.958 .38464 Mdot
.958 .38677 Mdot
.958 .38801 Mdot
.958 .38863 Mdot
.958 .39014 Mdot
.958 .39067 Mdot
.958 .39163 Mdot
.958 .39277 Mdot
.958 .39328 Mdot
.958 .39381 Mdot
.958 .39425 Mdot
.958 .39443 Mdot
.958 .39629 Mdot
.958 .3963 Mdot
.958 .39639 Mdot
.958 .39743 Mdot
.958 .39753 Mdot
.958 .40041 Mdot
.958 .40052 Mdot
.958 .40147 Mdot
.958 .40566 Mdot
.958 .40638 Mdot
.958 .40972 Mdot
.958 .40983 Mdot
.958 .40991 Mdot
.958 .41035 Mdot
.958 .41151 Mdot
.958 .41281 Mdot
.958 .41335 Mdot
.958 .41339 Mdot
.958 .416 Mdot
.958 .41619 Mdot
.958 .41706 Mdot
.958 .41773 Mdot
.958 .41842 Mdot
.958 .41857 Mdot
.958 .41884 Mdot
.958 .41939 Mdot
.958 .41952 Mdot
.958 .42099 Mdot
.958 .42128 Mdot
.958 .42226 Mdot
.958 .42412 Mdot
.958 .42412 Mdot
.958 .42432 Mdot
.958 .42455 Mdot
.958 .42516 Mdot
.958 .42777 Mdot
.958 .42802 Mdot
.958 .42831 Mdot
.958 .42859 Mdot
.958 .42938 Mdot
.958 .43129 Mdot
.958 .43182 Mdot
.958 .4319 Mdot
.958 .43329 Mdot
.958 .43383 Mdot
.958 .435 Mdot
.958 .43524 Mdot
.958 .43651 Mdot
.958 .43719 Mdot
.958 .43741 Mdot
.958 .43802 Mdot
.958 .43884 Mdot
.958 .43896 Mdot
.958 .43947 Mdot
.958 .44032 Mdot
.958 .4406 Mdot
.958 .4426 Mdot
.958 .44364 Mdot
.958 .44556 Mdot
.958 .44573 Mdot
.958 .44576 Mdot
.958 .44583 Mdot
.958 .44596 Mdot
.958 .446 Mdot
.958 .44718 Mdot
.958 .44724 Mdot
.958 .44804 Mdot
.958 .44817 Mdot
.958 .44844 Mdot
.958 .44892 Mdot
.958 .44905 Mdot
.958 .44942 Mdot
.958 .44985 Mdot
.958 .4504 Mdot
.958 .45081 Mdot
.958 .45085 Mdot
.958 .45262 Mdot
.958 .45263 Mdot
.958 .45319 Mdot
.958 .45338 Mdot
.958 .45447 Mdot
.958 .45452 Mdot
.958 .4557 Mdot
.958 .4558 Mdot
.958 .45608 Mdot
.958 .45698 Mdot
.958 .4572 Mdot
.958 .45748 Mdot
.958 .45794 Mdot
.958 .45818 Mdot
.958 .45831 Mdot
.958 .45838 Mdot
.958 .45878 Mdot
.958 .45939 Mdot
.958 .45941 Mdot
.958 .45961 Mdot
.958 .46055 Mdot
.958 .46216 Mdot
.958 .46282 Mdot
.958 .46288 Mdot
.958 .46327 Mdot
.958 .46368 Mdot
.958 .46461 Mdot
.958 .46472 Mdot
.958 .46528 Mdot
.958 .46553 Mdot
.958 .46619 Mdot
.958 .46623 Mdot
.958 .46648 Mdot
.958 .46738 Mdot
.958 .46775 Mdot
.958 .46788 Mdot
.958 .46813 Mdot
.958 .46934 Mdot
.958 .46963 Mdot
.958 .46973 Mdot
.958 .47113 Mdot
.958 .47193 Mdot
.958 .47199 Mdot
.958 .47224 Mdot
.958 .47236 Mdot
.958 .47243 Mdot
.958 .47275 Mdot
.958 .47344 Mdot
.958 .47353 Mdot
.958 .47606 Mdot
.958 .47625 Mdot
.958 .47634 Mdot
.958 .47813 Mdot
.958 .48042 Mdot
.958 .48166 Mdot
.958 .4817 Mdot
.958 .48219 Mdot
.958 .48306 Mdot
.958 .48369 Mdot
.958 .48458 Mdot
.958 .48481 Mdot
.958 .48622 Mdot
.958 .4873 Mdot
.958 .48768 Mdot
.958 .48829 Mdot
.958 .48884 Mdot
.958 .48939 Mdot
.958 .49101 Mdot
.958 .49142 Mdot
.958 .4934 Mdot
.958 .4943 Mdot
.958 .49461 Mdot
.958 .49502 Mdot
.958 .49647 Mdot
.958 .49662 Mdot
.958 .49675 Mdot
.958 .49676 Mdot
.958 .49762 Mdot
.958 .49805 Mdot
.958 .49953 Mdot
.958 .49972 Mdot
.958 .50036 Mdot
.958 .50037 Mdot
.958 .50074 Mdot
.958 .50202 Mdot
.958 .50214 Mdot
.958 .50225 Mdot
.958 .50248 Mdot
.958 .50294 Mdot
.958 .50334 Mdot
.958 .50597 Mdot
.958 .50655 Mdot
.958 .50747 Mdot
.958 .50797 Mdot
.958 .50843 Mdot
.958 .50878 Mdot
.958 .50898 Mdot
.958 .50909 Mdot
.958 .5091 Mdot
.958 .51194 Mdot
.958 .51196 Mdot
.958 .51199 Mdot
.958 .51316 Mdot
.958 .51344 Mdot
.958 .51388 Mdot
.958 .51418 Mdot
.958 .51566 Mdot
.958 .51609 Mdot
.958 .51629 Mdot
.958 .5171 Mdot
.958 .51721 Mdot
.958 .5175 Mdot
.958 .5175 Mdot
.958 .51773 Mdot
.958 .51874 Mdot
.958 .51971 Mdot
.958 .51999 Mdot
.958 .52026 Mdot
.958 .52098 Mdot
.958 .52124 Mdot
.958 .52125 Mdot
.958 .52327 Mdot
.958 .52422 Mdot
.958 .52452 Mdot
.958 .52496 Mdot
.958 .52503 Mdot
.958 .52578 Mdot
.958 .5259 Mdot
.958 .52596 Mdot
.958 .52609 Mdot
.958 .52626 Mdot
.958 .52639 Mdot
.958 .52644 Mdot
.958 .52758 Mdot
.958 .52864 Mdot
.958 .52918 Mdot
.958 .52978 Mdot
.958 .52988 Mdot
.958 .53003 Mdot
.958 .53085 Mdot
.958 .53127 Mdot
.958 .53175 Mdot
.958 .53449 Mdot
.958 .53544 Mdot
.958 .53599 Mdot
.958 .53701 Mdot
.958 .53705 Mdot
.958 .54073 Mdot
.958 .54078 Mdot
.958 .5408 Mdot
.958 .54085 Mdot
.958 .54123 Mdot
.958 .54195 Mdot
.958 .54209 Mdot
.958 .54297 Mdot
.958 .54301 Mdot
.958 .54312 Mdot
.958 .54481 Mdot
.958 .54518 Mdot
.958 .54558 Mdot
.958 .5457 Mdot
.958 .54602 Mdot
.958 .5465 Mdot
.958 .54694 Mdot
.958 .54703 Mdot
.958 .54704 Mdot
.958 .54798 Mdot
.958 .54922 Mdot
.958 .54933 Mdot
.958 .54942 Mdot
.958 .54992 Mdot
.958 .55052 Mdot
.958 .55053 Mdot
.958 .5511 Mdot
.958 .55238 Mdot
.958 .5527 Mdot
.958 .55345 Mdot
.958 .55403 Mdot
.958 .55532 Mdot
.958 .55567 Mdot
.958 .55567 Mdot
.958 .55579 Mdot
.958 .55582 Mdot
.958 .55633 Mdot
.958 .55764 Mdot
.958 .55872 Mdot
.958 .55916 Mdot
.958 .55984 Mdot
.958 .55988 Mdot
.958 .56029 Mdot
.958 .56121 Mdot
.958 .56145 Mdot
.958 .56159 Mdot
.958 .56232 Mdot
.958 .56259 Mdot
.958 .56265 Mdot
.958 .56268 Mdot
.958 .56278 Mdot
.958 .56286 Mdot
.958 .56299 Mdot
.958 .56397 Mdot
.958 .5643 Mdot
.958 .56449 Mdot
.958 .56523 Mdot
.958 .5658 Mdot
.958 .56696 Mdot
.958 .56748 Mdot
.958 .56789 Mdot
.958 .5684 Mdot
.958 .56888 Mdot
.958 .56895 Mdot
.958 .56976 Mdot
.958 .57099 Mdot
.958 .57123 Mdot
.958 .57137 Mdot
.958 .57157 Mdot
.958 .572 Mdot
.958 .57292 Mdot
.958 .57311 Mdot
.958 .57325 Mdot
.958 .57337 Mdot
.958 .5739 Mdot
.958 .57569 Mdot
.958 .57586 Mdot
.958 .57614 Mdot
.958 .5763 Mdot
.958 .57707 Mdot
.958 .57716 Mdot
.958 .57764 Mdot
.958 .57825 Mdot
.958 .57904 Mdot
.958 .57928 Mdot
.958 .57976 Mdot
.958 .58002 Mdot
.958 .58026 Mdot
.958 .58026 Mdot
.958 .58057 Mdot
.958 .58137 Mdot
.958 .58176 Mdot
.958 .58249 Mdot
.958 .58348 Mdot
.958 .5838 Mdot
.958 .58406 Mdot
.958 .58428 Mdot
.958 .58476 Mdot
.958 .58479 Mdot
.958 .58487 Mdot
.958 .58516 Mdot
.958 .58562 Mdot
.958 .58612 Mdot
.958 .58614 Mdot
.958 .58632 Mdot
.958 .58634 Mdot
.958 .58669 Mdot
.958 .58713 Mdot
.958 .58736 Mdot
.958 .58769 Mdot
.958 .58793 Mdot
.958 .58809 Mdot
.958 .58847 Mdot
.958 .58862 Mdot
.958 .58862 Mdot
.958 .58878 Mdot
.958 .58902 Mdot
.958 .58908 Mdot
.958 .58966 Mdot
.958 .58967 Mdot
.958 .58967 Mdot
.958 .58968 Mdot
.958 .58978 Mdot
.958 .58979 Mdot
.958 .58996 Mdot
.958 .59002 Mdot
.958 .59003 Mdot
.958 .59017 Mdot
.958 .59031 Mdot
.958 .59035 Mdot
.958 .5904 Mdot
.958 .59046 Mdot
.958 .59067 Mdot
.958 .59074 Mdot
.958 .59077 Mdot
.958 .59096 Mdot
.958 .59116 Mdot
.958 .59124 Mdot
.958 .59131 Mdot
.958 .59133 Mdot
.958 .59162 Mdot
.958 .59191 Mdot
.958 .59227 Mdot
.958 .59236 Mdot
.958 .59244 Mdot
.958 .59263 Mdot
.958 .59269 Mdot
.958 .59273 Mdot
.958 .59283 Mdot
.958 .59293 Mdot
.958 .59303 Mdot
.958 .59303 Mdot
.958 .5931 Mdot
.958 .59317 Mdot
.958 .59324 Mdot
.958 .59336 Mdot
.958 .59337 Mdot
.958 .59348 Mdot
.958 .5936 Mdot
.958 .59367 Mdot
.958 .59414 Mdot
.958 .5942 Mdot
.958 .5945 Mdot
.958 .59457 Mdot
.958 .59462 Mdot
.958 .59489 Mdot
.958 .59492 Mdot
.958 .59506 Mdot
.958 .59513 Mdot
.958 .5953 Mdot
.958 .59542 Mdot
.958 .59547 Mdot
.958 .59549 Mdot
.958 .59556 Mdot
.958 .59569 Mdot
.958 .5957 Mdot
.958 .59579 Mdot
.958 .59579 Mdot
.958 .59596 Mdot
.958 .59604 Mdot
.958 .59607 Mdot
.958 .59613 Mdot
.958 .59676 Mdot
.958 .59697 Mdot
.958 .59702 Mdot
.958 .59703 Mdot
.958 .59717 Mdot
.958 .59719 Mdot
.958 .59721 Mdot
.958 .59736 Mdot
.958 .59736 Mdot
.958 .59738 Mdot
.958 .59739 Mdot
.958 .59742 Mdot
.958 .59743 Mdot
.958 .59744 Mdot
.958 .59747 Mdot
.958 .59751 Mdot
.958 .59762 Mdot
.958 .59773 Mdot
.958 .59781 Mdot
.958 .59781 Mdot
.958 .59789 Mdot
.958 .59795 Mdot
.958 .59797 Mdot
.958 .59801 Mdot
.958 .59804 Mdot
.958 .59809 Mdot
.958 .59815 Mdot
.958 .59816 Mdot
.958 .59817 Mdot
.958 .59821 Mdot
.958 .59823 Mdot
.958 .59823 Mdot
.958 .59824 Mdot
.958 .59826 Mdot
.958 .59829 Mdot
.958 .59829 Mdot
.958 .59831 Mdot
.958 .59832 Mdot
.958 .59832 Mdot
.958 .59834 Mdot
.958 .59834 Mdot
.958 .59834 Mdot
.958 .59834 Mdot
.958 .59836 Mdot
.958 .59836 Mdot
.958 .59837 Mdot
.958 .59837 Mdot
.958 .59837 Mdot
.958 .59837 Mdot
.96 .03325 Mdot
.96 .03325 Mdot
.96 .03325 Mdot
.96 .03328 Mdot
.96 .03347 Mdot
.96 .0335 Mdot
.96 .03352 Mdot
.96 .03378 Mdot
.96 .03381 Mdot
.96 .03391 Mdot
.96 .03393 Mdot
.96 .03394 Mdot
.96 .03404 Mdot
.96 .03405 Mdot
.96 .03467 Mdot
.96 .03494 Mdot
.96 .03504 Mdot
.96 .03573 Mdot
.96 .03596 Mdot
.96 .03609 Mdot
.96 .03636 Mdot
.96 .03642 Mdot
.96 .03659 Mdot
.96 .03676 Mdot
.96 .037 Mdot
.96 .0371 Mdot
.96 .03725 Mdot
.96 .03754 Mdot
.96 .03758 Mdot
.96 .03856 Mdot
.96 .03872 Mdot
.96 .03911 Mdot
.96 .03919 Mdot
.96 .03957 Mdot
.96 .03968 Mdot
.96 .03985 Mdot
.96 .04031 Mdot
.96 .04047 Mdot
.96 .04051 Mdot
.96 .04052 Mdot
.96 .04053 Mdot
.96 .04097 Mdot
.96 .04101 Mdot
.96 .04117 Mdot
.96 .04136 Mdot
.96 .04138 Mdot
.96 .04147 Mdot
.96 .04209 Mdot
.96 .04255 Mdot
.96 .04321 Mdot
.96 .04342 Mdot
.96 .04343 Mdot
.96 .04412 Mdot
.96 .04414 Mdot
.96 .04499 Mdot
.96 .04526 Mdot
.96 .04557 Mdot
.96 .04559 Mdot
.96 .04719 Mdot
.96 .0472 Mdot
.96 .04775 Mdot
.96 .04786 Mdot
.96 .04832 Mdot
.96 .04862 Mdot
.96 .04896 Mdot
.96 .04916 Mdot
.96 .04944 Mdot
.96 .05031 Mdot
.96 .0512 Mdot
.96 .05131 Mdot
.96 .05268 Mdot
.96 .05304 Mdot
.96 .0534 Mdot
.96 .05353 Mdot
.96 .05529 Mdot
.96 .05562 Mdot
.96 .05586 Mdot
.96 .05593 Mdot
.96 .05606 Mdot
.96 .05619 Mdot
.96 .0562 Mdot
.96 .05693 Mdot
.96 .05736 Mdot
.96 .05754 Mdot
.96 .06045 Mdot
.96 .06156 Mdot
.96 .06253 Mdot
.96 .06301 Mdot
.96 .06369 Mdot
.96 .06398 Mdot
.96 .06413 Mdot
.96 .06646 Mdot
.96 .0667 Mdot
.96 .06845 Mdot
.96 .06863 Mdot
.96 .06891 Mdot
.96 .06972 Mdot
.96 .06993 Mdot
.96 .07016 Mdot
.96 .07022 Mdot
.96 .07102 Mdot
.96 .07114 Mdot
.96 .07171 Mdot
.96 .07185 Mdot
.96 .07348 Mdot
.96 .0737 Mdot
.96 .07371 Mdot
.96 .0738 Mdot
.96 .07457 Mdot
.96 .07488 Mdot
.96 .07498 Mdot
.96 .07616 Mdot
.96 .07658 Mdot
.96 .07674 Mdot
.96 .07759 Mdot
.96 .07862 Mdot
.96 .07877 Mdot
.96 .07942 Mdot
.96 .07974 Mdot
.96 .08041 Mdot
.96 .08089 Mdot
.96 .08169 Mdot
.96 .08172 Mdot
.96 .08313 Mdot
.96 .08321 Mdot
.96 .08382 Mdot
.96 .08411 Mdot
.96 .08463 Mdot
.96 .08474 Mdot
.96 .08504 Mdot
.96 .08582 Mdot
.96 .08595 Mdot
.96 .08595 Mdot
.96 .08596 Mdot
.96 .08608 Mdot
.96 .08633 Mdot
.96 .08677 Mdot
.96 .0869 Mdot
.96 .08697 Mdot
.96 .08712 Mdot
.96 .08723 Mdot
.96 .08725 Mdot
.96 .0879 Mdot
.96 .08805 Mdot
.96 .08809 Mdot
.96 .08839 Mdot
.96 .08848 Mdot
.96 .0885 Mdot
.96 .08888 Mdot
.96 .08892 Mdot
.96 .08979 Mdot
.96 .09123 Mdot
.96 .09145 Mdot
.96 .09221 Mdot
.96 .09257 Mdot
.96 .0928 Mdot
.96 .09365 Mdot
.96 .09369 Mdot
.96 .09512 Mdot
.96 .09555 Mdot
.96 .09569 Mdot
.96 .09588 Mdot
.96 .09596 Mdot
.96 .09647 Mdot
.96 .09672 Mdot
.96 .09723 Mdot
.96 .09747 Mdot
.96 .09766 Mdot
.96 .09831 Mdot
.96 .0989 Mdot
.96 .09979 Mdot
.96 .0998 Mdot
.96 .09994 Mdot
.96 .10016 Mdot
.96 .10064 Mdot
.96 .10072 Mdot
.96 .10178 Mdot
.96 .10191 Mdot
.96 .10291 Mdot
.96 .10542 Mdot
.96 .10551 Mdot
.96 .10583 Mdot
.96 .10607 Mdot
.96 .10751 Mdot
.96 .10778 Mdot
.96 .1078 Mdot
.96 .10843 Mdot
.96 .10893 Mdot
.96 .10918 Mdot
.96 .10956 Mdot
.96 .11019 Mdot
.96 .11186 Mdot
.96 .11244 Mdot
.96 .11258 Mdot
.96 .11263 Mdot
.96 .11266 Mdot
.96 .11414 Mdot
.96 .11424 Mdot
.96 .11439 Mdot
.96 .11449 Mdot
.96 .11498 Mdot
.96 .11503 Mdot
.96 .11565 Mdot
.96 .11574 Mdot
.96 .11607 Mdot
.96 .11666 Mdot
.96 .11701 Mdot
.96 .11817 Mdot
.96 .11828 Mdot
.96 .11863 Mdot
.96 .11994 Mdot
.96 .12026 Mdot
.96 .12051 Mdot
.96 .12184 Mdot
.96 .1223 Mdot
.96 .12307 Mdot
.96 .12312 Mdot
.96 .12371 Mdot
.96 .12442 Mdot
.96 .12558 Mdot
.96 .12565 Mdot
.96 .12591 Mdot
.96 .12624 Mdot
.96 .12766 Mdot
.96 .12867 Mdot
.96 .12962 Mdot
.96 .13072 Mdot
.96 .13079 Mdot
.96 .13108 Mdot
.96 .13203 Mdot
.96 .13213 Mdot
.96 .13218 Mdot
.96 .13266 Mdot
.96 .13312 Mdot
.96 .13318 Mdot
.96 .13463 Mdot
.96 .13481 Mdot
.96 .13555 Mdot
.96 .13646 Mdot
.96 .13649 Mdot
.96 .1371 Mdot
.96 .13834 Mdot
.96 .13843 Mdot
.96 .13884 Mdot
.96 .14044 Mdot
.96 .14114 Mdot
.96 .14139 Mdot
.96 .1415 Mdot
.96 .1427 Mdot
.96 .14338 Mdot
.96 .14439 Mdot
.96 .14513 Mdot
.96 .14654 Mdot
.96 .14743 Mdot
.96 .14774 Mdot
.96 .14796 Mdot
.96 .14866 Mdot
.96 .14925 Mdot
.96 .15052 Mdot
.96 .15088 Mdot
.96 .15098 Mdot
.96 .15275 Mdot
.96 .15533 Mdot
.96 .15565 Mdot
.96 .15593 Mdot
.96 .15688 Mdot
.96 .15813 Mdot
.96 .15859 Mdot
.96 .15969 Mdot
.96 .16059 Mdot
.96 .16165 Mdot
.96 .1636 Mdot
.96 .16462 Mdot
.96 .16574 Mdot
.96 .16658 Mdot
.96 .1668 Mdot
.96 .16726 Mdot
.96 .1677 Mdot
.96 .16772 Mdot
.96 .16798 Mdot
.96 .16861 Mdot
.96 .17022 Mdot
.96 .17033 Mdot
.96 .17167 Mdot
.96 .17227 Mdot
.96 .17262 Mdot
.96 .17318 Mdot
.96 .17326 Mdot
.96 .17485 Mdot
.96 .17562 Mdot
.96 .18208 Mdot
.96 .18353 Mdot
.96 .18437 Mdot
.96 .18481 Mdot
.96 .1858 Mdot
.96 .18632 Mdot
.96 .18789 Mdot
.96 .18891 Mdot
.96 .18905 Mdot
.96 .18906 Mdot
.96 .19062 Mdot
.96 .19255 Mdot
.96 .19285 Mdot
.96 .19287 Mdot
.96 .19331 Mdot
.96 .19344 Mdot
.96 .19379 Mdot
.96 .19384 Mdot
.96 .19434 Mdot
.96 .19822 Mdot
.96 .20028 Mdot
.96 .20148 Mdot
.96 .20198 Mdot
.96 .20252 Mdot
.96 .20264 Mdot
.96 .20278 Mdot
.96 .20447 Mdot
.96 .20523 Mdot
.96 .20588 Mdot
.96 .20745 Mdot
.96 .20768 Mdot
.96 .20847 Mdot
.96 .20907 Mdot
.96 .20995 Mdot
.96 .21055 Mdot
.96 .21259 Mdot
.96 .21325 Mdot
.96 .21382 Mdot
.96 .21399 Mdot
.96 .214 Mdot
.96 .21413 Mdot
.96 .2142 Mdot
.96 .21498 Mdot
.96 .21676 Mdot
.96 .21716 Mdot
.96 .21897 Mdot
.96 .21942 Mdot
.96 .21964 Mdot
.96 .222 Mdot
.96 .22231 Mdot
.96 .22395 Mdot
.96 .22461 Mdot
.96 .22481 Mdot
.96 .22531 Mdot
.96 .22534 Mdot
.96 .22562 Mdot
.96 .22651 Mdot
.96 .22773 Mdot
.96 .22783 Mdot
.96 .22807 Mdot
.96 .22904 Mdot
.96 .22937 Mdot
.96 .23308 Mdot
.96 .23354 Mdot
.96 .23439 Mdot
.96 .2349 Mdot
.96 .23508 Mdot
.96 .23755 Mdot
.96 .23888 Mdot
.96 .23967 Mdot
.96 .24075 Mdot
.96 .24122 Mdot
.96 .24205 Mdot
.96 .24324 Mdot
.96 .24332 Mdot
.96 .24423 Mdot
.96 .24514 Mdot
.96 .24538 Mdot
.96 .24592 Mdot
.96 .24594 Mdot
.96 .2463 Mdot
.96 .24662 Mdot
.96 .24778 Mdot
.96 .24826 Mdot
.96 .24888 Mdot
.96 .25025 Mdot
.96 .25033 Mdot
.96 .25107 Mdot
.96 .25149 Mdot
.96 .25463 Mdot
.96 .25487 Mdot
.96 .25673 Mdot
.96 .25762 Mdot
.96 .2579 Mdot
.96 .25918 Mdot
.96 .25953 Mdot
.96 .25966 Mdot
.96 .26044 Mdot
.96 .26079 Mdot
.96 .26206 Mdot
.96 .26279 Mdot
.96 .26316 Mdot
.96 .26317 Mdot
.96 .26321 Mdot
.96 .26356 Mdot
.96 .26426 Mdot
.96 .26431 Mdot
.96 .26562 Mdot
.96 .26564 Mdot
.96 .26601 Mdot
.96 .26623 Mdot
.96 .26654 Mdot
.96 .26669 Mdot
.96 .267 Mdot
.96 .26707 Mdot
.96 .26756 Mdot
.96 .26804 Mdot
.96 .26902 Mdot
.96 .26945 Mdot
.96 .26956 Mdot
.96 .27046 Mdot
.96 .27075 Mdot
.96 .27081 Mdot
.96 .27122 Mdot
.96 .27191 Mdot
.96 .27206 Mdot
.96 .27215 Mdot
.96 .27461 Mdot
.96 .27667 Mdot
.96 .27847 Mdot
.96 .27859 Mdot
.96 .27886 Mdot
.96 .27951 Mdot
.96 .28122 Mdot
.96 .28173 Mdot
.96 .28272 Mdot
.96 .2828 Mdot
.96 .28346 Mdot
.96 .28435 Mdot
.96 .28477 Mdot
.96 .28592 Mdot
.96 .28603 Mdot
.96 .28732 Mdot
.96 .28862 Mdot
.96 .29018 Mdot
.96 .29131 Mdot
.96 .29143 Mdot
.96 .29182 Mdot
.96 .29186 Mdot
.96 .29236 Mdot
.96 .29238 Mdot
.96 .29261 Mdot
.96 .2935 Mdot
.96 .29397 Mdot
.96 .29407 Mdot
.96 .29459 Mdot
.96 .29479 Mdot
.96 .29623 Mdot
.96 .29668 Mdot
.96 .29691 Mdot
.96 .29746 Mdot
.96 .29813 Mdot
.96 .29931 Mdot
.96 .30077 Mdot
.96 .301 Mdot
.96 .30166 Mdot
.96 .30349 Mdot
.96 .30354 Mdot
.96 .30392 Mdot
.96 .30402 Mdot
.96 .30454 Mdot
.96 .3059 Mdot
.96 .30611 Mdot
.96 .30909 Mdot
.96 .30922 Mdot
.96 .30945 Mdot
.96 .31019 Mdot
.96 .31225 Mdot
.96 .31366 Mdot
.96 .31413 Mdot
.96 .31917 Mdot
.96 .31942 Mdot
.96 .32 Mdot
.96 .3203 Mdot
.96 .32096 Mdot
.96 .32185 Mdot
.96 .32467 Mdot
.96 .32487 Mdot
.96 .3256 Mdot
.96 .32567 Mdot
.96 .3264 Mdot
.96 .32663 Mdot
.96 .32738 Mdot
.96 .32851 Mdot
.96 .32872 Mdot
.96 .32873 Mdot
.96 .32939 Mdot
.96 .33019 Mdot
.96 .33043 Mdot
.96 .33073 Mdot
.96 .3321 Mdot
.96 .33256 Mdot
.96 .33266 Mdot
.96 .33302 Mdot
.96 .33391 Mdot
.96 .33656 Mdot
.96 .3369 Mdot
.96 .3381 Mdot
.96 .33831 Mdot
.96 .33848 Mdot
.96 .33861 Mdot
.96 .33869 Mdot
.96 .3387 Mdot
.96 .34202 Mdot
.96 .34259 Mdot
.96 .34287 Mdot
.96 .34326 Mdot
.96 .34351 Mdot
.96 .3448 Mdot
.96 .34494 Mdot
.96 .34655 Mdot
.96 .34666 Mdot
.96 .34678 Mdot
.96 .34765 Mdot
.96 .34858 Mdot
.96 .34863 Mdot
.96 .34916 Mdot
.96 .34921 Mdot
.96 .34979 Mdot
.96 .35007 Mdot
.96 .35305 Mdot
.96 .35308 Mdot
.96 .35336 Mdot
.96 .35349 Mdot
.96 .35391 Mdot
.96 .35425 Mdot
.96 .35667 Mdot
.96 .35761 Mdot
.96 .35843 Mdot
.96 .35905 Mdot
.96 .36008 Mdot
.96 .36226 Mdot
.96 .36242 Mdot
.96 .36359 Mdot
.96 .36551 Mdot
.96 .36564 Mdot
.96 .36584 Mdot
.96 .36642 Mdot
.96 .36712 Mdot
.96 .36825 Mdot
.96 .3689 Mdot
.96 .36966 Mdot
.96 .37176 Mdot
.96 .37178 Mdot
.96 .37194 Mdot
.96 .37259 Mdot
.96 .3734 Mdot
.96 .37643 Mdot
.96 .37688 Mdot
.96 .3771 Mdot
.96 .37782 Mdot
.96 .37934 Mdot
.96 .38075 Mdot
.96 .38107 Mdot
.96 .38165 Mdot
.96 .38431 Mdot
.96 .38447 Mdot
.96 .38518 Mdot
.96 .38743 Mdot
.96 .38767 Mdot
.96 .3878 Mdot
.96 .38822 Mdot
.96 .38895 Mdot
.96 .39004 Mdot
.96 .39017 Mdot
.96 .39208 Mdot
.96 .3936 Mdot
.96 .39402 Mdot
.96 .39485 Mdot
.96 .39577 Mdot
.96 .39581 Mdot
.96 .39726 Mdot
.96 .39788 Mdot
.96 .39796 Mdot
.96 .39937 Mdot
.96 .3994 Mdot
.96 .40224 Mdot
.96 .40245 Mdot
.96 .40338 Mdot
.96 .40463 Mdot
.96 .40533 Mdot
.96 .40704 Mdot
.96 .40777 Mdot
.96 .40863 Mdot
.96 .40919 Mdot
.96 .40944 Mdot
.96 .41169 Mdot
.96 .41213 Mdot
.96 .41317 Mdot
.96 .41367 Mdot
.96 .41429 Mdot
.96 .4146 Mdot
.96 .41579 Mdot
.96 .4159 Mdot
.96 .41691 Mdot
.96 .41754 Mdot
.96 .41833 Mdot
.96 .41958 Mdot
.96 .42064 Mdot
.96 .42076 Mdot
.96 .42216 Mdot
.96 .4226 Mdot
.96 .42328 Mdot
.96 .42374 Mdot
.96 .42527 Mdot
.96 .42619 Mdot
.96 .42653 Mdot
.96 .42662 Mdot
.96 .42852 Mdot
.96 .42926 Mdot
.96 .43004 Mdot
.96 .43024 Mdot
.96 .4309 Mdot
.96 .43309 Mdot
.96 .434 Mdot
.96 .43562 Mdot
.96 .43578 Mdot
.96 .43665 Mdot
.96 .43673 Mdot
.96 .43845 Mdot
.96 .43938 Mdot
.96 .44005 Mdot
.96 .44028 Mdot
.96 .44063 Mdot
.96 .44115 Mdot
.96 .44259 Mdot
.96 .44414 Mdot
.96 .4445 Mdot
.96 .44514 Mdot
.96 .44607 Mdot
.96 .44671 Mdot
.96 .44828 Mdot
.96 .44888 Mdot
.96 .4501 Mdot
.96 .45221 Mdot
.96 .45286 Mdot
.96 .45606 Mdot
.96 .45805 Mdot
.96 .45913 Mdot
.96 .46021 Mdot
.96 .46039 Mdot
.96 .46185 Mdot
.96 .46227 Mdot
.96 .46315 Mdot
.96 .46398 Mdot
.96 .46401 Mdot
.96 .46443 Mdot
.96 .46451 Mdot
.96 .46571 Mdot
.96 .46674 Mdot
.96 .46786 Mdot
.96 .46874 Mdot
.96 .46894 Mdot
.96 .4708 Mdot
.96 .47144 Mdot
.96 .47198 Mdot
.96 .47255 Mdot
.96 .47319 Mdot
.96 .4737 Mdot
.96 .47423 Mdot
.96 .47437 Mdot
.96 .47487 Mdot
.96 .47553 Mdot
.96 .47727 Mdot
.96 .47834 Mdot
.96 .47865 Mdot
.96 .48092 Mdot
.96 .48184 Mdot
.96 .48246 Mdot
.96 .48287 Mdot
.96 .48405 Mdot
.96 .48568 Mdot
.96 .48865 Mdot
.96 .48878 Mdot
.96 .48999 Mdot
.96 .49029 Mdot
.96 .49056 Mdot
.96 .49245 Mdot
.96 .4933 Mdot
.96 .49387 Mdot
.96 .4946 Mdot
.96 .49484 Mdot
.96 .49626 Mdot
.96 .49712 Mdot
.96 .49846 Mdot
.96 .49954 Mdot
.96 .4997 Mdot
.96 .49987 Mdot
.96 .50114 Mdot
.96 .50136 Mdot
.96 .50158 Mdot
.96 .5016 Mdot
.96 .50234 Mdot
.96 .50411 Mdot
.96 .50537 Mdot
.96 .50552 Mdot
.96 .50605 Mdot
.96 .50717 Mdot
.96 .5075 Mdot
.96 .50764 Mdot
.96 .50767 Mdot
.96 .50836 Mdot
.96 .50856 Mdot
.96 .5091 Mdot
.96 .50918 Mdot
.96 .50988 Mdot
.96 .50996 Mdot
.96 .5106 Mdot
.96 .51163 Mdot
.96 .51231 Mdot
.96 .51444 Mdot
.96 .51461 Mdot
.96 .51586 Mdot
.96 .51621 Mdot
.96 .51806 Mdot
.96 .5189 Mdot
.96 .51921 Mdot
.96 .52014 Mdot
.96 .52065 Mdot
.96 .52138 Mdot
.96 .52159 Mdot
.96 .52176 Mdot
.96 .52215 Mdot
.96 .52233 Mdot
.96 .52252 Mdot
.96 .52345 Mdot
.96 .5239 Mdot
.96 .52478 Mdot
.96 .52493 Mdot
.96 .52549 Mdot
.96 .526 Mdot
.96 .5269 Mdot
.96 .52693 Mdot
.96 .52755 Mdot
.96 .52908 Mdot
.96 .52939 Mdot
.96 .53046 Mdot
.96 .53062 Mdot
.96 .53096 Mdot
.96 .53127 Mdot
.96 .53172 Mdot
.96 .53245 Mdot
.96 .53287 Mdot
.96 .53325 Mdot
.96 .53383 Mdot
.96 .53593 Mdot
.96 .53607 Mdot
.96 .53678 Mdot
.96 .53699 Mdot
.96 .53752 Mdot
.96 .53774 Mdot
.96 .53775 Mdot
.96 .53792 Mdot
.96 .538 Mdot
.96 .53859 Mdot
.96 .539 Mdot
.96 .53977 Mdot
.96 .54002 Mdot
.96 .54123 Mdot
.96 .54173 Mdot
.96 .54354 Mdot
.96 .54357 Mdot
.96 .54396 Mdot
.96 .54449 Mdot
.96 .54476 Mdot
.96 .54528 Mdot
.96 .54538 Mdot
.96 .54611 Mdot
.96 .54757 Mdot
.96 .54783 Mdot
.96 .54787 Mdot
.96 .54793 Mdot
.96 .54894 Mdot
.96 .54983 Mdot
.96 .5499 Mdot
.96 .55038 Mdot
.96 .55058 Mdot
.96 .55081 Mdot
.96 .55137 Mdot
.96 .55141 Mdot
.96 .55173 Mdot
.96 .5521 Mdot
.96 .55272 Mdot
.96 .55407 Mdot
.96 .55417 Mdot
.96 .55421 Mdot
.96 .55435 Mdot
.96 .55444 Mdot
.96 .5555 Mdot
.96 .55554 Mdot
.96 .55585 Mdot
.96 .55632 Mdot
.96 .55677 Mdot
.96 .5569 Mdot
.96 .55716 Mdot
.96 .55951 Mdot
.96 .55973 Mdot
.96 .5602 Mdot
.96 .56023 Mdot
.96 .56039 Mdot
.96 .56107 Mdot
.96 .56157 Mdot
.96 .56176 Mdot
.96 .56304 Mdot
.96 .56361 Mdot
.96 .56392 Mdot
.96 .56418 Mdot
.96 .56527 Mdot
.96 .56545 Mdot
.96 .56619 Mdot
.96 .5667 Mdot
.96 .5672 Mdot
.96 .56737 Mdot
.96 .56757 Mdot
.96 .56763 Mdot
.96 .56798 Mdot
.96 .56838 Mdot
.96 .56944 Mdot
.96 .56952 Mdot
.96 .57031 Mdot
.96 .57066 Mdot
.96 .5711 Mdot
.96 .57131 Mdot
.96 .57136 Mdot
.96 .57177 Mdot
.96 .57179 Mdot
.96 .57192 Mdot
.96 .57206 Mdot
.96 .57207 Mdot
.96 .5721 Mdot
.96 .57236 Mdot
.96 .57333 Mdot
.96 .57372 Mdot
.96 .57382 Mdot
.96 .57423 Mdot
.96 .57443 Mdot
.96 .57496 Mdot
.96 .57533 Mdot
.96 .57539 Mdot
.96 .57585 Mdot
.96 .57598 Mdot
.96 .5763 Mdot
.96 .5764 Mdot
.96 .57685 Mdot
.96 .577 Mdot
.96 .57709 Mdot
.96 .57853 Mdot
.96 .57867 Mdot
.96 .57885 Mdot
.96 .57938 Mdot
.96 .5795 Mdot
.96 .58018 Mdot
.96 .5808 Mdot
.96 .58099 Mdot
.96 .58103 Mdot
.96 .58173 Mdot
.96 .58187 Mdot
.96 .5821 Mdot
.96 .58215 Mdot
.96 .58219 Mdot
.96 .58269 Mdot
.96 .5827 Mdot
.96 .58293 Mdot
.96 .5833 Mdot
.96 .58375 Mdot
.96 .58421 Mdot
.96 .58443 Mdot
.96 .58444 Mdot
.96 .58447 Mdot
.96 .58468 Mdot
.96 .58482 Mdot
.96 .58503 Mdot
.96 .58511 Mdot
.96 .58514 Mdot
.96 .58528 Mdot
.96 .58536 Mdot
.96 .58552 Mdot
.96 .58554 Mdot
.96 .58592 Mdot
.96 .58593 Mdot
.96 .58614 Mdot
.96 .58627 Mdot
.96 .58645 Mdot
.96 .58653 Mdot
.96 .58671 Mdot
.96 .58675 Mdot
.96 .58702 Mdot
.96 .58725 Mdot
.96 .58729 Mdot
.96 .5874 Mdot
.96 .58772 Mdot
.96 .58774 Mdot
.96 .58783 Mdot
.96 .58803 Mdot
.96 .58806 Mdot
.96 .58806 Mdot
.96 .58812 Mdot
.96 .58855 Mdot
.96 .58859 Mdot
.96 .58874 Mdot
.96 .58877 Mdot
.96 .58898 Mdot
.96 .589 Mdot
.96 .58906 Mdot
.96 .58911 Mdot
.96 .58933 Mdot
.96 .5894 Mdot
.96 .58945 Mdot
.96 .58991 Mdot
.96 .58998 Mdot
.96 .59059 Mdot
.96 .59063 Mdot
.96 .59071 Mdot
.96 .59089 Mdot
.96 .59101 Mdot
.96 .59127 Mdot
.96 .59156 Mdot
.96 .59232 Mdot
.96 .59237 Mdot
.96 .59248 Mdot
.96 .59267 Mdot
.96 .59267 Mdot
.96 .59271 Mdot
.96 .59274 Mdot
.96 .59276 Mdot
.96 .59282 Mdot
.96 .59291 Mdot
.96 .59337 Mdot
.96 .5934 Mdot
.96 .5935 Mdot
.96 .59359 Mdot
.96 .59395 Mdot
.96 .59398 Mdot
.96 .59421 Mdot
.96 .59443 Mdot
.96 .59451 Mdot
.96 .59465 Mdot
.96 .59472 Mdot
.96 .59484 Mdot
.96 .59487 Mdot
.96 .59502 Mdot
.96 .59502 Mdot
.96 .59505 Mdot
.96 .59543 Mdot
.96 .59544 Mdot
.96 .59552 Mdot
.96 .59559 Mdot
.96 .59581 Mdot
.96 .59581 Mdot
.96 .59599 Mdot
.96 .59599 Mdot
.96 .59605 Mdot
.96 .59622 Mdot
.96 .59634 Mdot
.96 .5965 Mdot
.96 .59652 Mdot
.96 .59653 Mdot
.96 .59657 Mdot
.96 .59662 Mdot
.96 .59663 Mdot
.96 .59674 Mdot
.96 .59674 Mdot
.96 .59675 Mdot
.96 .59676 Mdot
.96 .5968 Mdot
.96 .59692 Mdot
.96 .59696 Mdot
.96 .59699 Mdot
.96 .59708 Mdot
.96 .59711 Mdot
.96 .59721 Mdot
.96 .59725 Mdot
.96 .5975 Mdot
.96 .59751 Mdot
.96 .59758 Mdot
.96 .59762 Mdot
.96 .59765 Mdot
.96 .59771 Mdot
.96 .59775 Mdot
.96 .5978 Mdot
.96 .59781 Mdot
.96 .59788 Mdot
.96 .59792 Mdot
.96 .59798 Mdot
.96 .59815 Mdot
.96 .59818 Mdot
.96 .59825 Mdot
.96 .5984 Mdot
.96 .59841 Mdot
.96 .59843 Mdot
.96 .59844 Mdot
.96 .59844 Mdot
.96 .59847 Mdot
.96 .59848 Mdot
.96 .59854 Mdot
.96 .59855 Mdot
.96 .59855 Mdot
.96 .5986 Mdot
.96 .59861 Mdot
.96 .59861 Mdot
.96 .59861 Mdot
.962 .03234 Mdot
.962 .03234 Mdot
.962 .03238 Mdot
.962 .03242 Mdot
.962 .03242 Mdot
.962 .0327 Mdot
.962 .03275 Mdot
.962 .03288 Mdot
.962 .0329 Mdot
.962 .03301 Mdot
.962 .03308 Mdot
.962 .03336 Mdot
.962 .03336 Mdot
.962 .0336 Mdot
.962 .03376 Mdot
.962 .03379 Mdot
.962 .03381 Mdot
.962 .03383 Mdot
.962 .03432 Mdot
.962 .03461 Mdot
.962 .03473 Mdot
.962 .03494 Mdot
.962 .03523 Mdot
.962 .03548 Mdot
.962 .03551 Mdot
.962 .03551 Mdot
.962 .03615 Mdot
.962 .03645 Mdot
.962 .0365 Mdot
.962 .03659 Mdot
.962 .03678 Mdot
.962 .03679 Mdot
.962 .037 Mdot
.962 .03757 Mdot
.962 .03788 Mdot
.962 .03849 Mdot
.962 .0387 Mdot
.962 .03895 Mdot
.962 .03922 Mdot
.962 .03956 Mdot
.962 .0397 Mdot
.962 .04004 Mdot
.962 .04041 Mdot
.962 .04067 Mdot
.962 .04085 Mdot
.962 .04132 Mdot
.962 .04225 Mdot
.962 .04267 Mdot
.962 .04272 Mdot
.962 .04325 Mdot
.962 .04332 Mdot
.962 .04343 Mdot
.962 .04346 Mdot
.962 .04357 Mdot
.962 .04384 Mdot
.962 .04386 Mdot
.962 .04387 Mdot
.962 .04425 Mdot
.962 .0449 Mdot
.962 .04505 Mdot
.962 .04505 Mdot
.962 .04581 Mdot
.962 .04589 Mdot
.962 .0462 Mdot
.962 .04624 Mdot
.962 .04654 Mdot
.962 .04729 Mdot
.962 .04789 Mdot
.962 .04804 Mdot
.962 .04828 Mdot
.962 .04876 Mdot
.962 .04895 Mdot
.962 .04948 Mdot
.962 .04949 Mdot
.962 .05003 Mdot
.962 .05062 Mdot
.962 .05069 Mdot
.962 .05107 Mdot
.962 .0514 Mdot
.962 .05151 Mdot
.962 .05163 Mdot
.962 .05176 Mdot
.962 .05181 Mdot
.962 .05246 Mdot
.962 .05393 Mdot
.962 .05484 Mdot
.962 .05534 Mdot
.962 .05619 Mdot
.962 .05639 Mdot
.962 .05678 Mdot
.962 .05774 Mdot
.962 .05916 Mdot
.962 .05918 Mdot
.962 .06067 Mdot
.962 .06102 Mdot
.962 .062 Mdot
.962 .06204 Mdot
.962 .06254 Mdot
.962 .06319 Mdot
.962 .06385 Mdot
.962 .06413 Mdot
.962 .06629 Mdot
.962 .06648 Mdot
.962 .06665 Mdot
.962 .06666 Mdot
.962 .06684 Mdot
.962 .06701 Mdot
.962 .0678 Mdot
.962 .06864 Mdot
.962 .06872 Mdot
.962 .0714 Mdot
.962 .07147 Mdot
.962 .07204 Mdot
.962 .0722 Mdot
.962 .07255 Mdot
.962 .07292 Mdot
.962 .07332 Mdot
.962 .0738 Mdot
.962 .07397 Mdot
.962 .07474 Mdot
.962 .07537 Mdot
.962 .07728 Mdot
.962 .07896 Mdot
.962 .08118 Mdot
.962 .08258 Mdot
.962 .08261 Mdot
.962 .0827 Mdot
.962 .08273 Mdot
.962 .08289 Mdot
.962 .0829 Mdot
.962 .08304 Mdot
.962 .08314 Mdot
.962 .08325 Mdot
.962 .08392 Mdot
.962 .08402 Mdot
.962 .08412 Mdot
.962 .08458 Mdot
.962 .08469 Mdot
.962 .0851 Mdot
.962 .08533 Mdot
.962 .08546 Mdot
.962 .08638 Mdot
.962 .08639 Mdot
.962 .08646 Mdot
.962 .08703 Mdot
.962 .08729 Mdot
.962 .0877 Mdot
.962 .08786 Mdot
.962 .088 Mdot
.962 .08806 Mdot
.962 .08815 Mdot
.962 .08825 Mdot
.962 .08903 Mdot
.962 .08961 Mdot
.962 .08997 Mdot
.962 .09053 Mdot
.962 .09104 Mdot
.962 .09112 Mdot
.962 .09146 Mdot
.962 .09217 Mdot
.962 .09224 Mdot
.962 .09313 Mdot
.962 .09333 Mdot
.962 .09363 Mdot
.962 .09422 Mdot
.962 .09434 Mdot
.962 .09435 Mdot
.962 .09448 Mdot
.962 .0952 Mdot
.962 .096 Mdot
.962 .09611 Mdot
.962 .09673 Mdot
.962 .09726 Mdot
.962 .09729 Mdot
.962 .09782 Mdot
.962 .09784 Mdot
.962 .09799 Mdot
.962 .09833 Mdot
.962 .09903 Mdot
.962 .09905 Mdot
.962 .09907 Mdot
.962 .0995 Mdot
.962 .09983 Mdot
.962 .1001 Mdot
.962 .1003 Mdot
.962 .10106 Mdot
.962 .10107 Mdot
.962 .10192 Mdot
.962 .10304 Mdot
.962 .10353 Mdot
.962 .10435 Mdot
.962 .1053 Mdot
.962 .10606 Mdot
.962 .10642 Mdot
.962 .10697 Mdot
.962 .10726 Mdot
.962 .10793 Mdot
.962 .10808 Mdot
.962 .10893 Mdot
.962 .10916 Mdot
.962 .10925 Mdot
.962 .10934 Mdot
.962 .1097 Mdot
.962 .10974 Mdot
.962 .10999 Mdot
.962 .11062 Mdot
.962 .11087 Mdot
.962 .11093 Mdot
.962 .11167 Mdot
.962 .1117 Mdot
.962 .11189 Mdot
.962 .11226 Mdot
.962 .11319 Mdot
.962 .11387 Mdot
.962 .11428 Mdot
.962 .11508 Mdot
.962 .11515 Mdot
.962 .11555 Mdot
.962 .11625 Mdot
.962 .11791 Mdot
.962 .11841 Mdot
.962 .11892 Mdot
.962 .11912 Mdot
.962 .12001 Mdot
.962 .1204 Mdot
.962 .12059 Mdot
.962 .12059 Mdot
.962 .12168 Mdot
.962 .12248 Mdot
.962 .12252 Mdot
.962 .12277 Mdot
.962 .12314 Mdot
.962 .12326 Mdot
.962 .12327 Mdot
.962 .12366 Mdot
.962 .12373 Mdot
.962 .12396 Mdot
.962 .1243 Mdot
.962 .12461 Mdot
.962 .12468 Mdot
.962 .12471 Mdot
.962 .12471 Mdot
.962 .12519 Mdot
.962 .1254 Mdot
.962 .12545 Mdot
.962 .12606 Mdot
.962 .12841 Mdot
.962 .12892 Mdot
.962 .12893 Mdot
.962 .12895 Mdot
.962 .13008 Mdot
.962 .13054 Mdot
.962 .13089 Mdot
.962 .13164 Mdot
.962 .13192 Mdot
.962 .13303 Mdot
.962 .13317 Mdot
.962 .13422 Mdot
.962 .13538 Mdot
.962 .13545 Mdot
.962 .13557 Mdot
.962 .13689 Mdot
.962 .13853 Mdot
.962 .139 Mdot
.962 .13952 Mdot
.962 .14035 Mdot
.962 .14205 Mdot
.962 .14271 Mdot
.962 .14317 Mdot
.962 .1435 Mdot
.962 .14455 Mdot
.962 .14462 Mdot
.962 .14481 Mdot
.962 .14651 Mdot
.962 .14855 Mdot
.962 .14881 Mdot
.962 .14891 Mdot
.962 .15012 Mdot
.962 .15049 Mdot
.962 .15118 Mdot
.962 .15127 Mdot
.962 .15164 Mdot
.962 .15206 Mdot
.962 .15253 Mdot
.962 .15268 Mdot
.962 .15367 Mdot
.962 .15459 Mdot
.962 .15496 Mdot
.962 .15777 Mdot
.962 .15783 Mdot
.962 .15796 Mdot
.962 .16002 Mdot
.962 .16037 Mdot
.962 .16185 Mdot
.962 .16315 Mdot
.962 .16487 Mdot
.962 .16714 Mdot
.962 .16774 Mdot
.962 .16843 Mdot
.962 .16975 Mdot
.962 .17091 Mdot
.962 .17244 Mdot
.962 .17304 Mdot
.962 .17389 Mdot
.962 .17642 Mdot
.962 .17783 Mdot
.962 .17789 Mdot
.962 .17826 Mdot
.962 .18014 Mdot
.962 .18251 Mdot
.962 .18254 Mdot
.962 .18289 Mdot
.962 .18407 Mdot
.962 .1868 Mdot
.962 .18734 Mdot
.962 .18747 Mdot
.962 .18891 Mdot
.962 .18914 Mdot
.962 .18958 Mdot
.962 .18971 Mdot
.962 .19006 Mdot
.962 .19131 Mdot
.962 .19195 Mdot
.962 .19314 Mdot
.962 .19348 Mdot
.962 .1944 Mdot
.962 .19846 Mdot
.962 .20006 Mdot
.962 .20048 Mdot
.962 .20152 Mdot
.962 .20214 Mdot
.962 .20269 Mdot
.962 .20273 Mdot
.962 .20331 Mdot
.962 .20388 Mdot
.962 .20458 Mdot
.962 .20616 Mdot
.962 .20643 Mdot
.962 .20813 Mdot
.962 .20918 Mdot
.962 .20944 Mdot
.962 .21039 Mdot
.962 .21095 Mdot
.962 .21128 Mdot
.962 .21246 Mdot
.962 .21308 Mdot
.962 .2141 Mdot
.962 .21532 Mdot
.962 .21609 Mdot
.962 .21805 Mdot
.962 .21829 Mdot
.962 .21956 Mdot
.962 .22011 Mdot
.962 .22063 Mdot
.962 .22155 Mdot
.962 .22175 Mdot
.962 .22291 Mdot
.962 .22366 Mdot
.962 .22419 Mdot
.962 .22572 Mdot
.962 .22584 Mdot
.962 .22627 Mdot
.962 .22858 Mdot
.962 .22868 Mdot
.962 .22949 Mdot
.962 .2307 Mdot
.962 .23358 Mdot
.962 .23669 Mdot
.962 .23714 Mdot
.962 .24014 Mdot
.962 .24064 Mdot
.962 .24192 Mdot
.962 .24489 Mdot
.962 .24495 Mdot
.962 .24878 Mdot
.962 .24902 Mdot
.962 .24957 Mdot
.962 .25148 Mdot
.962 .25306 Mdot
.962 .25314 Mdot
.962 .25343 Mdot
.962 .25352 Mdot
.962 .25399 Mdot
.962 .25403 Mdot
.962 .25446 Mdot
.962 .25477 Mdot
.962 .25509 Mdot
.962 .25618 Mdot
.962 .25714 Mdot
.962 .25714 Mdot
.962 .25744 Mdot
.962 .25752 Mdot
.962 .25775 Mdot
.962 .25915 Mdot
.962 .25947 Mdot
.962 .25976 Mdot
.962 .26072 Mdot
.962 .2614 Mdot
.962 .26179 Mdot
.962 .26358 Mdot
.962 .26456 Mdot
.962 .2646 Mdot
.962 .26465 Mdot
.962 .2648 Mdot
.962 .26651 Mdot
.962 .2673 Mdot
.962 .26853 Mdot
.962 .2689 Mdot
.962 .26898 Mdot
.962 .26942 Mdot
.962 .2696 Mdot
.962 .26986 Mdot
.962 .27015 Mdot
.962 .27246 Mdot
.962 .27265 Mdot
.962 .2742 Mdot
.962 .27523 Mdot
.962 .27525 Mdot
.962 .27582 Mdot
.962 .27692 Mdot
.962 .27693 Mdot
.962 .2784 Mdot
.962 .27865 Mdot
.962 .27878 Mdot
.962 .27965 Mdot
.962 .28172 Mdot
.962 .28194 Mdot
.962 .28257 Mdot
.962 .283 Mdot
.962 .28341 Mdot
.962 .28434 Mdot
.962 .28452 Mdot
.962 .28512 Mdot
.962 .28598 Mdot
.962 .28601 Mdot
.962 .28627 Mdot
.962 .28771 Mdot
.962 .28805 Mdot
.962 .28806 Mdot
.962 .28845 Mdot
.962 .28862 Mdot
.962 .28913 Mdot
.962 .28958 Mdot
.962 .29052 Mdot
.962 .29101 Mdot
.962 .29121 Mdot
.962 .29284 Mdot
.962 .29315 Mdot
.962 .29345 Mdot
.962 .29491 Mdot
.962 .2957 Mdot
.962 .29602 Mdot
.962 .2963 Mdot
.962 .29644 Mdot
.962 .29651 Mdot
.962 .29804 Mdot
.962 .29804 Mdot
.962 .2981 Mdot
.962 .29852 Mdot
.962 .29949 Mdot
.962 .29972 Mdot
.962 .30033 Mdot
.962 .30148 Mdot
.962 .30153 Mdot
.962 .30158 Mdot
.962 .30208 Mdot
.962 .30278 Mdot
.962 .30279 Mdot
.962 .30372 Mdot
.962 .30449 Mdot
.962 .30504 Mdot
.962 .3072 Mdot
.962 .30723 Mdot
.962 .30875 Mdot
.962 .3096 Mdot
.962 .31029 Mdot
.962 .31272 Mdot
.962 .31366 Mdot
.962 .31409 Mdot
.962 .31636 Mdot
.962 .31896 Mdot
.962 .32106 Mdot
.962 .32203 Mdot
.962 .32353 Mdot
.962 .32432 Mdot
.962 .32559 Mdot
.962 .32576 Mdot
.962 .32614 Mdot
.962 .32655 Mdot
.962 .32886 Mdot
.962 .32948 Mdot
.962 .32961 Mdot
.962 .32971 Mdot
.962 .32996 Mdot
.962 .33091 Mdot
.962 .33104 Mdot
.962 .33104 Mdot
.962 .33169 Mdot
.962 .3323 Mdot
.962 .33339 Mdot
.962 .33407 Mdot
.962 .33421 Mdot
.962 .33461 Mdot
.962 .33551 Mdot
.962 .33578 Mdot
.962 .33602 Mdot
.962 .33618 Mdot
.962 .33628 Mdot
.962 .33677 Mdot
.962 .33778 Mdot
.962 .33871 Mdot
.962 .34024 Mdot
.962 .34201 Mdot
.962 .34309 Mdot
.962 .34399 Mdot
.962 .34518 Mdot
.962 .34528 Mdot
.962 .34537 Mdot
.962 .34548 Mdot
.962 .34599 Mdot
.962 .34643 Mdot
.962 .34647 Mdot
.962 .34785 Mdot
.962 .34826 Mdot
.962 .34881 Mdot
.962 .34982 Mdot
.962 .35254 Mdot
.962 .35382 Mdot
.962 .35489 Mdot
.962 .35514 Mdot
.962 .35543 Mdot
.962 .35566 Mdot
.962 .35599 Mdot
.962 .35688 Mdot
.962 .35771 Mdot
.962 .35792 Mdot
.962 .35893 Mdot
.962 .35939 Mdot
.962 .3594 Mdot
.962 .35962 Mdot
.962 .3601 Mdot
.962 .36216 Mdot
.962 .36389 Mdot
.962 .36419 Mdot
.962 .36428 Mdot
.962 .36491 Mdot
.962 .36584 Mdot
.962 .36613 Mdot
.962 .36616 Mdot
.962 .36714 Mdot
.962 .36732 Mdot
.962 .36757 Mdot
.962 .36788 Mdot
.962 .36808 Mdot
.962 .36874 Mdot
.962 .36917 Mdot
.962 .36937 Mdot
.962 .36951 Mdot
.962 .36967 Mdot
.962 .36975 Mdot
.962 .36976 Mdot
.962 .37094 Mdot
.962 .37133 Mdot
.962 .37148 Mdot
.962 .3716 Mdot
.962 .37311 Mdot
.962 .37411 Mdot
.962 .37559 Mdot
.962 .3757 Mdot
.962 .3781 Mdot
.962 .37887 Mdot
.962 .37915 Mdot
.962 .38012 Mdot
.962 .38013 Mdot
.962 .38017 Mdot
.962 .38291 Mdot
.962 .38401 Mdot
.962 .38487 Mdot
.962 .3856 Mdot
.962 .38613 Mdot
.962 .38666 Mdot
.962 .38734 Mdot
.962 .38913 Mdot
.962 .38932 Mdot
.962 .38997 Mdot
.962 .3903 Mdot
.962 .3928 Mdot
.962 .39342 Mdot
.962 .39497 Mdot
.962 .39521 Mdot
.962 .39552 Mdot
.962 .39569 Mdot
.962 .39596 Mdot
.962 .39904 Mdot
.962 .40103 Mdot
.962 .40284 Mdot
.962 .40391 Mdot
.962 .40509 Mdot
.962 .40699 Mdot
.962 .41083 Mdot
.962 .41146 Mdot
.962 .41233 Mdot
.962 .41325 Mdot
.962 .41336 Mdot
.962 .41368 Mdot
.962 .41409 Mdot
.962 .41484 Mdot
.962 .41495 Mdot
.962 .41643 Mdot
.962 .41658 Mdot
.962 .417 Mdot
.962 .4174 Mdot
.962 .41814 Mdot
.962 .41994 Mdot
.962 .42075 Mdot
.962 .4236 Mdot
.962 .42519 Mdot
.962 .42574 Mdot
.962 .42596 Mdot
.962 .42602 Mdot
.962 .42828 Mdot
.962 .42856 Mdot
.962 .42936 Mdot
.962 .43083 Mdot
.962 .43104 Mdot
.962 .43169 Mdot
.962 .4318 Mdot
.962 .4327 Mdot
.962 .43358 Mdot
.962 .4337 Mdot
.962 .43401 Mdot
.962 .43448 Mdot
.962 .4361 Mdot
.962 .43635 Mdot
.962 .43802 Mdot
.962 .43874 Mdot
.962 .43878 Mdot
.962 .44458 Mdot
.962 .44468 Mdot
.962 .44497 Mdot
.962 .44578 Mdot
.962 .44622 Mdot
.962 .44772 Mdot
.962 .44913 Mdot
.962 .44982 Mdot
.962 .45267 Mdot
.962 .45278 Mdot
.962 .45443 Mdot
.962 .45535 Mdot
.962 .45624 Mdot
.962 .45871 Mdot
.962 .45945 Mdot
.962 .45967 Mdot
.962 .4631 Mdot
.962 .46424 Mdot
.962 .46513 Mdot
.962 .46556 Mdot
.962 .46645 Mdot
.962 .46805 Mdot
.962 .4691 Mdot
.962 .47022 Mdot
.962 .47189 Mdot
.962 .47271 Mdot
.962 .47304 Mdot
.962 .47414 Mdot
.962 .47419 Mdot
.962 .47471 Mdot
.962 .47491 Mdot
.962 .47571 Mdot
.962 .48028 Mdot
.962 .48278 Mdot
.962 .48288 Mdot
.962 .48355 Mdot
.962 .48528 Mdot
.962 .48536 Mdot
.962 .48662 Mdot
.962 .48683 Mdot
.962 .48951 Mdot
.962 .48994 Mdot
.962 .49092 Mdot
.962 .49096 Mdot
.962 .49156 Mdot
.962 .49269 Mdot
.962 .49348 Mdot
.962 .49356 Mdot
.962 .49399 Mdot
.962 .4942 Mdot
.962 .49567 Mdot
.962 .49717 Mdot
.962 .49736 Mdot
.962 .49811 Mdot
.962 .49843 Mdot
.962 .49878 Mdot
.962 .499 Mdot
.962 .49921 Mdot
.962 .50118 Mdot
.962 .50156 Mdot
.962 .50193 Mdot
.962 .50246 Mdot
.962 .50265 Mdot
.962 .50284 Mdot
.962 .50292 Mdot
.962 .50341 Mdot
.962 .50542 Mdot
.962 .50643 Mdot
.962 .50652 Mdot
.962 .50662 Mdot
.962 .50696 Mdot
.962 .50782 Mdot
.962 .50829 Mdot
.962 .50882 Mdot
.962 .51025 Mdot
.962 .51031 Mdot
.962 .51465 Mdot
.962 .51587 Mdot
.962 .51642 Mdot
.962 .51854 Mdot
.962 .51879 Mdot
.962 .51941 Mdot
.962 .51962 Mdot
.962 .52021 Mdot
.962 .52082 Mdot
.962 .52092 Mdot
.962 .52103 Mdot
.962 .52181 Mdot
.962 .5226 Mdot
.962 .52266 Mdot
.962 .52316 Mdot
.962 .52332 Mdot
.962 .52349 Mdot
.962 .5243 Mdot
.962 .52439 Mdot
.962 .52497 Mdot
.962 .52529 Mdot
.962 .52542 Mdot
.962 .52557 Mdot
.962 .52687 Mdot
.962 .5275 Mdot
.962 .52787 Mdot
.962 .52807 Mdot
.962 .52894 Mdot
.962 .5302 Mdot
.962 .53162 Mdot
.962 .53198 Mdot
.962 .53324 Mdot
.962 .53399 Mdot
.962 .53411 Mdot
.962 .53443 Mdot
.962 .53597 Mdot
.962 .53659 Mdot
.962 .53677 Mdot
.962 .53809 Mdot
.962 .53811 Mdot
.962 .53948 Mdot
.962 .53964 Mdot
.962 .54061 Mdot
.962 .54174 Mdot
.962 .54304 Mdot
.962 .54333 Mdot
.962 .5442 Mdot
.962 .54488 Mdot
.962 .54554 Mdot
.962 .54617 Mdot
.962 .54725 Mdot
.962 .54749 Mdot
.962 .54787 Mdot
.962 .54818 Mdot
.962 .54838 Mdot
.962 .54874 Mdot
.962 .54884 Mdot
.962 .54902 Mdot
.962 .54971 Mdot
.962 .55032 Mdot
.962 .5508 Mdot
.962 .55206 Mdot
.962 .55218 Mdot
.962 .55267 Mdot
.962 .55429 Mdot
.962 .55464 Mdot
.962 .55522 Mdot
.962 .55532 Mdot
.962 .55536 Mdot
.962 .55556 Mdot
.962 .5562 Mdot
.962 .55747 Mdot
.962 .55748 Mdot
.962 .55818 Mdot
.962 .55874 Mdot
.962 .55929 Mdot
.962 .56004 Mdot
.962 .56047 Mdot
.962 .56092 Mdot
.962 .56202 Mdot
.962 .56357 Mdot
.962 .564 Mdot
.962 .5647 Mdot
.962 .56474 Mdot
.962 .56475 Mdot
.962 .56567 Mdot
.962 .56594 Mdot
.962 .56666 Mdot
.962 .56686 Mdot
.962 .56731 Mdot
.962 .56848 Mdot
.962 .56886 Mdot
.962 .56895 Mdot
.962 .57027 Mdot
.962 .57111 Mdot
.962 .57114 Mdot
.962 .57116 Mdot
.962 .57243 Mdot
.962 .57253 Mdot
.962 .57266 Mdot
.962 .57298 Mdot
.962 .57396 Mdot
.962 .57397 Mdot
.962 .57403 Mdot
.962 .57417 Mdot
.962 .57428 Mdot
.962 .57438 Mdot
.962 .57444 Mdot
.962 .57457 Mdot
.962 .57479 Mdot
.962 .57501 Mdot
.962 .57532 Mdot
.962 .57548 Mdot
.962 .57572 Mdot
.962 .57592 Mdot
.962 .57606 Mdot
.962 .57652 Mdot
.962 .57683 Mdot
.962 .57685 Mdot
.962 .57707 Mdot
.962 .57773 Mdot
.962 .57778 Mdot
.962 .57779 Mdot
.962 .57801 Mdot
.962 .57808 Mdot
.962 .57825 Mdot
.962 .57832 Mdot
.962 .57843 Mdot
.962 .57845 Mdot
.962 .57854 Mdot
.962 .57878 Mdot
.962 .579 Mdot
.962 .57923 Mdot
.962 .5798 Mdot
.962 .58002 Mdot
.962 .58069 Mdot
.962 .5807 Mdot
.962 .58091 Mdot
.962 .58096 Mdot
.962 .58112 Mdot
.962 .58125 Mdot
.962 .58157 Mdot
.962 .58173 Mdot
.962 .58173 Mdot
.962 .58204 Mdot
.962 .58207 Mdot
.962 .58229 Mdot
.962 .58249 Mdot
.962 .58272 Mdot
.962 .58285 Mdot
.962 .58311 Mdot
.962 .5834 Mdot
.962 .58356 Mdot
.962 .5838 Mdot
.962 .58396 Mdot
.962 .58417 Mdot
.962 .58432 Mdot
.962 .5845 Mdot
.962 .58465 Mdot
.962 .58492 Mdot
.962 .58531 Mdot
.962 .58552 Mdot
.962 .58554 Mdot
.962 .58557 Mdot
.962 .58566 Mdot
.962 .58607 Mdot
.962 .58666 Mdot
.962 .58711 Mdot
.962 .58762 Mdot
.962 .58779 Mdot
.962 .58799 Mdot
.962 .58804 Mdot
.962 .58817 Mdot
.962 .58827 Mdot
.962 .58837 Mdot
.962 .58846 Mdot
.962 .58851 Mdot
.962 .58866 Mdot
.962 .58868 Mdot
.962 .58938 Mdot
.962 .5894 Mdot
.962 .58963 Mdot
.962 .58983 Mdot
.962 .58988 Mdot
.962 .58993 Mdot
.962 .58993 Mdot
.962 .58998 Mdot
.962 .59003 Mdot
.962 .5906 Mdot
.962 .59067 Mdot
.962 .59101 Mdot
.962 .59115 Mdot
.962 .59116 Mdot
.962 .59141 Mdot
.962 .59151 Mdot
.962 .5919 Mdot
.962 .5919 Mdot
.962 .59227 Mdot
.962 .59253 Mdot
.962 .59263 Mdot
.962 .59268 Mdot
.962 .5929 Mdot
.962 .59303 Mdot
.962 .59327 Mdot
.962 .59365 Mdot
.962 .59382 Mdot
.962 .59383 Mdot
.962 .59387 Mdot
.962 .5939 Mdot
.962 .59393 Mdot
.962 .59401 Mdot
.962 .59411 Mdot
.962 .59413 Mdot
.962 .59428 Mdot
.962 .59442 Mdot
.962 .59443 Mdot
.962 .59456 Mdot
.962 .59461 Mdot
.962 .59474 Mdot
.962 .5948 Mdot
.962 .59484 Mdot
.962 .59499 Mdot
.962 .59519 Mdot
.962 .59527 Mdot
.962 .59528 Mdot
.962 .59536 Mdot
.962 .59538 Mdot
.962 .59557 Mdot
.962 .59558 Mdot
.962 .59561 Mdot
.962 .59578 Mdot
.962 .59588 Mdot
.962 .59588 Mdot
.962 .59589 Mdot
.962 .59596 Mdot
.962 .59599 Mdot
.962 .59599 Mdot
.962 .59602 Mdot
.962 .59604 Mdot
.962 .59618 Mdot
.962 .59619 Mdot
.962 .5963 Mdot
.962 .59654 Mdot
.962 .59666 Mdot
.962 .59671 Mdot
.962 .59677 Mdot
.962 .59687 Mdot
.962 .59696 Mdot
.962 .59699 Mdot
.962 .59708 Mdot
.962 .59715 Mdot
.962 .59721 Mdot
.962 .59727 Mdot
.962 .59743 Mdot
.962 .5975 Mdot
.962 .59765 Mdot
.962 .5977 Mdot
.962 .59771 Mdot
.962 .59776 Mdot
.962 .59778 Mdot
.962 .59779 Mdot
.962 .59787 Mdot
.962 .59803 Mdot
.962 .59803 Mdot
.962 .59804 Mdot
.962 .5981 Mdot
.962 .59818 Mdot
.962 .59823 Mdot
.962 .59826 Mdot
.962 .59834 Mdot
.962 .59846 Mdot
.962 .59847 Mdot
.962 .59847 Mdot
.962 .59848 Mdot
.962 .59852 Mdot
.962 .59858 Mdot
.962 .59858 Mdot
.962 .59866 Mdot
.962 .59867 Mdot
.962 .5987 Mdot
.962 .59871 Mdot
.962 .59874 Mdot
.962 .59875 Mdot
.962 .59882 Mdot
.962 .59882 Mdot
.962 .59884 Mdot
.962 .59884 Mdot
.962 .59885 Mdot
.964 .03142 Mdot
.964 .03142 Mdot
.964 .03142 Mdot
.964 .03144 Mdot
.964 .03144 Mdot
.964 .03145 Mdot
.964 .03146 Mdot
.964 .03147 Mdot
.964 .0315 Mdot
.964 .03152 Mdot
.964 .03153 Mdot
.964 .03174 Mdot
.964 .03176 Mdot
.964 .03185 Mdot
.964 .03199 Mdot
.964 .03202 Mdot
.964 .03202 Mdot
.964 .03221 Mdot
.964 .03236 Mdot
.964 .03247 Mdot
.964 .03261 Mdot
.964 .03262 Mdot
.964 .03264 Mdot
.964 .03271 Mdot
.964 .03274 Mdot
.964 .03332 Mdot
.964 .03335 Mdot
.964 .03338 Mdot
.964 .034 Mdot
.964 .034 Mdot
.964 .03406 Mdot
.964 .03409 Mdot
.964 .03414 Mdot
.964 .03424 Mdot
.964 .03444 Mdot
.964 .03444 Mdot
.964 .03455 Mdot
.964 .03521 Mdot
.964 .03525 Mdot
.964 .03526 Mdot
.964 .03561 Mdot
.964 .03575 Mdot
.964 .03578 Mdot
.964 .03585 Mdot
.964 .03609 Mdot
.964 .03615 Mdot
.964 .03616 Mdot
.964 .03633 Mdot
.964 .03649 Mdot
.964 .03654 Mdot
.964 .03703 Mdot
.964 .03704 Mdot
.964 .03716 Mdot
.964 .03757 Mdot
.964 .03789 Mdot
.964 .03816 Mdot
.964 .03868 Mdot
.964 .03874 Mdot
.964 .03915 Mdot
.964 .03986 Mdot
.964 .04009 Mdot
.964 .04101 Mdot
.964 .04139 Mdot
.964 .04155 Mdot
.964 .04358 Mdot
.964 .04405 Mdot
.964 .04439 Mdot
.964 .04465 Mdot
.964 .04477 Mdot
.964 .04586 Mdot
.964 .04597 Mdot
.964 .04612 Mdot
.964 .04628 Mdot
.964 .04633 Mdot
.964 .0465 Mdot
.964 .04782 Mdot
.964 .04905 Mdot
.964 .04941 Mdot
.964 .0497 Mdot
.964 .04987 Mdot
.964 .05391 Mdot
.964 .05446 Mdot
.964 .05545 Mdot
.964 .0566 Mdot
.964 .05744 Mdot
.964 .05791 Mdot
.964 .05865 Mdot
.964 .05872 Mdot
.964 .05958 Mdot
.964 .05959 Mdot
.964 .05972 Mdot
.964 .06081 Mdot
.964 .0612 Mdot
.964 .06142 Mdot
.964 .06143 Mdot
.964 .06211 Mdot
.964 .06218 Mdot
.964 .06242 Mdot
.964 .06284 Mdot
.964 .06435 Mdot
.964 .06442 Mdot
.964 .0648 Mdot
.964 .06503 Mdot
.964 .06538 Mdot
.964 .06607 Mdot
.964 .06689 Mdot
.964 .06723 Mdot
.964 .06724 Mdot
.964 .06954 Mdot
.964 .07244 Mdot
.964 .07253 Mdot
.964 .07292 Mdot
.964 .07342 Mdot
.964 .07387 Mdot
.964 .07437 Mdot
.964 .07918 Mdot
.964 .07919 Mdot
.964 .07919 Mdot
.964 .07925 Mdot
.964 .07926 Mdot
.964 .0793 Mdot
.964 .07932 Mdot
.964 .07935 Mdot
.964 .07946 Mdot
.964 .07953 Mdot
.964 .07957 Mdot
.964 .07958 Mdot
.964 .08036 Mdot
.964 .08045 Mdot
.964 .08079 Mdot
.964 .0809 Mdot
.964 .08116 Mdot
.964 .0813 Mdot
.964 .08141 Mdot
.964 .08142 Mdot
.964 .08145 Mdot
.964 .08188 Mdot
.964 .08211 Mdot
.964 .08217 Mdot
.964 .0827 Mdot
.964 .08299 Mdot
.964 .08311 Mdot
.964 .08325 Mdot
.964 .08362 Mdot
.964 .08366 Mdot
.964 .08375 Mdot
.964 .08398 Mdot
.964 .0841 Mdot
.964 .0846 Mdot
.964 .08527 Mdot
.964 .08622 Mdot
.964 .08626 Mdot
.964 .08638 Mdot
.964 .08649 Mdot
.964 .0888 Mdot
.964 .0888 Mdot
.964 .08886 Mdot
.964 .08901 Mdot
.964 .08913 Mdot
.964 .08931 Mdot
.964 .08968 Mdot
.964 .08987 Mdot
.964 .08999 Mdot
.964 .09041 Mdot
.964 .09043 Mdot
.964 .09085 Mdot
.964 .0911 Mdot
.964 .09132 Mdot
.964 .09327 Mdot
.964 .09342 Mdot
.964 .09345 Mdot
.964 .09477 Mdot
.964 .09482 Mdot
.964 .09528 Mdot
.964 .09536 Mdot
.964 .09563 Mdot
.964 .09646 Mdot
.964 .09651 Mdot
.964 .09675 Mdot
.964 .09677 Mdot
.964 .09693 Mdot
.964 .09712 Mdot
.964 .0974 Mdot
.964 .09801 Mdot
.964 .09816 Mdot
.964 .09816 Mdot
.964 .09864 Mdot
.964 .09866 Mdot
.964 .09916 Mdot
.964 .09955 Mdot
.964 .09998 Mdot
.964 .10002 Mdot
.964 .10044 Mdot
.964 .10107 Mdot
.964 .10134 Mdot
.964 .10161 Mdot
.964 .10197 Mdot
.964 .10205 Mdot
.964 .10234 Mdot
.964 .10312 Mdot
.964 .10412 Mdot
.964 .10527 Mdot
.964 .1053 Mdot
.964 .10533 Mdot
.964 .1056 Mdot
.964 .10602 Mdot
.964 .10623 Mdot
.964 .10648 Mdot
.964 .10651 Mdot
.964 .1072 Mdot
.964 .10747 Mdot
.964 .10772 Mdot
.964 .10977 Mdot
.964 .10985 Mdot
.964 .11031 Mdot
.964 .11036 Mdot
.964 .11116 Mdot
.964 .11377 Mdot
.964 .11377 Mdot
.964 .1138 Mdot
.964 .11432 Mdot
.964 .11448 Mdot
.964 .1148 Mdot
.964 .11585 Mdot
.964 .11641 Mdot
.964 .11677 Mdot
.964 .118 Mdot
.964 .12053 Mdot
.964 .12064 Mdot
.964 .1208 Mdot
.964 .12095 Mdot
.964 .12188 Mdot
.964 .12206 Mdot
.964 .12313 Mdot
.964 .12373 Mdot
.964 .12429 Mdot
.964 .1254 Mdot
.964 .12546 Mdot
.964 .12646 Mdot
.964 .12662 Mdot
.964 .12756 Mdot
.964 .12797 Mdot
.964 .12963 Mdot
.964 .12966 Mdot
.964 .13019 Mdot
.964 .13042 Mdot
.964 .13066 Mdot
.964 .13187 Mdot
.964 .13224 Mdot
.964 .13251 Mdot
.964 .13279 Mdot
.964 .13334 Mdot
.964 .13354 Mdot
.964 .13378 Mdot
.964 .13413 Mdot
.964 .13733 Mdot
.964 .13781 Mdot
.964 .13787 Mdot
.964 .13821 Mdot
.964 .13824 Mdot
.964 .13879 Mdot
.964 .13891 Mdot
.964 .13938 Mdot
.964 .14005 Mdot
.964 .14028 Mdot
.964 .14052 Mdot
.964 .14073 Mdot
.964 .14084 Mdot
.964 .14097 Mdot
.964 .14158 Mdot
.964 .14161 Mdot
.964 .14163 Mdot
.964 .14313 Mdot
.964 .14364 Mdot
.964 .1439 Mdot
.964 .14439 Mdot
.964 .14539 Mdot
.964 .14597 Mdot
.964 .14671 Mdot
.964 .14918 Mdot
.964 .14991 Mdot
.964 .15433 Mdot
.964 .15645 Mdot
.964 .15664 Mdot
.964 .15778 Mdot
.964 .15999 Mdot
.964 .16189 Mdot
.964 .16331 Mdot
.964 .16349 Mdot
.964 .16431 Mdot
.964 .1653 Mdot
.964 .16786 Mdot
.964 .16807 Mdot
.964 .16923 Mdot
.964 .16979 Mdot
.964 .16982 Mdot
.964 .17117 Mdot
.964 .17173 Mdot
.964 .17208 Mdot
.964 .17367 Mdot
.964 .17368 Mdot
.964 .17619 Mdot
.964 .17642 Mdot
.964 .17712 Mdot
.964 .17931 Mdot
.964 .17935 Mdot
.964 .17976 Mdot
.964 .18021 Mdot
.964 .18195 Mdot
.964 .18345 Mdot
.964 .18476 Mdot
.964 .18505 Mdot
.964 .1851 Mdot
.964 .18547 Mdot
.964 .1855 Mdot
.964 .18627 Mdot
.964 .18694 Mdot
.964 .18742 Mdot
.964 .18777 Mdot
.964 .18802 Mdot
.964 .18882 Mdot
.964 .18977 Mdot
.964 .19022 Mdot
.964 .19292 Mdot
.964 .19433 Mdot
.964 .19455 Mdot
.964 .1952 Mdot
.964 .19543 Mdot
.964 .19623 Mdot
.964 .19669 Mdot
.964 .19744 Mdot
.964 .19835 Mdot
.964 .1986 Mdot
.964 .19877 Mdot
.964 .20085 Mdot
.964 .20137 Mdot
.964 .20357 Mdot
.964 .20403 Mdot
.964 .20465 Mdot
.964 .20468 Mdot
.964 .20931 Mdot
.964 .20999 Mdot
.964 .21217 Mdot
.964 .21471 Mdot
.964 .2157 Mdot
.964 .21848 Mdot
.964 .22076 Mdot
.964 .22149 Mdot
.964 .22175 Mdot
.964 .223 Mdot
.964 .22459 Mdot
.964 .22602 Mdot
.964 .22723 Mdot
.964 .22761 Mdot
.964 .22978 Mdot
.964 .23204 Mdot
.964 .23414 Mdot
.964 .23465 Mdot
.964 .23575 Mdot
.964 .2377 Mdot
.964 .23805 Mdot
.964 .2381 Mdot
.964 .23875 Mdot
.964 .24198 Mdot
.964 .24269 Mdot
.964 .2427 Mdot
.964 .24271 Mdot
.964 .24291 Mdot
.964 .24295 Mdot
.964 .24298 Mdot
.964 .24305 Mdot
.964 .24313 Mdot
.964 .2432 Mdot
.964 .24357 Mdot
.964 .24378 Mdot
.964 .2439 Mdot
.964 .24392 Mdot
.964 .24407 Mdot
.964 .24523 Mdot
.964 .24634 Mdot
.964 .2466 Mdot
.964 .24767 Mdot
.964 .248 Mdot
.964 .2484 Mdot
.964 .2488 Mdot
.964 .24923 Mdot
.964 .24955 Mdot
.964 .24961 Mdot
.964 .2497 Mdot
.964 .25102 Mdot
.964 .25172 Mdot
.964 .25189 Mdot
.964 .25209 Mdot
.964 .25351 Mdot
.964 .2544 Mdot
.964 .2545 Mdot
.964 .25475 Mdot
.964 .2552 Mdot
.964 .25634 Mdot
.964 .25645 Mdot
.964 .25662 Mdot
.964 .25672 Mdot
.964 .25742 Mdot
.964 .25777 Mdot
.964 .25882 Mdot
.964 .2593 Mdot
.964 .26073 Mdot
.964 .26082 Mdot
.964 .26133 Mdot
.964 .26176 Mdot
.964 .26289 Mdot
.964 .26359 Mdot
.964 .26419 Mdot
.964 .2643 Mdot
.964 .26467 Mdot
.964 .26499 Mdot
.964 .26854 Mdot
.964 .26876 Mdot
.964 .269 Mdot
.964 .27189 Mdot
.964 .27189 Mdot
.964 .27207 Mdot
.964 .27251 Mdot
.964 .27288 Mdot
.964 .2734 Mdot
.964 .27451 Mdot
.964 .27508 Mdot
.964 .27543 Mdot
.964 .27667 Mdot
.964 .27671 Mdot
.964 .27716 Mdot
.964 .27744 Mdot
.964 .27796 Mdot
.964 .27869 Mdot
.964 .27933 Mdot
.964 .28248 Mdot
.964 .2826 Mdot
.964 .28281 Mdot
.964 .28401 Mdot
.964 .28504 Mdot
.964 .28517 Mdot
.964 .28547 Mdot
.964 .28556 Mdot
.964 .28709 Mdot
.964 .2875 Mdot
.964 .28939 Mdot
.964 .28954 Mdot
.964 .28992 Mdot
.964 .29086 Mdot
.964 .29111 Mdot
.964 .29188 Mdot
.964 .29426 Mdot
.964 .29441 Mdot
.964 .29442 Mdot
.964 .29508 Mdot
.964 .29514 Mdot
.964 .29561 Mdot
.964 .29616 Mdot
.964 .2962 Mdot
.964 .29696 Mdot
.964 .29833 Mdot
.964 .29868 Mdot
.964 .29913 Mdot
.964 .29913 Mdot
.964 .30047 Mdot
.964 .30054 Mdot
.964 .30196 Mdot
.964 .30204 Mdot
.964 .30305 Mdot
.964 .30357 Mdot
.964 .30425 Mdot
.964 .30427 Mdot
.964 .30439 Mdot
.964 .30556 Mdot
.964 .30703 Mdot
.964 .30733 Mdot
.964 .30773 Mdot
.964 .30811 Mdot
.964 .30878 Mdot
.964 .30884 Mdot
.964 .30895 Mdot
.964 .30985 Mdot
.964 .31009 Mdot
.964 .3102 Mdot
.964 .3109 Mdot
.964 .31259 Mdot
.964 .31305 Mdot
.964 .31532 Mdot
.964 .31573 Mdot
.964 .31575 Mdot
.964 .31582 Mdot
.964 .31763 Mdot
.964 .31901 Mdot
.964 .31908 Mdot
.964 .31916 Mdot
.964 .31971 Mdot
.964 .31992 Mdot
.964 .321 Mdot
.964 .32106 Mdot
.964 .32163 Mdot
.964 .32198 Mdot
.964 .32232 Mdot
.964 .32241 Mdot
.964 .32266 Mdot
.964 .3243 Mdot
.964 .32468 Mdot
.964 .32501 Mdot
.964 .32562 Mdot
.964 .32569 Mdot
.964 .33124 Mdot
.964 .33147 Mdot
.964 .33156 Mdot
.964 .33269 Mdot
.964 .33281 Mdot
.964 .33496 Mdot
.964 .33834 Mdot
.964 .34188 Mdot
.964 .34189 Mdot
.964 .34196 Mdot
.964 .34282 Mdot
.964 .34295 Mdot
.964 .34334 Mdot
.964 .34338 Mdot
.964 .34376 Mdot
.964 .34459 Mdot
.964 .34484 Mdot
.964 .34496 Mdot
.964 .34734 Mdot
.964 .3488 Mdot
.964 .34884 Mdot
.964 .34974 Mdot
.964 .35219 Mdot
.964 .35279 Mdot
.964 .35291 Mdot
.964 .35324 Mdot
.964 .35473 Mdot
.964 .35675 Mdot
.964 .35939 Mdot
.964 .35958 Mdot
.964 .35966 Mdot
.964 .36007 Mdot
.964 .36026 Mdot
.964 .36046 Mdot
.964 .3612 Mdot
.964 .36281 Mdot
.964 .36282 Mdot
.964 .36294 Mdot
.964 .36327 Mdot
.964 .36449 Mdot
.964 .3647 Mdot
.964 .36594 Mdot
.964 .36595 Mdot
.964 .36745 Mdot
.964 .36837 Mdot
.964 .36886 Mdot
.964 .37144 Mdot
.964 .37162 Mdot
.964 .37177 Mdot
.964 .37239 Mdot
.964 .37424 Mdot
.964 .37462 Mdot
.964 .37597 Mdot
.964 .37694 Mdot
.964 .37771 Mdot
.964 .37793 Mdot
.964 .38198 Mdot
.964 .38204 Mdot
.964 .38332 Mdot
.964 .38388 Mdot
.964 .38429 Mdot
.964 .38445 Mdot
.964 .38501 Mdot
.964 .38687 Mdot
.964 .38737 Mdot
.964 .38824 Mdot
.964 .38858 Mdot
.964 .38876 Mdot
.964 .3889 Mdot
.964 .38955 Mdot
.964 .39087 Mdot
.964 .39133 Mdot
.964 .3919 Mdot
.964 .39272 Mdot
.964 .39787 Mdot
.964 .40021 Mdot
.964 .40079 Mdot
.964 .40133 Mdot
.964 .40146 Mdot
.964 .40174 Mdot
.964 .40224 Mdot
.964 .40232 Mdot
.964 .4025 Mdot
.964 .40357 Mdot
.964 .40385 Mdot
.964 .40414 Mdot
.964 .40494 Mdot
.964 .40647 Mdot
.964 .40699 Mdot
.964 .40754 Mdot
.964 .40802 Mdot
.964 .40827 Mdot
.964 .40855 Mdot
.964 .40994 Mdot
.964 .40999 Mdot
.964 .41006 Mdot
.964 .41205 Mdot
.964 .41212 Mdot
.964 .41343 Mdot
.964 .41372 Mdot
.964 .41457 Mdot
.964 .41515 Mdot
.964 .41624 Mdot
.964 .41807 Mdot
.964 .41844 Mdot
.964 .4186 Mdot
.964 .41973 Mdot
.964 .42003 Mdot
.964 .42125 Mdot
.964 .42135 Mdot
.964 .4223 Mdot
.964 .423 Mdot
.964 .42672 Mdot
.964 .42779 Mdot
.964 .42792 Mdot
.964 .42829 Mdot
.964 .43015 Mdot
.964 .43192 Mdot
.964 .43215 Mdot
.964 .43385 Mdot
.964 .43481 Mdot
.964 .43566 Mdot
.964 .43765 Mdot
.964 .44203 Mdot
.964 .44243 Mdot
.964 .44476 Mdot
.964 .44582 Mdot
.964 .4466 Mdot
.964 .44703 Mdot
.964 .44924 Mdot
.964 .4493 Mdot
.964 .44972 Mdot
.964 .45293 Mdot
.964 .45304 Mdot
.964 .45361 Mdot
.964 .45585 Mdot
.964 .4562 Mdot
.964 .4578 Mdot
.964 .45802 Mdot
.964 .45914 Mdot
.964 .45935 Mdot
.964 .45973 Mdot
.964 .46465 Mdot
.964 .46506 Mdot
.964 .46551 Mdot
.964 .46631 Mdot
.964 .46642 Mdot
.964 .46725 Mdot
.964 .46829 Mdot
.964 .46836 Mdot
.964 .47057 Mdot
.964 .47089 Mdot
.964 .47137 Mdot
.964 .47193 Mdot
.964 .47257 Mdot
.964 .47281 Mdot
.964 .47477 Mdot
.964 .47548 Mdot
.964 .47551 Mdot
.964 .479 Mdot
.964 .47971 Mdot
.964 .48004 Mdot
.964 .48045 Mdot
.964 .48171 Mdot
.964 .48558 Mdot
.964 .48565 Mdot
.964 .48637 Mdot
.964 .48714 Mdot
.964 .48744 Mdot
.964 .49016 Mdot
.964 .49086 Mdot
.964 .49232 Mdot
.964 .4927 Mdot
.964 .49394 Mdot
.964 .49491 Mdot
.964 .4954 Mdot
.964 .49549 Mdot
.964 .4961 Mdot
.964 .49615 Mdot
.964 .49679 Mdot
.964 .49716 Mdot
.964 .49743 Mdot
.964 .49854 Mdot
.964 .49932 Mdot
.964 .49991 Mdot
.964 .50008 Mdot
.964 .50031 Mdot
.964 .50161 Mdot
.964 .50309 Mdot
.964 .50314 Mdot
.964 .50369 Mdot
.964 .50386 Mdot
.964 .50391 Mdot
.964 .5056 Mdot
.964 .50814 Mdot
.964 .51034 Mdot
.964 .51069 Mdot
.964 .51143 Mdot
.964 .51168 Mdot
.964 .51204 Mdot
.964 .5125 Mdot
.964 .51326 Mdot
.964 .51394 Mdot
.964 .51395 Mdot
.964 .5141 Mdot
.964 .51508 Mdot
.964 .51594 Mdot
.964 .51639 Mdot
.964 .51645 Mdot
.964 .51682 Mdot
.964 .51707 Mdot
.964 .51806 Mdot
.964 .5183 Mdot
.964 .51884 Mdot
.964 .52015 Mdot
.964 .5209 Mdot
.964 .52152 Mdot
.964 .52308 Mdot
.964 .52392 Mdot
.964 .52406 Mdot
.964 .52472 Mdot
.964 .52512 Mdot
.964 .52553 Mdot
.964 .5256 Mdot
.964 .52564 Mdot
.964 .52736 Mdot
.964 .52745 Mdot
.964 .5302 Mdot
.964 .53029 Mdot
.964 .53036 Mdot
.964 .53201 Mdot
.964 .53224 Mdot
.964 .53262 Mdot
.964 .53293 Mdot
.964 .53296 Mdot
.964 .53359 Mdot
.964 .53431 Mdot
.964 .53501 Mdot
.964 .5358 Mdot
.964 .537 Mdot
.964 .53803 Mdot
.964 .5384 Mdot
.964 .53876 Mdot
.964 .53908 Mdot
.964 .54012 Mdot
.964 .54032 Mdot
.964 .54034 Mdot
.964 .54045 Mdot
.964 .54108 Mdot
.964 .54143 Mdot
.964 .54159 Mdot
.964 .54226 Mdot
.964 .54298 Mdot
.964 .54378 Mdot
.964 .54582 Mdot
.964 .54653 Mdot
.964 .5474 Mdot
.964 .5477 Mdot
.964 .54916 Mdot
.964 .551 Mdot
.964 .55181 Mdot
.964 .5526 Mdot
.964 .55273 Mdot
.964 .55337 Mdot
.964 .55388 Mdot
.964 .55395 Mdot
.964 .55438 Mdot
.964 .55533 Mdot
.964 .55603 Mdot
.964 .55617 Mdot
.964 .55638 Mdot
.964 .55672 Mdot
.964 .55674 Mdot
.964 .55766 Mdot
.964 .55818 Mdot
.964 .5591 Mdot
.964 .56012 Mdot
.964 .56069 Mdot
.964 .56086 Mdot
.964 .56126 Mdot
.964 .56127 Mdot
.964 .56177 Mdot
.964 .56183 Mdot
.964 .56287 Mdot
.964 .56311 Mdot
.964 .56316 Mdot
.964 .56477 Mdot
.964 .5651 Mdot
.964 .56515 Mdot
.964 .56577 Mdot
.964 .56704 Mdot
.964 .56725 Mdot
.964 .56796 Mdot
.964 .56876 Mdot
.964 .56883 Mdot
.964 .56941 Mdot
.964 .56941 Mdot
.964 .56942 Mdot
.964 .56959 Mdot
.964 .56963 Mdot
.964 .56966 Mdot
.964 .56972 Mdot
.964 .56979 Mdot
.964 .56986 Mdot
.964 .57004 Mdot
.964 .57018 Mdot
.964 .57037 Mdot
.964 .57038 Mdot
.964 .57047 Mdot
.964 .57049 Mdot
.964 .57063 Mdot
.964 .57163 Mdot
.964 .57199 Mdot
.964 .57251 Mdot
.964 .57258 Mdot
.964 .57264 Mdot
.964 .57279 Mdot
.964 .5728 Mdot
.964 .57369 Mdot
.964 .57397 Mdot
.964 .57429 Mdot
.964 .57462 Mdot
.964 .57492 Mdot
.964 .57497 Mdot
.964 .57523 Mdot
.964 .57527 Mdot
.964 .57531 Mdot
.964 .57534 Mdot
.964 .57605 Mdot
.964 .57639 Mdot
.964 .57693 Mdot
.964 .57707 Mdot
.964 .57721 Mdot
.964 .57722 Mdot
.964 .57722 Mdot
.964 .57816 Mdot
.964 .5783 Mdot
.964 .57832 Mdot
.964 .57895 Mdot
.964 .57903 Mdot
.964 .57922 Mdot
.964 .57922 Mdot
.964 .57947 Mdot
.964 .57954 Mdot
.964 .57955 Mdot
.964 .57956 Mdot
.964 .58036 Mdot
.964 .58044 Mdot
.964 .58056 Mdot
.964 .58063 Mdot
.964 .58071 Mdot
.964 .58112 Mdot
.964 .58122 Mdot
.964 .58136 Mdot
.964 .58137 Mdot
.964 .5815 Mdot
.964 .58178 Mdot
.964 .58183 Mdot
.964 .58196 Mdot
.964 .58208 Mdot
.964 .5824 Mdot
.964 .58335 Mdot
.964 .58341 Mdot
.964 .58371 Mdot
.964 .58374 Mdot
.964 .58402 Mdot
.964 .58473 Mdot
.964 .58498 Mdot
.964 .58516 Mdot
.964 .58552 Mdot
.964 .58559 Mdot
.964 .58581 Mdot
.964 .58589 Mdot
.964 .586 Mdot
.964 .58608 Mdot
.964 .58615 Mdot
.964 .58651 Mdot
.964 .58789 Mdot
.964 .58803 Mdot
.964 .58815 Mdot
.964 .58828 Mdot
.964 .58838 Mdot
.964 .5884 Mdot
.964 .58917 Mdot
.964 .58978 Mdot
.964 .58978 Mdot
.964 .58987 Mdot
.964 .59009 Mdot
.964 .59027 Mdot
.964 .59036 Mdot
.964 .59042 Mdot
.964 .59053 Mdot
.964 .59054 Mdot
.964 .59094 Mdot
.964 .59105 Mdot
.964 .59111 Mdot
.964 .59113 Mdot
.964 .59131 Mdot
.964 .59131 Mdot
.964 .59137 Mdot
.964 .59147 Mdot
.964 .59176 Mdot
.964 .59179 Mdot
.964 .5918 Mdot
.964 .59202 Mdot
.964 .59204 Mdot
.964 .59223 Mdot
.964 .59236 Mdot
.964 .59257 Mdot
.964 .59288 Mdot
.964 .59313 Mdot
.964 .59328 Mdot
.964 .59433 Mdot
.964 .59437 Mdot
.964 .59445 Mdot
.964 .59454 Mdot
.964 .59486 Mdot
.964 .5952 Mdot
.964 .59525 Mdot
.964 .59526 Mdot
.964 .5953 Mdot
.964 .59534 Mdot
.964 .59537 Mdot
.964 .59565 Mdot
.964 .59568 Mdot
.964 .59575 Mdot
.964 .59584 Mdot
.964 .59596 Mdot
.964 .59648 Mdot
.964 .59652 Mdot
.964 .59662 Mdot
.964 .59686 Mdot
.964 .59692 Mdot
.964 .5971 Mdot
.964 .59721 Mdot
.964 .59722 Mdot
.964 .59735 Mdot
.964 .59743 Mdot
.964 .59751 Mdot
.964 .59761 Mdot
.964 .59764 Mdot
.964 .59764 Mdot
.964 .59777 Mdot
.964 .59778 Mdot
.964 .59782 Mdot
.964 .59787 Mdot
.964 .59787 Mdot
.964 .59789 Mdot
.964 .59795 Mdot
.964 .59797 Mdot
.964 .59797 Mdot
.964 .59801 Mdot
.964 .5981 Mdot
.964 .5981 Mdot
.964 .59811 Mdot
.964 .59828 Mdot
.964 .59831 Mdot
.964 .59831 Mdot
.964 .59836 Mdot
.964 .59839 Mdot
.964 .5984 Mdot
.964 .59841 Mdot
.964 .59842 Mdot
.964 .59842 Mdot
.964 .59858 Mdot
.964 .59859 Mdot
.964 .5986 Mdot
.964 .59875 Mdot
.964 .59875 Mdot
.964 .59877 Mdot
.964 .59878 Mdot
.964 .59878 Mdot
.964 .59881 Mdot
.964 .59884 Mdot
.964 .59888 Mdot
.964 .59893 Mdot
.964 .59893 Mdot
.964 .59894 Mdot
.964 .59897 Mdot
.964 .599 Mdot
.964 .599 Mdot
.964 .59905 Mdot
.964 .59906 Mdot
.964 .59906 Mdot
.964 .59907 Mdot
.964 .59907 Mdot
.964 .59907 Mdot
.964 .59908 Mdot
.964 .59908 Mdot
.964 .59908 Mdot
.964 .59908 Mdot
.964 .59908 Mdot
.966 .03053 Mdot
.966 .03054 Mdot
.966 .03058 Mdot
.966 .03058 Mdot
.966 .03062 Mdot
.966 .03063 Mdot
.966 .03066 Mdot
.966 .03097 Mdot
.966 .03099 Mdot
.966 .03102 Mdot
.966 .03116 Mdot
.966 .03124 Mdot
.966 .03126 Mdot
.966 .0313 Mdot
.966 .0314 Mdot
.966 .0314 Mdot
.966 .03157 Mdot
.966 .03163 Mdot
.966 .03174 Mdot
.966 .03179 Mdot
.966 .03197 Mdot
.966 .03204 Mdot
.966 .03229 Mdot
.966 .03236 Mdot
.966 .03238 Mdot
.966 .03287 Mdot
.966 .03288 Mdot
.966 .03301 Mdot
.966 .0333 Mdot
.966 .03395 Mdot
.966 .03395 Mdot
.966 .03407 Mdot
.966 .03407 Mdot
.966 .03434 Mdot
.966 .03481 Mdot
.966 .03513 Mdot
.966 .0352 Mdot
.966 .0352 Mdot
.966 .03527 Mdot
.966 .03543 Mdot
.966 .03605 Mdot
.966 .03608 Mdot
.966 .03619 Mdot
.966 .03619 Mdot
.966 .03624 Mdot
.966 .03656 Mdot
.966 .03684 Mdot
.966 .03706 Mdot
.966 .0386 Mdot
.966 .0388 Mdot
.966 .03892 Mdot
.966 .04024 Mdot
.966 .04047 Mdot
.966 .04071 Mdot
.966 .04083 Mdot
.966 .04253 Mdot
.966 .04253 Mdot
.966 .04417 Mdot
.966 .0446 Mdot
.966 .04518 Mdot
.966 .04549 Mdot
.966 .0455 Mdot
.966 .04582 Mdot
.966 .04627 Mdot
.966 .0464 Mdot
.966 .04645 Mdot
.966 .04703 Mdot
.966 .04747 Mdot
.966 .04754 Mdot
.966 .04756 Mdot
.966 .04768 Mdot
.966 .04788 Mdot
.966 .04809 Mdot
.966 .04827 Mdot
.966 .04959 Mdot
.966 .05051 Mdot
.966 .0512 Mdot
.966 .05167 Mdot
.966 .05224 Mdot
.966 .0537 Mdot
.966 .05438 Mdot
.966 .05473 Mdot
.966 .05501 Mdot
.966 .05611 Mdot
.966 .05677 Mdot
.966 .05719 Mdot
.966 .05741 Mdot
.966 .05752 Mdot
.966 .05928 Mdot
.966 .0594 Mdot
.966 .06148 Mdot
.966 .06158 Mdot
.966 .06254 Mdot
.966 .06449 Mdot
.966 .06462 Mdot
.966 .06638 Mdot
.966 .06668 Mdot
.966 .067 Mdot
.966 .06703 Mdot
.966 .06712 Mdot
.966 .06827 Mdot
.966 .06851 Mdot
.966 .06921 Mdot
.966 .06983 Mdot
.966 .07057 Mdot
.966 .07133 Mdot
.966 .07442 Mdot
.966 .07585 Mdot
.966 .07589 Mdot
.966 .0759 Mdot
.966 .07604 Mdot
.966 .07604 Mdot
.966 .07621 Mdot
.966 .07623 Mdot
.966 .07635 Mdot
.966 .07753 Mdot
.966 .07759 Mdot
.966 .07768 Mdot
.966 .07823 Mdot
.966 .07852 Mdot
.966 .0786 Mdot
.966 .07862 Mdot
.966 .07875 Mdot
.966 .07912 Mdot
.966 .07913 Mdot
.966 .07919 Mdot
.966 .07976 Mdot
.966 .07998 Mdot
.966 .08039 Mdot
.966 .08058 Mdot
.966 .08094 Mdot
.966 .08122 Mdot
.966 .08125 Mdot
.966 .08154 Mdot
.966 .08222 Mdot
.966 .08244 Mdot
.966 .08244 Mdot
.966 .08272 Mdot
.966 .08278 Mdot
.966 .08354 Mdot
.966 .08462 Mdot
.966 .08466 Mdot
.966 .08489 Mdot
.966 .08516 Mdot
.966 .08622 Mdot
.966 .08863 Mdot
.966 .08865 Mdot
.966 .08908 Mdot
.966 .0891 Mdot
.966 .08966 Mdot
.966 .09009 Mdot
.966 .09158 Mdot
.966 .09182 Mdot
.966 .09253 Mdot
.966 .09258 Mdot
.966 .09272 Mdot
.966 .093 Mdot
.966 .09326 Mdot
.966 .09326 Mdot
.966 .09335 Mdot
.966 .09351 Mdot
.966 .09364 Mdot
.966 .09413 Mdot
.966 .09479 Mdot
.966 .09616 Mdot
.966 .09642 Mdot
.966 .09651 Mdot
.966 .09692 Mdot
.966 .09692 Mdot
.966 .09695 Mdot
.966 .09712 Mdot
.966 .09737 Mdot
.966 .09827 Mdot
.966 .09931 Mdot
.966 .09937 Mdot
.966 .10006 Mdot
.966 .1001 Mdot
.966 .10086 Mdot
.966 .10104 Mdot
.966 .10194 Mdot
.966 .10203 Mdot
.966 .10249 Mdot
.966 .10351 Mdot
.966 .10371 Mdot
.966 .10575 Mdot
.966 .10648 Mdot
.966 .10694 Mdot
.966 .10806 Mdot
.966 .10811 Mdot
.966 .10861 Mdot
.966 .11094 Mdot
.966 .11097 Mdot
.966 .11174 Mdot
.966 .11255 Mdot
.966 .1128 Mdot
.966 .11286 Mdot
.966 .11327 Mdot
.966 .11342 Mdot
.966 .11387 Mdot
.966 .11455 Mdot
.966 .1159 Mdot
.966 .11873 Mdot
.966 .11998 Mdot
.966 .11999 Mdot
.966 .12001 Mdot
.966 .12105 Mdot
.966 .12131 Mdot
.966 .12153 Mdot
.966 .12311 Mdot
.966 .12406 Mdot
.966 .12587 Mdot
.966 .12608 Mdot
.966 .12692 Mdot
.966 .12736 Mdot
.966 .12742 Mdot
.966 .12894 Mdot
.966 .12915 Mdot
.966 .12947 Mdot
.966 .13059 Mdot
.966 .13063 Mdot
.966 .13177 Mdot
.966 .13268 Mdot
.966 .13275 Mdot
.966 .13291 Mdot
.966 .13336 Mdot
.966 .1334 Mdot
.966 .13383 Mdot
.966 .134 Mdot
.966 .13499 Mdot
.966 .13502 Mdot
.966 .13604 Mdot
.966 .13761 Mdot
.966 .13787 Mdot
.966 .13792 Mdot
.966 .13836 Mdot
.966 .13904 Mdot
.966 .13979 Mdot
.966 .14044 Mdot
.966 .14053 Mdot
.966 .14109 Mdot
.966 .14125 Mdot
.966 .14142 Mdot
.966 .1417 Mdot
.966 .14487 Mdot
.966 .1449 Mdot
.966 .14506 Mdot
.966 .14532 Mdot
.966 .14613 Mdot
.966 .14641 Mdot
.966 .14721 Mdot
.966 .14755 Mdot
.966 .14828 Mdot
.966 .15013 Mdot
.966 .15067 Mdot
.966 .15201 Mdot
.966 .15227 Mdot
.966 .15233 Mdot
.966 .1543 Mdot
.966 .15568 Mdot
.966 .15586 Mdot
.966 .15666 Mdot
.966 .15733 Mdot
.966 .15746 Mdot
.966 .15919 Mdot
.966 .15933 Mdot
.966 .16122 Mdot
.966 .1617 Mdot
.966 .16179 Mdot
.966 .16241 Mdot
.966 .16289 Mdot
.966 .16383 Mdot
.966 .16568 Mdot
.966 .1672 Mdot
.966 .16762 Mdot
.966 .16984 Mdot
.966 .16985 Mdot
.966 .17087 Mdot
.966 .17105 Mdot
.966 .17116 Mdot
.966 .17127 Mdot
.966 .17132 Mdot
.966 .1714 Mdot
.966 .17203 Mdot
.966 .1724 Mdot
.966 .17316 Mdot
.966 .17319 Mdot
.966 .17471 Mdot
.966 .17484 Mdot
.966 .17526 Mdot
.966 .1753 Mdot
.966 .17606 Mdot
.966 .17835 Mdot
.966 .17876 Mdot
.966 .18096 Mdot
.966 .18337 Mdot
.966 .18574 Mdot
.966 .18607 Mdot
.966 .18877 Mdot
.966 .18913 Mdot
.966 .18929 Mdot
.966 .18937 Mdot
.966 .19075 Mdot
.966 .19143 Mdot
.966 .19177 Mdot
.966 .1935 Mdot
.966 .19458 Mdot
.966 .19493 Mdot
.966 .19573 Mdot
.966 .19619 Mdot
.966 .19869 Mdot
.966 .19985 Mdot
.966 .2002 Mdot
.966 .20196 Mdot
.966 .20238 Mdot
.966 .20294 Mdot
.966 .20398 Mdot
.966 .2041 Mdot
.966 .20437 Mdot
.966 .20813 Mdot
.966 .20887 Mdot
.966 .2089 Mdot
.966 .20916 Mdot
.966 .21083 Mdot
.966 .21116 Mdot
.966 .21118 Mdot
.966 .21317 Mdot
.966 .21445 Mdot
.966 .21556 Mdot
.966 .21801 Mdot
.966 .2182 Mdot
.966 .21894 Mdot
.966 .22048 Mdot
.966 .22261 Mdot
.966 .22487 Mdot
.966 .22775 Mdot
.966 .22785 Mdot
.966 .22848 Mdot
.966 .23236 Mdot
.966 .23237 Mdot
.966 .23249 Mdot
.966 .23253 Mdot
.966 .23297 Mdot
.966 .23298 Mdot
.966 .23351 Mdot
.966 .23355 Mdot
.966 .23394 Mdot
.966 .2347 Mdot
.966 .23515 Mdot
.966 .23611 Mdot
.966 .23762 Mdot
.966 .23782 Mdot
.966 .23807 Mdot
.966 .23812 Mdot
.966 .23916 Mdot
.966 .23981 Mdot
.966 .24061 Mdot
.966 .24071 Mdot
.966 .24096 Mdot
.966 .24105 Mdot
.966 .24144 Mdot
.966 .24244 Mdot
.966 .24258 Mdot
.966 .24263 Mdot
.966 .24281 Mdot
.966 .24458 Mdot
.966 .24527 Mdot
.966 .24534 Mdot
.966 .24651 Mdot
.966 .24711 Mdot
.966 .24726 Mdot
.966 .24754 Mdot
.966 .24822 Mdot
.966 .24855 Mdot
.966 .24909 Mdot
.966 .24916 Mdot
.966 .24925 Mdot
.966 .25006 Mdot
.966 .25214 Mdot
.966 .25216 Mdot
.966 .25282 Mdot
.966 .25283 Mdot
.966 .25368 Mdot
.966 .25387 Mdot
.966 .25551 Mdot
.966 .25558 Mdot
.966 .25615 Mdot
.966 .25618 Mdot
.966 .25691 Mdot
.966 .25812 Mdot
.966 .25844 Mdot
.966 .25898 Mdot
.966 .25945 Mdot
.966 .25956 Mdot
.966 .26029 Mdot
.966 .26108 Mdot
.966 .26369 Mdot
.966 .26418 Mdot
.966 .26428 Mdot
.966 .26472 Mdot
.966 .26484 Mdot
.966 .26564 Mdot
.966 .26717 Mdot
.966 .26786 Mdot
.966 .26974 Mdot
.966 .27012 Mdot
.966 .2715 Mdot
.966 .27155 Mdot
.966 .27173 Mdot
.966 .27282 Mdot
.966 .2729 Mdot
.966 .2745 Mdot
.966 .27456 Mdot
.966 .27582 Mdot
.966 .28021 Mdot
.966 .28092 Mdot
.966 .283 Mdot
.966 .28313 Mdot
.966 .28329 Mdot
.966 .28354 Mdot
.966 .28393 Mdot
.966 .28438 Mdot
.966 .28441 Mdot
.966 .28452 Mdot
.966 .28487 Mdot
.966 .28513 Mdot
.966 .28514 Mdot
.966 .28539 Mdot
.966 .28586 Mdot
.966 .28622 Mdot
.966 .28764 Mdot
.966 .28921 Mdot
.966 .28957 Mdot
.966 .2915 Mdot
.966 .29326 Mdot
.966 .29352 Mdot
.966 .29427 Mdot
.966 .29452 Mdot
.966 .29568 Mdot
.966 .29568 Mdot
.966 .29578 Mdot
.966 .29625 Mdot
.966 .29697 Mdot
.966 .29739 Mdot
.966 .29927 Mdot
.966 .29954 Mdot
.966 .3006 Mdot
.966 .30081 Mdot
.966 .30205 Mdot
.966 .3025 Mdot
.966 .30267 Mdot
.966 .3032 Mdot
.966 .30368 Mdot
.966 .30405 Mdot
.966 .30463 Mdot
.966 .30474 Mdot
.966 .30688 Mdot
.966 .30691 Mdot
.966 .30738 Mdot
.966 .30989 Mdot
.966 .31016 Mdot
.966 .31067 Mdot
.966 .31142 Mdot
.966 .31322 Mdot
.966 .31427 Mdot
.966 .31449 Mdot
.966 .31482 Mdot
.966 .31584 Mdot
.966 .31645 Mdot
.966 .31664 Mdot
.966 .31739 Mdot
.966 .31847 Mdot
.966 .3193 Mdot
.966 .32043 Mdot
.966 .32044 Mdot
.966 .32063 Mdot
.966 .32244 Mdot
.966 .32268 Mdot
.966 .32355 Mdot
.966 .32369 Mdot
.966 .32369 Mdot
.966 .32416 Mdot
.966 .32675 Mdot
.966 .32689 Mdot
.966 .32824 Mdot
.966 .3287 Mdot
.966 .33039 Mdot
.966 .33444 Mdot
.966 .3345 Mdot
.966 .3346 Mdot
.966 .33599 Mdot
.966 .33664 Mdot
.966 .33744 Mdot
.966 .33878 Mdot
.966 .33922 Mdot
.966 .33944 Mdot
.966 .33962 Mdot
.966 .34031 Mdot
.966 .34071 Mdot
.966 .34097 Mdot
.966 .3411 Mdot
.966 .34117 Mdot
.966 .34228 Mdot
.966 .34407 Mdot
.966 .34614 Mdot
.966 .34647 Mdot
.966 .34713 Mdot
.966 .34725 Mdot
.966 .34761 Mdot
.966 .34867 Mdot
.966 .35214 Mdot
.966 .35493 Mdot
.966 .35814 Mdot
.966 .35815 Mdot
.966 .35821 Mdot
.966 .36007 Mdot
.966 .36086 Mdot
.966 .36144 Mdot
.966 .3615 Mdot
.966 .36206 Mdot
.966 .36415 Mdot
.966 .36604 Mdot
.966 .3665 Mdot
.966 .36698 Mdot
.966 .36842 Mdot
.966 .37145 Mdot
.966 .37292 Mdot
.966 .37344 Mdot
.966 .3755 Mdot
.966 .3766 Mdot
.966 .37673 Mdot
.966 .3788 Mdot
.966 .38045 Mdot
.966 .38097 Mdot
.966 .38157 Mdot
.966 .38174 Mdot
.966 .3844 Mdot
.966 .38445 Mdot
.966 .38455 Mdot
.966 .38589 Mdot
.966 .38727 Mdot
.966 .38795 Mdot
.966 .38945 Mdot
.966 .38962 Mdot
.966 .39 Mdot
.966 .39076 Mdot
.966 .39105 Mdot
.966 .39115 Mdot
.966 .39217 Mdot
.966 .39248 Mdot
.966 .39258 Mdot
.966 .3949 Mdot
.966 .39498 Mdot
.966 .39551 Mdot
.966 .39638 Mdot
.966 .39736 Mdot
.966 .39795 Mdot
.966 .39851 Mdot
.966 .40102 Mdot
.966 .40162 Mdot
.966 .40173 Mdot
.966 .40198 Mdot
.966 .40275 Mdot
.966 .40312 Mdot
.966 .40431 Mdot
.966 .40479 Mdot
.966 .40512 Mdot
.966 .40529 Mdot
.966 .40602 Mdot
.966 .40701 Mdot
.966 .4075 Mdot
.966 .40758 Mdot
.966 .40771 Mdot
.966 .409 Mdot
.966 .40936 Mdot
.966 .40973 Mdot
.966 .41036 Mdot
.966 .41046 Mdot
.966 .41085 Mdot
.966 .41153 Mdot
.966 .41382 Mdot
.966 .41396 Mdot
.966 .41707 Mdot
.966 .41752 Mdot
.966 .41789 Mdot
.966 .41846 Mdot
.966 .41857 Mdot
.966 .41866 Mdot
.966 .42024 Mdot
.966 .42085 Mdot
.966 .42116 Mdot
.966 .42148 Mdot
.966 .42162 Mdot
.966 .42167 Mdot
.966 .4221 Mdot
.966 .42257 Mdot
.966 .42262 Mdot
.966 .42331 Mdot
.966 .42334 Mdot
.966 .42493 Mdot
.966 .42589 Mdot
.966 .42703 Mdot
.966 .42744 Mdot
.966 .42749 Mdot
.966 .42893 Mdot
.966 .43009 Mdot
.966 .43293 Mdot
.966 .43349 Mdot
.966 .4336 Mdot
.966 .43641 Mdot
.966 .43775 Mdot
.966 .43811 Mdot
.966 .4386 Mdot
.966 .44041 Mdot
.966 .44062 Mdot
.966 .441 Mdot
.966 .44113 Mdot
.966 .44225 Mdot
.966 .44265 Mdot
.966 .44402 Mdot
.966 .44412 Mdot
.966 .44428 Mdot
.966 .44603 Mdot
.966 .44675 Mdot
.966 .4478 Mdot
.966 .44808 Mdot
.966 .45096 Mdot
.966 .45142 Mdot
.966 .4516 Mdot
.966 .45188 Mdot
.966 .45283 Mdot
.966 .45301 Mdot
.966 .45409 Mdot
.966 .45425 Mdot
.966 .45488 Mdot
.966 .45509 Mdot
.966 .4552 Mdot
.966 .4553 Mdot
.966 .4557 Mdot
.966 .45696 Mdot
.966 .45705 Mdot
.966 .45727 Mdot
.966 .45936 Mdot
.966 .45972 Mdot
.966 .46065 Mdot
.966 .46157 Mdot
.966 .46211 Mdot
.966 .46245 Mdot
.966 .46333 Mdot
.966 .46356 Mdot
.966 .46437 Mdot
.966 .46857 Mdot
.966 .46859 Mdot
.966 .46879 Mdot
.966 .46931 Mdot
.966 .4705 Mdot
.966 .47084 Mdot
.966 .47105 Mdot
.966 .47125 Mdot
.966 .47127 Mdot
.966 .47134 Mdot
.966 .47149 Mdot
.966 .47262 Mdot
.966 .47266 Mdot
.966 .47334 Mdot
.966 .47473 Mdot
.966 .4748 Mdot
.966 .47582 Mdot
.966 .47612 Mdot
.966 .47629 Mdot
.966 .47756 Mdot
.966 .47781 Mdot
.966 .47856 Mdot
.966 .47864 Mdot
.966 .47878 Mdot
.966 .47951 Mdot
.966 .48001 Mdot
.966 .4815 Mdot
.966 .48174 Mdot
.966 .48242 Mdot
.966 .48279 Mdot
.966 .48407 Mdot
.966 .4848 Mdot
.966 .48598 Mdot
.966 .48684 Mdot
.966 .48746 Mdot
.966 .48863 Mdot
.966 .48977 Mdot
.966 .49276 Mdot
.966 .49455 Mdot
.966 .49474 Mdot
.966 .49568 Mdot
.966 .49675 Mdot
.966 .49729 Mdot
.966 .50038 Mdot
.966 .50172 Mdot
.966 .50227 Mdot
.966 .50231 Mdot
.966 .50257 Mdot
.966 .50269 Mdot
.966 .50459 Mdot
.966 .50466 Mdot
.966 .50491 Mdot
.966 .50532 Mdot
.966 .50599 Mdot
.966 .50654 Mdot
.966 .50712 Mdot
.966 .50863 Mdot
.966 .50925 Mdot
.966 .51092 Mdot
.966 .5111 Mdot
.966 .51115 Mdot
.966 .51147 Mdot
.966 .51222 Mdot
.966 .51229 Mdot
.966 .5127 Mdot
.966 .513 Mdot
.966 .51339 Mdot
.966 .51366 Mdot
.966 .51373 Mdot
.966 .51396 Mdot
.966 .51444 Mdot
.966 .5149 Mdot
.966 .51582 Mdot
.966 .51716 Mdot
.966 .51817 Mdot
.966 .5183 Mdot
.966 .51847 Mdot
.966 .51888 Mdot
.966 .51932 Mdot
.966 .51939 Mdot
.966 .51986 Mdot
.966 .52052 Mdot
.966 .52196 Mdot
.966 .52257 Mdot
.966 .52336 Mdot
.966 .52486 Mdot
.966 .52498 Mdot
.966 .52502 Mdot
.966 .52518 Mdot
.966 .5254 Mdot
.966 .52839 Mdot
.966 .52932 Mdot
.966 .52986 Mdot
.966 .52999 Mdot
.966 .53062 Mdot
.966 .53085 Mdot
.966 .53136 Mdot
.966 .53163 Mdot
.966 .53167 Mdot
.966 .53185 Mdot
.966 .53201 Mdot
.966 .53357 Mdot
.966 .53375 Mdot
.966 .53385 Mdot
.966 .53425 Mdot
.966 .5345 Mdot
.966 .53469 Mdot
.966 .53471 Mdot
.966 .53581 Mdot
.966 .53676 Mdot
.966 .53698 Mdot
.966 .53731 Mdot
.966 .5374 Mdot
.966 .53802 Mdot
.966 .53896 Mdot
.966 .53955 Mdot
.966 .54002 Mdot
.966 .54037 Mdot
.966 .54099 Mdot
.966 .5413 Mdot
.966 .54144 Mdot
.966 .54218 Mdot
.966 .54342 Mdot
.966 .54365 Mdot
.966 .54455 Mdot
.966 .54526 Mdot
.966 .54593 Mdot
.966 .54641 Mdot
.966 .54664 Mdot
.966 .54781 Mdot
.966 .54883 Mdot
.966 .54893 Mdot
.966 .54945 Mdot
.966 .54953 Mdot
.966 .55152 Mdot
.966 .55219 Mdot
.966 .5523 Mdot
.966 .55265 Mdot
.966 .55379 Mdot
.966 .5539 Mdot
.966 .55422 Mdot
.966 .55474 Mdot
.966 .55485 Mdot
.966 .55505 Mdot
.966 .55547 Mdot
.966 .55554 Mdot
.966 .55565 Mdot
.966 .55726 Mdot
.966 .55798 Mdot
.966 .55943 Mdot
.966 .55966 Mdot
.966 .55967 Mdot
.966 .55979 Mdot
.966 .55983 Mdot
.966 .56028 Mdot
.966 .56029 Mdot
.966 .56081 Mdot
.966 .56083 Mdot
.966 .56088 Mdot
.966 .56091 Mdot
.966 .56097 Mdot
.966 .56127 Mdot
.966 .56204 Mdot
.966 .56249 Mdot
.966 .56344 Mdot
.966 .56362 Mdot
.966 .56379 Mdot
.966 .56438 Mdot
.966 .56488 Mdot
.966 .56491 Mdot
.966 .56511 Mdot
.966 .56534 Mdot
.966 .56539 Mdot
.966 .56638 Mdot
.966 .56645 Mdot
.966 .56699 Mdot
.966 .56773 Mdot
.966 .56783 Mdot
.966 .56806 Mdot
.966 .56814 Mdot
.966 .56837 Mdot
.966 .56849 Mdot
.966 .5685 Mdot
.966 .5694 Mdot
.966 .56948 Mdot
.966 .56953 Mdot
.966 .56957 Mdot
.966 .56973 Mdot
.966 .57129 Mdot
.966 .5713 Mdot
.966 .57175 Mdot
.966 .57189 Mdot
.966 .57195 Mdot
.966 .57295 Mdot
.966 .57301 Mdot
.966 .57345 Mdot
.966 .57357 Mdot
.966 .57381 Mdot
.966 .57437 Mdot
.966 .57464 Mdot
.966 .57508 Mdot
.966 .57514 Mdot
.966 .57521 Mdot
.966 .5755 Mdot
.966 .57586 Mdot
.966 .57664 Mdot
.966 .57701 Mdot
.966 .57737 Mdot
.966 .57748 Mdot
.966 .5775 Mdot
.966 .578 Mdot
.966 .57801 Mdot
.966 .57865 Mdot
.966 .57879 Mdot
.966 .5788 Mdot
.966 .57999 Mdot
.966 .58005 Mdot
.966 .58033 Mdot
.966 .58045 Mdot
.966 .58048 Mdot
.966 .58072 Mdot
.966 .58077 Mdot
.966 .58099 Mdot
.966 .58118 Mdot
.966 .58172 Mdot
.966 .58183 Mdot
.966 .58205 Mdot
.966 .58242 Mdot
.966 .58273 Mdot
.966 .58281 Mdot
.966 .58298 Mdot
.966 .58302 Mdot
.966 .58303 Mdot
.966 .58329 Mdot
.966 .58381 Mdot
.966 .58509 Mdot
.966 .58545 Mdot
.966 .58575 Mdot
.966 .58581 Mdot
.966 .58607 Mdot
.966 .58615 Mdot
.966 .58662 Mdot
.966 .58677 Mdot
.966 .5875 Mdot
.966 .58789 Mdot
.966 .58871 Mdot
.966 .58891 Mdot
.966 .5891 Mdot
.966 .58927 Mdot
.966 .58945 Mdot
.966 .58951 Mdot
.966 .58982 Mdot
.966 .58984 Mdot
.966 .58985 Mdot
.966 .58993 Mdot
.966 .59001 Mdot
.966 .59048 Mdot
.966 .59051 Mdot
.966 .59102 Mdot
.966 .59128 Mdot
.966 .5913 Mdot
.966 .59185 Mdot
.966 .59188 Mdot
.966 .59234 Mdot
.966 .59237 Mdot
.966 .59243 Mdot
.966 .59254 Mdot
.966 .59271 Mdot
.966 .593 Mdot
.966 .59307 Mdot
.966 .59316 Mdot
.966 .59334 Mdot
.966 .59372 Mdot
.966 .59386 Mdot
.966 .59399 Mdot
.966 .59417 Mdot
.966 .59441 Mdot
.966 .59475 Mdot
.966 .5948 Mdot
.966 .59485 Mdot
.966 .5949 Mdot
.966 .59493 Mdot
.966 .59494 Mdot
.966 .59495 Mdot
.966 .59507 Mdot
.966 .59522 Mdot
.966 .59523 Mdot
.966 .59527 Mdot
.966 .59538 Mdot
.966 .59546 Mdot
.966 .59547 Mdot
.966 .59555 Mdot
.966 .5957 Mdot
.966 .59581 Mdot
.966 .59623 Mdot
.966 .59623 Mdot
.966 .59667 Mdot
.966 .5967 Mdot
.966 .59676 Mdot
.966 .59682 Mdot
.966 .59716 Mdot
.966 .59719 Mdot
.966 .59725 Mdot
.966 .59764 Mdot
.966 .5977 Mdot
.966 .59777 Mdot
.966 .59785 Mdot
.966 .59786 Mdot
.966 .59786 Mdot
.966 .59789 Mdot
.966 .5979 Mdot
.966 .59806 Mdot
.966 .5981 Mdot
.966 .59812 Mdot
.966 .59812 Mdot
.966 .59814 Mdot
.966 .59822 Mdot
.966 .59834 Mdot
.966 .5984 Mdot
.966 .59841 Mdot
.966 .59844 Mdot
.966 .59844 Mdot
.966 .5986 Mdot
.966 .59868 Mdot
.966 .59871 Mdot
.966 .59871 Mdot
.966 .59884 Mdot
.966 .59884 Mdot
.966 .59886 Mdot
.966 .59892 Mdot
.966 .59894 Mdot
.966 .59899 Mdot
.966 .599 Mdot
.966 .59903 Mdot
.966 .59905 Mdot
.966 .59909 Mdot
.966 .59909 Mdot
.966 .59911 Mdot
.966 .59912 Mdot
.966 .59913 Mdot
.966 .59915 Mdot
.966 .59919 Mdot
.966 .59919 Mdot
.966 .5992 Mdot
.966 .59928 Mdot
.966 .59929 Mdot
.966 .59929 Mdot
.966 .5993 Mdot
.966 .5993 Mdot
.966 .59931 Mdot
.966 .59931 Mdot
.968 .02959 Mdot
.968 .02959 Mdot
.968 .02959 Mdot
.968 .0296 Mdot
.968 .02961 Mdot
.968 .02962 Mdot
.968 .02964 Mdot
.968 .02968 Mdot
.968 .02969 Mdot
.968 .02969 Mdot
.968 .02974 Mdot
.968 .02977 Mdot
.968 .0299 Mdot
.968 .0299 Mdot
.968 .02995 Mdot
.968 .03006 Mdot
.968 .03011 Mdot
.968 .03012 Mdot
.968 .03013 Mdot
.968 .03018 Mdot
.968 .03019 Mdot
.968 .03023 Mdot
.968 .03038 Mdot
.968 .03045 Mdot
.968 .03092 Mdot
.968 .03109 Mdot
.968 .0311 Mdot
.968 .03146 Mdot
.968 .03219 Mdot
.968 .03257 Mdot
.968 .03276 Mdot
.968 .03294 Mdot
.968 .03346 Mdot
.968 .03373 Mdot
.968 .03384 Mdot
.968 .034 Mdot
.968 .03422 Mdot
.968 .03445 Mdot
.968 .03468 Mdot
.968 .03496 Mdot
.968 .03621 Mdot
.968 .03637 Mdot
.968 .03664 Mdot
.968 .03709 Mdot
.968 .03726 Mdot
.968 .03746 Mdot
.968 .03753 Mdot
.968 .03763 Mdot
.968 .03788 Mdot
.968 .03912 Mdot
.968 .03948 Mdot
.968 .03977 Mdot
.968 .03981 Mdot
.968 .04058 Mdot
.968 .04061 Mdot
.968 .04118 Mdot
.968 .04124 Mdot
.968 .04216 Mdot
.968 .04325 Mdot
.968 .04349 Mdot
.968 .04377 Mdot
.968 .04399 Mdot
.968 .04426 Mdot
.968 .04492 Mdot
.968 .04562 Mdot
.968 .04625 Mdot
.968 .04767 Mdot
.968 .04819 Mdot
.968 .04985 Mdot
.968 .05072 Mdot
.968 .05148 Mdot
.968 .052 Mdot
.968 .05206 Mdot
.968 .05259 Mdot
.968 .05277 Mdot
.968 .05321 Mdot
.968 .05406 Mdot
.968 .05492 Mdot
.968 .05545 Mdot
.968 .05614 Mdot
.968 .05643 Mdot
.968 .05735 Mdot
.968 .05757 Mdot
.968 .05761 Mdot
.968 .05763 Mdot
.968 .06047 Mdot
.968 .06404 Mdot
.968 .0642 Mdot
.968 .06483 Mdot
.968 .06487 Mdot
.968 .06514 Mdot
.968 .06609 Mdot
.968 .06689 Mdot
.968 .06814 Mdot
.968 .06905 Mdot
.968 .06937 Mdot
.968 .07042 Mdot
.968 .07071 Mdot
.968 .07157 Mdot
.968 .07178 Mdot
.968 .07234 Mdot
.968 .07234 Mdot
.968 .07235 Mdot
.968 .07237 Mdot
.968 .07242 Mdot
.968 .07245 Mdot
.968 .07253 Mdot
.968 .07267 Mdot
.968 .07271 Mdot
.968 .07271 Mdot
.968 .07292 Mdot
.968 .07301 Mdot
.968 .0731 Mdot
.968 .0731 Mdot
.968 .07351 Mdot
.968 .07352 Mdot
.968 .07371 Mdot
.968 .07412 Mdot
.968 .0743 Mdot
.968 .07436 Mdot
.968 .07437 Mdot
.968 .07443 Mdot
.968 .07456 Mdot
.968 .0746 Mdot
.968 .07476 Mdot
.968 .07493 Mdot
.968 .0753 Mdot
.968 .0756 Mdot
.968 .07633 Mdot
.968 .07691 Mdot
.968 .077 Mdot
.968 .07735 Mdot
.968 .078 Mdot
.968 .07802 Mdot
.968 .07939 Mdot
.968 .0812 Mdot
.968 .0821 Mdot
.968 .08352 Mdot
.968 .08417 Mdot
.968 .08422 Mdot
.968 .0849 Mdot
.968 .08684 Mdot
.968 .08784 Mdot
.968 .08812 Mdot
.968 .08827 Mdot
.968 .08885 Mdot
.968 .08896 Mdot
.968 .08966 Mdot
.968 .09026 Mdot
.968 .09045 Mdot
.968 .09051 Mdot
.968 .09123 Mdot
.968 .09138 Mdot
.968 .09242 Mdot
.968 .09314 Mdot
.968 .09467 Mdot
.968 .09558 Mdot
.968 .09594 Mdot
.968 .09655 Mdot
.968 .09669 Mdot
.968 .09702 Mdot
.968 .09761 Mdot
.968 .09808 Mdot
.968 .0986 Mdot
.968 .09907 Mdot
.968 .09965 Mdot
.968 .10027 Mdot
.968 .1009 Mdot
.968 .1009 Mdot
.968 .10109 Mdot
.968 .10151 Mdot
.968 .10163 Mdot
.968 .10164 Mdot
.968 .1019 Mdot
.968 .10223 Mdot
.968 .10281 Mdot
.968 .10317 Mdot
.968 .10319 Mdot
.968 .10327 Mdot
.968 .10363 Mdot
.968 .1043 Mdot
.968 .10541 Mdot
.968 .10553 Mdot
.968 .10769 Mdot
.968 .10787 Mdot
.968 .10848 Mdot
.968 .10862 Mdot
.968 .10902 Mdot
.968 .10953 Mdot
.968 .11004 Mdot
.968 .11019 Mdot
.968 .11077 Mdot
.968 .11175 Mdot
.968 .11244 Mdot
.968 .1128 Mdot
.968 .113 Mdot
.968 .11312 Mdot
.968 .11516 Mdot
.968 .1154 Mdot
.968 .11556 Mdot
.968 .11646 Mdot
.968 .11675 Mdot
.968 .1187 Mdot
.968 .11935 Mdot
.968 .12016 Mdot
.968 .12071 Mdot
.968 .12164 Mdot
.968 .12203 Mdot
.968 .12204 Mdot
.968 .12263 Mdot
.968 .12295 Mdot
.968 .12349 Mdot
.968 .12451 Mdot
.968 .1253 Mdot
.968 .12625 Mdot
.968 .12859 Mdot
.968 .12878 Mdot
.968 .13109 Mdot
.968 .13178 Mdot
.968 .13332 Mdot
.968 .13424 Mdot
.968 .1353 Mdot
.968 .13595 Mdot
.968 .13726 Mdot
.968 .13759 Mdot
.968 .13835 Mdot
.968 .13891 Mdot
.968 .13904 Mdot
.968 .13941 Mdot
.968 .14013 Mdot
.968 .1402 Mdot
.968 .14604 Mdot
.968 .14646 Mdot
.968 .1482 Mdot
.968 .14907 Mdot
.968 .15025 Mdot
.968 .15049 Mdot
.968 .15059 Mdot
.968 .15117 Mdot
.968 .15143 Mdot
.968 .1517 Mdot
.968 .15173 Mdot
.968 .15182 Mdot
.968 .15351 Mdot
.968 .15374 Mdot
.968 .15441 Mdot
.968 .15498 Mdot
.968 .15513 Mdot
.968 .15556 Mdot
.968 .15597 Mdot
.968 .15618 Mdot
.968 .1577 Mdot
.968 .1582 Mdot
.968 .16064 Mdot
.968 .16076 Mdot
.968 .16189 Mdot
.968 .16279 Mdot
.968 .16359 Mdot
.968 .164 Mdot
.968 .1654 Mdot
.968 .16777 Mdot
.968 .16781 Mdot
.968 .16878 Mdot
.968 .16903 Mdot
.968 .17189 Mdot
.968 .17265 Mdot
.968 .17278 Mdot
.968 .17286 Mdot
.968 .1749 Mdot
.968 .17508 Mdot
.968 .17509 Mdot
.968 .17514 Mdot
.968 .17516 Mdot
.968 .17702 Mdot
.968 .18037 Mdot
.968 .18086 Mdot
.968 .18237 Mdot
.968 .18242 Mdot
.968 .18457 Mdot
.968 .18598 Mdot
.968 .18658 Mdot
.968 .18838 Mdot
.968 .18881 Mdot
.968 .18946 Mdot
.968 .19032 Mdot
.968 .19096 Mdot
.968 .19114 Mdot
.968 .19176 Mdot
.968 .19267 Mdot
.968 .19387 Mdot
.968 .1942 Mdot
.968 .19432 Mdot
.968 .19486 Mdot
.968 .19695 Mdot
.968 .19707 Mdot
.968 .19746 Mdot
.968 .19795 Mdot
.968 .19865 Mdot
.968 .20097 Mdot
.968 .20107 Mdot
.968 .20111 Mdot
.968 .20124 Mdot
.968 .20221 Mdot
.968 .20297 Mdot
.968 .20358 Mdot
.968 .20595 Mdot
.968 .20595 Mdot
.968 .20697 Mdot
.968 .20779 Mdot
.968 .2081 Mdot
.968 .21059 Mdot
.968 .21068 Mdot
.968 .21074 Mdot
.968 .21107 Mdot
.968 .21156 Mdot
.968 .21157 Mdot
.968 .21177 Mdot
.968 .21275 Mdot
.968 .21275 Mdot
.968 .21377 Mdot
.968 .21415 Mdot
.968 .21474 Mdot
.968 .21504 Mdot
.968 .21506 Mdot
.968 .21506 Mdot
.968 .21516 Mdot
.968 .21608 Mdot
.968 .21742 Mdot
.968 .21887 Mdot
.968 .21891 Mdot
.968 .21954 Mdot
.968 .22134 Mdot
.968 .22134 Mdot
.968 .22134 Mdot
.968 .22142 Mdot
.968 .22158 Mdot
.968 .22168 Mdot
.968 .22194 Mdot
.968 .22194 Mdot
.968 .22239 Mdot
.968 .22249 Mdot
.968 .22251 Mdot
.968 .22317 Mdot
.968 .22347 Mdot
.968 .22374 Mdot
.968 .22374 Mdot
.968 .22438 Mdot
.968 .22454 Mdot
.968 .225 Mdot
.968 .22504 Mdot
.968 .22508 Mdot
.968 .2257 Mdot
.968 .227 Mdot
.968 .22757 Mdot
.968 .22774 Mdot
.968 .2278 Mdot
.968 .22797 Mdot
.968 .22839 Mdot
.968 .22851 Mdot
.968 .229 Mdot
.968 .22917 Mdot
.968 .22956 Mdot
.968 .23018 Mdot
.968 .23074 Mdot
.968 .23168 Mdot
.968 .23221 Mdot
.968 .23222 Mdot
.968 .23397 Mdot
.968 .23543 Mdot
.968 .23579 Mdot
.968 .23606 Mdot
.968 .23715 Mdot
.968 .23908 Mdot
.968 .2391 Mdot
.968 .23919 Mdot
.968 .23927 Mdot
.968 .23945 Mdot
.968 .23948 Mdot
.968 .23955 Mdot
.968 .24072 Mdot
.968 .24309 Mdot
.968 .24351 Mdot
.968 .24425 Mdot
.968 .24459 Mdot
.968 .2454 Mdot
.968 .24865 Mdot
.968 .24866 Mdot
.968 .24879 Mdot
.968 .24911 Mdot
.968 .2493 Mdot
.968 .24958 Mdot
.968 .25048 Mdot
.968 .25058 Mdot
.968 .25188 Mdot
.968 .25261 Mdot
.968 .25339 Mdot
.968 .25344 Mdot
.968 .25366 Mdot
.968 .25499 Mdot
.968 .25537 Mdot
.968 .2554 Mdot
.968 .25604 Mdot
.968 .2562 Mdot
.968 .25676 Mdot
.968 .25698 Mdot
.968 .25737 Mdot
.968 .2582 Mdot
.968 .25834 Mdot
.968 .26041 Mdot
.968 .26626 Mdot
.968 .26746 Mdot
.968 .26873 Mdot
.968 .26925 Mdot
.968 .27008 Mdot
.968 .27054 Mdot
.968 .27209 Mdot
.968 .27225 Mdot
.968 .27259 Mdot
.968 .27464 Mdot
.968 .27628 Mdot
.968 .27629 Mdot
.968 .27644 Mdot
.968 .27699 Mdot
.968 .27717 Mdot
.968 .27928 Mdot
.968 .27974 Mdot
.968 .28279 Mdot
.968 .28433 Mdot
.968 .28488 Mdot
.968 .28562 Mdot
.968 .28604 Mdot
.968 .28799 Mdot
.968 .2886 Mdot
.968 .28933 Mdot
.968 .28937 Mdot
.968 .29157 Mdot
.968 .29174 Mdot
.968 .29197 Mdot
.968 .293 Mdot
.968 .29476 Mdot
.968 .29514 Mdot
.968 .29579 Mdot
.968 .2961 Mdot
.968 .29633 Mdot
.968 .29651 Mdot
.968 .29692 Mdot
.968 .29776 Mdot
.968 .29911 Mdot
.968 .3006 Mdot
.968 .30148 Mdot
.968 .30193 Mdot
.968 .30357 Mdot
.968 .30451 Mdot
.968 .30531 Mdot
.968 .30661 Mdot
.968 .30709 Mdot
.968 .30711 Mdot
.968 .30763 Mdot
.968 .30881 Mdot
.968 .30916 Mdot
.968 .30918 Mdot
.968 .30955 Mdot
.968 .3099 Mdot
.968 .31006 Mdot
.968 .31084 Mdot
.968 .31161 Mdot
.968 .31243 Mdot
.968 .31245 Mdot
.968 .31324 Mdot
.968 .31345 Mdot
.968 .31351 Mdot
.968 .31373 Mdot
.968 .31377 Mdot
.968 .31393 Mdot
.968 .31473 Mdot
.968 .31657 Mdot
.968 .31962 Mdot
.968 .31996 Mdot
.968 .32257 Mdot
.968 .32485 Mdot
.968 .32535 Mdot
.968 .32587 Mdot
.968 .32636 Mdot
.968 .32674 Mdot
.968 .32802 Mdot
.968 .32838 Mdot
.968 .32947 Mdot
.968 .32998 Mdot
.968 .33086 Mdot
.968 .33179 Mdot
.968 .33223 Mdot
.968 .33262 Mdot
.968 .33418 Mdot
.968 .33562 Mdot
.968 .3368 Mdot
.968 .33739 Mdot
.968 .3379 Mdot
.968 .33824 Mdot
.968 .33863 Mdot
.968 .33903 Mdot
.968 .33958 Mdot
.968 .34011 Mdot
.968 .34044 Mdot
.968 .34172 Mdot
.968 .34536 Mdot
.968 .3458 Mdot
.968 .34644 Mdot
.968 .34685 Mdot
.968 .34811 Mdot
.968 .34864 Mdot
.968 .3492 Mdot
.968 .34994 Mdot
.968 .34994 Mdot
.968 .35081 Mdot
.968 .35174 Mdot
.968 .35367 Mdot
.968 .35498 Mdot
.968 .35665 Mdot
.968 .357 Mdot
.968 .35754 Mdot
.968 .35794 Mdot
.968 .35871 Mdot
.968 .35933 Mdot
.968 .36007 Mdot
.968 .36012 Mdot
.968 .36176 Mdot
.968 .36204 Mdot
.968 .36248 Mdot
.968 .3628 Mdot
.968 .36346 Mdot
.968 .3635 Mdot
.968 .36498 Mdot
.968 .36578 Mdot
.968 .36603 Mdot
.968 .36713 Mdot
.968 .36969 Mdot
.968 .37165 Mdot
.968 .37399 Mdot
.968 .37441 Mdot
.968 .37498 Mdot
.968 .3751 Mdot
.968 .37533 Mdot
.968 .37785 Mdot
.968 .37974 Mdot
.968 .37991 Mdot
.968 .37996 Mdot
.968 .38021 Mdot
.968 .38164 Mdot
.968 .38371 Mdot
.968 .38575 Mdot
.968 .3858 Mdot
.968 .3858 Mdot
.968 .38744 Mdot
.968 .38983 Mdot
.968 .39071 Mdot
.968 .39112 Mdot
.968 .39201 Mdot
.968 .39329 Mdot
.968 .39578 Mdot
.968 .39578 Mdot
.968 .39731 Mdot
.968 .3977 Mdot
.968 .39928 Mdot
.968 .40035 Mdot
.968 .40113 Mdot
.968 .40113 Mdot
.968 .40288 Mdot
.968 .40418 Mdot
.968 .40446 Mdot
.968 .40531 Mdot
.968 .40544 Mdot
.968 .40551 Mdot
.968 .40574 Mdot
.968 .40576 Mdot
.968 .40653 Mdot
.968 .40686 Mdot
.968 .40695 Mdot
.968 .40712 Mdot
.968 .41404 Mdot
.968 .41435 Mdot
.968 .41492 Mdot
.968 .41525 Mdot
.968 .41578 Mdot
.968 .41816 Mdot
.968 .41888 Mdot
.968 .4202 Mdot
.968 .42077 Mdot
.968 .42113 Mdot
.968 .42493 Mdot
.968 .42669 Mdot
.968 .42681 Mdot
.968 .42935 Mdot
.968 .42986 Mdot
.968 .43008 Mdot
.968 .43054 Mdot
.968 .43132 Mdot
.968 .43154 Mdot
.968 .43187 Mdot
.968 .43245 Mdot
.968 .43251 Mdot
.968 .43269 Mdot
.968 .43545 Mdot
.968 .43558 Mdot
.968 .43627 Mdot
.968 .43676 Mdot
.968 .43677 Mdot
.968 .43815 Mdot
.968 .43816 Mdot
.968 .43912 Mdot
.968 .43933 Mdot
.968 .43964 Mdot
.968 .44055 Mdot
.968 .44139 Mdot
.968 .44183 Mdot
.968 .44322 Mdot
.968 .44496 Mdot
.968 .44503 Mdot
.968 .44596 Mdot
.968 .4466 Mdot
.968 .44805 Mdot
.968 .45055 Mdot
.968 .4509 Mdot
.968 .45114 Mdot
.968 .45217 Mdot
.968 .45302 Mdot
.968 .45339 Mdot
.968 .45466 Mdot
.968 .45508 Mdot
.968 .45518 Mdot
.968 .45529 Mdot
.968 .4555 Mdot
.968 .45633 Mdot
.968 .45676 Mdot
.968 .45756 Mdot
.968 .45881 Mdot
.968 .45952 Mdot
.968 .46029 Mdot
.968 .46118 Mdot
.968 .46316 Mdot
.968 .46362 Mdot
.968 .46428 Mdot
.968 .46485 Mdot
.968 .46491 Mdot
.968 .46676 Mdot
.968 .46723 Mdot
.968 .46902 Mdot
.968 .47174 Mdot
.968 .47259 Mdot
.968 .47292 Mdot
.968 .47399 Mdot
.968 .47423 Mdot
.968 .47438 Mdot
.968 .47463 Mdot
.968 .47477 Mdot
.968 .47795 Mdot
.968 .47809 Mdot
.968 .47843 Mdot
.968 .47844 Mdot
.968 .47854 Mdot
.968 .47857 Mdot
.968 .48044 Mdot
.968 .48124 Mdot
.968 .48191 Mdot
.968 .48274 Mdot
.968 .48434 Mdot
.968 .48489 Mdot
.968 .48526 Mdot
.968 .48694 Mdot
.968 .48696 Mdot
.968 .48781 Mdot
.968 .48866 Mdot
.968 .48935 Mdot
.968 .48937 Mdot
.968 .49022 Mdot
.968 .49125 Mdot
.968 .49134 Mdot
.968 .49139 Mdot
.968 .49162 Mdot
.968 .49499 Mdot
.968 .49627 Mdot
.968 .49657 Mdot
.968 .49668 Mdot
.968 .49734 Mdot
.968 .49764 Mdot
.968 .49818 Mdot
.968 .49834 Mdot
.968 .49855 Mdot
.968 .49984 Mdot
.968 .50059 Mdot
.968 .50095 Mdot
.968 .50128 Mdot
.968 .50179 Mdot
.968 .50199 Mdot
.968 .50304 Mdot
.968 .50443 Mdot
.968 .50544 Mdot
.968 .50574 Mdot
.968 .50587 Mdot
.968 .50606 Mdot
.968 .50672 Mdot
.968 .50815 Mdot
.968 .50882 Mdot
.968 .51002 Mdot
.968 .51053 Mdot
.968 .51072 Mdot
.968 .51155 Mdot
.968 .51469 Mdot
.968 .51474 Mdot
.968 .51494 Mdot
.968 .51523 Mdot
.968 .51552 Mdot
.968 .51608 Mdot
.968 .51626 Mdot
.968 .5173 Mdot
.968 .51805 Mdot
.968 .51912 Mdot
.968 .52072 Mdot
.968 .52087 Mdot
.968 .52093 Mdot
.968 .52112 Mdot
.968 .52253 Mdot
.968 .52259 Mdot
.968 .52335 Mdot
.968 .52361 Mdot
.968 .52382 Mdot
.968 .52449 Mdot
.968 .52464 Mdot
.968 .52508 Mdot
.968 .52782 Mdot
.968 .52782 Mdot
.968 .52924 Mdot
.968 .53036 Mdot
.968 .53079 Mdot
.968 .53413 Mdot
.968 .53426 Mdot
.968 .53433 Mdot
.968 .53457 Mdot
.968 .53478 Mdot
.968 .53479 Mdot
.968 .53491 Mdot
.968 .53535 Mdot
.968 .53542 Mdot
.968 .53544 Mdot
.968 .53569 Mdot
.968 .53635 Mdot
.968 .53639 Mdot
.968 .53668 Mdot
.968 .53677 Mdot
.968 .53694 Mdot
.968 .53698 Mdot
.968 .53698 Mdot
.968 .53804 Mdot
.968 .5383 Mdot
.968 .53841 Mdot
.968 .53878 Mdot
.968 .53954 Mdot
.968 .53992 Mdot
.968 .53994 Mdot
.968 .53995 Mdot
.968 .54006 Mdot
.968 .54007 Mdot
.968 .54124 Mdot
.968 .54226 Mdot
.968 .54226 Mdot
.968 .54291 Mdot
.968 .54322 Mdot
.968 .54454 Mdot
.968 .54468 Mdot
.968 .54474 Mdot
.968 .5455 Mdot
.968 .54644 Mdot
.968 .54691 Mdot
.968 .54764 Mdot
.968 .54764 Mdot
.968 .54765 Mdot
.968 .54774 Mdot
.968 .54793 Mdot
.968 .54804 Mdot
.968 .54836 Mdot
.968 .54836 Mdot
.968 .54872 Mdot
.968 .54873 Mdot
.968 .54888 Mdot
.968 .549 Mdot
.968 .54903 Mdot
.968 .54979 Mdot
.968 .55014 Mdot
.968 .55045 Mdot
.968 .55046 Mdot
.968 .55118 Mdot
.968 .55137 Mdot
.968 .5516 Mdot
.968 .55189 Mdot
.968 .55193 Mdot
.968 .55198 Mdot
.968 .55268 Mdot
.968 .55304 Mdot
.968 .55403 Mdot
.968 .55413 Mdot
.968 .55449 Mdot
.968 .55477 Mdot
.968 .55495 Mdot
.968 .55501 Mdot
.968 .5552 Mdot
.968 .55546 Mdot
.968 .55565 Mdot
.968 .55578 Mdot
.968 .55632 Mdot
.968 .5565 Mdot
.968 .55692 Mdot
.968 .55758 Mdot
.968 .55803 Mdot
.968 .55818 Mdot
.968 .55917 Mdot
.968 .55972 Mdot
.968 .55972 Mdot
.968 .55974 Mdot
.968 .55974 Mdot
.968 .5598 Mdot
.968 .56152 Mdot
.968 .56188 Mdot
.968 .56299 Mdot
.968 .56335 Mdot
.968 .56361 Mdot
.968 .56394 Mdot
.968 .56468 Mdot
.968 .56533 Mdot
.968 .56557 Mdot
.968 .56561 Mdot
.968 .56578 Mdot
.968 .56652 Mdot
.968 .56655 Mdot
.968 .56663 Mdot
.968 .56671 Mdot
.968 .56688 Mdot
.968 .5669 Mdot
.968 .56697 Mdot
.968 .56756 Mdot
.968 .56806 Mdot
.968 .56986 Mdot
.968 .57007 Mdot
.968 .57017 Mdot
.968 .57021 Mdot
.968 .57058 Mdot
.968 .57068 Mdot
.968 .57104 Mdot
.968 .57123 Mdot
.968 .57153 Mdot
.968 .57222 Mdot
.968 .57306 Mdot
.968 .57469 Mdot
.968 .57495 Mdot
.968 .57495 Mdot
.968 .57506 Mdot
.968 .57532 Mdot
.968 .57547 Mdot
.968 .5757 Mdot
.968 .57642 Mdot
.968 .5765 Mdot
.968 .57674 Mdot
.968 .57751 Mdot
.968 .57761 Mdot
.968 .5778 Mdot
.968 .57807 Mdot
.968 .57841 Mdot
.968 .57866 Mdot
.968 .5787 Mdot
.968 .57886 Mdot
.968 .57951 Mdot
.968 .57954 Mdot
.968 .57984 Mdot
.968 .58002 Mdot
.968 .58012 Mdot
.968 .58014 Mdot
.968 .58025 Mdot
.968 .58057 Mdot
.968 .5806 Mdot
.968 .58072 Mdot
.968 .58077 Mdot
.968 .58111 Mdot
.968 .58127 Mdot
.968 .58154 Mdot
.968 .58192 Mdot
.968 .58195 Mdot
.968 .58212 Mdot
.968 .58221 Mdot
.968 .58246 Mdot
.968 .58288 Mdot
.968 .58339 Mdot
.968 .5836 Mdot
.968 .58365 Mdot
.968 .584 Mdot
.968 .58423 Mdot
.968 .58529 Mdot
.968 .58609 Mdot
.968 .58721 Mdot
.968 .58723 Mdot
.968 .58776 Mdot
.968 .58789 Mdot
.968 .58824 Mdot
.968 .58824 Mdot
.968 .58859 Mdot
.968 .58865 Mdot
.968 .58888 Mdot
.968 .58895 Mdot
.968 .58923 Mdot
.968 .58931 Mdot
.968 .58955 Mdot
.968 .58988 Mdot
.968 .5901 Mdot
.968 .59035 Mdot
.968 .59042 Mdot
.968 .59043 Mdot
.968 .59059 Mdot
.968 .59064 Mdot
.968 .59157 Mdot
.968 .59231 Mdot
.968 .59232 Mdot
.968 .59233 Mdot
.968 .59239 Mdot
.968 .59263 Mdot
.968 .5927 Mdot
.968 .59289 Mdot
.968 .59302 Mdot
.968 .59325 Mdot
.968 .59347 Mdot
.968 .59358 Mdot
.968 .59363 Mdot
.968 .59377 Mdot
.968 .59378 Mdot
.968 .59392 Mdot
.968 .59412 Mdot
.968 .59434 Mdot
.968 .59477 Mdot
.968 .59491 Mdot
.968 .59528 Mdot
.968 .59544 Mdot
.968 .59562 Mdot
.968 .59579 Mdot
.968 .59586 Mdot
.968 .59591 Mdot
.968 .59599 Mdot
.968 .59605 Mdot
.968 .59633 Mdot
.968 .59657 Mdot
.968 .59658 Mdot
.968 .59673 Mdot
.968 .59674 Mdot
.968 .59694 Mdot
.968 .59695 Mdot
.968 .59702 Mdot
.968 .59711 Mdot
.968 .59743 Mdot
.968 .5975 Mdot
.968 .59752 Mdot
.968 .59754 Mdot
.968 .59759 Mdot
.968 .59763 Mdot
.968 .59775 Mdot
.968 .59782 Mdot
.968 .59786 Mdot
.968 .59818 Mdot
.968 .59825 Mdot
.968 .59831 Mdot
.968 .59837 Mdot
.968 .59843 Mdot
.968 .59847 Mdot
.968 .5985 Mdot
.968 .59856 Mdot
.968 .5987 Mdot
.968 .59874 Mdot
.968 .59879 Mdot
.968 .59889 Mdot
.968 .59907 Mdot
.968 .59917 Mdot
.968 .59917 Mdot
.968 .59921 Mdot
.968 .59933 Mdot
.968 .59935 Mdot
.968 .59939 Mdot
.968 .5994 Mdot
.968 .5994 Mdot
.968 .59941 Mdot
.968 .59942 Mdot
.968 .59942 Mdot
.968 .59943 Mdot
.968 .59946 Mdot
.968 .59947 Mdot
.968 .59947 Mdot
.968 .59951 Mdot
.968 .59951 Mdot
.968 .59953 Mdot
.968 .59953 Mdot
.968 .59953 Mdot
.968 .59954 Mdot
.968 .59954 Mdot
.968 .59955 Mdot
.968 .59955 Mdot
.968 .59955 Mdot
.968 .59955 Mdot
.968 .59955 Mdot
.97 .02868 Mdot
.97 .02873 Mdot
.97 .02883 Mdot
.97 .02895 Mdot
.97 .02901 Mdot
.97 .02926 Mdot
.97 .02942 Mdot
.97 .02948 Mdot
.97 .02964 Mdot
.97 .02964 Mdot
.97 .02965 Mdot
.97 .02999 Mdot
.97 .03003 Mdot
.97 .03011 Mdot
.97 .03026 Mdot
.97 .03027 Mdot
.97 .03052 Mdot
.97 .03056 Mdot
.97 .03063 Mdot
.97 .03081 Mdot
.97 .03082 Mdot
.97 .03137 Mdot
.97 .03167 Mdot
.97 .03192 Mdot
.97 .03206 Mdot
.97 .03267 Mdot
.97 .03272 Mdot
.97 .03286 Mdot
.97 .03364 Mdot
.97 .0339 Mdot
.97 .03452 Mdot
.97 .03455 Mdot
.97 .03461 Mdot
.97 .03504 Mdot
.97 .0354 Mdot
.97 .03554 Mdot
.97 .0359 Mdot
.97 .03594 Mdot
.97 .03625 Mdot
.97 .03672 Mdot
.97 .03684 Mdot
.97 .03739 Mdot
.97 .03907 Mdot
.97 .03971 Mdot
.97 .04004 Mdot
.97 .04061 Mdot
.97 .04111 Mdot
.97 .04137 Mdot
.97 .04181 Mdot
.97 .04247 Mdot
.97 .04295 Mdot
.97 .04401 Mdot
.97 .04434 Mdot
.97 .04535 Mdot
.97 .0454 Mdot
.97 .04545 Mdot
.97 .04548 Mdot
.97 .04586 Mdot
.97 .04593 Mdot
.97 .04594 Mdot
.97 .04667 Mdot
.97 .04833 Mdot
.97 .05059 Mdot
.97 .0512 Mdot
.97 .05134 Mdot
.97 .0521 Mdot
.97 .05307 Mdot
.97 .05351 Mdot
.97 .05368 Mdot
.97 .05384 Mdot
.97 .05401 Mdot
.97 .05467 Mdot
.97 .05498 Mdot
.97 .05565 Mdot
.97 .05574 Mdot
.97 .06042 Mdot
.97 .06077 Mdot
.97 .06125 Mdot
.97 .06164 Mdot
.97 .06329 Mdot
.97 .06556 Mdot
.97 .06574 Mdot
.97 .06663 Mdot
.97 .06739 Mdot
.97 .06807 Mdot
.97 .06891 Mdot
.97 .06913 Mdot
.97 .06951 Mdot
.97 .06996 Mdot
.97 .07017 Mdot
.97 .07064 Mdot
.97 .07112 Mdot
.97 .07157 Mdot
.97 .07173 Mdot
.97 .07196 Mdot
.97 .07224 Mdot
.97 .07255 Mdot
.97 .07256 Mdot
.97 .07259 Mdot
.97 .07384 Mdot
.97 .07389 Mdot
.97 .07403 Mdot
.97 .07433 Mdot
.97 .0744 Mdot
.97 .07491 Mdot
.97 .07493 Mdot
.97 .07588 Mdot
.97 .07602 Mdot
.97 .07627 Mdot
.97 .07671 Mdot
.97 .07696 Mdot
.97 .07697 Mdot
.97 .07701 Mdot
.97 .07754 Mdot
.97 .07905 Mdot
.97 .08019 Mdot
.97 .08093 Mdot
.97 .08114 Mdot
.97 .08165 Mdot
.97 .0837 Mdot
.97 .08391 Mdot
.97 .08411 Mdot
.97 .0843 Mdot
.97 .08465 Mdot
.97 .0849 Mdot
.97 .0866 Mdot
.97 .08708 Mdot
.97 .08753 Mdot
.97 .08822 Mdot
.97 .0885 Mdot
.97 .08931 Mdot
.97 .0894 Mdot
.97 .09038 Mdot
.97 .0904 Mdot
.97 .09077 Mdot
.97 .09081 Mdot
.97 .09093 Mdot
.97 .09115 Mdot
.97 .09131 Mdot
.97 .09134 Mdot
.97 .09148 Mdot
.97 .0926 Mdot
.97 .09272 Mdot
.97 .09274 Mdot
.97 .09394 Mdot
.97 .09409 Mdot
.97 .09458 Mdot
.97 .09536 Mdot
.97 .09541 Mdot
.97 .09572 Mdot
.97 .09593 Mdot
.97 .09608 Mdot
.97 .09629 Mdot
.97 .09671 Mdot
.97 .0969 Mdot
.97 .09721 Mdot
.97 .09855 Mdot
.97 .09893 Mdot
.97 .09939 Mdot
.97 .10139 Mdot
.97 .10209 Mdot
.97 .10371 Mdot
.97 .10433 Mdot
.97 .10433 Mdot
.97 .10454 Mdot
.97 .10537 Mdot
.97 .10553 Mdot
.97 .10562 Mdot
.97 .106 Mdot
.97 .10608 Mdot
.97 .10662 Mdot
.97 .10754 Mdot
.97 .10812 Mdot
.97 .10897 Mdot
.97 .10952 Mdot
.97 .10987 Mdot
.97 .11002 Mdot
.97 .11109 Mdot
.97 .11317 Mdot
.97 .11496 Mdot
.97 .11563 Mdot
.97 .11591 Mdot
.97 .11699 Mdot
.97 .1175 Mdot
.97 .11755 Mdot
.97 .1187 Mdot
.97 .1189 Mdot
.97 .11918 Mdot
.97 .11962 Mdot
.97 .11986 Mdot
.97 .12016 Mdot
.97 .1216 Mdot
.97 .12208 Mdot
.97 .12248 Mdot
.97 .12374 Mdot
.97 .12398 Mdot
.97 .1247 Mdot
.97 .12541 Mdot
.97 .12658 Mdot
.97 .12674 Mdot
.97 .12749 Mdot
.97 .12888 Mdot
.97 .1293 Mdot
.97 .13019 Mdot
.97 .13037 Mdot
.97 .13053 Mdot
.97 .13063 Mdot
.97 .13198 Mdot
.97 .13226 Mdot
.97 .13227 Mdot
.97 .13308 Mdot
.97 .13368 Mdot
.97 .13386 Mdot
.97 .13488 Mdot
.97 .13506 Mdot
.97 .13603 Mdot
.97 .1363 Mdot
.97 .1364 Mdot
.97 .13828 Mdot
.97 .13885 Mdot
.97 .13946 Mdot
.97 .13983 Mdot
.97 .14063 Mdot
.97 .14072 Mdot
.97 .1435 Mdot
.97 .14539 Mdot
.97 .14867 Mdot
.97 .15079 Mdot
.97 .15128 Mdot
.97 .15295 Mdot
.97 .15393 Mdot
.97 .15515 Mdot
.97 .15581 Mdot
.97 .15649 Mdot
.97 .15651 Mdot
.97 .15729 Mdot
.97 .15879 Mdot
.97 .15939 Mdot
.97 .15985 Mdot
.97 .15994 Mdot
.97 .15994 Mdot
.97 .16053 Mdot
.97 .16077 Mdot
.97 .16103 Mdot
.97 .16118 Mdot
.97 .16126 Mdot
.97 .16257 Mdot
.97 .1628 Mdot
.97 .1633 Mdot
.97 .16385 Mdot
.97 .16393 Mdot
.97 .16614 Mdot
.97 .16648 Mdot
.97 .16702 Mdot
.97 .16731 Mdot
.97 .16865 Mdot
.97 .16885 Mdot
.97 .17014 Mdot
.97 .17102 Mdot
.97 .1714 Mdot
.97 .17302 Mdot
.97 .17523 Mdot
.97 .17535 Mdot
.97 .17611 Mdot
.97 .17694 Mdot
.97 .18233 Mdot
.97 .18252 Mdot
.97 .18326 Mdot
.97 .1835 Mdot
.97 .1836 Mdot
.97 .18383 Mdot
.97 .18492 Mdot
.97 .18497 Mdot
.97 .18498 Mdot
.97 .1851 Mdot
.97 .1859 Mdot
.97 .18641 Mdot
.97 .18973 Mdot
.97 .19052 Mdot
.97 .19191 Mdot
.97 .19201 Mdot
.97 .19396 Mdot
.97 .19415 Mdot
.97 .19558 Mdot
.97 .19627 Mdot
.97 .19629 Mdot
.97 .1972 Mdot
.97 .19882 Mdot
.97 .19924 Mdot
.97 .19941 Mdot
.97 .20002 Mdot
.97 .20012 Mdot
.97 .20293 Mdot
.97 .20381 Mdot
.97 .20535 Mdot
.97 .20542 Mdot
.97 .20763 Mdot
.97 .20782 Mdot
.97 .20944 Mdot
.97 .21027 Mdot
.97 .21036 Mdot
.97 .21106 Mdot
.97 .21112 Mdot
.97 .21154 Mdot
.97 .21163 Mdot
.97 .2123 Mdot
.97 .2129 Mdot
.97 .21376 Mdot
.97 .2142 Mdot
.97 .21443 Mdot
.97 .21543 Mdot
.97 .21588 Mdot
.97 .21594 Mdot
.97 .21751 Mdot
.97 .21757 Mdot
.97 .21815 Mdot
.97 .21857 Mdot
.97 .21882 Mdot
.97 .21893 Mdot
.97 .21944 Mdot
.97 .2202 Mdot
.97 .22052 Mdot
.97 .22096 Mdot
.97 .22108 Mdot
.97 .2214 Mdot
.97 .22174 Mdot
.97 .22208 Mdot
.97 .2221 Mdot
.97 .22221 Mdot
.97 .22374 Mdot
.97 .22415 Mdot
.97 .22513 Mdot
.97 .22617 Mdot
.97 .22636 Mdot
.97 .22675 Mdot
.97 .2268 Mdot
.97 .22774 Mdot
.97 .22795 Mdot
.97 .22901 Mdot
.97 .22926 Mdot
.97 .22958 Mdot
.97 .22965 Mdot
.97 .22974 Mdot
.97 .23175 Mdot
.97 .232 Mdot
.97 .23263 Mdot
.97 .23309 Mdot
.97 .23388 Mdot
.97 .23525 Mdot
.97 .23543 Mdot
.97 .23565 Mdot
.97 .23604 Mdot
.97 .23606 Mdot
.97 .23618 Mdot
.97 .23745 Mdot
.97 .23785 Mdot
.97 .23851 Mdot
.97 .24142 Mdot
.97 .24231 Mdot
.97 .24257 Mdot
.97 .24366 Mdot
.97 .24377 Mdot
.97 .24409 Mdot
.97 .24447 Mdot
.97 .24453 Mdot
.97 .2461 Mdot
.97 .24656 Mdot
.97 .24749 Mdot
.97 .24838 Mdot
.97 .24903 Mdot
.97 .24937 Mdot
.97 .24946 Mdot
.97 .24993 Mdot
.97 .2506 Mdot
.97 .2526 Mdot
.97 .25277 Mdot
.97 .25298 Mdot
.97 .25468 Mdot
.97 .25491 Mdot
.97 .25687 Mdot
.97 .25751 Mdot
.97 .25775 Mdot
.97 .25809 Mdot
.97 .25811 Mdot
.97 .25868 Mdot
.97 .25966 Mdot
.97 .25973 Mdot
.97 .2601 Mdot
.97 .26051 Mdot
.97 .261 Mdot
.97 .26147 Mdot
.97 .26562 Mdot
.97 .26707 Mdot
.97 .2681 Mdot
.97 .26842 Mdot
.97 .26887 Mdot
.97 .27048 Mdot
.97 .27133 Mdot
.97 .27142 Mdot
.97 .27372 Mdot
.97 .27399 Mdot
.97 .27688 Mdot
.97 .27694 Mdot
.97 .27794 Mdot
.97 .27804 Mdot
.97 .27815 Mdot
.97 .27825 Mdot
.97 .27853 Mdot
.97 .27915 Mdot
.97 .27964 Mdot
.97 .27973 Mdot
.97 .28013 Mdot
.97 .28168 Mdot
.97 .28341 Mdot
.97 .28376 Mdot
.97 .28378 Mdot
.97 .28381 Mdot
.97 .28463 Mdot
.97 .2867 Mdot
.97 .28731 Mdot
.97 .28774 Mdot
.97 .28826 Mdot
.97 .28918 Mdot
.97 .29144 Mdot
.97 .29157 Mdot
.97 .29248 Mdot
.97 .29306 Mdot
.97 .2935 Mdot
.97 .29404 Mdot
.97 .29411 Mdot
.97 .29532 Mdot
.97 .29586 Mdot
.97 .29674 Mdot
.97 .30001 Mdot
.97 .30043 Mdot
.97 .30058 Mdot
.97 .30165 Mdot
.97 .30294 Mdot
.97 .30298 Mdot
.97 .3037 Mdot
.97 .3043 Mdot
.97 .30545 Mdot
.97 .3086 Mdot
.97 .31054 Mdot
.97 .31149 Mdot
.97 .31228 Mdot
.97 .31455 Mdot
.97 .31506 Mdot
.97 .31608 Mdot
.97 .31618 Mdot
.97 .31677 Mdot
.97 .31678 Mdot
.97 .31737 Mdot
.97 .318 Mdot
.97 .3191 Mdot
.97 .31966 Mdot
.97 .3201 Mdot
.97 .32033 Mdot
.97 .32138 Mdot
.97 .32159 Mdot
.97 .32307 Mdot
.97 .32388 Mdot
.97 .32513 Mdot
.97 .3256 Mdot
.97 .32594 Mdot
.97 .32718 Mdot
.97 .32946 Mdot
.97 .33096 Mdot
.97 .33189 Mdot
.97 .33229 Mdot
.97 .33314 Mdot
.97 .33418 Mdot
.97 .33456 Mdot
.97 .33462 Mdot
.97 .33517 Mdot
.97 .3405 Mdot
.97 .34069 Mdot
.97 .34385 Mdot
.97 .34452 Mdot
.97 .34542 Mdot
.97 .34716 Mdot
.97 .34789 Mdot
.97 .35069 Mdot
.97 .35203 Mdot
.97 .35214 Mdot
.97 .35392 Mdot
.97 .35513 Mdot
.97 .35539 Mdot
.97 .35564 Mdot
.97 .35636 Mdot
.97 .35749 Mdot
.97 .35792 Mdot
.97 .35808 Mdot
.97 .35832 Mdot
.97 .35882 Mdot
.97 .35887 Mdot
.97 .36006 Mdot
.97 .36045 Mdot
.97 .36251 Mdot
.97 .36335 Mdot
.97 .36343 Mdot
.97 .36374 Mdot
.97 .3638 Mdot
.97 .36383 Mdot
.97 .36397 Mdot
.97 .364 Mdot
.97 .3642 Mdot
.97 .36475 Mdot
.97 .36791 Mdot
.97 .3685 Mdot
.97 .36882 Mdot
.97 .36979 Mdot
.97 .37022 Mdot
.97 .3703 Mdot
.97 .37122 Mdot
.97 .37207 Mdot
.97 .37331 Mdot
.97 .37434 Mdot
.97 .37497 Mdot
.97 .37516 Mdot
.97 .37535 Mdot
.97 .37721 Mdot
.97 .38038 Mdot
.97 .38059 Mdot
.97 .38158 Mdot
.97 .38161 Mdot
.97 .38193 Mdot
.97 .38368 Mdot
.97 .38376 Mdot
.97 .38421 Mdot
.97 .38458 Mdot
.97 .38484 Mdot
.97 .38607 Mdot
.97 .38652 Mdot
.97 .38809 Mdot
.97 .38875 Mdot
.97 .38877 Mdot
.97 .3907 Mdot
.97 .39187 Mdot
.97 .39211 Mdot
.97 .39255 Mdot
.97 .39266 Mdot
.97 .39495 Mdot
.97 .39538 Mdot
.97 .3956 Mdot
.97 .39766 Mdot
.97 .39777 Mdot
.97 .39828 Mdot
.97 .39839 Mdot
.97 .3985 Mdot
.97 .40065 Mdot
.97 .40116 Mdot
.97 .40122 Mdot
.97 .40288 Mdot
.97 .40417 Mdot
.97 .4042 Mdot
.97 .40437 Mdot
.97 .40439 Mdot
.97 .4049 Mdot
.97 .4056 Mdot
.97 .40562 Mdot
.97 .40644 Mdot
.97 .40815 Mdot
.97 .40825 Mdot
.97 .40847 Mdot
.97 .41103 Mdot
.97 .41351 Mdot
.97 .41402 Mdot
.97 .41472 Mdot
.97 .41894 Mdot
.97 .42065 Mdot
.97 .42138 Mdot
.97 .4222 Mdot
.97 .42359 Mdot
.97 .42578 Mdot
.97 .42611 Mdot
.97 .42846 Mdot
.97 .43068 Mdot
.97 .43103 Mdot
.97 .43172 Mdot
.97 .43184 Mdot
.97 .43222 Mdot
.97 .43291 Mdot
.97 .43301 Mdot
.97 .43302 Mdot
.97 .43526 Mdot
.97 .43694 Mdot
.97 .43723 Mdot
.97 .43731 Mdot
.97 .43773 Mdot
.97 .4383 Mdot
.97 .4384 Mdot
.97 .43968 Mdot
.97 .43987 Mdot
.97 .44057 Mdot
.97 .44124 Mdot
.97 .44178 Mdot
.97 .44191 Mdot
.97 .44263 Mdot
.97 .44268 Mdot
.97 .44298 Mdot
.97 .44359 Mdot
.97 .44429 Mdot
.97 .44489 Mdot
.97 .44681 Mdot
.97 .44735 Mdot
.97 .44855 Mdot
.97 .44948 Mdot
.97 .44965 Mdot
.97 .44967 Mdot
.97 .44968 Mdot
.97 .45065 Mdot
.97 .45085 Mdot
.97 .45099 Mdot
.97 .45133 Mdot
.97 .45186 Mdot
.97 .45216 Mdot
.97 .45231 Mdot
.97 .45264 Mdot
.97 .45313 Mdot
.97 .45384 Mdot
.97 .45461 Mdot
.97 .45491 Mdot
.97 .45511 Mdot
.97 .45537 Mdot
.97 .45562 Mdot
.97 .456 Mdot
.97 .45637 Mdot
.97 .45661 Mdot
.97 .45744 Mdot
.97 .4576 Mdot
.97 .4581 Mdot
.97 .45951 Mdot
.97 .46045 Mdot
.97 .46108 Mdot
.97 .46138 Mdot
.97 .4619 Mdot
.97 .46196 Mdot
.97 .46254 Mdot
.97 .46297 Mdot
.97 .46358 Mdot
.97 .46364 Mdot
.97 .46391 Mdot
.97 .46415 Mdot
.97 .46428 Mdot
.97 .46614 Mdot
.97 .46614 Mdot
.97 .46619 Mdot
.97 .46652 Mdot
.97 .4667 Mdot
.97 .46708 Mdot
.97 .46827 Mdot
.97 .46952 Mdot
.97 .47052 Mdot
.97 .47116 Mdot
.97 .47153 Mdot
.97 .47186 Mdot
.97 .47485 Mdot
.97 .47508 Mdot
.97 .47618 Mdot
.97 .47745 Mdot
.97 .47856 Mdot
.97 .47887 Mdot
.97 .4791 Mdot
.97 .4791 Mdot
.97 .47919 Mdot
.97 .48047 Mdot
.97 .48049 Mdot
.97 .48072 Mdot
.97 .48169 Mdot
.97 .48195 Mdot
.97 .48288 Mdot
.97 .48412 Mdot
.97 .48446 Mdot
.97 .4867 Mdot
.97 .48689 Mdot
.97 .48788 Mdot
.97 .4886 Mdot
.97 .48875 Mdot
.97 .48924 Mdot
.97 .49137 Mdot
.97 .4917 Mdot
.97 .49212 Mdot
.97 .49296 Mdot
.97 .49337 Mdot
.97 .49354 Mdot
.97 .49393 Mdot
.97 .49577 Mdot
.97 .49585 Mdot
.97 .49586 Mdot
.97 .49591 Mdot
.97 .49593 Mdot
.97 .49607 Mdot
.97 .4961 Mdot
.97 .49725 Mdot
.97 .4974 Mdot
.97 .49789 Mdot
.97 .49809 Mdot
.97 .49824 Mdot
.97 .49923 Mdot
.97 .4998 Mdot
.97 .50341 Mdot
.97 .50367 Mdot
.97 .50494 Mdot
.97 .50715 Mdot
.97 .50717 Mdot
.97 .50731 Mdot
.97 .5077 Mdot
.97 .51036 Mdot
.97 .51066 Mdot
.97 .51112 Mdot
.97 .51286 Mdot
.97 .51326 Mdot
.97 .51392 Mdot
.97 .51395 Mdot
.97 .51451 Mdot
.97 .51532 Mdot
.97 .51561 Mdot
.97 .51776 Mdot
.97 .51817 Mdot
.97 .51838 Mdot
.97 .51863 Mdot
.97 .51953 Mdot
.97 .51968 Mdot
.97 .52377 Mdot
.97 .52431 Mdot
.97 .52502 Mdot
.97 .52531 Mdot
.97 .52602 Mdot
.97 .52719 Mdot
.97 .5273 Mdot
.97 .5295 Mdot
.97 .53035 Mdot
.97 .53061 Mdot
.97 .53281 Mdot
.97 .53297 Mdot
.97 .53326 Mdot
.97 .53341 Mdot
.97 .53392 Mdot
.97 .53404 Mdot
.97 .53497 Mdot
.97 .53505 Mdot
.97 .5356 Mdot
.97 .53567 Mdot
.97 .53573 Mdot
.97 .5366 Mdot
.97 .53675 Mdot
.97 .53678 Mdot
.97 .53739 Mdot
.97 .53769 Mdot
.97 .53835 Mdot
.97 .53836 Mdot
.97 .53849 Mdot
.97 .53859 Mdot
.97 .53863 Mdot
.97 .53906 Mdot
.97 .53935 Mdot
.97 .54028 Mdot
.97 .54062 Mdot
.97 .54119 Mdot
.97 .54126 Mdot
.97 .54236 Mdot
.97 .54244 Mdot
.97 .54307 Mdot
.97 .54322 Mdot
.97 .5433 Mdot
.97 .54402 Mdot
.97 .54452 Mdot
.97 .54483 Mdot
.97 .54496 Mdot
.97 .54559 Mdot
.97 .54569 Mdot
.97 .54583 Mdot
.97 .54597 Mdot
.97 .5465 Mdot
.97 .54658 Mdot
.97 .54671 Mdot
.97 .54689 Mdot
.97 .54741 Mdot
.97 .54756 Mdot
.97 .54794 Mdot
.97 .54834 Mdot
.97 .54873 Mdot
.97 .54876 Mdot
.97 .54889 Mdot
.97 .54915 Mdot
.97 .54941 Mdot
.97 .5499 Mdot
.97 .55066 Mdot
.97 .55113 Mdot
.97 .55226 Mdot
.97 .55253 Mdot
.97 .55265 Mdot
.97 .55315 Mdot
.97 .55342 Mdot
.97 .55343 Mdot
.97 .55364 Mdot
.97 .55407 Mdot
.97 .55413 Mdot
.97 .55471 Mdot
.97 .55516 Mdot
.97 .5554 Mdot
.97 .55655 Mdot
.97 .55682 Mdot
.97 .55683 Mdot
.97 .55684 Mdot
.97 .55717 Mdot
.97 .55723 Mdot
.97 .55734 Mdot
.97 .55756 Mdot
.97 .55921 Mdot
.97 .55946 Mdot
.97 .55968 Mdot
.97 .55972 Mdot
.97 .56037 Mdot
.97 .56085 Mdot
.97 .56096 Mdot
.97 .56122 Mdot
.97 .56159 Mdot
.97 .56165 Mdot
.97 .56205 Mdot
.97 .56213 Mdot
.97 .56303 Mdot
.97 .56322 Mdot
.97 .56343 Mdot
.97 .56381 Mdot
.97 .56383 Mdot
.97 .56388 Mdot
.97 .56395 Mdot
.97 .56419 Mdot
.97 .56422 Mdot
.97 .56519 Mdot
.97 .56519 Mdot
.97 .56539 Mdot
.97 .56558 Mdot
.97 .56621 Mdot
.97 .56838 Mdot
.97 .56892 Mdot
.97 .56973 Mdot
.97 .56996 Mdot
.97 .57006 Mdot
.97 .57024 Mdot
.97 .5704 Mdot
.97 .57093 Mdot
.97 .57096 Mdot
.97 .57104 Mdot
.97 .57131 Mdot
.97 .57165 Mdot
.97 .5717 Mdot
.97 .57187 Mdot
.97 .57293 Mdot
.97 .57305 Mdot
.97 .57344 Mdot
.97 .57365 Mdot
.97 .57422 Mdot
.97 .57442 Mdot
.97 .57449 Mdot
.97 .57484 Mdot
.97 .57495 Mdot
.97 .57548 Mdot
.97 .57563 Mdot
.97 .57575 Mdot
.97 .57583 Mdot
.97 .57589 Mdot
.97 .57621 Mdot
.97 .57636 Mdot
.97 .57674 Mdot
.97 .57828 Mdot
.97 .57842 Mdot
.97 .57857 Mdot
.97 .5788 Mdot
.97 .57922 Mdot
.97 .57937 Mdot
.97 .57939 Mdot
.97 .57949 Mdot
.97 .57951 Mdot
.97 .57956 Mdot
.97 .57979 Mdot
.97 .57984 Mdot
.97 .57984 Mdot
.97 .58001 Mdot
.97 .58046 Mdot
.97 .58142 Mdot
.97 .58187 Mdot
.97 .58192 Mdot
.97 .58203 Mdot
.97 .58219 Mdot
.97 .58227 Mdot
.97 .58228 Mdot
.97 .58267 Mdot
.97 .583 Mdot
.97 .58303 Mdot
.97 .58333 Mdot
.97 .58337 Mdot
.97 .58338 Mdot
.97 .58352 Mdot
.97 .58363 Mdot
.97 .58363 Mdot
.97 .58389 Mdot
.97 .58392 Mdot
.97 .58421 Mdot
.97 .58452 Mdot
.97 .58465 Mdot
.97 .5851 Mdot
.97 .58526 Mdot
.97 .58542 Mdot
.97 .58617 Mdot
.97 .58707 Mdot
.97 .58722 Mdot
.97 .58729 Mdot
.97 .5879 Mdot
.97 .58805 Mdot
.97 .58848 Mdot
.97 .58866 Mdot
.97 .5889 Mdot
.97 .58958 Mdot
.97 .58976 Mdot
.97 .58996 Mdot
.97 .59019 Mdot
.97 .59024 Mdot
.97 .59084 Mdot
.97 .59127 Mdot
.97 .59137 Mdot
.97 .5915 Mdot
.97 .59159 Mdot
.97 .59281 Mdot
.97 .59284 Mdot
.97 .59301 Mdot
.97 .59309 Mdot
.97 .59326 Mdot
.97 .59331 Mdot
.97 .59335 Mdot
.97 .59339 Mdot
.97 .59351 Mdot
.97 .59376 Mdot
.97 .59396 Mdot
.97 .59399 Mdot
.97 .59415 Mdot
.97 .59474 Mdot
.97 .59517 Mdot
.97 .59536 Mdot
.97 .59536 Mdot
.97 .59538 Mdot
.97 .59548 Mdot
.97 .59549 Mdot
.97 .5955 Mdot
.97 .59551 Mdot
.97 .59577 Mdot
.97 .59586 Mdot
.97 .59613 Mdot
.97 .59625 Mdot
.97 .59642 Mdot
.97 .59654 Mdot
.97 .5966 Mdot
.97 .59673 Mdot
.97 .59688 Mdot
.97 .59696 Mdot
.97 .59713 Mdot
.97 .59756 Mdot
.97 .5977 Mdot
.97 .59773 Mdot
.97 .59785 Mdot
.97 .59793 Mdot
.97 .59794 Mdot
.97 .59803 Mdot
.97 .59807 Mdot
.97 .59816 Mdot
.97 .59827 Mdot
.97 .59829 Mdot
.97 .5983 Mdot
.97 .59845 Mdot
.97 .59852 Mdot
.97 .59862 Mdot
.97 .59872 Mdot
.97 .59876 Mdot
.97 .59877 Mdot
.97 .59892 Mdot
.97 .59896 Mdot
.97 .59902 Mdot
.97 .5991 Mdot
.97 .59924 Mdot
.97 .59924 Mdot
.97 .59929 Mdot
.97 .59931 Mdot
.97 .59932 Mdot
.97 .59938 Mdot
.97 .59938 Mdot
.97 .59942 Mdot
.97 .59944 Mdot
.97 .59945 Mdot
.97 .59954 Mdot
.97 .59954 Mdot
.97 .59954 Mdot
.97 .59958 Mdot
.97 .5996 Mdot
.97 .59964 Mdot
.97 .5997 Mdot
.97 .59972 Mdot
.97 .59975 Mdot
.97 .59977 Mdot
.97 .59979 Mdot
.972 .02775 Mdot
.972 .02775 Mdot
.972 .02776 Mdot
.972 .02776 Mdot
.972 .02778 Mdot
.972 .02787 Mdot
.972 .02795 Mdot
.972 .02807 Mdot
.972 .02836 Mdot
.972 .0284 Mdot
.972 .02841 Mdot
.972 .02848 Mdot
.972 .02854 Mdot
.972 .02866 Mdot
.972 .02869 Mdot
.972 .02872 Mdot
.972 .02893 Mdot
.972 .02916 Mdot
.972 .02923 Mdot
.972 .0293 Mdot
.972 .02943 Mdot
.972 .02949 Mdot
.972 .0298 Mdot
.972 .02984 Mdot
.972 .03 Mdot
.972 .03023 Mdot
.972 .03023 Mdot
.972 .03039 Mdot
.972 .03099 Mdot
.972 .03105 Mdot
.972 .03121 Mdot
.972 .03124 Mdot
.972 .03134 Mdot
.972 .03148 Mdot
.972 .03206 Mdot
.972 .03208 Mdot
.972 .03208 Mdot
.972 .03292 Mdot
.972 .03307 Mdot
.972 .0333 Mdot
.972 .03345 Mdot
.972 .03373 Mdot
.972 .03376 Mdot
.972 .0339 Mdot
.972 .03427 Mdot
.972 .0355 Mdot
.972 .03552 Mdot
.972 .03556 Mdot
.972 .03618 Mdot
.972 .03627 Mdot
.972 .03656 Mdot
.972 .03683 Mdot
.972 .03775 Mdot
.972 .0382 Mdot
.972 .03838 Mdot
.972 .0385 Mdot
.972 .03853 Mdot
.972 .03855 Mdot
.972 .04016 Mdot
.972 .04046 Mdot
.972 .04096 Mdot
.972 .04168 Mdot
.972 .0418 Mdot
.972 .04414 Mdot
.972 .04485 Mdot
.972 .04509 Mdot
.972 .04775 Mdot
.972 .04833 Mdot
.972 .04861 Mdot
.972 .04872 Mdot
.972 .04977 Mdot
.972 .04986 Mdot
.972 .05091 Mdot
.972 .05153 Mdot
.972 .05215 Mdot
.972 .05286 Mdot
.972 .05456 Mdot
.972 .05598 Mdot
.972 .0565 Mdot
.972 .05671 Mdot
.972 .05693 Mdot
.972 .05866 Mdot
.972 .05889 Mdot
.972 .05896 Mdot
.972 .0595 Mdot
.972 .05959 Mdot
.972 .05961 Mdot
.972 .05962 Mdot
.972 .06004 Mdot
.972 .06014 Mdot
.972 .06017 Mdot
.972 .0615 Mdot
.972 .06256 Mdot
.972 .06256 Mdot
.972 .06286 Mdot
.972 .06441 Mdot
.972 .06542 Mdot
.972 .06543 Mdot
.972 .06545 Mdot
.972 .06546 Mdot
.972 .06555 Mdot
.972 .06564 Mdot
.972 .06587 Mdot
.972 .06589 Mdot
.972 .06617 Mdot
.972 .06664 Mdot
.972 .06693 Mdot
.972 .06759 Mdot
.972 .06773 Mdot
.972 .06775 Mdot
.972 .0679 Mdot
.972 .06793 Mdot
.972 .06814 Mdot
.972 .06821 Mdot
.972 .0684 Mdot
.972 .06887 Mdot
.972 .069 Mdot
.972 .0691 Mdot
.972 .06974 Mdot
.972 .06988 Mdot
.972 .07075 Mdot
.972 .07104 Mdot
.972 .0713 Mdot
.972 .0718 Mdot
.972 .07193 Mdot
.972 .072 Mdot
.972 .07208 Mdot
.972 .07317 Mdot
.972 .07334 Mdot
.972 .07343 Mdot
.972 .07374 Mdot
.972 .07393 Mdot
.972 .07471 Mdot
.972 .0748 Mdot
.972 .07481 Mdot
.972 .0754 Mdot
.972 .07549 Mdot
.972 .07622 Mdot
.972 .07768 Mdot
.972 .0778 Mdot
.972 .07791 Mdot
.972 .078 Mdot
.972 .07834 Mdot
.972 .0785 Mdot
.972 .07859 Mdot
.972 .07896 Mdot
.972 .07951 Mdot
.972 .08017 Mdot
.972 .08121 Mdot
.972 .08168 Mdot
.972 .08175 Mdot
.972 .08176 Mdot
.972 .08189 Mdot
.972 .08224 Mdot
.972 .08232 Mdot
.972 .08445 Mdot
.972 .08449 Mdot
.972 .0849 Mdot
.972 .08526 Mdot
.972 .08543 Mdot
.972 .08544 Mdot
.972 .08575 Mdot
.972 .08632 Mdot
.972 .08687 Mdot
.972 .08792 Mdot
.972 .08801 Mdot
.972 .08834 Mdot
.972 .08855 Mdot
.972 .08993 Mdot
.972 .09143 Mdot
.972 .0917 Mdot
.972 .09261 Mdot
.972 .0928 Mdot
.972 .09343 Mdot
.972 .09447 Mdot
.972 .09453 Mdot
.972 .09468 Mdot
.972 .09621 Mdot
.972 .0964 Mdot
.972 .09699 Mdot
.972 .09699 Mdot
.972 .09731 Mdot
.972 .09839 Mdot
.972 .09939 Mdot
.972 .0998 Mdot
.972 .10073 Mdot
.972 .10167 Mdot
.972 .10171 Mdot
.972 .10274 Mdot
.972 .1036 Mdot
.972 .10418 Mdot
.972 .10424 Mdot
.972 .1044 Mdot
.972 .10508 Mdot
.972 .10552 Mdot
.972 .10563 Mdot
.972 .10569 Mdot
.972 .1061 Mdot
.972 .10821 Mdot
.972 .10883 Mdot
.972 .10947 Mdot
.972 .11157 Mdot
.972 .11182 Mdot
.972 .11251 Mdot
.972 .11266 Mdot
.972 .11366 Mdot
.972 .1137 Mdot
.972 .11413 Mdot
.972 .11431 Mdot
.972 .11432 Mdot
.972 .11445 Mdot
.972 .11707 Mdot
.972 .11751 Mdot
.972 .11779 Mdot
.972 .1182 Mdot
.972 .11849 Mdot
.972 .11856 Mdot
.972 .12132 Mdot
.972 .12591 Mdot
.972 .12719 Mdot
.972 .12802 Mdot
.972 .12822 Mdot
.972 .12847 Mdot
.972 .12931 Mdot
.972 .13155 Mdot
.972 .13282 Mdot
.972 .1333 Mdot
.972 .13396 Mdot
.972 .1343 Mdot
.972 .13558 Mdot
.972 .13787 Mdot
.972 .13876 Mdot
.972 .1397 Mdot
.972 .1403 Mdot
.972 .1408 Mdot
.972 .14177 Mdot
.972 .14217 Mdot
.972 .14276 Mdot
.972 .14341 Mdot
.972 .14395 Mdot
.972 .1443 Mdot
.972 .14586 Mdot
.972 .1459 Mdot
.972 .14617 Mdot
.972 .14773 Mdot
.972 .14806 Mdot
.972 .14909 Mdot
.972 .14934 Mdot
.972 .14943 Mdot
.972 .14983 Mdot
.972 .15035 Mdot
.972 .151 Mdot
.972 .15149 Mdot
.972 .15199 Mdot
.972 .15272 Mdot
.972 .15288 Mdot
.972 .15294 Mdot
.972 .15303 Mdot
.972 .15346 Mdot
.972 .15414 Mdot
.972 .15662 Mdot
.972 .15988 Mdot
.972 .16247 Mdot
.972 .16466 Mdot
.972 .16735 Mdot
.972 .16809 Mdot
.972 .16826 Mdot
.972 .16855 Mdot
.972 .16914 Mdot
.972 .16984 Mdot
.972 .17059 Mdot
.972 .17095 Mdot
.972 .17228 Mdot
.972 .17387 Mdot
.972 .17466 Mdot
.972 .17546 Mdot
.972 .17633 Mdot
.972 .17647 Mdot
.972 .17723 Mdot
.972 .17737 Mdot
.972 .17747 Mdot
.972 .17867 Mdot
.972 .1793 Mdot
.972 .17961 Mdot
.972 .17966 Mdot
.972 .17972 Mdot
.972 .18008 Mdot
.972 .18113 Mdot
.972 .18144 Mdot
.972 .18154 Mdot
.972 .18378 Mdot
.972 .18401 Mdot
.972 .18412 Mdot
.972 .1852 Mdot
.972 .18521 Mdot
.972 .18603 Mdot
.972 .18956 Mdot
.972 .18957 Mdot
.972 .18963 Mdot
.972 .18963 Mdot
.972 .19056 Mdot
.972 .19355 Mdot
.972 .19381 Mdot
.972 .19415 Mdot
.972 .19558 Mdot
.972 .19568 Mdot
.972 .19643 Mdot
.972 .1976 Mdot
.972 .19904 Mdot
.972 .19905 Mdot
.972 .19911 Mdot
.972 .19916 Mdot
.972 .19945 Mdot
.972 .19959 Mdot
.972 .19976 Mdot
.972 .20016 Mdot
.972 .20049 Mdot
.972 .20058 Mdot
.972 .20119 Mdot
.972 .20149 Mdot
.972 .20194 Mdot
.972 .20267 Mdot
.972 .20304 Mdot
.972 .2032 Mdot
.972 .20399 Mdot
.972 .20613 Mdot
.972 .20661 Mdot
.972 .20665 Mdot
.972 .20716 Mdot
.972 .20726 Mdot
.972 .20793 Mdot
.972 .20816 Mdot
.972 .20844 Mdot
.972 .20878 Mdot
.972 .21003 Mdot
.972 .21031 Mdot
.972 .21072 Mdot
.972 .21104 Mdot
.972 .21225 Mdot
.972 .21312 Mdot
.972 .21359 Mdot
.972 .21409 Mdot
.972 .21507 Mdot
.972 .2164 Mdot
.972 .2165 Mdot
.972 .21732 Mdot
.972 .21742 Mdot
.972 .21814 Mdot
.972 .21828 Mdot
.972 .21947 Mdot
.972 .21977 Mdot
.972 .21987 Mdot
.972 .22018 Mdot
.972 .2204 Mdot
.972 .22064 Mdot
.972 .22101 Mdot
.972 .22414 Mdot
.972 .22448 Mdot
.972 .22468 Mdot
.972 .22495 Mdot
.972 .22564 Mdot
.972 .22595 Mdot
.972 .22619 Mdot
.972 .22657 Mdot
.972 .22673 Mdot
.972 .22902 Mdot
.972 .22902 Mdot
.972 .22932 Mdot
.972 .22935 Mdot
.972 .22941 Mdot
.972 .2312 Mdot
.972 .23149 Mdot
.972 .23264 Mdot
.972 .23302 Mdot
.972 .2338 Mdot
.972 .23484 Mdot
.972 .23828 Mdot
.972 .23837 Mdot
.972 .23874 Mdot
.972 .23909 Mdot
.972 .23936 Mdot
.972 .24045 Mdot
.972 .24094 Mdot
.972 .24105 Mdot
.972 .24122 Mdot
.972 .24219 Mdot
.972 .24237 Mdot
.972 .24295 Mdot
.972 .24409 Mdot
.972 .2442 Mdot
.972 .24607 Mdot
.972 .24613 Mdot
.972 .24932 Mdot
.972 .24944 Mdot
.972 .24958 Mdot
.972 .25079 Mdot
.972 .251 Mdot
.972 .25102 Mdot
.972 .25142 Mdot
.972 .25167 Mdot
.972 .25251 Mdot
.972 .25274 Mdot
.972 .25442 Mdot
.972 .25444 Mdot
.972 .25573 Mdot
.972 .25716 Mdot
.972 .25739 Mdot
.972 .25855 Mdot
.972 .25924 Mdot
.972 .25935 Mdot
.972 .26061 Mdot
.972 .26168 Mdot
.972 .26181 Mdot
.972 .26221 Mdot
.972 .26223 Mdot
.972 .26317 Mdot
.972 .26362 Mdot
.972 .26489 Mdot
.972 .26504 Mdot
.972 .26618 Mdot
.972 .26654 Mdot
.972 .26713 Mdot
.972 .26777 Mdot
.972 .26968 Mdot
.972 .26988 Mdot
.972 .26995 Mdot
.972 .27028 Mdot
.972 .27082 Mdot
.972 .27094 Mdot
.972 .27157 Mdot
.972 .27238 Mdot
.972 .27254 Mdot
.972 .27451 Mdot
.972 .27455 Mdot
.972 .27567 Mdot
.972 .28003 Mdot
.972 .28009 Mdot
.972 .28087 Mdot
.972 .28337 Mdot
.972 .28355 Mdot
.972 .28409 Mdot
.972 .28595 Mdot
.972 .28605 Mdot
.972 .28666 Mdot
.972 .28735 Mdot
.972 .28885 Mdot
.972 .28897 Mdot
.972 .28914 Mdot
.972 .28958 Mdot
.972 .29108 Mdot
.972 .29191 Mdot
.972 .29378 Mdot
.972 .29399 Mdot
.972 .29435 Mdot
.972 .29455 Mdot
.972 .29486 Mdot
.972 .29505 Mdot
.972 .29624 Mdot
.972 .29624 Mdot
.972 .29716 Mdot
.972 .2976 Mdot
.972 .29796 Mdot
.972 .29935 Mdot
.972 .30024 Mdot
.972 .30105 Mdot
.972 .30174 Mdot
.972 .30236 Mdot
.972 .30306 Mdot
.972 .30358 Mdot
.972 .30376 Mdot
.972 .30403 Mdot
.972 .30406 Mdot
.972 .30423 Mdot
.972 .30686 Mdot
.972 .30891 Mdot
.972 .3092 Mdot
.972 .30949 Mdot
.972 .30961 Mdot
.972 .31012 Mdot
.972 .31174 Mdot
.972 .31249 Mdot
.972 .31487 Mdot
.972 .31505 Mdot
.972 .31649 Mdot
.972 .31665 Mdot
.972 .3171 Mdot
.972 .31789 Mdot
.972 .31822 Mdot
.972 .31868 Mdot
.972 .31898 Mdot
.972 .32017 Mdot
.972 .32048 Mdot
.972 .32064 Mdot
.972 .32176 Mdot
.972 .32407 Mdot
.972 .3247 Mdot
.972 .32614 Mdot
.972 .32618 Mdot
.972 .32686 Mdot
.972 .32726 Mdot
.972 .32754 Mdot
.972 .32921 Mdot
.972 .32922 Mdot
.972 .33095 Mdot
.972 .33657 Mdot
.972 .33697 Mdot
.972 .33724 Mdot
.972 .33869 Mdot
.972 .33908 Mdot
.972 .33948 Mdot
.972 .33993 Mdot
.972 .34097 Mdot
.972 .34181 Mdot
.972 .34212 Mdot
.972 .34224 Mdot
.972 .34335 Mdot
.972 .34382 Mdot
.972 .34388 Mdot
.972 .34388 Mdot
.972 .34389 Mdot
.972 .34412 Mdot
.972 .34418 Mdot
.972 .34419 Mdot
.972 .34492 Mdot
.972 .34549 Mdot
.972 .34914 Mdot
.972 .35019 Mdot
.972 .35105 Mdot
.972 .35219 Mdot
.972 .3529 Mdot
.972 .35396 Mdot
.972 .35471 Mdot
.972 .35489 Mdot
.972 .35614 Mdot
.972 .35915 Mdot
.972 .35923 Mdot
.972 .36057 Mdot
.972 .36195 Mdot
.972 .36266 Mdot
.972 .36267 Mdot
.972 .36338 Mdot
.972 .3643 Mdot
.972 .36507 Mdot
.972 .36718 Mdot
.972 .36724 Mdot
.972 .36771 Mdot
.972 .36869 Mdot
.972 .37163 Mdot
.972 .37305 Mdot
.972 .37346 Mdot
.972 .37362 Mdot
.972 .37435 Mdot
.972 .37662 Mdot
.972 .37815 Mdot
.972 .37825 Mdot
.972 .37856 Mdot
.972 .37864 Mdot
.972 .37915 Mdot
.972 .37971 Mdot
.972 .37973 Mdot
.972 .37989 Mdot
.972 .3818 Mdot
.972 .38419 Mdot
.972 .38432 Mdot
.972 .38584 Mdot
.972 .38606 Mdot
.972 .38629 Mdot
.972 .3872 Mdot
.972 .38759 Mdot
.972 .39023 Mdot
.972 .39023 Mdot
.972 .39137 Mdot
.972 .39293 Mdot
.972 .39375 Mdot
.972 .39528 Mdot
.972 .3957 Mdot
.972 .39628 Mdot
.972 .39676 Mdot
.972 .39945 Mdot
.972 .40003 Mdot
.972 .40209 Mdot
.972 .40366 Mdot
.972 .40413 Mdot
.972 .40575 Mdot
.972 .40631 Mdot
.972 .40698 Mdot
.972 .40766 Mdot
.972 .40881 Mdot
.972 .41026 Mdot
.972 .41101 Mdot
.972 .41191 Mdot
.972 .41324 Mdot
.972 .41469 Mdot
.972 .41589 Mdot
.972 .41668 Mdot
.972 .4168 Mdot
.972 .42014 Mdot
.972 .42021 Mdot
.972 .42081 Mdot
.972 .42227 Mdot
.972 .42373 Mdot
.972 .42423 Mdot
.972 .42439 Mdot
.972 .42494 Mdot
.972 .42677 Mdot
.972 .42718 Mdot
.972 .42772 Mdot
.972 .42792 Mdot
.972 .42865 Mdot
.972 .42878 Mdot
.972 .42964 Mdot
.972 .42989 Mdot
.972 .43129 Mdot
.972 .43202 Mdot
.972 .43233 Mdot
.972 .433 Mdot
.972 .43321 Mdot
.972 .4334 Mdot
.972 .43389 Mdot
.972 .43495 Mdot
.972 .43528 Mdot
.972 .43542 Mdot
.972 .43559 Mdot
.972 .43651 Mdot
.972 .43686 Mdot
.972 .43792 Mdot
.972 .44308 Mdot
.972 .4476 Mdot
.972 .44865 Mdot
.972 .44972 Mdot
.972 .45364 Mdot
.972 .4549 Mdot
.972 .4562 Mdot
.972 .45868 Mdot
.972 .4592 Mdot
.972 .4644 Mdot
.972 .46581 Mdot
.972 .46613 Mdot
.972 .46623 Mdot
.972 .46669 Mdot
.972 .4678 Mdot
.972 .46827 Mdot
.972 .46913 Mdot
.972 .47023 Mdot
.972 .47053 Mdot
.972 .4712 Mdot
.972 .47368 Mdot
.972 .47659 Mdot
.972 .47803 Mdot
.972 .47857 Mdot
.972 .47948 Mdot
.972 .48105 Mdot
.972 .4813 Mdot
.972 .48265 Mdot
.972 .4829 Mdot
.972 .48308 Mdot
.972 .48521 Mdot
.972 .48632 Mdot
.972 .48686 Mdot
.972 .48695 Mdot
.972 .48705 Mdot
.972 .48768 Mdot
.972 .48773 Mdot
.972 .4895 Mdot
.972 .48958 Mdot
.972 .49005 Mdot
.972 .49017 Mdot
.972 .49021 Mdot
.972 .49176 Mdot
.972 .49206 Mdot
.972 .49228 Mdot
.972 .49286 Mdot
.972 .49404 Mdot
.972 .49443 Mdot
.972 .49462 Mdot
.972 .49464 Mdot
.972 .49548 Mdot
.972 .49579 Mdot
.972 .49615 Mdot
.972 .49643 Mdot
.972 .49643 Mdot
.972 .49726 Mdot
.972 .49778 Mdot
.972 .49781 Mdot
.972 .49899 Mdot
.972 .50129 Mdot
.972 .5017 Mdot
.972 .50309 Mdot
.972 .50331 Mdot
.972 .50359 Mdot
.972 .50361 Mdot
.972 .5037 Mdot
.972 .5037 Mdot
.972 .50449 Mdot
.972 .50481 Mdot
.972 .5052 Mdot
.972 .50567 Mdot
.972 .50631 Mdot
.972 .50921 Mdot
.972 .50992 Mdot
.972 .51007 Mdot
.972 .51032 Mdot
.972 .51034 Mdot
.972 .51086 Mdot
.972 .5111 Mdot
.972 .51306 Mdot
.972 .51323 Mdot
.972 .51335 Mdot
.972 .51437 Mdot
.972 .51556 Mdot
.972 .51614 Mdot
.972 .51647 Mdot
.972 .51657 Mdot
.972 .51829 Mdot
.972 .5183 Mdot
.972 .5184 Mdot
.972 .51846 Mdot
.972 .51889 Mdot
.972 .51911 Mdot
.972 .51935 Mdot
.972 .51995 Mdot
.972 .52044 Mdot
.972 .52057 Mdot
.972 .52145 Mdot
.972 .52152 Mdot
.972 .5217 Mdot
.972 .5219 Mdot
.972 .52254 Mdot
.972 .52283 Mdot
.972 .5236 Mdot
.972 .52412 Mdot
.972 .52436 Mdot
.972 .52457 Mdot
.972 .52548 Mdot
.972 .52662 Mdot
.972 .52848 Mdot
.972 .52849 Mdot
.972 .52915 Mdot
.972 .52921 Mdot
.972 .52973 Mdot
.972 .52991 Mdot
.972 .53005 Mdot
.972 .53075 Mdot
.972 .53096 Mdot
.972 .53128 Mdot
.972 .53166 Mdot
.972 .53213 Mdot
.972 .53273 Mdot
.972 .53381 Mdot
.972 .53419 Mdot
.972 .53427 Mdot
.972 .53473 Mdot
.972 .53516 Mdot
.972 .53516 Mdot
.972 .53606 Mdot
.972 .53674 Mdot
.972 .53679 Mdot
.972 .53788 Mdot
.972 .53848 Mdot
.972 .53888 Mdot
.972 .53913 Mdot
.972 .5395 Mdot
.972 .54039 Mdot
.972 .54148 Mdot
.972 .54206 Mdot
.972 .54218 Mdot
.972 .5432 Mdot
.972 .54333 Mdot
.972 .54405 Mdot
.972 .54422 Mdot
.972 .54439 Mdot
.972 .54476 Mdot
.972 .54584 Mdot
.972 .5462 Mdot
.972 .54632 Mdot
.972 .54669 Mdot
.972 .54696 Mdot
.972 .54725 Mdot
.972 .54769 Mdot
.972 .54799 Mdot
.972 .54856 Mdot
.972 .54925 Mdot
.972 .54974 Mdot
.972 .55134 Mdot
.972 .5515 Mdot
.972 .55173 Mdot
.972 .55196 Mdot
.972 .55227 Mdot
.972 .55244 Mdot
.972 .55305 Mdot
.972 .5534 Mdot
.972 .55366 Mdot
.972 .55409 Mdot
.972 .55419 Mdot
.972 .55427 Mdot
.972 .55545 Mdot
.972 .55545 Mdot
.972 .55678 Mdot
.972 .55678 Mdot
.972 .5571 Mdot
.972 .55713 Mdot
.972 .5572 Mdot
.972 .5583 Mdot
.972 .55872 Mdot
.972 .55911 Mdot
.972 .55941 Mdot
.972 .55967 Mdot
.972 .55991 Mdot
.972 .56014 Mdot
.972 .56061 Mdot
.972 .561 Mdot
.972 .5617 Mdot
.972 .56179 Mdot
.972 .56184 Mdot
.972 .56284 Mdot
.972 .56423 Mdot
.972 .56608 Mdot
.972 .56621 Mdot
.972 .56623 Mdot
.972 .56625 Mdot
.972 .56629 Mdot
.972 .56665 Mdot
.972 .56679 Mdot
.972 .56698 Mdot
.972 .56724 Mdot
.972 .56727 Mdot
.972 .56734 Mdot
.972 .56763 Mdot
.972 .56773 Mdot
.972 .56825 Mdot
.972 .5687 Mdot
.972 .5688 Mdot
.972 .56896 Mdot
.972 .56914 Mdot
.972 .56984 Mdot
.972 .57001 Mdot
.972 .57053 Mdot
.972 .57118 Mdot
.972 .57154 Mdot
.972 .57164 Mdot
.972 .57182 Mdot
.972 .57196 Mdot
.972 .57231 Mdot
.972 .57325 Mdot
.972 .5733 Mdot
.972 .57353 Mdot
.972 .57517 Mdot
.972 .57594 Mdot
.972 .57596 Mdot
.972 .57604 Mdot
.972 .57615 Mdot
.972 .57711 Mdot
.972 .57711 Mdot
.972 .57716 Mdot
.972 .57728 Mdot
.972 .57729 Mdot
.972 .57761 Mdot
.972 .5778 Mdot
.972 .57844 Mdot
.972 .57862 Mdot
.972 .57879 Mdot
.972 .57937 Mdot
.972 .57988 Mdot
.972 .57989 Mdot
.972 .58005 Mdot
.972 .58057 Mdot
.972 .58058 Mdot
.972 .58083 Mdot
.972 .58109 Mdot
.972 .58185 Mdot
.972 .58201 Mdot
.972 .58206 Mdot
.972 .58281 Mdot
.972 .58299 Mdot
.972 .58304 Mdot
.972 .58328 Mdot
.972 .58336 Mdot
.972 .58419 Mdot
.972 .58488 Mdot
.972 .58497 Mdot
.972 .58501 Mdot
.972 .58522 Mdot
.972 .58523 Mdot
.972 .5858 Mdot
.972 .58582 Mdot
.972 .58592 Mdot
.972 .5861 Mdot
.972 .58637 Mdot
.972 .58686 Mdot
.972 .58695 Mdot
.972 .58701 Mdot
.972 .58743 Mdot
.972 .58762 Mdot
.972 .58783 Mdot
.972 .58809 Mdot
.972 .58817 Mdot
.972 .58853 Mdot
.972 .58856 Mdot
.972 .58914 Mdot
.972 .58957 Mdot
.972 .58967 Mdot
.972 .58971 Mdot
.972 .58988 Mdot
.972 .59017 Mdot
.972 .59022 Mdot
.972 .59055 Mdot
.972 .59095 Mdot
.972 .59103 Mdot
.972 .59103 Mdot
.972 .59131 Mdot
.972 .59166 Mdot
.972 .59167 Mdot
.972 .59169 Mdot
.972 .5918 Mdot
.972 .59181 Mdot
.972 .59181 Mdot
.972 .59184 Mdot
.972 .59198 Mdot
.972 .592 Mdot
.972 .59205 Mdot
.972 .59251 Mdot
.972 .59256 Mdot
.972 .59262 Mdot
.972 .59275 Mdot
.972 .59313 Mdot
.972 .59357 Mdot
.972 .59375 Mdot
.972 .59391 Mdot
.972 .59407 Mdot
.972 .59435 Mdot
.972 .59437 Mdot
.972 .59464 Mdot
.972 .59467 Mdot
.972 .59474 Mdot
.972 .59489 Mdot
.972 .59558 Mdot
.972 .59564 Mdot
.972 .59583 Mdot
.972 .59643 Mdot
.972 .59646 Mdot
.972 .59665 Mdot
.972 .59677 Mdot
.972 .59685 Mdot
.972 .59726 Mdot
.972 .59727 Mdot
.972 .59728 Mdot
.972 .59731 Mdot
.972 .59735 Mdot
.972 .59747 Mdot
.972 .5977 Mdot
.972 .59777 Mdot
.972 .59785 Mdot
.972 .59787 Mdot
.972 .59803 Mdot
.972 .59804 Mdot
.972 .59805 Mdot
.972 .59836 Mdot
.972 .59845 Mdot
.972 .59849 Mdot
.972 .5985 Mdot
.972 .59857 Mdot
.972 .59861 Mdot
.972 .59867 Mdot
.972 .59871 Mdot
.972 .59892 Mdot
.972 .59892 Mdot
.972 .59893 Mdot
.972 .59907 Mdot
.972 .59911 Mdot
.972 .59914 Mdot
.972 .59914 Mdot
.972 .59918 Mdot
.972 .5992 Mdot
.972 .59935 Mdot
.972 .59939 Mdot
.972 .59939 Mdot
.972 .59945 Mdot
.972 .59949 Mdot
.972 .5995 Mdot
.972 .59958 Mdot
.972 .59959 Mdot
.972 .59963 Mdot
.972 .59965 Mdot
.972 .59967 Mdot
.972 .59972 Mdot
.972 .59978 Mdot
.972 .59978 Mdot
.972 .59979 Mdot
.972 .59982 Mdot
.972 .59984 Mdot
.972 .59986 Mdot
.972 .59986 Mdot
.972 .59987 Mdot
.972 .59994 Mdot
.972 .59997 Mdot
.972 .59999 Mdot
.972 .60001 Mdot
.972 .60002 Mdot
.972 .60002 Mdot
.972 .60002 Mdot
.972 .60002 Mdot
.974 .02683 Mdot
.974 .02684 Mdot
.974 .02688 Mdot
.974 .02689 Mdot
.974 .02692 Mdot
.974 .02704 Mdot
.974 .02709 Mdot
.974 .02711 Mdot
.974 .02715 Mdot
.974 .02719 Mdot
.974 .02724 Mdot
.974 .02747 Mdot
.974 .02757 Mdot
.974 .0276 Mdot
.974 .02771 Mdot
.974 .02777 Mdot
.974 .0278 Mdot
.974 .02817 Mdot
.974 .02825 Mdot
.974 .02827 Mdot
.974 .02852 Mdot
.974 .02878 Mdot
.974 .02903 Mdot
.974 .0291 Mdot
.974 .02986 Mdot
.974 .02997 Mdot
.974 .02997 Mdot
.974 .03005 Mdot
.974 .03047 Mdot
.974 .03074 Mdot
.974 .03087 Mdot
.974 .0315 Mdot
.974 .03229 Mdot
.974 .03292 Mdot
.974 .03312 Mdot
.974 .03348 Mdot
.974 .03483 Mdot
.974 .03494 Mdot
.974 .03523 Mdot
.974 .03555 Mdot
.974 .03569 Mdot
.974 .03573 Mdot
.974 .03634 Mdot
.974 .03668 Mdot
.974 .03736 Mdot
.974 .03845 Mdot
.974 .03869 Mdot
.974 .03895 Mdot
.974 .0397 Mdot
.974 .03987 Mdot
.974 .04028 Mdot
.974 .04045 Mdot
.974 .04045 Mdot
.974 .04118 Mdot
.974 .04161 Mdot
.974 .04206 Mdot
.974 .04218 Mdot
.974 .04293 Mdot
.974 .04326 Mdot
.974 .04354 Mdot
.974 .04453 Mdot
.974 .04469 Mdot
.974 .04482 Mdot
.974 .04536 Mdot
.974 .04615 Mdot
.974 .04649 Mdot
.974 .04677 Mdot
.974 .04704 Mdot
.974 .04793 Mdot
.974 .04885 Mdot
.974 .04958 Mdot
.974 .04965 Mdot
.974 .04967 Mdot
.974 .04994 Mdot
.974 .05057 Mdot
.974 .05141 Mdot
.974 .05142 Mdot
.974 .05142 Mdot
.974 .05285 Mdot
.974 .05321 Mdot
.974 .05347 Mdot
.974 .05361 Mdot
.974 .05393 Mdot
.974 .05444 Mdot
.974 .05446 Mdot
.974 .05466 Mdot
.974 .05482 Mdot
.974 .05524 Mdot
.974 .05621 Mdot
.974 .05908 Mdot
.974 .05923 Mdot
.974 .05955 Mdot
.974 .05969 Mdot
.974 .06038 Mdot
.974 .06124 Mdot
.974 .06184 Mdot
.974 .06194 Mdot
.974 .06197 Mdot
.974 .06214 Mdot
.974 .06215 Mdot
.974 .06229 Mdot
.974 .06273 Mdot
.974 .06292 Mdot
.974 .063 Mdot
.974 .06305 Mdot
.974 .06316 Mdot
.974 .06333 Mdot
.974 .0635 Mdot
.974 .06366 Mdot
.974 .06422 Mdot
.974 .06436 Mdot
.974 .06475 Mdot
.974 .06488 Mdot
.974 .06511 Mdot
.974 .06529 Mdot
.974 .06552 Mdot
.974 .06559 Mdot
.974 .06563 Mdot
.974 .06568 Mdot
.974 .06702 Mdot
.974 .06733 Mdot
.974 .0674 Mdot
.974 .06772 Mdot
.974 .06838 Mdot
.974 .06929 Mdot
.974 .06935 Mdot
.974 .06949 Mdot
.974 .07029 Mdot
.974 .07055 Mdot
.974 .07082 Mdot
.974 .07167 Mdot
.974 .07196 Mdot
.974 .07245 Mdot
.974 .07276 Mdot
.974 .07344 Mdot
.974 .07385 Mdot
.974 .07386 Mdot
.974 .07414 Mdot
.974 .07467 Mdot
.974 .07528 Mdot
.974 .07552 Mdot
.974 .07573 Mdot
.974 .07676 Mdot
.974 .07723 Mdot
.974 .07784 Mdot
.974 .0779 Mdot
.974 .07877 Mdot
.974 .07888 Mdot
.974 .0796 Mdot
.974 .08141 Mdot
.974 .08144 Mdot
.974 .08155 Mdot
.974 .08167 Mdot
.974 .08257 Mdot
.974 .084 Mdot
.974 .08447 Mdot
.974 .08493 Mdot
.974 .08568 Mdot
.974 .0861 Mdot
.974 .08701 Mdot
.974 .08705 Mdot
.974 .08718 Mdot
.974 .08929 Mdot
.974 .09047 Mdot
.974 .09054 Mdot
.974 .09203 Mdot
.974 .09243 Mdot
.974 .09268 Mdot
.974 .09352 Mdot
.974 .09412 Mdot
.974 .09447 Mdot
.974 .0947 Mdot
.974 .09521 Mdot
.974 .09532 Mdot
.974 .09536 Mdot
.974 .09762 Mdot
.974 .09887 Mdot
.974 .09955 Mdot
.974 .09972 Mdot
.974 .10031 Mdot
.974 .10035 Mdot
.974 .10124 Mdot
.974 .10134 Mdot
.974 .10409 Mdot
.974 .1053 Mdot
.974 .10537 Mdot
.974 .10567 Mdot
.974 .1059 Mdot
.974 .10624 Mdot
.974 .10718 Mdot
.974 .10947 Mdot
.974 .10993 Mdot
.974 .11054 Mdot
.974 .11098 Mdot
.974 .11203 Mdot
.974 .1122 Mdot
.974 .11245 Mdot
.974 .11265 Mdot
.974 .11265 Mdot
.974 .11265 Mdot
.974 .11343 Mdot
.974 .11373 Mdot
.974 .11448 Mdot
.974 .11492 Mdot
.974 .11528 Mdot
.974 .11539 Mdot
.974 .11568 Mdot
.974 .11664 Mdot
.974 .11685 Mdot
.974 .11744 Mdot
.974 .11789 Mdot
.974 .1179 Mdot
.974 .11849 Mdot
.974 .1185 Mdot
.974 .11892 Mdot
.974 .119 Mdot
.974 .11926 Mdot
.974 .1203 Mdot
.974 .12058 Mdot
.974 .12071 Mdot
.974 .1216 Mdot
.974 .12279 Mdot
.974 .12379 Mdot
.974 .12405 Mdot
.974 .12737 Mdot
.974 .12794 Mdot
.974 .12839 Mdot
.974 .13032 Mdot
.974 .13246 Mdot
.974 .13311 Mdot
.974 .13433 Mdot
.974 .13472 Mdot
.974 .13473 Mdot
.974 .13532 Mdot
.974 .13537 Mdot
.974 .13629 Mdot
.974 .13857 Mdot
.974 .13944 Mdot
.974 .13944 Mdot
.974 .14058 Mdot
.974 .14238 Mdot
.974 .14268 Mdot
.974 .14389 Mdot
.974 .14523 Mdot
.974 .14548 Mdot
.974 .14555 Mdot
.974 .14649 Mdot
.974 .14824 Mdot
.974 .14845 Mdot
.974 .14871 Mdot
.974 .14936 Mdot
.974 .15001 Mdot
.974 .15163 Mdot
.974 .15166 Mdot
.974 .15166 Mdot
.974 .15214 Mdot
.974 .15312 Mdot
.974 .15642 Mdot
.974 .15662 Mdot
.974 .15776 Mdot
.974 .15788 Mdot
.974 .1588 Mdot
.974 .15928 Mdot
.974 .16035 Mdot
.974 .16135 Mdot
.974 .16212 Mdot
.974 .16218 Mdot
.974 .16288 Mdot
.974 .16342 Mdot
.974 .16439 Mdot
.974 .16487 Mdot
.974 .16574 Mdot
.974 .1679 Mdot
.974 .16806 Mdot
.974 .16818 Mdot
.974 .17068 Mdot
.974 .17269 Mdot
.974 .17426 Mdot
.974 .17489 Mdot
.974 .17499 Mdot
.974 .17643 Mdot
.974 .17766 Mdot
.974 .17794 Mdot
.974 .17845 Mdot
.974 .17953 Mdot
.974 .18 Mdot
.974 .18015 Mdot
.974 .18232 Mdot
.974 .18237 Mdot
.974 .18468 Mdot
.974 .18522 Mdot
.974 .18639 Mdot
.974 .18722 Mdot
.974 .18757 Mdot
.974 .18766 Mdot
.974 .18823 Mdot
.974 .18826 Mdot
.974 .18874 Mdot
.974 .18943 Mdot
.974 .19019 Mdot
.974 .19082 Mdot
.974 .19082 Mdot
.974 .19109 Mdot
.974 .19127 Mdot
.974 .19132 Mdot
.974 .19162 Mdot
.974 .19209 Mdot
.974 .19218 Mdot
.974 .19276 Mdot
.974 .19328 Mdot
.974 .19412 Mdot
.974 .19418 Mdot
.974 .19516 Mdot
.974 .19561 Mdot
.974 .19688 Mdot
.974 .19731 Mdot
.974 .1981 Mdot
.974 .19869 Mdot
.974 .19901 Mdot
.974 .19919 Mdot
.974 .19944 Mdot
.974 .19965 Mdot
.974 .19979 Mdot
.974 .19995 Mdot
.974 .20285 Mdot
.974 .20364 Mdot
.974 .20436 Mdot
.974 .20538 Mdot
.974 .2055 Mdot
.974 .20561 Mdot
.974 .20631 Mdot
.974 .20643 Mdot
.974 .20666 Mdot
.974 .20723 Mdot
.974 .20878 Mdot
.974 .21097 Mdot
.974 .21172 Mdot
.974 .21173 Mdot
.974 .21193 Mdot
.974 .21215 Mdot
.974 .21239 Mdot
.974 .21462 Mdot
.974 .21499 Mdot
.974 .21583 Mdot
.974 .21628 Mdot
.974 .21654 Mdot
.974 .2167 Mdot
.974 .21696 Mdot
.974 .21933 Mdot
.974 .21944 Mdot
.974 .22037 Mdot
.974 .22047 Mdot
.974 .22054 Mdot
.974 .22097 Mdot
.974 .22192 Mdot
.974 .22291 Mdot
.974 .22336 Mdot
.974 .22509 Mdot
.974 .22639 Mdot
.974 .2264 Mdot
.974 .2273 Mdot
.974 .22898 Mdot
.974 .22962 Mdot
.974 .23024 Mdot
.974 .23093 Mdot
.974 .23128 Mdot
.974 .23168 Mdot
.974 .23189 Mdot
.974 .23233 Mdot
.974 .2329 Mdot
.974 .23471 Mdot
.974 .2356 Mdot
.974 .23705 Mdot
.974 .23803 Mdot
.974 .23897 Mdot
.974 .23916 Mdot
.974 .23951 Mdot
.974 .24131 Mdot
.974 .24187 Mdot
.974 .24223 Mdot
.974 .24371 Mdot
.974 .24444 Mdot
.974 .2472 Mdot
.974 .24832 Mdot
.974 .24836 Mdot
.974 .24846 Mdot
.974 .24881 Mdot
.974 .24928 Mdot
.974 .24928 Mdot
.974 .24943 Mdot
.974 .25004 Mdot
.974 .25014 Mdot
.974 .25031 Mdot
.974 .25046 Mdot
.974 .25072 Mdot
.974 .25083 Mdot
.974 .2511 Mdot
.974 .25117 Mdot
.974 .2536 Mdot
.974 .25418 Mdot
.974 .25796 Mdot
.974 .25938 Mdot
.974 .25941 Mdot
.974 .25988 Mdot
.974 .2608 Mdot
.974 .26306 Mdot
.974 .26311 Mdot
.974 .26432 Mdot
.974 .26705 Mdot
.974 .26719 Mdot
.974 .26756 Mdot
.974 .26946 Mdot
.974 .27183 Mdot
.974 .27279 Mdot
.974 .27325 Mdot
.974 .27388 Mdot
.974 .27614 Mdot
.974 .2766 Mdot
.974 .27661 Mdot
.974 .27711 Mdot
.974 .27735 Mdot
.974 .27757 Mdot
.974 .2794 Mdot
.974 .28134 Mdot
.974 .28196 Mdot
.974 .28313 Mdot
.974 .28387 Mdot
.974 .28434 Mdot
.974 .28633 Mdot
.974 .28633 Mdot
.974 .28647 Mdot
.974 .28762 Mdot
.974 .28807 Mdot
.974 .28909 Mdot
.974 .28974 Mdot
.974 .2907 Mdot
.974 .29074 Mdot
.974 .29121 Mdot
.974 .29153 Mdot
.974 .29165 Mdot
.974 .29468 Mdot
.974 .29814 Mdot
.974 .29978 Mdot
.974 .30045 Mdot
.974 .30104 Mdot
.974 .30171 Mdot
.974 .30193 Mdot
.974 .30298 Mdot
.974 .30326 Mdot
.974 .30363 Mdot
.974 .30375 Mdot
.974 .30412 Mdot
.974 .30508 Mdot
.974 .30554 Mdot
.974 .30578 Mdot
.974 .3059 Mdot
.974 .30622 Mdot
.974 .30756 Mdot
.974 .30758 Mdot
.974 .30841 Mdot
.974 .3087 Mdot
.974 .3109 Mdot
.974 .31272 Mdot
.974 .31497 Mdot
.974 .31637 Mdot
.974 .31811 Mdot
.974 .3197 Mdot
.974 .31989 Mdot
.974 .32002 Mdot
.974 .32072 Mdot
.974 .32115 Mdot
.974 .32134 Mdot
.974 .32227 Mdot
.974 .32417 Mdot
.974 .32441 Mdot
.974 .32484 Mdot
.974 .32715 Mdot
.974 .32796 Mdot
.974 .33018 Mdot
.974 .33107 Mdot
.974 .33121 Mdot
.974 .3323 Mdot
.974 .33266 Mdot
.974 .33302 Mdot
.974 .33311 Mdot
.974 .33395 Mdot
.974 .33502 Mdot
.974 .33512 Mdot
.974 .33551 Mdot
.974 .33631 Mdot
.974 .33651 Mdot
.974 .3373 Mdot
.974 .33792 Mdot
.974 .3384 Mdot
.974 .33844 Mdot
.974 .33846 Mdot
.974 .33904 Mdot
.974 .33957 Mdot
.974 .33957 Mdot
.974 .33957 Mdot
.974 .34084 Mdot
.974 .34111 Mdot
.974 .34155 Mdot
.974 .34164 Mdot
.974 .34245 Mdot
.974 .34407 Mdot
.974 .34433 Mdot
.974 .34441 Mdot
.974 .34556 Mdot
.974 .34652 Mdot
.974 .34681 Mdot
.974 .34727 Mdot
.974 .3475 Mdot
.974 .34755 Mdot
.974 .34933 Mdot
.974 .34943 Mdot
.974 .35007 Mdot
.974 .35061 Mdot
.974 .35187 Mdot
.974 .35215 Mdot
.974 .35226 Mdot
.974 .3533 Mdot
.974 .35333 Mdot
.974 .35376 Mdot
.974 .35486 Mdot
.974 .35487 Mdot
.974 .35596 Mdot
.974 .35616 Mdot
.974 .35684 Mdot
.974 .35728 Mdot
.974 .35951 Mdot
.974 .36021 Mdot
.974 .36054 Mdot
.974 .36216 Mdot
.974 .36222 Mdot
.974 .36245 Mdot
.974 .36246 Mdot
.974 .3628 Mdot
.974 .3643 Mdot
.974 .36452 Mdot
.974 .36581 Mdot
.974 .36634 Mdot
.974 .36678 Mdot
.974 .36832 Mdot
.974 .36896 Mdot
.974 .36913 Mdot
.974 .37431 Mdot
.974 .37452 Mdot
.974 .37554 Mdot
.974 .37719 Mdot
.974 .37859 Mdot
.974 .37971 Mdot
.974 .38138 Mdot
.974 .38371 Mdot
.974 .38433 Mdot
.974 .38438 Mdot
.974 .38632 Mdot
.974 .38952 Mdot
.974 .39036 Mdot
.974 .39087 Mdot
.974 .39108 Mdot
.974 .39299 Mdot
.974 .39397 Mdot
.974 .39418 Mdot
.974 .39488 Mdot
.974 .39491 Mdot
.974 .3963 Mdot
.974 .39641 Mdot
.974 .39828 Mdot
.974 .39857 Mdot
.974 .39932 Mdot
.974 .40386 Mdot
.974 .40446 Mdot
.974 .40533 Mdot
.974 .40561 Mdot
.974 .40562 Mdot
.974 .40573 Mdot
.974 .40585 Mdot
.974 .40585 Mdot
.974 .40621 Mdot
.974 .40835 Mdot
.974 .40846 Mdot
.974 .41253 Mdot
.974 .41321 Mdot
.974 .41487 Mdot
.974 .4149 Mdot
.974 .41592 Mdot
.974 .41593 Mdot
.974 .41687 Mdot
.974 .41891 Mdot
.974 .41945 Mdot
.974 .41961 Mdot
.974 .41993 Mdot
.974 .42168 Mdot
.974 .42314 Mdot
.974 .42456 Mdot
.974 .42551 Mdot
.974 .42596 Mdot
.974 .42652 Mdot
.974 .42778 Mdot
.974 .42795 Mdot
.974 .42854 Mdot
.974 .42935 Mdot
.974 .43279 Mdot
.974 .43286 Mdot
.974 .43286 Mdot
.974 .4333 Mdot
.974 .43378 Mdot
.974 .43388 Mdot
.974 .43444 Mdot
.974 .43595 Mdot
.974 .43733 Mdot
.974 .43946 Mdot
.974 .44135 Mdot
.974 .44283 Mdot
.974 .44311 Mdot
.974 .44311 Mdot
.974 .44325 Mdot
.974 .44535 Mdot
.974 .4456 Mdot
.974 .44583 Mdot
.974 .44657 Mdot
.974 .4477 Mdot
.974 .44849 Mdot
.974 .44868 Mdot
.974 .45085 Mdot
.974 .45138 Mdot
.974 .45156 Mdot
.974 .45185 Mdot
.974 .45229 Mdot
.974 .45285 Mdot
.974 .45438 Mdot
.974 .45442 Mdot
.974 .4545 Mdot
.974 .45589 Mdot
.974 .45696 Mdot
.974 .45718 Mdot
.974 .45732 Mdot
.974 .45741 Mdot
.974 .45885 Mdot
.974 .45979 Mdot
.974 .46039 Mdot
.974 .46148 Mdot
.974 .46148 Mdot
.974 .46233 Mdot
.974 .46324 Mdot
.974 .46426 Mdot
.974 .46563 Mdot
.974 .46594 Mdot
.974 .46617 Mdot
.974 .46839 Mdot
.974 .46875 Mdot
.974 .47023 Mdot
.974 .47088 Mdot
.974 .47234 Mdot
.974 .47372 Mdot
.974 .47414 Mdot
.974 .4746 Mdot
.974 .47461 Mdot
.974 .4775 Mdot
.974 .47844 Mdot
.974 .47865 Mdot
.974 .47869 Mdot
.974 .4787 Mdot
.974 .47882 Mdot
.974 .4792 Mdot
.974 .48142 Mdot
.974 .48187 Mdot
.974 .48361 Mdot
.974 .48411 Mdot
.974 .48501 Mdot
.974 .48522 Mdot
.974 .48691 Mdot
.974 .48773 Mdot
.974 .48799 Mdot
.974 .48895 Mdot
.974 .49134 Mdot
.974 .49175 Mdot
.974 .49183 Mdot
.974 .49392 Mdot
.974 .49486 Mdot
.974 .49503 Mdot
.974 .49575 Mdot
.974 .49584 Mdot
.974 .49657 Mdot
.974 .49657 Mdot
.974 .49666 Mdot
.974 .49669 Mdot
.974 .4986 Mdot
.974 .49997 Mdot
.974 .50055 Mdot
.974 .5007 Mdot
.974 .50164 Mdot
.974 .50167 Mdot
.974 .50237 Mdot
.974 .50247 Mdot
.974 .50359 Mdot
.974 .50368 Mdot
.974 .50464 Mdot
.974 .5048 Mdot
.974 .50491 Mdot
.974 .50581 Mdot
.974 .50581 Mdot
.974 .50624 Mdot
.974 .50654 Mdot
.974 .50661 Mdot
.974 .50691 Mdot
.974 .50709 Mdot
.974 .5078 Mdot
.974 .50784 Mdot
.974 .50797 Mdot
.974 .50851 Mdot
.974 .50889 Mdot
.974 .50971 Mdot
.974 .51001 Mdot
.974 .51101 Mdot
.974 .5111 Mdot
.974 .5122 Mdot
.974 .51262 Mdot
.974 .51331 Mdot
.974 .51444 Mdot
.974 .51525 Mdot
.974 .5159 Mdot
.974 .51709 Mdot
.974 .51709 Mdot
.974 .51757 Mdot
.974 .51781 Mdot
.974 .51797 Mdot
.974 .51844 Mdot
.974 .51862 Mdot
.974 .51872 Mdot
.974 .51909 Mdot
.974 .5194 Mdot
.974 .5196 Mdot
.974 .51984 Mdot
.974 .52162 Mdot
.974 .52299 Mdot
.974 .523 Mdot
.974 .52406 Mdot
.974 .52446 Mdot
.974 .52451 Mdot
.974 .52519 Mdot
.974 .52621 Mdot
.974 .52687 Mdot
.974 .52765 Mdot
.974 .52782 Mdot
.974 .52782 Mdot
.974 .52798 Mdot
.974 .52895 Mdot
.974 .52911 Mdot
.974 .52943 Mdot
.974 .53022 Mdot
.974 .53233 Mdot
.974 .5334 Mdot
.974 .53356 Mdot
.974 .53527 Mdot
.974 .53625 Mdot
.974 .53628 Mdot
.974 .5364 Mdot
.974 .53654 Mdot
.974 .53682 Mdot
.974 .53687 Mdot
.974 .53687 Mdot
.974 .53702 Mdot
.974 .53714 Mdot
.974 .53717 Mdot
.974 .53718 Mdot
.974 .53754 Mdot
.974 .53867 Mdot
.974 .53944 Mdot
.974 .54002 Mdot
.974 .54049 Mdot
.974 .54155 Mdot
.974 .54212 Mdot
.974 .54245 Mdot
.974 .54264 Mdot
.974 .54297 Mdot
.974 .54316 Mdot
.974 .54513 Mdot
.974 .54588 Mdot
.974 .54601 Mdot
.974 .54604 Mdot
.974 .54639 Mdot
.974 .54713 Mdot
.974 .54726 Mdot
.974 .54734 Mdot
.974 .54785 Mdot
.974 .54862 Mdot
.974 .54875 Mdot
.974 .54898 Mdot
.974 .55013 Mdot
.974 .55038 Mdot
.974 .55041 Mdot
.974 .55066 Mdot
.974 .55123 Mdot
.974 .55147 Mdot
.974 .55259 Mdot
.974 .55264 Mdot
.974 .5541 Mdot
.974 .55412 Mdot
.974 .55473 Mdot
.974 .55496 Mdot
.974 .55512 Mdot
.974 .55553 Mdot
.974 .55644 Mdot
.974 .55695 Mdot
.974 .55764 Mdot
.974 .5583 Mdot
.974 .55904 Mdot
.974 .5594 Mdot
.974 .55983 Mdot
.974 .55986 Mdot
.974 .56004 Mdot
.974 .5605 Mdot
.974 .5611 Mdot
.974 .56186 Mdot
.974 .56191 Mdot
.974 .56254 Mdot
.974 .56293 Mdot
.974 .56382 Mdot
.974 .56486 Mdot
.974 .56525 Mdot
.974 .5662 Mdot
.974 .56648 Mdot
.974 .56709 Mdot
.974 .56727 Mdot
.974 .56754 Mdot
.974 .56759 Mdot
.974 .56884 Mdot
.974 .56927 Mdot
.974 .56978 Mdot
.974 .5701 Mdot
.974 .57035 Mdot
.974 .57125 Mdot
.974 .57143 Mdot
.974 .57143 Mdot
.974 .57207 Mdot
.974 .57442 Mdot
.974 .57535 Mdot
.974 .57539 Mdot
.974 .57547 Mdot
.974 .57575 Mdot
.974 .57583 Mdot
.974 .57597 Mdot
.974 .57613 Mdot
.974 .57614 Mdot
.974 .57626 Mdot
.974 .57648 Mdot
.974 .57675 Mdot
.974 .57683 Mdot
.974 .57696 Mdot
.974 .57708 Mdot
.974 .57728 Mdot
.974 .57737 Mdot
.974 .57758 Mdot
.974 .57764 Mdot
.974 .5777 Mdot
.974 .57804 Mdot
.974 .57846 Mdot
.974 .57944 Mdot
.974 .5795 Mdot
.974 .5796 Mdot
.974 .57993 Mdot
.974 .58071 Mdot
.974 .58095 Mdot
.974 .58096 Mdot
.974 .58112 Mdot
.974 .58117 Mdot
.974 .58231 Mdot
.974 .58254 Mdot
.974 .58264 Mdot
.974 .58303 Mdot
.974 .5836 Mdot
.974 .58362 Mdot
.974 .58394 Mdot
.974 .58451 Mdot
.974 .58454 Mdot
.974 .5848 Mdot
.974 .58523 Mdot
.974 .58536 Mdot
.974 .58598 Mdot
.974 .58601 Mdot
.974 .58604 Mdot
.974 .58605 Mdot
.974 .58672 Mdot
.974 .58676 Mdot
.974 .58699 Mdot
.974 .587 Mdot
.974 .58762 Mdot
.974 .58768 Mdot
.974 .58785 Mdot
.974 .58835 Mdot
.974 .58843 Mdot
.974 .58856 Mdot
.974 .58864 Mdot
.974 .58886 Mdot
.974 .58922 Mdot
.974 .58927 Mdot
.974 .58968 Mdot
.974 .59022 Mdot
.974 .59024 Mdot
.974 .59037 Mdot
.974 .5906 Mdot
.974 .59075 Mdot
.974 .59091 Mdot
.974 .59123 Mdot
.974 .59138 Mdot
.974 .59161 Mdot
.974 .59179 Mdot
.974 .59183 Mdot
.974 .59191 Mdot
.974 .59195 Mdot
.974 .5927 Mdot
.974 .59295 Mdot
.974 .59306 Mdot
.974 .5931 Mdot
.974 .59316 Mdot
.974 .59316 Mdot
.974 .59329 Mdot
.974 .59338 Mdot
.974 .59341 Mdot
.974 .59348 Mdot
.974 .59358 Mdot
.974 .59395 Mdot
.974 .59395 Mdot
.974 .59395 Mdot
.974 .59417 Mdot
.974 .59433 Mdot
.974 .5944 Mdot
.974 .5944 Mdot
.974 .59442 Mdot
.974 .59461 Mdot
.974 .59485 Mdot
.974 .59508 Mdot
.974 .59515 Mdot
.974 .59522 Mdot
.974 .59531 Mdot
.974 .59551 Mdot
.974 .59565 Mdot
.974 .59569 Mdot
.974 .59573 Mdot
.974 .59598 Mdot
.974 .59606 Mdot
.974 .59614 Mdot
.974 .59633 Mdot
.974 .59636 Mdot
.974 .59648 Mdot
.974 .59659 Mdot
.974 .59678 Mdot
.974 .59678 Mdot
.974 .59682 Mdot
.974 .59693 Mdot
.974 .59697 Mdot
.974 .59716 Mdot
.974 .59723 Mdot
.974 .59729 Mdot
.974 .59757 Mdot
.974 .59775 Mdot
.974 .59783 Mdot
.974 .59799 Mdot
.974 .598 Mdot
.974 .59804 Mdot
.974 .59812 Mdot
.974 .59819 Mdot
.974 .59822 Mdot
.974 .59856 Mdot
.974 .59866 Mdot
.974 .59871 Mdot
.974 .59887 Mdot
.974 .59907 Mdot
.974 .59923 Mdot
.974 .59926 Mdot
.974 .59933 Mdot
.974 .59944 Mdot
.974 .59946 Mdot
.974 .59946 Mdot
.974 .59949 Mdot
.974 .59968 Mdot
.974 .5997 Mdot
.974 .59976 Mdot
.974 .59983 Mdot
.974 .59989 Mdot
.974 .5999 Mdot
.974 .59992 Mdot
.974 .60001 Mdot
.974 .60002 Mdot
.974 .60003 Mdot
.974 .60006 Mdot
.974 .60007 Mdot
.974 .6001 Mdot
.974 .60015 Mdot
.974 .60017 Mdot
.974 .60018 Mdot
.974 .60019 Mdot
.974 .60019 Mdot
.974 .60021 Mdot
.974 .60023 Mdot
.974 .60024 Mdot
.974 .60024 Mdot
.974 .60026 Mdot
.974 .60026 Mdot
.976 .02593 Mdot
.976 .02593 Mdot
.976 .02607 Mdot
.976 .02614 Mdot
.976 .02617 Mdot
.976 .02634 Mdot
.976 .02638 Mdot
.976 .02639 Mdot
.976 .02641 Mdot
.976 .02648 Mdot
.976 .02656 Mdot
.976 .02658 Mdot
.976 .02661 Mdot
.976 .02665 Mdot
.976 .0267 Mdot
.976 .02679 Mdot
.976 .02679 Mdot
.976 .02682 Mdot
.976 .02724 Mdot
.976 .02729 Mdot
.976 .02737 Mdot
.976 .02751 Mdot
.976 .02772 Mdot
.976 .02795 Mdot
.976 .02838 Mdot
.976 .02848 Mdot
.976 .0287 Mdot
.976 .02901 Mdot
.976 .02914 Mdot
.976 .02946 Mdot
.976 .02971 Mdot
.976 .0298 Mdot
.976 .03005 Mdot
.976 .03014 Mdot
.976 .03017 Mdot
.976 .03048 Mdot
.976 .0306 Mdot
.976 .0307 Mdot
.976 .03154 Mdot
.976 .03159 Mdot
.976 .03229 Mdot
.976 .03264 Mdot
.976 .03286 Mdot
.976 .033 Mdot
.976 .03372 Mdot
.976 .0339 Mdot
.976 .0341 Mdot
.976 .03439 Mdot
.976 .03455 Mdot
.976 .03466 Mdot
.976 .03483 Mdot
.976 .03491 Mdot
.976 .03581 Mdot
.976 .03652 Mdot
.976 .03667 Mdot
.976 .03681 Mdot
.976 .03696 Mdot
.976 .03837 Mdot
.976 .0385 Mdot
.976 .03859 Mdot
.976 .03936 Mdot
.976 .0406 Mdot
.976 .0407 Mdot
.976 .04094 Mdot
.976 .04124 Mdot
.976 .04134 Mdot
.976 .04205 Mdot
.976 .04301 Mdot
.976 .04382 Mdot
.976 .04462 Mdot
.976 .04473 Mdot
.976 .04494 Mdot
.976 .04602 Mdot
.976 .0477 Mdot
.976 .04829 Mdot
.976 .04889 Mdot
.976 .04918 Mdot
.976 .04955 Mdot
.976 .04964 Mdot
.976 .05022 Mdot
.976 .05227 Mdot
.976 .05227 Mdot
.976 .05325 Mdot
.976 .05358 Mdot
.976 .05498 Mdot
.976 .05543 Mdot
.976 .05703 Mdot
.976 .05743 Mdot
.976 .05789 Mdot
.976 .05817 Mdot
.976 .05832 Mdot
.976 .0585 Mdot
.976 .05851 Mdot
.976 .05859 Mdot
.976 .05894 Mdot
.976 .05903 Mdot
.976 .05932 Mdot
.976 .05943 Mdot
.976 .0601 Mdot
.976 .06025 Mdot
.976 .06028 Mdot
.976 .06034 Mdot
.976 .06063 Mdot
.976 .06091 Mdot
.976 .06101 Mdot
.976 .06111 Mdot
.976 .06127 Mdot
.976 .06146 Mdot
.976 .06181 Mdot
.976 .06182 Mdot
.976 .06191 Mdot
.976 .06203 Mdot
.976 .06342 Mdot
.976 .06351 Mdot
.976 .06372 Mdot
.976 .064 Mdot
.976 .06401 Mdot
.976 .0644 Mdot
.976 .06443 Mdot
.976 .06455 Mdot
.976 .06502 Mdot
.976 .06527 Mdot
.976 .06535 Mdot
.976 .06601 Mdot
.976 .06607 Mdot
.976 .06622 Mdot
.976 .06629 Mdot
.976 .06771 Mdot
.976 .06787 Mdot
.976 .06823 Mdot
.976 .06835 Mdot
.976 .06904 Mdot
.976 .06906 Mdot
.976 .07025 Mdot
.976 .07043 Mdot
.976 .07073 Mdot
.976 .07196 Mdot
.976 .07287 Mdot
.976 .07304 Mdot
.976 .07323 Mdot
.976 .07418 Mdot
.976 .07432 Mdot
.976 .0745 Mdot
.976 .07461 Mdot
.976 .07581 Mdot
.976 .07626 Mdot
.976 .07664 Mdot
.976 .07688 Mdot
.976 .07721 Mdot
.976 .07747 Mdot
.976 .07834 Mdot
.976 .07846 Mdot
.976 .0798 Mdot
.976 .07998 Mdot
.976 .08085 Mdot
.976 .08148 Mdot
.976 .08186 Mdot
.976 .08192 Mdot
.976 .0826 Mdot
.976 .08373 Mdot
.976 .08391 Mdot
.976 .08442 Mdot
.976 .08474 Mdot
.976 .08524 Mdot
.976 .08599 Mdot
.976 .08742 Mdot
.976 .08792 Mdot
.976 .08808 Mdot
.976 .08826 Mdot
.976 .0886 Mdot
.976 .08929 Mdot
.976 .08934 Mdot
.976 .08981 Mdot
.976 .09018 Mdot
.976 .09044 Mdot
.976 .09101 Mdot
.976 .0911 Mdot
.976 .09142 Mdot
.976 .09207 Mdot
.976 .09234 Mdot
.976 .0928 Mdot
.976 .09319 Mdot
.976 .09377 Mdot
.976 .09509 Mdot
.976 .09514 Mdot
.976 .09568 Mdot
.976 .09629 Mdot
.976 .09832 Mdot
.976 .09886 Mdot
.976 .09891 Mdot
.976 .09937 Mdot
.976 .09991 Mdot
.976 .10036 Mdot
.976 .1011 Mdot
.976 .10229 Mdot
.976 .10308 Mdot
.976 .10437 Mdot
.976 .10509 Mdot
.976 .1053 Mdot
.976 .10538 Mdot
.976 .10557 Mdot
.976 .10571 Mdot
.976 .10591 Mdot
.976 .10597 Mdot
.976 .10614 Mdot
.976 .10866 Mdot
.976 .10872 Mdot
.976 .10881 Mdot
.976 .11001 Mdot
.976 .11008 Mdot
.976 .1102 Mdot
.976 .11067 Mdot
.976 .11323 Mdot
.976 .11361 Mdot
.976 .11405 Mdot
.976 .11445 Mdot
.976 .11554 Mdot
.976 .11586 Mdot
.976 .1159 Mdot
.976 .11629 Mdot
.976 .11848 Mdot
.976 .11932 Mdot
.976 .11966 Mdot
.976 .11968 Mdot
.976 .12164 Mdot
.976 .12193 Mdot
.976 .12225 Mdot
.976 .12425 Mdot
.976 .1246 Mdot
.976 .12487 Mdot
.976 .12771 Mdot
.976 .12777 Mdot
.976 .12811 Mdot
.976 .12886 Mdot
.976 .12948 Mdot
.976 .13109 Mdot
.976 .13272 Mdot
.976 .13419 Mdot
.976 .13436 Mdot
.976 .13717 Mdot
.976 .13824 Mdot
.976 .13825 Mdot
.976 .13868 Mdot
.976 .13946 Mdot
.976 .14075 Mdot
.976 .14267 Mdot
.976 .14287 Mdot
.976 .14386 Mdot
.976 .14388 Mdot
.976 .1452 Mdot
.976 .14526 Mdot
.976 .14549 Mdot
.976 .14636 Mdot
.976 .14686 Mdot
.976 .14753 Mdot
.976 .14767 Mdot
.976 .14961 Mdot
.976 .15133 Mdot
.976 .15143 Mdot
.976 .15283 Mdot
.976 .15295 Mdot
.976 .15341 Mdot
.976 .1543 Mdot
.976 .15468 Mdot
.976 .1547 Mdot
.976 .1556 Mdot
.976 .15571 Mdot
.976 .15809 Mdot
.976 .15909 Mdot
.976 .15922 Mdot
.976 .16084 Mdot
.976 .16155 Mdot
.976 .16166 Mdot
.976 .16406 Mdot
.976 .16559 Mdot
.976 .16576 Mdot
.976 .16991 Mdot
.976 .17073 Mdot
.976 .17106 Mdot
.976 .1724 Mdot
.976 .17398 Mdot
.976 .17441 Mdot
.976 .1746 Mdot
.976 .17462 Mdot
.976 .17492 Mdot
.976 .17545 Mdot
.976 .17606 Mdot
.976 .17609 Mdot
.976 .17636 Mdot
.976 .17753 Mdot
.976 .17786 Mdot
.976 .17799 Mdot
.976 .17883 Mdot
.976 .1792 Mdot
.976 .18146 Mdot
.976 .18198 Mdot
.976 .18206 Mdot
.976 .18228 Mdot
.976 .18325 Mdot
.976 .18343 Mdot
.976 .18371 Mdot
.976 .18419 Mdot
.976 .1843 Mdot
.976 .18453 Mdot
.976 .18485 Mdot
.976 .18538 Mdot
.976 .18566 Mdot
.976 .18585 Mdot
.976 .18602 Mdot
.976 .18678 Mdot
.976 .18719 Mdot
.976 .18722 Mdot
.976 .18725 Mdot
.976 .18752 Mdot
.976 .18766 Mdot
.976 .18794 Mdot
.976 .18853 Mdot
.976 .18935 Mdot
.976 .19021 Mdot
.976 .19254 Mdot
.976 .19288 Mdot
.976 .19356 Mdot
.976 .19448 Mdot
.976 .19452 Mdot
.976 .19582 Mdot
.976 .1959 Mdot
.976 .19629 Mdot
.976 .19664 Mdot
.976 .19787 Mdot
.976 .19868 Mdot
.976 .19882 Mdot
.976 .19894 Mdot
.976 .20064 Mdot
.976 .20112 Mdot
.976 .20133 Mdot
.976 .20149 Mdot
.976 .20182 Mdot
.976 .20202 Mdot
.976 .20283 Mdot
.976 .20301 Mdot
.976 .204 Mdot
.976 .20459 Mdot
.976 .20489 Mdot
.976 .20669 Mdot
.976 .20681 Mdot
.976 .20721 Mdot
.976 .2084 Mdot
.976 .20877 Mdot
.976 .21103 Mdot
.976 .21109 Mdot
.976 .21492 Mdot
.976 .21499 Mdot
.976 .21553 Mdot
.976 .21613 Mdot
.976 .21647 Mdot
.976 .21709 Mdot
.976 .22042 Mdot
.976 .22072 Mdot
.976 .22285 Mdot
.976 .22336 Mdot
.976 .22344 Mdot
.976 .2239 Mdot
.976 .22449 Mdot
.976 .22729 Mdot
.976 .22752 Mdot
.976 .22798 Mdot
.976 .22848 Mdot
.976 .22853 Mdot
.976 .2289 Mdot
.976 .22914 Mdot
.976 .23159 Mdot
.976 .2327 Mdot
.976 .23293 Mdot
.976 .23412 Mdot
.976 .2353 Mdot
.976 .23533 Mdot
.976 .23605 Mdot
.976 .23708 Mdot
.976 .23747 Mdot
.976 .23773 Mdot
.976 .23787 Mdot
.976 .2379 Mdot
.976 .23832 Mdot
.976 .23835 Mdot
.976 .24062 Mdot
.976 .24099 Mdot
.976 .24199 Mdot
.976 .24237 Mdot
.976 .24516 Mdot
.976 .24572 Mdot
.976 .24676 Mdot
.976 .24841 Mdot
.976 .24956 Mdot
.976 .25034 Mdot
.976 .25152 Mdot
.976 .25169 Mdot
.976 .25173 Mdot
.976 .25218 Mdot
.976 .25314 Mdot
.976 .25329 Mdot
.976 .25342 Mdot
.976 .25378 Mdot
.976 .25527 Mdot
.976 .25725 Mdot
.976 .25778 Mdot
.976 .25934 Mdot
.976 .26031 Mdot
.976 .26155 Mdot
.976 .26183 Mdot
.976 .2626 Mdot
.976 .26262 Mdot
.976 .26409 Mdot
.976 .26414 Mdot
.976 .2684 Mdot
.976 .26905 Mdot
.976 .26989 Mdot
.976 .27038 Mdot
.976 .27068 Mdot
.976 .27089 Mdot
.976 .27119 Mdot
.976 .27191 Mdot
.976 .27398 Mdot
.976 .27414 Mdot
.976 .27552 Mdot
.976 .2766 Mdot
.976 .27739 Mdot
.976 .27866 Mdot
.976 .27908 Mdot
.976 .27932 Mdot
.976 .27951 Mdot
.976 .2799 Mdot
.976 .28029 Mdot
.976 .28143 Mdot
.976 .28219 Mdot
.976 .28234 Mdot
.976 .28299 Mdot
.976 .28432 Mdot
.976 .28547 Mdot
.976 .28649 Mdot
.976 .28714 Mdot
.976 .28722 Mdot
.976 .2897 Mdot
.976 .29061 Mdot
.976 .29068 Mdot
.976 .29086 Mdot
.976 .29098 Mdot
.976 .29114 Mdot
.976 .29146 Mdot
.976 .29268 Mdot
.976 .29284 Mdot
.976 .29352 Mdot
.976 .29439 Mdot
.976 .29446 Mdot
.976 .29641 Mdot
.976 .30026 Mdot
.976 .3018 Mdot
.976 .30194 Mdot
.976 .30317 Mdot
.976 .30325 Mdot
.976 .30356 Mdot
.976 .30373 Mdot
.976 .30388 Mdot
.976 .30408 Mdot
.976 .30468 Mdot
.976 .30478 Mdot
.976 .30587 Mdot
.976 .30605 Mdot
.976 .30809 Mdot
.976 .30814 Mdot
.976 .31146 Mdot
.976 .31307 Mdot
.976 .31328 Mdot
.976 .31367 Mdot
.976 .31406 Mdot
.976 .31478 Mdot
.976 .31642 Mdot
.976 .31677 Mdot
.976 .31727 Mdot
.976 .31866 Mdot
.976 .31885 Mdot
.976 .31926 Mdot
.976 .31981 Mdot
.976 .32003 Mdot
.976 .32057 Mdot
.976 .32096 Mdot
.976 .32111 Mdot
.976 .3215 Mdot
.976 .32167 Mdot
.976 .32213 Mdot
.976 .3223 Mdot
.976 .32245 Mdot
.976 .32493 Mdot
.976 .32616 Mdot
.976 .32636 Mdot
.976 .32902 Mdot
.976 .32916 Mdot
.976 .32929 Mdot
.976 .32942 Mdot
.976 .33069 Mdot
.976 .33265 Mdot
.976 .33284 Mdot
.976 .33308 Mdot
.976 .33315 Mdot
.976 .33444 Mdot
.976 .33562 Mdot
.976 .33901 Mdot
.976 .34065 Mdot
.976 .34124 Mdot
.976 .34225 Mdot
.976 .34342 Mdot
.976 .34364 Mdot
.976 .34414 Mdot
.976 .34428 Mdot
.976 .34447 Mdot
.976 .34734 Mdot
.976 .34778 Mdot
.976 .34818 Mdot
.976 .34828 Mdot
.976 .34929 Mdot
.976 .35029 Mdot
.976 .35151 Mdot
.976 .3521 Mdot
.976 .35324 Mdot
.976 .35339 Mdot
.976 .35351 Mdot
.976 .35498 Mdot
.976 .35524 Mdot
.976 .35714 Mdot
.976 .35799 Mdot
.976 .35806 Mdot
.976 .35848 Mdot
.976 .35883 Mdot
.976 .3592 Mdot
.976 .35987 Mdot
.976 .36003 Mdot
.976 .36076 Mdot
.976 .36123 Mdot
.976 .36304 Mdot
.976 .36348 Mdot
.976 .36378 Mdot
.976 .36459 Mdot
.976 .36483 Mdot
.976 .3658 Mdot
.976 .36628 Mdot
.976 .36832 Mdot
.976 .3695 Mdot
.976 .36962 Mdot
.976 .37029 Mdot
.976 .37049 Mdot
.976 .37116 Mdot
.976 .37339 Mdot
.976 .37438 Mdot
.976 .37444 Mdot
.976 .37533 Mdot
.976 .37567 Mdot
.976 .37784 Mdot
.976 .37818 Mdot
.976 .37833 Mdot
.976 .37857 Mdot
.976 .37916 Mdot
.976 .38098 Mdot
.976 .38249 Mdot
.976 .38638 Mdot
.976 .38643 Mdot
.976 .38738 Mdot
.976 .38897 Mdot
.976 .38981 Mdot
.976 .38994 Mdot
.976 .39029 Mdot
.976 .39248 Mdot
.976 .39306 Mdot
.976 .39377 Mdot
.976 .39418 Mdot
.976 .39444 Mdot
.976 .39786 Mdot
.976 .39879 Mdot
.976 .39934 Mdot
.976 .39949 Mdot
.976 .40047 Mdot
.976 .40077 Mdot
.976 .40314 Mdot
.976 .40326 Mdot
.976 .40327 Mdot
.976 .40417 Mdot
.976 .40427 Mdot
.976 .40536 Mdot
.976 .40606 Mdot
.976 .40659 Mdot
.976 .4067 Mdot
.976 .40698 Mdot
.976 .40746 Mdot
.976 .409 Mdot
.976 .40926 Mdot
.976 .41335 Mdot
.976 .41381 Mdot
.976 .41579 Mdot
.976 .41603 Mdot
.976 .41607 Mdot
.976 .419 Mdot
.976 .41913 Mdot
.976 .41917 Mdot
.976 .41964 Mdot
.976 .42134 Mdot
.976 .42157 Mdot
.976 .42266 Mdot
.976 .4227 Mdot
.976 .42323 Mdot
.976 .42413 Mdot
.976 .42442 Mdot
.976 .42605 Mdot
.976 .42664 Mdot
.976 .42744 Mdot
.976 .42853 Mdot
.976 .42864 Mdot
.976 .43209 Mdot
.976 .43234 Mdot
.976 .43255 Mdot
.976 .43552 Mdot
.976 .43577 Mdot
.976 .43674 Mdot
.976 .4386 Mdot
.976 .4394 Mdot
.976 .43943 Mdot
.976 .44132 Mdot
.976 .44154 Mdot
.976 .44171 Mdot
.976 .44283 Mdot
.976 .4435 Mdot
.976 .44645 Mdot
.976 .44744 Mdot
.976 .44827 Mdot
.976 .44847 Mdot
.976 .44873 Mdot
.976 .44961 Mdot
.976 .45199 Mdot
.976 .45343 Mdot
.976 .45364 Mdot
.976 .45838 Mdot
.976 .45904 Mdot
.976 .45945 Mdot
.976 .46137 Mdot
.976 .4617 Mdot
.976 .46224 Mdot
.976 .46681 Mdot
.976 .46848 Mdot
.976 .46898 Mdot
.976 .46935 Mdot
.976 .46962 Mdot
.976 .47091 Mdot
.976 .47115 Mdot
.976 .47177 Mdot
.976 .47276 Mdot
.976 .47427 Mdot
.976 .47717 Mdot
.976 .47796 Mdot
.976 .47817 Mdot
.976 .47829 Mdot
.976 .47834 Mdot
.976 .47888 Mdot
.976 .47939 Mdot
.976 .47984 Mdot
.976 .48094 Mdot
.976 .48099 Mdot
.976 .48141 Mdot
.976 .48148 Mdot
.976 .48171 Mdot
.976 .48211 Mdot
.976 .48357 Mdot
.976 .48415 Mdot
.976 .48439 Mdot
.976 .48546 Mdot
.976 .48552 Mdot
.976 .48587 Mdot
.976 .48653 Mdot
.976 .48693 Mdot
.976 .49016 Mdot
.976 .49046 Mdot
.976 .49134 Mdot
.976 .49148 Mdot
.976 .49184 Mdot
.976 .49186 Mdot
.976 .49226 Mdot
.976 .49351 Mdot
.976 .49383 Mdot
.976 .4943 Mdot
.976 .49511 Mdot
.976 .4953 Mdot
.976 .49569 Mdot
.976 .49622 Mdot
.976 .49711 Mdot
.976 .49729 Mdot
.976 .49758 Mdot
.976 .49764 Mdot
.976 .4979 Mdot
.976 .49805 Mdot
.976 .49818 Mdot
.976 .49944 Mdot
.976 .50012 Mdot
.976 .50016 Mdot
.976 .50022 Mdot
.976 .50066 Mdot
.976 .50089 Mdot
.976 .50136 Mdot
.976 .50232 Mdot
.976 .50365 Mdot
.976 .50371 Mdot
.976 .5039 Mdot
.976 .50503 Mdot
.976 .50565 Mdot
.976 .50692 Mdot
.976 .50786 Mdot
.976 .50875 Mdot
.976 .50927 Mdot
.976 .51035 Mdot
.976 .51042 Mdot
.976 .51087 Mdot
.976 .51178 Mdot
.976 .51183 Mdot
.976 .51227 Mdot
.976 .51309 Mdot
.976 .51315 Mdot
.976 .51384 Mdot
.976 .51396 Mdot
.976 .51455 Mdot
.976 .51481 Mdot
.976 .51509 Mdot
.976 .51517 Mdot
.976 .51695 Mdot
.976 .51773 Mdot
.976 .51816 Mdot
.976 .51837 Mdot
.976 .51844 Mdot
.976 .51849 Mdot
.976 .51855 Mdot
.976 .51869 Mdot
.976 .52106 Mdot
.976 .52176 Mdot
.976 .52206 Mdot
.976 .5223 Mdot
.976 .52278 Mdot
.976 .52298 Mdot
.976 .52305 Mdot
.976 .52307 Mdot
.976 .52338 Mdot
.976 .52424 Mdot
.976 .52449 Mdot
.976 .52591 Mdot
.976 .52622 Mdot
.976 .52674 Mdot
.976 .52687 Mdot
.976 .52716 Mdot
.976 .52968 Mdot
.976 .52985 Mdot
.976 .53039 Mdot
.976 .53203 Mdot
.976 .53253 Mdot
.976 .53254 Mdot
.976 .53289 Mdot
.976 .53495 Mdot
.976 .53555 Mdot
.976 .53559 Mdot
.976 .53564 Mdot
.976 .53596 Mdot
.976 .5361 Mdot
.976 .53681 Mdot
.976 .53772 Mdot
.976 .53913 Mdot
.976 .53925 Mdot
.976 .54042 Mdot
.976 .54043 Mdot
.976 .54057 Mdot
.976 .54062 Mdot
.976 .5407 Mdot
.976 .54138 Mdot
.976 .54214 Mdot
.976 .54257 Mdot
.976 .54334 Mdot
.976 .54355 Mdot
.976 .54393 Mdot
.976 .54513 Mdot
.976 .54532 Mdot
.976 .54598 Mdot
.976 .54711 Mdot
.976 .54741 Mdot
.976 .54777 Mdot
.976 .55028 Mdot
.976 .55087 Mdot
.976 .55097 Mdot
.976 .55114 Mdot
.976 .55145 Mdot
.976 .5515 Mdot
.976 .55191 Mdot
.976 .55217 Mdot
.976 .55272 Mdot
.976 .55338 Mdot
.976 .55532 Mdot
.976 .55558 Mdot
.976 .55582 Mdot
.976 .55608 Mdot
.976 .55621 Mdot
.976 .55635 Mdot
.976 .55662 Mdot
.976 .55668 Mdot
.976 .55709 Mdot
.976 .55726 Mdot
.976 .55735 Mdot
.976 .55896 Mdot
.976 .55995 Mdot
.976 .55996 Mdot
.976 .56002 Mdot
.976 .5611 Mdot
.976 .56134 Mdot
.976 .56255 Mdot
.976 .56375 Mdot
.976 .56378 Mdot
.976 .56398 Mdot
.976 .56449 Mdot
.976 .56547 Mdot
.976 .5655 Mdot
.976 .56587 Mdot
.976 .56613 Mdot
.976 .56626 Mdot
.976 .56629 Mdot
.976 .5667 Mdot
.976 .56672 Mdot
.976 .56722 Mdot
.976 .56777 Mdot
.976 .56801 Mdot
.976 .56815 Mdot
.976 .56846 Mdot
.976 .56886 Mdot
.976 .5692 Mdot
.976 .57011 Mdot
.976 .57045 Mdot
.976 .57045 Mdot
.976 .57076 Mdot
.976 .57155 Mdot
.976 .5716 Mdot
.976 .57247 Mdot
.976 .57292 Mdot
.976 .5734 Mdot
.976 .57428 Mdot
.976 .57438 Mdot
.976 .57494 Mdot
.976 .57511 Mdot
.976 .57565 Mdot
.976 .57566 Mdot
.976 .57575 Mdot
.976 .57659 Mdot
.976 .57671 Mdot
.976 .57721 Mdot
.976 .57814 Mdot
.976 .57827 Mdot
.976 .5783 Mdot
.976 .57832 Mdot
.976 .57865 Mdot
.976 .57869 Mdot
.976 .57938 Mdot
.976 .57942 Mdot
.976 .5795 Mdot
.976 .57959 Mdot
.976 .57961 Mdot
.976 .57986 Mdot
.976 .58021 Mdot
.976 .58043 Mdot
.976 .58075 Mdot
.976 .58095 Mdot
.976 .58206 Mdot
.976 .58237 Mdot
.976 .58238 Mdot
.976 .58274 Mdot
.976 .5829 Mdot
.976 .583 Mdot
.976 .58346 Mdot
.976 .58371 Mdot
.976 .58381 Mdot
.976 .58395 Mdot
.976 .58423 Mdot
.976 .58427 Mdot
.976 .58445 Mdot
.976 .58483 Mdot
.976 .58525 Mdot
.976 .58544 Mdot
.976 .58592 Mdot
.976 .58594 Mdot
.976 .58604 Mdot
.976 .58621 Mdot
.976 .58684 Mdot
.976 .58688 Mdot
.976 .58711 Mdot
.976 .58718 Mdot
.976 .58726 Mdot
.976 .58794 Mdot
.976 .58828 Mdot
.976 .58897 Mdot
.976 .58934 Mdot
.976 .58952 Mdot
.976 .58969 Mdot
.976 .59007 Mdot
.976 .59012 Mdot
.976 .59014 Mdot
.976 .59033 Mdot
.976 .5904 Mdot
.976 .59055 Mdot
.976 .59056 Mdot
.976 .59066 Mdot
.976 .59082 Mdot
.976 .59118 Mdot
.976 .59199 Mdot
.976 .59208 Mdot
.976 .59215 Mdot
.976 .59219 Mdot
.976 .59227 Mdot
.976 .59239 Mdot
.976 .59249 Mdot
.976 .59291 Mdot
.976 .59302 Mdot
.976 .59339 Mdot
.976 .59347 Mdot
.976 .59373 Mdot
.976 .59373 Mdot
.976 .59426 Mdot
.976 .59441 Mdot
.976 .59443 Mdot
.976 .59453 Mdot
.976 .5946 Mdot
.976 .59476 Mdot
.976 .59491 Mdot
.976 .59535 Mdot
.976 .59563 Mdot
.976 .59568 Mdot
.976 .59571 Mdot
.976 .59591 Mdot
.976 .59612 Mdot
.976 .59637 Mdot
.976 .59655 Mdot
.976 .59658 Mdot
.976 .59666 Mdot
.976 .59672 Mdot
.976 .59674 Mdot
.976 .59706 Mdot
.976 .59726 Mdot
.976 .59728 Mdot
.976 .59732 Mdot
.976 .59768 Mdot
.976 .59772 Mdot
.976 .59775 Mdot
.976 .59779 Mdot
.976 .59797 Mdot
.976 .5982 Mdot
.976 .59822 Mdot
.976 .59827 Mdot
.976 .59829 Mdot
.976 .59833 Mdot
.976 .59841 Mdot
.976 .59846 Mdot
.976 .59851 Mdot
.976 .59869 Mdot
.976 .59872 Mdot
.976 .59878 Mdot
.976 .59887 Mdot
.976 .59905 Mdot
.976 .59906 Mdot
.976 .59927 Mdot
.976 .5993 Mdot
.976 .59933 Mdot
.976 .59941 Mdot
.976 .59942 Mdot
.976 .59944 Mdot
.976 .59951 Mdot
.976 .59953 Mdot
.976 .59959 Mdot
.976 .59967 Mdot
.976 .59971 Mdot
.976 .59978 Mdot
.976 .59984 Mdot
.976 .59986 Mdot
.976 .59998 Mdot
.976 .60003 Mdot
.976 .60009 Mdot
.976 .60012 Mdot
.976 .60014 Mdot
.976 .60016 Mdot
.976 .60026 Mdot
.976 .60027 Mdot
.976 .60027 Mdot
.976 .60029 Mdot
.976 .60031 Mdot
.976 .60032 Mdot
.976 .60032 Mdot
.976 .60033 Mdot
.976 .60035 Mdot
.976 .60037 Mdot
.976 .60037 Mdot
.976 .60037 Mdot
.976 .60038 Mdot
.976 .60043 Mdot
.976 .60043 Mdot
.976 .60045 Mdot
.976 .60049 Mdot
.976 .60049 Mdot
.978 .02499 Mdot
.978 .02501 Mdot
.978 .02504 Mdot
.978 .0251 Mdot
.978 .02512 Mdot
.978 .02516 Mdot
.978 .02526 Mdot
.978 .02532 Mdot
.978 .02537 Mdot
.978 .02548 Mdot
.978 .02551 Mdot
.978 .02552 Mdot
.978 .0256 Mdot
.978 .02562 Mdot
.978 .0257 Mdot
.978 .02571 Mdot
.978 .02579 Mdot
.978 .02584 Mdot
.978 .02602 Mdot
.978 .02604 Mdot
.978 .02662 Mdot
.978 .02673 Mdot
.978 .02678 Mdot
.978 .02679 Mdot
.978 .02681 Mdot
.978 .02687 Mdot
.978 .02688 Mdot
.978 .02706 Mdot
.978 .02727 Mdot
.978 .02759 Mdot
.978 .02765 Mdot
.978 .02766 Mdot
.978 .0278 Mdot
.978 .02798 Mdot
.978 .02803 Mdot
.978 .02815 Mdot
.978 .02819 Mdot
.978 .02855 Mdot
.978 .02887 Mdot
.978 .02889 Mdot
.978 .02905 Mdot
.978 .02948 Mdot
.978 .02956 Mdot
.978 .02961 Mdot
.978 .02964 Mdot
.978 .02998 Mdot
.978 .03059 Mdot
.978 .03067 Mdot
.978 .0308 Mdot
.978 .03084 Mdot
.978 .03099 Mdot
.978 .03109 Mdot
.978 .0322 Mdot
.978 .0324 Mdot
.978 .03282 Mdot
.978 .03309 Mdot
.978 .03442 Mdot
.978 .03455 Mdot
.978 .03527 Mdot
.978 .03537 Mdot
.978 .0359 Mdot
.978 .03596 Mdot
.978 .03609 Mdot
.978 .0365 Mdot
.978 .03656 Mdot
.978 .03778 Mdot
.978 .03869 Mdot
.978 .03878 Mdot
.978 .0392 Mdot
.978 .03996 Mdot
.978 .04147 Mdot
.978 .04254 Mdot
.978 .04323 Mdot
.978 .04384 Mdot
.978 .04601 Mdot
.978 .04637 Mdot
.978 .0468 Mdot
.978 .04746 Mdot
.978 .04842 Mdot
.978 .04901 Mdot
.978 .04931 Mdot
.978 .04959 Mdot
.978 .04997 Mdot
.978 .05044 Mdot
.978 .05065 Mdot
.978 .05088 Mdot
.978 .05108 Mdot
.978 .05126 Mdot
.978 .05292 Mdot
.978 .05341 Mdot
.978 .05351 Mdot
.978 .05492 Mdot
.978 .05502 Mdot
.978 .05509 Mdot
.978 .05511 Mdot
.978 .05534 Mdot
.978 .05542 Mdot
.978 .05557 Mdot
.978 .05597 Mdot
.978 .05621 Mdot
.978 .0564 Mdot
.978 .05671 Mdot
.978 .05681 Mdot
.978 .05692 Mdot
.978 .05697 Mdot
.978 .05726 Mdot
.978 .05733 Mdot
.978 .05764 Mdot
.978 .05768 Mdot
.978 .058 Mdot
.978 .0582 Mdot
.978 .05886 Mdot
.978 .05895 Mdot
.978 .05976 Mdot
.978 .06056 Mdot
.978 .06116 Mdot
.978 .06124 Mdot
.978 .06159 Mdot
.978 .06179 Mdot
.978 .06181 Mdot
.978 .0619 Mdot
.978 .06212 Mdot
.978 .06215 Mdot
.978 .06287 Mdot
.978 .06308 Mdot
.978 .06343 Mdot
.978 .06366 Mdot
.978 .06424 Mdot
.978 .06459 Mdot
.978 .06482 Mdot
.978 .06487 Mdot
.978 .06501 Mdot
.978 .06509 Mdot
.978 .06513 Mdot
.978 .06531 Mdot
.978 .06567 Mdot
.978 .06569 Mdot
.978 .06637 Mdot
.978 .06654 Mdot
.978 .06701 Mdot
.978 .06715 Mdot
.978 .06852 Mdot
.978 .06853 Mdot
.978 .06883 Mdot
.978 .06975 Mdot
.978 .06981 Mdot
.978 .0704 Mdot
.978 .07177 Mdot
.978 .07204 Mdot
.978 .07207 Mdot
.978 .0723 Mdot
.978 .07233 Mdot
.978 .07245 Mdot
.978 .07252 Mdot
.978 .07263 Mdot
.978 .07393 Mdot
.978 .07493 Mdot
.978 .07558 Mdot
.978 .07622 Mdot
.978 .07656 Mdot
.978 .07665 Mdot
.978 .07703 Mdot
.978 .07718 Mdot
.978 .0772 Mdot
.978 .07774 Mdot
.978 .07811 Mdot
.978 .07978 Mdot
.978 .0801 Mdot
.978 .0805 Mdot
.978 .08219 Mdot
.978 .08227 Mdot
.978 .08234 Mdot
.978 .08304 Mdot
.978 .08461 Mdot
.978 .08531 Mdot
.978 .0856 Mdot
.978 .08729 Mdot
.978 .08855 Mdot
.978 .08881 Mdot
.978 .0901 Mdot
.978 .09051 Mdot
.978 .09056 Mdot
.978 .09103 Mdot
.978 .09157 Mdot
.978 .0937 Mdot
.978 .09407 Mdot
.978 .09473 Mdot
.978 .09605 Mdot
.978 .09627 Mdot
.978 .09674 Mdot
.978 .09784 Mdot
.978 .09825 Mdot
.978 .09846 Mdot
.978 .09847 Mdot
.978 .09942 Mdot
.978 .09953 Mdot
.978 .09967 Mdot
.978 .10064 Mdot
.978 .10218 Mdot
.978 .10296 Mdot
.978 .10362 Mdot
.978 .10418 Mdot
.978 .10439 Mdot
.978 .10529 Mdot
.978 .10553 Mdot
.978 .10609 Mdot
.978 .10631 Mdot
.978 .10664 Mdot
.978 .10672 Mdot
.978 .10679 Mdot
.978 .10819 Mdot
.978 .10853 Mdot
.978 .11093 Mdot
.978 .11175 Mdot
.978 .11643 Mdot
.978 .11839 Mdot
.978 .12028 Mdot
.978 .12132 Mdot
.978 .12147 Mdot
.978 .12186 Mdot
.978 .12207 Mdot
.978 .12277 Mdot
.978 .12322 Mdot
.978 .12454 Mdot
.978 .12495 Mdot
.978 .12556 Mdot
.978 .1286 Mdot
.978 .12916 Mdot
.978 .13081 Mdot
.978 .13252 Mdot
.978 .13273 Mdot
.978 .13321 Mdot
.978 .13401 Mdot
.978 .13457 Mdot
.978 .13554 Mdot
.978 .13719 Mdot
.978 .1376 Mdot
.978 .13787 Mdot
.978 .13882 Mdot
.978 .13884 Mdot
.978 .14125 Mdot
.978 .14333 Mdot
.978 .14439 Mdot
.978 .14467 Mdot
.978 .14525 Mdot
.978 .14539 Mdot
.978 .1467 Mdot
.978 .14824 Mdot
.978 .14835 Mdot
.978 .14906 Mdot
.978 .14908 Mdot
.978 .1499 Mdot
.978 .1506 Mdot
.978 .15121 Mdot
.978 .15341 Mdot
.978 .1547 Mdot
.978 .15491 Mdot
.978 .15644 Mdot
.978 .157 Mdot
.978 .15802 Mdot
.978 .15868 Mdot
.978 .15904 Mdot
.978 .15908 Mdot
.978 .16057 Mdot
.978 .16159 Mdot
.978 .16217 Mdot
.978 .16266 Mdot
.978 .1639 Mdot
.978 .16424 Mdot
.978 .16447 Mdot
.978 .16454 Mdot
.978 .16527 Mdot
.978 .16532 Mdot
.978 .1656 Mdot
.978 .16614 Mdot
.978 .1675 Mdot
.978 .16832 Mdot
.978 .16892 Mdot
.978 .16898 Mdot
.978 .17004 Mdot
.978 .17036 Mdot
.978 .17074 Mdot
.978 .17093 Mdot
.978 .17095 Mdot
.978 .1719 Mdot
.978 .17191 Mdot
.978 .17215 Mdot
.978 .17233 Mdot
.978 .1732 Mdot
.978 .17333 Mdot
.978 .17442 Mdot
.978 .17511 Mdot
.978 .17733 Mdot
.978 .17763 Mdot
.978 .17969 Mdot
.978 .18036 Mdot
.978 .18307 Mdot
.978 .18451 Mdot
.978 .18508 Mdot
.978 .18536 Mdot
.978 .18653 Mdot
.978 .18671 Mdot
.978 .18721 Mdot
.978 .18728 Mdot
.978 .18756 Mdot
.978 .1883 Mdot
.978 .18834 Mdot
.978 .1884 Mdot
.978 .18856 Mdot
.978 .19016 Mdot
.978 .1908 Mdot
.978 .19128 Mdot
.978 .1915 Mdot
.978 .19265 Mdot
.978 .19278 Mdot
.978 .19344 Mdot
.978 .19512 Mdot
.978 .19536 Mdot
.978 .1956 Mdot
.978 .19653 Mdot
.978 .19728 Mdot
.978 .19742 Mdot
.978 .19789 Mdot
.978 .19815 Mdot
.978 .19831 Mdot
.978 .19889 Mdot
.978 .19991 Mdot
.978 .20007 Mdot
.978 .20014 Mdot
.978 .20062 Mdot
.978 .20236 Mdot
.978 .20294 Mdot
.978 .20448 Mdot
.978 .20486 Mdot
.978 .20493 Mdot
.978 .20536 Mdot
.978 .20686 Mdot
.978 .20824 Mdot
.978 .20908 Mdot
.978 .2094 Mdot
.978 .20942 Mdot
.978 .21043 Mdot
.978 .21054 Mdot
.978 .21095 Mdot
.978 .21208 Mdot
.978 .21339 Mdot
.978 .2136 Mdot
.978 .21363 Mdot
.978 .21372 Mdot
.978 .21417 Mdot
.978 .21551 Mdot
.978 .21745 Mdot
.978 .21992 Mdot
.978 .22077 Mdot
.978 .22089 Mdot
.978 .22161 Mdot
.978 .22172 Mdot
.978 .2221 Mdot
.978 .22232 Mdot
.978 .22268 Mdot
.978 .22682 Mdot
.978 .22712 Mdot
.978 .22866 Mdot
.978 .22999 Mdot
.978 .23205 Mdot
.978 .23244 Mdot
.978 .23406 Mdot
.978 .23481 Mdot
.978 .23495 Mdot
.978 .23512 Mdot
.978 .23541 Mdot
.978 .23662 Mdot
.978 .23707 Mdot
.978 .23714 Mdot
.978 .23882 Mdot
.978 .23998 Mdot
.978 .24015 Mdot
.978 .24195 Mdot
.978 .24196 Mdot
.978 .24234 Mdot
.978 .24247 Mdot
.978 .24329 Mdot
.978 .24372 Mdot
.978 .24394 Mdot
.978 .2452 Mdot
.978 .2462 Mdot
.978 .24697 Mdot
.978 .24742 Mdot
.978 .2476 Mdot
.978 .24858 Mdot
.978 .25262 Mdot
.978 .25287 Mdot
.978 .25307 Mdot
.978 .25316 Mdot
.978 .25356 Mdot
.978 .25486 Mdot
.978 .25522 Mdot
.978 .25532 Mdot
.978 .25942 Mdot
.978 .25952 Mdot
.978 .26003 Mdot
.978 .26084 Mdot
.978 .26213 Mdot
.978 .26302 Mdot
.978 .26428 Mdot
.978 .26641 Mdot
.978 .26658 Mdot
.978 .26672 Mdot
.978 .2681 Mdot
.978 .26996 Mdot
.978 .27034 Mdot
.978 .27187 Mdot
.978 .27223 Mdot
.978 .27265 Mdot
.978 .2743 Mdot
.978 .27522 Mdot
.978 .27619 Mdot
.978 .27647 Mdot
.978 .2777 Mdot
.978 .27784 Mdot
.978 .27797 Mdot
.978 .27826 Mdot
.978 .27924 Mdot
.978 .27986 Mdot
.978 .28082 Mdot
.978 .28587 Mdot
.978 .28629 Mdot
.978 .28707 Mdot
.978 .28815 Mdot
.978 .28869 Mdot
.978 .28935 Mdot
.978 .29005 Mdot
.978 .29255 Mdot
.978 .29388 Mdot
.978 .29451 Mdot
.978 .2958 Mdot
.978 .29584 Mdot
.978 .29603 Mdot
.978 .29667 Mdot
.978 .29693 Mdot
.978 .29805 Mdot
.978 .29833 Mdot
.978 .29841 Mdot
.978 .299 Mdot
.978 .29902 Mdot
.978 .30018 Mdot
.978 .30079 Mdot
.978 .3008 Mdot
.978 .30279 Mdot
.978 .30333 Mdot
.978 .30351 Mdot
.978 .3038 Mdot
.978 .30384 Mdot
.978 .30421 Mdot
.978 .30518 Mdot
.978 .30543 Mdot
.978 .30578 Mdot
.978 .30644 Mdot
.978 .30694 Mdot
.978 .30757 Mdot
.978 .30953 Mdot
.978 .31013 Mdot
.978 .31128 Mdot
.978 .31334 Mdot
.978 .31346 Mdot
.978 .31352 Mdot
.978 .31389 Mdot
.978 .31531 Mdot
.978 .31684 Mdot
.978 .31711 Mdot
.978 .31729 Mdot
.978 .31742 Mdot
.978 .31744 Mdot
.978 .31828 Mdot
.978 .3193 Mdot
.978 .31992 Mdot
.978 .32058 Mdot
.978 .32112 Mdot
.978 .32212 Mdot
.978 .32271 Mdot
.978 .32363 Mdot
.978 .3238 Mdot
.978 .32385 Mdot
.978 .32403 Mdot
.978 .32571 Mdot
.978 .32618 Mdot
.978 .32647 Mdot
.978 .32785 Mdot
.978 .32878 Mdot
.978 .32928 Mdot
.978 .32946 Mdot
.978 .32983 Mdot
.978 .33182 Mdot
.978 .33277 Mdot
.978 .33395 Mdot
.978 .33475 Mdot
.978 .33526 Mdot
.978 .3357 Mdot
.978 .33745 Mdot
.978 .33774 Mdot
.978 .33917 Mdot
.978 .33936 Mdot
.978 .33954 Mdot
.978 .34046 Mdot
.978 .34057 Mdot
.978 .34191 Mdot
.978 .34711 Mdot
.978 .34728 Mdot
.978 .34787 Mdot
.978 .34798 Mdot
.978 .34823 Mdot
.978 .3484 Mdot
.978 .34979 Mdot
.978 .35156 Mdot
.978 .35275 Mdot
.978 .35304 Mdot
.978 .35351 Mdot
.978 .35488 Mdot
.978 .35518 Mdot
.978 .35596 Mdot
.978 .35913 Mdot
.978 .35929 Mdot
.978 .35971 Mdot
.978 .36094 Mdot
.978 .36212 Mdot
.978 .36236 Mdot
.978 .36276 Mdot
.978 .36374 Mdot
.978 .36427 Mdot
.978 .36455 Mdot
.978 .36539 Mdot
.978 .36603 Mdot
.978 .36717 Mdot
.978 .37049 Mdot
.978 .37068 Mdot
.978 .3715 Mdot
.978 .37301 Mdot
.978 .37354 Mdot
.978 .37897 Mdot
.978 .38051 Mdot
.978 .38187 Mdot
.978 .38218 Mdot
.978 .38502 Mdot
.978 .38587 Mdot
.978 .38997 Mdot
.978 .39042 Mdot
.978 .39048 Mdot
.978 .39162 Mdot
.978 .39225 Mdot
.978 .39237 Mdot
.978 .39352 Mdot
.978 .39371 Mdot
.978 .39483 Mdot
.978 .39496 Mdot
.978 .39672 Mdot
.978 .39712 Mdot
.978 .40097 Mdot
.978 .40192 Mdot
.978 .40256 Mdot
.978 .40431 Mdot
.978 .40475 Mdot
.978 .4048 Mdot
.978 .40555 Mdot
.978 .40571 Mdot
.978 .40718 Mdot
.978 .41031 Mdot
.978 .41035 Mdot
.978 .41039 Mdot
.978 .41126 Mdot
.978 .41172 Mdot
.978 .41222 Mdot
.978 .41244 Mdot
.978 .41499 Mdot
.978 .41582 Mdot
.978 .41659 Mdot
.978 .41736 Mdot
.978 .41757 Mdot
.978 .41763 Mdot
.978 .41798 Mdot
.978 .41902 Mdot
.978 .41926 Mdot
.978 .41958 Mdot
.978 .41964 Mdot
.978 .42155 Mdot
.978 .42164 Mdot
.978 .42239 Mdot
.978 .42247 Mdot
.978 .42334 Mdot
.978 .42397 Mdot
.978 .42441 Mdot
.978 .42452 Mdot
.978 .42529 Mdot
.978 .42585 Mdot
.978 .42607 Mdot
.978 .42635 Mdot
.978 .42757 Mdot
.978 .42761 Mdot
.978 .42766 Mdot
.978 .4279 Mdot
.978 .42821 Mdot
.978 .42943 Mdot
.978 .42961 Mdot
.978 .43093 Mdot
.978 .43225 Mdot
.978 .43229 Mdot
.978 .43372 Mdot
.978 .43563 Mdot
.978 .43691 Mdot
.978 .43962 Mdot
.978 .44005 Mdot
.978 .44008 Mdot
.978 .44112 Mdot
.978 .44323 Mdot
.978 .44326 Mdot
.978 .44438 Mdot
.978 .44439 Mdot
.978 .4446 Mdot
.978 .44488 Mdot
.978 .44647 Mdot
.978 .44662 Mdot
.978 .44752 Mdot
.978 .44778 Mdot
.978 .44781 Mdot
.978 .44825 Mdot
.978 .44855 Mdot
.978 .44863 Mdot
.978 .44871 Mdot
.978 .45006 Mdot
.978 .45164 Mdot
.978 .45283 Mdot
.978 .45327 Mdot
.978 .45368 Mdot
.978 .45484 Mdot
.978 .45495 Mdot
.978 .45581 Mdot
.978 .45665 Mdot
.978 .45686 Mdot
.978 .45824 Mdot
.978 .45891 Mdot
.978 .45914 Mdot
.978 .45937 Mdot
.978 .4595 Mdot
.978 .45994 Mdot
.978 .46079 Mdot
.978 .46093 Mdot
.978 .46103 Mdot
.978 .46157 Mdot
.978 .46261 Mdot
.978 .46311 Mdot
.978 .46523 Mdot
.978 .46613 Mdot
.978 .4668 Mdot
.978 .46805 Mdot
.978 .4687 Mdot
.978 .46884 Mdot
.978 .469 Mdot
.978 .46956 Mdot
.978 .47004 Mdot
.978 .4704 Mdot
.978 .47045 Mdot
.978 .47065 Mdot
.978 .47094 Mdot
.978 .47137 Mdot
.978 .47171 Mdot
.978 .47175 Mdot
.978 .47262 Mdot
.978 .4729 Mdot
.978 .47352 Mdot
.978 .47355 Mdot
.978 .47399 Mdot
.978 .47433 Mdot
.978 .47584 Mdot
.978 .47594 Mdot
.978 .47616 Mdot
.978 .47636 Mdot
.978 .47675 Mdot
.978 .47676 Mdot
.978 .47815 Mdot
.978 .47879 Mdot
.978 .47886 Mdot
.978 .4794 Mdot
.978 .48266 Mdot
.978 .48341 Mdot
.978 .48394 Mdot
.978 .4845 Mdot
.978 .48456 Mdot
.978 .48533 Mdot
.978 .48757 Mdot
.978 .48874 Mdot
.978 .49006 Mdot
.978 .49226 Mdot
.978 .49341 Mdot
.978 .49552 Mdot
.978 .49585 Mdot
.978 .49681 Mdot
.978 .49728 Mdot
.978 .49792 Mdot
.978 .49798 Mdot
.978 .49922 Mdot
.978 .49952 Mdot
.978 .50017 Mdot
.978 .50035 Mdot
.978 .50046 Mdot
.978 .50092 Mdot
.978 .50213 Mdot
.978 .5022 Mdot
.978 .50229 Mdot
.978 .50234 Mdot
.978 .50256 Mdot
.978 .50263 Mdot
.978 .5046 Mdot
.978 .50511 Mdot
.978 .50515 Mdot
.978 .5055 Mdot
.978 .50556 Mdot
.978 .50564 Mdot
.978 .50617 Mdot
.978 .50694 Mdot
.978 .50729 Mdot
.978 .50759 Mdot
.978 .50802 Mdot
.978 .50838 Mdot
.978 .50911 Mdot
.978 .50925 Mdot
.978 .50932 Mdot
.978 .51035 Mdot
.978 .51046 Mdot
.978 .51063 Mdot
.978 .51133 Mdot
.978 .5123 Mdot
.978 .51297 Mdot
.978 .51333 Mdot
.978 .51364 Mdot
.978 .51369 Mdot
.978 .51376 Mdot
.978 .51492 Mdot
.978 .51505 Mdot
.978 .51512 Mdot
.978 .51626 Mdot
.978 .51648 Mdot
.978 .51717 Mdot
.978 .51757 Mdot
.978 .51781 Mdot
.978 .51793 Mdot
.978 .51802 Mdot
.978 .51849 Mdot
.978 .51867 Mdot
.978 .51886 Mdot
.978 .52019 Mdot
.978 .5204 Mdot
.978 .52043 Mdot
.978 .52053 Mdot
.978 .52092 Mdot
.978 .52101 Mdot
.978 .52123 Mdot
.978 .52131 Mdot
.978 .52244 Mdot
.978 .52355 Mdot
.978 .52377 Mdot
.978 .5246 Mdot
.978 .52474 Mdot
.978 .52679 Mdot
.978 .52733 Mdot
.978 .52743 Mdot
.978 .52803 Mdot
.978 .52836 Mdot
.978 .52867 Mdot
.978 .52936 Mdot
.978 .53 Mdot
.978 .53012 Mdot
.978 .5312 Mdot
.978 .53125 Mdot
.978 .53131 Mdot
.978 .53201 Mdot
.978 .53315 Mdot
.978 .53359 Mdot
.978 .53362 Mdot
.978 .53496 Mdot
.978 .53511 Mdot
.978 .53554 Mdot
.978 .53567 Mdot
.978 .53716 Mdot
.978 .53747 Mdot
.978 .53768 Mdot
.978 .53865 Mdot
.978 .53873 Mdot
.978 .53886 Mdot
.978 .53913 Mdot
.978 .53917 Mdot
.978 .53929 Mdot
.978 .5393 Mdot
.978 .53987 Mdot
.978 .54153 Mdot
.978 .54158 Mdot
.978 .54233 Mdot
.978 .54352 Mdot
.978 .544 Mdot
.978 .54703 Mdot
.978 .54804 Mdot
.978 .54818 Mdot
.978 .54821 Mdot
.978 .54869 Mdot
.978 .54904 Mdot
.978 .54916 Mdot
.978 .54961 Mdot
.978 .54987 Mdot
.978 .55029 Mdot
.978 .55075 Mdot
.978 .5509 Mdot
.978 .5522 Mdot
.978 .55241 Mdot
.978 .55372 Mdot
.978 .55386 Mdot
.978 .55457 Mdot
.978 .55502 Mdot
.978 .55536 Mdot
.978 .55583 Mdot
.978 .5559 Mdot
.978 .55639 Mdot
.978 .55704 Mdot
.978 .55848 Mdot
.978 .56065 Mdot
.978 .56077 Mdot
.978 .56105 Mdot
.978 .56165 Mdot
.978 .56271 Mdot
.978 .56347 Mdot
.978 .56361 Mdot
.978 .56378 Mdot
.978 .56408 Mdot
.978 .56451 Mdot
.978 .56482 Mdot
.978 .56527 Mdot
.978 .56571 Mdot
.978 .56577 Mdot
.978 .56614 Mdot
.978 .56739 Mdot
.978 .56762 Mdot
.978 .56848 Mdot
.978 .56864 Mdot
.978 .5703 Mdot
.978 .5703 Mdot
.978 .57065 Mdot
.978 .57076 Mdot
.978 .5715 Mdot
.978 .57189 Mdot
.978 .57208 Mdot
.978 .57256 Mdot
.978 .57302 Mdot
.978 .57318 Mdot
.978 .57403 Mdot
.978 .57431 Mdot
.978 .57468 Mdot
.978 .575 Mdot
.978 .57506 Mdot
.978 .57517 Mdot
.978 .57521 Mdot
.978 .57602 Mdot
.978 .57785 Mdot
.978 .57873 Mdot
.978 .57921 Mdot
.978 .57923 Mdot
.978 .5794 Mdot
.978 .57956 Mdot
.978 .57962 Mdot
.978 .57987 Mdot
.978 .57992 Mdot
.978 .58008 Mdot
.978 .58047 Mdot
.978 .58089 Mdot
.978 .58115 Mdot
.978 .58119 Mdot
.978 .58122 Mdot
.978 .58148 Mdot
.978 .58165 Mdot
.978 .58249 Mdot
.978 .58334 Mdot
.978 .58363 Mdot
.978 .58374 Mdot
.978 .58408 Mdot
.978 .58415 Mdot
.978 .58449 Mdot
.978 .58502 Mdot
.978 .58582 Mdot
.978 .58586 Mdot
.978 .58631 Mdot
.978 .58641 Mdot
.978 .5865 Mdot
.978 .58719 Mdot
.978 .58733 Mdot
.978 .58762 Mdot
.978 .58779 Mdot
.978 .58844 Mdot
.978 .58849 Mdot
.978 .58854 Mdot
.978 .58862 Mdot
.978 .5894 Mdot
.978 .58948 Mdot
.978 .59023 Mdot
.978 .59033 Mdot
.978 .59041 Mdot
.978 .59046 Mdot
.978 .59052 Mdot
.978 .59061 Mdot
.978 .59082 Mdot
.978 .59091 Mdot
.978 .59139 Mdot
.978 .59157 Mdot
.978 .59178 Mdot
.978 .59258 Mdot
.978 .593 Mdot
.978 .59341 Mdot
.978 .59344 Mdot
.978 .59356 Mdot
.978 .594 Mdot
.978 .59404 Mdot
.978 .59409 Mdot
.978 .59415 Mdot
.978 .59421 Mdot
.978 .59433 Mdot
.978 .59443 Mdot
.978 .5945 Mdot
.978 .59458 Mdot
.978 .59473 Mdot
.978 .59498 Mdot
.978 .59515 Mdot
.978 .59526 Mdot
.978 .59535 Mdot
.978 .59591 Mdot
.978 .59607 Mdot
.978 .59625 Mdot
.978 .59652 Mdot
.978 .59691 Mdot
.978 .5971 Mdot
.978 .59721 Mdot
.978 .59724 Mdot
.978 .59747 Mdot
.978 .59778 Mdot
.978 .5978 Mdot
.978 .5979 Mdot
.978 .59793 Mdot
.978 .59795 Mdot
.978 .59809 Mdot
.978 .59811 Mdot
.978 .5983 Mdot
.978 .59833 Mdot
.978 .59867 Mdot
.978 .59874 Mdot
.978 .59884 Mdot
.978 .5989 Mdot
.978 .59918 Mdot
.978 .5992 Mdot
.978 .59924 Mdot
.978 .59925 Mdot
.978 .59928 Mdot
.978 .59931 Mdot
.978 .59946 Mdot
.978 .59955 Mdot
.978 .59956 Mdot
.978 .59957 Mdot
.978 .59959 Mdot
.978 .5997 Mdot
.978 .59974 Mdot
.978 .59974 Mdot
.978 .59982 Mdot
.978 .59992 Mdot
.978 .59993 Mdot
.978 .59996 Mdot
.978 .59997 Mdot
.978 .60001 Mdot
.978 .60005 Mdot
.978 .60005 Mdot
.978 .60015 Mdot
.978 .6002 Mdot
.978 .60025 Mdot
.978 .60025 Mdot
.978 .60027 Mdot
.978 .60027 Mdot
.978 .60027 Mdot
.978 .60029 Mdot
.978 .60032 Mdot
.978 .60046 Mdot
.978 .60047 Mdot
.978 .60051 Mdot
.978 .60052 Mdot
.978 .60055 Mdot
.978 .60055 Mdot
.978 .60057 Mdot
.978 .60057 Mdot
.978 .60059 Mdot
.978 .6006 Mdot
.978 .6006 Mdot
.978 .60063 Mdot
.978 .60064 Mdot
.978 .60066 Mdot
.978 .60068 Mdot
.978 .60069 Mdot
.978 .6007 Mdot
.978 .60072 Mdot
.978 .60072 Mdot
.978 .60073 Mdot
.98 .02406 Mdot
.98 .02406 Mdot
.98 .02407 Mdot
.98 .02408 Mdot
.98 .0242 Mdot
.98 .0242 Mdot
.98 .02422 Mdot
.98 .02427 Mdot
.98 .02429 Mdot
.98 .0244 Mdot
.98 .02451 Mdot
.98 .0246 Mdot
.98 .02463 Mdot
.98 .0247 Mdot
.98 .02495 Mdot
.98 .02524 Mdot
.98 .02543 Mdot
.98 .02568 Mdot
.98 .0257 Mdot
.98 .02572 Mdot
.98 .02619 Mdot
.98 .02622 Mdot
.98 .02632 Mdot
.98 .02648 Mdot
.98 .0267 Mdot
.98 .02676 Mdot
.98 .02753 Mdot
.98 .02762 Mdot
.98 .02763 Mdot
.98 .02772 Mdot
.98 .02925 Mdot
.98 .02972 Mdot
.98 .02982 Mdot
.98 .03075 Mdot
.98 .03076 Mdot
.98 .03078 Mdot
.98 .03169 Mdot
.98 .0328 Mdot
.98 .03291 Mdot
.98 .03298 Mdot
.98 .03298 Mdot
.98 .03322 Mdot
.98 .03434 Mdot
.98 .03448 Mdot
.98 .03486 Mdot
.98 .03545 Mdot
.98 .03593 Mdot
.98 .03647 Mdot
.98 .03657 Mdot
.98 .03685 Mdot
.98 .03728 Mdot
.98 .03797 Mdot
.98 .03984 Mdot
.98 .04031 Mdot
.98 .0405 Mdot
.98 .04088 Mdot
.98 .04112 Mdot
.98 .04217 Mdot
.98 .04268 Mdot
.98 .04325 Mdot
.98 .0442 Mdot
.98 .04437 Mdot
.98 .04625 Mdot
.98 .04682 Mdot
.98 .04722 Mdot
.98 .04771 Mdot
.98 .04827 Mdot
.98 .04951 Mdot
.98 .05037 Mdot
.98 .05046 Mdot
.98 .05053 Mdot
.98 .05069 Mdot
.98 .05076 Mdot
.98 .05085 Mdot
.98 .05136 Mdot
.98 .05137 Mdot
.98 .05142 Mdot
.98 .05142 Mdot
.98 .05188 Mdot
.98 .05191 Mdot
.98 .05198 Mdot
.98 .05216 Mdot
.98 .05223 Mdot
.98 .05264 Mdot
.98 .05266 Mdot
.98 .05309 Mdot
.98 .05344 Mdot
.98 .05354 Mdot
.98 .05382 Mdot
.98 .05399 Mdot
.98 .05408 Mdot
.98 .0543 Mdot
.98 .05473 Mdot
.98 .0548 Mdot
.98 .05547 Mdot
.98 .0559 Mdot
.98 .05641 Mdot
.98 .05663 Mdot
.98 .057 Mdot
.98 .05758 Mdot
.98 .05768 Mdot
.98 .05775 Mdot
.98 .05785 Mdot
.98 .05801 Mdot
.98 .05896 Mdot
.98 .05949 Mdot
.98 .05954 Mdot
.98 .05966 Mdot
.98 .06 Mdot
.98 .06003 Mdot
.98 .06065 Mdot
.98 .06129 Mdot
.98 .06149 Mdot
.98 .0615 Mdot
.98 .06171 Mdot
.98 .06172 Mdot
.98 .0631 Mdot
.98 .06453 Mdot
.98 .06465 Mdot
.98 .06501 Mdot
.98 .06506 Mdot
.98 .06541 Mdot
.98 .06585 Mdot
.98 .06615 Mdot
.98 .06816 Mdot
.98 .06826 Mdot
.98 .06827 Mdot
.98 .07119 Mdot
.98 .07162 Mdot
.98 .07297 Mdot
.98 .07304 Mdot
.98 .07335 Mdot
.98 .07391 Mdot
.98 .07543 Mdot
.98 .07564 Mdot
.98 .07604 Mdot
.98 .07642 Mdot
.98 .07686 Mdot
.98 .0769 Mdot
.98 .07696 Mdot
.98 .07812 Mdot
.98 .08041 Mdot
.98 .08137 Mdot
.98 .08137 Mdot
.98 .08157 Mdot
.98 .08178 Mdot
.98 .08179 Mdot
.98 .08288 Mdot
.98 .0832 Mdot
.98 .08355 Mdot
.98 .08455 Mdot
.98 .08497 Mdot
.98 .08522 Mdot
.98 .08525 Mdot
.98 .08612 Mdot
.98 .08669 Mdot
.98 .08781 Mdot
.98 .0903 Mdot
.98 .09058 Mdot
.98 .09084 Mdot
.98 .09106 Mdot
.98 .09224 Mdot
.98 .09441 Mdot
.98 .09445 Mdot
.98 .09494 Mdot
.98 .09621 Mdot
.98 .09726 Mdot
.98 .09732 Mdot
.98 .09818 Mdot
.98 .09856 Mdot
.98 .09959 Mdot
.98 .09987 Mdot
.98 .10006 Mdot
.98 .10045 Mdot
.98 .1005 Mdot
.98 .10118 Mdot
.98 .10371 Mdot
.98 .1039 Mdot
.98 .10494 Mdot
.98 .10549 Mdot
.98 .10862 Mdot
.98 .10882 Mdot
.98 .10899 Mdot
.98 .10916 Mdot
.98 .10919 Mdot
.98 .10928 Mdot
.98 .11055 Mdot
.98 .11113 Mdot
.98 .11138 Mdot
.98 .11225 Mdot
.98 .11287 Mdot
.98 .11289 Mdot
.98 .11296 Mdot
.98 .1137 Mdot
.98 .11431 Mdot
.98 .11521 Mdot
.98 .11552 Mdot
.98 .11898 Mdot
.98 .12086 Mdot
.98 .1212 Mdot
.98 .12167 Mdot
.98 .12289 Mdot
.98 .12575 Mdot
.98 .12631 Mdot
.98 .12692 Mdot
.98 .12757 Mdot
.98 .13016 Mdot
.98 .13035 Mdot
.98 .13283 Mdot
.98 .13362 Mdot
.98 .13471 Mdot
.98 .13565 Mdot
.98 .13614 Mdot
.98 .13707 Mdot
.98 .1388 Mdot
.98 .13956 Mdot
.98 .14078 Mdot
.98 .1424 Mdot
.98 .14313 Mdot
.98 .14409 Mdot
.98 .14476 Mdot
.98 .14481 Mdot
.98 .14516 Mdot
.98 .14816 Mdot
.98 .14847 Mdot
.98 .14861 Mdot
.98 .14874 Mdot
.98 .1493 Mdot
.98 .14953 Mdot
.98 .14974 Mdot
.98 .14984 Mdot
.98 .15043 Mdot
.98 .15163 Mdot
.98 .15164 Mdot
.98 .15178 Mdot
.98 .15182 Mdot
.98 .15184 Mdot
.98 .15199 Mdot
.98 .15319 Mdot
.98 .15344 Mdot
.98 .15356 Mdot
.98 .1538 Mdot
.98 .15442 Mdot
.98 .15466 Mdot
.98 .15609 Mdot
.98 .15615 Mdot
.98 .15617 Mdot
.98 .15636 Mdot
.98 .1569 Mdot
.98 .15727 Mdot
.98 .15763 Mdot
.98 .15789 Mdot
.98 .15883 Mdot
.98 .15921 Mdot
.98 .15993 Mdot
.98 .16016 Mdot
.98 .1606 Mdot
.98 .16074 Mdot
.98 .16094 Mdot
.98 .16107 Mdot
.98 .16182 Mdot
.98 .16206 Mdot
.98 .16329 Mdot
.98 .16354 Mdot
.98 .16583 Mdot
.98 .16624 Mdot
.98 .16625 Mdot
.98 .16696 Mdot
.98 .16731 Mdot
.98 .16784 Mdot
.98 .16908 Mdot
.98 .16947 Mdot
.98 .16982 Mdot
.98 .17022 Mdot
.98 .17022 Mdot
.98 .17067 Mdot
.98 .17109 Mdot
.98 .17305 Mdot
.98 .17306 Mdot
.98 .17341 Mdot
.98 .17363 Mdot
.98 .17397 Mdot
.98 .17405 Mdot
.98 .17453 Mdot
.98 .17773 Mdot
.98 .17954 Mdot
.98 .1797 Mdot
.98 .18011 Mdot
.98 .18018 Mdot
.98 .18124 Mdot
.98 .18136 Mdot
.98 .18345 Mdot
.98 .18558 Mdot
.98 .18628 Mdot
.98 .1863 Mdot
.98 .18699 Mdot
.98 .18703 Mdot
.98 .18782 Mdot
.98 .18783 Mdot
.98 .18884 Mdot
.98 .18935 Mdot
.98 .19056 Mdot
.98 .19164 Mdot
.98 .19635 Mdot
.98 .19638 Mdot
.98 .19678 Mdot
.98 .19723 Mdot
.98 .19724 Mdot
.98 .19798 Mdot
.98 .19813 Mdot
.98 .19928 Mdot
.98 .19979 Mdot
.98 .20021 Mdot
.98 .20074 Mdot
.98 .20091 Mdot
.98 .20144 Mdot
.98 .20172 Mdot
.98 .20177 Mdot
.98 .20177 Mdot
.98 .20598 Mdot
.98 .2061 Mdot
.98 .20722 Mdot
.98 .2083 Mdot
.98 .20863 Mdot
.98 .20868 Mdot
.98 .21464 Mdot
.98 .21623 Mdot
.98 .21813 Mdot
.98 .2185 Mdot
.98 .21909 Mdot
.98 .2195 Mdot
.98 .22008 Mdot
.98 .22242 Mdot
.98 .22385 Mdot
.98 .22385 Mdot
.98 .22394 Mdot
.98 .22408 Mdot
.98 .22505 Mdot
.98 .22684 Mdot
.98 .2273 Mdot
.98 .22758 Mdot
.98 .23137 Mdot
.98 .23165 Mdot
.98 .23232 Mdot
.98 .23245 Mdot
.98 .23358 Mdot
.98 .23478 Mdot
.98 .23599 Mdot
.98 .23617 Mdot
.98 .23628 Mdot
.98 .23649 Mdot
.98 .23773 Mdot
.98 .23819 Mdot
.98 .23874 Mdot
.98 .24011 Mdot
.98 .2436 Mdot
.98 .24529 Mdot
.98 .24723 Mdot
.98 .24738 Mdot
.98 .24992 Mdot
.98 .2502 Mdot
.98 .2502 Mdot
.98 .25072 Mdot
.98 .25081 Mdot
.98 .25145 Mdot
.98 .2515 Mdot
.98 .25169 Mdot
.98 .25485 Mdot
.98 .2558 Mdot
.98 .25689 Mdot
.98 .2582 Mdot
.98 .25949 Mdot
.98 .25994 Mdot
.98 .26122 Mdot
.98 .26195 Mdot
.98 .26196 Mdot
.98 .26204 Mdot
.98 .26213 Mdot
.98 .26213 Mdot
.98 .26351 Mdot
.98 .26425 Mdot
.98 .26469 Mdot
.98 .26536 Mdot
.98 .2664 Mdot
.98 .26796 Mdot
.98 .26897 Mdot
.98 .26912 Mdot
.98 .26977 Mdot
.98 .27261 Mdot
.98 .27312 Mdot
.98 .27517 Mdot
.98 .27534 Mdot
.98 .27718 Mdot
.98 .27727 Mdot
.98 .27737 Mdot
.98 .27799 Mdot
.98 .27877 Mdot
.98 .27944 Mdot
.98 .28289 Mdot
.98 .28413 Mdot
.98 .28923 Mdot
.98 .28936 Mdot
.98 .29047 Mdot
.98 .29071 Mdot
.98 .29072 Mdot
.98 .29079 Mdot
.98 .2909 Mdot
.98 .29209 Mdot
.98 .29316 Mdot
.98 .29432 Mdot
.98 .29445 Mdot
.98 .29507 Mdot
.98 .2973 Mdot
.98 .29746 Mdot
.98 .29762 Mdot
.98 .29906 Mdot
.98 .29949 Mdot
.98 .29982 Mdot
.98 .30002 Mdot
.98 .30008 Mdot
.98 .30116 Mdot
.98 .30123 Mdot
.98 .30322 Mdot
.98 .30411 Mdot
.98 .3049 Mdot
.98 .30544 Mdot
.98 .30608 Mdot
.98 .30652 Mdot
.98 .30666 Mdot
.98 .30673 Mdot
.98 .3086 Mdot
.98 .30949 Mdot
.98 .30986 Mdot
.98 .3099 Mdot
.98 .31184 Mdot
.98 .31352 Mdot
.98 .31364 Mdot
.98 .31567 Mdot
.98 .31618 Mdot
.98 .31691 Mdot
.98 .31907 Mdot
.98 .32059 Mdot
.98 .32486 Mdot
.98 .32489 Mdot
.98 .32916 Mdot
.98 .3297 Mdot
.98 .33014 Mdot
.98 .33061 Mdot
.98 .3307 Mdot
.98 .33095 Mdot
.98 .33132 Mdot
.98 .33189 Mdot
.98 .33339 Mdot
.98 .33375 Mdot
.98 .33418 Mdot
.98 .33437 Mdot
.98 .33551 Mdot
.98 .33592 Mdot
.98 .33658 Mdot
.98 .3367 Mdot
.98 .33796 Mdot
.98 .33834 Mdot
.98 .33891 Mdot
.98 .34056 Mdot
.98 .34062 Mdot
.98 .3408 Mdot
.98 .34191 Mdot
.98 .34274 Mdot
.98 .34352 Mdot
.98 .34405 Mdot
.98 .34437 Mdot
.98 .34483 Mdot
.98 .3457 Mdot
.98 .34596 Mdot
.98 .34663 Mdot
.98 .34674 Mdot
.98 .34686 Mdot
.98 .34755 Mdot
.98 .35002 Mdot
.98 .35008 Mdot
.98 .35228 Mdot
.98 .35344 Mdot
.98 .35362 Mdot
.98 .35654 Mdot
.98 .35655 Mdot
.98 .35667 Mdot
.98 .35964 Mdot
.98 .36133 Mdot
.98 .36221 Mdot
.98 .36325 Mdot
.98 .3634 Mdot
.98 .36341 Mdot
.98 .36466 Mdot
.98 .36503 Mdot
.98 .36523 Mdot
.98 .36642 Mdot
.98 .36647 Mdot
.98 .36655 Mdot
.98 .36874 Mdot
.98 .37215 Mdot
.98 .37358 Mdot
.98 .37364 Mdot
.98 .37502 Mdot
.98 .37547 Mdot
.98 .37654 Mdot
.98 .37741 Mdot
.98 .37763 Mdot
.98 .37813 Mdot
.98 .37815 Mdot
.98 .37963 Mdot
.98 .38024 Mdot
.98 .38066 Mdot
.98 .38159 Mdot
.98 .38264 Mdot
.98 .38283 Mdot
.98 .38293 Mdot
.98 .38445 Mdot
.98 .38466 Mdot
.98 .38491 Mdot
.98 .38537 Mdot
.98 .38558 Mdot
.98 .38836 Mdot
.98 .39046 Mdot
.98 .39087 Mdot
.98 .39275 Mdot
.98 .39298 Mdot
.98 .39366 Mdot
.98 .39377 Mdot
.98 .39529 Mdot
.98 .39532 Mdot
.98 .39754 Mdot
.98 .39869 Mdot
.98 .39992 Mdot
.98 .40078 Mdot
.98 .40085 Mdot
.98 .40207 Mdot
.98 .40296 Mdot
.98 .40351 Mdot
.98 .40365 Mdot
.98 .40486 Mdot
.98 .40527 Mdot
.98 .40579 Mdot
.98 .40642 Mdot
.98 .40661 Mdot
.98 .40685 Mdot
.98 .40844 Mdot
.98 .40876 Mdot
.98 .4094 Mdot
.98 .40992 Mdot
.98 .41018 Mdot
.98 .41106 Mdot
.98 .41109 Mdot
.98 .41255 Mdot
.98 .41259 Mdot
.98 .41306 Mdot
.98 .41308 Mdot
.98 .4147 Mdot
.98 .41621 Mdot
.98 .41685 Mdot
.98 .41835 Mdot
.98 .41842 Mdot
.98 .41847 Mdot
.98 .41923 Mdot
.98 .4207 Mdot
.98 .42245 Mdot
.98 .42431 Mdot
.98 .42432 Mdot
.98 .42583 Mdot
.98 .42596 Mdot
.98 .42631 Mdot
.98 .4265 Mdot
.98 .42681 Mdot
.98 .42709 Mdot
.98 .42738 Mdot
.98 .4283 Mdot
.98 .4288 Mdot
.98 .42899 Mdot
.98 .42925 Mdot
.98 .42941 Mdot
.98 .42946 Mdot
.98 .43073 Mdot
.98 .4333 Mdot
.98 .43333 Mdot
.98 .43363 Mdot
.98 .43371 Mdot
.98 .43376 Mdot
.98 .43404 Mdot
.98 .43407 Mdot
.98 .43538 Mdot
.98 .43572 Mdot
.98 .43616 Mdot
.98 .43662 Mdot
.98 .43714 Mdot
.98 .43729 Mdot
.98 .43739 Mdot
.98 .43761 Mdot
.98 .4379 Mdot
.98 .43855 Mdot
.98 .4392 Mdot
.98 .4397 Mdot
.98 .44046 Mdot
.98 .44048 Mdot
.98 .44085 Mdot
.98 .44195 Mdot
.98 .44215 Mdot
.98 .44246 Mdot
.98 .44267 Mdot
.98 .4428 Mdot
.98 .44284 Mdot
.98 .44322 Mdot
.98 .44335 Mdot
.98 .4436 Mdot
.98 .44434 Mdot
.98 .44461 Mdot
.98 .4451 Mdot
.98 .44585 Mdot
.98 .44639 Mdot
.98 .4483 Mdot
.98 .44906 Mdot
.98 .45053 Mdot
.98 .45061 Mdot
.98 .451 Mdot
.98 .45131 Mdot
.98 .45188 Mdot
.98 .45215 Mdot
.98 .45228 Mdot
.98 .4525 Mdot
.98 .45256 Mdot
.98 .45282 Mdot
.98 .45432 Mdot
.98 .4548 Mdot
.98 .45712 Mdot
.98 .45723 Mdot
.98 .45771 Mdot
.98 .45806 Mdot
.98 .461 Mdot
.98 .46149 Mdot
.98 .46162 Mdot
.98 .46205 Mdot
.98 .46219 Mdot
.98 .46229 Mdot
.98 .46282 Mdot
.98 .463 Mdot
.98 .46301 Mdot
.98 .46392 Mdot
.98 .46437 Mdot
.98 .46452 Mdot
.98 .46505 Mdot
.98 .46527 Mdot
.98 .46542 Mdot
.98 .46606 Mdot
.98 .46822 Mdot
.98 .46842 Mdot
.98 .46916 Mdot
.98 .46965 Mdot
.98 .46981 Mdot
.98 .47056 Mdot
.98 .47057 Mdot
.98 .47142 Mdot
.98 .47221 Mdot
.98 .47324 Mdot
.98 .47423 Mdot
.98 .47563 Mdot
.98 .47584 Mdot
.98 .47586 Mdot
.98 .4765 Mdot
.98 .47652 Mdot
.98 .4769 Mdot
.98 .47702 Mdot
.98 .47753 Mdot
.98 .47767 Mdot
.98 .47836 Mdot
.98 .47855 Mdot
.98 .47883 Mdot
.98 .47905 Mdot
.98 .47976 Mdot
.98 .47981 Mdot
.98 .48005 Mdot
.98 .48044 Mdot
.98 .48099 Mdot
.98 .48136 Mdot
.98 .48334 Mdot
.98 .48398 Mdot
.98 .48402 Mdot
.98 .48431 Mdot
.98 .48537 Mdot
.98 .48625 Mdot
.98 .4874 Mdot
.98 .48749 Mdot
.98 .48778 Mdot
.98 .4885 Mdot
.98 .48854 Mdot
.98 .48862 Mdot
.98 .48905 Mdot
.98 .48943 Mdot
.98 .4896 Mdot
.98 .48985 Mdot
.98 .49045 Mdot
.98 .49066 Mdot
.98 .49075 Mdot
.98 .49154 Mdot
.98 .49231 Mdot
.98 .49288 Mdot
.98 .49424 Mdot
.98 .49512 Mdot
.98 .49517 Mdot
.98 .49564 Mdot
.98 .49572 Mdot
.98 .49587 Mdot
.98 .49636 Mdot
.98 .49642 Mdot
.98 .49784 Mdot
.98 .499 Mdot
.98 .49904 Mdot
.98 .50018 Mdot
.98 .50025 Mdot
.98 .5007 Mdot
.98 .50154 Mdot
.98 .50157 Mdot
.98 .50278 Mdot
.98 .50286 Mdot
.98 .50312 Mdot
.98 .50322 Mdot
.98 .50355 Mdot
.98 .50384 Mdot
.98 .50404 Mdot
.98 .50465 Mdot
.98 .506 Mdot
.98 .50614 Mdot
.98 .50661 Mdot
.98 .50705 Mdot
.98 .50755 Mdot
.98 .50771 Mdot
.98 .50784 Mdot
.98 .5084 Mdot
.98 .50861 Mdot
.98 .51098 Mdot
.98 .51099 Mdot
.98 .51387 Mdot
.98 .51505 Mdot
.98 .51509 Mdot
.98 .5157 Mdot
.98 .51639 Mdot
.98 .5164 Mdot
.98 .51653 Mdot
.98 .51751 Mdot
.98 .51774 Mdot
.98 .51875 Mdot
.98 .51945 Mdot
.98 .51988 Mdot
.98 .51995 Mdot
.98 .52006 Mdot
.98 .52021 Mdot
.98 .52083 Mdot
.98 .52161 Mdot
.98 .52186 Mdot
.98 .52227 Mdot
.98 .52264 Mdot
.98 .52305 Mdot
.98 .52311 Mdot
.98 .52311 Mdot
.98 .5232 Mdot
.98 .52537 Mdot
.98 .52767 Mdot
.98 .5277 Mdot
.98 .52835 Mdot
.98 .52841 Mdot
.98 .5291 Mdot
.98 .52927 Mdot
.98 .53044 Mdot
.98 .53049 Mdot
.98 .53082 Mdot
.98 .53169 Mdot
.98 .53206 Mdot
.98 .5323 Mdot
.98 .53276 Mdot
.98 .53276 Mdot
.98 .53282 Mdot
.98 .53363 Mdot
.98 .53405 Mdot
.98 .53618 Mdot
.98 .53649 Mdot
.98 .53675 Mdot
.98 .53758 Mdot
.98 .53825 Mdot
.98 .53879 Mdot
.98 .54035 Mdot
.98 .54053 Mdot
.98 .54067 Mdot
.98 .54123 Mdot
.98 .54235 Mdot
.98 .54269 Mdot
.98 .54389 Mdot
.98 .54398 Mdot
.98 .54503 Mdot
.98 .54506 Mdot
.98 .54551 Mdot
.98 .54623 Mdot
.98 .54654 Mdot
.98 .54673 Mdot
.98 .54743 Mdot
.98 .54792 Mdot
.98 .55021 Mdot
.98 .55055 Mdot
.98 .55059 Mdot
.98 .55187 Mdot
.98 .55187 Mdot
.98 .55197 Mdot
.98 .55213 Mdot
.98 .55235 Mdot
.98 .55247 Mdot
.98 .55324 Mdot
.98 .55325 Mdot
.98 .55351 Mdot
.98 .55526 Mdot
.98 .55562 Mdot
.98 .55577 Mdot
.98 .55607 Mdot
.98 .55608 Mdot
.98 .55835 Mdot
.98 .56016 Mdot
.98 .56045 Mdot
.98 .56115 Mdot
.98 .56129 Mdot
.98 .56129 Mdot
.98 .5615 Mdot
.98 .56198 Mdot
.98 .56224 Mdot
.98 .56244 Mdot
.98 .56245 Mdot
.98 .56366 Mdot
.98 .56399 Mdot
.98 .56409 Mdot
.98 .56428 Mdot
.98 .56487 Mdot
.98 .56505 Mdot
.98 .56516 Mdot
.98 .56531 Mdot
.98 .56537 Mdot
.98 .56622 Mdot
.98 .56657 Mdot
.98 .56663 Mdot
.98 .56702 Mdot
.98 .56721 Mdot
.98 .56754 Mdot
.98 .56862 Mdot
.98 .56863 Mdot
.98 .56882 Mdot
.98 .5691 Mdot
.98 .5693 Mdot
.98 .57011 Mdot
.98 .57107 Mdot
.98 .57148 Mdot
.98 .572 Mdot
.98 .5727 Mdot
.98 .57275 Mdot
.98 .57348 Mdot
.98 .57399 Mdot
.98 .57512 Mdot
.98 .57525 Mdot
.98 .57682 Mdot
.98 .57733 Mdot
.98 .57755 Mdot
.98 .57755 Mdot
.98 .57796 Mdot
.98 .57803 Mdot
.98 .57854 Mdot
.98 .57856 Mdot
.98 .57857 Mdot
.98 .57862 Mdot
.98 .57866 Mdot
.98 .57872 Mdot
.98 .57958 Mdot
.98 .57973 Mdot
.98 .58001 Mdot
.98 .58094 Mdot
.98 .58095 Mdot
.98 .58105 Mdot
.98 .58111 Mdot
.98 .5818 Mdot
.98 .58181 Mdot
.98 .58244 Mdot
.98 .58257 Mdot
.98 .58349 Mdot
.98 .58362 Mdot
.98 .58436 Mdot
.98 .58466 Mdot
.98 .5855 Mdot
.98 .5856 Mdot
.98 .58567 Mdot
.98 .58568 Mdot
.98 .58597 Mdot
.98 .58597 Mdot
.98 .58603 Mdot
.98 .58608 Mdot
.98 .58608 Mdot
.98 .58695 Mdot
.98 .5874 Mdot
.98 .5875 Mdot
.98 .58761 Mdot
.98 .58766 Mdot
.98 .58807 Mdot
.98 .58829 Mdot
.98 .58867 Mdot
.98 .58955 Mdot
.98 .58956 Mdot
.98 .58958 Mdot
.98 .59011 Mdot
.98 .59019 Mdot
.98 .59054 Mdot
.98 .59091 Mdot
.98 .59127 Mdot
.98 .59133 Mdot
.98 .59139 Mdot
.98 .59172 Mdot
.98 .59186 Mdot
.98 .592 Mdot
.98 .59224 Mdot
.98 .59229 Mdot
.98 .59251 Mdot
.98 .59266 Mdot
.98 .59291 Mdot
.98 .5931 Mdot
.98 .59321 Mdot
.98 .59327 Mdot
.98 .59329 Mdot
.98 .59364 Mdot
.98 .59411 Mdot
.98 .59413 Mdot
.98 .59414 Mdot
.98 .59419 Mdot
.98 .59421 Mdot
.98 .59423 Mdot
.98 .59445 Mdot
.98 .59477 Mdot
.98 .59492 Mdot
.98 .59504 Mdot
.98 .59515 Mdot
.98 .59529 Mdot
.98 .59578 Mdot
.98 .59582 Mdot
.98 .59607 Mdot
.98 .59621 Mdot
.98 .59635 Mdot
.98 .59661 Mdot
.98 .59668 Mdot
.98 .59677 Mdot
.98 .59682 Mdot
.98 .59694 Mdot
.98 .59742 Mdot
.98 .5976 Mdot
.98 .59771 Mdot
.98 .59778 Mdot
.98 .59781 Mdot
.98 .59794 Mdot
.98 .59807 Mdot
.98 .59822 Mdot
.98 .59831 Mdot
.98 .59835 Mdot
.98 .59864 Mdot
.98 .5987 Mdot
.98 .5987 Mdot
.98 .59872 Mdot
.98 .59874 Mdot
.98 .59903 Mdot
.98 .59926 Mdot
.98 .59926 Mdot
.98 .59927 Mdot
.98 .5995 Mdot
.98 .59953 Mdot
.98 .59965 Mdot
.98 .60004 Mdot
.98 .60006 Mdot
.98 .60006 Mdot
.98 .60009 Mdot
.98 .60028 Mdot
.98 .60029 Mdot
.98 .60035 Mdot
.98 .60039 Mdot
.98 .60042 Mdot
.98 .60042 Mdot
.98 .60054 Mdot
.98 .60055 Mdot
.98 .60055 Mdot
.98 .60062 Mdot
.98 .60067 Mdot
.98 .60074 Mdot
.98 .6008 Mdot
.98 .60082 Mdot
.98 .60083 Mdot
.98 .60085 Mdot
.98 .60088 Mdot
.98 .60091 Mdot
.98 .60091 Mdot
.98 .60092 Mdot
.98 .60093 Mdot
.98 .60093 Mdot
.98 .60096 Mdot
.98 .60096 Mdot
.98 .60096 Mdot
.98 .60096 Mdot
.982 .02313 Mdot
.982 .02313 Mdot
.982 .02314 Mdot
.982 .02316 Mdot
.982 .02316 Mdot
.982 .02321 Mdot
.982 .02322 Mdot
.982 .02322 Mdot
.982 .02343 Mdot
.982 .02344 Mdot
.982 .02345 Mdot
.982 .02356 Mdot
.982 .02358 Mdot
.982 .02359 Mdot
.982 .02361 Mdot
.982 .02363 Mdot
.982 .02365 Mdot
.982 .02367 Mdot
.982 .02378 Mdot
.982 .02383 Mdot
.982 .02401 Mdot
.982 .02419 Mdot
.982 .02429 Mdot
.982 .02433 Mdot
.982 .02437 Mdot
.982 .02559 Mdot
.982 .02563 Mdot
.982 .02565 Mdot
.982 .02567 Mdot
.982 .02592 Mdot
.982 .02603 Mdot
.982 .02705 Mdot
.982 .02722 Mdot
.982 .02738 Mdot
.982 .02744 Mdot
.982 .02788 Mdot
.982 .02799 Mdot
.982 .02835 Mdot
.982 .02842 Mdot
.982 .02846 Mdot
.982 .02873 Mdot
.982 .02922 Mdot
.982 .02926 Mdot
.982 .02984 Mdot
.982 .02986 Mdot
.982 .0309 Mdot
.982 .03094 Mdot
.982 .0311 Mdot
.982 .03133 Mdot
.982 .03195 Mdot
.982 .03232 Mdot
.982 .03317 Mdot
.982 .03446 Mdot
.982 .03464 Mdot
.982 .03497 Mdot
.982 .03523 Mdot
.982 .03592 Mdot
.982 .03683 Mdot
.982 .03733 Mdot
.982 .03737 Mdot
.982 .03766 Mdot
.982 .03772 Mdot
.982 .03861 Mdot
.982 .03869 Mdot
.982 .03935 Mdot
.982 .04003 Mdot
.982 .04026 Mdot
.982 .04033 Mdot
.982 .04155 Mdot
.982 .04161 Mdot
.982 .04188 Mdot
.982 .04192 Mdot
.982 .04194 Mdot
.982 .04224 Mdot
.982 .0423 Mdot
.982 .04271 Mdot
.982 .04304 Mdot
.982 .04312 Mdot
.982 .04312 Mdot
.982 .04443 Mdot
.982 .04457 Mdot
.982 .04468 Mdot
.982 .04577 Mdot
.982 .04607 Mdot
.982 .0464 Mdot
.982 .04748 Mdot
.982 .04753 Mdot
.982 .04778 Mdot
.982 .04778 Mdot
.982 .04783 Mdot
.982 .0479 Mdot
.982 .04791 Mdot
.982 .0481 Mdot
.982 .04812 Mdot
.982 .04813 Mdot
.982 .04866 Mdot
.982 .04894 Mdot
.982 .04897 Mdot
.982 .04902 Mdot
.982 .04946 Mdot
.982 .04954 Mdot
.982 .04956 Mdot
.982 .04963 Mdot
.982 .04972 Mdot
.982 .04979 Mdot
.982 .04987 Mdot
.982 .05005 Mdot
.982 .05019 Mdot
.982 .05029 Mdot
.982 .05049 Mdot
.982 .05116 Mdot
.982 .05188 Mdot
.982 .05226 Mdot
.982 .05227 Mdot
.982 .05241 Mdot
.982 .05257 Mdot
.982 .05276 Mdot
.982 .05332 Mdot
.982 .05455 Mdot
.982 .05521 Mdot
.982 .05563 Mdot
.982 .05626 Mdot
.982 .05637 Mdot
.982 .05704 Mdot
.982 .05726 Mdot
.982 .05742 Mdot
.982 .0575 Mdot
.982 .05755 Mdot
.982 .058 Mdot
.982 .05853 Mdot
.982 .05896 Mdot
.982 .06286 Mdot
.982 .06348 Mdot
.982 .06411 Mdot
.982 .06435 Mdot
.982 .06481 Mdot
.982 .06602 Mdot
.982 .06618 Mdot
.982 .06642 Mdot
.982 .06645 Mdot
.982 .06742 Mdot
.982 .06779 Mdot
.982 .06806 Mdot
.982 .06823 Mdot
.982 .0683 Mdot
.982 .06925 Mdot
.982 .06933 Mdot
.982 .07054 Mdot
.982 .07058 Mdot
.982 .07075 Mdot
.982 .07109 Mdot
.982 .07126 Mdot
.982 .07347 Mdot
.982 .07354 Mdot
.982 .07538 Mdot
.982 .0755 Mdot
.982 .07625 Mdot
.982 .07638 Mdot
.982 .07726 Mdot
.982 .07729 Mdot
.982 .07744 Mdot
.982 .07759 Mdot
.982 .0776 Mdot
.982 .0777 Mdot
.982 .07821 Mdot
.982 .07908 Mdot
.982 .07927 Mdot
.982 .07938 Mdot
.982 .0811 Mdot
.982 .08139 Mdot
.982 .08152 Mdot
.982 .08192 Mdot
.982 .08277 Mdot
.982 .08383 Mdot
.982 .08435 Mdot
.982 .08505 Mdot
.982 .08516 Mdot
.982 .0857 Mdot
.982 .08595 Mdot
.982 .08717 Mdot
.982 .09022 Mdot
.982 .09077 Mdot
.982 .09108 Mdot
.982 .09115 Mdot
.982 .09145 Mdot
.982 .09195 Mdot
.982 .09269 Mdot
.982 .09313 Mdot
.982 .09364 Mdot
.982 .09531 Mdot
.982 .09621 Mdot
.982 .09786 Mdot
.982 .09791 Mdot
.982 .09954 Mdot
.982 .09973 Mdot
.982 .1014 Mdot
.982 .10155 Mdot
.982 .1025 Mdot
.982 .1028 Mdot
.982 .10284 Mdot
.982 .10289 Mdot
.982 .10333 Mdot
.982 .10364 Mdot
.982 .10564 Mdot
.982 .10573 Mdot
.982 .10608 Mdot
.982 .10637 Mdot
.982 .107 Mdot
.982 .10881 Mdot
.982 .10892 Mdot
.982 .11007 Mdot
.982 .11045 Mdot
.982 .11052 Mdot
.982 .11096 Mdot
.982 .11128 Mdot
.982 .11165 Mdot
.982 .11168 Mdot
.982 .1121 Mdot
.982 .11236 Mdot
.982 .11355 Mdot
.982 .11416 Mdot
.982 .11429 Mdot
.982 .11431 Mdot
.982 .11678 Mdot
.982 .11703 Mdot
.982 .11798 Mdot
.982 .11815 Mdot
.982 .1182 Mdot
.982 .11822 Mdot
.982 .11848 Mdot
.982 .1185 Mdot
.982 .1193 Mdot
.982 .11951 Mdot
.982 .12098 Mdot
.982 .12135 Mdot
.982 .12219 Mdot
.982 .12247 Mdot
.982 .12248 Mdot
.982 .12293 Mdot
.982 .12357 Mdot
.982 .12717 Mdot
.982 .12766 Mdot
.982 .12807 Mdot
.982 .13039 Mdot
.982 .1315 Mdot
.982 .13198 Mdot
.982 .13305 Mdot
.982 .13341 Mdot
.982 .13422 Mdot
.982 .13609 Mdot
.982 .13805 Mdot
.982 .1382 Mdot
.982 .13909 Mdot
.982 .13911 Mdot
.982 .13927 Mdot
.982 .13952 Mdot
.982 .13957 Mdot
.982 .14023 Mdot
.982 .14032 Mdot
.982 .14035 Mdot
.982 .14057 Mdot
.982 .14124 Mdot
.982 .14209 Mdot
.982 .14216 Mdot
.982 .14223 Mdot
.982 .14319 Mdot
.982 .14329 Mdot
.982 .14349 Mdot
.982 .14502 Mdot
.982 .1452 Mdot
.982 .1453 Mdot
.982 .14539 Mdot
.982 .14563 Mdot
.982 .14594 Mdot
.982 .14618 Mdot
.982 .14646 Mdot
.982 .1471 Mdot
.982 .14735 Mdot
.982 .14759 Mdot
.982 .14795 Mdot
.982 .14846 Mdot
.982 .14856 Mdot
.982 .14859 Mdot
.982 .14865 Mdot
.982 .15008 Mdot
.982 .1501 Mdot
.982 .15099 Mdot
.982 .15173 Mdot
.982 .15175 Mdot
.982 .15205 Mdot
.982 .15349 Mdot
.982 .15481 Mdot
.982 .15485 Mdot
.982 .15493 Mdot
.982 .15535 Mdot
.982 .15588 Mdot
.982 .15655 Mdot
.982 .1585 Mdot
.982 .1615 Mdot
.982 .16273 Mdot
.982 .16294 Mdot
.982 .16502 Mdot
.982 .16646 Mdot
.982 .16797 Mdot
.982 .16862 Mdot
.982 .169 Mdot
.982 .17123 Mdot
.982 .17127 Mdot
.982 .17204 Mdot
.982 .17255 Mdot
.982 .17257 Mdot
.982 .17286 Mdot
.982 .17303 Mdot
.982 .17399 Mdot
.982 .17455 Mdot
.982 .17587 Mdot
.982 .17634 Mdot
.982 .1776 Mdot
.982 .17782 Mdot
.982 .17821 Mdot
.982 .18141 Mdot
.982 .18174 Mdot
.982 .18372 Mdot
.982 .18802 Mdot
.982 .19091 Mdot
.982 .19116 Mdot
.982 .19299 Mdot
.982 .19361 Mdot
.982 .19378 Mdot
.982 .19404 Mdot
.982 .19417 Mdot
.982 .19438 Mdot
.982 .19489 Mdot
.982 .19494 Mdot
.982 .19506 Mdot
.982 .19586 Mdot
.982 .19738 Mdot
.982 .19761 Mdot
.982 .19777 Mdot
.982 .19961 Mdot
.982 .20137 Mdot
.982 .20162 Mdot
.982 .20191 Mdot
.982 .20269 Mdot
.982 .20279 Mdot
.982 .20286 Mdot
.982 .20596 Mdot
.982 .20719 Mdot
.982 .20797 Mdot
.982 .20807 Mdot
.982 .2086 Mdot
.982 .20883 Mdot
.982 .21058 Mdot
.982 .2116 Mdot
.982 .21192 Mdot
.982 .21218 Mdot
.982 .21613 Mdot
.982 .21626 Mdot
.982 .2168 Mdot
.982 .21788 Mdot
.982 .2181 Mdot
.982 .21844 Mdot
.982 .21861 Mdot
.982 .22138 Mdot
.982 .22206 Mdot
.982 .2234 Mdot
.982 .22425 Mdot
.982 .2255 Mdot
.982 .22573 Mdot
.982 .22585 Mdot
.982 .22852 Mdot
.982 .23003 Mdot
.982 .23068 Mdot
.982 .2312 Mdot
.982 .2316 Mdot
.982 .23197 Mdot
.982 .23432 Mdot
.982 .23474 Mdot
.982 .23665 Mdot
.982 .2375 Mdot
.982 .23759 Mdot
.982 .23808 Mdot
.982 .23808 Mdot
.982 .23854 Mdot
.982 .23857 Mdot
.982 .2389 Mdot
.982 .24049 Mdot
.982 .24319 Mdot
.982 .24379 Mdot
.982 .24414 Mdot
.982 .24635 Mdot
.982 .24656 Mdot
.982 .24708 Mdot
.982 .24803 Mdot
.982 .24803 Mdot
.982 .24813 Mdot
.982 .24944 Mdot
.982 .24945 Mdot
.982 .25035 Mdot
.982 .25036 Mdot
.982 .25075 Mdot
.982 .2509 Mdot
.982 .25198 Mdot
.982 .25345 Mdot
.982 .25359 Mdot
.982 .25461 Mdot
.982 .25709 Mdot
.982 .25754 Mdot
.982 .25785 Mdot
.982 .25787 Mdot
.982 .25821 Mdot
.982 .25941 Mdot
.982 .26027 Mdot
.982 .26076 Mdot
.982 .26155 Mdot
.982 .26172 Mdot
.982 .26189 Mdot
.982 .26351 Mdot
.982 .2639 Mdot
.982 .26428 Mdot
.982 .26433 Mdot
.982 .2665 Mdot
.982 .26754 Mdot
.982 .26796 Mdot
.982 .27266 Mdot
.982 .27417 Mdot
.982 .27453 Mdot
.982 .27522 Mdot
.982 .27582 Mdot
.982 .27705 Mdot
.982 .27713 Mdot
.982 .27797 Mdot
.982 .27868 Mdot
.982 .2796 Mdot
.982 .2798 Mdot
.982 .28069 Mdot
.982 .28215 Mdot
.982 .2822 Mdot
.982 .28242 Mdot
.982 .28432 Mdot
.982 .2849 Mdot
.982 .2856 Mdot
.982 .28565 Mdot
.982 .28589 Mdot
.982 .28592 Mdot
.982 .28634 Mdot
.982 .2871 Mdot
.982 .28771 Mdot
.982 .28962 Mdot
.982 .29084 Mdot
.982 .29149 Mdot
.982 .29191 Mdot
.982 .29196 Mdot
.982 .29454 Mdot
.982 .29928 Mdot
.982 .29935 Mdot
.982 .29943 Mdot
.982 .30221 Mdot
.982 .30389 Mdot
.982 .30408 Mdot
.982 .30461 Mdot
.982 .30486 Mdot
.982 .30489 Mdot
.982 .30554 Mdot
.982 .30566 Mdot
.982 .30715 Mdot
.982 .30785 Mdot
.982 .30792 Mdot
.982 .30883 Mdot
.982 .30932 Mdot
.982 .30974 Mdot
.982 .31079 Mdot
.982 .31086 Mdot
.982 .31241 Mdot
.982 .31305 Mdot
.982 .31325 Mdot
.982 .31335 Mdot
.982 .31351 Mdot
.982 .31474 Mdot
.982 .31532 Mdot
.982 .3156 Mdot
.982 .31571 Mdot
.982 .31873 Mdot
.982 .31923 Mdot
.982 .31944 Mdot
.982 .32113 Mdot
.982 .32138 Mdot
.982 .32162 Mdot
.982 .32172 Mdot
.982 .32235 Mdot
.982 .32251 Mdot
.982 .32299 Mdot
.982 .32308 Mdot
.982 .32314 Mdot
.982 .32411 Mdot
.982 .32417 Mdot
.982 .32487 Mdot
.982 .32489 Mdot
.982 .3263 Mdot
.982 .32757 Mdot
.982 .32963 Mdot
.982 .3298 Mdot
.982 .3301 Mdot
.982 .3332 Mdot
.982 .33423 Mdot
.982 .3344 Mdot
.982 .33445 Mdot
.982 .33534 Mdot
.982 .33539 Mdot
.982 .33558 Mdot
.982 .33563 Mdot
.982 .33616 Mdot
.982 .3364 Mdot
.982 .33645 Mdot
.982 .33646 Mdot
.982 .33744 Mdot
.982 .33751 Mdot
.982 .33864 Mdot
.982 .33933 Mdot
.982 .34249 Mdot
.982 .3441 Mdot
.982 .34444 Mdot
.982 .3445 Mdot
.982 .34486 Mdot
.982 .34882 Mdot
.982 .34949 Mdot
.982 .3496 Mdot
.982 .35097 Mdot
.982 .35155 Mdot
.982 .35163 Mdot
.982 .35408 Mdot
.982 .35451 Mdot
.982 .35465 Mdot
.982 .3547 Mdot
.982 .35537 Mdot
.982 .35542 Mdot
.982 .35748 Mdot
.982 .35781 Mdot
.982 .35803 Mdot
.982 .36178 Mdot
.982 .36273 Mdot
.982 .36275 Mdot
.982 .36455 Mdot
.982 .36474 Mdot
.982 .36485 Mdot
.982 .36557 Mdot
.982 .3656 Mdot
.982 .36673 Mdot
.982 .36726 Mdot
.982 .36744 Mdot
.982 .36833 Mdot
.982 .36854 Mdot
.982 .37569 Mdot
.982 .37707 Mdot
.982 .37728 Mdot
.982 .37849 Mdot
.982 .3795 Mdot
.982 .38045 Mdot
.982 .38514 Mdot
.982 .38784 Mdot
.982 .38889 Mdot
.982 .38898 Mdot
.982 .39069 Mdot
.982 .39153 Mdot
.982 .39223 Mdot
.982 .39234 Mdot
.982 .39239 Mdot
.982 .39254 Mdot
.982 .39325 Mdot
.982 .39329 Mdot
.982 .39431 Mdot
.982 .39691 Mdot
.982 .39859 Mdot
.982 .39872 Mdot
.982 .40056 Mdot
.982 .40161 Mdot
.982 .40327 Mdot
.982 .40363 Mdot
.982 .40567 Mdot
.982 .40572 Mdot
.982 .40609 Mdot
.982 .40609 Mdot
.982 .40666 Mdot
.982 .40679 Mdot
.982 .40742 Mdot
.982 .4083 Mdot
.982 .40841 Mdot
.982 .4085 Mdot
.982 .40858 Mdot
.982 .40908 Mdot
.982 .41059 Mdot
.982 .41243 Mdot
.982 .41252 Mdot
.982 .41269 Mdot
.982 .41283 Mdot
.982 .41314 Mdot
.982 .41334 Mdot
.982 .41435 Mdot
.982 .41441 Mdot
.982 .415 Mdot
.982 .41523 Mdot
.982 .41566 Mdot
.982 .41656 Mdot
.982 .4191 Mdot
.982 .41949 Mdot
.982 .41972 Mdot
.982 .41973 Mdot
.982 .41988 Mdot
.982 .41991 Mdot
.982 .42044 Mdot
.982 .42112 Mdot
.982 .42113 Mdot
.982 .42165 Mdot
.982 .42227 Mdot
.982 .42368 Mdot
.982 .42397 Mdot
.982 .42424 Mdot
.982 .42475 Mdot
.982 .42553 Mdot
.982 .42665 Mdot
.982 .42686 Mdot
.982 .42693 Mdot
.982 .42705 Mdot
.982 .42711 Mdot
.982 .42908 Mdot
.982 .43016 Mdot
.982 .43019 Mdot
.982 .43064 Mdot
.982 .43211 Mdot
.982 .43326 Mdot
.982 .43368 Mdot
.982 .43373 Mdot
.982 .43436 Mdot
.982 .43462 Mdot
.982 .43741 Mdot
.982 .4394 Mdot
.982 .44019 Mdot
.982 .44026 Mdot
.982 .44044 Mdot
.982 .4413 Mdot
.982 .44242 Mdot
.982 .4438 Mdot
.982 .44522 Mdot
.982 .4471 Mdot
.982 .44779 Mdot
.982 .44855 Mdot
.982 .45039 Mdot
.982 .45349 Mdot
.982 .45385 Mdot
.982 .45431 Mdot
.982 .4563 Mdot
.982 .45672 Mdot
.982 .45825 Mdot
.982 .45916 Mdot
.982 .45988 Mdot
.982 .46079 Mdot
.982 .4636 Mdot
.982 .46587 Mdot
.982 .4665 Mdot
.982 .46772 Mdot
.982 .46845 Mdot
.982 .46936 Mdot
.982 .4708 Mdot
.982 .4721 Mdot
.982 .47266 Mdot
.982 .47273 Mdot
.982 .47415 Mdot
.982 .47511 Mdot
.982 .47513 Mdot
.982 .47558 Mdot
.982 .47567 Mdot
.982 .47598 Mdot
.982 .47775 Mdot
.982 .47819 Mdot
.982 .47877 Mdot
.982 .4807 Mdot
.982 .48115 Mdot
.982 .482 Mdot
.982 .48271 Mdot
.982 .48424 Mdot
.982 .48426 Mdot
.982 .48456 Mdot
.982 .48465 Mdot
.982 .48469 Mdot
.982 .48534 Mdot
.982 .48609 Mdot
.982 .48958 Mdot
.982 .49095 Mdot
.982 .49151 Mdot
.982 .49438 Mdot
.982 .49482 Mdot
.982 .49489 Mdot
.982 .49589 Mdot
.982 .49596 Mdot
.982 .49667 Mdot
.982 .49861 Mdot
.982 .50103 Mdot
.982 .50178 Mdot
.982 .50182 Mdot
.982 .50208 Mdot
.982 .50359 Mdot
.982 .50675 Mdot
.982 .50677 Mdot
.982 .50686 Mdot
.982 .50706 Mdot
.982 .50715 Mdot
.982 .50717 Mdot
.982 .5075 Mdot
.982 .50928 Mdot
.982 .51004 Mdot
.982 .51051 Mdot
.982 .51102 Mdot
.982 .51129 Mdot
.982 .51131 Mdot
.982 .51168 Mdot
.982 .51172 Mdot
.982 .51189 Mdot
.982 .51218 Mdot
.982 .51221 Mdot
.982 .51301 Mdot
.982 .51308 Mdot
.982 .51326 Mdot
.982 .51435 Mdot
.982 .51449 Mdot
.982 .5153 Mdot
.982 .51609 Mdot
.982 .51611 Mdot
.982 .51681 Mdot
.982 .51713 Mdot
.982 .51716 Mdot
.982 .51741 Mdot
.982 .51793 Mdot
.982 .51797 Mdot
.982 .51821 Mdot
.982 .51822 Mdot
.982 .51856 Mdot
.982 .51915 Mdot
.982 .52015 Mdot
.982 .52274 Mdot
.982 .52288 Mdot
.982 .52311 Mdot
.982 .52353 Mdot
.982 .52419 Mdot
.982 .52466 Mdot
.982 .5248 Mdot
.982 .52481 Mdot
.982 .52489 Mdot
.982 .52515 Mdot
.982 .52599 Mdot
.982 .52607 Mdot
.982 .5275 Mdot
.982 .52779 Mdot
.982 .52823 Mdot
.982 .52843 Mdot
.982 .52866 Mdot
.982 .52878 Mdot
.982 .52929 Mdot
.982 .531 Mdot
.982 .53134 Mdot
.982 .53206 Mdot
.982 .53221 Mdot
.982 .53293 Mdot
.982 .53324 Mdot
.982 .5334 Mdot
.982 .53408 Mdot
.982 .53419 Mdot
.982 .5343 Mdot
.982 .53445 Mdot
.982 .53559 Mdot
.982 .53564 Mdot
.982 .53647 Mdot
.982 .53664 Mdot
.982 .53694 Mdot
.982 .53737 Mdot
.982 .5374 Mdot
.982 .5374 Mdot
.982 .5377 Mdot
.982 .53787 Mdot
.982 .53794 Mdot
.982 .54059 Mdot
.982 .54105 Mdot
.982 .54277 Mdot
.982 .54294 Mdot
.982 .54314 Mdot
.982 .54362 Mdot
.982 .54446 Mdot
.982 .54496 Mdot
.982 .54523 Mdot
.982 .54564 Mdot
.982 .54586 Mdot
.982 .54672 Mdot
.982 .54688 Mdot
.982 .54889 Mdot
.982 .5492 Mdot
.982 .55 Mdot
.982 .55156 Mdot
.982 .55194 Mdot
.982 .55255 Mdot
.982 .55311 Mdot
.982 .55315 Mdot
.982 .55396 Mdot
.982 .55398 Mdot
.982 .55413 Mdot
.982 .55419 Mdot
.982 .55423 Mdot
.982 .55431 Mdot
.982 .55436 Mdot
.982 .5551 Mdot
.982 .55604 Mdot
.982 .55732 Mdot
.982 .55791 Mdot
.982 .558 Mdot
.982 .55895 Mdot
.982 .55913 Mdot
.982 .55964 Mdot
.982 .5602 Mdot
.982 .56062 Mdot
.982 .56101 Mdot
.982 .56196 Mdot
.982 .56342 Mdot
.982 .56384 Mdot
.982 .56574 Mdot
.982 .56657 Mdot
.982 .56665 Mdot
.982 .56666 Mdot
.982 .56713 Mdot
.982 .56713 Mdot
.982 .56756 Mdot
.982 .56757 Mdot
.982 .56759 Mdot
.982 .56791 Mdot
.982 .56852 Mdot
.982 .56941 Mdot
.982 .56965 Mdot
.982 .56984 Mdot
.982 .5711 Mdot
.982 .57186 Mdot
.982 .57239 Mdot
.982 .5727 Mdot
.982 .57461 Mdot
.982 .57478 Mdot
.982 .57522 Mdot
.982 .57601 Mdot
.982 .57602 Mdot
.982 .57609 Mdot
.982 .57717 Mdot
.982 .57717 Mdot
.982 .57721 Mdot
.982 .57738 Mdot
.982 .57789 Mdot
.982 .5779 Mdot
.982 .57809 Mdot
.982 .57821 Mdot
.982 .57823 Mdot
.982 .57833 Mdot
.982 .57865 Mdot
.982 .57917 Mdot
.982 .57952 Mdot
.982 .57955 Mdot
.982 .58009 Mdot
.982 .58017 Mdot
.982 .58029 Mdot
.982 .58032 Mdot
.982 .5804 Mdot
.982 .58115 Mdot
.982 .58165 Mdot
.982 .58166 Mdot
.982 .58235 Mdot
.982 .58294 Mdot
.982 .58326 Mdot
.982 .58347 Mdot
.982 .58349 Mdot
.982 .58372 Mdot
.982 .58454 Mdot
.982 .58494 Mdot
.982 .58508 Mdot
.982 .58511 Mdot
.982 .5853 Mdot
.982 .58543 Mdot
.982 .58594 Mdot
.982 .58605 Mdot
.982 .58616 Mdot
.982 .58662 Mdot
.982 .58665 Mdot
.982 .58707 Mdot
.982 .5871 Mdot
.982 .58718 Mdot
.982 .58718 Mdot
.982 .58742 Mdot
.982 .58745 Mdot
.982 .58765 Mdot
.982 .58768 Mdot
.982 .58891 Mdot
.982 .58895 Mdot
.982 .58896 Mdot
.982 .58928 Mdot
.982 .58955 Mdot
.982 .58978 Mdot
.982 .59005 Mdot
.982 .59011 Mdot
.982 .59047 Mdot
.982 .59225 Mdot
.982 .5925 Mdot
.982 .59267 Mdot
.982 .5927 Mdot
.982 .59287 Mdot
.982 .59298 Mdot
.982 .59315 Mdot
.982 .59347 Mdot
.982 .59361 Mdot
.982 .59374 Mdot
.982 .59428 Mdot
.982 .59432 Mdot
.982 .59467 Mdot
.982 .59497 Mdot
.982 .59498 Mdot
.982 .59526 Mdot
.982 .59534 Mdot
.982 .59542 Mdot
.982 .5957 Mdot
.982 .59573 Mdot
.982 .59577 Mdot
.982 .5961 Mdot
.982 .5961 Mdot
.982 .59612 Mdot
.982 .59621 Mdot
.982 .59631 Mdot
.982 .59633 Mdot
.982 .59641 Mdot
.982 .59641 Mdot
.982 .59642 Mdot
.982 .59649 Mdot
.982 .59651 Mdot
.982 .59682 Mdot
.982 .59684 Mdot
.982 .5969 Mdot
.982 .59707 Mdot
.982 .59724 Mdot
.982 .59726 Mdot
.982 .59749 Mdot
.982 .5975 Mdot
.982 .59758 Mdot
.982 .59759 Mdot
.982 .59772 Mdot
.982 .59795 Mdot
.982 .59813 Mdot
.982 .59819 Mdot
.982 .59828 Mdot
.982 .59832 Mdot
.982 .59865 Mdot
.982 .59887 Mdot
.982 .59896 Mdot
.982 .59912 Mdot
.982 .59918 Mdot
.982 .59922 Mdot
.982 .59923 Mdot
.982 .59949 Mdot
.982 .5995 Mdot
.982 .59965 Mdot
.982 .59966 Mdot
.982 .59978 Mdot
.982 .59985 Mdot
.982 .59986 Mdot
.982 .59988 Mdot
.982 .59997 Mdot
.982 .6 Mdot
.982 .60011 Mdot
.982 .60012 Mdot
.982 .60017 Mdot
.982 .60021 Mdot
.982 .60047 Mdot
.982 .60049 Mdot
.982 .60056 Mdot
.982 .60056 Mdot
.982 .60057 Mdot
.982 .60058 Mdot
.982 .60089 Mdot
.982 .6009 Mdot
.982 .60091 Mdot
.982 .60093 Mdot
.982 .60098 Mdot
.982 .60102 Mdot
.982 .60104 Mdot
.982 .60106 Mdot
.982 .60107 Mdot
.982 .60107 Mdot
.982 .60108 Mdot
.982 .60108 Mdot
.982 .60108 Mdot
.982 .60109 Mdot
.982 .60112 Mdot
.982 .60112 Mdot
.982 .60112 Mdot
.982 .60118 Mdot
.982 .60118 Mdot
.982 .60118 Mdot
.982 .60119 Mdot
.982 .60119 Mdot
.982 .6012 Mdot
.982 .6012 Mdot
.982 .6012 Mdot
.984 .0222 Mdot
.984 .02223 Mdot
.984 .02224 Mdot
.984 .02225 Mdot
.984 .02232 Mdot
.984 .02232 Mdot
.984 .02238 Mdot
.984 .02238 Mdot
.984 .02239 Mdot
.984 .0224 Mdot
.984 .02264 Mdot
.984 .02272 Mdot
.984 .02276 Mdot
.984 .0229 Mdot
.984 .02296 Mdot
.984 .02297 Mdot
.984 .02329 Mdot
.984 .02329 Mdot
.984 .02348 Mdot
.984 .02349 Mdot
.984 .02367 Mdot
.984 .02381 Mdot
.984 .02385 Mdot
.984 .02386 Mdot
.984 .02389 Mdot
.984 .0239 Mdot
.984 .02425 Mdot
.984 .0245 Mdot
.984 .02487 Mdot
.984 .02518 Mdot
.984 .02535 Mdot
.984 .02538 Mdot
.984 .02594 Mdot
.984 .02594 Mdot
.984 .02602 Mdot
.984 .02608 Mdot
.984 .02609 Mdot
.984 .02691 Mdot
.984 .02725 Mdot
.984 .02744 Mdot
.984 .02749 Mdot
.984 .02766 Mdot
.984 .02798 Mdot
.984 .028 Mdot
.984 .02809 Mdot
.984 .02809 Mdot
.984 .02859 Mdot
.984 .02861 Mdot
.984 .02922 Mdot
.984 .02939 Mdot
.984 .02996 Mdot
.984 .03194 Mdot
.984 .03337 Mdot
.984 .03414 Mdot
.984 .03417 Mdot
.984 .03437 Mdot
.984 .03477 Mdot
.984 .03528 Mdot
.984 .03627 Mdot
.984 .03686 Mdot
.984 .03702 Mdot
.984 .03718 Mdot
.984 .03778 Mdot
.984 .03844 Mdot
.984 .03863 Mdot
.984 .03942 Mdot
.984 .03961 Mdot
.984 .03974 Mdot
.984 .04073 Mdot
.984 .04125 Mdot
.984 .04227 Mdot
.984 .04278 Mdot
.984 .04278 Mdot
.984 .04419 Mdot
.984 .0442 Mdot
.984 .0443 Mdot
.984 .0443 Mdot
.984 .04432 Mdot
.984 .04438 Mdot
.984 .04463 Mdot
.984 .04466 Mdot
.984 .04467 Mdot
.984 .04478 Mdot
.984 .04489 Mdot
.984 .04489 Mdot
.984 .04494 Mdot
.984 .04497 Mdot
.984 .04588 Mdot
.984 .0461 Mdot
.984 .0462 Mdot
.984 .04635 Mdot
.984 .04689 Mdot
.984 .04692 Mdot
.984 .04709 Mdot
.984 .04712 Mdot
.984 .04716 Mdot
.984 .04795 Mdot
.984 .04841 Mdot
.984 .04843 Mdot
.984 .04895 Mdot
.984 .04915 Mdot
.984 .0492 Mdot
.984 .04941 Mdot
.984 .04985 Mdot
.984 .04988 Mdot
.984 .05041 Mdot
.984 .05057 Mdot
.984 .05063 Mdot
.984 .05074 Mdot
.984 .05077 Mdot
.984 .05161 Mdot
.984 .05193 Mdot
.984 .05213 Mdot
.984 .05216 Mdot
.984 .05309 Mdot
.984 .05329 Mdot
.984 .05355 Mdot
.984 .0545 Mdot
.984 .05571 Mdot
.984 .05637 Mdot
.984 .05645 Mdot
.984 .05646 Mdot
.984 .05658 Mdot
.984 .05799 Mdot
.984 .05804 Mdot
.984 .05837 Mdot
.984 .05861 Mdot
.984 .05863 Mdot
.984 .05864 Mdot
.984 .05894 Mdot
.984 .05917 Mdot
.984 .05919 Mdot
.984 .05961 Mdot
.984 .06233 Mdot
.984 .06304 Mdot
.984 .06318 Mdot
.984 .06365 Mdot
.984 .06436 Mdot
.984 .06456 Mdot
.984 .06519 Mdot
.984 .06523 Mdot
.984 .06574 Mdot
.984 .06627 Mdot
.984 .06642 Mdot
.984 .06651 Mdot
.984 .06671 Mdot
.984 .06682 Mdot
.984 .06683 Mdot
.984 .06874 Mdot
.984 .06882 Mdot
.984 .06901 Mdot
.984 .06911 Mdot
.984 .06942 Mdot
.984 .07113 Mdot
.984 .07176 Mdot
.984 .07391 Mdot
.984 .07602 Mdot
.984 .07772 Mdot
.984 .07809 Mdot
.984 .08012 Mdot
.984 .08077 Mdot
.984 .0814 Mdot
.984 .08318 Mdot
.984 .08473 Mdot
.984 .08674 Mdot
.984 .08676 Mdot
.984 .08828 Mdot
.984 .08856 Mdot
.984 .08962 Mdot
.984 .08973 Mdot
.984 .09025 Mdot
.984 .09046 Mdot
.984 .09195 Mdot
.984 .09386 Mdot
.984 .09528 Mdot
.984 .09623 Mdot
.984 .09701 Mdot
.984 .09701 Mdot
.984 .09753 Mdot
.984 .09816 Mdot
.984 .09936 Mdot
.984 .09969 Mdot
.984 .10027 Mdot
.984 .10029 Mdot
.984 .10075 Mdot
.984 .10087 Mdot
.984 .10218 Mdot
.984 .10308 Mdot
.984 .10353 Mdot
.984 .10405 Mdot
.984 .10406 Mdot
.984 .10549 Mdot
.984 .10619 Mdot
.984 .1091 Mdot
.984 .1098 Mdot
.984 .11026 Mdot
.984 .11054 Mdot
.984 .11084 Mdot
.984 .11386 Mdot
.984 .11445 Mdot
.984 .11477 Mdot
.984 .11574 Mdot
.984 .11576 Mdot
.984 .11624 Mdot
.984 .11944 Mdot
.984 .12129 Mdot
.984 .12129 Mdot
.984 .12231 Mdot
.984 .12392 Mdot
.984 .12636 Mdot
.984 .12641 Mdot
.984 .12656 Mdot
.984 .12674 Mdot
.984 .12675 Mdot
.984 .12684 Mdot
.984 .12705 Mdot
.984 .12721 Mdot
.984 .12794 Mdot
.984 .12806 Mdot
.984 .12808 Mdot
.984 .12846 Mdot
.984 .12887 Mdot
.984 .12887 Mdot
.984 .12904 Mdot
.984 .12908 Mdot
.984 .12914 Mdot
.984 .13112 Mdot
.984 .13241 Mdot
.984 .1332 Mdot
.984 .13333 Mdot
.984 .13353 Mdot
.984 .13402 Mdot
.984 .13408 Mdot
.984 .13452 Mdot
.984 .13493 Mdot
.984 .13599 Mdot
.984 .1361 Mdot
.984 .13611 Mdot
.984 .13672 Mdot
.984 .13683 Mdot
.984 .13694 Mdot
.984 .13754 Mdot
.984 .13767 Mdot
.984 .13834 Mdot
.984 .13976 Mdot
.984 .14006 Mdot
.984 .14137 Mdot
.984 .14139 Mdot
.984 .14144 Mdot
.984 .14233 Mdot
.984 .14329 Mdot
.984 .14399 Mdot
.984 .14415 Mdot
.984 .14416 Mdot
.984 .14466 Mdot
.984 .1449 Mdot
.984 .14615 Mdot
.984 .14645 Mdot
.984 .14656 Mdot
.984 .1473 Mdot
.984 .14824 Mdot
.984 .14843 Mdot
.984 .14845 Mdot
.984 .14897 Mdot
.984 .14917 Mdot
.984 .14957 Mdot
.984 .14969 Mdot
.984 .15026 Mdot
.984 .15153 Mdot
.984 .15261 Mdot
.984 .15372 Mdot
.984 .15443 Mdot
.984 .15454 Mdot
.984 .15494 Mdot
.984 .15499 Mdot
.984 .15639 Mdot
.984 .15675 Mdot
.984 .15726 Mdot
.984 .15726 Mdot
.984 .15774 Mdot
.984 .15807 Mdot
.984 .15812 Mdot
.984 .15845 Mdot
.984 .15935 Mdot
.984 .15959 Mdot
.984 .16263 Mdot
.984 .16449 Mdot
.984 .16631 Mdot
.984 .16678 Mdot
.984 .16833 Mdot
.984 .16905 Mdot
.984 .16932 Mdot
.984 .16938 Mdot
.984 .16975 Mdot
.984 .17003 Mdot
.984 .17028 Mdot
.984 .1741 Mdot
.984 .17457 Mdot
.984 .17475 Mdot
.984 .17587 Mdot
.984 .17669 Mdot
.984 .17676 Mdot
.984 .17677 Mdot
.984 .17779 Mdot
.984 .17857 Mdot
.984 .17866 Mdot
.984 .17926 Mdot
.984 .18006 Mdot
.984 .1806 Mdot
.984 .18197 Mdot
.984 .18213 Mdot
.984 .18545 Mdot
.984 .18562 Mdot
.984 .18618 Mdot
.984 .18859 Mdot
.984 .18923 Mdot
.984 .19073 Mdot
.984 .19158 Mdot
.984 .19205 Mdot
.984 .19245 Mdot
.984 .19276 Mdot
.984 .19361 Mdot
.984 .19361 Mdot
.984 .19468 Mdot
.984 .19536 Mdot
.984 .19598 Mdot
.984 .19662 Mdot
.984 .19773 Mdot
.984 .1983 Mdot
.984 .19873 Mdot
.984 .19886 Mdot
.984 .19897 Mdot
.984 .19941 Mdot
.984 .19978 Mdot
.984 .20035 Mdot
.984 .20052 Mdot
.984 .20069 Mdot
.984 .20226 Mdot
.984 .20276 Mdot
.984 .20305 Mdot
.984 .20372 Mdot
.984 .20408 Mdot
.984 .20412 Mdot
.984 .20432 Mdot
.984 .20447 Mdot
.984 .208 Mdot
.984 .20922 Mdot
.984 .2094 Mdot
.984 .21036 Mdot
.984 .21049 Mdot
.984 .21061 Mdot
.984 .21124 Mdot
.984 .21157 Mdot
.984 .21257 Mdot
.984 .21311 Mdot
.984 .2149 Mdot
.984 .21563 Mdot
.984 .21765 Mdot
.984 .21809 Mdot
.984 .21866 Mdot
.984 .21883 Mdot
.984 .21992 Mdot
.984 .22011 Mdot
.984 .22057 Mdot
.984 .22281 Mdot
.984 .22414 Mdot
.984 .22443 Mdot
.984 .22458 Mdot
.984 .22539 Mdot
.984 .22644 Mdot
.984 .22702 Mdot
.984 .23205 Mdot
.984 .23259 Mdot
.984 .23317 Mdot
.984 .23368 Mdot
.984 .23551 Mdot
.984 .23904 Mdot
.984 .23949 Mdot
.984 .2402 Mdot
.984 .24276 Mdot
.984 .24297 Mdot
.984 .24492 Mdot
.984 .24598 Mdot
.984 .24651 Mdot
.984 .24853 Mdot
.984 .24902 Mdot
.984 .24913 Mdot
.984 .25036 Mdot
.984 .25047 Mdot
.984 .25275 Mdot
.984 .25294 Mdot
.984 .25342 Mdot
.984 .25394 Mdot
.984 .25411 Mdot
.984 .2556 Mdot
.984 .25596 Mdot
.984 .25788 Mdot
.984 .25865 Mdot
.984 .26069 Mdot
.984 .26195 Mdot
.984 .26369 Mdot
.984 .26677 Mdot
.984 .26681 Mdot
.984 .26789 Mdot
.984 .2681 Mdot
.984 .26859 Mdot
.984 .27137 Mdot
.984 .27221 Mdot
.984 .27538 Mdot
.984 .2757 Mdot
.984 .27698 Mdot
.984 .27726 Mdot
.984 .27786 Mdot
.984 .27839 Mdot
.984 .27901 Mdot
.984 .27987 Mdot
.984 .27994 Mdot
.984 .28002 Mdot
.984 .28018 Mdot
.984 .28155 Mdot
.984 .28226 Mdot
.984 .28433 Mdot
.984 .28557 Mdot
.984 .28604 Mdot
.984 .28767 Mdot
.984 .28784 Mdot
.984 .29199 Mdot
.984 .29263 Mdot
.984 .29419 Mdot
.984 .29429 Mdot
.984 .29432 Mdot
.984 .29474 Mdot
.984 .29502 Mdot
.984 .29575 Mdot
.984 .29697 Mdot
.984 .29698 Mdot
.984 .2972 Mdot
.984 .29817 Mdot
.984 .29847 Mdot
.984 .29904 Mdot
.984 .29975 Mdot
.984 .30027 Mdot
.984 .30127 Mdot
.984 .30161 Mdot
.984 .30207 Mdot
.984 .30263 Mdot
.984 .30367 Mdot
.984 .30445 Mdot
.984 .30462 Mdot
.984 .30627 Mdot
.984 .30632 Mdot
.984 .30686 Mdot
.984 .30762 Mdot
.984 .30797 Mdot
.984 .3093 Mdot
.984 .31018 Mdot
.984 .3111 Mdot
.984 .31162 Mdot
.984 .31163 Mdot
.984 .31306 Mdot
.984 .31414 Mdot
.984 .31433 Mdot
.984 .31539 Mdot
.984 .31593 Mdot
.984 .31686 Mdot
.984 .31689 Mdot
.984 .31696 Mdot
.984 .31698 Mdot
.984 .31991 Mdot
.984 .32083 Mdot
.984 .32096 Mdot
.984 .32275 Mdot
.984 .32308 Mdot
.984 .32385 Mdot
.984 .32447 Mdot
.984 .32449 Mdot
.984 .32522 Mdot
.984 .32811 Mdot
.984 .32947 Mdot
.984 .33017 Mdot
.984 .33072 Mdot
.984 .33116 Mdot
.984 .33259 Mdot
.984 .33272 Mdot
.984 .33319 Mdot
.984 .33385 Mdot
.984 .33445 Mdot
.984 .33459 Mdot
.984 .33468 Mdot
.984 .3354 Mdot
.984 .33684 Mdot
.984 .33684 Mdot
.984 .33779 Mdot
.984 .33951 Mdot
.984 .34131 Mdot
.984 .34252 Mdot
.984 .34329 Mdot
.984 .34343 Mdot
.984 .34501 Mdot
.984 .34508 Mdot
.984 .34585 Mdot
.984 .34602 Mdot
.984 .34616 Mdot
.984 .34838 Mdot
.984 .34845 Mdot
.984 .34969 Mdot
.984 .35141 Mdot
.984 .35507 Mdot
.984 .35523 Mdot
.984 .35635 Mdot
.984 .35797 Mdot
.984 .35878 Mdot
.984 .35949 Mdot
.984 .36272 Mdot
.984 .36272 Mdot
.984 .36315 Mdot
.984 .36359 Mdot
.984 .36529 Mdot
.984 .36935 Mdot
.984 .3729 Mdot
.984 .37371 Mdot
.984 .37436 Mdot
.984 .37543 Mdot
.984 .37556 Mdot
.984 .37593 Mdot
.984 .37637 Mdot
.984 .37641 Mdot
.984 .37662 Mdot
.984 .37715 Mdot
.984 .37754 Mdot
.984 .37839 Mdot
.984 .37933 Mdot
.984 .37962 Mdot
.984 .37968 Mdot
.984 .38022 Mdot
.984 .38059 Mdot
.984 .3816 Mdot
.984 .38161 Mdot
.984 .38202 Mdot
.984 .38212 Mdot
.984 .38227 Mdot
.984 .38227 Mdot
.984 .38251 Mdot
.984 .38295 Mdot
.984 .38592 Mdot
.984 .38705 Mdot
.984 .38848 Mdot
.984 .38885 Mdot
.984 .38922 Mdot
.984 .39017 Mdot
.984 .39021 Mdot
.984 .39037 Mdot
.984 .39205 Mdot
.984 .39213 Mdot
.984 .39236 Mdot
.984 .39283 Mdot
.984 .39378 Mdot
.984 .39399 Mdot
.984 .39414 Mdot
.984 .39423 Mdot
.984 .39518 Mdot
.984 .39614 Mdot
.984 .39646 Mdot
.984 .39651 Mdot
.984 .39679 Mdot
.984 .39863 Mdot
.984 .39888 Mdot
.984 .39893 Mdot
.984 .40028 Mdot
.984 .40035 Mdot
.984 .40059 Mdot
.984 .40086 Mdot
.984 .40226 Mdot
.984 .40254 Mdot
.984 .40412 Mdot
.984 .40498 Mdot
.984 .40572 Mdot
.984 .40649 Mdot
.984 .40738 Mdot
.984 .40771 Mdot
.984 .40807 Mdot
.984 .40962 Mdot
.984 .41105 Mdot
.984 .4111 Mdot
.984 .41122 Mdot
.984 .41323 Mdot
.984 .41393 Mdot
.984 .41399 Mdot
.984 .41539 Mdot
.984 .41694 Mdot
.984 .41731 Mdot
.984 .41734 Mdot
.984 .41802 Mdot
.984 .41846 Mdot
.984 .41898 Mdot
.984 .42087 Mdot
.984 .42108 Mdot
.984 .42129 Mdot
.984 .42175 Mdot
.984 .42242 Mdot
.984 .42266 Mdot
.984 .4236 Mdot
.984 .42409 Mdot
.984 .42427 Mdot
.984 .42459 Mdot
.984 .42575 Mdot
.984 .42634 Mdot
.984 .42675 Mdot
.984 .4268 Mdot
.984 .4273 Mdot
.984 .42753 Mdot
.984 .42793 Mdot
.984 .42835 Mdot
.984 .42863 Mdot
.984 .42922 Mdot
.984 .42948 Mdot
.984 .4307 Mdot
.984 .43155 Mdot
.984 .43159 Mdot
.984 .43344 Mdot
.984 .43354 Mdot
.984 .43572 Mdot
.984 .437 Mdot
.984 .43791 Mdot
.984 .43807 Mdot
.984 .43955 Mdot
.984 .43978 Mdot
.984 .43982 Mdot
.984 .44063 Mdot
.984 .44073 Mdot
.984 .44365 Mdot
.984 .44439 Mdot
.984 .44543 Mdot
.984 .44544 Mdot
.984 .44641 Mdot
.984 .4471 Mdot
.984 .44715 Mdot
.984 .4472 Mdot
.984 .44788 Mdot
.984 .44969 Mdot
.984 .45018 Mdot
.984 .45103 Mdot
.984 .45452 Mdot
.984 .45629 Mdot
.984 .45802 Mdot
.984 .45994 Mdot
.984 .46348 Mdot
.984 .46439 Mdot
.984 .46482 Mdot
.984 .46645 Mdot
.984 .46736 Mdot
.984 .46738 Mdot
.984 .46874 Mdot
.984 .46925 Mdot
.984 .46935 Mdot
.984 .47006 Mdot
.984 .47059 Mdot
.984 .47082 Mdot
.984 .47104 Mdot
.984 .47209 Mdot
.984 .47219 Mdot
.984 .47228 Mdot
.984 .47356 Mdot
.984 .47536 Mdot
.984 .47539 Mdot
.984 .47729 Mdot
.984 .47813 Mdot
.984 .47866 Mdot
.984 .47899 Mdot
.984 .47931 Mdot
.984 .48134 Mdot
.984 .48283 Mdot
.984 .48295 Mdot
.984 .48297 Mdot
.984 .48391 Mdot
.984 .4841 Mdot
.984 .48479 Mdot
.984 .48554 Mdot
.984 .4856 Mdot
.984 .48601 Mdot
.984 .48617 Mdot
.984 .48632 Mdot
.984 .48739 Mdot
.984 .48861 Mdot
.984 .48879 Mdot
.984 .48889 Mdot
.984 .48973 Mdot
.984 .49047 Mdot
.984 .49211 Mdot
.984 .49237 Mdot
.984 .49269 Mdot
.984 .4964 Mdot
.984 .49657 Mdot
.984 .498 Mdot
.984 .49828 Mdot
.984 .49923 Mdot
.984 .49966 Mdot
.984 .49972 Mdot
.984 .50114 Mdot
.984 .50314 Mdot
.984 .50319 Mdot
.984 .50355 Mdot
.984 .50423 Mdot
.984 .50452 Mdot
.984 .50498 Mdot
.984 .50565 Mdot
.984 .5063 Mdot
.984 .50666 Mdot
.984 .50666 Mdot
.984 .50746 Mdot
.984 .50755 Mdot
.984 .50801 Mdot
.984 .50819 Mdot
.984 .50876 Mdot
.984 .50913 Mdot
.984 .50939 Mdot
.984 .50989 Mdot
.984 .51095 Mdot
.984 .51121 Mdot
.984 .51122 Mdot
.984 .51145 Mdot
.984 .51173 Mdot
.984 .5125 Mdot
.984 .51288 Mdot
.984 .51394 Mdot
.984 .51394 Mdot
.984 .51432 Mdot
.984 .51489 Mdot
.984 .51534 Mdot
.984 .51586 Mdot
.984 .51605 Mdot
.984 .51637 Mdot
.984 .51668 Mdot
.984 .51755 Mdot
.984 .5184 Mdot
.984 .51904 Mdot
.984 .51924 Mdot
.984 .5194 Mdot
.984 .51952 Mdot
.984 .52005 Mdot
.984 .5203 Mdot
.984 .5206 Mdot
.984 .52094 Mdot
.984 .52144 Mdot
.984 .5217 Mdot
.984 .52194 Mdot
.984 .52195 Mdot
.984 .52199 Mdot
.984 .52253 Mdot
.984 .52424 Mdot
.984 .52479 Mdot
.984 .52495 Mdot
.984 .52538 Mdot
.984 .52632 Mdot
.984 .52679 Mdot
.984 .52684 Mdot
.984 .52687 Mdot
.984 .5269 Mdot
.984 .52718 Mdot
.984 .52739 Mdot
.984 .52787 Mdot
.984 .53068 Mdot
.984 .53085 Mdot
.984 .53092 Mdot
.984 .53231 Mdot
.984 .53288 Mdot
.984 .53397 Mdot
.984 .53422 Mdot
.984 .53497 Mdot
.984 .53545 Mdot
.984 .53551 Mdot
.984 .53568 Mdot
.984 .53584 Mdot
.984 .5359 Mdot
.984 .53667 Mdot
.984 .53707 Mdot
.984 .53711 Mdot
.984 .53809 Mdot
.984 .53843 Mdot
.984 .53905 Mdot
.984 .53912 Mdot
.984 .54017 Mdot
.984 .54144 Mdot
.984 .54218 Mdot
.984 .54236 Mdot
.984 .54253 Mdot
.984 .5443 Mdot
.984 .54463 Mdot
.984 .54488 Mdot
.984 .54493 Mdot
.984 .54502 Mdot
.984 .54544 Mdot
.984 .54613 Mdot
.984 .54634 Mdot
.984 .54668 Mdot
.984 .54673 Mdot
.984 .54704 Mdot
.984 .54767 Mdot
.984 .54789 Mdot
.984 .54845 Mdot
.984 .54925 Mdot
.984 .54958 Mdot
.984 .54964 Mdot
.984 .55002 Mdot
.984 .55109 Mdot
.984 .55114 Mdot
.984 .55224 Mdot
.984 .55235 Mdot
.984 .55252 Mdot
.984 .55263 Mdot
.984 .55277 Mdot
.984 .55297 Mdot
.984 .55314 Mdot
.984 .55386 Mdot
.984 .55406 Mdot
.984 .55438 Mdot
.984 .55464 Mdot
.984 .55473 Mdot
.984 .55525 Mdot
.984 .55589 Mdot
.984 .55661 Mdot
.984 .55678 Mdot
.984 .55683 Mdot
.984 .55786 Mdot
.984 .55827 Mdot
.984 .55866 Mdot
.984 .56018 Mdot
.984 .5613 Mdot
.984 .56138 Mdot
.984 .56187 Mdot
.984 .56246 Mdot
.984 .56299 Mdot
.984 .56441 Mdot
.984 .56484 Mdot
.984 .56485 Mdot
.984 .56508 Mdot
.984 .56509 Mdot
.984 .56523 Mdot
.984 .56533 Mdot
.984 .56574 Mdot
.984 .56575 Mdot
.984 .56673 Mdot
.984 .5671 Mdot
.984 .56761 Mdot
.984 .56767 Mdot
.984 .56794 Mdot
.984 .56827 Mdot
.984 .56869 Mdot
.984 .56884 Mdot
.984 .56935 Mdot
.984 .56963 Mdot
.984 .56999 Mdot
.984 .57048 Mdot
.984 .57067 Mdot
.984 .57071 Mdot
.984 .57111 Mdot
.984 .57144 Mdot
.984 .57156 Mdot
.984 .5717 Mdot
.984 .57189 Mdot
.984 .57251 Mdot
.984 .57308 Mdot
.984 .5736 Mdot
.984 .57379 Mdot
.984 .57452 Mdot
.984 .57497 Mdot
.984 .57665 Mdot
.984 .57678 Mdot
.984 .57705 Mdot
.984 .57714 Mdot
.984 .57813 Mdot
.984 .57822 Mdot
.984 .57998 Mdot
.984 .57999 Mdot
.984 .58013 Mdot
.984 .5805 Mdot
.984 .58089 Mdot
.984 .58102 Mdot
.984 .58126 Mdot
.984 .58159 Mdot
.984 .5819 Mdot
.984 .5819 Mdot
.984 .58211 Mdot
.984 .58237 Mdot
.984 .58372 Mdot
.984 .58418 Mdot
.984 .58425 Mdot
.984 .58466 Mdot
.984 .5852 Mdot
.984 .58561 Mdot
.984 .58626 Mdot
.984 .58643 Mdot
.984 .58697 Mdot
.984 .58707 Mdot
.984 .58752 Mdot
.984 .58926 Mdot
.984 .58934 Mdot
.984 .58937 Mdot
.984 .58998 Mdot
.984 .59009 Mdot
.984 .59023 Mdot
.984 .59036 Mdot
.984 .5909 Mdot
.984 .59094 Mdot
.984 .59184 Mdot
.984 .59209 Mdot
.984 .59216 Mdot
.984 .59224 Mdot
.984 .59226 Mdot
.984 .59263 Mdot
.984 .59266 Mdot
.984 .59341 Mdot
.984 .59348 Mdot
.984 .59377 Mdot
.984 .59383 Mdot
.984 .59392 Mdot
.984 .59437 Mdot
.984 .59448 Mdot
.984 .5946 Mdot
.984 .59486 Mdot
.984 .59508 Mdot
.984 .59514 Mdot
.984 .59534 Mdot
.984 .59568 Mdot
.984 .59571 Mdot
.984 .59574 Mdot
.984 .5958 Mdot
.984 .59583 Mdot
.984 .59619 Mdot
.984 .59619 Mdot
.984 .59633 Mdot
.984 .59659 Mdot
.984 .59672 Mdot
.984 .59697 Mdot
.984 .59701 Mdot
.984 .59706 Mdot
.984 .59726 Mdot
.984 .59731 Mdot
.984 .59748 Mdot
.984 .59763 Mdot
.984 .59767 Mdot
.984 .59771 Mdot
.984 .59786 Mdot
.984 .59811 Mdot
.984 .59825 Mdot
.984 .59835 Mdot
.984 .5984 Mdot
.984 .59841 Mdot
.984 .5986 Mdot
.984 .59897 Mdot
.984 .59947 Mdot
.984 .59962 Mdot
.984 .59966 Mdot
.984 .59981 Mdot
.984 .59982 Mdot
.984 .59995 Mdot
.984 .59995 Mdot
.984 .59997 Mdot
.984 .59997 Mdot
.984 .60005 Mdot
.984 .6001 Mdot
.984 .60011 Mdot
.984 .60016 Mdot
.984 .60024 Mdot
.984 .60045 Mdot
.984 .60045 Mdot
.984 .60047 Mdot
.984 .60049 Mdot
.984 .60049 Mdot
.984 .60063 Mdot
.984 .60064 Mdot
.984 .60068 Mdot
.984 .60076 Mdot
.984 .60085 Mdot
.984 .60092 Mdot
.984 .60101 Mdot
.984 .60101 Mdot
.984 .60102 Mdot
.984 .60102 Mdot
.984 .60103 Mdot
.984 .60106 Mdot
.984 .60111 Mdot
.984 .60111 Mdot
.984 .60116 Mdot
.984 .60116 Mdot
.984 .60124 Mdot
.984 .60124 Mdot
.984 .60126 Mdot
.984 .60129 Mdot
.984 .6013 Mdot
.984 .60133 Mdot
.984 .60138 Mdot
.984 .60139 Mdot
.984 .60139 Mdot
.984 .60139 Mdot
.984 .6014 Mdot
.984 .60141 Mdot
.984 .60142 Mdot
.984 .60143 Mdot
.984 .60143 Mdot
.984 .60144 Mdot
.986 .02128 Mdot
.986 .02129 Mdot
.986 .02138 Mdot
.986 .02145 Mdot
.986 .02146 Mdot
.986 .02146 Mdot
.986 .02146 Mdot
.986 .0215 Mdot
.986 .02153 Mdot
.986 .02154 Mdot
.986 .02157 Mdot
.986 .02163 Mdot
.986 .02184 Mdot
.986 .02185 Mdot
.986 .02189 Mdot
.986 .02197 Mdot
.986 .02207 Mdot
.986 .02223 Mdot
.986 .02237 Mdot
.986 .02254 Mdot
.986 .02282 Mdot
.986 .02286 Mdot
.986 .02337 Mdot
.986 .02343 Mdot
.986 .02356 Mdot
.986 .02367 Mdot
.986 .02398 Mdot
.986 .024 Mdot
.986 .0244 Mdot
.986 .02463 Mdot
.986 .02479 Mdot
.986 .02516 Mdot
.986 .02516 Mdot
.986 .02555 Mdot
.986 .02574 Mdot
.986 .02585 Mdot
.986 .02591 Mdot
.986 .02632 Mdot
.986 .02664 Mdot
.986 .02715 Mdot
.986 .02731 Mdot
.986 .02773 Mdot
.986 .0282 Mdot
.986 .02829 Mdot
.986 .0283 Mdot
.986 .02918 Mdot
.986 .02946 Mdot
.986 .02982 Mdot
.986 .03022 Mdot
.986 .03094 Mdot
.986 .031 Mdot
.986 .03109 Mdot
.986 .03153 Mdot
.986 .03178 Mdot
.986 .03232 Mdot
.986 .03233 Mdot
.986 .03372 Mdot
.986 .03415 Mdot
.986 .03455 Mdot
.986 .03455 Mdot
.986 .03579 Mdot
.986 .03696 Mdot
.986 .03824 Mdot
.986 .03855 Mdot
.986 .03906 Mdot
.986 .03921 Mdot
.986 .04062 Mdot
.986 .04063 Mdot
.986 .04101 Mdot
.986 .04106 Mdot
.986 .04128 Mdot
.986 .04131 Mdot
.986 .04132 Mdot
.986 .04133 Mdot
.986 .04133 Mdot
.986 .04147 Mdot
.986 .04159 Mdot
.986 .0416 Mdot
.986 .04162 Mdot
.986 .04173 Mdot
.986 .04199 Mdot
.986 .04238 Mdot
.986 .04273 Mdot
.986 .04278 Mdot
.986 .04283 Mdot
.986 .043 Mdot
.986 .0433 Mdot
.986 .04352 Mdot
.986 .04364 Mdot
.986 .0437 Mdot
.986 .04433 Mdot
.986 .04487 Mdot
.986 .04489 Mdot
.986 .04523 Mdot
.986 .04552 Mdot
.986 .04661 Mdot
.986 .04677 Mdot
.986 .04699 Mdot
.986 .04731 Mdot
.986 .04873 Mdot
.986 .04897 Mdot
.986 .04948 Mdot
.986 .04989 Mdot
.986 .05074 Mdot
.986 .05108 Mdot
.986 .05116 Mdot
.986 .05123 Mdot
.986 .05124 Mdot
.986 .05148 Mdot
.986 .05239 Mdot
.986 .05273 Mdot
.986 .05359 Mdot
.986 .05424 Mdot
.986 .05459 Mdot
.986 .05563 Mdot
.986 .05564 Mdot
.986 .05596 Mdot
.986 .05701 Mdot
.986 .05713 Mdot
.986 .05735 Mdot
.986 .05787 Mdot
.986 .05811 Mdot
.986 .05831 Mdot
.986 .05854 Mdot
.986 .05918 Mdot
.986 .0598 Mdot
.986 .06009 Mdot
.986 .06058 Mdot
.986 .0613 Mdot
.986 .0616 Mdot
.986 .06326 Mdot
.986 .06335 Mdot
.986 .06346 Mdot
.986 .06384 Mdot
.986 .06388 Mdot
.986 .06404 Mdot
.986 .06423 Mdot
.986 .06507 Mdot
.986 .06511 Mdot
.986 .06548 Mdot
.986 .0665 Mdot
.986 .06709 Mdot
.986 .06728 Mdot
.986 .06762 Mdot
.986 .06767 Mdot
.986 .06959 Mdot
.986 .06976 Mdot
.986 .07027 Mdot
.986 .071 Mdot
.986 .07118 Mdot
.986 .07187 Mdot
.986 .07207 Mdot
.986 .07252 Mdot
.986 .07263 Mdot
.986 .07343 Mdot
.986 .07492 Mdot
.986 .07564 Mdot
.986 .07707 Mdot
.986 .07766 Mdot
.986 .07789 Mdot
.986 .07811 Mdot
.986 .07823 Mdot
.986 .07987 Mdot
.986 .08081 Mdot
.986 .08092 Mdot
.986 .08215 Mdot
.986 .08254 Mdot
.986 .08256 Mdot
.986 .08277 Mdot
.986 .08285 Mdot
.986 .08288 Mdot
.986 .08314 Mdot
.986 .08354 Mdot
.986 .08468 Mdot
.986 .08542 Mdot
.986 .0872 Mdot
.986 .08793 Mdot
.986 .08806 Mdot
.986 .08969 Mdot
.986 .09116 Mdot
.986 .09118 Mdot
.986 .09136 Mdot
.986 .09309 Mdot
.986 .09343 Mdot
.986 .09355 Mdot
.986 .09411 Mdot
.986 .09454 Mdot
.986 .09519 Mdot
.986 .09557 Mdot
.986 .09576 Mdot
.986 .09667 Mdot
.986 .09677 Mdot
.986 .09697 Mdot
.986 .09766 Mdot
.986 .09788 Mdot
.986 .09809 Mdot
.986 .0994 Mdot
.986 .09958 Mdot
.986 .10003 Mdot
.986 .10008 Mdot
.986 .10025 Mdot
.986 .10145 Mdot
.986 .10225 Mdot
.986 .10251 Mdot
.986 .10286 Mdot
.986 .10392 Mdot
.986 .1048 Mdot
.986 .1059 Mdot
.986 .10593 Mdot
.986 .10765 Mdot
.986 .1078 Mdot
.986 .10812 Mdot
.986 .10837 Mdot
.986 .11 Mdot
.986 .11059 Mdot
.986 .11063 Mdot
.986 .11112 Mdot
.986 .11263 Mdot
.986 .1135 Mdot
.986 .11355 Mdot
.986 .11375 Mdot
.986 .1142 Mdot
.986 .11476 Mdot
.986 .11491 Mdot
.986 .11512 Mdot
.986 .11558 Mdot
.986 .1159 Mdot
.986 .11592 Mdot
.986 .11599 Mdot
.986 .11603 Mdot
.986 .11607 Mdot
.986 .11607 Mdot
.986 .11658 Mdot
.986 .11702 Mdot
.986 .11705 Mdot
.986 .11714 Mdot
.986 .11755 Mdot
.986 .11846 Mdot
.986 .11911 Mdot
.986 .1192 Mdot
.986 .11989 Mdot
.986 .12085 Mdot
.986 .12115 Mdot
.986 .12132 Mdot
.986 .12151 Mdot
.986 .12211 Mdot
.986 .12318 Mdot
.986 .12354 Mdot
.986 .12399 Mdot
.986 .12441 Mdot
.986 .12464 Mdot
.986 .1269 Mdot
.986 .12774 Mdot
.986 .12883 Mdot
.986 .12892 Mdot
.986 .13013 Mdot
.986 .13116 Mdot
.986 .13229 Mdot
.986 .13503 Mdot
.986 .1356 Mdot
.986 .13635 Mdot
.986 .13641 Mdot
.986 .13684 Mdot
.986 .13753 Mdot
.986 .13824 Mdot
.986 .13857 Mdot
.986 .13982 Mdot
.986 .14106 Mdot
.986 .14255 Mdot
.986 .14334 Mdot
.986 .14342 Mdot
.986 .14363 Mdot
.986 .14519 Mdot
.986 .14536 Mdot
.986 .14578 Mdot
.986 .14591 Mdot
.986 .14597 Mdot
.986 .14664 Mdot
.986 .14684 Mdot
.986 .14861 Mdot
.986 .14961 Mdot
.986 .1508 Mdot
.986 .1511 Mdot
.986 .15133 Mdot
.986 .15136 Mdot
.986 .15183 Mdot
.986 .15203 Mdot
.986 .15219 Mdot
.986 .15445 Mdot
.986 .15518 Mdot
.986 .15538 Mdot
.986 .15613 Mdot
.986 .15656 Mdot
.986 .15955 Mdot
.986 .15998 Mdot
.986 .16039 Mdot
.986 .16178 Mdot
.986 .16272 Mdot
.986 .163 Mdot
.986 .16382 Mdot
.986 .16546 Mdot
.986 .16659 Mdot
.986 .1666 Mdot
.986 .16665 Mdot
.986 .16767 Mdot
.986 .1677 Mdot
.986 .17009 Mdot
.986 .1713 Mdot
.986 .17171 Mdot
.986 .17246 Mdot
.986 .17423 Mdot
.986 .1743 Mdot
.986 .17507 Mdot
.986 .17573 Mdot
.986 .17585 Mdot
.986 .1765 Mdot
.986 .1772 Mdot
.986 .17867 Mdot
.986 .18078 Mdot
.986 .18175 Mdot
.986 .18342 Mdot
.986 .18365 Mdot
.986 .18427 Mdot
.986 .18579 Mdot
.986 .18585 Mdot
.986 .18683 Mdot
.986 .19238 Mdot
.986 .19269 Mdot
.986 .19304 Mdot
.986 .19334 Mdot
.986 .19362 Mdot
.986 .19431 Mdot
.986 .19445 Mdot
.986 .19496 Mdot
.986 .19552 Mdot
.986 .19562 Mdot
.986 .1965 Mdot
.986 .19774 Mdot
.986 .19841 Mdot
.986 .19853 Mdot
.986 .19975 Mdot
.986 .20045 Mdot
.986 .20093 Mdot
.986 .20306 Mdot
.986 .20312 Mdot
.986 .2042 Mdot
.986 .20446 Mdot
.986 .20506 Mdot
.986 .20568 Mdot
.986 .20678 Mdot
.986 .20693 Mdot
.986 .20792 Mdot
.986 .20882 Mdot
.986 .20889 Mdot
.986 .20981 Mdot
.986 .21005 Mdot
.986 .21094 Mdot
.986 .21186 Mdot
.986 .21254 Mdot
.986 .2132 Mdot
.986 .21375 Mdot
.986 .21412 Mdot
.986 .21497 Mdot
.986 .21542 Mdot
.986 .21775 Mdot
.986 .21833 Mdot
.986 .22056 Mdot
.986 .22097 Mdot
.986 .2212 Mdot
.986 .22126 Mdot
.986 .22152 Mdot
.986 .22265 Mdot
.986 .22271 Mdot
.986 .22301 Mdot
.986 .22357 Mdot
.986 .22474 Mdot
.986 .2255 Mdot
.986 .22557 Mdot
.986 .23031 Mdot
.986 .23191 Mdot
.986 .23259 Mdot
.986 .23287 Mdot
.986 .23465 Mdot
.986 .23588 Mdot
.986 .23708 Mdot
.986 .23714 Mdot
.986 .23809 Mdot
.986 .23862 Mdot
.986 .23894 Mdot
.986 .23958 Mdot
.986 .23967 Mdot
.986 .24036 Mdot
.986 .24074 Mdot
.986 .24122 Mdot
.986 .24165 Mdot
.986 .2418 Mdot
.986 .24451 Mdot
.986 .24586 Mdot
.986 .24728 Mdot
.986 .24876 Mdot
.986 .24895 Mdot
.986 .2491 Mdot
.986 .25017 Mdot
.986 .25103 Mdot
.986 .25289 Mdot
.986 .25339 Mdot
.986 .25407 Mdot
.986 .25414 Mdot
.986 .25469 Mdot
.986 .25478 Mdot
.986 .25503 Mdot
.986 .25514 Mdot
.986 .25569 Mdot
.986 .25593 Mdot
.986 .25648 Mdot
.986 .25714 Mdot
.986 .25945 Mdot
.986 .25975 Mdot
.986 .26021 Mdot
.986 .26061 Mdot
.986 .26288 Mdot
.986 .26349 Mdot
.986 .26514 Mdot
.986 .26758 Mdot
.986 .26824 Mdot
.986 .26825 Mdot
.986 .27044 Mdot
.986 .27083 Mdot
.986 .27282 Mdot
.986 .27541 Mdot
.986 .27569 Mdot
.986 .27791 Mdot
.986 .279 Mdot
.986 .27922 Mdot
.986 .28003 Mdot
.986 .28011 Mdot
.986 .28063 Mdot
.986 .28086 Mdot
.986 .28357 Mdot
.986 .2838 Mdot
.986 .2857 Mdot
.986 .28672 Mdot
.986 .28673 Mdot
.986 .28706 Mdot
.986 .28744 Mdot
.986 .28868 Mdot
.986 .28943 Mdot
.986 .28995 Mdot
.986 .29183 Mdot
.986 .29283 Mdot
.986 .29293 Mdot
.986 .29349 Mdot
.986 .29421 Mdot
.986 .29487 Mdot
.986 .29611 Mdot
.986 .29639 Mdot
.986 .29698 Mdot
.986 .29783 Mdot
.986 .29893 Mdot
.986 .29956 Mdot
.986 .30018 Mdot
.986 .30132 Mdot
.986 .30302 Mdot
.986 .30355 Mdot
.986 .30391 Mdot
.986 .3042 Mdot
.986 .30442 Mdot
.986 .30568 Mdot
.986 .30585 Mdot
.986 .3059 Mdot
.986 .30633 Mdot
.986 .30637 Mdot
.986 .3097 Mdot
.986 .30979 Mdot
.986 .31106 Mdot
.986 .31162 Mdot
.986 .31168 Mdot
.986 .31194 Mdot
.986 .31269 Mdot
.986 .31366 Mdot
.986 .31543 Mdot
.986 .3159 Mdot
.986 .31662 Mdot
.986 .31799 Mdot
.986 .31826 Mdot
.986 .31906 Mdot
.986 .31982 Mdot
.986 .32048 Mdot
.986 .32105 Mdot
.986 .32209 Mdot
.986 .32217 Mdot
.986 .32274 Mdot
.986 .32403 Mdot
.986 .32522 Mdot
.986 .32651 Mdot
.986 .32689 Mdot
.986 .3273 Mdot
.986 .32803 Mdot
.986 .32818 Mdot
.986 .32884 Mdot
.986 .32934 Mdot
.986 .33326 Mdot
.986 .33484 Mdot
.986 .33495 Mdot
.986 .33627 Mdot
.986 .33645 Mdot
.986 .33664 Mdot
.986 .34032 Mdot
.986 .34263 Mdot
.986 .34276 Mdot
.986 .34328 Mdot
.986 .34448 Mdot
.986 .34577 Mdot
.986 .34595 Mdot
.986 .34634 Mdot
.986 .34689 Mdot
.986 .3481 Mdot
.986 .34895 Mdot
.986 .34901 Mdot
.986 .34919 Mdot
.986 .34928 Mdot
.986 .34938 Mdot
.986 .35073 Mdot
.986 .35187 Mdot
.986 .35195 Mdot
.986 .35218 Mdot
.986 .35259 Mdot
.986 .35318 Mdot
.986 .35323 Mdot
.986 .35559 Mdot
.986 .35676 Mdot
.986 .35726 Mdot
.986 .35743 Mdot
.986 .35751 Mdot
.986 .35767 Mdot
.986 .35928 Mdot
.986 .35957 Mdot
.986 .36168 Mdot
.986 .36173 Mdot
.986 .36194 Mdot
.986 .36248 Mdot
.986 .36293 Mdot
.986 .36342 Mdot
.986 .36412 Mdot
.986 .36421 Mdot
.986 .36492 Mdot
.986 .36502 Mdot
.986 .36552 Mdot
.986 .36622 Mdot
.986 .36684 Mdot
.986 .36765 Mdot
.986 .36785 Mdot
.986 .36803 Mdot
.986 .36855 Mdot
.986 .36955 Mdot
.986 .36966 Mdot
.986 .37072 Mdot
.986 .3713 Mdot
.986 .37497 Mdot
.986 .37691 Mdot
.986 .37897 Mdot
.986 .37914 Mdot
.986 .37916 Mdot
.986 .38166 Mdot
.986 .38187 Mdot
.986 .38326 Mdot
.986 .38405 Mdot
.986 .38436 Mdot
.986 .38482 Mdot
.986 .3873 Mdot
.986 .3881 Mdot
.986 .38986 Mdot
.986 .39003 Mdot
.986 .39044 Mdot
.986 .39363 Mdot
.986 .39434 Mdot
.986 .39628 Mdot
.986 .39653 Mdot
.986 .3973 Mdot
.986 .39788 Mdot
.986 .3981 Mdot
.986 .39962 Mdot
.986 .39976 Mdot
.986 .40007 Mdot
.986 .40058 Mdot
.986 .40077 Mdot
.986 .40238 Mdot
.986 .40337 Mdot
.986 .40368 Mdot
.986 .40404 Mdot
.986 .40469 Mdot
.986 .40479 Mdot
.986 .40658 Mdot
.986 .40688 Mdot
.986 .40767 Mdot
.986 .40842 Mdot
.986 .40932 Mdot
.986 .41051 Mdot
.986 .41388 Mdot
.986 .41427 Mdot
.986 .41566 Mdot
.986 .41583 Mdot
.986 .4163 Mdot
.986 .41743 Mdot
.986 .4191 Mdot
.986 .41978 Mdot
.986 .42018 Mdot
.986 .42109 Mdot
.986 .42139 Mdot
.986 .42152 Mdot
.986 .42301 Mdot
.986 .42343 Mdot
.986 .42411 Mdot
.986 .42731 Mdot
.986 .42735 Mdot
.986 .42947 Mdot
.986 .43106 Mdot
.986 .43203 Mdot
.986 .43269 Mdot
.986 .43318 Mdot
.986 .43324 Mdot
.986 .43375 Mdot
.986 .43396 Mdot
.986 .43407 Mdot
.986 .43424 Mdot
.986 .43466 Mdot
.986 .43501 Mdot
.986 .43726 Mdot
.986 .43822 Mdot
.986 .43841 Mdot
.986 .43848 Mdot
.986 .43977 Mdot
.986 .43991 Mdot
.986 .44066 Mdot
.986 .44129 Mdot
.986 .44172 Mdot
.986 .44304 Mdot
.986 .44328 Mdot
.986 .44417 Mdot
.986 .44438 Mdot
.986 .44872 Mdot
.986 .44963 Mdot
.986 .45028 Mdot
.986 .45115 Mdot
.986 .4518 Mdot
.986 .45198 Mdot
.986 .45291 Mdot
.986 .45399 Mdot
.986 .45476 Mdot
.986 .45664 Mdot
.986 .45718 Mdot
.986 .45773 Mdot
.986 .4588 Mdot
.986 .45925 Mdot
.986 .46136 Mdot
.986 .46201 Mdot
.986 .46316 Mdot
.986 .46352 Mdot
.986 .4642 Mdot
.986 .46423 Mdot
.986 .46432 Mdot
.986 .46478 Mdot
.986 .46628 Mdot
.986 .46633 Mdot
.986 .46643 Mdot
.986 .46769 Mdot
.986 .4694 Mdot
.986 .47088 Mdot
.986 .47315 Mdot
.986 .4739 Mdot
.986 .47531 Mdot
.986 .47749 Mdot
.986 .47789 Mdot
.986 .47856 Mdot
.986 .47869 Mdot
.986 .47951 Mdot
.986 .47995 Mdot
.986 .48008 Mdot
.986 .48128 Mdot
.986 .4815 Mdot
.986 .48234 Mdot
.986 .48268 Mdot
.986 .48311 Mdot
.986 .48393 Mdot
.986 .48423 Mdot
.986 .48557 Mdot
.986 .48581 Mdot
.986 .48654 Mdot
.986 .48809 Mdot
.986 .48822 Mdot
.986 .48854 Mdot
.986 .49022 Mdot
.986 .49023 Mdot
.986 .49192 Mdot
.986 .49409 Mdot
.986 .49469 Mdot
.986 .49477 Mdot
.986 .49517 Mdot
.986 .49541 Mdot
.986 .49569 Mdot
.986 .49589 Mdot
.986 .49621 Mdot
.986 .49624 Mdot
.986 .4971 Mdot
.986 .4972 Mdot
.986 .49803 Mdot
.986 .49877 Mdot
.986 .49886 Mdot
.986 .49912 Mdot
.986 .50051 Mdot
.986 .50073 Mdot
.986 .50334 Mdot
.986 .50678 Mdot
.986 .50685 Mdot
.986 .50948 Mdot
.986 .50997 Mdot
.986 .51052 Mdot
.986 .51099 Mdot
.986 .51143 Mdot
.986 .5119 Mdot
.986 .51251 Mdot
.986 .51272 Mdot
.986 .51295 Mdot
.986 .51352 Mdot
.986 .51362 Mdot
.986 .51437 Mdot
.986 .51454 Mdot
.986 .51588 Mdot
.986 .5159 Mdot
.986 .5161 Mdot
.986 .51655 Mdot
.986 .51777 Mdot
.986 .51793 Mdot
.986 .51853 Mdot
.986 .51876 Mdot
.986 .51894 Mdot
.986 .51954 Mdot
.986 .52076 Mdot
.986 .52179 Mdot
.986 .52202 Mdot
.986 .5225 Mdot
.986 .52367 Mdot
.986 .52435 Mdot
.986 .5246 Mdot
.986 .5256 Mdot
.986 .52567 Mdot
.986 .52659 Mdot
.986 .52715 Mdot
.986 .52722 Mdot
.986 .52759 Mdot
.986 .52844 Mdot
.986 .52931 Mdot
.986 .53083 Mdot
.986 .53105 Mdot
.986 .53186 Mdot
.986 .53241 Mdot
.986 .53349 Mdot
.986 .53364 Mdot
.986 .53374 Mdot
.986 .53471 Mdot
.986 .53497 Mdot
.986 .53529 Mdot
.986 .53572 Mdot
.986 .53648 Mdot
.986 .53677 Mdot
.986 .53716 Mdot
.986 .5377 Mdot
.986 .53859 Mdot
.986 .53946 Mdot
.986 .53951 Mdot
.986 .53965 Mdot
.986 .54017 Mdot
.986 .54048 Mdot
.986 .54064 Mdot
.986 .54095 Mdot
.986 .54135 Mdot
.986 .54174 Mdot
.986 .5423 Mdot
.986 .54261 Mdot
.986 .54462 Mdot
.986 .54486 Mdot
.986 .54522 Mdot
.986 .54549 Mdot
.986 .54587 Mdot
.986 .54594 Mdot
.986 .54604 Mdot
.986 .5479 Mdot
.986 .54816 Mdot
.986 .54865 Mdot
.986 .54886 Mdot
.986 .54914 Mdot
.986 .54941 Mdot
.986 .54949 Mdot
.986 .54977 Mdot
.986 .54979 Mdot
.986 .55006 Mdot
.986 .55112 Mdot
.986 .5512 Mdot
.986 .55155 Mdot
.986 .55219 Mdot
.986 .55234 Mdot
.986 .55316 Mdot
.986 .55353 Mdot
.986 .5544 Mdot
.986 .55449 Mdot
.986 .55674 Mdot
.986 .5572 Mdot
.986 .55738 Mdot
.986 .55929 Mdot
.986 .55969 Mdot
.986 .56014 Mdot
.986 .56138 Mdot
.986 .56208 Mdot
.986 .56238 Mdot
.986 .56273 Mdot
.986 .5632 Mdot
.986 .56352 Mdot
.986 .5642 Mdot
.986 .56432 Mdot
.986 .56543 Mdot
.986 .5657 Mdot
.986 .56591 Mdot
.986 .5666 Mdot
.986 .56666 Mdot
.986 .56758 Mdot
.986 .56809 Mdot
.986 .56833 Mdot
.986 .56835 Mdot
.986 .56839 Mdot
.986 .56851 Mdot
.986 .569 Mdot
.986 .56908 Mdot
.986 .56973 Mdot
.986 .57008 Mdot
.986 .57043 Mdot
.986 .57052 Mdot
.986 .57092 Mdot
.986 .57106 Mdot
.986 .5722 Mdot
.986 .57347 Mdot
.986 .57464 Mdot
.986 .57539 Mdot
.986 .57584 Mdot
.986 .57587 Mdot
.986 .57675 Mdot
.986 .57684 Mdot
.986 .57707 Mdot
.986 .57722 Mdot
.986 .57735 Mdot
.986 .57765 Mdot
.986 .57807 Mdot
.986 .5782 Mdot
.986 .57821 Mdot
.986 .57837 Mdot
.986 .57889 Mdot
.986 .57902 Mdot
.986 .57949 Mdot
.986 .58003 Mdot
.986 .58032 Mdot
.986 .58042 Mdot
.986 .58049 Mdot
.986 .58071 Mdot
.986 .58103 Mdot
.986 .58109 Mdot
.986 .58121 Mdot
.986 .58126 Mdot
.986 .58162 Mdot
.986 .58167 Mdot
.986 .58173 Mdot
.986 .58192 Mdot
.986 .58197 Mdot
.986 .582 Mdot
.986 .5823 Mdot
.986 .5824 Mdot
.986 .58258 Mdot
.986 .58269 Mdot
.986 .58284 Mdot
.986 .58287 Mdot
.986 .58297 Mdot
.986 .58343 Mdot
.986 .58435 Mdot
.986 .58455 Mdot
.986 .58502 Mdot
.986 .58522 Mdot
.986 .58553 Mdot
.986 .58563 Mdot
.986 .58573 Mdot
.986 .58579 Mdot
.986 .58579 Mdot
.986 .5859 Mdot
.986 .58622 Mdot
.986 .58697 Mdot
.986 .58725 Mdot
.986 .58763 Mdot
.986 .58842 Mdot
.986 .58845 Mdot
.986 .58862 Mdot
.986 .58881 Mdot
.986 .58904 Mdot
.986 .58918 Mdot
.986 .58922 Mdot
.986 .58988 Mdot
.986 .59004 Mdot
.986 .5904 Mdot
.986 .59041 Mdot
.986 .59063 Mdot
.986 .59068 Mdot
.986 .59073 Mdot
.986 .59083 Mdot
.986 .59086 Mdot
.986 .59132 Mdot
.986 .59159 Mdot
.986 .59179 Mdot
.986 .59195 Mdot
.986 .59223 Mdot
.986 .59243 Mdot
.986 .59252 Mdot
.986 .59279 Mdot
.986 .59315 Mdot
.986 .59372 Mdot
.986 .59395 Mdot
.986 .59402 Mdot
.986 .59402 Mdot
.986 .59415 Mdot
.986 .59503 Mdot
.986 .59511 Mdot
.986 .59557 Mdot
.986 .59565 Mdot
.986 .59598 Mdot
.986 .59601 Mdot
.986 .59621 Mdot
.986 .5963 Mdot
.986 .5965 Mdot
.986 .59657 Mdot
.986 .59664 Mdot
.986 .59711 Mdot
.986 .59715 Mdot
.986 .59728 Mdot
.986 .59736 Mdot
.986 .59769 Mdot
.986 .59799 Mdot
.986 .5983 Mdot
.986 .5983 Mdot
.986 .5984 Mdot
.986 .59852 Mdot
.986 .59887 Mdot
.986 .59887 Mdot
.986 .59901 Mdot
.986 .59907 Mdot
.986 .59918 Mdot
.986 .59921 Mdot
.986 .59922 Mdot
.986 .59941 Mdot
.986 .59951 Mdot
.986 .5996 Mdot
.986 .59967 Mdot
.986 .59989 Mdot
.986 .5999 Mdot
.986 .59992 Mdot
.986 .60004 Mdot
.986 .60014 Mdot
.986 .60019 Mdot
.986 .60032 Mdot
.986 .6004 Mdot
.986 .6005 Mdot
.986 .60051 Mdot
.986 .60054 Mdot
.986 .60059 Mdot
.986 .60069 Mdot
.986 .60069 Mdot
.986 .60078 Mdot
.986 .60082 Mdot
.986 .60088 Mdot
.986 .60098 Mdot
.986 .60099 Mdot
.986 .60107 Mdot
.986 .60109 Mdot
.986 .60113 Mdot
.986 .60114 Mdot
.986 .60127 Mdot
.986 .60128 Mdot
.986 .60135 Mdot
.986 .60139 Mdot
.986 .60143 Mdot
.986 .60147 Mdot
.986 .60149 Mdot
.986 .60151 Mdot
.986 .60152 Mdot
.986 .60153 Mdot
.986 .60158 Mdot
.986 .6016 Mdot
.986 .6016 Mdot
.986 .60161 Mdot
.986 .60161 Mdot
.986 .60162 Mdot
.986 .60162 Mdot
.986 .60162 Mdot
.986 .60163 Mdot
.986 .60164 Mdot
.986 .60167 Mdot
.986 .60167 Mdot
.988 .02034 Mdot
.988 .02034 Mdot
.988 .02034 Mdot
.988 .02035 Mdot
.988 .02036 Mdot
.988 .02037 Mdot
.988 .02039 Mdot
.988 .02042 Mdot
.988 .02043 Mdot
.988 .02043 Mdot
.988 .02046 Mdot
.988 .02048 Mdot
.988 .02054 Mdot
.988 .02054 Mdot
.988 .02054 Mdot
.988 .02055 Mdot
.988 .02056 Mdot
.988 .02056 Mdot
.988 .02057 Mdot
.988 .0206 Mdot
.988 .02066 Mdot
.988 .02085 Mdot
.988 .02085 Mdot
.988 .02093 Mdot
.988 .02099 Mdot
.988 .02099 Mdot
.988 .021 Mdot
.988 .02103 Mdot
.988 .02105 Mdot
.988 .0211 Mdot
.988 .02116 Mdot
.988 .02123 Mdot
.988 .02133 Mdot
.988 .02134 Mdot
.988 .02141 Mdot
.988 .02145 Mdot
.988 .02165 Mdot
.988 .02178 Mdot
.988 .02215 Mdot
.988 .02217 Mdot
.988 .02224 Mdot
.988 .02291 Mdot
.988 .02292 Mdot
.988 .02298 Mdot
.988 .02334 Mdot
.988 .02339 Mdot
.988 .02405 Mdot
.988 .02409 Mdot
.988 .0241 Mdot
.988 .02474 Mdot
.988 .02506 Mdot
.988 .0257 Mdot
.988 .0257 Mdot
.988 .0272 Mdot
.988 .02742 Mdot
.988 .02772 Mdot
.988 .02783 Mdot
.988 .02815 Mdot
.988 .02828 Mdot
.988 .02848 Mdot
.988 .02855 Mdot
.988 .02857 Mdot
.988 .02882 Mdot
.988 .03037 Mdot
.988 .03157 Mdot
.988 .03173 Mdot
.988 .03312 Mdot
.988 .0335 Mdot
.988 .0341 Mdot
.988 .03432 Mdot
.988 .03434 Mdot
.988 .03459 Mdot
.988 .03466 Mdot
.988 .03646 Mdot
.988 .03682 Mdot
.988 .03694 Mdot
.988 .03696 Mdot
.988 .03697 Mdot
.988 .03698 Mdot
.988 .03704 Mdot
.988 .03706 Mdot
.988 .03706 Mdot
.988 .03713 Mdot
.988 .03722 Mdot
.988 .03728 Mdot
.988 .03729 Mdot
.988 .0373 Mdot
.988 .03741 Mdot
.988 .0375 Mdot
.988 .03752 Mdot
.988 .03757 Mdot
.988 .03772 Mdot
.988 .03772 Mdot
.988 .03774 Mdot
.988 .03778 Mdot
.988 .0378 Mdot
.988 .03783 Mdot
.988 .03783 Mdot
.988 .03786 Mdot
.988 .03795 Mdot
.988 .03819 Mdot
.988 .03819 Mdot
.988 .03883 Mdot
.988 .03895 Mdot
.988 .03896 Mdot
.988 .03925 Mdot
.988 .03943 Mdot
.988 .03948 Mdot
.988 .0395 Mdot
.988 .03952 Mdot
.988 .03967 Mdot
.988 .03973 Mdot
.988 .03985 Mdot
.988 .03992 Mdot
.988 .03993 Mdot
.988 .03996 Mdot
.988 .04016 Mdot
.988 .04041 Mdot
.988 .04042 Mdot
.988 .04081 Mdot
.988 .04084 Mdot
.988 .04111 Mdot
.988 .04128 Mdot
.988 .04132 Mdot
.988 .04177 Mdot
.988 .04206 Mdot
.988 .04259 Mdot
.988 .04337 Mdot
.988 .04402 Mdot
.988 .04402 Mdot
.988 .04411 Mdot
.988 .04438 Mdot
.988 .04477 Mdot
.988 .04599 Mdot
.988 .04645 Mdot
.988 .04696 Mdot
.988 .047 Mdot
.988 .04722 Mdot
.988 .04725 Mdot
.988 .04731 Mdot
.988 .04744 Mdot
.988 .04765 Mdot
.988 .04855 Mdot
.988 .04865 Mdot
.988 .04883 Mdot
.988 .04883 Mdot
.988 .04925 Mdot
.988 .04957 Mdot
.988 .0506 Mdot
.988 .05139 Mdot
.988 .05153 Mdot
.988 .05159 Mdot
.988 .05168 Mdot
.988 .05305 Mdot
.988 .05366 Mdot
.988 .05403 Mdot
.988 .05416 Mdot
.988 .05466 Mdot
.988 .05528 Mdot
.988 .05593 Mdot
.988 .05773 Mdot
.988 .05773 Mdot
.988 .0594 Mdot
.988 .05971 Mdot
.988 .06288 Mdot
.988 .06341 Mdot
.988 .06346 Mdot
.988 .06347 Mdot
.988 .0638 Mdot
.988 .06394 Mdot
.988 .06433 Mdot
.988 .06508 Mdot
.988 .06547 Mdot
.988 .06589 Mdot
.988 .06709 Mdot
.988 .06759 Mdot
.988 .06835 Mdot
.988 .06843 Mdot
.988 .06862 Mdot
.988 .06869 Mdot
.988 .06964 Mdot
.988 .07296 Mdot
.988 .07318 Mdot
.988 .07444 Mdot
.988 .07552 Mdot
.988 .07861 Mdot
.988 .07948 Mdot
.988 .08006 Mdot
.988 .08064 Mdot
.988 .08358 Mdot
.988 .08401 Mdot
.988 .08434 Mdot
.988 .08585 Mdot
.988 .08652 Mdot
.988 .0873 Mdot
.988 .08951 Mdot
.988 .08971 Mdot
.988 .08991 Mdot
.988 .09033 Mdot
.988 .09043 Mdot
.988 .09134 Mdot
.988 .09144 Mdot
.988 .0916 Mdot
.988 .09188 Mdot
.988 .09234 Mdot
.988 .09253 Mdot
.988 .09321 Mdot
.988 .09355 Mdot
.988 .09397 Mdot
.988 .09515 Mdot
.988 .0952 Mdot
.988 .09621 Mdot
.988 .09827 Mdot
.988 .09928 Mdot
.988 .09961 Mdot
.988 .10007 Mdot
.988 .10013 Mdot
.988 .10017 Mdot
.988 .1002 Mdot
.988 .10033 Mdot
.988 .10041 Mdot
.988 .10051 Mdot
.988 .10052 Mdot
.988 .10078 Mdot
.988 .1011 Mdot
.988 .10132 Mdot
.988 .10135 Mdot
.988 .10138 Mdot
.988 .10181 Mdot
.988 .10213 Mdot
.988 .10218 Mdot
.988 .10222 Mdot
.988 .10239 Mdot
.988 .10291 Mdot
.988 .10292 Mdot
.988 .10293 Mdot
.988 .10298 Mdot
.988 .103 Mdot
.988 .10314 Mdot
.988 .10321 Mdot
.988 .10333 Mdot
.988 .10334 Mdot
.988 .10345 Mdot
.988 .10378 Mdot
.988 .10412 Mdot
.988 .10466 Mdot
.988 .10467 Mdot
.988 .10495 Mdot
.988 .10592 Mdot
.988 .10624 Mdot
.988 .10691 Mdot
.988 .10701 Mdot
.988 .10744 Mdot
.988 .10747 Mdot
.988 .10856 Mdot
.988 .10919 Mdot
.988 .10937 Mdot
.988 .10945 Mdot
.988 .10952 Mdot
.988 .10954 Mdot
.988 .11007 Mdot
.988 .11028 Mdot
.988 .11072 Mdot
.988 .11099 Mdot
.988 .11102 Mdot
.988 .11114 Mdot
.988 .11187 Mdot
.988 .11203 Mdot
.988 .11279 Mdot
.988 .11281 Mdot
.988 .11286 Mdot
.988 .11425 Mdot
.988 .11435 Mdot
.988 .11527 Mdot
.988 .11533 Mdot
.988 .11593 Mdot
.988 .11609 Mdot
.988 .11773 Mdot
.988 .11876 Mdot
.988 .12067 Mdot
.988 .12076 Mdot
.988 .12243 Mdot
.988 .12272 Mdot
.988 .12351 Mdot
.988 .12583 Mdot
.988 .12583 Mdot
.988 .12616 Mdot
.988 .12634 Mdot
.988 .12651 Mdot
.988 .12713 Mdot
.988 .12832 Mdot
.988 .12849 Mdot
.988 .12854 Mdot
.988 .12858 Mdot
.988 .12955 Mdot
.988 .12978 Mdot
.988 .1298 Mdot
.988 .13223 Mdot
.988 .13236 Mdot
.988 .13288 Mdot
.988 .1338 Mdot
.988 .13406 Mdot
.988 .13451 Mdot
.988 .13491 Mdot
.988 .1352 Mdot
.988 .13634 Mdot
.988 .13648 Mdot
.988 .13726 Mdot
.988 .13738 Mdot
.988 .13759 Mdot
.988 .13779 Mdot
.988 .13803 Mdot
.988 .13878 Mdot
.988 .14017 Mdot
.988 .1407 Mdot
.988 .14197 Mdot
.988 .14232 Mdot
.988 .14295 Mdot
.988 .14297 Mdot
.988 .14443 Mdot
.988 .14557 Mdot
.988 .14772 Mdot
.988 .14835 Mdot
.988 .14917 Mdot
.988 .14997 Mdot
.988 .14999 Mdot
.988 .15135 Mdot
.988 .15178 Mdot
.988 .15196 Mdot
.988 .15208 Mdot
.988 .15243 Mdot
.988 .15264 Mdot
.988 .15277 Mdot
.988 .15296 Mdot
.988 .15775 Mdot
.988 .15983 Mdot
.988 .16027 Mdot
.988 .16029 Mdot
.988 .16064 Mdot
.988 .16113 Mdot
.988 .16159 Mdot
.988 .1623 Mdot
.988 .16247 Mdot
.988 .16318 Mdot
.988 .16331 Mdot
.988 .16545 Mdot
.988 .16617 Mdot
.988 .16715 Mdot
.988 .16765 Mdot
.988 .168 Mdot
.988 .17383 Mdot
.988 .17383 Mdot
.988 .17405 Mdot
.988 .17826 Mdot
.988 .17948 Mdot
.988 .18048 Mdot
.988 .18053 Mdot
.988 .1819 Mdot
.988 .18357 Mdot
.988 .18446 Mdot
.988 .18469 Mdot
.988 .18472 Mdot
.988 .18559 Mdot
.988 .18849 Mdot
.988 .1894 Mdot
.988 .19071 Mdot
.988 .19119 Mdot
.988 .19294 Mdot
.988 .19312 Mdot
.988 .19315 Mdot
.988 .19426 Mdot
.988 .19453 Mdot
.988 .1947 Mdot
.988 .19539 Mdot
.988 .196 Mdot
.988 .19766 Mdot
.988 .19812 Mdot
.988 .19849 Mdot
.988 .19979 Mdot
.988 .20002 Mdot
.988 .20119 Mdot
.988 .20415 Mdot
.988 .20512 Mdot
.988 .20537 Mdot
.988 .20675 Mdot
.988 .20775 Mdot
.988 .20925 Mdot
.988 .20949 Mdot
.988 .21011 Mdot
.988 .21037 Mdot
.988 .21043 Mdot
.988 .21043 Mdot
.988 .21345 Mdot
.988 .22094 Mdot
.988 .22225 Mdot
.988 .22414 Mdot
.988 .22486 Mdot
.988 .22885 Mdot
.988 .22946 Mdot
.988 .23061 Mdot
.988 .2323 Mdot
.988 .23254 Mdot
.988 .23281 Mdot
.988 .23438 Mdot
.988 .23665 Mdot
.988 .23747 Mdot
.988 .24024 Mdot
.988 .24202 Mdot
.988 .24369 Mdot
.988 .24471 Mdot
.988 .24651 Mdot
.988 .24833 Mdot
.988 .25152 Mdot
.988 .25256 Mdot
.988 .25258 Mdot
.988 .25283 Mdot
.988 .25389 Mdot
.988 .25539 Mdot
.988 .2554 Mdot
.988 .25645 Mdot
.988 .2568 Mdot
.988 .25738 Mdot
.988 .25745 Mdot
.988 .25869 Mdot
.988 .25968 Mdot
.988 .26188 Mdot
.988 .26365 Mdot
.988 .26428 Mdot
.988 .2663 Mdot
.988 .26784 Mdot
.988 .26864 Mdot
.988 .27358 Mdot
.988 .2739 Mdot
.988 .27466 Mdot
.988 .27527 Mdot
.988 .27585 Mdot
.988 .27644 Mdot
.988 .27723 Mdot
.988 .2777 Mdot
.988 .27798 Mdot
.988 .27873 Mdot
.988 .28067 Mdot
.988 .28097 Mdot
.988 .28144 Mdot
.988 .28228 Mdot
.988 .28316 Mdot
.988 .28343 Mdot
.988 .28362 Mdot
.988 .28418 Mdot
.988 .28616 Mdot
.988 .28717 Mdot
.988 .2884 Mdot
.988 .29124 Mdot
.988 .29181 Mdot
.988 .29196 Mdot
.988 .29489 Mdot
.988 .29622 Mdot
.988 .29718 Mdot
.988 .29726 Mdot
.988 .3006 Mdot
.988 .3008 Mdot
.988 .30272 Mdot
.988 .30369 Mdot
.988 .30433 Mdot
.988 .30464 Mdot
.988 .30592 Mdot
.988 .30611 Mdot
.988 .3062 Mdot
.988 .30626 Mdot
.988 .3063 Mdot
.988 .30668 Mdot
.988 .30689 Mdot
.988 .30717 Mdot
.988 .30719 Mdot
.988 .30765 Mdot
.988 .30793 Mdot
.988 .30806 Mdot
.988 .30884 Mdot
.988 .30947 Mdot
.988 .30955 Mdot
.988 .30963 Mdot
.988 .31083 Mdot
.988 .31173 Mdot
.988 .31187 Mdot
.988 .31198 Mdot
.988 .31247 Mdot
.988 .31339 Mdot
.988 .31393 Mdot
.988 .31395 Mdot
.988 .31397 Mdot
.988 .31411 Mdot
.988 .31416 Mdot
.988 .31455 Mdot
.988 .31476 Mdot
.988 .31509 Mdot
.988 .31511 Mdot
.988 .31544 Mdot
.988 .316 Mdot
.988 .31635 Mdot
.988 .31728 Mdot
.988 .3188 Mdot
.988 .31881 Mdot
.988 .31894 Mdot
.988 .31959 Mdot
.988 .31968 Mdot
.988 .32083 Mdot
.988 .32228 Mdot
.988 .32315 Mdot
.988 .325 Mdot
.988 .32526 Mdot
.988 .3256 Mdot
.988 .32573 Mdot
.988 .32644 Mdot
.988 .32651 Mdot
.988 .32653 Mdot
.988 .32836 Mdot
.988 .32949 Mdot
.988 .33119 Mdot
.988 .33169 Mdot
.988 .33189 Mdot
.988 .33209 Mdot
.988 .33215 Mdot
.988 .33357 Mdot
.988 .33403 Mdot
.988 .33415 Mdot
.988 .33436 Mdot
.988 .33533 Mdot
.988 .33605 Mdot
.988 .3361 Mdot
.988 .33613 Mdot
.988 .33645 Mdot
.988 .33842 Mdot
.988 .33883 Mdot
.988 .34086 Mdot
.988 .34093 Mdot
.988 .34106 Mdot
.988 .34175 Mdot
.988 .34199 Mdot
.988 .34473 Mdot
.988 .34499 Mdot
.988 .34566 Mdot
.988 .34743 Mdot
.988 .34759 Mdot
.988 .34914 Mdot
.988 .34942 Mdot
.988 .34959 Mdot
.988 .34965 Mdot
.988 .35385 Mdot
.988 .35651 Mdot
.988 .35818 Mdot
.988 .35848 Mdot
.988 .36141 Mdot
.988 .36165 Mdot
.988 .3619 Mdot
.988 .36203 Mdot
.988 .36219 Mdot
.988 .36302 Mdot
.988 .36453 Mdot
.988 .36587 Mdot
.988 .36617 Mdot
.988 .36662 Mdot
.988 .36686 Mdot
.988 .36776 Mdot
.988 .36861 Mdot
.988 .36889 Mdot
.988 .37206 Mdot
.988 .37216 Mdot
.988 .37338 Mdot
.988 .37395 Mdot
.988 .37401 Mdot
.988 .37403 Mdot
.988 .37441 Mdot
.988 .37442 Mdot
.988 .37518 Mdot
.988 .37522 Mdot
.988 .37567 Mdot
.988 .37575 Mdot
.988 .37611 Mdot
.988 .3769 Mdot
.988 .37763 Mdot
.988 .37989 Mdot
.988 .38008 Mdot
.988 .38056 Mdot
.988 .38096 Mdot
.988 .38109 Mdot
.988 .38118 Mdot
.988 .38355 Mdot
.988 .38355 Mdot
.988 .38412 Mdot
.988 .38417 Mdot
.988 .38437 Mdot
.988 .38956 Mdot
.988 .39002 Mdot
.988 .39026 Mdot
.988 .39032 Mdot
.988 .39033 Mdot
.988 .39134 Mdot
.988 .39159 Mdot
.988 .39193 Mdot
.988 .39295 Mdot
.988 .39377 Mdot
.988 .39439 Mdot
.988 .39547 Mdot
.988 .3964 Mdot
.988 .39709 Mdot
.988 .39977 Mdot
.988 .4001 Mdot
.988 .40191 Mdot
.988 .4022 Mdot
.988 .40268 Mdot
.988 .40275 Mdot
.988 .40314 Mdot
.988 .4037 Mdot
.988 .4039 Mdot
.988 .40543 Mdot
.988 .40735 Mdot
.988 .40829 Mdot
.988 .40829 Mdot
.988 .40863 Mdot
.988 .40985 Mdot
.988 .41274 Mdot
.988 .41353 Mdot
.988 .41494 Mdot
.988 .415 Mdot
.988 .41826 Mdot
.988 .41904 Mdot
.988 .4207 Mdot
.988 .42079 Mdot
.988 .42552 Mdot
.988 .42691 Mdot
.988 .42869 Mdot
.988 .43041 Mdot
.988 .43046 Mdot
.988 .43252 Mdot
.988 .43338 Mdot
.988 .43392 Mdot
.988 .4343 Mdot
.988 .43468 Mdot
.988 .43494 Mdot
.988 .43568 Mdot
.988 .4357 Mdot
.988 .43598 Mdot
.988 .43612 Mdot
.988 .43613 Mdot
.988 .4364 Mdot
.988 .43654 Mdot
.988 .43681 Mdot
.988 .43836 Mdot
.988 .43994 Mdot
.988 .43995 Mdot
.988 .44019 Mdot
.988 .44033 Mdot
.988 .44057 Mdot
.988 .44288 Mdot
.988 .44316 Mdot
.988 .44677 Mdot
.988 .44717 Mdot
.988 .45082 Mdot
.988 .45092 Mdot
.988 .45102 Mdot
.988 .45147 Mdot
.988 .45186 Mdot
.988 .45192 Mdot
.988 .45195 Mdot
.988 .45201 Mdot
.988 .45265 Mdot
.988 .45365 Mdot
.988 .45456 Mdot
.988 .45458 Mdot
.988 .45482 Mdot
.988 .4555 Mdot
.988 .45597 Mdot
.988 .45631 Mdot
.988 .45643 Mdot
.988 .45771 Mdot
.988 .45779 Mdot
.988 .45798 Mdot
.988 .45825 Mdot
.988 .4583 Mdot
.988 .46009 Mdot
.988 .46204 Mdot
.988 .46217 Mdot
.988 .46328 Mdot
.988 .4634 Mdot
.988 .46346 Mdot
.988 .46358 Mdot
.988 .46358 Mdot
.988 .46433 Mdot
.988 .4652 Mdot
.988 .4654 Mdot
.988 .46546 Mdot
.988 .46559 Mdot
.988 .46643 Mdot
.988 .46709 Mdot
.988 .47251 Mdot
.988 .47325 Mdot
.988 .47801 Mdot
.988 .47801 Mdot
.988 .47842 Mdot
.988 .47992 Mdot
.988 .48041 Mdot
.988 .48458 Mdot
.988 .485 Mdot
.988 .48525 Mdot
.988 .48568 Mdot
.988 .48571 Mdot
.988 .486 Mdot
.988 .48815 Mdot
.988 .48849 Mdot
.988 .4899 Mdot
.988 .48998 Mdot
.988 .4912 Mdot
.988 .49166 Mdot
.988 .49189 Mdot
.988 .49235 Mdot
.988 .49236 Mdot
.988 .49239 Mdot
.988 .49262 Mdot
.988 .49311 Mdot
.988 .49314 Mdot
.988 .49441 Mdot
.988 .49486 Mdot
.988 .49522 Mdot
.988 .49549 Mdot
.988 .49614 Mdot
.988 .49673 Mdot
.988 .49706 Mdot
.988 .49712 Mdot
.988 .49717 Mdot
.988 .49851 Mdot
.988 .49862 Mdot
.988 .50191 Mdot
.988 .502 Mdot
.988 .50343 Mdot
.988 .50482 Mdot
.988 .50491 Mdot
.988 .50703 Mdot
.988 .50767 Mdot
.988 .5078 Mdot
.988 .50989 Mdot
.988 .51057 Mdot
.988 .51085 Mdot
.988 .5109 Mdot
.988 .51263 Mdot
.988 .51305 Mdot
.988 .51332 Mdot
.988 .51438 Mdot
.988 .51531 Mdot
.988 .51721 Mdot
.988 .51735 Mdot
.988 .51784 Mdot
.988 .51853 Mdot
.988 .51909 Mdot
.988 .51984 Mdot
.988 .521 Mdot
.988 .52103 Mdot
.988 .52136 Mdot
.988 .52309 Mdot
.988 .52576 Mdot
.988 .52585 Mdot
.988 .52735 Mdot
.988 .52786 Mdot
.988 .52872 Mdot
.988 .52898 Mdot
.988 .52909 Mdot
.988 .531 Mdot
.988 .53239 Mdot
.988 .53297 Mdot
.988 .53442 Mdot
.988 .53464 Mdot
.988 .53475 Mdot
.988 .53509 Mdot
.988 .5351 Mdot
.988 .53559 Mdot
.988 .53593 Mdot
.988 .53601 Mdot
.988 .53602 Mdot
.988 .53636 Mdot
.988 .53888 Mdot
.988 .53999 Mdot
.988 .54087 Mdot
.988 .54113 Mdot
.988 .54185 Mdot
.988 .54235 Mdot
.988 .54243 Mdot
.988 .54304 Mdot
.988 .54341 Mdot
.988 .54566 Mdot
.988 .54607 Mdot
.988 .54932 Mdot
.988 .54932 Mdot
.988 .55014 Mdot
.988 .55086 Mdot
.988 .55124 Mdot
.988 .55249 Mdot
.988 .55307 Mdot
.988 .55321 Mdot
.988 .55389 Mdot
.988 .55415 Mdot
.988 .5553 Mdot
.988 .55569 Mdot
.988 .55596 Mdot
.988 .55683 Mdot
.988 .55708 Mdot
.988 .55709 Mdot
.988 .55716 Mdot
.988 .55743 Mdot
.988 .55792 Mdot
.988 .55834 Mdot
.988 .559 Mdot
.988 .56023 Mdot
.988 .56201 Mdot
.988 .56225 Mdot
.988 .56254 Mdot
.988 .56341 Mdot
.988 .56361 Mdot
.988 .56366 Mdot
.988 .56414 Mdot
.988 .56424 Mdot
.988 .56425 Mdot
.988 .56641 Mdot
.988 .5666 Mdot
.988 .56669 Mdot
.988 .56681 Mdot
.988 .5672 Mdot
.988 .56721 Mdot
.988 .56767 Mdot
.988 .56785 Mdot
.988 .56984 Mdot
.988 .56999 Mdot
.988 .57067 Mdot
.988 .57139 Mdot
.988 .57148 Mdot
.988 .57171 Mdot
.988 .57179 Mdot
.988 .57219 Mdot
.988 .57223 Mdot
.988 .57291 Mdot
.988 .57291 Mdot
.988 .57298 Mdot
.988 .57325 Mdot
.988 .57327 Mdot
.988 .57332 Mdot
.988 .57382 Mdot
.988 .57387 Mdot
.988 .57488 Mdot
.988 .57496 Mdot
.988 .57542 Mdot
.988 .57694 Mdot
.988 .5776 Mdot
.988 .57783 Mdot
.988 .57851 Mdot
.988 .57923 Mdot
.988 .57941 Mdot
.988 .5795 Mdot
.988 .57976 Mdot
.988 .57999 Mdot
.988 .5803 Mdot
.988 .58032 Mdot
.988 .58051 Mdot
.988 .58102 Mdot
.988 .5813 Mdot
.988 .58213 Mdot
.988 .58241 Mdot
.988 .58242 Mdot
.988 .58274 Mdot
.988 .58285 Mdot
.988 .58294 Mdot
.988 .58313 Mdot
.988 .58318 Mdot
.988 .5833 Mdot
.988 .58342 Mdot
.988 .58383 Mdot
.988 .58388 Mdot
.988 .58474 Mdot
.988 .58532 Mdot
.988 .58541 Mdot
.988 .58552 Mdot
.988 .58662 Mdot
.988 .58684 Mdot
.988 .58795 Mdot
.988 .58828 Mdot
.988 .58834 Mdot
.988 .58954 Mdot
.988 .59041 Mdot
.988 .59071 Mdot
.988 .59075 Mdot
.988 .59084 Mdot
.988 .59085 Mdot
.988 .59099 Mdot
.988 .59182 Mdot
.988 .5919 Mdot
.988 .5928 Mdot
.988 .59313 Mdot
.988 .59326 Mdot
.988 .59339 Mdot
.988 .59355 Mdot
.988 .5939 Mdot
.988 .59419 Mdot
.988 .59445 Mdot
.988 .59453 Mdot
.988 .59464 Mdot
.988 .59471 Mdot
.988 .59495 Mdot
.988 .595 Mdot
.988 .59503 Mdot
.988 .59506 Mdot
.988 .59526 Mdot
.988 .59537 Mdot
.988 .59569 Mdot
.988 .59588 Mdot
.988 .59605 Mdot
.988 .59646 Mdot
.988 .59657 Mdot
.988 .59681 Mdot
.988 .59692 Mdot
.988 .59693 Mdot
.988 .59695 Mdot
.988 .59706 Mdot
.988 .59721 Mdot
.988 .59738 Mdot
.988 .59747 Mdot
.988 .59753 Mdot
.988 .59755 Mdot
.988 .59762 Mdot
.988 .59766 Mdot
.988 .59773 Mdot
.988 .59782 Mdot
.988 .59828 Mdot
.988 .5983 Mdot
.988 .59836 Mdot
.988 .59837 Mdot
.988 .59842 Mdot
.988 .59857 Mdot
.988 .59867 Mdot
.988 .59902 Mdot
.988 .59906 Mdot
.988 .59937 Mdot
.988 .59976 Mdot
.988 .59983 Mdot
.988 .59983 Mdot
.988 .59985 Mdot
.988 .5999 Mdot
.988 .59993 Mdot
.988 .60001 Mdot
.988 .60004 Mdot
.988 .60012 Mdot
.988 .60017 Mdot
.988 .60055 Mdot
.988 .60055 Mdot
.988 .60071 Mdot
.988 .6008 Mdot
.988 .60096 Mdot
.988 .60096 Mdot
.988 .60097 Mdot
.988 .60114 Mdot
.988 .60115 Mdot
.988 .60124 Mdot
.988 .60126 Mdot
.988 .60126 Mdot
.988 .60143 Mdot
.988 .60144 Mdot
.988 .60145 Mdot
.988 .60154 Mdot
.988 .60158 Mdot
.988 .60163 Mdot
.988 .60164 Mdot
.988 .60166 Mdot
.988 .60166 Mdot
.988 .60168 Mdot
.988 .6017 Mdot
.988 .60171 Mdot
.988 .60173 Mdot
.988 .60173 Mdot
.988 .60174 Mdot
.988 .60174 Mdot
.988 .60174 Mdot
.988 .60176 Mdot
.988 .60178 Mdot
.988 .60178 Mdot
.988 .60183 Mdot
.988 .60184 Mdot
.988 .60185 Mdot
.988 .60185 Mdot
.988 .60185 Mdot
.988 .60185 Mdot
.988 .60186 Mdot
.988 .60186 Mdot
.988 .60186 Mdot
.988 .60187 Mdot
.988 .60188 Mdot
.988 .60188 Mdot
.988 .60188 Mdot
.988 .60188 Mdot
.988 .60189 Mdot
.988 .6019 Mdot
.988 .6019 Mdot
.988 .6019 Mdot
.988 .6019 Mdot
.988 .60191 Mdot
.988 .60191 Mdot
.99 .0194 Mdot
.99 .01941 Mdot
.99 .01942 Mdot
.99 .01942 Mdot
.99 .01942 Mdot
.99 .01943 Mdot
.99 .01944 Mdot
.99 .01945 Mdot
.99 .01948 Mdot
.99 .01952 Mdot
.99 .01957 Mdot
.99 .01975 Mdot
.99 .01979 Mdot
.99 .01988 Mdot
.99 .0201 Mdot
.99 .02015 Mdot
.99 .02021 Mdot
.99 .02026 Mdot
.99 .02031 Mdot
.99 .02034 Mdot
.99 .02041 Mdot
.99 .02051 Mdot
.99 .02054 Mdot
.99 .02067 Mdot
.99 .02072 Mdot
.99 .02082 Mdot
.99 .02085 Mdot
.99 .0209 Mdot
.99 .02109 Mdot
.99 .02111 Mdot
.99 .02143 Mdot
.99 .02231 Mdot
.99 .0224 Mdot
.99 .02247 Mdot
.99 .02266 Mdot
.99 .02271 Mdot
.99 .02307 Mdot
.99 .02329 Mdot
.99 .02337 Mdot
.99 .02353 Mdot
.99 .02359 Mdot
.99 .02373 Mdot
.99 .02388 Mdot
.99 .02486 Mdot
.99 .02488 Mdot
.99 .02508 Mdot
.99 .02565 Mdot
.99 .02671 Mdot
.99 .02685 Mdot
.99 .02698 Mdot
.99 .02761 Mdot
.99 .02764 Mdot
.99 .02771 Mdot
.99 .02779 Mdot
.99 .02781 Mdot
.99 .02781 Mdot
.99 .02901 Mdot
.99 .02931 Mdot
.99 .02937 Mdot
.99 .02943 Mdot
.99 .02945 Mdot
.99 .0298 Mdot
.99 .03007 Mdot
.99 .03012 Mdot
.99 .03048 Mdot
.99 .03084 Mdot
.99 .03145 Mdot
.99 .03168 Mdot
.99 .03234 Mdot
.99 .03239 Mdot
.99 .03255 Mdot
.99 .03273 Mdot
.99 .03329 Mdot
.99 .0333 Mdot
.99 .03334 Mdot
.99 .03337 Mdot
.99 .03337 Mdot
.99 .0334 Mdot
.99 .03345 Mdot
.99 .03347 Mdot
.99 .03357 Mdot
.99 .03374 Mdot
.99 .0339 Mdot
.99 .03393 Mdot
.99 .03396 Mdot
.99 .03463 Mdot
.99 .0348 Mdot
.99 .03484 Mdot
.99 .03515 Mdot
.99 .03603 Mdot
.99 .03623 Mdot
.99 .03646 Mdot
.99 .03665 Mdot
.99 .03666 Mdot
.99 .03686 Mdot
.99 .03698 Mdot
.99 .03724 Mdot
.99 .03726 Mdot
.99 .03729 Mdot
.99 .03762 Mdot
.99 .03775 Mdot
.99 .03826 Mdot
.99 .03829 Mdot
.99 .03846 Mdot
.99 .03848 Mdot
.99 .03864 Mdot
.99 .03883 Mdot
.99 .03895 Mdot
.99 .03895 Mdot
.99 .03895 Mdot
.99 .03915 Mdot
.99 .03951 Mdot
.99 .03985 Mdot
.99 .03986 Mdot
.99 .0399 Mdot
.99 .0399 Mdot
.99 .03994 Mdot
.99 .03996 Mdot
.99 .03997 Mdot
.99 .04008 Mdot
.99 .0412 Mdot
.99 .0416 Mdot
.99 .04286 Mdot
.99 .04313 Mdot
.99 .04348 Mdot
.99 .04448 Mdot
.99 .04463 Mdot
.99 .04499 Mdot
.99 .04526 Mdot
.99 .04601 Mdot
.99 .04619 Mdot
.99 .04729 Mdot
.99 .04759 Mdot
.99 .04846 Mdot
.99 .04878 Mdot
.99 .04939 Mdot
.99 .0496 Mdot
.99 .04981 Mdot
.99 .05018 Mdot
.99 .05072 Mdot
.99 .05101 Mdot
.99 .05101 Mdot
.99 .05217 Mdot
.99 .05279 Mdot
.99 .05338 Mdot
.99 .05454 Mdot
.99 .05458 Mdot
.99 .05459 Mdot
.99 .05493 Mdot
.99 .05538 Mdot
.99 .05543 Mdot
.99 .05669 Mdot
.99 .05677 Mdot
.99 .05692 Mdot
.99 .0574 Mdot
.99 .05747 Mdot
.99 .05756 Mdot
.99 .05805 Mdot
.99 .05939 Mdot
.99 .05968 Mdot
.99 .06049 Mdot
.99 .06104 Mdot
.99 .06118 Mdot
.99 .06163 Mdot
.99 .06218 Mdot
.99 .06265 Mdot
.99 .06302 Mdot
.99 .0634 Mdot
.99 .06358 Mdot
.99 .0638 Mdot
.99 .06451 Mdot
.99 .06467 Mdot
.99 .06506 Mdot
.99 .06519 Mdot
.99 .0654 Mdot
.99 .06544 Mdot
.99 .06545 Mdot
.99 .06576 Mdot
.99 .06582 Mdot
.99 .06582 Mdot
.99 .06594 Mdot
.99 .06688 Mdot
.99 .06699 Mdot
.99 .06728 Mdot
.99 .06867 Mdot
.99 .06909 Mdot
.99 .07038 Mdot
.99 .07155 Mdot
.99 .07177 Mdot
.99 .072 Mdot
.99 .07208 Mdot
.99 .0734 Mdot
.99 .07444 Mdot
.99 .0746 Mdot
.99 .07489 Mdot
.99 .07596 Mdot
.99 .07732 Mdot
.99 .07778 Mdot
.99 .07798 Mdot
.99 .07818 Mdot
.99 .07848 Mdot
.99 .07963 Mdot
.99 .08051 Mdot
.99 .08124 Mdot
.99 .08214 Mdot
.99 .08219 Mdot
.99 .08296 Mdot
.99 .08317 Mdot
.99 .08375 Mdot
.99 .08444 Mdot
.99 .085 Mdot
.99 .08653 Mdot
.99 .08658 Mdot
.99 .08673 Mdot
.99 .08681 Mdot
.99 .08682 Mdot
.99 .0869 Mdot
.99 .08693 Mdot
.99 .08707 Mdot
.99 .08713 Mdot
.99 .08719 Mdot
.99 .08748 Mdot
.99 .08759 Mdot
.99 .08777 Mdot
.99 .08821 Mdot
.99 .0888 Mdot
.99 .08891 Mdot
.99 .08902 Mdot
.99 .09153 Mdot
.99 .09215 Mdot
.99 .09215 Mdot
.99 .09231 Mdot
.99 .09346 Mdot
.99 .09393 Mdot
.99 .09498 Mdot
.99 .09675 Mdot
.99 .09747 Mdot
.99 .09832 Mdot
.99 .09854 Mdot
.99 .09904 Mdot
.99 .09907 Mdot
.99 .09979 Mdot
.99 .10023 Mdot
.99 .10039 Mdot
.99 .10081 Mdot
.99 .10118 Mdot
.99 .10126 Mdot
.99 .10138 Mdot
.99 .10261 Mdot
.99 .10294 Mdot
.99 .103 Mdot
.99 .10307 Mdot
.99 .10494 Mdot
.99 .10506 Mdot
.99 .10543 Mdot
.99 .10567 Mdot
.99 .10574 Mdot
.99 .10634 Mdot
.99 .10705 Mdot
.99 .10748 Mdot
.99 .10749 Mdot
.99 .10749 Mdot
.99 .10822 Mdot
.99 .10878 Mdot
.99 .10913 Mdot
.99 .10954 Mdot
.99 .11077 Mdot
.99 .11082 Mdot
.99 .11094 Mdot
.99 .11094 Mdot
.99 .11109 Mdot
.99 .11118 Mdot
.99 .11119 Mdot
.99 .11161 Mdot
.99 .11373 Mdot
.99 .11492 Mdot
.99 .11544 Mdot
.99 .1157 Mdot
.99 .11633 Mdot
.99 .11713 Mdot
.99 .1197 Mdot
.99 .12119 Mdot
.99 .1217 Mdot
.99 .12266 Mdot
.99 .12379 Mdot
.99 .12395 Mdot
.99 .12752 Mdot
.99 .12807 Mdot
.99 .12936 Mdot
.99 .13031 Mdot
.99 .13247 Mdot
.99 .13301 Mdot
.99 .13317 Mdot
.99 .13363 Mdot
.99 .1352 Mdot
.99 .1369 Mdot
.99 .13757 Mdot
.99 .13825 Mdot
.99 .13863 Mdot
.99 .14031 Mdot
.99 .14171 Mdot
.99 .14242 Mdot
.99 .14283 Mdot
.99 .14312 Mdot
.99 .14453 Mdot
.99 .14496 Mdot
.99 .145 Mdot
.99 .14573 Mdot
.99 .14624 Mdot
.99 .14648 Mdot
.99 .14725 Mdot
.99 .14767 Mdot
.99 .14775 Mdot
.99 .14966 Mdot
.99 .15023 Mdot
.99 .15067 Mdot
.99 .15069 Mdot
.99 .15474 Mdot
.99 .15689 Mdot
.99 .15812 Mdot
.99 .15848 Mdot
.99 .15893 Mdot
.99 .1606 Mdot
.99 .16099 Mdot
.99 .16122 Mdot
.99 .16204 Mdot
.99 .16294 Mdot
.99 .16308 Mdot
.99 .16313 Mdot
.99 .16428 Mdot
.99 .16584 Mdot
.99 .16601 Mdot
.99 .16665 Mdot
.99 .16696 Mdot
.99 .17034 Mdot
.99 .17061 Mdot
.99 .17112 Mdot
.99 .17276 Mdot
.99 .17301 Mdot
.99 .1733 Mdot
.99 .17418 Mdot
.99 .17498 Mdot
.99 .17687 Mdot
.99 .17764 Mdot
.99 .1795 Mdot
.99 .17953 Mdot
.99 .1805 Mdot
.99 .18325 Mdot
.99 .18511 Mdot
.99 .18556 Mdot
.99 .18565 Mdot
.99 .18707 Mdot
.99 .18836 Mdot
.99 .18891 Mdot
.99 .18994 Mdot
.99 .18999 Mdot
.99 .19003 Mdot
.99 .19045 Mdot
.99 .19047 Mdot
.99 .19049 Mdot
.99 .19173 Mdot
.99 .19181 Mdot
.99 .19194 Mdot
.99 .19301 Mdot
.99 .1936 Mdot
.99 .19434 Mdot
.99 .19523 Mdot
.99 .19608 Mdot
.99 .19668 Mdot
.99 .1972 Mdot
.99 .19852 Mdot
.99 .19894 Mdot
.99 .19964 Mdot
.99 .19975 Mdot
.99 .19981 Mdot
.99 .20081 Mdot
.99 .201 Mdot
.99 .20101 Mdot
.99 .20134 Mdot
.99 .20143 Mdot
.99 .20167 Mdot
.99 .20237 Mdot
.99 .20452 Mdot
.99 .20486 Mdot
.99 .20583 Mdot
.99 .20805 Mdot
.99 .20901 Mdot
.99 .21036 Mdot
.99 .21037 Mdot
.99 .21175 Mdot
.99 .21187 Mdot
.99 .21462 Mdot
.99 .21593 Mdot
.99 .21971 Mdot
.99 .22042 Mdot
.99 .22115 Mdot
.99 .22139 Mdot
.99 .22563 Mdot
.99 .22613 Mdot
.99 .22894 Mdot
.99 .22944 Mdot
.99 .22965 Mdot
.99 .23039 Mdot
.99 .2324 Mdot
.99 .23378 Mdot
.99 .23401 Mdot
.99 .2349 Mdot
.99 .23806 Mdot
.99 .23874 Mdot
.99 .23887 Mdot
.99 .2395 Mdot
.99 .24014 Mdot
.99 .24077 Mdot
.99 .24118 Mdot
.99 .2417 Mdot
.99 .24232 Mdot
.99 .24528 Mdot
.99 .24612 Mdot
.99 .24661 Mdot
.99 .24772 Mdot
.99 .24801 Mdot
.99 .25026 Mdot
.99 .25227 Mdot
.99 .25229 Mdot
.99 .25305 Mdot
.99 .2532 Mdot
.99 .25556 Mdot
.99 .25622 Mdot
.99 .25788 Mdot
.99 .258 Mdot
.99 .25822 Mdot
.99 .26008 Mdot
.99 .26179 Mdot
.99 .26188 Mdot
.99 .26309 Mdot
.99 .26643 Mdot
.99 .26656 Mdot
.99 .26704 Mdot
.99 .26728 Mdot
.99 .26729 Mdot
.99 .26756 Mdot
.99 .26763 Mdot
.99 .26804 Mdot
.99 .26814 Mdot
.99 .26823 Mdot
.99 .26841 Mdot
.99 .26929 Mdot
.99 .26963 Mdot
.99 .27017 Mdot
.99 .27084 Mdot
.99 .27116 Mdot
.99 .27148 Mdot
.99 .27152 Mdot
.99 .27244 Mdot
.99 .27325 Mdot
.99 .27357 Mdot
.99 .2739 Mdot
.99 .27521 Mdot
.99 .27666 Mdot
.99 .27836 Mdot
.99 .28135 Mdot
.99 .2822 Mdot
.99 .28316 Mdot
.99 .28319 Mdot
.99 .28363 Mdot
.99 .28501 Mdot
.99 .28574 Mdot
.99 .28701 Mdot
.99 .28837 Mdot
.99 .2887 Mdot
.99 .28975 Mdot
.99 .29011 Mdot
.99 .29143 Mdot
.99 .29151 Mdot
.99 .29154 Mdot
.99 .29237 Mdot
.99 .29475 Mdot
.99 .29655 Mdot
.99 .29663 Mdot
.99 .29687 Mdot
.99 .29735 Mdot
.99 .29847 Mdot
.99 .29864 Mdot
.99 .30035 Mdot
.99 .30106 Mdot
.99 .30156 Mdot
.99 .30169 Mdot
.99 .30216 Mdot
.99 .30252 Mdot
.99 .3029 Mdot
.99 .30311 Mdot
.99 .30321 Mdot
.99 .30524 Mdot
.99 .3065 Mdot
.99 .30695 Mdot
.99 .30778 Mdot
.99 .30815 Mdot
.99 .30919 Mdot
.99 .3094 Mdot
.99 .30975 Mdot
.99 .30988 Mdot
.99 .31004 Mdot
.99 .31032 Mdot
.99 .31066 Mdot
.99 .31258 Mdot
.99 .31321 Mdot
.99 .31411 Mdot
.99 .31429 Mdot
.99 .31449 Mdot
.99 .31467 Mdot
.99 .31542 Mdot
.99 .31601 Mdot
.99 .31626 Mdot
.99 .31693 Mdot
.99 .31968 Mdot
.99 .32001 Mdot
.99 .32009 Mdot
.99 .32103 Mdot
.99 .3217 Mdot
.99 .32191 Mdot
.99 .32326 Mdot
.99 .32355 Mdot
.99 .32426 Mdot
.99 .3255 Mdot
.99 .3258 Mdot
.99 .32668 Mdot
.99 .3267 Mdot
.99 .3267 Mdot
.99 .32823 Mdot
.99 .32834 Mdot
.99 .3287 Mdot
.99 .32896 Mdot
.99 .329 Mdot
.99 .33021 Mdot
.99 .33041 Mdot
.99 .33098 Mdot
.99 .33116 Mdot
.99 .33131 Mdot
.99 .33227 Mdot
.99 .33559 Mdot
.99 .33572 Mdot
.99 .33605 Mdot
.99 .33606 Mdot
.99 .33644 Mdot
.99 .33667 Mdot
.99 .33671 Mdot
.99 .33673 Mdot
.99 .33675 Mdot
.99 .33683 Mdot
.99 .33784 Mdot
.99 .33866 Mdot
.99 .33883 Mdot
.99 .33906 Mdot
.99 .34349 Mdot
.99 .34349 Mdot
.99 .34542 Mdot
.99 .34586 Mdot
.99 .34662 Mdot
.99 .34691 Mdot
.99 .34801 Mdot
.99 .34868 Mdot
.99 .35032 Mdot
.99 .35142 Mdot
.99 .35223 Mdot
.99 .35242 Mdot
.99 .35632 Mdot
.99 .35644 Mdot
.99 .35757 Mdot
.99 .35793 Mdot
.99 .35907 Mdot
.99 .35987 Mdot
.99 .36287 Mdot
.99 .36417 Mdot
.99 .36661 Mdot
.99 .36789 Mdot
.99 .36945 Mdot
.99 .36985 Mdot
.99 .37549 Mdot
.99 .37874 Mdot
.99 .37967 Mdot
.99 .38009 Mdot
.99 .38085 Mdot
.99 .38324 Mdot
.99 .38384 Mdot
.99 .38395 Mdot
.99 .38555 Mdot
.99 .39076 Mdot
.99 .39148 Mdot
.99 .39192 Mdot
.99 .39193 Mdot
.99 .39204 Mdot
.99 .39204 Mdot
.99 .39243 Mdot
.99 .3933 Mdot
.99 .39353 Mdot
.99 .3949 Mdot
.99 .39499 Mdot
.99 .39517 Mdot
.99 .39723 Mdot
.99 .40123 Mdot
.99 .40279 Mdot
.99 .40319 Mdot
.99 .40436 Mdot
.99 .40439 Mdot
.99 .40496 Mdot
.99 .40524 Mdot
.99 .40656 Mdot
.99 .4091 Mdot
.99 .41027 Mdot
.99 .41148 Mdot
.99 .41213 Mdot
.99 .41229 Mdot
.99 .41251 Mdot
.99 .41391 Mdot
.99 .41482 Mdot
.99 .41549 Mdot
.99 .41778 Mdot
.99 .41865 Mdot
.99 .41938 Mdot
.99 .4196 Mdot
.99 .41969 Mdot
.99 .42132 Mdot
.99 .42142 Mdot
.99 .4215 Mdot
.99 .42244 Mdot
.99 .42261 Mdot
.99 .42275 Mdot
.99 .42296 Mdot
.99 .42466 Mdot
.99 .42559 Mdot
.99 .42561 Mdot
.99 .42575 Mdot
.99 .42576 Mdot
.99 .42957 Mdot
.99 .42992 Mdot
.99 .43115 Mdot
.99 .4321 Mdot
.99 .43213 Mdot
.99 .43655 Mdot
.99 .4378 Mdot
.99 .4403 Mdot
.99 .4404 Mdot
.99 .44043 Mdot
.99 .44072 Mdot
.99 .4411 Mdot
.99 .44112 Mdot
.99 .44334 Mdot
.99 .44347 Mdot
.99 .44518 Mdot
.99 .44653 Mdot
.99 .44741 Mdot
.99 .44772 Mdot
.99 .44842 Mdot
.99 .44845 Mdot
.99 .44937 Mdot
.99 .452 Mdot
.99 .45203 Mdot
.99 .4522 Mdot
.99 .45275 Mdot
.99 .45278 Mdot
.99 .45354 Mdot
.99 .45401 Mdot
.99 .4549 Mdot
.99 .45563 Mdot
.99 .45636 Mdot
.99 .45742 Mdot
.99 .45771 Mdot
.99 .45779 Mdot
.99 .45781 Mdot
.99 .45957 Mdot
.99 .46006 Mdot
.99 .46049 Mdot
.99 .46197 Mdot
.99 .46204 Mdot
.99 .4631 Mdot
.99 .46311 Mdot
.99 .46343 Mdot
.99 .46345 Mdot
.99 .4635 Mdot
.99 .46468 Mdot
.99 .46527 Mdot
.99 .46853 Mdot
.99 .47029 Mdot
.99 .47035 Mdot
.99 .47165 Mdot
.99 .47172 Mdot
.99 .47222 Mdot
.99 .47225 Mdot
.99 .47317 Mdot
.99 .47389 Mdot
.99 .47623 Mdot
.99 .4764 Mdot
.99 .47668 Mdot
.99 .47721 Mdot
.99 .47884 Mdot
.99 .47953 Mdot
.99 .47977 Mdot
.99 .48029 Mdot
.99 .48371 Mdot
.99 .48378 Mdot
.99 .48382 Mdot
.99 .4845 Mdot
.99 .48502 Mdot
.99 .48507 Mdot
.99 .48508 Mdot
.99 .48526 Mdot
.99 .48838 Mdot
.99 .48843 Mdot
.99 .48965 Mdot
.99 .49013 Mdot
.99 .49182 Mdot
.99 .49486 Mdot
.99 .49802 Mdot
.99 .49877 Mdot
.99 .49892 Mdot
.99 .49935 Mdot
.99 .4994 Mdot
.99 .50098 Mdot
.99 .50129 Mdot
.99 .50301 Mdot
.99 .50341 Mdot
.99 .50357 Mdot
.99 .5043 Mdot
.99 .50597 Mdot
.99 .50606 Mdot
.99 .50612 Mdot
.99 .5068 Mdot
.99 .50683 Mdot
.99 .50686 Mdot
.99 .50885 Mdot
.99 .50897 Mdot
.99 .50918 Mdot
.99 .5097 Mdot
.99 .50972 Mdot
.99 .50994 Mdot
.99 .50998 Mdot
.99 .51087 Mdot
.99 .51144 Mdot
.99 .5118 Mdot
.99 .51295 Mdot
.99 .51409 Mdot
.99 .51433 Mdot
.99 .51442 Mdot
.99 .51463 Mdot
.99 .5149 Mdot
.99 .51564 Mdot
.99 .51633 Mdot
.99 .51645 Mdot
.99 .51655 Mdot
.99 .51661 Mdot
.99 .51735 Mdot
.99 .51907 Mdot
.99 .5192 Mdot
.99 .51933 Mdot
.99 .51954 Mdot
.99 .51996 Mdot
.99 .52062 Mdot
.99 .52101 Mdot
.99 .52117 Mdot
.99 .52126 Mdot
.99 .52191 Mdot
.99 .52273 Mdot
.99 .52302 Mdot
.99 .52303 Mdot
.99 .52351 Mdot
.99 .52364 Mdot
.99 .52399 Mdot
.99 .52501 Mdot
.99 .52526 Mdot
.99 .52621 Mdot
.99 .52751 Mdot
.99 .52809 Mdot
.99 .52857 Mdot
.99 .5295 Mdot
.99 .52981 Mdot
.99 .52993 Mdot
.99 .53004 Mdot
.99 .53093 Mdot
.99 .53261 Mdot
.99 .533 Mdot
.99 .53421 Mdot
.99 .53432 Mdot
.99 .53614 Mdot
.99 .53614 Mdot
.99 .53762 Mdot
.99 .53798 Mdot
.99 .53813 Mdot
.99 .53935 Mdot
.99 .53972 Mdot
.99 .54045 Mdot
.99 .54049 Mdot
.99 .54172 Mdot
.99 .542 Mdot
.99 .54251 Mdot
.99 .54337 Mdot
.99 .54448 Mdot
.99 .54805 Mdot
.99 .5489 Mdot
.99 .54936 Mdot
.99 .54978 Mdot
.99 .55007 Mdot
.99 .5518 Mdot
.99 .55201 Mdot
.99 .55211 Mdot
.99 .5537 Mdot
.99 .55396 Mdot
.99 .55495 Mdot
.99 .55499 Mdot
.99 .55539 Mdot
.99 .55539 Mdot
.99 .55552 Mdot
.99 .55553 Mdot
.99 .55555 Mdot
.99 .55602 Mdot
.99 .55683 Mdot
.99 .55865 Mdot
.99 .5592 Mdot
.99 .55943 Mdot
.99 .56022 Mdot
.99 .56233 Mdot
.99 .56242 Mdot
.99 .56376 Mdot
.99 .56399 Mdot
.99 .56406 Mdot
.99 .56417 Mdot
.99 .56478 Mdot
.99 .56489 Mdot
.99 .56715 Mdot
.99 .56788 Mdot
.99 .568 Mdot
.99 .56829 Mdot
.99 .56865 Mdot
.99 .56877 Mdot
.99 .56917 Mdot
.99 .56937 Mdot
.99 .56997 Mdot
.99 .57055 Mdot
.99 .57093 Mdot
.99 .57141 Mdot
.99 .57198 Mdot
.99 .57217 Mdot
.99 .57459 Mdot
.99 .57532 Mdot
.99 .57573 Mdot
.99 .57666 Mdot
.99 .5769 Mdot
.99 .57705 Mdot
.99 .57737 Mdot
.99 .57863 Mdot
.99 .57873 Mdot
.99 .57964 Mdot
.99 .5803 Mdot
.99 .58032 Mdot
.99 .5809 Mdot
.99 .58101 Mdot
.99 .58151 Mdot
.99 .58248 Mdot
.99 .58276 Mdot
.99 .58324 Mdot
.99 .58441 Mdot
.99 .58449 Mdot
.99 .5846 Mdot
.99 .58464 Mdot
.99 .58515 Mdot
.99 .5859 Mdot
.99 .58591 Mdot
.99 .58615 Mdot
.99 .58689 Mdot
.99 .58697 Mdot
.99 .58702 Mdot
.99 .58707 Mdot
.99 .58784 Mdot
.99 .58937 Mdot
.99 .58948 Mdot
.99 .58984 Mdot
.99 .58992 Mdot
.99 .58995 Mdot
.99 .59019 Mdot
.99 .59033 Mdot
.99 .59034 Mdot
.99 .59053 Mdot
.99 .59057 Mdot
.99 .59075 Mdot
.99 .59081 Mdot
.99 .59086 Mdot
.99 .59096 Mdot
.99 .59144 Mdot
.99 .59147 Mdot
.99 .59162 Mdot
.99 .59183 Mdot
.99 .59191 Mdot
.99 .59226 Mdot
.99 .59241 Mdot
.99 .59242 Mdot
.99 .59255 Mdot
.99 .59259 Mdot
.99 .59261 Mdot
.99 .59294 Mdot
.99 .59307 Mdot
.99 .59315 Mdot
.99 .59347 Mdot
.99 .59362 Mdot
.99 .59378 Mdot
.99 .59408 Mdot
.99 .59408 Mdot
.99 .59439 Mdot
.99 .59504 Mdot
.99 .59577 Mdot
.99 .59602 Mdot
.99 .59611 Mdot
.99 .59618 Mdot
.99 .59651 Mdot
.99 .5969 Mdot
.99 .59692 Mdot
.99 .59693 Mdot
.99 .59694 Mdot
.99 .59695 Mdot
.99 .59695 Mdot
.99 .59704 Mdot
.99 .59718 Mdot
.99 .59718 Mdot
.99 .59726 Mdot
.99 .59731 Mdot
.99 .59735 Mdot
.99 .59761 Mdot
.99 .59762 Mdot
.99 .59777 Mdot
.99 .59823 Mdot
.99 .59847 Mdot
.99 .59847 Mdot
.99 .59877 Mdot
.99 .59882 Mdot
.99 .59886 Mdot
.99 .59887 Mdot
.99 .59904 Mdot
.99 .5991 Mdot
.99 .59925 Mdot
.99 .59934 Mdot
.99 .59944 Mdot
.99 .59945 Mdot
.99 .59952 Mdot
.99 .59961 Mdot
.99 .59962 Mdot
.99 .59964 Mdot
.99 .59972 Mdot
.99 .60002 Mdot
.99 .60002 Mdot
.99 .60003 Mdot
.99 .60005 Mdot
.99 .60006 Mdot
.99 .60007 Mdot
.99 .60023 Mdot
.99 .60026 Mdot
.99 .6003 Mdot
.99 .60057 Mdot
.99 .60071 Mdot
.99 .60076 Mdot
.99 .60077 Mdot
.99 .60102 Mdot
.99 .60105 Mdot
.99 .60109 Mdot
.99 .6011 Mdot
.99 .60114 Mdot
.99 .60116 Mdot
.99 .60122 Mdot
.99 .60131 Mdot
.99 .60132 Mdot
.99 .60137 Mdot
.99 .60139 Mdot
.99 .60141 Mdot
.99 .60163 Mdot
.99 .60171 Mdot
.99 .60172 Mdot
.99 .60177 Mdot
.99 .60178 Mdot
.99 .60179 Mdot
.99 .60181 Mdot
.99 .60182 Mdot
.99 .60186 Mdot
.99 .60186 Mdot
.99 .60189 Mdot
.99 .60191 Mdot
.99 .60191 Mdot
.99 .60193 Mdot
.99 .60194 Mdot
.99 .60195 Mdot
.99 .60197 Mdot
.99 .60202 Mdot
.99 .60205 Mdot
.99 .60206 Mdot
.99 .6021 Mdot
.99 .60211 Mdot
.99 .60212 Mdot
.99 .60213 Mdot
.99 .60213 Mdot
.99 .60214 Mdot
.99 .60214 Mdot
.99 .60214 Mdot
.99 .60214 Mdot
.99 .60214 Mdot
.99 .60214 Mdot
.992 .01848 Mdot
.992 .01853 Mdot
.992 .01854 Mdot
.992 .01862 Mdot
.992 .01874 Mdot
.992 .01879 Mdot
.992 .01883 Mdot
.992 .01884 Mdot
.992 .01897 Mdot
.992 .01903 Mdot
.992 .01919 Mdot
.992 .01926 Mdot
.992 .01944 Mdot
.992 .01945 Mdot
.992 .01977 Mdot
.992 .01993 Mdot
.992 .02015 Mdot
.992 .02053 Mdot
.992 .02139 Mdot
.992 .02142 Mdot
.992 .02153 Mdot
.992 .0222 Mdot
.992 .02235 Mdot
.992 .02253 Mdot
.992 .02324 Mdot
.992 .02342 Mdot
.992 .02397 Mdot
.992 .02466 Mdot
.992 .02473 Mdot
.992 .0256 Mdot
.992 .02685 Mdot
.992 .02686 Mdot
.992 .02844 Mdot
.992 .02874 Mdot
.992 .02881 Mdot
.992 .0292 Mdot
.992 .02965 Mdot
.992 .02985 Mdot
.992 .0299 Mdot
.992 .03018 Mdot
.992 .03019 Mdot
.992 .0305 Mdot
.992 .03067 Mdot
.992 .03088 Mdot
.992 .03105 Mdot
.992 .03107 Mdot
.992 .0316 Mdot
.992 .03181 Mdot
.992 .03245 Mdot
.992 .03275 Mdot
.992 .03345 Mdot
.992 .03349 Mdot
.992 .03349 Mdot
.992 .03393 Mdot
.992 .03422 Mdot
.992 .03473 Mdot
.992 .03477 Mdot
.992 .03536 Mdot
.992 .03621 Mdot
.992 .03654 Mdot
.992 .03705 Mdot
.992 .03755 Mdot
.992 .03772 Mdot
.992 .03869 Mdot
.992 .03893 Mdot
.992 .03893 Mdot
.992 .04108 Mdot
.992 .04115 Mdot
.992 .0412 Mdot
.992 .04137 Mdot
.992 .04161 Mdot
.992 .04218 Mdot
.992 .04228 Mdot
.992 .04379 Mdot
.992 .04424 Mdot
.992 .04429 Mdot
.992 .04468 Mdot
.992 .04482 Mdot
.992 .04552 Mdot
.992 .04574 Mdot
.992 .0468 Mdot
.992 .04753 Mdot
.992 .0478 Mdot
.992 .04788 Mdot
.992 .04827 Mdot
.992 .04863 Mdot
.992 .04896 Mdot
.992 .05001 Mdot
.992 .05013 Mdot
.992 .0511 Mdot
.992 .05143 Mdot
.992 .0519 Mdot
.992 .05251 Mdot
.992 .05377 Mdot
.992 .05402 Mdot
.992 .05405 Mdot
.992 .05463 Mdot
.992 .0555 Mdot
.992 .05552 Mdot
.992 .05584 Mdot
.992 .05595 Mdot
.992 .05636 Mdot
.992 .05737 Mdot
.992 .05822 Mdot
.992 .0585 Mdot
.992 .0589 Mdot
.992 .05969 Mdot
.992 .05976 Mdot
.992 .06065 Mdot
.992 .06109 Mdot
.992 .06122 Mdot
.992 .06127 Mdot
.992 .06127 Mdot
.992 .06213 Mdot
.992 .06219 Mdot
.992 .06222 Mdot
.992 .06401 Mdot
.992 .06553 Mdot
.992 .06591 Mdot
.992 .0678 Mdot
.992 .06814 Mdot
.992 .06824 Mdot
.992 .06885 Mdot
.992 .06917 Mdot
.992 .06939 Mdot
.992 .06962 Mdot
.992 .06967 Mdot
.992 .07113 Mdot
.992 .07284 Mdot
.992 .07297 Mdot
.992 .07353 Mdot
.992 .07359 Mdot
.992 .07362 Mdot
.992 .07381 Mdot
.992 .07487 Mdot
.992 .07491 Mdot
.992 .07517 Mdot
.992 .07608 Mdot
.992 .07632 Mdot
.992 .0764 Mdot
.992 .07647 Mdot
.992 .07673 Mdot
.992 .0773 Mdot
.992 .07751 Mdot
.992 .07813 Mdot
.992 .0782 Mdot
.992 .07821 Mdot
.992 .07949 Mdot
.992 .07955 Mdot
.992 .08021 Mdot
.992 .0804 Mdot
.992 .08101 Mdot
.992 .08174 Mdot
.992 .08223 Mdot
.992 .08285 Mdot
.992 .08321 Mdot
.992 .0834 Mdot
.992 .08361 Mdot
.992 .08398 Mdot
.992 .08411 Mdot
.992 .08453 Mdot
.992 .08464 Mdot
.992 .08465 Mdot
.992 .08524 Mdot
.992 .08658 Mdot
.992 .08716 Mdot
.992 .08729 Mdot
.992 .0873 Mdot
.992 .08755 Mdot
.992 .0885 Mdot
.992 .08896 Mdot
.992 .0892 Mdot
.992 .09004 Mdot
.992 .09076 Mdot
.992 .09195 Mdot
.992 .09207 Mdot
.992 .09371 Mdot
.992 .09427 Mdot
.992 .09742 Mdot
.992 .09863 Mdot
.992 .09896 Mdot
.992 .09947 Mdot
.992 .09955 Mdot
.992 .09996 Mdot
.992 .1005 Mdot
.992 .10055 Mdot
.992 .10088 Mdot
.992 .10191 Mdot
.992 .10238 Mdot
.992 .10292 Mdot
.992 .10301 Mdot
.992 .10323 Mdot
.992 .10548 Mdot
.992 .10655 Mdot
.992 .10743 Mdot
.992 .10743 Mdot
.992 .10862 Mdot
.992 .10977 Mdot
.992 .11001 Mdot
.992 .11167 Mdot
.992 .11172 Mdot
.992 .11192 Mdot
.992 .11493 Mdot
.992 .11528 Mdot
.992 .11541 Mdot
.992 .11557 Mdot
.992 .11573 Mdot
.992 .11581 Mdot
.992 .11634 Mdot
.992 .11718 Mdot
.992 .11723 Mdot
.992 .11731 Mdot
.992 .11927 Mdot
.992 .11962 Mdot
.992 .11964 Mdot
.992 .1219 Mdot
.992 .12203 Mdot
.992 .12334 Mdot
.992 .12356 Mdot
.992 .12411 Mdot
.992 .12461 Mdot
.992 .12509 Mdot
.992 .12627 Mdot
.992 .12673 Mdot
.992 .1269 Mdot
.992 .12769 Mdot
.992 .12831 Mdot
.992 .12833 Mdot
.992 .1288 Mdot
.992 .13131 Mdot
.992 .13209 Mdot
.992 .13244 Mdot
.992 .13269 Mdot
.992 .13293 Mdot
.992 .13399 Mdot
.992 .13588 Mdot
.992 .13698 Mdot
.992 .13709 Mdot
.992 .13729 Mdot
.992 .13739 Mdot
.992 .13778 Mdot
.992 .1378 Mdot
.992 .13846 Mdot
.992 .13943 Mdot
.992 .13964 Mdot
.992 .13972 Mdot
.992 .14109 Mdot
.992 .14236 Mdot
.992 .14274 Mdot
.992 .14282 Mdot
.992 .14352 Mdot
.992 .1442 Mdot
.992 .14422 Mdot
.992 .14436 Mdot
.992 .14452 Mdot
.992 .14644 Mdot
.992 .14653 Mdot
.992 .14721 Mdot
.992 .14764 Mdot
.992 .1494 Mdot
.992 .14959 Mdot
.992 .15103 Mdot
.992 .15222 Mdot
.992 .1526 Mdot
.992 .15351 Mdot
.992 .15383 Mdot
.992 .15539 Mdot
.992 .15578 Mdot
.992 .15596 Mdot
.992 .15615 Mdot
.992 .15703 Mdot
.992 .15833 Mdot
.992 .15919 Mdot
.992 .15973 Mdot
.992 .16036 Mdot
.992 .16081 Mdot
.992 .1612 Mdot
.992 .16131 Mdot
.992 .16332 Mdot
.992 .16518 Mdot
.992 .16596 Mdot
.992 .16604 Mdot
.992 .16632 Mdot
.992 .16639 Mdot
.992 .16749 Mdot
.992 .16786 Mdot
.992 .16926 Mdot
.992 .16996 Mdot
.992 .17217 Mdot
.992 .17272 Mdot
.992 .17306 Mdot
.992 .17345 Mdot
.992 .1752 Mdot
.992 .17561 Mdot
.992 .17562 Mdot
.992 .17657 Mdot
.992 .17792 Mdot
.992 .18062 Mdot
.992 .18062 Mdot
.992 .18084 Mdot
.992 .18212 Mdot
.992 .18265 Mdot
.992 .18289 Mdot
.992 .1834 Mdot
.992 .18369 Mdot
.992 .18385 Mdot
.992 .1853 Mdot
.992 .18533 Mdot
.992 .18577 Mdot
.992 .18593 Mdot
.992 .18594 Mdot
.992 .18595 Mdot
.992 .18627 Mdot
.992 .1875 Mdot
.992 .18816 Mdot
.992 .18816 Mdot
.992 .1886 Mdot
.992 .18883 Mdot
.992 .18901 Mdot
.992 .18912 Mdot
.992 .18916 Mdot
.992 .18925 Mdot
.992 .18967 Mdot
.992 .1951 Mdot
.992 .19601 Mdot
.992 .19767 Mdot
.992 .19929 Mdot
.992 .20014 Mdot
.992 .20139 Mdot
.992 .20547 Mdot
.992 .20674 Mdot
.992 .20758 Mdot
.992 .20759 Mdot
.992 .20872 Mdot
.992 .20903 Mdot
.992 .21103 Mdot
.992 .21206 Mdot
.992 .2123 Mdot
.992 .2127 Mdot
.992 .21278 Mdot
.992 .21354 Mdot
.992 .2137 Mdot
.992 .21623 Mdot
.992 .21665 Mdot
.992 .21818 Mdot
.992 .21841 Mdot
.992 .21865 Mdot
.992 .21915 Mdot
.992 .22005 Mdot
.992 .22135 Mdot
.992 .22157 Mdot
.992 .22392 Mdot
.992 .22436 Mdot
.992 .22614 Mdot
.992 .22616 Mdot
.992 .22631 Mdot
.992 .22643 Mdot
.992 .22693 Mdot
.992 .22702 Mdot
.992 .22784 Mdot
.992 .2279 Mdot
.992 .22845 Mdot
.992 .22981 Mdot
.992 .23041 Mdot
.992 .23051 Mdot
.992 .23076 Mdot
.992 .23137 Mdot
.992 .23246 Mdot
.992 .23424 Mdot
.992 .23439 Mdot
.992 .23464 Mdot
.992 .23501 Mdot
.992 .23526 Mdot
.992 .23548 Mdot
.992 .23629 Mdot
.992 .23806 Mdot
.992 .23809 Mdot
.992 .23866 Mdot
.992 .23871 Mdot
.992 .23875 Mdot
.992 .24068 Mdot
.992 .2408 Mdot
.992 .24083 Mdot
.992 .24089 Mdot
.992 .24092 Mdot
.992 .24184 Mdot
.992 .24217 Mdot
.992 .2438 Mdot
.992 .24478 Mdot
.992 .24494 Mdot
.992 .24511 Mdot
.992 .2456 Mdot
.992 .24718 Mdot
.992 .24776 Mdot
.992 .24899 Mdot
.992 .24965 Mdot
.992 .25005 Mdot
.992 .25191 Mdot
.992 .25202 Mdot
.992 .25274 Mdot
.992 .25342 Mdot
.992 .25533 Mdot
.992 .25643 Mdot
.992 .25702 Mdot
.992 .25729 Mdot
.992 .25765 Mdot
.992 .25855 Mdot
.992 .25878 Mdot
.992 .25878 Mdot
.992 .25919 Mdot
.992 .26047 Mdot
.992 .26081 Mdot
.992 .26083 Mdot
.992 .26261 Mdot
.992 .26329 Mdot
.992 .26331 Mdot
.992 .26566 Mdot
.992 .26581 Mdot
.992 .26666 Mdot
.992 .26684 Mdot
.992 .26842 Mdot
.992 .26883 Mdot
.992 .26885 Mdot
.992 .26959 Mdot
.992 .27151 Mdot
.992 .27213 Mdot
.992 .27244 Mdot
.992 .27383 Mdot
.992 .27454 Mdot
.992 .2758 Mdot
.992 .27705 Mdot
.992 .27768 Mdot
.992 .27792 Mdot
.992 .27917 Mdot
.992 .28137 Mdot
.992 .28154 Mdot
.992 .28232 Mdot
.992 .28268 Mdot
.992 .28305 Mdot
.992 .28785 Mdot
.992 .28904 Mdot
.992 .2894 Mdot
.992 .28947 Mdot
.992 .29473 Mdot
.992 .29547 Mdot
.992 .29571 Mdot
.992 .29702 Mdot
.992 .29837 Mdot
.992 .29855 Mdot
.992 .29861 Mdot
.992 .30207 Mdot
.992 .30301 Mdot
.992 .30447 Mdot
.992 .3047 Mdot
.992 .30532 Mdot
.992 .30586 Mdot
.992 .30737 Mdot
.992 .30751 Mdot
.992 .30846 Mdot
.992 .31135 Mdot
.992 .31247 Mdot
.992 .31268 Mdot
.992 .31418 Mdot
.992 .31445 Mdot
.992 .31505 Mdot
.992 .31637 Mdot
.992 .3169 Mdot
.992 .31776 Mdot
.992 .32078 Mdot
.992 .32129 Mdot
.992 .32418 Mdot
.992 .32426 Mdot
.992 .32529 Mdot
.992 .32667 Mdot
.992 .32667 Mdot
.992 .32827 Mdot
.992 .3299 Mdot
.992 .33267 Mdot
.992 .33302 Mdot
.992 .33325 Mdot
.992 .33367 Mdot
.992 .33814 Mdot
.992 .33828 Mdot
.992 .3388 Mdot
.992 .3398 Mdot
.992 .34161 Mdot
.992 .34203 Mdot
.992 .34218 Mdot
.992 .34265 Mdot
.992 .34342 Mdot
.992 .34446 Mdot
.992 .34478 Mdot
.992 .34635 Mdot
.992 .34636 Mdot
.992 .34658 Mdot
.992 .34678 Mdot
.992 .34772 Mdot
.992 .34786 Mdot
.992 .34805 Mdot
.992 .34847 Mdot
.992 .3489 Mdot
.992 .34912 Mdot
.992 .3492 Mdot
.992 .35049 Mdot
.992 .35269 Mdot
.992 .35283 Mdot
.992 .35303 Mdot
.992 .35449 Mdot
.992 .3559 Mdot
.992 .35593 Mdot
.992 .35596 Mdot
.992 .3563 Mdot
.992 .35667 Mdot
.992 .35811 Mdot
.992 .3583 Mdot
.992 .35855 Mdot
.992 .35869 Mdot
.992 .35899 Mdot
.992 .35904 Mdot
.992 .36 Mdot
.992 .36479 Mdot
.992 .36482 Mdot
.992 .36497 Mdot
.992 .36516 Mdot
.992 .36566 Mdot
.992 .36691 Mdot
.992 .36846 Mdot
.992 .36902 Mdot
.992 .3691 Mdot
.992 .37011 Mdot
.992 .3704 Mdot
.992 .3709 Mdot
.992 .37165 Mdot
.992 .37239 Mdot
.992 .37285 Mdot
.992 .37378 Mdot
.992 .37443 Mdot
.992 .37572 Mdot
.992 .37579 Mdot
.992 .37692 Mdot
.992 .37736 Mdot
.992 .37791 Mdot
.992 .37884 Mdot
.992 .37887 Mdot
.992 .37929 Mdot
.992 .38081 Mdot
.992 .38087 Mdot
.992 .38201 Mdot
.992 .38267 Mdot
.992 .3841 Mdot
.992 .38533 Mdot
.992 .38555 Mdot
.992 .38811 Mdot
.992 .38999 Mdot
.992 .39033 Mdot
.992 .39041 Mdot
.992 .39084 Mdot
.992 .39143 Mdot
.992 .3916 Mdot
.992 .39201 Mdot
.992 .39454 Mdot
.992 .39614 Mdot
.992 .39788 Mdot
.992 .39899 Mdot
.992 .3995 Mdot
.992 .40018 Mdot
.992 .40023 Mdot
.992 .40157 Mdot
.992 .40182 Mdot
.992 .40195 Mdot
.992 .40229 Mdot
.992 .40253 Mdot
.992 .40295 Mdot
.992 .40343 Mdot
.992 .40349 Mdot
.992 .40448 Mdot
.992 .405 Mdot
.992 .40501 Mdot
.992 .40618 Mdot
.992 .40726 Mdot
.992 .40773 Mdot
.992 .40791 Mdot
.992 .40936 Mdot
.992 .41101 Mdot
.992 .41105 Mdot
.992 .41241 Mdot
.992 .41343 Mdot
.992 .41387 Mdot
.992 .41393 Mdot
.992 .41475 Mdot
.992 .41479 Mdot
.992 .41497 Mdot
.992 .41655 Mdot
.992 .41806 Mdot
.992 .41812 Mdot
.992 .41842 Mdot
.992 .41878 Mdot
.992 .42306 Mdot
.992 .42326 Mdot
.992 .42396 Mdot
.992 .42474 Mdot
.992 .425 Mdot
.992 .42569 Mdot
.992 .42671 Mdot
.992 .42685 Mdot
.992 .42951 Mdot
.992 .42993 Mdot
.992 .43022 Mdot
.992 .43218 Mdot
.992 .43264 Mdot
.992 .43304 Mdot
.992 .43415 Mdot
.992 .43556 Mdot
.992 .43623 Mdot
.992 .43638 Mdot
.992 .43668 Mdot
.992 .4383 Mdot
.992 .43864 Mdot
.992 .43893 Mdot
.992 .43898 Mdot
.992 .4401 Mdot
.992 .44039 Mdot
.992 .44187 Mdot
.992 .44225 Mdot
.992 .44306 Mdot
.992 .44343 Mdot
.992 .44355 Mdot
.992 .44383 Mdot
.992 .44555 Mdot
.992 .44566 Mdot
.992 .44833 Mdot
.992 .44874 Mdot
.992 .44959 Mdot
.992 .45006 Mdot
.992 .45105 Mdot
.992 .45116 Mdot
.992 .45243 Mdot
.992 .45334 Mdot
.992 .45413 Mdot
.992 .45434 Mdot
.992 .45836 Mdot
.992 .45908 Mdot
.992 .4595 Mdot
.992 .46105 Mdot
.992 .46202 Mdot
.992 .46282 Mdot
.992 .46353 Mdot
.992 .46367 Mdot
.992 .46423 Mdot
.992 .46436 Mdot
.992 .46529 Mdot
.992 .4655 Mdot
.992 .46648 Mdot
.992 .46718 Mdot
.992 .4674 Mdot
.992 .46831 Mdot
.992 .46986 Mdot
.992 .46992 Mdot
.992 .4707 Mdot
.992 .47118 Mdot
.992 .47531 Mdot
.992 .4757 Mdot
.992 .4759 Mdot
.992 .47634 Mdot
.992 .47696 Mdot
.992 .47768 Mdot
.992 .47907 Mdot
.992 .47957 Mdot
.992 .4798 Mdot
.992 .48046 Mdot
.992 .48089 Mdot
.992 .48162 Mdot
.992 .48165 Mdot
.992 .48194 Mdot
.992 .48262 Mdot
.992 .48336 Mdot
.992 .48527 Mdot
.992 .48577 Mdot
.992 .4858 Mdot
.992 .48778 Mdot
.992 .48787 Mdot
.992 .48838 Mdot
.992 .48897 Mdot
.992 .49052 Mdot
.992 .49053 Mdot
.992 .4909 Mdot
.992 .49179 Mdot
.992 .49231 Mdot
.992 .49257 Mdot
.992 .49313 Mdot
.992 .49373 Mdot
.992 .49404 Mdot
.992 .49444 Mdot
.992 .49531 Mdot
.992 .4958 Mdot
.992 .49608 Mdot
.992 .49614 Mdot
.992 .49802 Mdot
.992 .49853 Mdot
.992 .49859 Mdot
.992 .49868 Mdot
.992 .49932 Mdot
.992 .49946 Mdot
.992 .49959 Mdot
.992 .4996 Mdot
.992 .49962 Mdot
.992 .50016 Mdot
.992 .50219 Mdot
.992 .5027 Mdot
.992 .50319 Mdot
.992 .50327 Mdot
.992 .50327 Mdot
.992 .50387 Mdot
.992 .50399 Mdot
.992 .50438 Mdot
.992 .50467 Mdot
.992 .50485 Mdot
.992 .50491 Mdot
.992 .50506 Mdot
.992 .50574 Mdot
.992 .50818 Mdot
.992 .50839 Mdot
.992 .51001 Mdot
.992 .5111 Mdot
.992 .51151 Mdot
.992 .51274 Mdot
.992 .51383 Mdot
.992 .51414 Mdot
.992 .51433 Mdot
.992 .51573 Mdot
.992 .51826 Mdot
.992 .52063 Mdot
.992 .52069 Mdot
.992 .52116 Mdot
.992 .52162 Mdot
.992 .5217 Mdot
.992 .52196 Mdot
.992 .52379 Mdot
.992 .52392 Mdot
.992 .52621 Mdot
.992 .52647 Mdot
.992 .52653 Mdot
.992 .5277 Mdot
.992 .52778 Mdot
.992 .52841 Mdot
.992 .52964 Mdot
.992 .52985 Mdot
.992 .5314 Mdot
.992 .53174 Mdot
.992 .53179 Mdot
.992 .53257 Mdot
.992 .53257 Mdot
.992 .53406 Mdot
.992 .53413 Mdot
.992 .53454 Mdot
.992 .53602 Mdot
.992 .53626 Mdot
.992 .5369 Mdot
.992 .53724 Mdot
.992 .53833 Mdot
.992 .53859 Mdot
.992 .53891 Mdot
.992 .53943 Mdot
.992 .53953 Mdot
.992 .53986 Mdot
.992 .53987 Mdot
.992 .54053 Mdot
.992 .54055 Mdot
.992 .54074 Mdot
.992 .54183 Mdot
.992 .5419 Mdot
.992 .54251 Mdot
.992 .54305 Mdot
.992 .54335 Mdot
.992 .54378 Mdot
.992 .54395 Mdot
.992 .54397 Mdot
.992 .54425 Mdot
.992 .54449 Mdot
.992 .54593 Mdot
.992 .54599 Mdot
.992 .5464 Mdot
.992 .54668 Mdot
.992 .54683 Mdot
.992 .54698 Mdot
.992 .54745 Mdot
.992 .54758 Mdot
.992 .54867 Mdot
.992 .54879 Mdot
.992 .55024 Mdot
.992 .5505 Mdot
.992 .55088 Mdot
.992 .55276 Mdot
.992 .55325 Mdot
.992 .55375 Mdot
.992 .55565 Mdot
.992 .55577 Mdot
.992 .5558 Mdot
.992 .55597 Mdot
.992 .5561 Mdot
.992 .5561 Mdot
.992 .5563 Mdot
.992 .55666 Mdot
.992 .55676 Mdot
.992 .55695 Mdot
.992 .55743 Mdot
.992 .55752 Mdot
.992 .55767 Mdot
.992 .55774 Mdot
.992 .55789 Mdot
.992 .55834 Mdot
.992 .55981 Mdot
.992 .55993 Mdot
.992 .56045 Mdot
.992 .56056 Mdot
.992 .56083 Mdot
.992 .56147 Mdot
.992 .56261 Mdot
.992 .56263 Mdot
.992 .56286 Mdot
.992 .56413 Mdot
.992 .56444 Mdot
.992 .5646 Mdot
.992 .56484 Mdot
.992 .56522 Mdot
.992 .56547 Mdot
.992 .56558 Mdot
.992 .56569 Mdot
.992 .56623 Mdot
.992 .56649 Mdot
.992 .56735 Mdot
.992 .5674 Mdot
.992 .56822 Mdot
.992 .56824 Mdot
.992 .56879 Mdot
.992 .56884 Mdot
.992 .56887 Mdot
.992 .56888 Mdot
.992 .56927 Mdot
.992 .5693 Mdot
.992 .57017 Mdot
.992 .57069 Mdot
.992 .5707 Mdot
.992 .5708 Mdot
.992 .57083 Mdot
.992 .57089 Mdot
.992 .57092 Mdot
.992 .57176 Mdot
.992 .57206 Mdot
.992 .57212 Mdot
.992 .57219 Mdot
.992 .57334 Mdot
.992 .57352 Mdot
.992 .57392 Mdot
.992 .57438 Mdot
.992 .57452 Mdot
.992 .57467 Mdot
.992 .57473 Mdot
.992 .57509 Mdot
.992 .57513 Mdot
.992 .57576 Mdot
.992 .5764 Mdot
.992 .57643 Mdot
.992 .57681 Mdot
.992 .57692 Mdot
.992 .57705 Mdot
.992 .57788 Mdot
.992 .57793 Mdot
.992 .57795 Mdot
.992 .5784 Mdot
.992 .57847 Mdot
.992 .57878 Mdot
.992 .57964 Mdot
.992 .58025 Mdot
.992 .58034 Mdot
.992 .58061 Mdot
.992 .58089 Mdot
.992 .58099 Mdot
.992 .58114 Mdot
.992 .58125 Mdot
.992 .58127 Mdot
.992 .58141 Mdot
.992 .58283 Mdot
.992 .58362 Mdot
.992 .58404 Mdot
.992 .58422 Mdot
.992 .58448 Mdot
.992 .58474 Mdot
.992 .5851 Mdot
.992 .58525 Mdot
.992 .58525 Mdot
.992 .5854 Mdot
.992 .58543 Mdot
.992 .58553 Mdot
.992 .58564 Mdot
.992 .58573 Mdot
.992 .5859 Mdot
.992 .58603 Mdot
.992 .58638 Mdot
.992 .58661 Mdot
.992 .58663 Mdot
.992 .58697 Mdot
.992 .58721 Mdot
.992 .58743 Mdot
.992 .58744 Mdot
.992 .58746 Mdot
.992 .58777 Mdot
.992 .58819 Mdot
.992 .5882 Mdot
.992 .58835 Mdot
.992 .58923 Mdot
.992 .58935 Mdot
.992 .58944 Mdot
.992 .58962 Mdot
.992 .58971 Mdot
.992 .59021 Mdot
.992 .59031 Mdot
.992 .5907 Mdot
.992 .5912 Mdot
.992 .59142 Mdot
.992 .59142 Mdot
.992 .59143 Mdot
.992 .59147 Mdot
.992 .59158 Mdot
.992 .59182 Mdot
.992 .59183 Mdot
.992 .59204 Mdot
.992 .59214 Mdot
.992 .59222 Mdot
.992 .5927 Mdot
.992 .59281 Mdot
.992 .59283 Mdot
.992 .59292 Mdot
.992 .59292 Mdot
.992 .59315 Mdot
.992 .5933 Mdot
.992 .5937 Mdot
.992 .59386 Mdot
.992 .59398 Mdot
.992 .59431 Mdot
.992 .59434 Mdot
.992 .5947 Mdot
.992 .59489 Mdot
.992 .59491 Mdot
.992 .59498 Mdot
.992 .59517 Mdot
.992 .59545 Mdot
.992 .59572 Mdot
.992 .59582 Mdot
.992 .59595 Mdot
.992 .59633 Mdot
.992 .59636 Mdot
.992 .59657 Mdot
.992 .59662 Mdot
.992 .59719 Mdot
.992 .59725 Mdot
.992 .59754 Mdot
.992 .59767 Mdot
.992 .5978 Mdot
.992 .59825 Mdot
.992 .59839 Mdot
.992 .59847 Mdot
.992 .59858 Mdot
.992 .59934 Mdot
.992 .59942 Mdot
.992 .59967 Mdot
.992 .59977 Mdot
.992 .59979 Mdot
.992 .59986 Mdot
.992 .60026 Mdot
.992 .60026 Mdot
.992 .60058 Mdot
.992 .6008 Mdot
.992 .60082 Mdot
.992 .60099 Mdot
.992 .60113 Mdot
.992 .60118 Mdot
.992 .60136 Mdot
.992 .6014 Mdot
.992 .60144 Mdot
.992 .60161 Mdot
.992 .60163 Mdot
.992 .60164 Mdot
.992 .60186 Mdot
.992 .60196 Mdot
.992 .60201 Mdot
.992 .60205 Mdot
.992 .60213 Mdot
.992 .60213 Mdot
.992 .60218 Mdot
.992 .6022 Mdot
.992 .60224 Mdot
.992 .60225 Mdot
.992 .60228 Mdot
.992 .60229 Mdot
.992 .6023 Mdot
.992 .60231 Mdot
.992 .60234 Mdot
.992 .60236 Mdot
.992 .60236 Mdot
.992 .60238 Mdot
.994 .01753 Mdot
.994 .01753 Mdot
.994 .01754 Mdot
.994 .01755 Mdot
.994 .01756 Mdot
.994 .01756 Mdot
.994 .0177 Mdot
.994 .01775 Mdot
.994 .01788 Mdot
.994 .01799 Mdot
.994 .01799 Mdot
.994 .01822 Mdot
.994 .01837 Mdot
.994 .01863 Mdot
.994 .01895 Mdot
.994 .01896 Mdot
.994 .01921 Mdot
.994 .01942 Mdot
.994 .01965 Mdot
.994 .0198 Mdot
.994 .02026 Mdot
.994 .02061 Mdot
.994 .02163 Mdot
.994 .02168 Mdot
.994 .02189 Mdot
.994 .02198 Mdot
.994 .02228 Mdot
.994 .02236 Mdot
.994 .02269 Mdot
.994 .02335 Mdot
.994 .02357 Mdot
.994 .02384 Mdot
.994 .02404 Mdot
.994 .02492 Mdot
.994 .02496 Mdot
.994 .02592 Mdot
.994 .02593 Mdot
.994 .02594 Mdot
.994 .026 Mdot
.994 .02602 Mdot
.994 .02603 Mdot
.994 .02614 Mdot
.994 .02659 Mdot
.994 .0267 Mdot
.994 .0267 Mdot
.994 .02673 Mdot
.994 .02679 Mdot
.994 .02729 Mdot
.994 .0273 Mdot
.994 .02771 Mdot
.994 .02775 Mdot
.994 .02796 Mdot
.994 .02814 Mdot
.994 .02855 Mdot
.994 .02863 Mdot
.994 .02866 Mdot
.994 .02887 Mdot
.994 .02923 Mdot
.994 .03027 Mdot
.994 .03152 Mdot
.994 .03155 Mdot
.994 .03162 Mdot
.994 .03209 Mdot
.994 .03238 Mdot
.994 .03248 Mdot
.994 .03255 Mdot
.994 .03265 Mdot
.994 .03337 Mdot
.994 .03416 Mdot
.994 .03427 Mdot
.994 .03485 Mdot
.994 .03527 Mdot
.994 .03533 Mdot
.994 .03591 Mdot
.994 .03616 Mdot
.994 .03665 Mdot
.994 .03716 Mdot
.994 .03788 Mdot
.994 .03804 Mdot
.994 .03869 Mdot
.994 .03985 Mdot
.994 .04053 Mdot
.994 .04202 Mdot
.994 .04224 Mdot
.994 .04305 Mdot
.994 .0434 Mdot
.994 .04367 Mdot
.994 .04454 Mdot
.994 .04481 Mdot
.994 .04485 Mdot
.994 .04487 Mdot
.994 .0451 Mdot
.994 .0457 Mdot
.994 .04602 Mdot
.994 .04615 Mdot
.994 .04785 Mdot
.994 .04821 Mdot
.994 .04872 Mdot
.994 .0495 Mdot
.994 .04956 Mdot
.994 .05061 Mdot
.994 .05138 Mdot
.994 .05182 Mdot
.994 .05191 Mdot
.994 .05442 Mdot
.994 .05479 Mdot
.994 .05493 Mdot
.994 .0553 Mdot
.994 .05582 Mdot
.994 .05743 Mdot
.994 .05794 Mdot
.994 .0586 Mdot
.994 .05865 Mdot
.994 .05866 Mdot
.994 .05869 Mdot
.994 .05893 Mdot
.994 .05902 Mdot
.994 .05904 Mdot
.994 .05949 Mdot
.994 .05952 Mdot
.994 .06028 Mdot
.994 .06029 Mdot
.994 .06031 Mdot
.994 .06121 Mdot
.994 .06134 Mdot
.994 .06161 Mdot
.994 .06164 Mdot
.994 .06175 Mdot
.994 .06189 Mdot
.994 .06198 Mdot
.994 .06269 Mdot
.994 .06284 Mdot
.994 .06343 Mdot
.994 .06351 Mdot
.994 .06389 Mdot
.994 .06392 Mdot
.994 .06551 Mdot
.994 .06564 Mdot
.994 .06592 Mdot
.994 .06646 Mdot
.994 .06715 Mdot
.994 .06717 Mdot
.994 .06792 Mdot
.994 .06808 Mdot
.994 .0687 Mdot
.994 .06901 Mdot
.994 .06911 Mdot
.994 .06932 Mdot
.994 .06938 Mdot
.994 .06991 Mdot
.994 .07019 Mdot
.994 .07062 Mdot
.994 .0713 Mdot
.994 .07158 Mdot
.994 .07186 Mdot
.994 .07395 Mdot
.994 .07523 Mdot
.994 .07618 Mdot
.994 .07619 Mdot
.994 .07649 Mdot
.994 .07679 Mdot
.994 .07703 Mdot
.994 .07797 Mdot
.994 .07874 Mdot
.994 .07929 Mdot
.994 .07996 Mdot
.994 .08004 Mdot
.994 .0803 Mdot
.994 .0812 Mdot
.994 .08188 Mdot
.994 .08207 Mdot
.994 .08267 Mdot
.994 .08293 Mdot
.994 .08317 Mdot
.994 .08357 Mdot
.994 .08381 Mdot
.994 .0842 Mdot
.994 .08453 Mdot
.994 .08487 Mdot
.994 .0859 Mdot
.994 .08641 Mdot
.994 .08679 Mdot
.994 .0869 Mdot
.994 .08766 Mdot
.994 .08984 Mdot
.994 .09002 Mdot
.994 .09025 Mdot
.994 .09197 Mdot
.994 .0924 Mdot
.994 .09396 Mdot
.994 .09412 Mdot
.994 .09418 Mdot
.994 .09636 Mdot
.994 .09639 Mdot
.994 .09729 Mdot
.994 .09907 Mdot
.994 .09926 Mdot
.994 .1009 Mdot
.994 .10095 Mdot
.994 .10098 Mdot
.994 .10205 Mdot
.994 .10331 Mdot
.994 .10362 Mdot
.994 .10363 Mdot
.994 .1042 Mdot
.994 .10559 Mdot
.994 .10661 Mdot
.994 .10699 Mdot
.994 .10768 Mdot
.994 .11085 Mdot
.994 .11169 Mdot
.994 .11269 Mdot
.994 .11274 Mdot
.994 .11294 Mdot
.994 .11334 Mdot
.994 .11368 Mdot
.994 .11524 Mdot
.994 .11577 Mdot
.994 .11712 Mdot
.994 .11778 Mdot
.994 .11853 Mdot
.994 .11876 Mdot
.994 .11953 Mdot
.994 .11998 Mdot
.994 .12006 Mdot
.994 .12215 Mdot
.994 .12248 Mdot
.994 .12375 Mdot
.994 .12415 Mdot
.994 .12471 Mdot
.994 .12498 Mdot
.994 .12783 Mdot
.994 .12839 Mdot
.994 .12881 Mdot
.994 .12896 Mdot
.994 .12902 Mdot
.994 .12983 Mdot
.994 .13054 Mdot
.994 .13094 Mdot
.994 .13107 Mdot
.994 .13177 Mdot
.994 .13198 Mdot
.994 .13285 Mdot
.994 .13312 Mdot
.994 .13313 Mdot
.994 .13361 Mdot
.994 .13498 Mdot
.994 .136 Mdot
.994 .13801 Mdot
.994 .13841 Mdot
.994 .13963 Mdot
.994 .14091 Mdot
.994 .14271 Mdot
.994 .14521 Mdot
.994 .14549 Mdot
.994 .14568 Mdot
.994 .14836 Mdot
.994 .14863 Mdot
.994 .14937 Mdot
.994 .14988 Mdot
.994 .14999 Mdot
.994 .15062 Mdot
.994 .15086 Mdot
.994 .15207 Mdot
.994 .15344 Mdot
.994 .15362 Mdot
.994 .15395 Mdot
.994 .15418 Mdot
.994 .15442 Mdot
.994 .1547 Mdot
.994 .15519 Mdot
.994 .15734 Mdot
.994 .15751 Mdot
.994 .15757 Mdot
.994 .15968 Mdot
.994 .16009 Mdot
.994 .16199 Mdot
.994 .1622 Mdot
.994 .16264 Mdot
.994 .16266 Mdot
.994 .16391 Mdot
.994 .16441 Mdot
.994 .1657 Mdot
.994 .16746 Mdot
.994 .1683 Mdot
.994 .16832 Mdot
.994 .17059 Mdot
.994 .17185 Mdot
.994 .17296 Mdot
.994 .17298 Mdot
.994 .17301 Mdot
.994 .17313 Mdot
.994 .17403 Mdot
.994 .17424 Mdot
.994 .17474 Mdot
.994 .17696 Mdot
.994 .17713 Mdot
.994 .17718 Mdot
.994 .17729 Mdot
.994 .17809 Mdot
.994 .17814 Mdot
.994 .1784 Mdot
.994 .17842 Mdot
.994 .17847 Mdot
.994 .17915 Mdot
.994 .1792 Mdot
.994 .18 Mdot
.994 .18009 Mdot
.994 .18104 Mdot
.994 .18132 Mdot
.994 .18267 Mdot
.994 .18269 Mdot
.994 .18276 Mdot
.994 .18324 Mdot
.994 .1834 Mdot
.994 .1858 Mdot
.994 .18624 Mdot
.994 .18638 Mdot
.994 .18714 Mdot
.994 .18725 Mdot
.994 .18761 Mdot
.994 .18809 Mdot
.994 .1884 Mdot
.994 .18886 Mdot
.994 .19075 Mdot
.994 .19126 Mdot
.994 .19132 Mdot
.994 .1914 Mdot
.994 .192 Mdot
.994 .19324 Mdot
.994 .1935 Mdot
.994 .19373 Mdot
.994 .19385 Mdot
.994 .19458 Mdot
.994 .19476 Mdot
.994 .19488 Mdot
.994 .19574 Mdot
.994 .19575 Mdot
.994 .19729 Mdot
.994 .20013 Mdot
.994 .20027 Mdot
.994 .20057 Mdot
.994 .20149 Mdot
.994 .20327 Mdot
.994 .20554 Mdot
.994 .2056 Mdot
.994 .2078 Mdot
.994 .20805 Mdot
.994 .20829 Mdot
.994 .20861 Mdot
.994 .20889 Mdot
.994 .21063 Mdot
.994 .21162 Mdot
.994 .21194 Mdot
.994 .21246 Mdot
.994 .21261 Mdot
.994 .21263 Mdot
.994 .21284 Mdot
.994 .21455 Mdot
.994 .21547 Mdot
.994 .21602 Mdot
.994 .21685 Mdot
.994 .21776 Mdot
.994 .21905 Mdot
.994 .21995 Mdot
.994 .22086 Mdot
.994 .22114 Mdot
.994 .22475 Mdot
.994 .22756 Mdot
.994 .22808 Mdot
.994 .23034 Mdot
.994 .23163 Mdot
.994 .23405 Mdot
.994 .23465 Mdot
.994 .23467 Mdot
.994 .23472 Mdot
.994 .23562 Mdot
.994 .23658 Mdot
.994 .23665 Mdot
.994 .23731 Mdot
.994 .24027 Mdot
.994 .24039 Mdot
.994 .241 Mdot
.994 .24188 Mdot
.994 .24196 Mdot
.994 .24255 Mdot
.994 .24268 Mdot
.994 .24334 Mdot
.994 .24442 Mdot
.994 .24468 Mdot
.994 .24602 Mdot
.994 .24649 Mdot
.994 .24673 Mdot
.994 .24695 Mdot
.994 .24756 Mdot
.994 .2501 Mdot
.994 .25033 Mdot
.994 .25204 Mdot
.994 .25245 Mdot
.994 .25303 Mdot
.994 .25488 Mdot
.994 .25568 Mdot
.994 .25641 Mdot
.994 .2573 Mdot
.994 .25763 Mdot
.994 .25837 Mdot
.994 .2585 Mdot
.994 .25954 Mdot
.994 .25981 Mdot
.994 .26057 Mdot
.994 .2608 Mdot
.994 .26159 Mdot
.994 .26184 Mdot
.994 .26277 Mdot
.994 .26419 Mdot
.994 .26473 Mdot
.994 .26476 Mdot
.994 .2653 Mdot
.994 .26571 Mdot
.994 .26627 Mdot
.994 .26741 Mdot
.994 .26775 Mdot
.994 .27002 Mdot
.994 .27108 Mdot
.994 .27134 Mdot
.994 .27655 Mdot
.994 .27707 Mdot
.994 .27776 Mdot
.994 .28092 Mdot
.994 .28147 Mdot
.994 .28285 Mdot
.994 .28327 Mdot
.994 .28413 Mdot
.994 .2853 Mdot
.994 .28543 Mdot
.994 .28849 Mdot
.994 .28869 Mdot
.994 .28878 Mdot
.994 .28916 Mdot
.994 .28934 Mdot
.994 .29054 Mdot
.994 .29057 Mdot
.994 .29242 Mdot
.994 .29373 Mdot
.994 .29433 Mdot
.994 .29565 Mdot
.994 .29576 Mdot
.994 .29662 Mdot
.994 .29834 Mdot
.994 .29898 Mdot
.994 .30345 Mdot
.994 .30398 Mdot
.994 .30543 Mdot
.994 .30651 Mdot
.994 .30802 Mdot
.994 .30805 Mdot
.994 .30864 Mdot
.994 .30876 Mdot
.994 .30885 Mdot
.994 .30986 Mdot
.994 .31187 Mdot
.994 .31311 Mdot
.994 .31315 Mdot
.994 .3154 Mdot
.994 .31626 Mdot
.994 .31628 Mdot
.994 .3169 Mdot
.994 .31738 Mdot
.994 .31787 Mdot
.994 .31817 Mdot
.994 .32134 Mdot
.994 .32173 Mdot
.994 .32186 Mdot
.994 .32284 Mdot
.994 .32397 Mdot
.994 .32455 Mdot
.994 .32557 Mdot
.994 .32689 Mdot
.994 .32746 Mdot
.994 .32931 Mdot
.994 .3319 Mdot
.994 .33228 Mdot
.994 .33252 Mdot
.994 .33472 Mdot
.994 .33537 Mdot
.994 .33607 Mdot
.994 .33788 Mdot
.994 .33832 Mdot
.994 .34099 Mdot
.994 .34113 Mdot
.994 .34167 Mdot
.994 .34271 Mdot
.994 .34291 Mdot
.994 .34363 Mdot
.994 .34489 Mdot
.994 .34494 Mdot
.994 .34624 Mdot
.994 .34776 Mdot
.994 .34833 Mdot
.994 .34878 Mdot
.994 .34914 Mdot
.994 .34915 Mdot
.994 .34916 Mdot
.994 .34965 Mdot
.994 .34991 Mdot
.994 .35035 Mdot
.994 .35066 Mdot
.994 .35266 Mdot
.994 .35365 Mdot
.994 .35425 Mdot
.994 .35437 Mdot
.994 .35619 Mdot
.994 .35632 Mdot
.994 .35654 Mdot
.994 .35692 Mdot
.994 .35881 Mdot
.994 .35891 Mdot
.994 .36006 Mdot
.994 .36026 Mdot
.994 .36398 Mdot
.994 .3656 Mdot
.994 .36643 Mdot
.994 .36654 Mdot
.994 .36722 Mdot
.994 .36929 Mdot
.994 .36963 Mdot
.994 .36964 Mdot
.994 .36971 Mdot
.994 .36996 Mdot
.994 .37065 Mdot
.994 .37204 Mdot
.994 .37272 Mdot
.994 .37552 Mdot
.994 .37574 Mdot
.994 .37672 Mdot
.994 .3798 Mdot
.994 .3808 Mdot
.994 .38117 Mdot
.994 .3812 Mdot
.994 .3822 Mdot
.994 .38248 Mdot
.994 .38256 Mdot
.994 .3827 Mdot
.994 .3841 Mdot
.994 .38463 Mdot
.994 .38469 Mdot
.994 .38482 Mdot
.994 .38639 Mdot
.994 .38703 Mdot
.994 .38738 Mdot
.994 .38768 Mdot
.994 .38773 Mdot
.994 .38797 Mdot
.994 .38803 Mdot
.994 .38909 Mdot
.994 .38917 Mdot
.994 .38937 Mdot
.994 .38938 Mdot
.994 .38988 Mdot
.994 .39051 Mdot
.994 .39131 Mdot
.994 .39196 Mdot
.994 .39261 Mdot
.994 .39264 Mdot
.994 .39279 Mdot
.994 .39325 Mdot
.994 .39347 Mdot
.994 .39378 Mdot
.994 .39378 Mdot
.994 .39418 Mdot
.994 .39495 Mdot
.994 .39702 Mdot
.994 .39812 Mdot
.994 .39942 Mdot
.994 .40365 Mdot
.994 .40412 Mdot
.994 .40504 Mdot
.994 .40576 Mdot
.994 .40664 Mdot
.994 .40787 Mdot
.994 .41045 Mdot
.994 .41079 Mdot
.994 .41093 Mdot
.994 .41106 Mdot
.994 .41115 Mdot
.994 .41489 Mdot
.994 .41531 Mdot
.994 .41579 Mdot
.994 .41582 Mdot
.994 .41661 Mdot
.994 .41702 Mdot
.994 .41703 Mdot
.994 .41844 Mdot
.994 .41899 Mdot
.994 .42049 Mdot
.994 .4211 Mdot
.994 .4211 Mdot
.994 .42152 Mdot
.994 .42547 Mdot
.994 .42743 Mdot
.994 .42801 Mdot
.994 .42963 Mdot
.994 .43052 Mdot
.994 .43061 Mdot
.994 .43061 Mdot
.994 .43073 Mdot
.994 .43096 Mdot
.994 .43232 Mdot
.994 .43284 Mdot
.994 .43404 Mdot
.994 .43542 Mdot
.994 .43677 Mdot
.994 .43833 Mdot
.994 .43871 Mdot
.994 .43939 Mdot
.994 .43988 Mdot
.994 .44021 Mdot
.994 .44039 Mdot
.994 .44097 Mdot
.994 .44125 Mdot
.994 .44199 Mdot
.994 .44606 Mdot
.994 .44618 Mdot
.994 .44637 Mdot
.994 .44647 Mdot
.994 .44647 Mdot
.994 .44681 Mdot
.994 .44694 Mdot
.994 .44849 Mdot
.994 .44974 Mdot
.994 .45123 Mdot
.994 .45208 Mdot
.994 .45352 Mdot
.994 .45354 Mdot
.994 .45359 Mdot
.994 .45443 Mdot
.994 .45538 Mdot
.994 .4556 Mdot
.994 .45589 Mdot
.994 .45619 Mdot
.994 .4563 Mdot
.994 .45677 Mdot
.994 .45719 Mdot
.994 .45721 Mdot
.994 .45723 Mdot
.994 .45909 Mdot
.994 .4597 Mdot
.994 .46069 Mdot
.994 .46074 Mdot
.994 .46083 Mdot
.994 .46089 Mdot
.994 .4632 Mdot
.994 .4637 Mdot
.994 .46533 Mdot
.994 .46661 Mdot
.994 .4682 Mdot
.994 .46821 Mdot
.994 .46824 Mdot
.994 .47057 Mdot
.994 .47254 Mdot
.994 .47349 Mdot
.994 .47374 Mdot
.994 .47437 Mdot
.994 .47437 Mdot
.994 .47456 Mdot
.994 .47491 Mdot
.994 .47492 Mdot
.994 .47513 Mdot
.994 .47697 Mdot
.994 .47701 Mdot
.994 .47707 Mdot
.994 .47727 Mdot
.994 .47894 Mdot
.994 .47932 Mdot
.994 .48023 Mdot
.994 .48259 Mdot
.994 .48393 Mdot
.994 .48425 Mdot
.994 .48442 Mdot
.994 .48455 Mdot
.994 .48464 Mdot
.994 .48483 Mdot
.994 .48546 Mdot
.994 .48579 Mdot
.994 .48626 Mdot
.994 .48635 Mdot
.994 .48638 Mdot
.994 .48682 Mdot
.994 .48684 Mdot
.994 .48695 Mdot
.994 .48723 Mdot
.994 .48815 Mdot
.994 .48822 Mdot
.994 .48844 Mdot
.994 .4891 Mdot
.994 .48963 Mdot
.994 .48979 Mdot
.994 .49144 Mdot
.994 .49184 Mdot
.994 .49193 Mdot
.994 .49416 Mdot
.994 .49425 Mdot
.994 .49429 Mdot
.994 .49442 Mdot
.994 .49524 Mdot
.994 .49551 Mdot
.994 .49652 Mdot
.994 .49854 Mdot
.994 .49942 Mdot
.994 .49955 Mdot
.994 .5003 Mdot
.994 .50053 Mdot
.994 .50168 Mdot
.994 .5018 Mdot
.994 .50197 Mdot
.994 .50207 Mdot
.994 .50226 Mdot
.994 .50226 Mdot
.994 .5024 Mdot
.994 .50257 Mdot
.994 .50336 Mdot
.994 .50386 Mdot
.994 .50388 Mdot
.994 .50462 Mdot
.994 .50651 Mdot
.994 .50744 Mdot
.994 .50768 Mdot
.994 .5085 Mdot
.994 .50858 Mdot
.994 .50872 Mdot
.994 .50968 Mdot
.994 .51056 Mdot
.994 .51163 Mdot
.994 .51204 Mdot
.994 .5124 Mdot
.994 .51258 Mdot
.994 .51373 Mdot
.994 .51401 Mdot
.994 .51418 Mdot
.994 .51552 Mdot
.994 .51554 Mdot
.994 .5167 Mdot
.994 .51734 Mdot
.994 .51735 Mdot
.994 .51788 Mdot
.994 .51826 Mdot
.994 .52052 Mdot
.994 .52134 Mdot
.994 .52213 Mdot
.994 .52234 Mdot
.994 .52279 Mdot
.994 .52343 Mdot
.994 .52344 Mdot
.994 .52404 Mdot
.994 .52414 Mdot
.994 .52519 Mdot
.994 .52523 Mdot
.994 .52592 Mdot
.994 .52653 Mdot
.994 .52672 Mdot
.994 .52994 Mdot
.994 .53002 Mdot
.994 .53181 Mdot
.994 .53194 Mdot
.994 .53212 Mdot
.994 .53231 Mdot
.994 .53278 Mdot
.994 .53308 Mdot
.994 .53342 Mdot
.994 .53375 Mdot
.994 .53418 Mdot
.994 .53457 Mdot
.994 .53628 Mdot
.994 .53691 Mdot
.994 .53793 Mdot
.994 .53823 Mdot
.994 .53865 Mdot
.994 .53908 Mdot
.994 .53934 Mdot
.994 .53953 Mdot
.994 .53955 Mdot
.994 .53983 Mdot
.994 .54003 Mdot
.994 .54122 Mdot
.994 .54183 Mdot
.994 .54204 Mdot
.994 .54321 Mdot
.994 .54392 Mdot
.994 .54496 Mdot
.994 .54609 Mdot
.994 .54713 Mdot
.994 .54767 Mdot
.994 .54872 Mdot
.994 .54877 Mdot
.994 .54986 Mdot
.994 .55005 Mdot
.994 .55019 Mdot
.994 .55248 Mdot
.994 .55339 Mdot
.994 .55385 Mdot
.994 .55385 Mdot
.994 .5542 Mdot
.994 .55442 Mdot
.994 .55446 Mdot
.994 .55497 Mdot
.994 .55515 Mdot
.994 .55518 Mdot
.994 .55591 Mdot
.994 .55665 Mdot
.994 .55754 Mdot
.994 .55758 Mdot
.994 .55815 Mdot
.994 .55823 Mdot
.994 .55878 Mdot
.994 .55879 Mdot
.994 .55901 Mdot
.994 .55909 Mdot
.994 .56024 Mdot
.994 .5603 Mdot
.994 .56056 Mdot
.994 .5606 Mdot
.994 .56061 Mdot
.994 .56094 Mdot
.994 .56131 Mdot
.994 .56197 Mdot
.994 .56197 Mdot
.994 .56361 Mdot
.994 .56374 Mdot
.994 .5638 Mdot
.994 .56435 Mdot
.994 .56447 Mdot
.994 .56508 Mdot
.994 .5651 Mdot
.994 .56514 Mdot
.994 .56576 Mdot
.994 .5659 Mdot
.994 .56598 Mdot
.994 .56605 Mdot
.994 .56626 Mdot
.994 .567 Mdot
.994 .56707 Mdot
.994 .56725 Mdot
.994 .56728 Mdot
.994 .56764 Mdot
.994 .56771 Mdot
.994 .56861 Mdot
.994 .57053 Mdot
.994 .57064 Mdot
.994 .57121 Mdot
.994 .5715 Mdot
.994 .57202 Mdot
.994 .57209 Mdot
.994 .5724 Mdot
.994 .57259 Mdot
.994 .57263 Mdot
.994 .57274 Mdot
.994 .57334 Mdot
.994 .57429 Mdot
.994 .57452 Mdot
.994 .57507 Mdot
.994 .57565 Mdot
.994 .57567 Mdot
.994 .57607 Mdot
.994 .57628 Mdot
.994 .57646 Mdot
.994 .57683 Mdot
.994 .57698 Mdot
.994 .57741 Mdot
.994 .57761 Mdot
.994 .57766 Mdot
.994 .57768 Mdot
.994 .57795 Mdot
.994 .57905 Mdot
.994 .57924 Mdot
.994 .57962 Mdot
.994 .58015 Mdot
.994 .58024 Mdot
.994 .58058 Mdot
.994 .58088 Mdot
.994 .58089 Mdot
.994 .58134 Mdot
.994 .58211 Mdot
.994 .58272 Mdot
.994 .5833 Mdot
.994 .58383 Mdot
.994 .58446 Mdot
.994 .58469 Mdot
.994 .58479 Mdot
.994 .58493 Mdot
.994 .5852 Mdot
.994 .58529 Mdot
.994 .58572 Mdot
.994 .58579 Mdot
.994 .586 Mdot
.994 .58618 Mdot
.994 .58668 Mdot
.994 .58683 Mdot
.994 .58704 Mdot
.994 .58729 Mdot
.994 .58735 Mdot
.994 .58743 Mdot
.994 .58751 Mdot
.994 .58751 Mdot
.994 .5881 Mdot
.994 .58865 Mdot
.994 .58872 Mdot
.994 .58898 Mdot
.994 .58909 Mdot
.994 .5893 Mdot
.994 .58932 Mdot
.994 .58964 Mdot
.994 .58969 Mdot
.994 .58988 Mdot
.994 .59021 Mdot
.994 .59084 Mdot
.994 .59086 Mdot
.994 .59102 Mdot
.994 .59106 Mdot
.994 .59126 Mdot
.994 .59141 Mdot
.994 .59168 Mdot
.994 .59168 Mdot
.994 .59168 Mdot
.994 .59188 Mdot
.994 .59212 Mdot
.994 .59229 Mdot
.994 .59243 Mdot
.994 .59284 Mdot
.994 .59298 Mdot
.994 .59321 Mdot
.994 .59386 Mdot
.994 .59388 Mdot
.994 .59448 Mdot
.994 .59481 Mdot
.994 .59491 Mdot
.994 .59538 Mdot
.994 .59546 Mdot
.994 .59561 Mdot
.994 .59567 Mdot
.994 .59569 Mdot
.994 .59598 Mdot
.994 .59678 Mdot
.994 .59696 Mdot
.994 .59725 Mdot
.994 .59746 Mdot
.994 .59765 Mdot
.994 .5979 Mdot
.994 .59796 Mdot
.994 .59811 Mdot
.994 .59813 Mdot
.994 .59841 Mdot
.994 .59879 Mdot
.994 .59884 Mdot
.994 .59886 Mdot
.994 .59894 Mdot
.994 .59906 Mdot
.994 .59975 Mdot
.994 .59981 Mdot
.994 .59982 Mdot
.994 .59983 Mdot
.994 .59994 Mdot
.994 .59998 Mdot
.994 .6003 Mdot
.994 .6003 Mdot
.994 .6003 Mdot
.994 .60044 Mdot
.994 .60074 Mdot
.994 .60075 Mdot
.994 .60098 Mdot
.994 .60103 Mdot
.994 .60109 Mdot
.994 .60115 Mdot
.994 .60132 Mdot
.994 .6014 Mdot
.994 .60142 Mdot
.994 .60149 Mdot
.994 .60152 Mdot
.994 .60157 Mdot
.994 .60158 Mdot
.994 .60184 Mdot
.994 .60193 Mdot
.994 .60204 Mdot
.994 .60208 Mdot
.994 .60214 Mdot
.994 .60219 Mdot
.994 .60226 Mdot
.994 .60226 Mdot
.994 .60234 Mdot
.994 .6024 Mdot
.994 .60244 Mdot
.994 .6025 Mdot
.994 .6025 Mdot
.994 .60253 Mdot
.994 .60256 Mdot
.994 .60257 Mdot
.994 .60261 Mdot
.994 .60261 Mdot
.994 .60261 Mdot
.994 .60261 Mdot
.994 .60261 Mdot
.994 .60261 Mdot
.996 .01664 Mdot
.996 .01666 Mdot
.996 .01668 Mdot
.996 .01678 Mdot
.996 .01681 Mdot
.996 .01681 Mdot
.996 .01692 Mdot
.996 .01697 Mdot
.996 .01705 Mdot
.996 .0173 Mdot
.996 .01765 Mdot
.996 .01767 Mdot
.996 .01816 Mdot
.996 .0183 Mdot
.996 .01833 Mdot
.996 .01857 Mdot
.996 .01865 Mdot
.996 .01909 Mdot
.996 .0191 Mdot
.996 .01919 Mdot
.996 .01934 Mdot
.996 .01968 Mdot
.996 .01989 Mdot
.996 .01997 Mdot
.996 .02031 Mdot
.996 .02051 Mdot
.996 .02203 Mdot
.996 .02228 Mdot
.996 .02238 Mdot
.996 .02246 Mdot
.996 .02254 Mdot
.996 .02256 Mdot
.996 .02262 Mdot
.996 .02296 Mdot
.996 .02303 Mdot
.996 .02305 Mdot
.996 .02306 Mdot
.996 .02331 Mdot
.996 .02332 Mdot
.996 .0235 Mdot
.996 .02372 Mdot
.996 .02401 Mdot
.996 .02458 Mdot
.996 .02501 Mdot
.996 .02597 Mdot
.996 .02638 Mdot
.996 .02648 Mdot
.996 .0265 Mdot
.996 .0267 Mdot
.996 .02715 Mdot
.996 .02731 Mdot
.996 .0281 Mdot
.996 .02842 Mdot
.996 .02863 Mdot
.996 .02896 Mdot
.996 .02908 Mdot
.996 .02918 Mdot
.996 .02934 Mdot
.996 .02936 Mdot
.996 .02976 Mdot
.996 .03003 Mdot
.996 .03031 Mdot
.996 .03033 Mdot
.996 .03061 Mdot
.996 .03098 Mdot
.996 .03175 Mdot
.996 .03208 Mdot
.996 .03211 Mdot
.996 .03228 Mdot
.996 .03249 Mdot
.996 .03306 Mdot
.996 .03338 Mdot
.996 .0344 Mdot
.996 .0344 Mdot
.996 .0349 Mdot
.996 .03494 Mdot
.996 .03517 Mdot
.996 .03522 Mdot
.996 .03554 Mdot
.996 .03689 Mdot
.996 .03728 Mdot
.996 .03733 Mdot
.996 .03765 Mdot
.996 .03854 Mdot
.996 .0386 Mdot
.996 .03905 Mdot
.996 .03929 Mdot
.996 .04009 Mdot
.996 .0401 Mdot
.996 .04011 Mdot
.996 .04024 Mdot
.996 .04031 Mdot
.996 .04041 Mdot
.996 .04061 Mdot
.996 .04127 Mdot
.996 .04241 Mdot
.996 .0425 Mdot
.996 .04307 Mdot
.996 .04358 Mdot
.996 .04369 Mdot
.996 .04369 Mdot
.996 .04458 Mdot
.996 .04495 Mdot
.996 .04528 Mdot
.996 .04538 Mdot
.996 .04557 Mdot
.996 .04564 Mdot
.996 .04589 Mdot
.996 .04647 Mdot
.996 .04679 Mdot
.996 .04723 Mdot
.996 .04748 Mdot
.996 .04757 Mdot
.996 .0476 Mdot
.996 .04787 Mdot
.996 .04858 Mdot
.996 .04861 Mdot
.996 .04869 Mdot
.996 .04877 Mdot
.996 .04932 Mdot
.996 .05015 Mdot
.996 .05066 Mdot
.996 .0513 Mdot
.996 .05188 Mdot
.996 .05202 Mdot
.996 .05245 Mdot
.996 .05263 Mdot
.996 .0535 Mdot
.996 .05515 Mdot
.996 .05554 Mdot
.996 .05608 Mdot
.996 .05651 Mdot
.996 .05884 Mdot
.996 .05965 Mdot
.996 .06039 Mdot
.996 .06042 Mdot
.996 .06066 Mdot
.996 .06081 Mdot
.996 .06086 Mdot
.996 .0612 Mdot
.996 .06128 Mdot
.996 .06164 Mdot
.996 .06178 Mdot
.996 .06195 Mdot
.996 .06338 Mdot
.996 .06372 Mdot
.996 .06398 Mdot
.996 .06497 Mdot
.996 .06702 Mdot
.996 .06823 Mdot
.996 .06875 Mdot
.996 .06876 Mdot
.996 .06903 Mdot
.996 .06924 Mdot
.996 .07015 Mdot
.996 .07029 Mdot
.996 .0706 Mdot
.996 .07074 Mdot
.996 .07113 Mdot
.996 .07119 Mdot
.996 .0717 Mdot
.996 .07179 Mdot
.996 .07228 Mdot
.996 .07332 Mdot
.996 .07416 Mdot
.996 .07435 Mdot
.996 .07541 Mdot
.996 .07548 Mdot
.996 .07606 Mdot
.996 .07655 Mdot
.996 .07694 Mdot
.996 .07748 Mdot
.996 .07794 Mdot
.996 .07804 Mdot
.996 .08082 Mdot
.996 .08207 Mdot
.996 .08218 Mdot
.996 .08252 Mdot
.996 .08281 Mdot
.996 .08362 Mdot
.996 .08534 Mdot
.996 .08577 Mdot
.996 .08639 Mdot
.996 .08685 Mdot
.996 .08688 Mdot
.996 .08697 Mdot
.996 .0885 Mdot
.996 .08907 Mdot
.996 .08922 Mdot
.996 .08948 Mdot
.996 .09028 Mdot
.996 .09077 Mdot
.996 .09077 Mdot
.996 .09094 Mdot
.996 .09139 Mdot
.996 .09189 Mdot
.996 .09262 Mdot
.996 .09276 Mdot
.996 .09365 Mdot
.996 .09381 Mdot
.996 .09432 Mdot
.996 .0945 Mdot
.996 .09499 Mdot
.996 .09713 Mdot
.996 .09725 Mdot
.996 .09818 Mdot
.996 .09977 Mdot
.996 .1 Mdot
.996 .10145 Mdot
.996 .10162 Mdot
.996 .10281 Mdot
.996 .10371 Mdot
.996 .10442 Mdot
.996 .10443 Mdot
.996 .1053 Mdot
.996 .10608 Mdot
.996 .1062 Mdot
.996 .10632 Mdot
.996 .10653 Mdot
.996 .10796 Mdot
.996 .10818 Mdot
.996 .10884 Mdot
.996 .10897 Mdot
.996 .10935 Mdot
.996 .11138 Mdot
.996 .11139 Mdot
.996 .11175 Mdot
.996 .1118 Mdot
.996 .11183 Mdot
.996 .11187 Mdot
.996 .11231 Mdot
.996 .11258 Mdot
.996 .11295 Mdot
.996 .11367 Mdot
.996 .11444 Mdot
.996 .11606 Mdot
.996 .11758 Mdot
.996 .11766 Mdot
.996 .11854 Mdot
.996 .1202 Mdot
.996 .12052 Mdot
.996 .12058 Mdot
.996 .1207 Mdot
.996 .12259 Mdot
.996 .12297 Mdot
.996 .12443 Mdot
.996 .12444 Mdot
.996 .12482 Mdot
.996 .12483 Mdot
.996 .12622 Mdot
.996 .12801 Mdot
.996 .1282 Mdot
.996 .12936 Mdot
.996 .13054 Mdot
.996 .13082 Mdot
.996 .1309 Mdot
.996 .13156 Mdot
.996 .13168 Mdot
.996 .13184 Mdot
.996 .13189 Mdot
.996 .13268 Mdot
.996 .13273 Mdot
.996 .13314 Mdot
.996 .13478 Mdot
.996 .13593 Mdot
.996 .13659 Mdot
.996 .13749 Mdot
.996 .13761 Mdot
.996 .13796 Mdot
.996 .13838 Mdot
.996 .13869 Mdot
.996 .13881 Mdot
.996 .13915 Mdot
.996 .13926 Mdot
.996 .13977 Mdot
.996 .14056 Mdot
.996 .14225 Mdot
.996 .14229 Mdot
.996 .1424 Mdot
.996 .14247 Mdot
.996 .14267 Mdot
.996 .14296 Mdot
.996 .14392 Mdot
.996 .1449 Mdot
.996 .14572 Mdot
.996 .14647 Mdot
.996 .14783 Mdot
.996 .14802 Mdot
.996 .14826 Mdot
.996 .14962 Mdot
.996 .15061 Mdot
.996 .1512 Mdot
.996 .15172 Mdot
.996 .15186 Mdot
.996 .1525 Mdot
.996 .15333 Mdot
.996 .15339 Mdot
.996 .1539 Mdot
.996 .15435 Mdot
.996 .15588 Mdot
.996 .15649 Mdot
.996 .1579 Mdot
.996 .15791 Mdot
.996 .15952 Mdot
.996 .16316 Mdot
.996 .16441 Mdot
.996 .1652 Mdot
.996 .16522 Mdot
.996 .16656 Mdot
.996 .16713 Mdot
.996 .16819 Mdot
.996 .16843 Mdot
.996 .16983 Mdot
.996 .16991 Mdot
.996 .1706 Mdot
.996 .17133 Mdot
.996 .17374 Mdot
.996 .17434 Mdot
.996 .17627 Mdot
.996 .17718 Mdot
.996 .17753 Mdot
.996 .17786 Mdot
.996 .17828 Mdot
.996 .17965 Mdot
.996 .17983 Mdot
.996 .18016 Mdot
.996 .1804 Mdot
.996 .18062 Mdot
.996 .18107 Mdot
.996 .18121 Mdot
.996 .18312 Mdot
.996 .18319 Mdot
.996 .184 Mdot
.996 .18452 Mdot
.996 .1847 Mdot
.996 .18505 Mdot
.996 .18582 Mdot
.996 .18611 Mdot
.996 .18635 Mdot
.996 .18723 Mdot
.996 .18731 Mdot
.996 .18766 Mdot
.996 .18777 Mdot
.996 .18835 Mdot
.996 .18884 Mdot
.996 .18992 Mdot
.996 .19138 Mdot
.996 .19203 Mdot
.996 .19315 Mdot
.996 .19427 Mdot
.996 .19516 Mdot
.996 .19598 Mdot
.996 .19844 Mdot
.996 .19858 Mdot
.996 .19933 Mdot
.996 .20167 Mdot
.996 .20269 Mdot
.996 .20269 Mdot
.996 .20518 Mdot
.996 .20648 Mdot
.996 .20701 Mdot
.996 .20877 Mdot
.996 .20917 Mdot
.996 .2099 Mdot
.996 .21086 Mdot
.996 .2109 Mdot
.996 .21178 Mdot
.996 .21245 Mdot
.996 .21542 Mdot
.996 .21586 Mdot
.996 .21642 Mdot
.996 .21689 Mdot
.996 .2171 Mdot
.996 .21725 Mdot
.996 .21732 Mdot
.996 .21858 Mdot
.996 .21879 Mdot
.996 .22044 Mdot
.996 .22073 Mdot
.996 .22229 Mdot
.996 .22229 Mdot
.996 .22255 Mdot
.996 .22316 Mdot
.996 .22335 Mdot
.996 .22403 Mdot
.996 .22562 Mdot
.996 .2259 Mdot
.996 .22793 Mdot
.996 .22815 Mdot
.996 .2283 Mdot
.996 .22892 Mdot
.996 .22926 Mdot
.996 .22995 Mdot
.996 .23177 Mdot
.996 .2323 Mdot
.996 .23253 Mdot
.996 .23288 Mdot
.996 .23435 Mdot
.996 .2359 Mdot
.996 .23628 Mdot
.996 .23713 Mdot
.996 .2384 Mdot
.996 .23883 Mdot
.996 .23979 Mdot
.996 .24018 Mdot
.996 .24029 Mdot
.996 .24059 Mdot
.996 .24202 Mdot
.996 .24317 Mdot
.996 .24435 Mdot
.996 .24481 Mdot
.996 .24757 Mdot
.996 .24842 Mdot
.996 .24858 Mdot
.996 .24858 Mdot
.996 .24926 Mdot
.996 .25033 Mdot
.996 .25256 Mdot
.996 .25313 Mdot
.996 .25346 Mdot
.996 .2535 Mdot
.996 .25451 Mdot
.996 .2554 Mdot
.996 .25559 Mdot
.996 .25729 Mdot
.996 .25787 Mdot
.996 .26074 Mdot
.996 .26097 Mdot
.996 .26312 Mdot
.996 .26442 Mdot
.996 .26463 Mdot
.996 .26631 Mdot
.996 .26688 Mdot
.996 .26769 Mdot
.996 .26777 Mdot
.996 .26804 Mdot
.996 .27235 Mdot
.996 .27265 Mdot
.996 .27436 Mdot
.996 .27481 Mdot
.996 .2756 Mdot
.996 .27721 Mdot
.996 .27758 Mdot
.996 .27798 Mdot
.996 .27868 Mdot
.996 .27932 Mdot
.996 .27941 Mdot
.996 .27942 Mdot
.996 .27993 Mdot
.996 .28123 Mdot
.996 .28126 Mdot
.996 .28273 Mdot
.996 .2829 Mdot
.996 .28292 Mdot
.996 .28403 Mdot
.996 .28488 Mdot
.996 .28529 Mdot
.996 .2862 Mdot
.996 .28725 Mdot
.996 .28788 Mdot
.996 .28835 Mdot
.996 .28986 Mdot
.996 .29038 Mdot
.996 .29182 Mdot
.996 .29324 Mdot
.996 .29325 Mdot
.996 .29729 Mdot
.996 .29798 Mdot
.996 .29834 Mdot
.996 .30047 Mdot
.996 .30101 Mdot
.996 .30108 Mdot
.996 .30271 Mdot
.996 .30554 Mdot
.996 .3062 Mdot
.996 .30621 Mdot
.996 .31028 Mdot
.996 .31056 Mdot
.996 .31077 Mdot
.996 .31167 Mdot
.996 .31277 Mdot
.996 .31312 Mdot
.996 .31413 Mdot
.996 .31525 Mdot
.996 .31663 Mdot
.996 .31773 Mdot
.996 .31862 Mdot
.996 .31863 Mdot
.996 .31882 Mdot
.996 .31909 Mdot
.996 .32019 Mdot
.996 .32105 Mdot
.996 .32319 Mdot
.996 .32352 Mdot
.996 .32387 Mdot
.996 .32395 Mdot
.996 .32445 Mdot
.996 .32837 Mdot
.996 .3288 Mdot
.996 .32895 Mdot
.996 .33063 Mdot
.996 .33076 Mdot
.996 .33112 Mdot
.996 .33159 Mdot
.996 .33213 Mdot
.996 .33475 Mdot
.996 .33761 Mdot
.996 .33765 Mdot
.996 .33795 Mdot
.996 .33862 Mdot
.996 .33875 Mdot
.996 .33882 Mdot
.996 .33894 Mdot
.996 .34011 Mdot
.996 .34082 Mdot
.996 .34182 Mdot
.996 .34262 Mdot
.996 .34372 Mdot
.996 .34474 Mdot
.996 .34545 Mdot
.996 .34577 Mdot
.996 .34725 Mdot
.996 .34752 Mdot
.996 .34773 Mdot
.996 .34926 Mdot
.996 .34961 Mdot
.996 .34973 Mdot
.996 .35003 Mdot
.996 .3534 Mdot
.996 .354 Mdot
.996 .3542 Mdot
.996 .35445 Mdot
.996 .3557 Mdot
.996 .35649 Mdot
.996 .35685 Mdot
.996 .35907 Mdot
.996 .36057 Mdot
.996 .36075 Mdot
.996 .36137 Mdot
.996 .36158 Mdot
.996 .36174 Mdot
.996 .36203 Mdot
.996 .36228 Mdot
.996 .36358 Mdot
.996 .36685 Mdot
.996 .36709 Mdot
.996 .36709 Mdot
.996 .36739 Mdot
.996 .36782 Mdot
.996 .36837 Mdot
.996 .36864 Mdot
.996 .37149 Mdot
.996 .37152 Mdot
.996 .3718 Mdot
.996 .37246 Mdot
.996 .3725 Mdot
.996 .37425 Mdot
.996 .37568 Mdot
.996 .37594 Mdot
.996 .37625 Mdot
.996 .37639 Mdot
.996 .37821 Mdot
.996 .37863 Mdot
.996 .37914 Mdot
.996 .38016 Mdot
.996 .38038 Mdot
.996 .38083 Mdot
.996 .38159 Mdot
.996 .38191 Mdot
.996 .38237 Mdot
.996 .38239 Mdot
.996 .38368 Mdot
.996 .38656 Mdot
.996 .38701 Mdot
.996 .38722 Mdot
.996 .38742 Mdot
.996 .38825 Mdot
.996 .38901 Mdot
.996 .38931 Mdot
.996 .38968 Mdot
.996 .38982 Mdot
.996 .39006 Mdot
.996 .39113 Mdot
.996 .39147 Mdot
.996 .39171 Mdot
.996 .39182 Mdot
.996 .3928 Mdot
.996 .39297 Mdot
.996 .39672 Mdot
.996 .39685 Mdot
.996 .39941 Mdot
.996 .40098 Mdot
.996 .40212 Mdot
.996 .40245 Mdot
.996 .40307 Mdot
.996 .40334 Mdot
.996 .40417 Mdot
.996 .40469 Mdot
.996 .40503 Mdot
.996 .40513 Mdot
.996 .40586 Mdot
.996 .40614 Mdot
.996 .40692 Mdot
.996 .40717 Mdot
.996 .40759 Mdot
.996 .40836 Mdot
.996 .41009 Mdot
.996 .41015 Mdot
.996 .414 Mdot
.996 .41409 Mdot
.996 .41435 Mdot
.996 .4145 Mdot
.996 .41495 Mdot
.996 .41561 Mdot
.996 .41612 Mdot
.996 .41776 Mdot
.996 .41776 Mdot
.996 .41997 Mdot
.996 .42078 Mdot
.996 .42179 Mdot
.996 .4223 Mdot
.996 .42238 Mdot
.996 .42345 Mdot
.996 .4237 Mdot
.996 .42402 Mdot
.996 .42643 Mdot
.996 .42684 Mdot
.996 .42738 Mdot
.996 .42985 Mdot
.996 .43032 Mdot
.996 .43083 Mdot
.996 .43247 Mdot
.996 .43373 Mdot
.996 .43484 Mdot
.996 .43514 Mdot
.996 .4352 Mdot
.996 .43593 Mdot
.996 .4365 Mdot
.996 .43699 Mdot
.996 .43751 Mdot
.996 .43827 Mdot
.996 .43838 Mdot
.996 .43946 Mdot
.996 .44042 Mdot
.996 .443 Mdot
.996 .44308 Mdot
.996 .44361 Mdot
.996 .44488 Mdot
.996 .44631 Mdot
.996 .44779 Mdot
.996 .44781 Mdot
.996 .45108 Mdot
.996 .45134 Mdot
.996 .45839 Mdot
.996 .46085 Mdot
.996 .46241 Mdot
.996 .46245 Mdot
.996 .46506 Mdot
.996 .4653 Mdot
.996 .4658 Mdot
.996 .46615 Mdot
.996 .46818 Mdot
.996 .46863 Mdot
.996 .4713 Mdot
.996 .47144 Mdot
.996 .47204 Mdot
.996 .47208 Mdot
.996 .47276 Mdot
.996 .47411 Mdot
.996 .47485 Mdot
.996 .4775 Mdot
.996 .47859 Mdot
.996 .4797 Mdot
.996 .47984 Mdot
.996 .48081 Mdot
.996 .48095 Mdot
.996 .48319 Mdot
.996 .48482 Mdot
.996 .48545 Mdot
.996 .4856 Mdot
.996 .48604 Mdot
.996 .48679 Mdot
.996 .4873 Mdot
.996 .4892 Mdot
.996 .48921 Mdot
.996 .4894 Mdot
.996 .48953 Mdot
.996 .49011 Mdot
.996 .49053 Mdot
.996 .49073 Mdot
.996 .4909 Mdot
.996 .49164 Mdot
.996 .49169 Mdot
.996 .49192 Mdot
.996 .4925 Mdot
.996 .49348 Mdot
.996 .49473 Mdot
.996 .49484 Mdot
.996 .49523 Mdot
.996 .49535 Mdot
.996 .49535 Mdot
.996 .49673 Mdot
.996 .49724 Mdot
.996 .4976 Mdot
.996 .49791 Mdot
.996 .49849 Mdot
.996 .49935 Mdot
.996 .4998 Mdot
.996 .50028 Mdot
.996 .50068 Mdot
.996 .50209 Mdot
.996 .50213 Mdot
.996 .50227 Mdot
.996 .50285 Mdot
.996 .50293 Mdot
.996 .50303 Mdot
.996 .50371 Mdot
.996 .50398 Mdot
.996 .50478 Mdot
.996 .50653 Mdot
.996 .50772 Mdot
.996 .50889 Mdot
.996 .50924 Mdot
.996 .50991 Mdot
.996 .51168 Mdot
.996 .51304 Mdot
.996 .51344 Mdot
.996 .51354 Mdot
.996 .51393 Mdot
.996 .51482 Mdot
.996 .51558 Mdot
.996 .5157 Mdot
.996 .51609 Mdot
.996 .51649 Mdot
.996 .51803 Mdot
.996 .51926 Mdot
.996 .51983 Mdot
.996 .52004 Mdot
.996 .52115 Mdot
.996 .52255 Mdot
.996 .52255 Mdot
.996 .5246 Mdot
.996 .52496 Mdot
.996 .5257 Mdot
.996 .52608 Mdot
.996 .52609 Mdot
.996 .52665 Mdot
.996 .52729 Mdot
.996 .52751 Mdot
.996 .52788 Mdot
.996 .52801 Mdot
.996 .52963 Mdot
.996 .53145 Mdot
.996 .53219 Mdot
.996 .5334 Mdot
.996 .53348 Mdot
.996 .5346 Mdot
.996 .53516 Mdot
.996 .53584 Mdot
.996 .53614 Mdot
.996 .53686 Mdot
.996 .53743 Mdot
.996 .53743 Mdot
.996 .53748 Mdot
.996 .53776 Mdot
.996 .53864 Mdot
.996 .53879 Mdot
.996 .53917 Mdot
.996 .53953 Mdot
.996 .54012 Mdot
.996 .54025 Mdot
.996 .54069 Mdot
.996 .54136 Mdot
.996 .54244 Mdot
.996 .54279 Mdot
.996 .54336 Mdot
.996 .54357 Mdot
.996 .54392 Mdot
.996 .54399 Mdot
.996 .54463 Mdot
.996 .54521 Mdot
.996 .54542 Mdot
.996 .54548 Mdot
.996 .54567 Mdot
.996 .54575 Mdot
.996 .54731 Mdot
.996 .54736 Mdot
.996 .54757 Mdot
.996 .54958 Mdot
.996 .54992 Mdot
.996 .55046 Mdot
.996 .55062 Mdot
.996 .55177 Mdot
.996 .55177 Mdot
.996 .55208 Mdot
.996 .55279 Mdot
.996 .55302 Mdot
.996 .5538 Mdot
.996 .55499 Mdot
.996 .55518 Mdot
.996 .55562 Mdot
.996 .55594 Mdot
.996 .55629 Mdot
.996 .55642 Mdot
.996 .55668 Mdot
.996 .55707 Mdot
.996 .55821 Mdot
.996 .55824 Mdot
.996 .55844 Mdot
.996 .55851 Mdot
.996 .55861 Mdot
.996 .55867 Mdot
.996 .55907 Mdot
.996 .55929 Mdot
.996 .55939 Mdot
.996 .55966 Mdot
.996 .56022 Mdot
.996 .5604 Mdot
.996 .56111 Mdot
.996 .56132 Mdot
.996 .56154 Mdot
.996 .56202 Mdot
.996 .56233 Mdot
.996 .56289 Mdot
.996 .56312 Mdot
.996 .56348 Mdot
.996 .565 Mdot
.996 .565 Mdot
.996 .56629 Mdot
.996 .56631 Mdot
.996 .56655 Mdot
.996 .56677 Mdot
.996 .56692 Mdot
.996 .56709 Mdot
.996 .56776 Mdot
.996 .56783 Mdot
.996 .56827 Mdot
.996 .56848 Mdot
.996 .56899 Mdot
.996 .5694 Mdot
.996 .56946 Mdot
.996 .56994 Mdot
.996 .57031 Mdot
.996 .57034 Mdot
.996 .57067 Mdot
.996 .57077 Mdot
.996 .57106 Mdot
.996 .57203 Mdot
.996 .57215 Mdot
.996 .57237 Mdot
.996 .57243 Mdot
.996 .57267 Mdot
.996 .57341 Mdot
.996 .57396 Mdot
.996 .57445 Mdot
.996 .57486 Mdot
.996 .57549 Mdot
.996 .57552 Mdot
.996 .57608 Mdot
.996 .57632 Mdot
.996 .57635 Mdot
.996 .57721 Mdot
.996 .57791 Mdot
.996 .57804 Mdot
.996 .57805 Mdot
.996 .5786 Mdot
.996 .57871 Mdot
.996 .57892 Mdot
.996 .57937 Mdot
.996 .57946 Mdot
.996 .57971 Mdot
.996 .57994 Mdot
.996 .57995 Mdot
.996 .58014 Mdot
.996 .58121 Mdot
.996 .58164 Mdot
.996 .58189 Mdot
.996 .58192 Mdot
.996 .58263 Mdot
.996 .58268 Mdot
.996 .58333 Mdot
.996 .58346 Mdot
.996 .58358 Mdot
.996 .58376 Mdot
.996 .58398 Mdot
.996 .58409 Mdot
.996 .58424 Mdot
.996 .58467 Mdot
.996 .58468 Mdot
.996 .5848 Mdot
.996 .58508 Mdot
.996 .58583 Mdot
.996 .58702 Mdot
.996 .58717 Mdot
.996 .58732 Mdot
.996 .58755 Mdot
.996 .58805 Mdot
.996 .58855 Mdot
.996 .58883 Mdot
.996 .58899 Mdot
.996 .58911 Mdot
.996 .58935 Mdot
.996 .58947 Mdot
.996 .58947 Mdot
.996 .59046 Mdot
.996 .59079 Mdot
.996 .59125 Mdot
.996 .5913 Mdot
.996 .59143 Mdot
.996 .59145 Mdot
.996 .59159 Mdot
.996 .59166 Mdot
.996 .59185 Mdot
.996 .59267 Mdot
.996 .59278 Mdot
.996 .59292 Mdot
.996 .59367 Mdot
.996 .59372 Mdot
.996 .59383 Mdot
.996 .59387 Mdot
.996 .59418 Mdot
.996 .59467 Mdot
.996 .59469 Mdot
.996 .5949 Mdot
.996 .59518 Mdot
.996 .59526 Mdot
.996 .59554 Mdot
.996 .59598 Mdot
.996 .59598 Mdot
.996 .59614 Mdot
.996 .59628 Mdot
.996 .59631 Mdot
.996 .5966 Mdot
.996 .59677 Mdot
.996 .59682 Mdot
.996 .59684 Mdot
.996 .59686 Mdot
.996 .5969 Mdot
.996 .5969 Mdot
.996 .5969 Mdot
.996 .5971 Mdot
.996 .59717 Mdot
.996 .59728 Mdot
.996 .5973 Mdot
.996 .59761 Mdot
.996 .59762 Mdot
.996 .59815 Mdot
.996 .59822 Mdot
.996 .59823 Mdot
.996 .59835 Mdot
.996 .59861 Mdot
.996 .59889 Mdot
.996 .59903 Mdot
.996 .59922 Mdot
.996 .59931 Mdot
.996 .59939 Mdot
.996 .59953 Mdot
.996 .59963 Mdot
.996 .59964 Mdot
.996 .59968 Mdot
.996 .59982 Mdot
.996 .59995 Mdot
.996 .60015 Mdot
.996 .60019 Mdot
.996 .60031 Mdot
.996 .60036 Mdot
.996 .60049 Mdot
.996 .60084 Mdot
.996 .60116 Mdot
.996 .60116 Mdot
.996 .60123 Mdot
.996 .60133 Mdot
.996 .60135 Mdot
.996 .60142 Mdot
.996 .60148 Mdot
.996 .60187 Mdot
.996 .60191 Mdot
.996 .602 Mdot
.996 .60202 Mdot
.996 .60207 Mdot
.996 .60216 Mdot
.996 .6022 Mdot
.996 .60222 Mdot
.996 .60222 Mdot
.996 .60233 Mdot
.996 .60235 Mdot
.996 .60241 Mdot
.996 .60242 Mdot
.996 .60245 Mdot
.996 .60258 Mdot
.996 .60258 Mdot
.996 .60267 Mdot
.996 .60273 Mdot
.996 .60275 Mdot
.996 .60277 Mdot
.996 .60279 Mdot
.996 .6028 Mdot
.996 .6028 Mdot
.996 .60283 Mdot
.996 .60283 Mdot
.996 .60284 Mdot
.998 .01566 Mdot
.998 .01567 Mdot
.998 .01568 Mdot
.998 .01569 Mdot
.998 .01571 Mdot
.998 .01574 Mdot
.998 .01581 Mdot
.998 .01601 Mdot
.998 .01604 Mdot
.998 .01621 Mdot
.998 .01626 Mdot
.998 .01637 Mdot
.998 .01702 Mdot
.998 .01718 Mdot
.998 .01719 Mdot
.998 .01742 Mdot
.998 .01755 Mdot
.998 .01786 Mdot
.998 .0179 Mdot
.998 .01823 Mdot
.998 .01848 Mdot
.998 .01853 Mdot
.998 .01856 Mdot
.998 .01859 Mdot
.998 .01862 Mdot
.998 .01862 Mdot
.998 .01871 Mdot
.998 .0188 Mdot
.998 .01895 Mdot
.998 .01902 Mdot
.998 .01908 Mdot
.998 .01962 Mdot
.998 .01981 Mdot
.998 .01984 Mdot
.998 .01991 Mdot
.998 .02 Mdot
.998 .02017 Mdot
.998 .0206 Mdot
.998 .02068 Mdot
.998 .02068 Mdot
.998 .02071 Mdot
.998 .02081 Mdot
.998 .0209 Mdot
.998 .02125 Mdot
.998 .02134 Mdot
.998 .02155 Mdot
.998 .02222 Mdot
.998 .02274 Mdot
.998 .02277 Mdot
.998 .02285 Mdot
.998 .02311 Mdot
.998 .0239 Mdot
.998 .02398 Mdot
.998 .024 Mdot
.998 .0243 Mdot
.998 .02446 Mdot
.998 .02455 Mdot
.998 .02457 Mdot
.998 .02549 Mdot
.998 .02556 Mdot
.998 .02585 Mdot
.998 .02596 Mdot
.998 .02599 Mdot
.998 .02606 Mdot
.998 .02717 Mdot
.998 .02722 Mdot
.998 .02727 Mdot
.998 .02739 Mdot
.998 .02754 Mdot
.998 .02869 Mdot
.998 .0289 Mdot
.998 .02907 Mdot
.998 .0294 Mdot
.998 .02946 Mdot
.998 .02966 Mdot
.998 .02973 Mdot
.998 .02986 Mdot
.998 .02989 Mdot
.998 .02999 Mdot
.998 .03011 Mdot
.998 .03023 Mdot
.998 .03025 Mdot
.998 .03026 Mdot
.998 .03059 Mdot
.998 .03065 Mdot
.998 .03094 Mdot
.998 .03101 Mdot
.998 .03151 Mdot
.998 .03181 Mdot
.998 .03181 Mdot
.998 .03203 Mdot
.998 .03285 Mdot
.998 .03364 Mdot
.998 .034 Mdot
.998 .03418 Mdot
.998 .03447 Mdot
.998 .03448 Mdot
.998 .03485 Mdot
.998 .0349 Mdot
.998 .03502 Mdot
.998 .03519 Mdot
.998 .03529 Mdot
.998 .0353 Mdot
.998 .03567 Mdot
.998 .03627 Mdot
.998 .03634 Mdot
.998 .03679 Mdot
.998 .0375 Mdot
.998 .03763 Mdot
.998 .03801 Mdot
.998 .03831 Mdot
.998 .03834 Mdot
.998 .03846 Mdot
.998 .03871 Mdot
.998 .03885 Mdot
.998 .03919 Mdot
.998 .03942 Mdot
.998 .04057 Mdot
.998 .0409 Mdot
.998 .04143 Mdot
.998 .04164 Mdot
.998 .04174 Mdot
.998 .04263 Mdot
.998 .04275 Mdot
.998 .04295 Mdot
.998 .04435 Mdot
.998 .04636 Mdot
.998 .0464 Mdot
.998 .04649 Mdot
.998 .04678 Mdot
.998 .04736 Mdot
.998 .04757 Mdot
.998 .0478 Mdot
.998 .04901 Mdot
.998 .05087 Mdot
.998 .05111 Mdot
.998 .05117 Mdot
.998 .05125 Mdot
.998 .0524 Mdot
.998 .05304 Mdot
.998 .05337 Mdot
.998 .05348 Mdot
.998 .05374 Mdot
.998 .05391 Mdot
.998 .05397 Mdot
.998 .05696 Mdot
.998 .057 Mdot
.998 .05728 Mdot
.998 .05785 Mdot
.998 .05839 Mdot
.998 .05851 Mdot
.998 .05892 Mdot
.998 .0592 Mdot
.998 .05967 Mdot
.998 .06089 Mdot
.998 .06125 Mdot
.998 .06137 Mdot
.998 .06218 Mdot
.998 .06347 Mdot
.998 .06364 Mdot
.998 .06384 Mdot
.998 .06424 Mdot
.998 .06431 Mdot
.998 .06489 Mdot
.998 .06598 Mdot
.998 .06862 Mdot
.998 .0689 Mdot
.998 .06929 Mdot
.998 .0694 Mdot
.998 .06955 Mdot
.998 .06983 Mdot
.998 .07005 Mdot
.998 .07072 Mdot
.998 .07096 Mdot
.998 .07104 Mdot
.998 .07199 Mdot
.998 .07215 Mdot
.998 .0722 Mdot
.998 .07222 Mdot
.998 .07291 Mdot
.998 .07295 Mdot
.998 .07321 Mdot
.998 .07356 Mdot
.998 .07373 Mdot
.998 .07382 Mdot
.998 .07422 Mdot
.998 .07466 Mdot
.998 .0748 Mdot
.998 .07511 Mdot
.998 .07519 Mdot
.998 .07522 Mdot
.998 .07647 Mdot
.998 .0767 Mdot
.998 .07779 Mdot
.998 .07809 Mdot
.998 .07913 Mdot
.998 .07997 Mdot
.998 .08005 Mdot
.998 .08073 Mdot
.998 .08108 Mdot
.998 .08109 Mdot
.998 .08162 Mdot
.998 .08192 Mdot
.998 .08269 Mdot
.998 .08344 Mdot
.998 .08372 Mdot
.998 .08427 Mdot
.998 .08501 Mdot
.998 .08559 Mdot
.998 .0857 Mdot
.998 .08797 Mdot
.998 .08929 Mdot
.998 .08996 Mdot
.998 .09022 Mdot
.998 .09107 Mdot
.998 .0911 Mdot
.998 .0918 Mdot
.998 .09192 Mdot
.998 .0922 Mdot
.998 .09247 Mdot
.998 .09267 Mdot
.998 .0931 Mdot
.998 .09374 Mdot
.998 .09412 Mdot
.998 .09416 Mdot
.998 .09419 Mdot
.998 .09484 Mdot
.998 .09526 Mdot
.998 .09551 Mdot
.998 .09705 Mdot
.998 .09753 Mdot
.998 .09776 Mdot
.998 .09802 Mdot
.998 .09846 Mdot
.998 .09967 Mdot
.998 .10053 Mdot
.998 .10103 Mdot
.998 .10128 Mdot
.998 .10229 Mdot
.998 .10279 Mdot
.998 .10417 Mdot
.998 .10469 Mdot
.998 .10528 Mdot
.998 .10538 Mdot
.998 .1054 Mdot
.998 .10583 Mdot
.998 .10585 Mdot
.998 .1059 Mdot
.998 .1061 Mdot
.998 .10624 Mdot
.998 .10676 Mdot
.998 .10726 Mdot
.998 .10744 Mdot
.998 .10784 Mdot
.998 .10851 Mdot
.998 .1091 Mdot
.998 .10936 Mdot
.998 .11099 Mdot
.998 .11252 Mdot
.998 .11355 Mdot
.998 .11478 Mdot
.998 .11554 Mdot
.998 .11587 Mdot
.998 .11632 Mdot
.998 .11668 Mdot
.998 .11746 Mdot
.998 .11757 Mdot
.998 .11782 Mdot
.998 .11948 Mdot
.998 .12104 Mdot
.998 .12147 Mdot
.998 .12172 Mdot
.998 .12221 Mdot
.998 .12287 Mdot
.998 .12361 Mdot
.998 .12425 Mdot
.998 .12447 Mdot
.998 .12515 Mdot
.998 .12724 Mdot
.998 .13245 Mdot
.998 .13446 Mdot
.998 .13458 Mdot
.998 .13491 Mdot
.998 .13506 Mdot
.998 .13575 Mdot
.998 .13594 Mdot
.998 .13612 Mdot
.998 .13802 Mdot
.998 .13812 Mdot
.998 .13812 Mdot
.998 .13876 Mdot
.998 .13958 Mdot
.998 .13982 Mdot
.998 .14123 Mdot
.998 .14232 Mdot
.998 .14322 Mdot
.998 .14385 Mdot
.998 .14507 Mdot
.998 .14529 Mdot
.998 .14785 Mdot
.998 .14831 Mdot
.998 .14989 Mdot
.998 .1504 Mdot
.998 .15044 Mdot
.998 .15123 Mdot
.998 .15145 Mdot
.998 .15172 Mdot
.998 .15241 Mdot
.998 .15269 Mdot
.998 .15577 Mdot
.998 .15637 Mdot
.998 .15798 Mdot
.998 .15914 Mdot
.998 .15936 Mdot
.998 .1595 Mdot
.998 .1604 Mdot
.998 .161 Mdot
.998 .16116 Mdot
.998 .16123 Mdot
.998 .16645 Mdot
.998 .16677 Mdot
.998 .16763 Mdot
.998 .17129 Mdot
.998 .17151 Mdot
.998 .17163 Mdot
.998 .17167 Mdot
.998 .1726 Mdot
.998 .17294 Mdot
.998 .17378 Mdot
.998 .17455 Mdot
.998 .1758 Mdot
.998 .17596 Mdot
.998 .17628 Mdot
.998 .1764 Mdot
.998 .17682 Mdot
.998 .17804 Mdot
.998 .1782 Mdot
.998 .17913 Mdot
.998 .18073 Mdot
.998 .18281 Mdot
.998 .18388 Mdot
.998 .18487 Mdot
.998 .18505 Mdot
.998 .18597 Mdot
.998 .18608 Mdot
.998 .18646 Mdot
.998 .18919 Mdot
.998 .19026 Mdot
.998 .19338 Mdot
.998 .19351 Mdot
.998 .19395 Mdot
.998 .19409 Mdot
.998 .19476 Mdot
.998 .19609 Mdot
.998 .19615 Mdot
.998 .19632 Mdot
.998 .19759 Mdot
.998 .19824 Mdot
.998 .20183 Mdot
.998 .20251 Mdot
.998 .20271 Mdot
.998 .20277 Mdot
.998 .20302 Mdot
.998 .20332 Mdot
.998 .20343 Mdot
.998 .20453 Mdot
.998 .20474 Mdot
.998 .205 Mdot
.998 .20535 Mdot
.998 .2057 Mdot
.998 .20758 Mdot
.998 .20901 Mdot
.998 .21036 Mdot
.998 .21051 Mdot
.998 .21143 Mdot
.998 .21268 Mdot
.998 .21306 Mdot
.998 .2132 Mdot
.998 .21353 Mdot
.998 .21446 Mdot
.998 .21518 Mdot
.998 .21545 Mdot
.998 .21547 Mdot
.998 .21688 Mdot
.998 .21722 Mdot
.998 .21734 Mdot
.998 .2174 Mdot
.998 .21811 Mdot
.998 .21839 Mdot
.998 .21852 Mdot
.998 .21888 Mdot
.998 .22136 Mdot
.998 .22144 Mdot
.998 .2216 Mdot
.998 .22196 Mdot
.998 .2221 Mdot
.998 .22212 Mdot
.998 .22217 Mdot
.998 .22344 Mdot
.998 .22439 Mdot
.998 .22454 Mdot
.998 .22535 Mdot
.998 .22649 Mdot
.998 .22704 Mdot
.998 .22732 Mdot
.998 .2286 Mdot
.998 .22916 Mdot
.998 .22921 Mdot
.998 .22998 Mdot
.998 .23033 Mdot
.998 .23044 Mdot
.998 .23144 Mdot
.998 .23168 Mdot
.998 .23176 Mdot
.998 .23324 Mdot
.998 .23459 Mdot
.998 .23564 Mdot
.998 .23572 Mdot
.998 .23645 Mdot
.998 .2369 Mdot
.998 .23704 Mdot
.998 .23778 Mdot
.998 .23785 Mdot
.998 .23839 Mdot
.998 .23898 Mdot
.998 .23991 Mdot
.998 .23991 Mdot
.998 .24051 Mdot
.998 .24083 Mdot
.998 .24388 Mdot
.998 .24409 Mdot
.998 .24568 Mdot
.998 .2467 Mdot
.998 .24695 Mdot
.998 .24794 Mdot
.998 .24908 Mdot
.998 .2495 Mdot
.998 .25009 Mdot
.998 .25016 Mdot
.998 .25018 Mdot
.998 .25175 Mdot
.998 .25184 Mdot
.998 .25274 Mdot
.998 .25403 Mdot
.998 .25514 Mdot
.998 .25572 Mdot
.998 .25741 Mdot
.998 .25745 Mdot
.998 .25828 Mdot
.998 .25997 Mdot
.998 .26172 Mdot
.998 .26223 Mdot
.998 .26282 Mdot
.998 .26398 Mdot
.998 .26432 Mdot
.998 .26756 Mdot
.998 .2689 Mdot
.998 .26965 Mdot
.998 .27112 Mdot
.998 .27116 Mdot
.998 .27259 Mdot
.998 .2737 Mdot
.998 .2746 Mdot
.998 .27513 Mdot
.998 .27711 Mdot
.998 .2779 Mdot
.998 .27803 Mdot
.998 .27927 Mdot
.998 .27972 Mdot
.998 .28042 Mdot
.998 .28051 Mdot
.998 .28098 Mdot
.998 .28207 Mdot
.998 .28231 Mdot
.998 .28257 Mdot
.998 .28292 Mdot
.998 .28317 Mdot
.998 .28375 Mdot
.998 .28453 Mdot
.998 .28515 Mdot
.998 .28544 Mdot
.998 .28606 Mdot
.998 .28618 Mdot
.998 .28639 Mdot
.998 .28672 Mdot
.998 .28828 Mdot
.998 .28837 Mdot
.998 .28939 Mdot
.998 .28948 Mdot
.998 .28959 Mdot
.998 .29147 Mdot
.998 .29242 Mdot
.998 .29271 Mdot
.998 .2928 Mdot
.998 .29344 Mdot
.998 .29787 Mdot
.998 .29927 Mdot
.998 .29991 Mdot
.998 .30066 Mdot
.998 .30149 Mdot
.998 .30192 Mdot
.998 .30427 Mdot
.998 .3045 Mdot
.998 .30537 Mdot
.998 .30665 Mdot
.998 .30782 Mdot
.998 .30924 Mdot
.998 .30978 Mdot
.998 .30993 Mdot
.998 .31051 Mdot
.998 .31076 Mdot
.998 .31278 Mdot
.998 .31417 Mdot
.998 .31652 Mdot
.998 .31708 Mdot
.998 .31803 Mdot
.998 .31942 Mdot
.998 .31948 Mdot
.998 .32004 Mdot
.998 .32112 Mdot
.998 .3214 Mdot
.998 .32144 Mdot
.998 .32193 Mdot
.998 .32253 Mdot
.998 .32264 Mdot
.998 .32268 Mdot
.998 .32282 Mdot
.998 .3234 Mdot
.998 .32378 Mdot
.998 .3252 Mdot
.998 .32658 Mdot
.998 .32689 Mdot
.998 .32706 Mdot
.998 .32816 Mdot
.998 .33 Mdot
.998 .33117 Mdot
.998 .33159 Mdot
.998 .33228 Mdot
.998 .33546 Mdot
.998 .33604 Mdot
.998 .3367 Mdot
.998 .34073 Mdot
.998 .3408 Mdot
.998 .34355 Mdot
.998 .34679 Mdot
.998 .34881 Mdot
.998 .34968 Mdot
.998 .35025 Mdot
.998 .35042 Mdot
.998 .35084 Mdot
.998 .35178 Mdot
.998 .35256 Mdot
.998 .35383 Mdot
.998 .35411 Mdot
.998 .35423 Mdot
.998 .35471 Mdot
.998 .35475 Mdot
.998 .35524 Mdot
.998 .35553 Mdot
.998 .35843 Mdot
.998 .3587 Mdot
.998 .35905 Mdot
.998 .35946 Mdot
.998 .35986 Mdot
.998 .36007 Mdot
.998 .36294 Mdot
.998 .36304 Mdot
.998 .36377 Mdot
.998 .36415 Mdot
.998 .36479 Mdot
.998 .36496 Mdot
.998 .36602 Mdot
.998 .36746 Mdot
.998 .36769 Mdot
.998 .36799 Mdot
.998 .36839 Mdot
.998 .36958 Mdot
.998 .37119 Mdot
.998 .37174 Mdot
.998 .37307 Mdot
.998 .37343 Mdot
.998 .37367 Mdot
.998 .37387 Mdot
.998 .37641 Mdot
.998 .37741 Mdot
.998 .37863 Mdot
.998 .37937 Mdot
.998 .38429 Mdot
.998 .38828 Mdot
.998 .38896 Mdot
.998 .3913 Mdot
.998 .39422 Mdot
.998 .39599 Mdot
.998 .3961 Mdot
.998 .39638 Mdot
.998 .3965 Mdot
.998 .39716 Mdot
.998 .39752 Mdot
.998 .39787 Mdot
.998 .39858 Mdot
.998 .39915 Mdot
.998 .39959 Mdot
.998 .40001 Mdot
.998 .4039 Mdot
.998 .40416 Mdot
.998 .40447 Mdot
.998 .40468 Mdot
.998 .4047 Mdot
.998 .4052 Mdot
.998 .40617 Mdot
.998 .40715 Mdot
.998 .40807 Mdot
.998 .40862 Mdot
.998 .40944 Mdot
.998 .41072 Mdot
.998 .41184 Mdot
.998 .41216 Mdot
.998 .41431 Mdot
.998 .41605 Mdot
.998 .41623 Mdot
.998 .41635 Mdot
.998 .41674 Mdot
.998 .41768 Mdot
.998 .41777 Mdot
.998 .42049 Mdot
.998 .42099 Mdot
.998 .4234 Mdot
.998 .42566 Mdot
.998 .42665 Mdot
.998 .42763 Mdot
.998 .43104 Mdot
.998 .43108 Mdot
.998 .43219 Mdot
.998 .43225 Mdot
.998 .43292 Mdot
.998 .43325 Mdot
.998 .4333 Mdot
.998 .43396 Mdot
.998 .43443 Mdot
.998 .435 Mdot
.998 .43513 Mdot
.998 .4363 Mdot
.998 .43644 Mdot
.998 .43649 Mdot
.998 .43707 Mdot
.998 .43776 Mdot
.998 .44355 Mdot
.998 .44379 Mdot
.998 .44479 Mdot
.998 .44811 Mdot
.998 .44866 Mdot
.998 .44995 Mdot
.998 .45048 Mdot
.998 .4505 Mdot
.998 .45094 Mdot
.998 .45122 Mdot
.998 .45306 Mdot
.998 .45425 Mdot
.998 .45457 Mdot
.998 .45471 Mdot
.998 .45889 Mdot
.998 .45916 Mdot
.998 .45979 Mdot
.998 .46215 Mdot
.998 .46502 Mdot
.998 .46564 Mdot
.998 .46571 Mdot
.998 .46626 Mdot
.998 .46711 Mdot
.998 .46713 Mdot
.998 .46729 Mdot
.998 .46816 Mdot
.998 .47063 Mdot
.998 .47165 Mdot
.998 .47422 Mdot
.998 .47464 Mdot
.998 .47487 Mdot
.998 .47495 Mdot
.998 .47666 Mdot
.998 .4773 Mdot
.998 .47786 Mdot
.998 .47885 Mdot
.998 .47969 Mdot
.998 .48014 Mdot
.998 .48025 Mdot
.998 .48252 Mdot
.998 .48283 Mdot
.998 .4834 Mdot
.998 .48362 Mdot
.998 .48437 Mdot
.998 .48656 Mdot
.998 .48684 Mdot
.998 .48849 Mdot
.998 .49049 Mdot
.998 .49128 Mdot
.998 .49169 Mdot
.998 .49271 Mdot
.998 .49279 Mdot
.998 .49303 Mdot
.998 .49489 Mdot
.998 .49505 Mdot
.998 .49526 Mdot
.998 .49624 Mdot
.998 .49671 Mdot
.998 .49704 Mdot
.998 .49816 Mdot
.998 .49824 Mdot
.998 .49839 Mdot
.998 .49869 Mdot
.998 .49879 Mdot
.998 .49992 Mdot
.998 .50003 Mdot
.998 .50023 Mdot
.998 .50041 Mdot
.998 .50106 Mdot
.998 .50188 Mdot
.998 .50194 Mdot
.998 .50554 Mdot
.998 .50729 Mdot
.998 .5075 Mdot
.998 .50909 Mdot
.998 .51065 Mdot
.998 .51224 Mdot
.998 .51246 Mdot
.998 .51314 Mdot
.998 .51336 Mdot
.998 .5142 Mdot
.998 .51441 Mdot
.998 .51646 Mdot
.998 .51655 Mdot
.998 .51681 Mdot
.998 .51791 Mdot
.998 .51867 Mdot
.998 .51875 Mdot
.998 .51972 Mdot
.998 .52274 Mdot
.998 .52287 Mdot
.998 .52426 Mdot
.998 .52482 Mdot
.998 .52501 Mdot
.998 .52505 Mdot
.998 .52526 Mdot
.998 .52603 Mdot
.998 .52632 Mdot
.998 .5264 Mdot
.998 .52677 Mdot
.998 .5272 Mdot
.998 .52735 Mdot
.998 .52777 Mdot
.998 .52892 Mdot
.998 .52922 Mdot
.998 .52959 Mdot
.998 .53008 Mdot
.998 .53057 Mdot
.998 .53082 Mdot
.998 .53126 Mdot
.998 .53283 Mdot
.998 .53319 Mdot
.998 .53458 Mdot
.998 .53515 Mdot
.998 .5357 Mdot
.998 .53644 Mdot
.998 .53697 Mdot
.998 .53716 Mdot
.998 .53767 Mdot
.998 .53839 Mdot
.998 .53897 Mdot
.998 .54005 Mdot
.998 .54024 Mdot
.998 .54053 Mdot
.998 .54072 Mdot
.998 .54089 Mdot
.998 .54091 Mdot
.998 .54115 Mdot
.998 .54119 Mdot
.998 .54159 Mdot
.998 .54192 Mdot
.998 .54235 Mdot
.998 .54327 Mdot
.998 .54362 Mdot
.998 .54363 Mdot
.998 .54542 Mdot
.998 .54584 Mdot
.998 .54599 Mdot
.998 .54607 Mdot
.998 .54684 Mdot
.998 .54695 Mdot
.998 .54729 Mdot
.998 .54735 Mdot
.998 .54745 Mdot
.998 .54789 Mdot
.998 .5479 Mdot
.998 .54859 Mdot
.998 .54946 Mdot
.998 .54987 Mdot
.998 .55031 Mdot
.998 .55088 Mdot
.998 .55099 Mdot
.998 .5511 Mdot
.998 .55117 Mdot
.998 .55124 Mdot
.998 .55157 Mdot
.998 .55161 Mdot
.998 .55169 Mdot
.998 .55177 Mdot
.998 .55179 Mdot
.998 .55185 Mdot
.998 .55334 Mdot
.998 .55377 Mdot
.998 .55443 Mdot
.998 .5546 Mdot
.998 .55553 Mdot
.998 .55681 Mdot
.998 .55709 Mdot
.998 .55743 Mdot
.998 .55775 Mdot
.998 .55916 Mdot
.998 .55967 Mdot
.998 .55977 Mdot
.998 .55982 Mdot
.998 .56041 Mdot
.998 .56065 Mdot
.998 .56102 Mdot
.998 .56114 Mdot
.998 .5622 Mdot
.998 .56245 Mdot
.998 .56254 Mdot
.998 .56408 Mdot
.998 .5646 Mdot
.998 .56546 Mdot
.998 .56651 Mdot
.998 .56659 Mdot
.998 .56731 Mdot
.998 .56776 Mdot
.998 .56789 Mdot
.998 .56862 Mdot
.998 .56868 Mdot
.998 .5692 Mdot
.998 .56946 Mdot
.998 .56977 Mdot
.998 .57016 Mdot
.998 .57064 Mdot
.998 .57064 Mdot
.998 .5712 Mdot
.998 .57131 Mdot
.998 .5715 Mdot
.998 .57223 Mdot
.998 .57427 Mdot
.998 .57445 Mdot
.998 .57451 Mdot
.998 .57469 Mdot
.998 .5749 Mdot
.998 .57521 Mdot
.998 .57583 Mdot
.998 .57636 Mdot
.998 .5767 Mdot
.998 .57683 Mdot
.998 .57692 Mdot
.998 .57775 Mdot
.998 .57817 Mdot
.998 .57868 Mdot
.998 .57903 Mdot
.998 .57913 Mdot
.998 .57946 Mdot
.998 .5795 Mdot
.998 .57956 Mdot
.998 .57957 Mdot
.998 .5797 Mdot
.998 .57988 Mdot
.998 .58081 Mdot
.998 .58088 Mdot
.998 .58101 Mdot
.998 .58157 Mdot
.998 .58182 Mdot
.998 .58195 Mdot
.998 .58243 Mdot
.998 .58255 Mdot
.998 .58272 Mdot
.998 .58326 Mdot
.998 .58333 Mdot
.998 .58336 Mdot
.998 .58379 Mdot
.998 .58499 Mdot
.998 .58502 Mdot
.998 .58538 Mdot
.998 .58552 Mdot
.998 .5856 Mdot
.998 .5858 Mdot
.998 .58608 Mdot
.998 .58632 Mdot
.998 .5865 Mdot
.998 .58674 Mdot
.998 .58789 Mdot
.998 .58821 Mdot
.998 .58839 Mdot
.998 .58857 Mdot
.998 .58859 Mdot
.998 .58888 Mdot
.998 .5889 Mdot
.998 .5892 Mdot
.998 .58927 Mdot
.998 .58931 Mdot
.998 .58944 Mdot
.998 .58951 Mdot
.998 .59021 Mdot
.998 .59066 Mdot
.998 .5912 Mdot
.998 .59141 Mdot
.998 .59144 Mdot
.998 .59153 Mdot
.998 .59185 Mdot
.998 .59215 Mdot
.998 .59233 Mdot
.998 .59256 Mdot
.998 .59333 Mdot
.998 .59335 Mdot
.998 .59339 Mdot
.998 .59407 Mdot
.998 .59461 Mdot
.998 .59498 Mdot
.998 .59504 Mdot
.998 .59529 Mdot
.998 .59617 Mdot
.998 .59622 Mdot
.998 .59625 Mdot
.998 .59651 Mdot
.998 .59656 Mdot
.998 .59707 Mdot
.998 .59725 Mdot
.998 .59753 Mdot
.998 .59756 Mdot
.998 .59775 Mdot
.998 .59788 Mdot
.998 .59812 Mdot
.998 .59815 Mdot
.998 .59824 Mdot
.998 .59833 Mdot
.998 .59833 Mdot
.998 .59846 Mdot
.998 .59855 Mdot
.998 .59875 Mdot
.998 .59901 Mdot
.998 .59921 Mdot
.998 .59931 Mdot
.998 .59941 Mdot
.998 .59951 Mdot
.998 .59954 Mdot
.998 .59961 Mdot
.998 .59962 Mdot
.998 .59971 Mdot
.998 .59975 Mdot
.998 .60009 Mdot
.998 .60016 Mdot
.998 .60019 Mdot
.998 .60047 Mdot
.998 .60049 Mdot
.998 .60052 Mdot
.998 .60059 Mdot
.998 .60087 Mdot
.998 .60091 Mdot
.998 .60099 Mdot
.998 .60099 Mdot
.998 .60121 Mdot
.998 .60128 Mdot
.998 .6013 Mdot
.998 .60131 Mdot
.998 .60144 Mdot
.998 .6016 Mdot
.998 .60168 Mdot
.998 .60179 Mdot
.998 .60181 Mdot
.998 .60182 Mdot
.998 .60184 Mdot
.998 .60195 Mdot
.998 .60204 Mdot
.998 .60204 Mdot
.998 .60209 Mdot
.998 .60224 Mdot
.998 .60226 Mdot
.998 .60234 Mdot
.998 .60235 Mdot
.998 .60244 Mdot
.998 .60252 Mdot
.998 .60253 Mdot
.998 .60261 Mdot
.998 .60264 Mdot
.998 .6027 Mdot
.998 .6027 Mdot
.998 .60274 Mdot
.998 .6029 Mdot
.998 .60293 Mdot
.998 .60295 Mdot
.998 .60299 Mdot
.998 .60299 Mdot
.998 .60305 Mdot
.998 .60306 Mdot
.998 .60307 Mdot
.998 .60307 Mdot
.998 .60308 Mdot
.998 .60308 Mdot
.998 .60308 Mdot
1 .01472 Mdot
1 .01472 Mdot
1 .01472 Mdot
1 .01472 Mdot
1 .01472 Mdot
1 .01473 Mdot
1 .01473 Mdot
1 .01474 Mdot
1 .01474 Mdot
1 .01475 Mdot
1 .01475 Mdot
1 .01476 Mdot
1 .01478 Mdot
1 .01479 Mdot
1 .01479 Mdot
1 .01481 Mdot
1 .01483 Mdot
1 .01484 Mdot
1 .01485 Mdot
1 .01486 Mdot
1 .01491 Mdot
1 .01492 Mdot
1 .01498 Mdot
1 .01499 Mdot
1 .01499 Mdot
1 .01501 Mdot
1 .01503 Mdot
1 .01509 Mdot
1 .01517 Mdot
1 .0152 Mdot
1 .01522 Mdot
1 .01523 Mdot
1 .01527 Mdot
1 .01529 Mdot
1 .01551 Mdot
1 .01551 Mdot
1 .01555 Mdot
1 .01555 Mdot
1 .01561 Mdot
1 .01571 Mdot
1 .01577 Mdot
1 .01581 Mdot
1 .01583 Mdot
1 .01591 Mdot
1 .01591 Mdot
1 .01598 Mdot
1 .0162 Mdot
1 .01632 Mdot
1 .01636 Mdot
1 .01639 Mdot
1 .01653 Mdot
1 .01654 Mdot
1 .01665 Mdot
1 .01674 Mdot
1 .01676 Mdot
1 .01693 Mdot
1 .01695 Mdot
1 .01696 Mdot
1 .017 Mdot
1 .01714 Mdot
1 .01734 Mdot
1 .0176 Mdot
1 .01772 Mdot
1 .01775 Mdot
1 .01781 Mdot
1 .01788 Mdot
1 .0179 Mdot
1 .0179 Mdot
1 .01804 Mdot
1 .01805 Mdot
1 .01817 Mdot
1 .01825 Mdot
1 .01829 Mdot
1 .01868 Mdot
1 .01874 Mdot
1 .01893 Mdot
1 .0191 Mdot
1 .01916 Mdot
1 .01917 Mdot
1 .01948 Mdot
1 .01951 Mdot
1 .01958 Mdot
1 .01975 Mdot
1 .01991 Mdot
1 .02004 Mdot
1 .02065 Mdot
1 .02072 Mdot
1 .02113 Mdot
1 .0213 Mdot
1 .0214 Mdot
1 .02195 Mdot
1 .02198 Mdot
1 .02199 Mdot
1 .02244 Mdot
1 .02279 Mdot
1 .02289 Mdot
1 .02345 Mdot
1 .02353 Mdot
1 .02363 Mdot
1 .02368 Mdot
1 .02383 Mdot
1 .02439 Mdot
1 .02453 Mdot
1 .02471 Mdot
1 .02471 Mdot
1 .0249 Mdot
1 .02517 Mdot
1 .02534 Mdot
1 .02536 Mdot
1 .02547 Mdot
1 .02619 Mdot
1 .02668 Mdot
1 .0268 Mdot
1 .02704 Mdot
1 .02733 Mdot
1 .0274 Mdot
1 .0274 Mdot
1 .02741 Mdot
1 .02795 Mdot
1 .02799 Mdot
1 .02845 Mdot
1 .02879 Mdot
1 .02893 Mdot
1 .02894 Mdot
1 .0296 Mdot
1 .02997 Mdot
1 .03008 Mdot
1 .03046 Mdot
1 .03072 Mdot
1 .03084 Mdot
1 .03122 Mdot
1 .03127 Mdot
1 .03146 Mdot
1 .03213 Mdot
1 .03237 Mdot
1 .0324 Mdot
1 .03275 Mdot
1 .03363 Mdot
1 .03374 Mdot
1 .03401 Mdot
1 .0347 Mdot
1 .03531 Mdot
1 .03581 Mdot
1 .03626 Mdot
1 .03821 Mdot
1 .03848 Mdot
1 .03871 Mdot
1 .03945 Mdot
1 .04011 Mdot
1 .04051 Mdot
1 .04077 Mdot
1 .04115 Mdot
1 .04128 Mdot
1 .04228 Mdot
1 .04294 Mdot
1 .0433 Mdot
1 .0433 Mdot
1 .04344 Mdot
1 .04347 Mdot
1 .04406 Mdot
1 .04409 Mdot
1 .04496 Mdot
1 .0452 Mdot
1 .04587 Mdot
1 .04603 Mdot
1 .04657 Mdot
1 .04696 Mdot
1 .04697 Mdot
1 .04838 Mdot
1 .04913 Mdot
1 .04946 Mdot
1 .04974 Mdot
1 .04982 Mdot
1 .05059 Mdot
1 .05061 Mdot
1 .05078 Mdot
1 .05136 Mdot
1 .05167 Mdot
1 .05177 Mdot
1 .05278 Mdot
1 .05284 Mdot
1 .05286 Mdot
1 .05289 Mdot
1 .05334 Mdot
1 .05401 Mdot
1 .05403 Mdot
1 .0544 Mdot
1 .05475 Mdot
1 .05478 Mdot
1 .05519 Mdot
1 .05578 Mdot
1 .05644 Mdot
1 .05652 Mdot
1 .05653 Mdot
1 .05696 Mdot
1 .05773 Mdot
1 .05809 Mdot
1 .05974 Mdot
1 .06075 Mdot
1 .06104 Mdot
1 .06155 Mdot
1 .06159 Mdot
1 .06182 Mdot
1 .06207 Mdot
1 .06298 Mdot
1 .06385 Mdot
1 .06409 Mdot
1 .06419 Mdot
1 .06435 Mdot
1 .06435 Mdot
1 .06436 Mdot
1 .06439 Mdot
1 .06503 Mdot
1 .06649 Mdot
1 .06652 Mdot
1 .06664 Mdot
1 .06728 Mdot
1 .06837 Mdot
1 .06881 Mdot
1 .06928 Mdot
1 .06966 Mdot
1 .07021 Mdot
1 .07023 Mdot
1 .07025 Mdot
1 .07274 Mdot
1 .07416 Mdot
1 .07421 Mdot
1 .07456 Mdot
1 .07464 Mdot
1 .07488 Mdot
1 .07521 Mdot
1 .07602 Mdot
1 .07663 Mdot
1 .077 Mdot
1 .07746 Mdot
1 .07887 Mdot
1 .07907 Mdot
1 .07981 Mdot
1 .08004 Mdot
1 .08231 Mdot
1 .08243 Mdot
1 .0825 Mdot
1 .08324 Mdot
1 .08335 Mdot
1 .08346 Mdot
1 .0837 Mdot
1 .08446 Mdot
1 .08464 Mdot
1 .08532 Mdot
1 .08574 Mdot
1 .08616 Mdot
1 .08624 Mdot
1 .08796 Mdot
1 .08835 Mdot
1 .08936 Mdot
1 .08953 Mdot
1 .09114 Mdot
1 .09196 Mdot
1 .09235 Mdot
1 .09295 Mdot
1 .09401 Mdot
1 .09423 Mdot
1 .09608 Mdot
1 .09773 Mdot
1 .09994 Mdot
1 .10026 Mdot
1 .10365 Mdot
1 .10469 Mdot
1 .10494 Mdot
1 .10593 Mdot
1 .10679 Mdot
1 .10949 Mdot
1 .10952 Mdot
1 .10974 Mdot
1 .10986 Mdot
1 .11193 Mdot
1 .11257 Mdot
1 .11337 Mdot
1 .11356 Mdot
1 .11385 Mdot
1 .11432 Mdot
1 .1145 Mdot
1 .11452 Mdot
1 .1157 Mdot
1 .11617 Mdot
1 .11677 Mdot
1 .11754 Mdot
1 .11761 Mdot
1 .11983 Mdot
1 .12222 Mdot
1 .1235 Mdot
1 .12351 Mdot
1 .124 Mdot
1 .12403 Mdot
1 .12412 Mdot
1 .12598 Mdot
1 .12626 Mdot
1 .12635 Mdot
1 .12925 Mdot
1 .12947 Mdot
1 .12948 Mdot
1 .13034 Mdot
1 .13152 Mdot
1 .13223 Mdot
1 .13275 Mdot
1 .13333 Mdot
1 .13523 Mdot
1 .13664 Mdot
1 .13668 Mdot
1 .13814 Mdot
1 .1406 Mdot
1 .14119 Mdot
1 .14167 Mdot
1 .14344 Mdot
1 .14432 Mdot
1 .14548 Mdot
1 .14555 Mdot
1 .14649 Mdot
1 .14678 Mdot
1 .1475 Mdot
1 .14947 Mdot
1 .14955 Mdot
1 .14959 Mdot
1 .15015 Mdot
1 .15113 Mdot
1 .15216 Mdot
1 .15327 Mdot
1 .15362 Mdot
1 .15565 Mdot
1 .15631 Mdot
1 .15659 Mdot
1 .15713 Mdot
1 .15736 Mdot
1 .15742 Mdot
1 .15751 Mdot
1 .15852 Mdot
1 .15859 Mdot
1 .15909 Mdot
1 .16095 Mdot
1 .1614 Mdot
1 .16148 Mdot
1 .16237 Mdot
1 .16241 Mdot
1 .16277 Mdot
1 .16398 Mdot
1 .16406 Mdot
1 .16549 Mdot
1 .16549 Mdot
1 .16607 Mdot
1 .16754 Mdot
1 .16929 Mdot
1 .16978 Mdot
1 .17006 Mdot
1 .17011 Mdot
1 .17158 Mdot
1 .17217 Mdot
1 .1731 Mdot
1 .17421 Mdot
1 .17545 Mdot
1 .17655 Mdot
1 .17661 Mdot
1 .17724 Mdot
1 .17783 Mdot
1 .17791 Mdot
1 .18104 Mdot
1 .18228 Mdot
1 .18289 Mdot
1 .18297 Mdot
1 .18399 Mdot
1 .18445 Mdot
1 .18545 Mdot
1 .18716 Mdot
1 .18729 Mdot
1 .18748 Mdot
1 .1877 Mdot
1 .18807 Mdot
1 .18888 Mdot
1 .19183 Mdot
1 .19196 Mdot
1 .19296 Mdot
1 .19412 Mdot
1 .19486 Mdot
1 .19507 Mdot
1 .19539 Mdot
1 .19566 Mdot
1 .196 Mdot
1 .19652 Mdot
1 .19652 Mdot
1 .19655 Mdot
1 .19664 Mdot
1 .19764 Mdot
1 .19779 Mdot
1 .19878 Mdot
1 .19883 Mdot
1 .19886 Mdot
1 .19936 Mdot
1 .2036 Mdot
1 .20371 Mdot
1 .20409 Mdot
1 .20621 Mdot
1 .20655 Mdot
1 .20979 Mdot
1 .21057 Mdot
1 .21121 Mdot
1 .21275 Mdot
1 .21399 Mdot
1 .21578 Mdot
1 .21582 Mdot
1 .21589 Mdot
1 .21735 Mdot
1 .22098 Mdot
1 .22384 Mdot
1 .22393 Mdot
1 .22417 Mdot
1 .22683 Mdot
1 .22713 Mdot
1 .22729 Mdot
1 .22848 Mdot
1 .22864 Mdot
1 .22976 Mdot
1 .23001 Mdot
1 .23079 Mdot
1 .23184 Mdot
1 .23269 Mdot
1 .2344 Mdot
1 .23459 Mdot
1 .23632 Mdot
1 .23693 Mdot
1 .23749 Mdot
1 .23811 Mdot
1 .23878 Mdot
1 .23895 Mdot
1 .23968 Mdot
1 .24338 Mdot
1 .24399 Mdot
1 .24603 Mdot
1 .2463 Mdot
1 .24703 Mdot
1 .24868 Mdot
1 .25194 Mdot
1 .25404 Mdot
1 .25442 Mdot
1 .25464 Mdot
1 .2569 Mdot
1 .25693 Mdot
1 .25724 Mdot
1 .25757 Mdot
1 .25832 Mdot
1 .25835 Mdot
1 .26063 Mdot
1 .2612 Mdot
1 .26161 Mdot
1 .26326 Mdot
1 .26453 Mdot
1 .26551 Mdot
1 .26582 Mdot
1 .26604 Mdot
1 .26695 Mdot
1 .26708 Mdot
1 .26731 Mdot
1 .27125 Mdot
1 .27201 Mdot
1 .2724 Mdot
1 .27493 Mdot
1 .27544 Mdot
1 .27593 Mdot
1 .27595 Mdot
1 .27758 Mdot
1 .27804 Mdot
1 .28073 Mdot
1 .28316 Mdot
1 .28429 Mdot
1 .28554 Mdot
1 .28608 Mdot
1 .28736 Mdot
1 .28908 Mdot
1 .28918 Mdot
1 .2898 Mdot
1 .29518 Mdot
1 .29563 Mdot
1 .29621 Mdot
1 .2976 Mdot
1 .29818 Mdot
1 .29833 Mdot
1 .29849 Mdot
1 .29871 Mdot
1 .29994 Mdot
1 .30082 Mdot
1 .30116 Mdot
1 .30122 Mdot
1 .30297 Mdot
1 .30361 Mdot
1 .30625 Mdot
1 .30717 Mdot
1 .30741 Mdot
1 .30794 Mdot
1 .30834 Mdot
1 .30844 Mdot
1 .30845 Mdot
1 .30875 Mdot
1 .30943 Mdot
1 .31072 Mdot
1 .31213 Mdot
1 .3122 Mdot
1 .3131 Mdot
1 .31336 Mdot
1 .31456 Mdot
1 .31476 Mdot
1 .31565 Mdot
1 .31671 Mdot
1 .31812 Mdot
1 .31847 Mdot
1 .31885 Mdot
1 .31959 Mdot
1 .3203 Mdot
1 .3212 Mdot
1 .32302 Mdot
1 .32389 Mdot
1 .3254 Mdot
1 .32697 Mdot
1 .32806 Mdot
1 .32824 Mdot
1 .32842 Mdot
1 .32883 Mdot
1 .33278 Mdot
1 .33287 Mdot
1 .33346 Mdot
1 .33378 Mdot
1 .33888 Mdot
1 .33934 Mdot
1 .34105 Mdot
1 .34144 Mdot
1 .34165 Mdot
1 .34319 Mdot
1 .3437 Mdot
1 .34447 Mdot
1 .34519 Mdot
1 .34573 Mdot
1 .34619 Mdot
1 .34624 Mdot
1 .34679 Mdot
1 .3468 Mdot
1 .34756 Mdot
1 .34774 Mdot
1 .34795 Mdot
1 .34859 Mdot
1 .34917 Mdot
1 .34935 Mdot
1 .35059 Mdot
1 .35215 Mdot
1 .35317 Mdot
1 .35416 Mdot
1 .35436 Mdot
1 .35659 Mdot
1 .35876 Mdot
1 .36008 Mdot
1 .36017 Mdot
1 .36095 Mdot
1 .36236 Mdot
1 .36296 Mdot
1 .36621 Mdot
1 .36738 Mdot
1 .36773 Mdot
1 .36943 Mdot
1 .36947 Mdot
1 .37036 Mdot
1 .37069 Mdot
1 .37078 Mdot
1 .37099 Mdot
1 .37198 Mdot
1 .37566 Mdot
1 .37573 Mdot
1 .37636 Mdot
1 .37657 Mdot
1 .38215 Mdot
1 .38371 Mdot
1 .38425 Mdot
1 .38427 Mdot
1 .38493 Mdot
1 .38533 Mdot
1 .38635 Mdot
1 .38921 Mdot
1 .38923 Mdot
1 .38958 Mdot
1 .39093 Mdot
1 .39212 Mdot
1 .39218 Mdot
1 .39326 Mdot
1 .39356 Mdot
1 .39477 Mdot
1 .39481 Mdot
1 .39508 Mdot
1 .39509 Mdot
1 .39521 Mdot
1 .39808 Mdot
1 .39978 Mdot
1 .4014 Mdot
1 .40148 Mdot
1 .40358 Mdot
1 .40462 Mdot
1 .4049 Mdot
1 .40507 Mdot
1 .40944 Mdot
1 .40978 Mdot
1 .41056 Mdot
1 .41185 Mdot
1 .41191 Mdot
1 .41302 Mdot
1 .4137 Mdot
1 .41619 Mdot
1 .41661 Mdot
1 .41702 Mdot
1 .41854 Mdot
1 .419 Mdot
1 .41913 Mdot
1 .41974 Mdot
1 .41982 Mdot
1 .41984 Mdot
1 .42127 Mdot
1 .42158 Mdot
1 .42174 Mdot
1 .42236 Mdot
1 .42258 Mdot
1 .42292 Mdot
1 .42374 Mdot
1 .42382 Mdot
1 .42445 Mdot
1 .42578 Mdot
1 .42603 Mdot
1 .42611 Mdot
1 .42851 Mdot
1 .4291 Mdot
1 .43033 Mdot
1 .43051 Mdot
1 .4306 Mdot
1 .4318 Mdot
1 .43308 Mdot
1 .43341 Mdot
1 .43391 Mdot
1 .43613 Mdot
1 .43848 Mdot
1 .43912 Mdot
1 .43922 Mdot
1 .44106 Mdot
1 .44141 Mdot
1 .44149 Mdot
1 .44152 Mdot
1 .44348 Mdot
1 .44372 Mdot
1 .44485 Mdot
1 .44542 Mdot
1 .44655 Mdot
1 .44701 Mdot
1 .44715 Mdot
1 .4473 Mdot
1 .44732 Mdot
1 .44732 Mdot
1 .44766 Mdot
1 .44806 Mdot
1 .44882 Mdot
1 .4494 Mdot
1 .44954 Mdot
1 .45058 Mdot
1 .45244 Mdot
1 .45252 Mdot
1 .45309 Mdot
1 .45397 Mdot
1 .45415 Mdot
1 .45434 Mdot
1 .45524 Mdot
1 .4554 Mdot
1 .45717 Mdot
1 .45726 Mdot
1 .4577 Mdot
1 .45798 Mdot
1 .45802 Mdot
1 .4598 Mdot
1 .46017 Mdot
1 .46036 Mdot
1 .46053 Mdot
1 .46054 Mdot
1 .46227 Mdot
1 .46332 Mdot
1 .46333 Mdot
1 .46337 Mdot
1 .46354 Mdot
1 .46446 Mdot
1 .46714 Mdot
1 .46729 Mdot
1 .46913 Mdot
1 .4694 Mdot
1 .4705 Mdot
1 .47065 Mdot
1 .47157 Mdot
1 .47195 Mdot
1 .4721 Mdot
1 .4722 Mdot
1 .47269 Mdot
1 .47333 Mdot
1 .47334 Mdot
1 .47337 Mdot
1 .47365 Mdot
1 .47391 Mdot
1 .47477 Mdot
1 .47496 Mdot
1 .47606 Mdot
1 .47687 Mdot
1 .47778 Mdot
1 .47792 Mdot
1 .47982 Mdot
1 .48001 Mdot
1 .48046 Mdot
1 .48208 Mdot
1 .48401 Mdot
1 .48406 Mdot
1 .48407 Mdot
1 .48418 Mdot
1 .4842 Mdot
1 .48483 Mdot
1 .48531 Mdot
1 .48636 Mdot
1 .48652 Mdot
1 .48812 Mdot
1 .48828 Mdot
1 .48942 Mdot
1 .49202 Mdot
1 .49352 Mdot
1 .49416 Mdot
1 .49521 Mdot
1 .49535 Mdot
1 .49709 Mdot
1 .49732 Mdot
1 .49787 Mdot
1 .49817 Mdot
1 .49872 Mdot
1 .49956 Mdot
1 .50087 Mdot
1 .5024 Mdot
1 .50262 Mdot
1 .50287 Mdot
1 .50294 Mdot
1 .50301 Mdot
1 .5033 Mdot
1 .50331 Mdot
1 .50391 Mdot
1 .50525 Mdot
1 .50532 Mdot
1 .50628 Mdot
1 .50999 Mdot
1 .51014 Mdot
1 .51021 Mdot
1 .51027 Mdot
1 .51067 Mdot
1 .51179 Mdot
1 .51277 Mdot
1 .51361 Mdot
1 .51375 Mdot
1 .51388 Mdot
1 .51476 Mdot
1 .51508 Mdot
1 .51515 Mdot
1 .51558 Mdot
1 .51567 Mdot
1 .51599 Mdot
1 .51601 Mdot
1 .51652 Mdot
1 .51697 Mdot
1 .51721 Mdot
1 .51732 Mdot
1 .51732 Mdot
1 .51736 Mdot
1 .5175 Mdot
1 .51769 Mdot
1 .51902 Mdot
1 .51925 Mdot
1 .51986 Mdot
1 .51988 Mdot
1 .52 Mdot
1 .52073 Mdot
1 .52081 Mdot
1 .52086 Mdot
1 .52092 Mdot
1 .52112 Mdot
1 .5216 Mdot
1 .5218 Mdot
1 .52405 Mdot
1 .52464 Mdot
1 .52526 Mdot
1 .5278 Mdot
1 .52795 Mdot
1 .52851 Mdot
1 .52884 Mdot
1 .52982 Mdot
1 .53138 Mdot
1 .53145 Mdot
1 .53149 Mdot
1 .53197 Mdot
1 .53325 Mdot
1 .53432 Mdot
1 .53479 Mdot
1 .53641 Mdot
1 .53746 Mdot
1 .53831 Mdot
1 .54034 Mdot
1 .54063 Mdot
1 .54084 Mdot
1 .54121 Mdot
1 .54195 Mdot
1 .54255 Mdot
1 .54425 Mdot
1 .5443 Mdot
1 .54439 Mdot
1 .54522 Mdot
1 .54532 Mdot
1 .54621 Mdot
1 .54734 Mdot
1 .54942 Mdot
1 .55065 Mdot
1 .55283 Mdot
1 .55298 Mdot
1 .55299 Mdot
1 .5533 Mdot
1 .55334 Mdot
1 .55402 Mdot
1 .55412 Mdot
1 .5544 Mdot
1 .55475 Mdot
1 .55509 Mdot
1 .55632 Mdot
1 .55638 Mdot
1 .55742 Mdot
1 .55772 Mdot
1 .55775 Mdot
1 .55793 Mdot
1 .55921 Mdot
1 .55924 Mdot
1 .55941 Mdot
1 .5596 Mdot
1 .55962 Mdot
1 .56063 Mdot
1 .5609 Mdot
1 .56174 Mdot
1 .56267 Mdot
1 .56284 Mdot
1 .56373 Mdot
1 .56375 Mdot
1 .56415 Mdot
1 .56483 Mdot
1 .56485 Mdot
1 .56541 Mdot
1 .56549 Mdot
1 .56568 Mdot
1 .56697 Mdot
1 .56741 Mdot
1 .568 Mdot
1 .56856 Mdot
1 .56915 Mdot
1 .56979 Mdot
1 .56996 Mdot
1 .57065 Mdot
1 .57231 Mdot
1 .5725 Mdot
1 .57307 Mdot
1 .57314 Mdot
1 .57405 Mdot
1 .57459 Mdot
1 .57636 Mdot
1 .57638 Mdot
1 .57659 Mdot
1 .57721 Mdot
1 .57722 Mdot
1 .57739 Mdot
1 .57747 Mdot
1 .57775 Mdot
1 .57848 Mdot
1 .57852 Mdot
1 .57858 Mdot
1 .57989 Mdot
1 .58017 Mdot
1 .58109 Mdot
1 .58118 Mdot
1 .58278 Mdot
1 .58306 Mdot
1 .58323 Mdot
1 .58355 Mdot
1 .58398 Mdot
1 .58486 Mdot
1 .58488 Mdot
1 .58499 Mdot
1 .5851 Mdot
1 .58533 Mdot
1 .58554 Mdot
1 .5856 Mdot
1 .58585 Mdot
1 .58587 Mdot
1 .58651 Mdot
1 .58741 Mdot
1 .58778 Mdot
1 .58794 Mdot
1 .58805 Mdot
1 .58909 Mdot
1 .58935 Mdot
1 .58947 Mdot
1 .58987 Mdot
1 .59007 Mdot
1 .59046 Mdot
1 .59064 Mdot
1 .59068 Mdot
1 .59077 Mdot
1 .5913 Mdot
1 .59137 Mdot
1 .5915 Mdot
1 .59158 Mdot
1 .59227 Mdot
1 .59236 Mdot
1 .59268 Mdot
1 .59302 Mdot
1 .59313 Mdot
1 .59322 Mdot
1 .59362 Mdot
1 .59362 Mdot
1 .59363 Mdot
1 .5939 Mdot
1 .59393 Mdot
1 .59401 Mdot
1 .59416 Mdot
1 .59421 Mdot
1 .59443 Mdot
1 .59478 Mdot
1 .59514 Mdot
1 .59538 Mdot
1 .59542 Mdot
1 .59566 Mdot
1 .59588 Mdot
1 .59589 Mdot
1 .59608 Mdot
1 .59617 Mdot
1 .59634 Mdot
1 .5966 Mdot
1 .5968 Mdot
1 .59707 Mdot
1 .59726 Mdot
1 .59788 Mdot
1 .59878 Mdot
1 .59915 Mdot
1 .59916 Mdot
1 .59926 Mdot
1 .59945 Mdot
1 .59948 Mdot
1 .59958 Mdot
1 .59974 Mdot
1 .60013 Mdot
1 .60062 Mdot
1 .60065 Mdot
1 .60065 Mdot
1 .60076 Mdot
1 .60081 Mdot
1 .60081 Mdot
1 .60085 Mdot
1 .60113 Mdot
1 .6015 Mdot
1 .60182 Mdot
1 .60199 Mdot
1 .60202 Mdot
1 .6021 Mdot
1 .60221 Mdot
1 .60231 Mdot
1 .60243 Mdot
1 .60245 Mdot
1 .60252 Mdot
1 .60254 Mdot
1 .60256 Mdot
1 .60257 Mdot
1 .6026 Mdot
1 .60266 Mdot
1 .60271 Mdot
1 .60276 Mdot
1 .60276 Mdot
1 .60286 Mdot
1 .6029 Mdot
1 .60291 Mdot
1 .60292 Mdot
1 .60302 Mdot
1 .60307 Mdot
1 .6031 Mdot
1 .60311 Mdot
1 .60312 Mdot
1 .60319 Mdot
1 .60321 Mdot
1 .60325 Mdot
1 .60325 Mdot
1 .60327 Mdot
1 .6033 Mdot
1 .6033 Mdot
1 .6033 Mdot
1 .60331 Mdot
1 .60332 Mdot
1 .60332 Mdot
1 .60332 Mdot
1 .60332 Mdot
1 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[49]:=",
  ImageSize->{741.063, 458},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000AG0002[b000`400?l00000o`00003oo`3ooooo
0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0
ooooo`3ooomK0?ooo`000P3oool4000000H0oooo0P0000060?ooo`@00000J@3oool4000000H0oooo
0P0000060?ooo`@00000103oool6000000@0oooo1000001U0?ooo`@000001P3oool2000000H0oooo
100000050?ooo`@00000I03oool4000000H0oooo0P0000060?ooo`@000001`3oool00`000000oooo
0?ooo`040?ooo`@00000JP3oool4000000H0oooo0P0000060?ooo`<00000JP3oool4000000H0oooo
0P0000060?ooo`<000001@3oool6000000@0oooo1000001U0?ooo`@000001P3oool2000000H0oooo
0`0000060?ooo`@00000I03oool4000000H0oooo0P0000060?ooo`<00000203oool00`000000oooo
0?ooo`040?ooo`@00000O@3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool00`3o
ool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo0640oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`80
00001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`1P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool20000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool2000000T0oooo00<000000?ooo`3oool0IP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000090?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0H@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P000009
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1P
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000T0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0NP3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`1P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`1V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0H@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`1P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0NP3oool00003
0?ooo`000000oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo06D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0640oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1V0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0NP3oool000030?ooo`000000oooo00<0oooo
00<000000?ooo`3oool02`3oool4000006P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0;0?ooo`@000001`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@000002@3oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool4000000P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0303oool5000006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0<0?ooo`D000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`D000001`3oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool5000000H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1j0?ooo`0000<0oooo0000003oool00`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo1000001T0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo1000001S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3o
ool4000006T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo1000001T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`@00000H`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo1000001m0?ooo`0000<0oooo0000003oool00`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0JP3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000IP3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0OP3oool000030?ooo`000000oooo00<0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0JP3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000IP3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0OP3oool00080oooo
1000000>0?ooo`@00000J@3oool4000000h0oooo100000050?ooo`@000001@3oool5000006@0oooo
1000000>0?ooo`@000001@3oool5000006<0oooo1000000>0?ooo`@00000103oool6000000@0oooo
1@00001Y0?ooo`@000003`3oool4000006P0oooo1000000?0?ooo`@00000103oool4000000D0oooo
1@00001T0?ooo`@000003`3oool4000000@0oooo1@00001S0?ooo`@000003`3oool4000000<0oooo
1P0000040?ooo`D00000O03oool00?l0ooooo`3ooooo0?ooool0ooooD`3oool00`000000oooo0?oo
o`050?ooo`00o`3ooooo0?ooool0ooooo`3ooomC0?ooo`030000003oool0oooo00D0oooo003o0?oo
ool0ooooo`3ooooo0?oooe<0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooooo0?ooool0
ooooD`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?ooool0ooooo`3ooomC0?ooo`030000
003oool0oooo00D0oooo003o0?ooool0ooooo`3ooooo0?oooe<0oooo00<000000?ooo`3oool01@3o
ool00?l0ooooo`3ooooo0?ooool0ooooD`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?oo
ool0ooooo`3ooomC0?ooo`030000003oool0oooo00D0oooo003o0?ooool0ooooo`3ooooo0?oooe<0
oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooooo0?ooool0ooooD`3oool00`000000oooo
0?ooo`050?ooo`00o`3ooooo0?ooool0ooooo`3ooomC0?ooo`030000003oool0oooo00D0oooo003o
0?ooool0ooooo`3ooooo0?oooe<0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooooo0?oo
ool0ooooD`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?ooool0ooooo`3ooomC0?ooo`03
0000003oool0oooo00D0oooo003o0?ooool0ooooo`3ooooo0?oooe<0oooo00<000000?ooo`3oool0
1@3oool00?l0ooooo`3ooooo0?ooool0ooooD`3oool00`000000oooo0?ooo`050?ooo`003@3ooooo
00000?l00000o`00003o000004L000001`3oool000d0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0503oool01@00
0000oooo0000003oool0000000L0oooo000=0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo00L000000?oo
o`000000oooo0000003oool0000000L0oooo000=0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0100oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000001`3oool000d0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
3@3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000L0oooo
000=0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`250?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0N03oool00`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000L0oooo000=0?ooo`03
0000003oool0oooo08D0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo08D0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo08D0oooo00<000000?ooo`3oool0MP3oool01@000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool000d0oooo00<0
00000?ooo`3oool0Q@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08D0oooo00<0
00000?ooo`3oool0Q@3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0Q@3oool00`000000oooo0?ooo`1d0?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000L0oooo003o
0?ooool0ooooo`3ooooo0?oood00oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo
0?ooool0ooooo`3ooolm0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00
o`3ooooo0?ooool0ooooo`3ooolk0?ooo`030000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000070?ooo`00o`3ooooo0?ooool0ooooo`3oooli0?ooo`050000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000L0oooo003o0?ooool0ooooo`3ooooo0?ooocL0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000001`3o
ool00?l0ooooo`3ooooo0?ooool0oooo=@3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool0000000L0oooo003o0?ooool0ooooo`3ooooo0?oooc<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo00000007
0?ooo`00o`3ooooo0?ooool0ooooo`3oool`0?ooo`0>0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3o
ool00?l0ooooo`3ooooo0?ooool0oooo;P3oool00`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000L0oooo003o0?ooool0ooooo`3ooooo0?ooob`0oooo00D000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000
003oool0000000L0oooo003o0?ooool0ooooo`3ooooo0?ooobX0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?ooool0oooo
:03oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?oo
o`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1`3oool00?l0ooooo`3ooooo0?ooool0oooo9@3oool030000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00L000000?ooo`000000oooo0000003oool0000000P0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?ooool0oooo8`3oool00`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000001`3oool00?l0ooooo`3ooooo0?ooool0oooo8@3oool01@000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000L0oooo
003o0?ooool0ooooo`3ooooo0?oooal0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00070?ooo`00o`3ooooo0?ooool0ooooo`3ooolM0?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000001`3oool00?l0ooooo`3ooooo0?ooool0oooo6`3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000L0oooo003o0?ooool0ooooo`3ooooo0?oooaP0oooo00h000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo
0?ooool0oooo5P3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`070000003oool00000
0?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooool0ooooo`3ooolD0?ooo`050000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
1`3oool00?l0ooooo`3ooooo0?ooool0oooo4P3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003o
ool0000000D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool0
2P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000L0oooo003o0?ooool0ooooo`3ooooo0?oooa00oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooool0ooooo`3oool=0?ooo`0<0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooool0ooooo`3oool;0?ooo`03
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0<
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01@000000
oooo0000003oool0000000<0oooo1@0000030?ooo`00o`3ooooo0?ooool0ooooo`3oool90?ooo`05
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool01@3o
ool00?l0ooooo`3ooooo0?ooool0oooo1`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?ooool0oooo1@3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00001`3oool00?l0ooooo`3ooooo0?ooool0oooo0`3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0
oooo003o0?ooool0ooooo`3ooooo0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0
ooooo`3ooooo0?ooood0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`050?ooo`00o`3ooooo0?ooool0oooon`3oool01@000000oooo0?ooo`3oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`030000003oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000L0
oooo003o0?ooool0ooooo`3ooooi0?ooo`030000003oool0000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003o
ool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
00070?ooo`00o`3ooooo0?ooool0oooom`3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`000000203oool01@000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool01@3oool03P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000060?ooo`050000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?oo
oo@0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo00000007
0?ooo`00o`3ooooo0?ooool0oooolP3oool00`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0oooo003o
0?ooool0ooooo`3oooo`0?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`0000040?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`05
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?ooool0ooookP3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool0103oool01@000000oooo0000003oool0000000@0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo
00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000070?ooo`00
o`3ooooo0?ooool0ooook03oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`050000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?ooonX0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000050?oo
o`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`050000003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000P0oooo00<000000?ooo`3oool01P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooool0oooo
i@3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?oo
on<0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`0:0000003oool0oooo
0000003oool000000?ooo`000000oooo000000<0oooo00`000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`030000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000001P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0
oooo003o0?ooool0ooooo`3ooooQ0?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0
000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000004
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000070?ooo`00o`3ooooo0?ooool0oooog`3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`08
0000003oool0oooo0000003oool000000?ooo`0000030?ooo`0<0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool00000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`00
00001P3oool00`000000oooo0?ooo`030?ooo`0<0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000001`3oool00?l0ooooo`3ooooo0?ooom`0oooo00`000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000060?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo
0?ooool0oooofP3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`0<0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool00000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?oo
omP0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool01@000000oooo0000003oool0000000@0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000060?ooo`050000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?ooomH0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000001@3oool030000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`060?ooo`050000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`0>
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000070?ooo`00o`3ooooo0?ooool0ooooe03oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool0
0`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo003o0?ooool0ooooo`3ooooB
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool010000000oooo
0?ooo`0000050?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000
103oool00`000000oooo0?ooo`030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000
oooo000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000040?ooo`030000
003oool0000000D0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooooo0?oooll0oooo00<0
00000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool0
00000`3oool00`000000oooo000000040?ooo`030000003oool0000000H0oooo00<000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo
00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0
ooooo`3ooooo0?ooold0oooo00<000000?ooo`000000103oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool00000
00H0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000
oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1`3oool00?l0ooooo`3ooooo0?oool/0oooo00D000000?ooo`000000oooo000000040?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000
003oool0000000H0oooo00<000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000
003oool000000`3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo
000000040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001@3oool01@000000
oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0
000000L0oooo003o0?ooool0ooooo`3oooo90?ooo`070000003oool000000?ooo`000000oooo0000
00040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00h000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00001`3oool00?l0ooooo`3ooooo0?ooolL0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool02P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`0000080?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
00080?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0000003oool0000000L0
oooo003o0?ooool0ooooo`3oooo20?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000040?ooo`070000003oool000000?ooo`000000oooo00000004
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000001P3oool00`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`050000
003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00070?ooo`00o`3ooooo0?ooool0oooo`03oool00`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`00
0000oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool5000000<0oooo
003o0?ooool0ooooo`3ooonn0?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`060000003oool0oooo
0000003oool000001@3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`00
0000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?oo
ok`0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo
000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo
0000003oool000000?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool01@3oool00?l0ooooo`3ooooo0?oookX0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000060?ooo`05
0000003oool000000?ooo`0000001@3oool030000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000@0oooo00<000000?ooo`3oool01@3oool01P000000oooo0?ooo`000000
oooo000000D0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00`000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`0000070?ooo`00o`3ooooo0?ooool0oooo]`3oool02000
0000oooo0?ooo`000000oooo0000003oool000000`3oool03P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool00000103oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo
000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0
000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000007
0?ooo`00o`3ooooo0?ooool0oooo]@3oool00`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00H0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo003o0?oo
ool0ooooo`3ooonc0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000P0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo000000050?ooo`080000003oool0oooo0000003oool000000?ooo`00
00050?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00D00000
0?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000070?ooo`00o`3ooooo0?ooool0oooo/@3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`060000003o
ool0oooo0000003oool000001@3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo
0?ooo`000000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000000<0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?oo
o`050000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?oo
ool0oooo[`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`050000
003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000<0oooo00H000000?oo
o`3oool000000?ooo`0000070?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo
000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`060000003oool0oooo0000003oool000001@3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?ooojX0oooo00h00000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01`000000
oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
103oool01@000000oooo0?ooo`3oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`0000070?ooo`00o`3ooooo0?ooool0ooooZ03oool00`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000060?ooo`030000003oool0oooo00@0oooo00L00000
0?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000P0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool00000
0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooool0ooooYP3oool01@00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`3oool00`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00060?ooo`050000003oool0oooo0?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`030000003oool0000000L0oooo003o0?ooool0ooooo`3ooonT0?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?oo
o`030000003oool0000000D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`050?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000001`3oool00?l0ooooo`3ooooo0?oooj80oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo
0?ooo`030?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000070?oo
o`00o`3ooooo0?ooool0ooooW`3oool030000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3o
ool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
00002P3oool00`000000oooo0?ooo`030?ooo`0:0000003oool0oooo0000003oool000000?ooo`00
0000oooo000000@0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0000000D0
oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooooo0?oooid0oooo
00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000080?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000001P3oool00`000000oooo0?ooo`030?ooo`080000003oool0oooo0000
003oool000000?ooo`0000050?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo000000050?ooo`060000003oool0oooo0000003oool000000`3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00<000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?oooi/0oooo00D0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo00@0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0
000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`080000003oool0
oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`00
0000oooo000000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000<0oooo00D000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooool0oooo
V@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo0000000:0?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001@3oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000060?ooo`050000003oool000000?ooo`000000103oool02@000000oooo0000
003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooool0ooooU@3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`000000oooo000000040?ooo`0;0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0
oooo000000060?ooo`050000003oool000000?ooo`0000001@3oool020000000oooo0?ooo`000000
oooo0000003oool000001P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`00
0000103oool00`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000L0oooo003o0?ooool0
ooooo`3ooonB0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0000003oool000000080oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool0
20000000oooo0?ooo`000000oooo0000003oool000002P3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00
o`3ooooo0?ooool0ooooT03oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo00000008
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool000000?ooo`00
00001@3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?ooohh0oooo00D000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000
003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo0000
00<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooool0ooooS03oool01`000000oooo0?oo
o`3oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool0000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00X0oooo00D000000?ooo`000000oooo000000040?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo000000060?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooool0ooooRP3oool00`000000oooo
000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo
000000030?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`000000oooo0000003oool0
000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000080?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`050000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`070000003o
ool0oooo0?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo00000004
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`0<0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000001P3oool01@000000oooo
0000003oool0000000L0oooo003o0?ooool0ooooo`3ooon70?ooo`060000003oool0oooo0000003o
ool000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`0000001@3oool00`000000oooo0000000:0?ooo`0:0000003oool0oooo0000003oool000000?oo
o`000000oooo000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?oo
ool0ooooP`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`0000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
00@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`0000060?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`060?oo
o`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`000000103oool00`000000
oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00001`3oool00?l0ooooo`3ooooo0?oooh40oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool00000
0?ooo`000000103oool01@000000oooo0000003oool0000000P0oooo00D000000?ooo`3oool0oooo
000000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000001P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000
oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000001`3oool00?l0oooo
o`3ooooo0?ooogl0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00080?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo00D0
oooo003o0?ooool0ooooo`3ooomm0?ooo`030000003oool0oooo00L0oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`030000003oool000000080oooo00/000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo000000030?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3o
ool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00001`3oool00?l0ooooo`3ooooo0?ooohL0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
oooo0?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001`3oool00?l0oooo
o`3ooooo0?ooogX0oooo00<000000?ooo`3oool02P3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool0000000P0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D00000
0?ooo`3oool0oooo0000000>0?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`000000203oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000L0oooo003o0?ooool0ooooo`3ooomh
0?ooo`030000003oool0000000`0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00060?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00030?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000060?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000070?ooo`00o`3ooooo0?ooool0ooooM03oool00`000000oooo0000000>0?oo
o`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0
00000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000040?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool020000000oooo0?ooo`000000
oooo0000003oool000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000P0
oooo00D000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool5
000000<0oooo003o0?ooool0ooooo`3ooom_0?ooo`040000003oool0oooo000000X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000060?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool00000103oool00`000000oooo000000030?ooo`0<0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000001P3oool01@000000oooo0000
003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo003o0?ooool0
ooooo`3ooom]0?ooo`030000003oool0oooo00l0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`000000203oool01`000000oooo0?ooo`3oool000000?ooo`000000
103oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000H0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000001`3oool00?l0ooooo`3ooooo0?ooof/0oooo00<000000?ooo`3oool04`3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?oo
o`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000000:0?ooo`030000
003oool000000080oooo00D000000?ooo`000000oooo000000080?ooo`050000003oool0oooo0?oo
o`0000000`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3o
oooo0?oooh<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo
00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool0
3P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000001P3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo000000060?ooo`03
0000003oool0oooo00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000L0oooo003o0?oo
ool0ooooo`3ooomW0?ooo`030000003oool0000001/0oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003o
ool0000000H0oooo00<000000?ooo`3oool01@3oool02P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool01P3oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000
003oool0000000L0oooo003o0?ooool0ooooo`3ooomR0?ooo`060000003oool0oooo0000003oool0
00007`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`030000
003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`0;0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000
003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000103o
ool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool0
00000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool0
00000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo000000020?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000L0oooo003o0?ooool0ooooo`3ooomP0?ooo`030000003oool0
00000080oooo00<000000?ooo`0000007`3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo00@0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000@0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000203oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooooo
0?oooeh0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool000000280oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000
oooo000000040?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo000000030?oo
o`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000P0oooo00<000000?ooo`00
00001P3oool01@000000oooo0000003oool0000000D0oooo00@000000?ooo`3oool000000`3oool0
1@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00060?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00o`3o
oooo0?ooool0ooooG03oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo0000000R0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000
0`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool000000080oooo
00D000000?ooo`3oool0oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`00
0000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000
003oool0oooo0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?oo
o`000000103oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`050?ooo`00o`3ooooo0?ooool0ooooFP3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000002@0oooo00L000000?ooo`3oool0
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool0
00000?ooo`000000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?oo
o`070000003oool000000?ooo`000000oooo000000080?ooo`050000003oool000000?ooo`000000
103oool00`000000oooo0000000:0?ooo`030000003oool0000000H0oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000103oool00`00
0000oooo000000050?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000001P3oool0
1`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?oooeD0oooo00<0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000002@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?oo
o`030000003oool000000080oooo00<000000?ooo`0000001`3oool02P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo000000060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo000000020?ooo`050000003oool000000?ooo`0000002P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`000000oooo000000040?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?oo
o`3oool0oooo000000040?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0000
003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3o
ool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00
o`3ooooo0?ooool0ooooD`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000X0?ooo`030000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo
0?oooe40oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000X0?ooo`030000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`030000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
0P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
203oool00`000000oooo000000050?ooo`030000003oool000000080oooo00<000000?ooo`000000
303oool01@000000oooo0?ooo`3oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`000000
oooo000000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?ooodl0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000002H0oooo00D000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L00000
0?ooo`3oool0oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000D0oooo00H00000
0?ooo`3oool000000?ooo`0000070?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000L0oooo
003o0?ooool0ooooo`3ooom=0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000002P0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo
0000003oool0000000X0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?oo
o`050000003oool000000?ooo`000000203oool01@000000oooo0000003oool0000000@0oooo00<0
00000?ooo`3oool00`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000003
0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000060?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`000000oooo000000080?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo
0?ooodX0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
0000:03oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`00
0000103oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`060?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3o
ool000000?ooo`0000001P3oool00`000000oooo000000050?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000060?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00X0oooo00D000000?ooo`000000oooo000000060?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000203oool0
1`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000P0
oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo003o0?ooool0ooooo`3ooom60?oo
o`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00`0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003o
ool0000002P0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0000000:
0?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`040000003o
ool0oooo000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000X0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000000`3oool01@000000
oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00L0
00000?ooo`3oool0oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000
oooo0000003oool00000103oool00`000000oooo000000030?ooo`030000003oool0000000L0oooo
003o0?ooool0ooooo`3ooom40?ooo`050000003oool000000?ooo`000000103oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`030000003oool0000002P0oooo00<000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo
000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000203oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000303o
ool00`000000oooo0?ooo`060?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?ooool0oooo@P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000
003oool0000002P0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001P3oool0
0`000000oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo0000
000<0?ooo`030000003oool0oooo00@0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0000003oool000000`3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000040?ooo`05
0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00H0oooo00D000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooool0oooo@03oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`030000003oool0000002P0oooo00<000000?ooo`3oool00P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000
003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0000000D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo000000050?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo0000
00040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000L0oooo003o0?oo
ool0ooooo`3ooolk0?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000002P0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`00
0000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000P0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000003oool0000000X0oooo00D000000?ooo`3oool0oooo000000060?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`00
0000oooo000000070?ooo`00o`3ooooo0?ooool0oooo>@3oool01@000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000002P0oooo00<00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00P0
00000?ooo`3oool000000?ooo`000000oooo000000P0oooo00L000000?ooo`3oool0oooo0000003o
ool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
0000203oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?ooocL0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000002X0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1P3oool00`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool00`000000
oooo000000050?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000080?ooo`030000003oool0000000D0oooo00`000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00@000000?oo
o`3oool000001@3oool00`000000oooo000000080?ooo`030000003oool0oooo00@0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?ooocD0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000002d0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000H0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000001P3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`00
00001@3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo000000080?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000070?ooo`00o`3ooooo
0?ooool0oooo<P3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000002P0oooo00<0
00000?ooo`3oool00P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool0
00001P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000001P3oool00`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo00000004
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool0
0`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooooo0?ooobh0oooo00D000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0000000_0?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
103oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000
oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000007
0?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01`00
0000oooo0?ooo`3oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000070?ooo`00o`3ooooo0?ooool0oooo
;03oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000002P0oooo00<0
00000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000P0oooo00D000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`000005
0?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000D0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000001P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000
003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0oooo003o0?ooool0
ooooo`3ooolZ0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000
oooo0?ooo`0V0?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool000000080oooo00D000000?ooo`000000oooo000000060?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo000000060?ooo`050000003oool000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`0000003P3oool00`000000oooo0?ooo`040?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000
1@3oool020000000oooo0?ooo`000000oooo0000003oool00000203oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?ooool0oooo:03o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`000000:P3oool03P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool01`000000oooo0000003oool000000?ooo`000000
103oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000080?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00<000000?ooo`3oool01P3oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
103oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool00`000000
oooo0000000400000080oooo00@000000?ooo`3oool0oooo0P0000040?ooo`P0000000@0oooo0000
003oool00000103oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo003o0?oo
ool0ooooo`3ooolS0?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000002P0oooo
00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00H0oooo
00D000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool01@000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo0000000<0?ooo`050000003oool000000?oo
o`0000000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P0000000`3oool00000
0?ooo`020?ooo`<0000000D0oooo0000003oool0oooo000000030?ooo`<000001P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooooo0?ooob40
oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`000000:03oool00`000000oooo0000
00040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`3oool01@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0000000H0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`000000103oool00`000000oooo
000000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`060?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P000000103oool0
00000?ooo`0000090?ooo`8000000`3oool00`000000oooo000000040?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?ooool0oooo7`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`030000003oool000000080oooo00<000000?ooo`000000:03oool00`000000oooo00000002
0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000002
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`0;0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool00P000000303oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000L0oooo003o0?ooool0ooooo`3ooolM0?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`030000003oool0000002d0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo00000002
0?ooo`030000003oool0000000X0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000D0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0
oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00@0oooo00<000000?ooo`000000203oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`060000003oool000000?ooo`000000oooo
0P000000103oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool30000
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000050?ooo`P00000003o0?ooool0
ooooo`3ooolJ0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000060?ooo`070000003o
ool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000d0oooo
00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool0oooo0?ooo`000000oooo000000040?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@00
0000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo
003o0?ooool0ooooo`3ooolF0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo000000040?ooo`050000003oool000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<00000
0?ooo`000000:03oool00`000000oooo0?ooo`080?ooo`050000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
00P0oooo00<000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`000000oooo000000020?ooo`080000003oool000000?ooo`000000
oooo0000003oool2000000060?ooo`000000oooo0000003oool000000`3oool010000000oooo0000
000000030?ooo`<0000000@0oooo0000003oool000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooool0oooo503oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000
003oool00000:03oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000001P3oool01`000000
oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000000:0?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01@000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`80000000<0oooo
0000003oool00`000000103oool000000?ooo`0000020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool0000000L0oooo003o0?ooool0ooooo`3ooolB0?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000
003oool0000000<0oooo00@000000?ooo`3oool000001@3oool01@000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000:03o
ool00`000000oooo0?ooo`020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00L00000
0?ooo`3oool0oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0
oooo000000060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool01@00
0000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool020000000oooo0?ooo`00
0000oooo0000003oool000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`040000003oool0oooo
0?ooo`D00000103oool02P000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool40000
00060?ooo`000000oooo0000003oool000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool01@3oool00?l0ooooo`3ooooo0?ooo`d0oooo00h000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000
oooo000000060?ooo`030000003oool0oooo02/0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000`3oool030000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000H0
oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103o
ool01@000000oooo0000003oool0000000H0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3o
oooo0?ooo`/0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
0000:P3oool010000000oooo0?ooo`0000070?ooo`030000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`000000203oool01@000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000P0oooo00L000000?oo
o`3oool0oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool02@000000oooo0000
003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooool0oooo2@3oool01@000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000]0?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0000003oool0
000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000040?ooo`070000003o
ool0oooo0?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000001P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
0000203oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003o
ool000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?ooo`L0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool00000
00@0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0Z0?ooo`060000003oool0oooo
0000003oool000000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001P3oool00`000000
oooo0?ooo`040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000
oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000001`3oool00?l0ooooo`3ooooo0?ooo`80oooo00`000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000@0oooo00<00000
0?ooo`3oool0;@3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000002P3o
ool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0103oool01@000000oooo
0?ooo`3oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool00000
0?ooo`0000001P3oool00`000000oooo000000050?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
000000L0oooo003o0?ooool0ooooo`3oool00`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01P000000oooo
0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000:03oool00`000000
oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool0
00000?ooo`000000203oool01@000000oooo0000003oool0000000H0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`080?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`0<0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool00000103oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000P0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000L0oooo003o0?ooool0
ooooo@3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`00
00000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`0;0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00L0oooo
00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0000
00030?ooo`060000003oool0oooo0000003oool000001@3oool00`000000oooo000000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`04
0000003oool0oooo000000L0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`030000003oool0000000H0oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`00
0000oooo000000H0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001`3oool0
0?l0ooooo`3ooook0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000000:0?ooo`0>0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0:P3oool0
10000000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool00000
1@3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo
00<000000?ooo`0000001`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00P000000?oo
o`3oool000000?ooo`000000oooo000000D0oooo00X000000?ooo`3oool000000?ooo`000000oooo
0000003oool00000103oool00`000000oooo000000050?ooo`030000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000P0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooooL0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`000000:03oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool0103oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool0203oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000
oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`3oool0203oool01@000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000007
0?ooo`00o`3ooooo0?oooo@0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000:P3oool01P00
0000oooo0?ooo`000000oooo000000X0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool01@3oool030000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo
000000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`000000103oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`000000203oool01@000000oooo0?ooo`3oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
103oool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@00
0000oooo0?ooo`3oool0000000L0oooo003o0?ooool0oooolP3oool00`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool0
00000`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo00H0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`3oool00`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`0000001`3oool00?l0ooooo`3oooo^0?ooo`030000003oool0000000<0oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000001P3oool01@000000oooo0000003oool000000080oooo
00<000000?ooo`3oool00`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00000A0?ooo`030000
003oool0000002X0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`030000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`0000040?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0
oooo00P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000001`3oool0
0`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool0
0?l0ooooo`3oooo/0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo000000<0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool00000
00@0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo
0?ooo`000000oooo000000060?ooo`030000003oool0000000H0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000H0oooo00D00000
0?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0oooo003o0?ooool0ooooj@3o
ool010000000oooo0?ooo`0000070?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00D000000?ooo`3oool0oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`00
00030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo0080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000004`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo000000030?oo
o`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000
oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?oo
onL0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000P3o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo0000000d0?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000080?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool00000
0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool00000
00<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00X00000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool030000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00h000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool0
0?l0ooooo`3ooooS0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00P0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000002l0
oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?oo
o`050?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000@0
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo
000000`0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`000000
1@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000@0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooQ0?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool01`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`00
0000103oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`00
00001@3oool010000000oooo0?ooo`0000030?ooo`070000003oool0oooo0?ooo`000000oooo0000
00040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000
003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool0
1@000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo0000
00<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`000000203o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000L0oooo003o0?ooool0oooog`3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00<000000?ooo`3oool02P3oool00`000000oooo000000040?ooo`030000
003oool0000000D0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`0000001P3oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`070000003oool000000?ooo`00
0000oooo000000060?ooo`070000003oool000000?ooo`000000oooo0000000:0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo
00D000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`050?ooo`00o`3ooooo0?ooomX0oooo00<000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0
203oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0;`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000P0oooo00L0
00000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000002P3oool01P000000
oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0
oooo00@000000?ooo`3oool000001@3oool01@000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?ooomP0oooo00D000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000`0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo0340
oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00060?ooo`030000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`05
0000003oool000000?ooo`000000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool01@000000oooo
0000003oool0000000H0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000060?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool0000000L0oooo003o0?ooool0ooooeP3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool02`000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`000000oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000002P3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool00000103oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00L0
00000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`000000;`3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?oo
o`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool000000?ooo`000000203oool00`000000
oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0
000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`00
0000oooo000000070?ooo`00o`3ooooo0?ooom40oooo00`000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`030000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`030000003oool0oooo00P0oooo00/000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0?oo
o`3oool000000?ooo`0000000P3oool00`000000oooo0000000_0?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?oo
o`000000oooo000000060?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
3P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3o
ool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`03
0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo
0?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3o
ooo?0?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0oooo00P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0
oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000X0?ooo`03
0000003oool0oooo00@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0?ooo`3oool000000?ooo`000000103oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`030000003oool0000000P0oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000002P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool020000000oooo
0?ooo`000000oooo0000003oool000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`00
00000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`00
00070?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`3oool0oooo0000003oool00000
0080oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000070?ooo`030000003oool0
oooo00D0oooo003o0?ooool0ooooc@3oool01@000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<000000?ooo`000000203o
ool00`000000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001P3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo
000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000020?oo
o`030000003oool0000000D0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`050000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000070?ooo`00o`3ooooo0?ooolT0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`3o
ool0203oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`3oool0103oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo02d0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001P3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`02
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`000000
oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000001`3oool00?l0ooooo`3oooo70?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000003@3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`050000003oool000000?ooo`0000002P3oool02P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`0000030?ooo`060000003oool0oooo0000003oool000000`3oool00`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000H0oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`0000001P3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo000000050?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`0<0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000001P3oool01@000000oooo0000003oool00000
00@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000070?ooo`00o`3ooooo0?oool@0
oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000002P3oool00`000000oooo000000020?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000P0oooo00<00000
0?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`000000oooo000000080?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo
000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000001@3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`07
0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01@3oool00?l0ooooo`3oooo00?ooo`050000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0
oooo00@000000?ooo`3oool000002P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3o
ool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00@0
00000?ooo`3oool000000`3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00001@3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`040000003oool0oooo0000
00<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00@0
00000?ooo`3oool000000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`D000000`3oool00?l0ooooo`3ooonn0?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`3oool02P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?oo
o`0000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo000000030?oo
o`030000003oool000000080oooo00<000000?ooo`000000;@3oool00`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`070000003oool000000?ooo`000000oooo000000040?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000070?ooo`030000003oool000000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo003o0?ooool0
oooo_03oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`080?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo0000000b
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001P3oool01`000000oooo0000003o
ool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000103oool01@00
0000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?oo
o`3oool0000000H0oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00D000000?oo
o`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000@0oooo00D000000?ooo`000000oooo000000030?ooo`04
0000003oool0oooo000000T0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool01@3oool00?l0ooooo`3ooong0?ooo`030000003oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool00000303oool00`00
0000oooo0?ooo`030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000070?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00`000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000001P3oool00`000000oooo000000030?ooo`060000003oool0oooo0000003oool00000
:P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000001@3oool020000000oooo0?ooo`000000
oooo0000003oool000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`00
0000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000050?ooo`030000003oool0oooo00D0oooo003o0?ooool0oooo
]@3oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool01@3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool00`000000oooo0?ooo`080?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`030000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0000002P0oooo00<000000?oo
o`3oool0203oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool01@3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000040?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?oo
o`030000003oool000000080oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0
000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000
oooo000000040?ooo`030000003oool0000000L0oooo00H000000?ooo`3oool000000?ooo`000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool030000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000001`3oool00?l0ooooo`3ooona0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool03000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
000]0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0303oool00`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool0203oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?oo
o`000000103oool00`000000oooo000000030?ooo`030000003oool0000000L0oooo003o0?ooool0
oooo[`3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo
00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000H0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00X0oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000103oool00`000000oooo0000
00030?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`040000
003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01P000000oooo0?ooo`000000oooo000002X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0000000@0?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`0<0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool00000203oool01@000000oooo0?oo
o`3oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`060000003oool0oooo0000
003oool000001@3oool00`000000oooo000000020?ooo`030000003oool0000000X0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?oooj`0oooo00h000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool02P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000203oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001@3o
ool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`080?ooo`050000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?oo
o`050000003oool000000?ooo`0000002P3oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000X0oooo00D000000?ooo`000000oooo000000040?oo
o`050000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool0
00001@3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000001P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo
0?ooojP0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000@0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool00`000000oooo0?ooo`080?ooo`050000003oool000000?ooo`00
00001@3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01P000000oooo0?oo
o`000000oooo000000L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000040?oo
o`050000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000
oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool02P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`0000040?ooo`030000003oool0000002P0oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`00
0000oooo000000`0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo
00P000000?ooo`3oool000000?ooo`000000oooo000000D0oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo003o0?ooool0ooooYP3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?oo
o`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00P0oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00P00000
0?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000h0oooo00D000000?ooo`000000
oooo000000040?ooo`030000003oool0000000D0oooo00X000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000103oool00`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool0000000L0oooo003o0?oo
ool0ooooY03oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000
003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?oo
o`0000030?ooo`030000003oool0000000l0oooo00<000000?ooo`0000000`3oool00`000000oooo
000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo
0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`000000:03oool00`000000oooo0?ooo`060?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool020000000oooo0?ooo`000000oooo
0000003oool000000`3oool00`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000001P3oool00`000000
oooo000000080?ooo`050000003oool0oooo0?ooo`000000103oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000001P3oool00`000000
oooo0000000>0?ooo`030000003oool0000000H0oooo00L000000?ooo`3oool0oooo0000003oool0
000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000L0oooo003o0?ooool0oooo
W`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000000=
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`03
0000003oool0000000H0oooo00<000000?ooo`3oool01P3oool01@000000oooo0000003oool00000
00<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`000000:03oool00`000000oooo0000000:0?oo
o`030000003oool0000000@0oooo00D000000?ooo`000000oooo000000040?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00000<
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000060?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`0000001`3oool0
30000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000L0oooo003o0?ooool0ooooW@3o
ool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0?0?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool010000000oooo
0?ooo`0000050?ooo`030000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`00000f
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000001P3oool01@000000oooo0?ooo`3o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo
00<000000?ooo`000000203oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000103oool00`000000oooo0?ooo`080?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooonI0?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`030000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`000003
0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`080?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000040?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3o
ool000000?ooo`0000050?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`000000:03oool0
0`000000oooo000000060?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0203oool0
1@000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000
003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0oooo
0080oooo00D000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00h00000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00D0
00000?ooo`000000oooo000000080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000H0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo
00<000000?ooo`3oool01@3oool00?l0ooooo`3ooonG0?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool0203oool00`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000002l0oooo00<0
00000?ooo`000000203oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L0
00000?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
203oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`0000000P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo000000060?oo
o`070000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000060?ooo`050000003oool000000?ooo`0000001P3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000070?ooo`00o`3ooooo0?oooi@0oooo00`000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?oo
o`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000000?0?ooo`050000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`000003
0?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000H0oooo
00<000000?ooo`3oool0203oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo000000040?ooo`030000003o
ool0oooo02X0oooo00@000000?ooo`3oool000001@3oool01@000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00@000000?ooo`3oool00000303oool01`000000oooo0?ooo`3oool00000
0?ooo`000000203oool00`000000oooo0?ooo`080?ooo`030000003oool0000000<0oooo00P00000
0?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000103oool00`000000
oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001@3oool020000000oooo0?ooo`000000
oooo0000003oool000000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00<000000?oo
o`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000001@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00`000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`0000070?ooo`00o`3ooooo0?oooi00oooo00D000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00D000000?ooo`000000oooo000000060?ooo`050000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`000000
0`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo000000040?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00X000000?oo
o`3oool000000?ooo`000000oooo0000003oool00000303oool00`000000oooo000000040?ooo`03
0000003oool0000000D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool010000000oooo0?ooo`00
00030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000L0oooo003o0?ooool0ooooSP3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000H0oooo
00<000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00P000000?ooo`3o
ool000000?ooo`000000oooo000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`03
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`0000000`3oool00`000000oooo0000000d0?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000D0oooo00h00000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0
000000X0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool0000000P0oooo00<0
00000?ooo`000000203oool01`000000oooo0000003oool000000?ooo`0000001`3oool00?l0oooo
o`3ooon:0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`040?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000030?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0000003oool00000
00<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000103oool00`000000
oooo0000000X0?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000040?oo
o`050000003oool0oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`060000003oool0
oooo0000003oool000000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`00
0000oooo000000030?ooo`030000003oool0oooo00D0oooo003o0?ooool0ooooQ`3oool03P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00@000000?ooo`3oool000002P3oool00`000000oooo000000050?ooo`030000
003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool01P3oool01@000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool00`000000oooo000000040?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`0000002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000P0oooo00L000000?oo
o`3oool0oooo0000003oool0000000h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`000000oooo000000060?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo
000000060?ooo`050000003oool0oooo0?ooo`000000203oool01`000000oooo0000003oool00000
0?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000070?ooo`00o`3ooooo0?ooohD0oooo00<000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`3oool0203oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0:03oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?oo
o`080000003oool0oooo0000003oool000000?ooo`00000:0?ooo`030000003oool0000000<0oooo
00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`000000oooo0000
00040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool030000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`050?ooo`00o`3ooooo0?oooh40oooo00<000000?ooo`0000000`3oool03P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0
oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000X0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000001@3oool030000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000H0oooo00<000000?ooo`0000001@3oool00`000000oooo000000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool01@00
0000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`050000003oool000000?oo
o`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo000000030?ooo`030000003oool0000000L0oooo003o0?oo
ool0ooooO`3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00D000000?ooo`000000oooo
000000030?ooo`060000003oool0oooo0000003oool000000`3oool01@000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`060?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000203oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool09P3oool00`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
00001P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000001P3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`050000003oool0oooo0?ooo`0000001P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool02000
0000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`070000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0oooo003o0?ooool0
ooooNP3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00h000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00L000000?ooo`3oool0oooo
0000003oool0000000P0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000080?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool0
0000203oool00`000000oooo0?ooo`0a0?ooo`070000003oool0oooo0?ooo`000000oooo00000002
0?ooo`030000003oool0000000`0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo
00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`00
0000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000l0oooo00<000000?ooo`0000001@3oool030000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000P0oooo00<000000?ooo`000000103o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooogP0
oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00h000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000<0oooo00D000000?ooo`000000
oooo000000040?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000060?oo
o`050000003oool0oooo0?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo000000060?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000H0oooo00<000000?ooo`000000
0`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool000000080oooo
00D000000?ooo`3oool0oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooog@0oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?oo
o`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool01@00
0000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo000000030?ooo`030000003oool0oooo00/0oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000203o
ool00`000000oooo0?ooo`040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo000000060?ooo`050000003oool00000
0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
0000000_0?ooo`050000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo00@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
203oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000H0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000007
0?ooo`00o`3ooooo0?ooog80oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool01@000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000040?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool0103oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool00`000000oooo0000000:
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`0000000P3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00P0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo00000004
0?ooo`030000003oool0oooo00D0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000H0
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`030000
003oool0oooo00@0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool0
0?l0ooooo`3ooom]0?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`050000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000H0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000002P3oool01`000000oooo0000003oool00000
0?ooo`000000203oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
0000000<0?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0000003oool0000000<0oooo00@000000?ooo`3oool00000:P3oool00`000000oooo000000040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000h0oooo00<000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
1P3oool01@000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000
oooo000000<0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool000000?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo0000000:0?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo00D0oooo003o0?ooool0ooooJ`3oool01@00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?oo
o`3oool0oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0
oooo00D000000?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000004@3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000
003oool000001P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00D000000?ooo`000000oooo0000000c0?ooo`0<0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000002P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?oo
o`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0
oooo00H0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`000000
oooo0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?oo
ofL0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3o
ool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool00`000000oooo000000080?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`030000003oool0
oooo00`0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`040?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool03P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000002X0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`000000oooo000000040?ooo`07
0000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool0
oooo0?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000203oool00`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?oo
of@0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000
oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003o
ool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool00`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0?ooo`3o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000D0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`0000001P3oool01@000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo0?ooo`0V0?ooo`030000003oool000000080oooo00<000000?oo
o`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo0000
00080?ooo`050000003oool000000?ooo`0000002P3oool00`000000oooo000000040?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000H0oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`000000103oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001`3oool00?l0ooooo`3ooomR0?ooo`030000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool020000000oooo
0?ooo`000000oooo0000003oool000000`3oool00`000000oooo000000020?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000050?oo
o`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000060?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000001P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00020?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool000000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool00`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000080?ooo`030000
003oool0000002l0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?oo
o`000000203oool01`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000
003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<00000
0?ooo`0000001P3oool00`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000103oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?oooeh0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000001@3oool03P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool01`000000oooo0000003oool000000?ooo`000000
103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool0
00000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool000000080oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`070000003oool0
oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
103oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000040?oo
o`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool00`000000oooo0?ooo`0V0?ooo`030000003oool0000000H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000203oool00`000000
oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool02P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo00000006
0?ooo`050000003oool000000?ooo`000000203oool010000000oooo0?ooo`3oool5000000<0oooo
003o0?ooool0ooooG03oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000H0oooo00<0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000001P3oool01@000000oooo0000003oool000000080oooo00<0
00000?ooo`0000001@3oool00`000000oooo0000000C0?ooo`050000003oool000000?ooo`000000
1P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`070000003oool0
oooo0?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000000`3oool010000000
oooo0?ooo`00000/0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000000P3oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000001P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool0
1`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool01`000000oooo0000
003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?oooeL0oooo
00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0>0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`05
0000003oool000000?ooo`000000203oool01@000000oooo0?ooo`3oool0000000@0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0oooo00P0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000203oool00`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0
oooo000000080?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`000000:P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`080?ooo`050000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000X0oooo00L000000?ooo`000000oooo0000003o
ool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool02000
0000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000001P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00o`3o
oooo0?oooeD0oooo00<000000?ooo`3oool0103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo00000003
0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`0000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
0000000A0?ooo`030000003oool0oooo00H0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool000000080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3o
ool00`000000oooo000000050?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`000000103o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool010000000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000080?ooo`050000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`050?ooo`00o`3ooooo0?oooe40oooo00<000000?ooo`000000303oool01@000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo
0?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0
000000@0oooo00<000000?ooo`0000002P3oool01@000000oooo0?ooo`3oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`3oool03P3oool01@000000
oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`000000
103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`050000003oool0oooo0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`000000103oool01`000000
oooo0?ooo`3oool000000?ooo`000000103oool01@000000oooo0000003oool0000000P0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0
000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`070000003oool0
00000?ooo`000000oooo000000060?ooo`030000003oool0000000@0oooo00<000000?ooo`000000
0`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000070?oo
o`00o`3ooooo0?ooodl0oooo00D000000?ooo`000000oooo0000000<0?ooo`050000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo
000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0
00000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000060?ooo`030000003oool0oooo00H0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00H000000?ooo`3oool000000?ooo`00000_0?ooo`050000003o
ool0oooo0?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool030000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`000000203oool00`000000oooo000000040?ooo`050000003oool0oooo
0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`00000<
0?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`00
00001@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool02`00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01@3oool00?l0ooooo`3ooom:0?ooo`030000003oool000000080oooo00D000000?ooo`000000
oooo0000000<0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`070000003oool000000?ooo`00
0000oooo000000080?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0
oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000002l0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo000000060?ooo`050000003oool0oooo0?ooo`00
0000203oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000005
0?ooo`080000003oool0oooo0000003oool000000?ooo`0000050?ooo`030000003oool0oooo0080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo0000
00060?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000000P3oool00`000000oooo000000050?ooo`030000003oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooodP0oooo
00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000303oool01@00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000P3oool01@000000oooo0000003oool0000000<0oooo00X000000?oo
o`3oool000000?ooo`000000oooo0000003oool000001P3oool00`000000oooo000000030?ooo`03
0000003oool0000000P0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool0
oooo0?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000
oooo0?ooo`00000:0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`0<0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool0
0`000000oooo0000000Z0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0000000H0oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`070000003oool00000
0?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool00000
0?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01P000000oooo
0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?oo
o`050000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo00D0oooo003o0?ooool0ooooA03oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000003P3oool00`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`0000060?ooo`050000003oool000000?ooo`0000000`3oool03P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo0000000:0?ooo`030000003oool000000080oooo
00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000`3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000002P3o
ool01`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001P3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001P3oool01@000000
oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0000003oool0
000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003o
ool00000203oool00`000000oooo000000030?ooo`040000003oool0oooo000000D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool01@3oool00?l0ooooo`3ooom20?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo00D000000?oo
o`3oool0oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?oo
o`3oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool01@000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo
0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000060?ooo`070000003oool00000
0?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0;0?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000060?ooo`050000003oool000000?ooo`000000103o
ool01`000000oooo0?ooo`3oool000000?ooo`000000203oool01@000000oooo0000003oool00000
00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool00000
0?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool000000080oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000Z0?ooo`0:
0000003oool0oooo0000003oool000000?ooo`000000oooo000000P0oooo00<000000?ooo`3oool0
203oool00`000000oooo000000050?ooo`060000003oool0oooo0000003oool000001@3oool02000
0000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo000000040?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01`000000oooo
0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`040000003oool0oooo
000000D0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?oo
o`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool00?l0ooooo`3ooolm0?ooo`030000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`000000303oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool02@000000
oooo0000003oool000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003o
ool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000`0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo000000050?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo0000
00080?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000080?ooo`030000
003oool0000000L0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`0000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
00@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000203oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo
000000L0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000007
0?ooo`00o`3ooooo0?oooc/0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000`0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00D0
00000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`030000003oool0000000D0oooo00h000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0000
00040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`0000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo000000060?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool00P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000001P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo00000005
0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000070?ooo`00o`3ooooo
0?ooocL0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo0000000<0?ooo`030000003oool0oooo00@0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000203oool00`000000
oooo0?ooo`040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000
0`3oool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0
000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000002d0oooo00D000000?ooo`3o
ool0oooo0000000<0?ooo`030000003oool0oooo00X0oooo00D000000?ooo`000000oooo00000002
0?ooo`030000003oool000000100oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`03
0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`0000000`3o
ool020000000oooo0?ooo`000000oooo0000003oool000002P3oool00`000000oooo000000080?oo
o`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00o`3ooooo0?oooc80oooo00<00000
0?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000`0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
00@0oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`030000003oool0000000<0oooo00P0
00000?ooo`3oool000000?ooo`000000oooo000000P0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3o
ool0oooo0000000=0?ooo`070000003oool0oooo0?ooo`000000oooo000000080?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000080?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000001`3oool03000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?oo
o`000000:03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo0000
00D0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool0103oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo
000000060?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01@000000oooo0000003oool0000000`0oooo00<000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000001P3o
ool01`000000oooo0000003oool000000?ooo`000000203oool00`000000oooo000000070?ooo`00
o`3ooooo0?oooc00oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`000000303oool01@000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?oo
o`0000001P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000050?ooo`030000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`050000003oool000000?ooo`0000004@3oool00`000000oooo0?oo
o`060?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080
oooo00D000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000203oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo02l0oooo00<000000?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool0000000`0oooo00D000000?ooo`000000oooo0000000:0?ooo`080000
003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0000000@0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`05
0000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool00`000000oooo000000030?ooo`030000003oool0
00000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo00P0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
203oool00`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000L0oooo003o0?ooool0oooo;03oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00h0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3o
ool01@000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`030000003oool0000000P0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool0
oooo0?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000005@3oool00`00
0000oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0000002P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000070?ooo`030000003oool0oooo0080oooo
00D000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0000000H0oooo00<000000?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0<0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`050000
003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool00000
00<0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`0000001`3oool00?l0ooooo`3ooolZ0?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000`0oooo00D000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000002P3oool010000000oooo
0?ooo`0000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0;0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool030000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000H0oooo00D000000?ooo`00
0000oooo0000000?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo00000003
0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
0000103oool00`000000oooo0000000X0?ooo`030000003oool0000001D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000060?ooo`030000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000
003oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000
003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001`3oool0
0?l0ooooo`3ooolU0?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`000000303oool01@000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000001P3oool02`00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`050000003oool0oooo0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`0:0000
003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000000<0oooo00<000000?ooo`000000203oool00`000000oooo000000020?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0103oool00`000000oooo000000050?oo
o`060000003oool0oooo0000003oool00000203oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo00000003
0?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`0:0000003oool0oooo0000003oool000000?ooo`00
0000oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooolS
0?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo0000000>0?ooo`030000003oool0oooo0080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000060?ooo`0;0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`000000203oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
0000103oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`080?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`040000003o
ool0oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?oo
o`000000oooo000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0_0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`3oool0oooo0000000E0?ooo`070000003oool000000?ooo`000000oooo
0000000:0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool01P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`050000003oool00000
0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooolO0?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo0000000<0?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0000000X0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000001@3oool03P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000001P3oool00`000000oooo0?ooo`080?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000060?oo
o`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00`000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`0000001@3oool02P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000040?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0000000<0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000103o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo000000080?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000000H0oooo00<000000?ooo`000000303oool01`000000oooo0000003oool0
00000?ooo`0000001P3oool01@000000oooo0000003oool0000000L0oooo003o0?ooool0oooo6P3o
ool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000>0?oo
o`030000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000060?oo
o`030000003oool0000000@0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000X0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo000000030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000060?ooo`030000
003oool0oooo00P0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000;@3oool00`000000oooo0?ooo`060?ooo`050000003oool000000?oo
o`0000001P3oool01@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`3oool0oooo0000
003oool0000000P0oooo00<000000?ooo`0000001P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3o
ool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool0
oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`000000
1P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?oo
oaP0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`000000303oool00`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`0000002P3oool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`3oool0oooo
0000003oool0000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool00000
0080oooo00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`3oool01P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`0_0?ooo`030000003oool00000
00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000000<0?ooo`030000003oool0
oooo0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000P0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`0000001P3oool01@000000oooo0000003oool0000000X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000
003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000L0oooo003o0?ooool0oooo503oool00`000000oooo000000030?ooo`0>0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0oooo
00@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000001`3o
ool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00/0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
oooo00P0oooo00D000000?ooo`000000oooo0000000:0?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0103oool02`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`030000003oool0oooo02l0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000060?ooo`050000003o
ool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`070000003o
ool000000?ooo`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00P000000?ooo`3oool000000?ooo`00
0000oooo000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000P0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000D0oooo00P000000?oo
o`3oool000000?ooo`000000oooo000000X0oooo00<000000?ooo`0000001P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?oooa80oooo00D000000?oo
o`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000h0oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0oooo00D0oooo00X000000?ooo`3oool000000?ooo`000000oooo
0000003oool000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool00000:P3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000001@3oool00`000000
oooo000000040?ooo`050000003oool000000?ooo`000000203oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0
000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001`3oool00?l0
ooooo`3oool=0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool03P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000<0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0000
00040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001@3oool010000000oooo
0?ooo`00000@0?ooo`030000003oool0000000H0oooo00<000000?ooo`0000000`3oool03P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`00
0000oooo0?ooo`050?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool00000103oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?oo
o`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000060?ooo`030000003oool0000003@0oooo00D000000?oo
o`3oool0oooo000000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000001P3oool01`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000X0oooo00L000000?ooo`3oool0oooo0000003oool00000
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00
o`3ooooo0?ooo`/0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0
oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo0000000E0?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000X0oooo00<00000
0?ooo`3oool00`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool03P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00001P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool030000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`030?ooo`030000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool000000080oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`0X0?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00P0
00000?ooo`3oool000000?ooo`000000oooo000000H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo00000008
0?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooo`L0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000303oool01@00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080
oooo00D000000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool0
1`000000oooo0000003oool000000?ooo`0000001P3oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000L0oooo00X000000?ooo`3oool000000?oo
o`000000oooo0000003oool00000103oool00`000000oooo0?ooo`0:0?ooo`070000003oool0oooo
0?ooo`000000oooo0000000:0?ooo`030000003oool0oooo03X0oooo00D000000?ooo`000000oooo
000000040?ooo`070000003oool0oooo0?ooo`000000oooo0000000?0?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00H0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000080?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
1@3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`040000003o
ool0oooo000000L0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool01@3oool00?l0ooooo`3oool20?ooo`080000003oool0oooo0000003oool000000?oo
o`0000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`0>
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`030000003oool000000180oooo00<000000?ooo`3oool0
103oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000080?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`080000003o
ool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo00@0oooo00L000000?oo
o`3oool0oooo0000003oool000000080oooo00<000000?ooo`3oool02P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000203o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000050?oo
o`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003o
ool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo0?ooo`050?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool00000103oool00`000000oooo0000000:0?ooo`070000003oool000000?ooo`000000oooo0000
00070?ooo`00o`3ooooo0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`000000oooo0000
00040?ooo`030000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
0000000>0?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
0?ooo`050?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?oo
o`000000203oool00`000000oooo000000060?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000P0oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000
003oool0000000H0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000001`3oool00`000000oooo000000040?ooo`07
0000003oool0oooo0?ooo`000000oooo0000000<0?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`000000oooo000000040?ooo`030000003oool0000000L0oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1`3oool00?l0ooooo@3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000303oool01@00
0000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo00000006
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003o
ool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000002P3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`00
0000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool000000`3oool0
1@000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000002P3oool00`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000
003oool000001@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool000000080oooo00<00000
0?ooo`3oool01@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000H0oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool0
00000?ooo`0000050?ooo`080000003oool0oooo0000003oool000000?ooo`0000060?ooo`070000
003oool0oooo0?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0000000:0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00L0oooo003o0?ooooT0oooo00<000000?ooo`0000002P3oool00`000000oooo000000030?ooo`03
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo0000000>0?ooo`030000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00L0
00000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
203oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000004@3oool00`000000oooo0000000:0?ooo`050000003oool0
oooo0?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0000000H0oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000
003oool000000?ooo`000000oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
0`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`000000203oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`3oool00`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo
0?ooo`050?ooo`00o`3ooood0?ooo`030000003oool0000001<0oooo00D000000?ooo`000000oooo
000000040?ooo`030000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`000000403oool020000000oooo0?ooo`000000oooo0000003oool0
00000`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000@0
oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000002P3oool01`000000oooo0000003oool00000
0?ooo`0000002P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00X000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`040?ooo`030000003oool0000000X0oooo
00D000000?ooo`3oool0oooo000000060?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`00
0000oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`050000003o
ool0oooo0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000L0oooo
003o0?oooo00oooo00<000000?ooo`0000006@3oool00`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00060?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000<0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool00000
0?ooo`000000203oool00`000000oooo000000060?ooo`050000003oool000000?ooo`000000103o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000002P3oool00`000000oooo
0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00D00000
0?ooo`000000oooo000000030?ooo`040000003oool0oooo000003L0oooo00<000000?ooo`3oool0
103oool01`000000oooo0?ooo`3oool000000?ooo`0000002P3oool00`000000oooo0?ooo`020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000P0oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00L000000?ooo`000000
oooo0000003oool0000000@0oooo00<000000?ooo`0000001P3oool00`000000oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000X0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00@0
00000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000P3oool020000000oooo0?ooo`3oool000000?ooo`00
0000oooo1@0000030?ooo`00o`3oooo^0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`00
0000103oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000
003oool000000?ooo`00000@0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00@0
00000?ooo`3oool000000`3oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo000000030?ooo`030000003o
ool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000203oool01@000000oooo0000003oool0000000H0oooo00D000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`060000003o
ool0oooo0000003oool000000`3oool01@000000oooo0000003oool0000000P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000
00060?ooo`030000003oool0000000H0oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`000000203oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00@000000?ooo`3oool000001`3oool03P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0
000000X0oooo00D000000?ooo`3oool0oooo000000070?ooo`00o`3ooooY0?ooo`040000003oool0
oooo000001l0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`0>0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo0000000E0?ooo`070000003oool000000?oo
o`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00/000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo000000080?ooo`030000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?oo
o`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00h0oooo00D000000?ooo`000000oooo000000080?ooo`030000
003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00@000000?oo
o`3oool000000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000060?ooo`03
0000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo000000050?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo
0340oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00D000000?ooo`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
00@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000040?ooo`030000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000080?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
000000<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001`3oool00?l0ooooi`3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000`0oooo00D000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0
00000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`00
00003`3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`3oool01@3oool00`000000oooo000000080?ooo`030000003oool0000000H0oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`00
00003@3oool01@000000oooo0000003oool0000000`0oooo00<000000?ooo`3oool0103oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`3oool0oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D0
00000?ooo`000000oooo000000080?ooo`030000003oool0oooo00P0oooo00D000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`070000003oool000000?ooo`000000
oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001`3oool00?l0oooo
o`3oool;0?ooo`050000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`0>
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000
0`3oool020000000oooo0?ooo`000000oooo0000003oool00000303oool01@000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`00
00000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000060?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000@0oooo00<000000?oo
o`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo
000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`030000003oool000000080oooo00<000000?ooo`000000:03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`080?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`05
0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000050?ooo`060000003oool0oooo0000003oool000001@3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool020000000oooo0?ooo`000000
oooo0000003oool00000203oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00001@3oool020000000oooo0?ooo`000000oooo0000003oool000001@3oool020000000oooo0?oo
o`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool00000
0?ooo`0000001`3oool00?l0ooooi@3oool00`000000oooo0?ooo`0R0?ooo`050000003oool00000
0?ooo`000000103oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000`0oooo00D000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool0
0000203oool01@000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`00
0000oooo000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000060?ooo`03
0000003oool0000000X0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3o
ool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000001P3oool01@000000
oooo0?ooo`3oool0000000`0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
103oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`050?oo
o`060000003oool0oooo0000003oool000000`3oool01@000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo0000000<0?ooo`050000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000050?ooo`030000
003oool0000000L0oooo003o0?ooool0oooo3@3oool00`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000003P3oool0
1@000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000
00030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00P00000
0?ooo`3oool000000?ooo`000000oooo000000<0oooo00`000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`0000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`00
0000oooo000000040?ooo`050000003oool000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000080?ooo`050000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000004@3oool00`000000oooo0?ooo`0A
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo000000050?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`0<0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01`000000oooo
0000003oool000000?ooo`000000203oool01`000000oooo0000003oool000000?ooo`0000001P3o
ool00`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool01@000000
oooo0000003oool0000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo000000050?oo
o`080000003oool0oooo0000003oool000000?ooo`0000060?ooo`030000003oool0000000D0oooo
00<000000?ooo`3oool00P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001`3oool00?l0
ooooh`3oool00`000000oooo0?ooo`0R0?ooo`070000003oool0oooo0?ooo`000000oooo00000004
0?ooo`030000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000@0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000`0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00060?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?oo
o`0000000`3oool00`000000oooo0000000:0?ooo`030000003oool000000080oooo00<000000?oo
o`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000d0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000080?ooo`070000
003oool0oooo0?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool0=03oool01@000000oooo0?ooo`3oool0000001<0oooo00<000000?ooo`0000002P3oool0
1@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000060?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool00000
00@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L00000
0?ooo`000000oooo0000003oool0000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo
0?ooo`080?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000L0oooo003o0?oo
omh0oooo00@000000?ooo`3oool00000:P3oool00`000000oooo000000060?ooo`050000003oool0
oooo0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
3P3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
103oool01`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`0000040?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool01`00
0000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo
00L000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`3oool0203oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0000000D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0[0?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000004@3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool00000
00L0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`0:0000003oool0oooo0000003oool0
00000?ooo`000000oooo000000`0oooo00<000000?ooo`0000001P3oool01@000000oooo0000003o
ool0000000L0oooo003o0?ooomP0oooo00D000000?ooo`000000oooo0000000Y0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`0>0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`000000303oool00`000000oooo0?oo
o`040?ooo`050000003oool000000?ooo`0000001P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000203oool01`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool03P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000004@3oool01`000000oooo
0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo
0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`060?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000
103oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`000000
:03oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`060?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
0000203oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`3oool0103oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00`000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000070?ooo`00o`3ooooD0?ooo`030000003oool0000000h0
oooo00<000000?ooo`3oool08P3oool01@000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`000000303oool01@000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000060?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`0=0?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`080?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`050000003oool0
00000?ooo`000000=P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00`000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool02P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000080?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001@3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000070?ooo`00o`3oooo=0?ooo`050000003oool000000?ooo`0000005@3o
ool00`000000oooo0000000J0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000103oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000h0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool01`00
0000oooo0000003oool000000?ooo`0000002P3oool00`000000oooo000000020?ooo`0;0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000001P3oool01@00
0000oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo000000020?ooo`070000003o
ool0oooo0?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00L000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000003X0oooo00<000000?ooo`3oool02P3oool01`000000oooo0000003o
ool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0?ooo`3oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`00
00001`3oool00?l0oooob@3oool00`000000oooo0000000P0?ooo`030000003oool000000180oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo
00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000`0oooo00D000000?ooo`3oool0oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00D000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000001P3oool01`000000oooo0000003oool000000?ooo`000000103o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?oo
o`030000003oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?oo
o`050000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`070000003oool0
oooo0?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000030?ooo`0:0000003oool0
oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000
003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo0000000:0?ooo`030000
003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00070?ooo`00o`3oooo40?ooo`030000003oool0000002T0oooo00<000000?ooo`000000303oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool0
30000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000
oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000h0oooo00<000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`060000003oool0
oooo0000003oool000000`3oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`3o
ool0oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool01@00
0000oooo0?ooo`3oool0000000H0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000X0
oooo00D000000?ooo`3oool0oooo000000040?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo00X0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000
oooo000000070?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`00
00000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?oo
o`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`050?ooo`00o`3oooo00?ooo`030000003oool000000340
oooo00<000000?ooo`0000000P3oool00`000000oooo0000000<0?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000`0oooo00<000000?ooo`0000001P3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool0
0000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`00
0000103oool00`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0000001<0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0000003o
ool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000020?ooo`030000003oool0000003D0oooo00<000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000H0oooo00/000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000
003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`080000003oool0oooo0000
003oool000000?ooo`0000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo000000060?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000L0oooo003o0?oookT0oooo00H000000?ooo`3oool000000?ooo`00000n
0?ooo`030000003oool0oooo00P0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo
00<000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00004`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003o
ool000000?ooo`000000oooo000000040?ooo`030000003oool0000000P0oooo00<000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000006
0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool03P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0000
003oool0000000P0oooo00<000000?ooo`0000001P3oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?oo
o`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00D000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo000000020?oo
o`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000
oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000L0oooo003o
0?oookD0oooo00<000000?ooo`000000A`3oool00`000000oooo0?ooo`060?ooo`070000003oool0
oooo0?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`000000303oool00`000000oooo0?ooo`06
0?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`00
00001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo0000
00020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000@0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool00000
00`0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool0000000H0oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool00000
00H0oooo00<000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool01@000000oooo0000003oool0000000D0oooo00P0
00000?ooo`3oool000000?ooo`000000oooo000000<0oooo00@000000?ooo`3oool00000:P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool00000
0?ooo`000000103oool00`000000oooo000000050?ooo`0<0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool00000103oool00`000000oooo0000000:0?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00L0
00000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`3oool01@3oool00`000000
oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooona0?ooo`030000003oool0
000004d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000@0oooo00<000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000000:0?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000303oool01@00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0000003oool0000000P0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool00`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool00`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo
0000000:0?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
000000030?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool01P3oool00`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000203oool01`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00L00000
0?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103o
ool00`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`030000003oool0oooo00@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo
0000003oool0000000L0oooo003o0?ooojh0oooo00<000000?ooo`3oool0D`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`0>
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo000000060?ooo`050000003oool000000?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
3`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000000?0?ooo`070000003oool0
oooo0?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000
oooo000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000003`3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000000:0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0000002P0oooo
00<000000?ooo`0000000P3oool00`000000oooo0000000:0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`000000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo
00<000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo00000005
0?ooo`060000003oool0oooo0000003oool000001@3oool03P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool00000103oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo
0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000070?ooo`00o`3ooonZ0?ooo`030000003oool0000005T0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0000000H0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo000000060?ooo`050000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo0000000<0?ooo`030000003oool0000000H0oooo00L000000?ooo`000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00L000000?ooo`000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool01`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0000
00050?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool00000
00@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000`3oool010000000oooo0?ooo`00000_0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000060?ooo`050000003oool000000?ooo`000000103oool00`000000oooo00000003
0?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000X0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?oo
o`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool0000000L0oooo003o0?ooojH0
oooo00<000000?ooo`000000H@3oool01@000000oooo0000003oool0000000@0oooo00<000000?oo
o`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`0>
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo0000000<0?oo
o`030000003oool0oooo00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool01`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0
000000<0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`050000003oool000000?ooo`00
00001P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`070000003o
ool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`00
0000oooo0000000E0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo000000040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000040?ooo`07
0000003oool0oooo0?ooo`000000oooo0000000h0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
000000060?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001P3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo003o0?oooj40oooo00@00000
0?ooo`3oool00000I`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool06@3oool01@000000oooo0000003o
ool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo0000000<0?ooo`050000003oool000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool0103oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000:
0?ooo`030000003oool0000001L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`00
0000103oool01@000000oooo0?ooo`3oool0000000<0oooo00X000000?ooo`3oool000000?ooo`00
0000oooo0000003oool00000303oool00`000000oooo000000020?ooo`070000003oool0oooo0?oo
o`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
000g0?ooo`040000003oool0oooo000000`0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00`000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000080?ooo`030000003oool0000000H0oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`00
00001P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000001`3oool00?l0ooooW@3oool00`000000oooo0000001^0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000000P3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000080?ooo`050000003oool0oooo
0?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo
000000080?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000P0oooo00<00000
0?ooo`3oool0103oool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool00000
0`3oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`0<0?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`000000203oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<0
00000?ooo`0000002P3oool01@000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool0
00000?ooo`0000050?ooo`030000003oool000000080oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo
00L000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000203oool01@000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo00D0oooo003o0?oooi/0oooo00<000000?ooo`3o
ool0L`3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000040?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`0>0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0000000C0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool03@3o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000001P3oool01@000000oooo
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`000000203oool01@000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03<0oooo00H000000?ooo`3oool000000?ooo`0000070?ooo`040000003oool0oooo000000L0oooo
00<000000?ooo`3oool0103oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000P0oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo0000
00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000X0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`050?ooo`00o`3ooonF0?ooo`040000003oool0oooo000007T0oooo00<000000?ooo`000000
0`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000403oool00`00
0000oooo000000020?ooo`050000003oool0oooo0?ooo`000000203oool01`000000oooo0?ooo`3o
ool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00060?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?oo
o`000000oooo000000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`080?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`000000oooo000000040?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3oool01P000000oooo
0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0
000000P0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool0
00000`3oool01@000000oooo0?ooo`3oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0000000:
0?ooo`050000003oool000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000060?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000<0oooo00P000000?ooo`3o
ool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00070?ooo`00o`3ooonD0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`0000000`3oool0
3P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool00000103oool00`000000oooo0000000@0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000001@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`00
0000103oool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000001@3oool0
1@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000080?ooo`050000
003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo
00@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0000000P0oooo00D000000?ooo`000000oooo
000000060?ooo`030000003oool0oooo00X0oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000203oool00`000000oooo0?ooo`020?ooo`0;0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo
0000000:0?ooo`030000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo
000000<0oooo00<000000?ooo`3oool0;@3oool01P000000oooo0?ooo`000000oooo000000D0oooo
00<000000?ooo`3oool0103oool01@000000oooo0000003oool0000000H0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000P0
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000H0oooo00D000000?oo
o`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`050?ooo`00o`3ooon@0?ooo`030000003oool000000880oooo00D000000?ooo`3oool0oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00040?ooo`050000003oool000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool010000000oooo0?ooo`0000030?ooo`070000003oool0oooo0?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001P3oool00`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool00000
00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`030?ooo`05
0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`0>0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000070?ooo`030000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0303oool030000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0
oooo00D000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3o
ool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`06
0000003oool0oooo0000003oool000001@3oool01P000000oooo0?ooo`000000oooo000000D0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`00
00001`3oool010000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0000
00030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000070?ooo`00
o`3ooon>0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0000001D0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`050000003oool00000
0?ooo`0000000`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000H0oooo00<0
00000?ooo`0000001P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00D000000?ooo`000000oooo0000000A0?ooo`050000003oool000000?ooo`0000004@3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0<0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0000
00030?ooo`050000003oool0oooo0?ooo`000000103oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`030000003oool000000340oooo00<000000?ooo`3oool0103oool0
0`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00`000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`00000<0?ooo`060000003oool0oooo
0000003oool000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
103oool01`000000oooo0?ooo`3oool000000?ooo`0000001`3oool00?l0ooooR@3oool010000000
oooo0?ooo`00002<0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000
000<0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000003`3oool0
0`000000oooo000000030?ooo`030000003oool0000000H0oooo00<000000?ooo`0000000`3oool0
30000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo
000000040?ooo`050000003oool000000?ooo`0000001@3oool030000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000@0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo000000040?ooo`030000003oool0000000<0
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo
000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool00000103oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
1P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00D000000?ooo`000000oooo0000000<0?ooo`050000003oool000000?ooo`00
00000P3oool010000000oooo0?ooo`3oool500000080oooo00@000000?ooo`3oool0oooo0P000002
0?ooo`030000003oool000000080oooo1@0000030?ooo`0<0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000001`3oool00?l0ooooQ`3oool00`000000oooo0?ooo`2?0?oo
o`060000003oool0oooo0000003oool000000`3oool01@000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000001<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0000
000?0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000060?oo
o`070000003oool0oooo0?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000040?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`0000001@3oool02P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool020000000oooo0?oo
o`000000oooo0000003oool000001P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000H0oooo00<000000?ooo`3oool0;@3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`080?ooo`0>0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool01`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0000000L0oooo00/000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`02
000000030?ooo`000000oooo0080oooo0`0000000`3oool000000?ooo`030?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000070?oo
o`00o`3ooon50?ooo`030000003oool0oooo09@0oooo00<000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0
000001<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool01@3oool010000000
oooo0?ooo`0000050?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000H0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo
00L000000?ooo`3oool0oooo0000003oool0000000X0oooo00<000000?ooo`3oool0103oool01`00
0000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`050000003oool000000?ooo`0000002P3oool01@00
0000oooo0?ooo`3oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool000000080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`00
0000oooo0000000_0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000303oool01@00
0000oooo0?ooo`3oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000D0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00H000000?ooo`000000oooo0000003oool2000000080?oo
o`000000oooo0000003oool000000?ooo`0000060?ooo`050000003oool000000?ooo`0000001P3o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000070?ooo`00o`3ooon30?ooo`03
0000003oool0oooo09P0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000001T0oooo00D000000?ooo`000000
oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000080?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00D000000?ooo`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`070000003oool0
oooo0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000004@3oool01@000000oooo0?ooo`3oool0000000D0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00001P3oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`05
0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000001P3oool0
0`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000001@3oool0
1P000000oooo0?ooo`000000oooo00000340oooo00<000000?ooo`0000002P3oool01@000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool00000
0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`080000003oool0oooo
0?ooo`000000oooo0000003oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`000000
0`3oool8000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`0000070?ooo`00o`3ooon10?ooo`030000003oool0oooo09`0oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`0000006@3o
ool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00H0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L0
00000?ooo`000000oooo0000003oool0000000P0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000H0oooo00L000000?ooo`000000
oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?oo
o`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000001@3oool03P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0000000H0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00060?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo000000030?ooo`030000
003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo0000
00D0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0000000D0oooo00P000000?ooo`3oool000000?ooo`000000oooo
000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool02P000000
oooo000000000000oooo0000003oool000000?ooo`00000<0?ooo`P00000003o0?ooog`0oooo00@0
00000?ooo`3oool00000X03oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000C0?ooo`070000003o
ool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`00
0000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool0000000H0oooo00<000000?ooo`3oool00`3oool020000000oooo0?ooo`00
0000oooo0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`080000
003oool0oooo0000003oool000000?ooo`0000060?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool0103oool00`000000
oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000040?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000303oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`060?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`080?ooo`040000003oool000000?ooo`8000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00H000000?ooo`00000000000?ooo`0000030?ooo`030000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool0
0?l0ooooNP3oool00`000000oooo0?ooo`2U0?ooo`050000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool000000`3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool00000
00<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0?ooo`0G0?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?oo
o`050000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00L0
00000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0?`3oool00`000000
oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0
000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000060?ooo`070000003o
ool000000?ooo`000000oooo000000080?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3o
ool000000?ooo`0000070?ooo`030000003oool0oooo0080oooo00H000000?ooo`000000oooo0000
003oool2000000040?ooo`000000oooo000000<0oooo00<000000?ooo`000000103oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000L0oooo003o0?ooogP0oooo00<000000?ooo`3oool0Y`3oool01@000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo0000000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool01@000000
oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool00`000000oooo00000003
0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`00
00030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0oooo00P0oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00<000000?oo
o`0000000`3oool00`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo0000
00040?ooo`030000003oool0oooo00D0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo000000060?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`000000303oool00`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`0000002P3oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000103o
ool01P000000oooo0000003oool000000?ooo`8000001@3oool01@000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo
000000070?ooo`00o`3ooomf0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?oo
o`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000000`3oool02P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000040?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000003`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?oo
o`000000103oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
00050?ooo`030000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
000_0?ooo`030000003oool0oooo00P0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`000000oooo000000060?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000P0
oooo00<000000?ooo`000000103oool010000000oooo0000003oool500000080oooo00<000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo0`0000000`3oool000000?ooo`07
0?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooobL0oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000001<0oooo
00L000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool00`3oool01P000000oooo0?oo
o`000000oooo000000L0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000P0oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000003@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000H0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`000000
103oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000L0oooo003o0?ooog@0oooo
00<000000?ooo`3oool0[@3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00001P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool00`000000oooo0000000<
0?ooo`030000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo
00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo00000003
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool02P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`0000040?ooo`050000003oool000000?ooo`0000001@3o
ool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00<000000?ooo`0000001P3oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`080?ooo`050000003oool000000?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`03
0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0340oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000X0oooo00<000000?ooo`3oool0
103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`3oool0oooo0000003oool0000000H0oooo00<000000?ooo`000000203oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00L0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo000000040?ooo`030000003oool0000000D0oooo
00<000000?ooo`3oool01@3oool00?l0ooooL@3oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
0000303oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000000:0?ooo`040000003o
ool0oooo000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?oo
o`3oool0oooo0000003oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0000
000=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool01@000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000P0
oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo0000000:0?ooo`040000003oool0oooo000003`0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo
000000040?ooo`050000003oool000000?ooo`0000001P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0oooo00`0oooo00L000000?ooo`3oool0oooo
0000003oool0000000H0oooo00<000000?ooo`3oool01P3oool01`000000oooo0?ooo`3oool00000
0?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000001P3oool00`000000oooo000000030?ooo`030000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0oooo
K`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00@0
00000?ooo`3oool00000403oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool0103oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01@00
0000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000050?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000d0oooo
00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01@00
0000oooo0?ooo`3oool0000001<0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`030000003oool000000080oooo
00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0000000D0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00h000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000050?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000L0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0
00000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000070?ooo`00o`3ooom]0?oo
o`030000003oool0oooo0;@0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo0000000<0?ooo`050000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool010000000
oooo0?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool0oooo0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo000000080?ooo`050000003o
ool000000?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`0A0?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo00000006
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`070000003oool000000?ooo`00
0000oooo000000080?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000060?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool010000000oooo0?ooo`00000>0?ooo`030000003oool0000000<0oooo00P000000?oo
o`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`000000oooo000000040?ooo`07
0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103o
ool00`000000oooo000000050?ooo`030000003oool0oooo00D0oooo003o0?ooool0oooo8`3oool0
1@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`000000303oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`000000oooo0000000<0?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000005@3oool00`000000oooo000000040?ooo`050000
003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00X000000?ooo`3oool000000?oo
o`000000oooo0000003oool000001P3oool01@000000oooo0000003oool0000000H0oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`03
0000003oool0000000@0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo
000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo000000040?ooo`030000003oool0000000h0oooo00<000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`050000003oool000000?ooo`000000103oool00`000000oooo000000030?oo
o`060000003oool0oooo0000003oool000001@3oool00`000000oooo000000040?ooo`070000003o
ool000000?ooo`000000oooo0000000?0?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000L0oooo003o0?ooof/0oooo00<000000?ooo`3oool0]03oool0
1@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`000000303oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`0000001@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000103o
ool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool03P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000`0oooo
00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000103oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000P0oooo00<000000?ooo`3oool00P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool0
0`000000oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo0000
00080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0000
00080?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`0<0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000080?ooo`070000003oool000000?ooo`000000oooo
000000060?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000060?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000040?ooo`030000003oool0000000X0oooo00D000000?ooo`000000oooo
000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`03
0000003oool0oooo00P0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3o
ool00?l0ooooo`3ooolS0?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`050000003oool000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000002P3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000@0oooo00L000000?oo
o`000000oooo0000003oool0000000P0oooo00<000000?ooo`000000203oool01`000000oooo0?oo
o`3oool000000?ooo`000000103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000P0
oooo00D000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000X0oooo00L000000?oo
o`000000oooo0000003oool0000000d0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000
003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?oo
o`000000oooo000000060?ooo`030000003oool0oooo03<0oooo00<000000?ooo`000000103oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?oo
o`0000001@3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`000000203oool01@000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000080?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001`3oool00?l0oooo
J@3oool00`000000oooo0?ooo`2d0?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo00D0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000050?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000001P3oool00`000000
oooo000000030?ooo`050000003oool0oooo0?ooo`0000003`3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000103oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo0000000a0?ooo`040000003oool0
oooo000000D0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool01@000000oooo0000003o
ool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000H0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool020000000oooo0?oo
o`000000oooo0000003oool000001P3oool00`000000oooo0?ooo`030?ooo`050000003oool00000
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool030000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000L0oooo003o0?ooool0oooo8@3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool01@000000oooo0000003oool000000100oooo00`000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool03P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`0>0?ooo`050000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000X0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000103oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000X0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo0000
00D0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
000000030?ooo`030000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000001P3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo00L00000
0?ooo`000000oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00L000000?ooo`000000oooo
0000003oool0000000L0oooo003o0?ooofL0oooo00<000000?ooo`3oool0]P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo
0000000<0?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000050?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000l0oooo00D000000?ooo`3oool0oooo000000050?ooo`060000003oool0
oooo0000003oool000001@3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`0000001P3oool0
0`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo000000060?ooo`030000003oool0oooo03P0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?oo
o`0000001P3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000040?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000
003oool000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000P0oooo00D0
00000?ooo`000000oooo000000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`060?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
1@3oool00?l0ooooo`3ooolQ0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo00<00000
0?ooo`000000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool00000
0?ooo`0000002P3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0
00000080oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000040?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool00`000000oooo0000000:0?ooo`030000003oool0
000000P0oooo00D000000?ooo`000000oooo0000000_0?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0000000@0oooo00<000000?ooo`000000203oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`00
0000oooo000000D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000080?ooo`03
0000003oool0000000P0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000050?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0000000@0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0oooo
003o0?ooool0oooo7`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000303oool01@000000
oooo0?ooo`3oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000070?ooo`0>0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00000:0?ooo`030000
003oool0oooo0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000X0oooo00L000000?ooo`3oool0oooo0000003oool000000080
oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000H0oooo00<000000?oo
o`3oool0;`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`0;0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000
003oool000000?ooo`000000oooo0000000?0?ooo`070000003oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0oooo00D0oooo00P000000?ooo`3oool000000?ooo`000000oooo0000
00X0oooo00<000000?ooo`0000001P3oool01@000000oooo0000003oool0000000D0oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000001@3oool010000000
oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000001`3oool00?l0ooooI03oool00`00
0000oooo0?ooo`2g0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000C0?ooo`050000003o
ool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0000000H0oooo00L000000?ooo`3oool0oooo0000
003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000
003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000P0oooo00<000000?oo
o`3oool0203oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000060?ooo`030000003oool0000000P0oooo00<000000?oo
o`0000001P3oool00`000000oooo000000030?ooo`030000003oool0000000P0oooo00D000000?oo
o`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo000000060?ooo`070000
003oool0oooo0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`030000003oool0000000P0oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00040?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000030?ooo`030000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000
003oool000000?ooo`0000001`3oool00?l0ooooo`3ooolO0?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`000000303oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`00
00002P3oool01`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`00
00001P3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`06
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool01P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000080?ooo`030000003o
ool0000000D0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0000003<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000<0?ooo`030000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000080?ooo`050000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`00
00001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000P0oooo00<000000?ooo`00
00001@3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`030000
003oool0000000L0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00@00000
0?ooo`3oool000001@3oool01@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000070?oo
o`00o`3ooooo0?oooad0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`060000003oool0oooo0000003oool000003P3oool01@000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`000000
2P3oool01@000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo00@0oooo00L0
00000?ooo`000000oooo0000003oool0000000X0oooo00<000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000000=0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo00000080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`000000103oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000001P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool00P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000
003oool0000000@0oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000P3oool00`000000oooo000000050?ooo`040000003oool0oooo0000
00<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool00000
0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000X0oooo00@000000?ooo`3oool000001@3oool00`000000
oooo000000070?ooo`00o`3ooooo0?oooad0oooo00<000000?ooo`0000001@3oool00`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000003P3oool00`000000
oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000001P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool03@3oool00`000000oooo000000030?oo
o`050000003oool0oooo0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
2P3oool00`000000oooo000000020?ooo`030000003oool0oooo00X0oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00@0
00000?ooo`3oool00000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000001P3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?oo
o`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000P0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000
003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`000000203oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?oooad0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool000000100oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool000000?ooo`00
0000103oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000040?ooo`030000003oool0000000<0oooo00<000000?oo
o`0000001P3oool00`000000oooo000000030?ooo`040000003oool0oooo000000L0oooo00<00000
0?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000203oool00`000000oooo
0000000C0?ooo`030000003oool0oooo00D0oooo00P000000?ooo`3oool000000?ooo`000000oooo
000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`060000003oool0oooo0000003o
ool000000`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0103oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0000
02l0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000203o
ool00`000000oooo0000000<0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo
000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`000000103oool01@000000oooo
0000003oool0000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?oo
o`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000070?ooo`00o`3ooomR
0?ooo`030000003oool0oooo0;@0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
000E0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool0
30000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00L00000
0?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000X0oooo00<00000
0?ooo`3oool0103oool00`000000oooo000000030?ooo`030000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?oo
o`030000003oool000000140oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`0:0000003o
ool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00`000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`00000?0?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`000000;`3o
ool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000D0oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`060000003oool0oooo0000003oool000001@3oool02000
0000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00P0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000D0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool00000
00L0oooo003o0?ooool0oooo6P3oool020000000oooo0?ooo`000000oooo0000003oool000000`3o
ool00`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000D0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000`0oooo00D0
00000?ooo`3oool0oooo0000000=0?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo000000050?oo
o`030000003oool000000080oooo00D000000?ooo`000000oooo000000060?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`030000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool0403oool00`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00<000000?ooo`0000002P3oool01P00
0000oooo0?ooo`000000oooo000000D0oooo00<000000?ooo`3oool0103oool01`000000oooo0000
003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0X0?ooo`0<0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool00`000000oooo
000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo0000000:0?ooo`07
0000003oool0oooo0?ooo`000000oooo000000080?ooo`050000003oool000000?ooo`000000103o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo
0?ooo`000000oooo000000060?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0103o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo
000000040?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool00000
00<0oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0000000P0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000002P3o
ool00`000000oooo0?ooo`050?ooo`00o`3ooomI0?ooo`080000003oool0oooo0000003oool00000
0?ooo`00002h0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000060?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool0
1@000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00@0oooo00L000000?oo
o`000000oooo0000003oool0000000X0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000h0
oooo00<000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000
003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`05
0000003oool000000?ooo`0000000P3oool00`000000oooo000000070?ooo`0<0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool00000103oool02@000000oooo0000003oool0
00000?ooo`000000oooo0000000_0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`050000003oool000000?ooo`0000000`3oool03P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000080?ooo`050000
003oool000000?ooo`000000103oool00`000000oooo000000060?ooo`030000003oool0000000<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`0000000`3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000
00040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool0000000L0oooo003o0?oooe40oooo00L000000?ooo`000000oooo0000003oool0000000X0
oooo00<000000?ooo`3oool0/P3oool00`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`000000403oool00`000000oooo0?ooo`040?ooo`070000003oool000000?ooo`000000oooo
000000060?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000030?ooo`06
0000003oool0oooo0000003oool000000`3oool01@000000oooo0000003oool0000000X0oooo00<0
00000?ooo`3oool0103oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000P0oooo00D000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`000000
1@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo0000000A
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`050000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo00000005
0?ooo`030000003oool0oooo02d0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00L000000?ooo`000000oooo0000003oool0000000H0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`000000oooo0000
00030?ooo`060000003oool0oooo0000003oool000000`3oool01@000000oooo0000003oool00000
0080oooo00<000000?ooo`0000001@3oool03P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool0
00000?ooo`0000001`3oool00?l0ooooB03oool01@000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool0a`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo0000000<0?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo
00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo00@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?oo
o`000000oooo000000080?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool01`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000080?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`07
0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo
000000040?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000003oool00000
0?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`050?ooo`00o`3ooolo0?ooo`030000003oool000000080oooo00<000000?ooo`000000dP3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00D000000?ooo`000000oooo0000000@0?ooo`0<0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool0
1@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000H0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0000000K0?ooo`030000
003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000
003oool0000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?oo
o`0000003P3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000H0oooo00L000000?oo
o`000000oooo0000003oool0000002l0oooo00<000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`040000
003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000002P3oool01@000000oooo0000003oool000000080oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000001P3o
ool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0oooo=`3oool01`000000
oooo0000003oool000000?ooo`000000e`3oool01@000000oooo0?ooo`3oool0000000@0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
00000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo0000000<0?ooo`030000003oool0000000@0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000001P3oool00`000000oooo000000060?ooo`030000003oool0
oooo00D0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool000001@3oool0
0`000000oooo0000000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0000000<0oooo00P000000?ooo`3oool000000?oo
o`000000oooo000000<0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool0
1P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000H0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0Y0?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`050000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`000000
203oool00`000000oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00P0
00000?ooo`3oool000000?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000
003oool0000000X0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`040?ooo`0;0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00070?ooo`00o`3oool^0?ooo`070000003oool000000?ooo`000000oooo0000003P0?ooo`050000
003oool0oooo0?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool00`000000oooo0000
00030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo0000000<0?ooo`050000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000
003oool0000000H0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool000000080
oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000050?ooo`050000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`07
0000003oool0oooo0?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000d0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo
0?ooo`0000000`3oool010000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool0
00000?ooo`0000070?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo00000004
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000006
0?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000oooo0000003o
ool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`050000003oool000000?ooo`000000203oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000L0oooo003o0?ooobD0oooo
00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo0>H0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000<0?ooo`050000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000@0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool0103oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?oo
o`0000004`3oool01@000000oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo0000
00060?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0903oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000080?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
103oool01`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`00
0000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000P3oool01@000000oooo0000003oool0000000H0oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000001`3oool00?l0oooo703oool020000000oooo0?ooo`000000oooo0000
003oool00000@03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0000000<0oooo00P00000
0?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000003P3oool00`000000oooo000000040?oo
o`030000003oool0000000<0oooo00<000000?ooo`000000103oool01`000000oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003o
ool0000000H0oooo00<000000?ooo`000000203oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0303oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo0000
00030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`0T0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000H0
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool01@000000oooo
0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`03
0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00H00000
0?ooo`3oool0oooo0000003oool5000000<0oooo003o0?oooaH0oooo00D000000?ooo`000000oooo
0000003h0?ooo`030000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000@0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000003P3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000X0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`00
00000P3oool00`000000oooo000000080?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00H000000?ooo`3oool000000?ooo`00000E0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`0000001P3oool00`000000oooo000000040?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`060000
003oool0oooo0000003oool000000`3oool01@000000oooo0000003oool000000080oooo00L00000
0?ooo`3oool0oooo0000003oool0000000X0oooo00D000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo000000@0oooo00<000000?ooo`000000903oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo00000004
0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000`0oooo00<000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000P0oooo00L000000?ooo`3oool0oooo0000
003oool0000000P0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo00D0oooo003o0?ooo`d0oooo00D000000?oo
o`000000oooo000000020?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0Z@3oool0
0`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo00<00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool00000
0?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000X0oooo00L000000?ooo`000000
oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0
oooo000000<0oooo00D000000?ooo`000000oooo0000000:0?ooo`030000003oool0000000@0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000H0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool000000080oooo
00<000000?ooo`3oool02P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000080?ooo`030000003oool000000080oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool000000080oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003o
ool0oooo000002@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000
003oool000000?ooo`0000001@3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000080?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0000003oool00000
00<0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
103oool00`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`000003
0?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000203oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001P3oool00`000000oooo00000003
0?ooo`030000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00001`3oool00?l0oooo103oool020000000oooo0?ooo`000000oooo0000003oool00000o`3oool6
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool0
1`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool000000100
oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo00X0oooo00h000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0
000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000004
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00001@3oool00`000000oooo000000020?ooo`030000003oool0oooo00X0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000P3oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo
00D000000?ooo`000000oooo000000080?ooo`030000003oool0000000<0oooo00<000000?ooo`00
00002P3oool00`000000oooo000000060?ooo`050000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`00
0000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool0103oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000001`3oool00?/0oooo00L000000?ooo`000000oooo0000003oool000000?l0
oooo4@3oool00`000000oooo000000080?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000P0oooo
00<000000?ooo`3oool0103oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`000000303oool00`000000oooo000000040?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0000000C0?ooo`030000003oool0oooo00<0oooo00`000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000040?ooo`050000003oool000000?ooo`0000000`3oool0
10000000oooo0?ooo`00000:0?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000050?ooo`03
0000003oool0000000@0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0000000H0oooo00<000000?ooo`3oool07@3oool01P000000oooo0?ooo`000000
oooo000000D0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000001@3oool020000000oooo0?ooo`000000oooo0000003oool000000`3o
ool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool00`000000oooo0000000@0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool0
oooo0?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000
oooo000000H0oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo003d0?ooo`050000
003oool000000?ooo`000000K`3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0000000<0
oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0oooo00h0oooo00D000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo
000000040?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`000000203oool00`000000oooo000000040?ooo`03
0000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo000000050?ooo`0:
0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0
3`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000303oool03P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool00`00
0000oooo000000030?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000005@3oool00`000000oooo0?ooo`0O0?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000203oool01`000000oooo
0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000D0oooo00X000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo000000050?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo003[0?ooo`080000
003oool0oooo0000003oool000000?ooo`00001g0?ooo`030000003oool0oooo0:00oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo000000<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`050000003o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000`0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`00
00001P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool01@00
0000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo
00<000000?ooo`0000001@3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`00
00001P3oool01@000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000040?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool03P3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool0000000H0oooo00<000000?ooo`3oool01P3oool01`000000oooo0?ooo`3oool000000?oo
o`000000203oool00`000000oooo0?ooo`040?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000P0oooo00L000000?oo
o`000000oooo0000003oool0000002@0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool030000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00D000000?ooo`000000oooo
000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000030?ooo`040000003oool0oooo000000`0oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0203oool00`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000060?ooo`050000003oool000000?ooo`0000001`3oool00><0oooo00L000000?oo
o`000000oooo0000003oool000000?l0oooo903oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo
00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00D000000?ooo`3oool0oooo0000000:0?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`000000303oool01@000000oooo0?ooo`3oool0000000@0
oooo00D000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000030?ooo`030000
003oool0000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`070000
003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?oo
o`000000oooo000000060?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00X0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`000000103oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000H0
oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool00`000000oooo000000080?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool0
1@000000oooo0000003oool000000080oooo00<000000?ooo`0000007@3oool00`000000oooo0000
00020?ooo`030000003oool0000000D0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00L000000?ooo`000000oooo0000003oool00000
00@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool00000
0?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo
000000050?ooo`030000003oool0oooo00@0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0
000000D0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000070?ooo`00g03oool00`00
0000oooo000000020?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0W03oool00`00
0000oooo000000040?ooo`030000003oool0000000H0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool03P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01@000000oooo0000
003oool0000000`0oooo00<000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?oo
o`0000001P3oool01`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000002@3oool030000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`030000003oool0oooo00@0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003o
ool0oooo00X0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000001@3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000008P3oool00`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`000000203oool01`000000oooo0000003oool000000?ooo`000000103oool0
1@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo
0000003oool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool00000
00@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0000000:0?ooo`030000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`000000oooo000000060?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool0000000L0oooo003C0?ooo`080000003oool0oooo0000003oool000000?oo
o`00002C0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`000000103oool00`000000oooo
000000060?ooo`050000003oool000000?ooo`0000001@3oool030000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000@0oooo00L000000?ooo`3oool0oooo0000003oool0
000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000`0oooo00<000000?ooo`000000103oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000080?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01`000000
oooo0?ooo`3oool000000?ooo`000000203oool00`000000oooo000000030?ooo`030000003oool0
oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000
oooo000000080?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`080?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00L000000?ooo`000000
oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`080000003oool0
oooo0000003oool000000?ooo`0000030?ooo`030000003oool000000080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?oo
o`0I0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000
003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000203oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo0000
00070?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00`3oool02P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`00000:0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0000000H0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000L0oooo003=0?ooo`050000003oool000000?ooo`000000o`3ooolj
0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000001P3oool02`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo0000000>0?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000
003oool0000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0000000:0?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool01`000000oooo0000003oool000000?oo
o`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?oo
o`050?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`030?ooo`060000003oool0oooo0000003oool000007@3oool00`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3o
ool01@000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0000000:0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000070?ooo`00a03oool00`000000oooo000000020?ooo`030000003oool000000:@0
oooo00<000000?ooo`3oool0UP3oool01@000000oooo0000003oool0000000@0oooo00<000000?oo
o`0000001P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?oo
o`0000001@3oool00`000000oooo000000060?ooo`050000003oool000000?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000`0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00@0oooo00<000000?ooo`000000203oool01`000000oooo0?ooo`3oool000000?ooo`000000203o
ool00`000000oooo0?ooo`030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?oo
o`030000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000P0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`00000:0?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo000000020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000050?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0000001T0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0000
00030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000H0oooo00D00000
0?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo
000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00H0
00000?ooo`3oool000000?ooo`0000050?ooo`060000003oool0oooo0000003oool000001@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool00000
0?ooo`000000103oool00`000000oooo000000050?ooo`080000003oool0oooo0000003oool00000
0?ooo`0000080?ooo`050000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`00000<
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool00;h0oooo00D000000?oo
o`000000oooo0000002`0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`080?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000`0oooo00D000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000001P3oool01`000000oooo0000
003oool000000?ooo`0000002P3oool00`000000oooo0?ooo`040?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0000
00030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool00000
00@0oooo00D000000?ooo`000000oooo000000080?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000002P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool0
00000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000040?oo
o`070000003oool0oooo0?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`000000
2P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`000000oooo000000060?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool00`000000oooo0000000:0?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool0103oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000L0oooo002e
0?ooo`070000003oool000000?ooo`000000oooo0000002i0?ooo`030000003oool0oooo08l0oooo
00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool03P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`000000303oool01@000000oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000003oool00000
0?ooo`0000001P3oool00`000000oooo000000050?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000H0oooo00<000000?ooo`00
0000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0000000d0oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool000000?oo
o`00000G0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`060?ooo`070000003o
ool000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003o
ool0000000P0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`000000103oool00`000000oooo000000080?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001`3oool00:h0oooo00H000000?oo
o`3oool000000?ooo`0000330?ooo`030000003oool0oooo0940oooo00<000000?ooo`000000103o
ool00`000000oooo000000060?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103o
ool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`05
0000003oool000000?ooo`000000303oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo
000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000203oool01@000000oooo0000003oool0
000000d0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000D0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000
oooo000000060?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0103oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`3oool00P3oool02`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000001P3oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01P3oool0
1`000000oooo0000003oool000000?ooo`0000001`3oool00:P0oooo00D000000?ooo`000000oooo
0000003o0?oooel0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`0:0000
003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`00
0000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool020000000oooo0?ooo`00
0000oooo0000003oool00000303oool01@000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000050?ooo`080000003oool0oooo0000003oool000000?oo
o`0000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`0>
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000203oool00`000000
oooo0?ooo`020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`080?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000
oooo0000003oool0000000H0oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00H0
00000?ooo`3oool000000?ooo`0000050?ooo`030000003oool000000080oooo00D000000?ooo`00
0000oooo000000050?ooo`080000003oool0oooo0000003oool000000?ooo`0000060?ooo`030000
003oool0oooo01l0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool0103oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0000000D0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo
000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000040?oo
o`070000003oool0oooo0?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00H0
00000?ooo`3oool000000?ooo`0000050?ooo`030000003oool0oooo00D0oooo002O0?ooo`050000
003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo08T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000003oool0000000H0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`000000303oool01@000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?oo
o`3oool0000000P0oooo00<000000?ooo`0000001P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000001P3o
ool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
000000060?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000H0oooo00D00000
0?ooo`3oool0oooo0000000>0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000040?ooo`050000003oool000000?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000080?ooo`050000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`030000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo
00D000000?ooo`3oool0oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000008
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo
00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`060000
003oool0oooo0000003oool000001`3oool00`000000oooo0?ooo`020?ooo`050000003oool00000
0?ooo`000000103oool00`000000oooo000000050?ooo`030000003oool0oooo00D0oooo002I0?oo
o`050000003oool000000?ooo`000000g@3oool00`000000oooo0?ooo`290?ooo`070000003oool0
oooo0?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00`000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000060?ooo`050000003oool000000?ooo`00
00000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`000000103oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`000000303oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000H0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0
oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`03
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool00000
0?ooo`0000001P3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000002P3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`3oool0
oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00<000000?ooo`000000
303oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`040000003oool0oooo00000240oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`000000103oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000H0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool0
0`000000oooo0?ooo`050?ooo`00TP3oool01@000000oooo0000003oool000000>L0oooo00<00000
0?ooo`000000PP3oool00`000000oooo000000050?ooo`030000003oool0000000d0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`05
0000003oool000000?ooo`000000303oool01@000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
000000060?ooo`030000003oool0000000P0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000X0oooo00h00000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00D0
00000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`00
0000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000080?ooo`050000003oool0oooo0?ooo`000000103oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool08P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?oo
o`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000
003oool0oooo0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
1P000000oooo0?ooo`000000oooo000000D0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`050000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0
000000@0oooo00D000000?ooo`3oool0oooo000000080?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000
oooo0000003oool000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`050?ooo`00R`3oool01P000000oooo0?ooo`000000oooo0000
0?40oooo00<000000?ooo`3oool0QP3oool00`000000oooo000000040?ooo`030000003oool0oooo
00H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo
0000003oool0000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000
oooo0000000<0?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000P0oooo
00D000000?ooo`3oool0oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000H0oooo00D000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`00
00000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00<000000?ooo`0000001P3oool0
1@000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000060?ooo`030000
003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00P0
oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00@0oooo00D000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000001P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000P0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
203oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
1P3oool00`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000
oooo000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000001P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool00000
00@0oooo00<000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000070?ooo`00Q@3oool01@000000oooo0000003oool000000?X0oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000060?oo
o`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
1P3oool00`000000oooo000000050?ooo`030000003oool000000080oooo00L000000?ooo`3oool0
oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`050000003oool000000?ooo`000000303oool01@000000oooo0000003oool0000000@0oooo00<0
00000?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool01@000000
oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000`3oool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103o
ool00`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000050?oo
o`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000H0oooo00D000000?ooo`00
0000oooo000000030?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000050?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?ooo`000000
oooo000000060?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000060?oo
o`050000003oool0oooo0?ooo`000000903oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool03000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0oooo00@0
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00D000000?ooo`000000oooo0000000:0?ooo`050000003oool0oooo0?oo
o`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?oo
o`3oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000002P3oool0
0`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo0?oo
o`000000oooo000000<0oooo00<000000?ooo`0000001`3oool007`0oooo00<000000?ooo`000000
0P3oool00`000000oooo0000003o0?ooo`<0oooo00<000000?ooo`3oool0PP3oool00`000000oooo
000000040?ooo`030000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`030000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo000000060?oo
o`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool020000000oooo0?ooo`000000oooo0000003oool00000303oool01@000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000060?ooo`030000
003oool0oooo00X0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0
oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000040?ooo`050000
003oool000000?ooo`000000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?oo
o`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00020?ooo`030000003oool000000180oooo00<000000?ooo`3oool02P3oool01P000000oooo0?oo
o`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000H0oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo
0080oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3o
ool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0
oooo00H0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0
oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000`0oooo00<000000?ooo`0000001`3oool007H0oooo
00D000000?ooo`000000oooo0000003o0?ooo`h0oooo00<000000?ooo`3oool0P03oool00`000000
oooo000000040?ooo`030000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0
000000H0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool0
00000`3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000002P3oool00`00
0000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0000000<0
oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000001P3o
ool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000001P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo
000000060?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00D000000?ooo`000000oooo0000000:0?ooo`0>0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000001`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0000000H0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`0000002P3oool00`00
0000oooo0000000V0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
0`000000oooo000000060?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0000
00040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`0000001P3oool00`000000oooo0?ooo`060?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000@0oooo00L000000?oo
o`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`050000
003oool000000?ooo`0000001`3oool006l0oooo00D000000?ooo`000000oooo0000003o0?oooaP0
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3o
ool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00<00000
0?ooo`0000002P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000080?ooo`030000003oool0000000X0oooo00D000000?ooo`000000oooo000000060?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool0
1@3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000080?ooo`030000003o
ool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000080?ooo`030000
003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo00`0oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`030000003oool000000080oooo00<000000?ooo`000000
0`3oool01@000000oooo0?ooo`3oool000000080oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001@3oool00`000000
oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`050000003oool0
oooo0?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool0
00000?ooo`0000070?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0
oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000070?ooo`00J@3oool01@000000
oooo0000003oool000000?l0oooo803oool00`000000oooo0000001k0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`000000103oool00`000000oooo000000050?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000H0oooo
00<000000?ooo`0000002P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000050?ooo`060000003oool0oooo0000003oool000001@3oool00`000000oooo0?oo
o`020?ooo`050000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool00000
0?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0000003oool00000
0`3oool01@000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000040?oo
o`030000003oool0000000D0oooo00@000000?ooo`3oool000002P3oool02`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo00000004
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool02`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000001T0oooo00<000000?ooo`3oool02P3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`05
0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool000000`3oool01@000000
oooo0000003oool0000000@0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000003
0?ooo`050000003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`050?ooo`00HP3oool01@000000oooo0000003oool000000?l0oooo:`3oool00`00
0000oooo0?ooo`1c0?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000002P3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00X000000?oo
o`3oool000000?ooo`000000oooo0000003oool000001P3oool01@000000oooo0000003oool00000
00H0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00@000000?ooo`3oool00000
0`3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000060?oo
o`030000003oool0000000L0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`000000303oool010000000oooo0?ooo`0000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00P0oooo00D000000?ooo`000000oooo000000020?ooo`070000
003oool0oooo0?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000001@3o
ool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000004`3oool00`000000oooo0?ooo`0>0?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
103oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000080?oo
o`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00D0oooo00X0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000001P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`04
0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`00
0000oooo000000060?ooo`050000003oool000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool005`0oooo00D000000?oo
o`000000oooo0000003o0?oooc<0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003o
ool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`080?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0
oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000060?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool0
00000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool01@000000
oooo0000003oool0000000h0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?oo
o`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00/000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1P000000oooo0?ooo`000000oooo000000L0oooo00H000000?ooo`3oool000000?ooo`0000050?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`050000003oool000000?ooo`000000
203oool00`000000oooo000000060?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool0
00001`3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000070?ooo`00E@3oool01@000000oooo0000003oool000000?l0
oooo?03oool010000000oooo0?ooo`00001Q0?ooo`050000003oool0oooo0?ooo`000000303oool0
0`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0000000:0?ooo`070000003oool0oooo0?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000050?ooo`060000
003oool0oooo0000003oool000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool01P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`000000203o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo000000080?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0000003oool0000000h0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo
0000003oool000002P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool000000080oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000050?ooo`060000003oool0oooo0000003oool0
00000`3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo
00D000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`00
0000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000P0oooo
00<000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00`000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000070?ooo`00CP3oool01P000000
oooo0?ooo`000000oooo00000?l0ooooA`3oool00`000000oooo0?ooo`1H0?ooo`040000003oool0
oooo00000180oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000000H0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`030000003o
ool0000000`0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`050000003o
ool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000
003oool0000000X0oooo00<000000?ooo`0000002P3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
00@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0oooo01/0oooo00<000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo000000040?ooo`03
0000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo000000050?ooo`06
0000003oool0oooo0000003oool000000`3oool00`000000oooo000000020?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
1@3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000H0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo
00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`040?ooo`070000003oool000000?oo
o`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000L0oooo00180?ooo`050000003oool00000
0?ooo`000000o`3ooom@0?ooo`030000003oool0000006`0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`03
0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo
000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`000000
203oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`000000203oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0
oooo000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0303oool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo00000006
0?ooo`030000003oool0000000P0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000P0oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00140?ooo`030000003oool000000?l0ooooFP3oool00`000000oooo0?ooo`1@0?ooo`030000
003oool0oooo00l0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000
003oool000000080oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000003oool000000?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`050000003oool000000?ooo`0000001P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`3oool0103oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000`0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000203oool01`000000oooo0000
003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`0<0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool00000103oool01@000000oooo0000003oool00000
00<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000
1P3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
00000080oooo00<000000?ooo`0000001`3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`0000008P3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo0000
00040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00h000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000H0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0000000H0oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001`3o
ool003d0oooo00D000000?ooo`000000oooo0000003o0?ooof80oooo00<000000?ooo`000000B`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`030000003oool0oooo00P0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo000000030?ooo`040000003oool0oooo0000
00<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool01@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000H0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000020?oo
o`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000001P3oool00`000000oooo000000050?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`000000203oool01@000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool01@3oool00`000000
oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000P0oooo00D0
00000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`000003
0?ooo`080000003oool0oooo0000003oool000000?ooo`0000050?ooo`060000003oool0oooo0000
003oool000000`3oool00`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo
000000070?ooo`00=P3oool01P000000oooo0?ooo`000000oooo00000?l0ooooK03oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo01T0oooo00<000000?ooo`000000103oool00`000000
oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`000000103oool00`000000oooo0000000>0?ooo`030000003oool0000000@0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0
oooo00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0
00000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000P0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`000000203oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000K0?ooo`050000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0
00000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000D0oooo00X000000?ooo`3oool0
00000?ooo`000000oooo0000003oool00000103oool02`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00@0oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool00`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`060000003oool000000?ooo`000000oooo1@0000030?ooo`00<03oool0
1@000000oooo0000003oool000000?l0ooooM@3oool00`000000oooo000000110?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000@0oooo
00<000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool00000103oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?oo
o`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0000000D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`000000103oool00`000000oooo
0?ooo`030?ooo`050000003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`000000203oool01@000000oooo0?ooo`3oool0000000<0oooo00@00000
0?ooo`3oool000000`3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`000000
0`3oool00`000000oooo0000000:0?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0000000l0oooo
00D000000?ooo`000000oooo000000080?ooo`050000003oool000000?ooo`0000004@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00002P3oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`0000001@3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000001`3oool010000000oooo0?ooo`0000050?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000203oool02@000000
oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`000000
1`3oool002T0oooo00H000000?ooo`3oool000000?ooo`00003o0?ooogl0oooo00@000000?ooo`3o
ool00000FP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00P000000?oo
o`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00X0oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00l0oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo
000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
103oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000080?ooo`030000003oool0oooo0080oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo000000060?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3o
ool000000?ooo`0000050?ooo`030000003oool0oooo0080oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`0>0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`000000:03oool00`000000
oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`000000203oool00`000000oooo0?ooo`030?ooo`060000003oool0
oooo0000003oool000001`3oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`00
00002P3oool00`000000oooo0?ooo`040?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo00000005
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000060?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool0000000P0oooo00<000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0oooo000U0?ooo`030000
003oool000000?l0ooooR`3oool00`000000oooo0000000f0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`000000103oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`070000003oool000000?oo
o`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000060?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`0<0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000001P3oool00`000000oooo
0?ooo`030?ooo`060000003oool0oooo0000003oool000000`3oool01@000000oooo0000003oool0
00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`070?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000030?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000030?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0203oool01`00
0000oooo0?ooo`3oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo00000002
0?ooo`030000003oool0000001l0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000
003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00060?ooo`050000003oool000000?ooo`000000103oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`000000303oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`07
0000003oool0oooo0?ooo`000000oooo000000080?ooo`030000003oool0oooo00H0oooo00D00000
0?ooo`000000oooo000000080?ooo`050000003oool000000?ooo`0000000`3oool02P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`0000060?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
1`3oool001h0oooo00H000000?ooo`3oool000000?ooo`00003o0?oooi<0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00001P3oool01@000000oooo0?ooo`3oool000000080oooo00/000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000H0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo000000040?ooo`030000003oool0000000D0
oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool02P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00X0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
1P3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0000003oool000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0000000P0oooo00<000000?ooo`0000000`3oool010000000oooo0?oo
o`0000030?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo000000040?ooo`03
0000003oool0oooo01d0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000P0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00<000000?ooo`0000001@3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`000000203oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`00
0000103oool01@000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000003P3oool02P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`0000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000080?oo
o`050000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool001P0oooo
00D000000?ooo`000000oooo0000003o0?oooi`0oooo00@000000?ooo`3oool00000C`3oool00`00
0000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool0000000H0oooo00<000000?ooo`3oool01P3oool01@000000oooo0000003o
ool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000X0oooo00D000000?oo
o`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool020000000oooo0?oo
o`000000oooo0000003oool00000203oool01@000000oooo0000003oool0000000<0oooo00P00000
0?ooo`3oool000000?ooo`000000oooo000000D0oooo00P000000?ooo`3oool000000?ooo`000000
oooo000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
0`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo0000
00030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000020?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00D0oooo00@000000?ooo`3oool00000303oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000X0oooo00<0
00000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000070?ooo`030000003oool0
oooo0080oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0000001T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0000000D0oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`030000003oool0000000@0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo00000006
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000007
0?ooo`00503oool00`000000oooo0000003o0?ooojL0oooo00<000000?ooo`0000009P3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`00
00050?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
0`000000oooo0?ooo`0<0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00h000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00D00000
0?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0
000000@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000040?ooo`070000003o
ool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000P0
oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool00`000000oooo000000060?ooo`030000003oool0000000H0oooo00<000000?oo
o`0000007@3oool00`000000oooo000000020?ooo`030000003oool0000000D0oooo00`000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000060?ooo`050000003oool00000
0?ooo`000000203oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0000000@0oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`003@3oool01@000000
oooo0000003oool000000?l0oooo/03oool00`000000oooo000000170?ooo`030000003oool00000
00@0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo00l0oooo00L000000?ooo`3oool0
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0
oooo00<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00D000000?ooo`000000oooo0000000@0?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000050?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo0000
00040?ooo`050000003oool0oooo0?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool01@3oool020000000oooo0?ooo`000000oooo0000003oool00000
0`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool010000000
oooo0?ooo`0000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000P0oooo
00<000000?ooo`0000000P3oool00`000000oooo0000000M0?ooo`030000003oool000000080oooo
00<000000?ooo`0000001@3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool000000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo
000000060?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`07
0000003oool0oooo0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooaP3o
ool010000000oooo0?ooo`0000120?ooo`030000003oool0000000H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool020000000
oooo0?ooo`000000oooo0000003oool000002P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000060?ooo`050000003o
ool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00@0oooo00L000000?ooo`000000oooo0000003oool0000000P0oooo
00D000000?ooo`000000oooo000000040?ooo`030000003oool0000000H0oooo00L000000?ooo`00
0000oooo0000003oool0000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000001`3oool020000000oooo0?oo
o`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0oooo00`0oooo00D000000?ooo`000000oooo000000020?ooo`03
0000003oool0000001d0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01@000000oooo0?ooo`3oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000060?ooo`070000003oool000000?ooo`000000oooo000000060?oo
o`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0000000D0oooo00P0
00000?ooo`3oool000000?ooo`000000oooo000000H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?oo
o`3oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00060?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000
003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool00`000000oooo000000070?ooo`00o`3oooo;0?ooo`030000003oool0000001L0
oooo00<000000?ooo`3oool0803oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool0
0`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`00000:0?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000001P3o
ool01`000000oooo0?ooo`3oool000000?ooo`000000203oool00`000000oooo0?ooo`060?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
103oool00`000000oooo0?ooo`080?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
1P3oool00`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003o
ool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?oo
o`3oool01@3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00`0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0000003oool0000000P0oooo
00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000@0
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0000001d0oooo00<000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`0000040?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo
000000060?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool00000
00<0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo0000000<0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000070?ooo`00o`3oooo?0?ooo`030000003oool0000003X0oooo00<0
00000?ooo`000000103oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`00000:0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`0000001@3oool020000000oooo0?ooo`000000oooo0000
003oool000001@3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01P000000
oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003o
ool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000<0
oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00<000000?ooo`3oool01@3oool030000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000@0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`3o
ool0oooo000000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0000000O0?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool01P000000oooo
0?ooo`000000oooo000000D0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000P0oooo00D000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0000000D0oooo00X000000?ooo`3oool000000?oo
o`000000oooo0000003oool000001P3oool00`000000oooo000000080?ooo`030000003oool00000
00<0oooo00<000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo
0?ooo`3oool000000?ooo`000000203oool01@000000oooo0000003oool0000000L0oooo003o0?oo
om@0oooo00<000000?ooo`000000=@3oool00`000000oooo000000040?ooo`030000003oool00000
00<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00D000000?ooo`3oool0oooo0000000<0?ooo`050000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0000000:0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool0
00001`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000203oool00`00
0000oooo0?ooo`030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0
oooo00@000000?ooo`3oool000002P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool0000000H0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000001P3oool01@000000oooo
0?ooo`3oool0000000P0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool00000
00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0000000<0oooo00H00000
0?ooo`3oool000000?ooo`00000O0?ooo`060000003oool0oooo0000003oool000000`3oool00`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
00001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003o
ool0000000<0oooo00<000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool01P000000oooo0?ooo`000000oooo000000D0oooo00<000000?ooo`3oool00P3oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`070000
003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000001`3oool0
0?l0oooof03oool00`000000oooo0000000a0?ooo`030000003oool0000000@0oooo00<000000?oo
o`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`0000030?ooo`080000003oool0oooo0000003oool000000?ooo`00000:0?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000
oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo000000L0oooo00@000000?ooo`3oool000001`3oool00`000000oooo
000000020?ooo`030000003oool0oooo00`0oooo00L000000?ooo`000000oooo0000003oool00000
00d0oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000003oool0oooo
0?ooo`000000203oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`0000007`3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`030000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0000003oool0000000H0oooo00D000000?ooo`000000
oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000080?ooo`070000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0000000H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
00060?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000070?ooo`00o`3ooooL0?ooo`030000003oool0000002/0oooo00D000000?oo
o`000000oooo000000040?ooo`030000003oool0000000<0oooo00h000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo
0000000<0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`06
0000003oool0oooo0000003oool000001@3oool00`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`000000
1P3oool01`000000oooo0?ooo`3oool000000?ooo`000000203oool01@000000oooo0000003oool0
000000@0oooo00<000000?ooo`3oool07@3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00D0oooo
00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?oo
o`020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000002P3oool00`000000oooo0?ooo`060?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`050000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001`3oool00?l0ooooh@3oool0
0`000000oooo0000000V0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0000
00030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000103o
ool01@000000oooo0000003oool0000000h0oooo00<000000?ooo`3oool00P3oool01`000000oooo
0000003oool000000?ooo`000000203oool00`000000oooo0?ooo`0<0?ooo`050000003oool00000
0?ooo`000000103oool00`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo000000P0oooo00<000000?ooo`0000000`3oool03P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000001P3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`000000oooo000000040?ooo`070000003o
ool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0
oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`000000oooo000000060?ooo`030000003oool0000000H0oooo00<000000?ooo`0000001@3oool0
0`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0000
000O0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo
0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0000000@0oooo00L00000
0?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`3oool0oooo0000003oool00000
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000203oool01@000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
000000060?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooo`d0
oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`040?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`000000303oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo
0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
000000D0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000H0oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`080?oo
o`030000003oool0000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?oo
o`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool000000080oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01P00
0000oooo0?ooo`000000oooo000000`0oooo00<000000?ooo`3oool0303oool01@000000oooo0000
003oool000000080oooo00<000000?ooo`0000008P3oool00`000000oooo000000030?ooo`030000
003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
1@000000oooo0000003oool0000000P0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`0000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo000000050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo
000000070?ooo`00o`3ooooo0?ooo`d0oooo00<000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000P0oooo00D000000?oo
o`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000203oool01@000000oooo0?oo
o`3oool0000000`0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000H0
oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000L0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo
000000`0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`000000
0`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool000000280oooo
00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000P0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00X000000?ooo`3o
ool000000?ooo`000000oooo0000003oool00000303oool00`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo00D0oooo003o0?ooool0oooo3@3oool00`000000oooo0000
00040?ooo`030000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`0000040?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo
000000060?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool0303oool01@000000oooo
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00X00000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool010000000oooo0?ooo`000003
0?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
00001@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000H0oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?oo
o`0000050?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo
000000040?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000003oool00000
0?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
0280oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000H0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?oo
o`050000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00P0
00000?ooo`3oool000000?ooo`000000oooo000000H0oooo00<000000?ooo`3oool00`3oool01@00
0000oooo0?ooo`3oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000030?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0103oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000
003oool0000000L0oooo003o0?ooool0oooo3@3oool00`000000oooo000000060?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0000000P0oooo00D000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
000@0?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000001P3oool00`000000oooo000000080?ooo`030000003oool0oooo00<0oooo00P000000?oo
o`3oool000000?ooo`000000oooo000000D0oooo00P000000?ooo`3oool000000?ooo`000000oooo
000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool0000000@0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool0
00000?ooo`0000050?ooo`060000003oool0oooo0000003oool000001`3oool010000000oooo0?oo
o`00000<0?ooo`050000003oool000000?ooo`0000001P3oool01`000000oooo0?ooo`3oool00000
0?ooo`000000103oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`0000001P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?oo
o`070000003oool0oooo0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000050?ooo`0<0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0000000R
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00@000000?oo
o`3oool000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0?ooo`3oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
103oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000L0oooo003o0?ooool0oooo3@3o
ool00`000000oooo000000040?ooo`030000003oool0000000P0oooo00L000000?ooo`000000oooo
0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000003P3o
ool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000050?ooo`080000003oool0oooo
0000003oool000000?ooo`0000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<0
00000?ooo`000000203oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo00000003
0?ooo`030000003oool000000080oooo00<000000?ooo`0000001`3oool01P000000oooo0?ooo`00
0000oooo000000D0oooo00H000000?ooo`3oool000000?ooo`00000R0?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`07
0000003oool0oooo0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3o
ool00`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`060?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`050000003oool000000?ooo`000000203oool01@000000oooo0?ooo`3oool0000000P0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000L0oooo003o0?ooonD0oooo00<000000?ooo`3oool0
903oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00P000000?ooo`3oool0
00000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000h0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000
00060?ooo`030000003oool0000000D0oooo00P000000?ooo`3oool000000?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool000000?ooo`0000001P3o
ool01`000000oooo0000003oool000000?ooo`000000203oool01@000000oooo0000003oool00000
00@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo
000000050?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`080?ooo`07
0000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0oooo00<0oooo00P00000
0?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`050?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000
00030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`03
0000003oool0000002@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3o
ool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000001P3oool00`000000oooo000000030?ooo`040000003oool0
oooo000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool000000?ooo`00
00000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool000000080oooo00<000000?ooo`3oool01@3oool0
1P000000oooo0?ooo`000000oooo000000L0oooo00@000000?ooo`3oool000001@3oool00`000000
oooo000000060?ooo`050000003oool0oooo0?ooo`0000001P3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000070?oo
o`00o`3ooooo0?ooo`d0oooo00<000000?ooo`000000103oool00`000000oooo000000060?ooo`0;
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0303oool00`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`050?ooo`03
0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<00000
0?ooo`0000001@3oool00`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`3oool01P3oool02`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000080?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203o
ool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`000000oooo000000050?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?ooo`000000903oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000P0oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00@000000?ooo`3o
ool000000`3oool01@000000oooo0000003oool0000000X0oooo00<000000?ooo`3oool0103oool0
1`000000oooo0?ooo`3oool000000?ooo`000000103oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000060?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?oo
o`0000000`3oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00o`3o
oooW0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00030?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`3oool0oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`03
0000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool000000100oooo00`000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`070000003oool000000?ooo`000000oooo000000060?oo
o`050000003oool0oooo0?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000002P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`050000003oool000000?ooo`000000203oool00`000000oooo000000060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01P00
0000oooo0?ooo`000000oooo000000D0oooo00<000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000002@0oooo00L000000?oo
o`3oool0oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool0
0`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01`000000oooo
0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`070000003oool0oooo
0?ooo`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo
000000<0oooo00<000000?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0P3oool00`000000oooo000000050?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`00
00001`3oool00?l0ooooo`3oool=0?ooo`030000003oool0000000H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000000G0?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool0
1@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000050?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`0000001P3oool00`000000oooo000000030?ooo`030000003oool00000
00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`000000203oool01@000000oooo
0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
000000060?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo0000000T0?ooo`050000003oool000000?ooo`000000103oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000H0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0000003oool00000
00P0oooo00D000000?ooo`000000oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000050?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00X0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`02
0?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`00
00001`3oool00?l0ooooj@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0000000@0oooo
00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000203oool0
1@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000H0
oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`0000030?ooo`050000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`03
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00D00000
0?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool01@000000
oooo0?ooo`3oool0000000H0oooo00<000000?ooo`000000103oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0oooo00X0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`070000003oool0
oooo0?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000X0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000T0?oo
o`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`000000oooo000000080?ooo`050000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00X0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool010000000oooo0?ooo`00
00030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00@000000?oo
o`3oool000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000203oool00`000000oooo
000000040?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00o`3oooo/0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`0<
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?oo
o`030000003oool0000000h0oooo00D000000?ooo`3oool0oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`000000203oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool0
00001`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo00000006
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000003@3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo
00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`000000203oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000P0
oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`000000903oool01`000000oooo0?ooo`3oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00L000000?oo
o`3oool0oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00D000000?ooo`000000oooo000000060?ooo`050000003oool000000?oo
o`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?oo
o`000000oooo000000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
1@000000oooo0?ooo`3oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool00000
00@0oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool01@3oool00?l0ooooo`3oool;0?ooo`050000003oool000000?ooo`000000103oool0
0`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000001<0oooo00D00000
0?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`060000003oool0
oooo0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool000000080oooo
00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`080?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
00001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000040?ooo`030000003oool0000002X0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000050?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`3oool0oooo0000003oool0
000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00?l0ooookP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
000000@0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000006
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`03
0?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo0000000C0?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000060?ooo`030000003oool0000000H0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000X0oooo00<000000?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00002P3oool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00@000000?ooo`3oool000002P3oool00`000000oooo000000070?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo000000020?ooo`030000003oool00000
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000020?ooo`030000003oool00000
00L0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`060000003oool0oooo0000003oool0
00000`3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`3oool09P3oool00`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000001@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0000000@0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`00
0000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0000000H0oooo00D000000?ooo`000000oooo000000040?ooo`0;0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000001P3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo003o0?oo
oo00oooo00<000000?ooo`3oool05@3oool01`000000oooo0?ooo`3oool000000?ooo`000000103o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001P3o
ool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo0?ooo`0C0?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000003`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00H0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`05
0000003oool000000?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`000000203o
ool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000002P0oooo00<0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo0000000:0?ooo`030000003oool0000000@0oooo00D000000?ooo`000000
oooo000000050?ooo`030000003oool0oooo00@0oooo00L000000?ooo`000000oooo0000003oool0
000000@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`060000003oool0
oooo0000003oool000000`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`00
0000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00o`3oooob
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`000000103oool00`000000oooo00000006
0?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`030000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`000000303oool01@000000oooo0?ooo`3oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3o
ool000000?ooo`000000103oool00`000000oooo0?ooo`080?ooo`070000003oool000000?ooo`00
0000oooo000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000:0?ooo`070000003o
ool0oooo0?ooo`000000oooo000000060?ooo`030000003oool0oooo00H0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000002P0oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo0000000:
0?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000D0
oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000001P3oool01`000000oooo
0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool00000
00@0oooo00<000000?ooo`0000001@3oool030000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo003o
0?oooo@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000@0oooo00<000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01@000000oooo0?ooo`3oool0000000<0oooo00H000000?ooo`3oool000000?ooo`00
00050?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo0000000<0?ooo`050000
003oool0oooo0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo0000
00080?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000`0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`040?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo0000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo000000040?ooo`030000003oool0000000P0oooo00L000000?ooo`3oool0oooo
0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`000000:03oool00`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`070000003oool000000?ooo`000000oooo0000000:0?ooo`030000003oool00000
00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`040?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000L0oooo003o0?ooooH0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000@0oooo00<00000
0?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool0oooo
0?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000001@3oool020000000oooo
0?ooo`000000oooo0000003oool000003P3oool00`000000oooo0?ooo`040?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000203oool01@000000
oooo0?ooo`3oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000000P0oooo00D0
00000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000D0oooo00<0
00000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000
oooo0?ooo`050?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool00`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000002H0oooo
00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000060?ooo`050000003oool000000?ooo`000000203oool01`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000001@3oool01P000000oooo0?ooo`000000oooo0000
00D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo
0?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000050?ooo`030000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0oooo003o
0?ooooT0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`050000003oool0
00000?ooo`000000103oool00`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool0
00000?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000001@3oool01@000000oooo0000
003oool0000000H0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo0000
00<0oooo00D000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`000000103o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0oooo00X0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool01@00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo0000000X0?ooo`030000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000080?ooo`050000003oool0oooo0?ooo`0000001P3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo000000030?ooo`060000003oool0oooo0000003oool000001@3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000000<0oooo1@0000030?ooo`00o`3ooook0?ooo`050000003oool000000?oo
o`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
103oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000
oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000050?oo
o`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000080?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0000000X0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000060?oo
o`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo0000000X0?ooo`030000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000060?ooo`030000003oool0000000P0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`060000003oool0oooo0000003oool000001@3oool00`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo00000002
0?ooo`030000003oool0000000D0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`04
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo
0?ooo`d0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000H0oooo00<0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0oooo00P0oooo00L0
00000?ooo`3oool0oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000>0?oo
o`030000003oool0oooo00H0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000002P3oool00`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool02P3oool010000000oooo0?ooo`0000070?ooo`030000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`03
0?ooo`050000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`000000:03oool00`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000H0oooo
00<000000?ooo`3oool0103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000H0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00002P3oool01@000000oooo0000003oool0000000P0oooo00<000000?ooo`000000203oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000X0oooo
00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001P3oool01`000000oooo0000003o
ool000000?ooo`0000001`3oool00?l0ooooo`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0000000@0oooo00<000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003o
ool000000`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000001D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`000000203oool01@000000oooo0?ooo`3oool00000
00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000P0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000000=0?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000002P0oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000
oooo000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003o
ool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?oo
o`000000oooo000000080?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00D0oooo003o0?ooool0oooo2@3oool01`000000oooo0?ooo`3o
ool000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`000000oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`00
00003P3oool00`000000oooo0?ooo`040?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00001@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000@0oooo00D000000?oo
o`000000oooo000000080?ooo`030000003oool0000000D0oooo00P000000?ooo`3oool000000?oo
o`000000oooo000000<0oooo00<000000?ooo`3oool03`3oool00`000000oooo000000050?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000L0oooo00`000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool0000002P0
oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool0203oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000P0oooo00<000000?ooo`3oool01@3oool020000000oooo0?ooo`000000oooo0000
003oool000001P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool01@3o
ool00?l0ooooo`3oool20?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000@0oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000002P3oool010000000oooo0?ooo`0000050?ooo`050000003oool000000?ooo`000000
1P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000P0oooo00D000000?ooo`3oool0
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`000008
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`3oool0203oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`0000001@3oool00`000000oooo000000040?ooo`050000003o
ool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool010000000oooo0?ooo`00000Z0?ooo`030000003oool000000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000`0
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`0000000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00`000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000070?ooo`00o`3ooooo0?ooo`D0oooo00<00000
0?ooo`0000001@3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00h00000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`000000803oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000001P3oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo00000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000203oool00`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000000?0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo
00D000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000001@3oool03P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000X0?ooo`030000
003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`030000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000003P3oool00`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
1@000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000060?ooo`0;0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000001P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`0000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00
o`3ooooo0?ooo`L0oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000
003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
000000080?ooo`030000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo00<000000?ooo`3oool0203o
ool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00H0oooo00<000000?ooo`3oool0203oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?oo
o`070000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000d0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool030000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000H0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
0000;@3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo000000060?ooo`050000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`00
0000103oool00`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00<0oooo00P000000?ooo`3o
ool000000?ooo`000000oooo000000D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000
003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000L0oooo003o0?ooool0
oooo2@3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo0?ooo`03
0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool000000100oooo00<000000?oo
o`3oool00P3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000203oool00`000000oooo0000
00030?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000`0
oooo00<000000?ooo`0000001P3oool00`000000oooo000000080?ooo`050000003oool000000?oo
o`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00P0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000303oool00`000000oooo
000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool03P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`000000:03oool00`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`000000103oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?oo
o`030000003oool0000000X0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00D0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo000000060?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`060000003oool0oooo
0000003oool000000`3oool00`000000oooo000000070?ooo`00o`3ooooo0?ooo`/0oooo00D00000
0?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00`000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000060?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo0000000>0?ooo`030000003oool0oooo00@0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`000000203oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo000000050?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000
oooo000000H0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`00
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000002P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`000000303oool00`000000oooo0?oo
o`040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo00@0oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00D000000?ooo`000000oooo0000000:0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool0
0`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0000
00060?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo0000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103o
ool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000P0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool01@3o
ool00?l0ooooo`3oool=0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool0
2P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000060?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool020000000oooo0?ooo`000000oooo
0000003oool00000403oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0
000000P0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000040?oo
o`050000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0:
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00h000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000040?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool00P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`000000203oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000H0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0000000H0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`000000203oool00`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?oo
o`0000001`3oool00?l0ooooo`3oool=0?ooo`030000003oool0000000@0oooo00<000000?ooo`00
00001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000P0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000`0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo
00D000000?ooo`000000oooo0000000:0?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00P0oooo00L000000?ooo`3oool0oooo0000003o
ool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`0000001P3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`00
00001@3oool00`000000oooo000000020?ooo`030000003oool0000000D0oooo00`000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000002P0oooo00<000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo000000050?ooo`060000003oool0oooo0000003oool00000
203oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool01P3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000080?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000L0oooo
003o0?ooool0oooo3`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000403oool03000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000`0
oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0000
00030?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000P0oooo00D000000?ooo`000000oooo0000
00030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000001@3oool00`000000oooo
000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`3oool01@3oool010000000oooo0?ooo`0000070?ooo`0:0000003oool0oooo0000003oool0
00000?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0000000X0?ooo`03
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000103oool00`000000oooo
000000050?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`0000001`3oool010000000oooo0?ooo`0000030?ooo`050000003o
ool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000001@3oool02P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`0000030?ooo`030000003oool0oooo00P0oooo00`000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`0000070?ooo`00o`3ooooo0?oooa80oooo00D000000?oo
o`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool00000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00H0oooo00<000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000001D0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000H0oooo00<00000
0?ooo`0000001@3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool00000103oool00`000000oooo000000060?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000060?oo
o`050000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`00000<0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00001P3oool00`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`00
0000oooo000000060?ooo`030000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000020?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo00P0
oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool0oooo0?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
30000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<00000
0?ooo`0000001@3oool00`000000oooo0000000:0?ooo`030000003oool0oooo0080oooo00L00000
0?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`0000001`3oool00?l0ooooo`3ooolD0?ooo`030000
003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3o
ool010000000oooo0?ooo`0000050?ooo`050000003oool000000?ooo`0000001P3oool01@000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
000000@0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`040?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000080?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000002P3oool00`000000
oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000080?oo
o`030000003oool0000000@0oooo00<000000?ooo`0000002P3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0
000000L0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000002P0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`000000
103oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool03000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00<000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`000000oooo
000000030?ooo`060000003oool0oooo0000003oool000000`3oool01@000000oooo0?ooo`3oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`0000001`3oool00?l0ooooo`3ooolF0?ooo`050000003oool0
oooo0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000h0oooo00<000000?ooo`3o
ool0103oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00h000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo
0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo
0?ooo`080?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00X000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000001P3oool01@000000oooo0000003oool0000000<0oooo00P0
00000?ooo`3oool000000?ooo`000000oooo000000<0oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0?ooo`3oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`3oool0oooo000000080?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00<000000?ooo`3oool0103oool02@000000oooo0000003oool000000?oo
o`000000oooo000000070?ooo`00o`3ooooo0?oooaX0oooo00h000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000001@3oool0
0`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?oo
o`0000030?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0000000>0?ooo`03
0000003oool0000000P0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo
000000060?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo000000050?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool00000103oool00`000000oooo000000080?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo0000000_0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`030000003oool0000000P0oooo00<000000?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00L0oooo00H000000?ooo`3o
ool000000?ooo`0000050?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool01`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooolH0?ooo`030000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000203oool0
0`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo0000000>0?ooo`030000003oool000000080oooo00<000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00D000000?ooo`000000oooo000000060?ooo`0;0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0oooo00L0oooo00h000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00D000000?ooo`000000oooo
000000060?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`050000003oool00000
0?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool0203oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000001`3oool020000000oooo0?ooo`000000oooo0000003oool00000
0`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`000000;@3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000X0oooo
00<000000?ooo`0000002P3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000X0oooo00D000000?ooo`000000oooo00000003
0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000020?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000001P3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0000000P0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001`3oool0
0?l0ooooo`3ooolJ0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000P0
oooo00D000000?ooo`3oool0oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo00<000000?oo
o`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool00000
00<0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool000000?ooo`000000
1P3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000003@3oool01@000000oooo0?ooo`3oool0
000000D0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool000000080oooo
00<000000?ooo`0000000`3oool00`000000oooo0000000?0?ooo`030000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000X0?ooo`030000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003o
ool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000H0
oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo
0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?oooad0oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0000000P0
oooo00<000000?ooo`000000103oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`000000403oool00`000000oooo000000020?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
000:0?ooo`030000003oool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000
003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0
oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`0;0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0000000P0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?oo
o`3oool000000?ooo`000000103oool00`000000oooo0000000Z0?ooo`0>0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool00000
00@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00P00000
0?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?oo
o`050000003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000103oool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0
oooo003o0?ooool0oooo7`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000
00030?ooo`080000003oool0oooo0000003oool000000?ooo`00000>0?ooo`030000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000040?ooo`030000003oool0000000P0oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0oooo00/0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool000000140oooo00/0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`000000:03oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000203oool01`000000
oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`070000003oool0
oooo0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool020000000
oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000060?ooo`070000
003oool000000?ooo`000000oooo000000060?ooo`030000003oool0oooo00D0oooo00H000000?oo
o`3oool000000?ooo`0000050?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000
1P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`050?ooo`00o`3ooooo0?oooal0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`05
0000003oool0oooo0?ooo`0000002P3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000`0oooo00<000000?ooo`3oool0103oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
000000060?ooo`030000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000001P3oool00`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000003
0?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool0
0`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`040000
003oool0oooo000000`0oooo00D000000?ooo`000000oooo000000030?ooo`060000003oool0oooo
0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000
oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000002P0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000004
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00D000000?ooo`000000oooo000000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
0000103oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool000000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo000000030?ooo`030000003oool0000000L0oooo003o0?ooool0
oooo8@3oool01@000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo0000000<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000`3oool02P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`0000060?ooo`050000003oool000000?oo
o`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool00000203oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000H0oooo00<000000?ooo`3o
ool0103oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000002P0oooo00<000000?ooo`000000103oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001@3oool02000
0000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`070000
003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`050000
003oool0oooo0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool0
10000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`0000001`3oool00?l0ooooo`3o
oolS0?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool03P3oool0
1@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000P0oooo00<000000?ooo`0000000`3oool0
2P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00000:0?ooo`050000003oool00000
0?ooo`000000203oool01@000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool00`000000oooo000000080?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo000000060?ooo`030000003oool0oooo00P0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000:P3oool00`000000oooo
0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo
0000003oool000000`3oool00`000000oooo000000080?ooo`050000003oool0oooo0?ooo`000000
103oool01@000000oooo0000003oool0000000H0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00D0
00000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000001@3oool030000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000080oooo00L000000?ooo`000000oooo0000003oool000000140oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooolU0?oo
o`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000003P3oool00`000000
oooo0?ooo`060?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000D0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`040000003o
ool0oooo000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`3oool0203oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000103oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`000000:P3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000060?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`000000
1`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`040000
003oool0oooo000000<0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00<00000
0?ooo`0000002P3oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`000000203o
ool01@000000oooo0?ooo`3oool0000000L0oooo003o0?ooool0oooo9@3oool00`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000>0?ooo`030000
003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?oo
o`0000001P3oool01@000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000030?ooo`06
0000003oool0oooo0000003oool000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000040?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000
4@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0203oool010000000
oooo0?ooo`00000<0?ooo`050000003oool0oooo0?ooo`0000001P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0;`3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`00
0000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000006
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000203oool01@000000oooo0?ooo`3o
ool0000000L0oooo003o0?ooool0oooo9`3oool03P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`3oool0oooo0000000@0?ooo`040000003oool0oooo000000<0oooo00D000000?oo
o`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool030000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo000000080?oo
o`030000003oool0000000@0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0
000000@0oooo00<000000?ooo`000000:03oool00`000000oooo0?ooo`040?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000
1P3oool00`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`00
00000P3oool00`000000oooo000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`00
00000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`030000003oool0000000P0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0000000L0
oooo003o0?ooool0oooo:P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3o
ool03P3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000001P3oool00`00
0000oooo000000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001P3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo00000006
0?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`000000;@3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000203oool01@00
0000oooo0000003oool0000000X0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo
00<000000?ooo`3oool00`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
00060?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?oo
o`000000oooo000000070?ooo`00o`3ooooo0?ooob`0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool000000?ooo`0000004`3oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo
00D000000?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`000000203oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000000=0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool0000000@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00L000000?oo
o`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`060?ooo`050000003oool0oooo0?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000103oool0
1`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000002P0oooo00<000000?ooo`3oool00P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`3oool00`3oool0
2P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3o
ool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`020?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool03P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01`00
0000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000L0oooo003o0?ooool0oooo;03oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo0000000>0?ooo`030000003oool0oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000
oooo0000003oool0000000X0oooo00D000000?ooo`000000oooo000000040?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool01@3oool03P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000203oool00`00
0000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00X0oooo00L000000?ooo`00
0000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool03`3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`030000003oool0000002X0oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`050000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool000000080
oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00L000000?ooo`3oool0oooo0000
003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`080000003oool0oooo0000
003oool000000?ooo`0000030?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`00
00001P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00@000000?ooo`00
0000oooo1@0000060?ooo`<0000000<0oooo0000003oool00`3oool5000000030?ooo`000000oooo
00<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000070?ooo`00o`3ooooo0?ooobh0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool00`000000oooo0000000E0?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?oo
o`000000oooo0000000:0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool000000?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`000000203oool01@000000oooo0000
003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`030000003oool0oooo0080oooo00/000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00X0oooo00L000000?oo
o`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000040?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`3oool09P3oool00`000000oooo000000040?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000203oool00`000000oooo
0?ooo`060?ooo`050000003oool000000?ooo`0000002P3oool00`000000oooo000000030?ooo`03
0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`8000000`3o
ool010000000oooo0000000000020?ooo`040000003oool000000?ooo`8000000`3oool01@000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo00D0oooo003o0?ooool0oooo<03oool01@000000oooo0000003oool000000080oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
203oool00`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0
oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0000000:0?ooo`0:0000003oool0oooo0000003oool000000?ooo`00
0000oooo000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`0000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`040000003oool0oooo
000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool00000203oool00`00
0000oooo000000030?ooo`030000003oool0oooo00@0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo000000090?ooo`8000000`3o
ool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
00L0oooo003o0?ooool0oooo<P3oool00`000000oooo000000020?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000050?ooo`080000
003oool0oooo0000003oool000000?ooo`00000<0?ooo`050000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo
0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo0000000:0?ooo`030000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000<0oooo00<000000?ooo`3oool03@3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001P3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000001`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo0000000X0?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo
00<000000?ooo`000000303oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`040000003oool00000000000<0oooo00<000000?ooo`000000103oool020000000oooo
0?ooo`3oool000000?ooo`000000oooo200000000?l0ooooo`3ooolb0?ooo`030000003oool00000
0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
0000000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`3oool01@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`030000003oool0
000000H0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool02P3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?oo
o`050000003oool000000?ooo`000000203oool01@000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0
000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000002d0oooo00<000000?ooo`00
00000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool020000000oooo0?ooo`00
0000oooo0000003oool00000203oool01`000000oooo0000003oool000000?ooo`000000103oool0
1@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
000000030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`0000001@3o
ool00`000000oooo00000003000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`03
0000003oool0000000L0oooo003o0?ooool0oooo=03oool010000000oooo0?ooo`0000030?ooo`05
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo0000000<0?ooo`030000003oool00000
00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`000000oooo000000040?ooo`0;0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0oooo00P0oooo00D000000?ooo`000000oooo000000050?ooo`0:0000003oool0oooo
0000003oool000000?ooo`000000oooo000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000060?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
:P3oool00`000000oooo0?ooo`080?ooo`030000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`00
00080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000001P3oool00`000000oooo0000
00060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`050?ooo`00o`3ooooo0?ooocL0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000`0oooo00<000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo00000004
0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000
00060?ooo`030000003oool0oooo00X0oooo00D000000?ooo`000000oooo000000080?ooo`050000
003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool000000?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000002P0oooo00<000000?oo
o`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`000000203oool01`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool0
1`000000oooo0000003oool000000?ooo`0000002P3oool01@000000oooo0000003oool0000000@0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00P000000?ooo`3oool000000?oo
o`000000oooo000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo000000020?ooo`08
0000003oool000000?ooo`000000oooo0000003oool2000000040?ooo`000000oooo000000<0oooo
00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000H0oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooolg0?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000403oool030000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00P000000?ooo`3oool000000?oo
o`000000oooo000000H0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool00000
00<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000d0oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool030000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`060000003o
ool0oooo0000003oool00000:P3oool03P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool01@000000oooo0000003oool0000000H0oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo000000090?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?ooocT0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000060?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0000000P0oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00<000000?ooo`000000
0`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000D0oooo00X000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000`3oool010000000oooo0?ooo`00000<0?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool00000
0140oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
02l0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0?ooo`3oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`050000003oool00000
0?ooo`0000003@3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool02P3o
ool01`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00P0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0
00000080oooo100000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00040?ooo`<0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000L0oooo003o0?ooool0oooo>`3oool01@000000oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
303oool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0
00000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`0:0000003o
ool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00`000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`0000040?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000003@3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo000000070?ooo`040000003oool0oooo
000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000002P0oooo00<000000?ooo`000000103oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000P0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000002P3oool00`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000`0oooo00<000000?ooo`3oool0103oool00`000000
oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000080?ooo`050000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`00
0000oooo0000003oool000000`3oool00`000000oooo000000040?ooo`030000003oool0000000<0
oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000203oool01@000000oooo
0?ooo`3oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001`3o
ool00?l0ooooo`3ooolk0?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool000000100
oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00X000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000001P3oool01@000000oooo0000003oool0000000<0oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00<000000?ooo`000000203oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo0000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000001P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0000000@0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo
0?ooo`3oool000000?ooo`000000203oool01@000000oooo0?ooo`3oool0000000X0oooo00<00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000060?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103o
ool01@000000oooo0000003oool0000000`0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3o
oolm0?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`000000303oool01@000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000
00030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000103o
ool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000060?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0000003oool00000
00<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000103oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool03@3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0
00000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool000000080oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000002X0oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000080?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000203oool00`000000oooo00000006
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`000000103oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0000003oool0000000P0oooo00<000000?ooo`0000001P3oool00`000000oooo
000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00D0oooo003o0?ooool0oooo?`3oool03P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0000000@0?ooo`03
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
203oool01@000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool00`000000
oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000040?oo
o`070000003oool0oooo0?ooo`000000oooo000000060?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`000000
103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000
oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool00`000000oooo0000000X0?ooo`030000003oool0000000@0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool020000000oooo0?ooo`00
0000oooo0000003oool000000`3oool00`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0000
00020?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`050000003oool000000?oo
o`0000001@3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000001`3oool00?l0ooooo`3ooolo0?ooo`0>0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`05
0000003oool000000?ooo`0000003P3oool00`000000oooo000000040?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool00000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
103oool01`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool0
00000?ooo`000000oooo000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`060?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000002P3oool0
1@000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool00000
00<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0
000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000P0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`000000203oool01`000000oooo0?oo
o`3oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000001`3oool00?l0ooooo`3ooom20?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo00<000000?ooo`00
00001P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000H0oooo00D000000?ooo`3oool0oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo0080oooo
00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000050?ooo`030000003oool0oooo00H0oooo00D000000?ooo`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`00
00000`3oool020000000oooo0?ooo`000000oooo0000003oool000001P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool0
1P000000oooo0?ooo`000000oooo000000L0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000
oooo000000070?ooo`00o`3ooooo0?oood@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000h0oooo00<000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`030000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool02P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`0000060?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo0000
00030?ooo`030000003oool0000000d0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`020?ooo`050000
003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0000003oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
00@0oooo00D000000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool00000
00<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000001`3oool00?l0ooooo`3ooom40?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
0000000>0?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000003`3oool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool00000
0`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00P0oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool0;@3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000D0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool030000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000@0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0oooo003o0?ooool0
ooooAP3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000`0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000060?ooo`050000003o
ool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000P3oool01`000000oooo0000003oool000000?ooo`0000001P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000@0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000
003oool0000000H0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`00000:0?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo
0?ooo`000000oooo000000P0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`080000003oool0oooo0000003oool0
00000?ooo`0000030?ooo`030000003oool0000000P0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000050?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003o
ool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo
0?ooodP0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
303oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000103oool01@000000
oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`00
0000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`00
00030?ooo`050000003oool000000?ooo`000000103oool00`000000oooo000000050?ooo`0<0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01@000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool0103oool01`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool00000
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`050000003oool00000
0?ooo`000000103oool00`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?ooodP0oooo00D000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`000000303oool01@000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?oo
o`0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`08
0000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo000000040?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo0000000=0?ooo`030000003oool0
oooo00L0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00h000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000
003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000001P3oool00`000000oooo000000060?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000001P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000001P3o
ool01@000000oooo0?ooo`3oool0000000L0oooo003o0?ooool0ooooBP3oool00`000000oooo0000
00020?ooo`050000003oool000000?ooo`000000303oool01@000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000
003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`3oool0oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
1@000000oooo0?ooo`3oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000`3oool010000000oooo0?ooo`00000:0?ooo`070000003oool0oooo0?ooo`000000
oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`000000;`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo
00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo000000080?ooo`050000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000303oool00`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`050000003oool00000
0?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`030000003oool0000000L0oooo003o0?ooool0ooooC03oool0
20000000oooo0?ooo`000000oooo0000003oool00000303oool01@000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000060?ooo`03
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool00P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo0000000A0?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`000000<`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool0000000X0oooo00@000000?ooo`3oool000001`3oool00`000000oooo000000060?oo
o`030000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000
oooo000000040?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`050?oo
o`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`060000003oool0
oooo0000003oool000001@3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?oood`0oooo00P0
00000?ooo`3oool000000?ooo`000000oooo000000`0oooo00D000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000080?ooo`030000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`00
0000oooo000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`03
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000080?ooo`050000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000060?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool09P3oool00`000000oooo000000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool00000
00P0oooo00D000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo
000000060?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000000`3oool030000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0
000000H0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?ooodl0oooo00D00000
0?ooo`000000oooo0000000<0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo000000060?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool0203oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0000000X0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0000000D0oooo00`000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`000000203oool00`000000oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo000000080?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool00?l0
ooooo`3ooomA0?ooo`030000003oool0000000`0oooo00D000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`030000003oool0
oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`070000003oool0
oooo0?ooo`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool0
00000?ooo`0000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool00P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo000000040?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000040?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?oo
o`0000001P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000X0oooo00D000000?ooo`3oool0oooo000000060?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000L0oooo003o0?ooool0ooooD@3oool00`00
0000oooo0000000:0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool00P3oool01`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`0000040?ooo`030000003oool0000002P0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000080?ooo`05
0000003oool000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0000000X0oooo00L000000?ooo`000000oooo0000003oool00000
00L0oooo003o0?ooool0ooooD`3oool00`000000oooo0?ooo`080?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool030000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000H0oooo00<000000?ooo`0000000`3o
ool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`0:0000003oool0
oooo0000003oool000000?ooo`000000oooo000000@0oooo00L000000?ooo`000000oooo0000003o
ool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000000]0?ooo`030000003o
ool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo
00D000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo00000006
0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000008
0?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003o
ool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003o
ool0000000P0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool01@3oool00?l0ooooo`3ooomN0?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0
000000<0oooo00<000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo000000050?ooo`030000003oool0oooo00@0oooo00L000000?ooo`000000oooo0000003oool0
000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`000000
1@3oool00`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000
oooo0000000a0?ooo`030000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`000003
0?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000P0oooo
00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?oo
o`3oool01P3oool01@000000oooo0000003oool0000000X0oooo00<000000?ooo`000000203oool0
0`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000001@3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?oooeD0oooo00<000000?ooo`3oool0103oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000P0oooo00D000000?oo
o`3oool0oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000050?ooo`0<
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000003`3oool00`000000oooo000000030?ooo`030000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool01@000000oooo0000003oool0000000X0oooo00H000000?ooo`3oool000000?ooo`00
000Z0?ooo`060000003oool0oooo0000003oool000001@3oool00`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool00000
00<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000H0oooo00<000000?ooo`00
00001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000060?ooo`050000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00001`3oool00?l0ooooo`3ooomG0?ooo`030000003oool0oooo00@0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000060?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?oo
o`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`00
0000oooo000000040?ooo`030000003oool0oooo00P0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool01@000000oooo0000003oool0000000H0
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool00`000000oooo0?ooo`0V0?ooo`030000003oool0000000@0
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool000000?oo
o`000000203oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool0
3P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool00000
0080oooo00<000000?ooo`0000001@3oool020000000oooo0?ooo`000000oooo0000003oool00000
0`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?oooeX0oooo00/000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0000000D0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00`0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool000000080oooo00D000000?ooo`3oool0
oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003o
ool000000080oooo00<000000?ooo`000000:P3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000D0oooo00h000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00D00000
0?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000001@3oool00`000000
oooo000000060?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo000000030?oo
o`030000003oool0oooo0080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo000000040?ooo`030000003oool0oooo00<0oooo00h000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000080?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo00000005
0?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooomJ0?ooo`0;0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0
000000@0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000003`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo0000
00<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool000000080oooo00<0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`020?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000P0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000060?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000103oool01@000000oooo
0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000060?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
000000H0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000070?ooo`00o`3ooooo0?oooeh0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo000000080?ooo`05
0000003oool000000?ooo`0000001@3oool030000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool00`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo
00L000000?ooo`3oool0oooo0000003oool0000000l0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`050000003oool000000?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3o
ool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo0000000:0?ooo`050000003oool000000?ooo`000000103oool02@000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000
1P3oool01@000000oooo0000003oool0000000H0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo003o0?ooool0ooooG03oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`07
0000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00`0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool00P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000008
0?ooo`050000003oool0oooo0?ooo`000000103oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool00`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000@0
oooo00<000000?ooo`0000002P3oool01@000000oooo0000003oool0000000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000070?ooo`00o`3ooooo0?oooeh0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool01P3oool01@000000oooo
0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`07
0000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool00000
2P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000`0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000H0oooo00/000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000002l0oooo00<000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`00
0000oooo000000080?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool0000000H0oooo
00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`00
00000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000050?ooo`030000003oool00000
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
00L0oooo003o0?ooool0ooooGP3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0:0000
003oool0oooo0000003oool000000?ooo`000000oooo000000H0oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool020000000oooo
0?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000000:0?oo
o`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool01@3oool03P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool0
1@000000oooo0000003oool0000000@0oooo00/000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000P0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo0?oo
o`050?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`060000003oool0oooo
0000003oool000000`3oool00`000000oooo000000040?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool0103oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003o
ool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo000000030?ooo`030000003oool0000000@000000`3oool00?l0oooo
o`3ooomP0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool00000103oool00`000000oooo000000030?oo
o`060000003oool0oooo0000003oool000000`3oool01@000000oooo0000003oool0000000@0oooo
00D000000?ooo`3oool0oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`00
00030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000H0
oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D00000
0?ooo`000000oooo0000000:0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool0
:03oool010000000oooo0?ooo`0000050?ooo`050000003oool000000?ooo`000000203oool00`00
0000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000l0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`030000003o
ool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`00
00000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`070000
003oool0oooo0?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool00000203o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000000L0oooo003o0?ooool0ooooHP3oool0
0`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`030000003oool0000000<0
oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3o
ool00`000000oooo000000050?ooo`060000003oool0oooo0000003oool000000`3oool00`000000
oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo0?ooo`030?oo
o`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`080000003oool0
oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool0000002l0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
0?ooo`050?ooo`060000003oool0oooo0000003oool000000`3oool01@000000oooo0?ooo`3oool0
00000140oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000060?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000
oooo0?ooo`3oool000000?ooo`0000003`3oool01@000000oooo0?ooo`3oool0000000P0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?oo
of80oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`000007
0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000040?ooo`050000003o
ool0oooo0?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000
003oool0oooo00D0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo0000000X0?ooo`030000003oool0000000@0oooo00<00000
0?ooo`0000001@3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool0
00000?ooo`000000203oool01@000000oooo0000003oool0000000H0oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000030?ooo`030000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01@00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000:0?ooo`050000003o
ool0oooo0?ooo`0000001`3oool00?l0ooooo`3ooomT0?ooo`0<0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool01@000000oooo0000003oool0000000P0oooo
00D000000?ooo`000000oooo000000080?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`000000:P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00H0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`3oool0oooo000000060?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000H0oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00?l0ooooo`3ooomT0?ooo`0<0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool01`000000oooo0000003oool000000?ooo`000000
1P3oool00`000000oooo000000050?ooo`080000003oool0oooo0000003oool000000?ooo`000005
0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
2`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00030?ooo`080000003oool0oooo0000003oool000000?ooo`0000050?ooo`030000003oool0oooo
0080oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3o
ool01@000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000D0oooo00@000000?ooo`3oool000001`3oool00`000000oooo000000020?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool0
0`000000oooo000000060?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0000
00040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01@000000oooo
0000003oool0000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`040?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
1@3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?oo
ofL0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`070000003oool0
00000?ooo`000000oooo000000080?ooo`050000003oool0oooo0?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00L0
00000?ooo`3oool0oooo0000003oool0000000<0oooo00@000000?ooo`3oool000001`3oool03P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000030?ooo`060000003oool0oooo0000003oool00000:03o
ool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`05
0000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0
oooo0?ooo`000000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0
000000X0oooo00D000000?ooo`3oool0oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000060?ooo`070000003oool0
00000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000001P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool0
00000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000001`3oool00?l0ooooo`3ooomY0?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<0
00000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000
oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`030000003oool0oooo00D0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0]0?ooo`050000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0000000@0oooo00D000000?ooo`000000oooo000000060?ooo`050000003oool00000
0?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0
oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000X0oooo00P0
00000?ooo`3oool000000?ooo`000000oooo000000D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000060?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003o
ool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
00070?ooo`00o`3ooooo0?ooofT0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000203oool00`000000oooo0?ooo`04
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`060000003o
ool0oooo0000003oool000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool01@3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool00000
0`3oool01@000000oooo0?ooo`3oool0000000@0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`000000:P3oool010000000oooo0?ooo`0000030?ooo`050000003o
ool0oooo0?ooo`0000001P3oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00/000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00001P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000H0oooo
00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00L0oooo00`000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool0
0?l0ooooo`3ooom[0?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000103oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0
1@3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000103oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo00/000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000040?ooo`070000003oool0oooo0?ooo`000000oooo0000
00040?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`0;0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000H0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000
003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`030000003oool00000
00H0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`0<0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000001`3oool00?l0ooooo`3ooom[0?oo
o`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`030000003oool0000000D0oooo00P000000?ooo`3oool000000?ooo`000000
oooo000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0
oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000:03o
ool00`000000oooo0?ooo`040?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool00000
1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo000000080?ooo`030000003oool0oooo00X0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000203oool00`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`000000103oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000070?ooo`00o`3ooooo0?ooofd0oooo00<000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`000000203oool00`000000oooo000000030?ooo`0>0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`070000003o
ool000000?ooo`000000oooo000000040?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool0103oool01`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
0000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000002d0oooo
00D000000?ooo`000000oooo000000080?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`040?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool0
1`000000oooo0?ooo`3oool000000?ooo`000000103oool01@000000oooo0000003oool0000000D0
oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooofl0oooo00`000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`030000003oool00000
00P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0oooo00P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool00000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000002d0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool01@00
0000oooo0000003oool0000000P0oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo
00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001`3oool0
0?l0ooooo`3ooom_0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool00000103oool01@000000oooo0000003oool0000000P0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000P3o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203o
ool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000060?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0000000Z0?ooo`0<0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000001P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`030000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000
003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00h000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00D00000
0?ooo`000000oooo000000080?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`05
0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooomb0?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000001P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
1@000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0oooo00P0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?oo
o`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`000000:03oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00D000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`040?ooo`030000003oool00000
00P0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`000000
1@3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000001P3oool00`000000
oooo000000030?ooo`030000003oool0000000L0oooo003o0?ooool0ooooLP3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00@00000
0?ooo`3oool000001@3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000203oool00`000000
oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`08
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool00`000000oooo000000030?ooo`060000003oool0oooo0000003o
ool00000:03oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?oo
o`00000:0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo
0000003oool000000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool010000000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000L0oooo
003o0?ooool0ooooM03oool01`000000oooo0000003oool000000?ooo`0000001P3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool02000
0000oooo0?ooo`000000oooo0000003oool000000`3oool020000000oooo0?ooo`000000oooo0000
003oool000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00P00000
0?ooo`3oool000000?ooo`000000oooo000000D0oooo00@000000?ooo`3oool000000`3oool01@00
0000oooo0?ooo`3oool0000002d0oooo00<000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
0000103oool01@000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000001@3oool03P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool00`000000oooo000000030?ooo`030000003oool00000
0080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00<00000
0?ooo`3oool02P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`00o`3ooooo0?ooog@0oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00@00000
0?ooo`3oool000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
oooo00P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`000000103oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000040?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000
oooo0000000Z0?ooo`060000003oool0oooo0000003oool000000`3oool01@000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000001P3oool00`000000oooo000000030?ooo`050000003o
ool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000P0oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0000000L0
oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000103oool01`000000oooo
0000003oool000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3o
oomf0?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0
oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000001@3oool030000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0oooo00P0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000P0oooo00D000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000002d0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000P0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool0000000H0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo
00<000000?ooo`0000001@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo0?oo
o`000000oooo000000<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool00000
00<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000D0oooo00@000000?ooo`3oool0
00000`3oool01@000000oooo0?ooo`3oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000001`3oool00?l0ooooo`3ooomh0?ooo`030000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
1P3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01@000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool00`000000oooo000000050?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`030000003oool0000000D0oooo00P000000?ooo`3o
ool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000103oool00`000000oooo0000
00080?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00<0oooo00`000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000
oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0oooo003o0?ooool0ooooN03o
ool00`000000oooo000000040?ooo`050000003oool000000?ooo`000000203oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool0203oool00`000000oooo000000050?ooo`030000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000001P3oool00`00
0000oooo0?ooo`0X0?ooo`060000003oool0oooo0000003oool000001`3oool030000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000`0oooo00<00000
0?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool00000
1@3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`050000003oool000000?ooo`000000203oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooogX0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000050?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`3oool0203oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`030000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool01P3oool01@000000oooo0000003oool000000080oooo
00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@00
0000oooo0000003oool0000000P0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`03
0?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`00
0000103oool00`000000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo00000006
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`00
0000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo003o0?ooool0oooo
NP3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool010000000
oooo0?ooo`0000050?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00001P3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`00
000:0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`030000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000001P3oool00`000000oooo000000040?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000
003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`0000001@3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00<000000?ooo`0000001@3oool03P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool00`000000oooo000000050?ooo`030000003oool0
oooo0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo0000000:0?ooo`030000003oool0000000@0oooo00L0
00000?ooo`3oool0oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000001`3oool00?l0ooooo`3ooomo0?ooo`050000003oool000000?ooo`0000000`3o
ool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`080000003oool0
oooo0000003oool000000?ooo`0000030?ooo`060000003oool0oooo0000003oool000000`3oool0
1@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo0?ooo`080?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000
003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo0000
00<0oooo00D000000?ooo`000000oooo000000080?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000001P3oool00`000000oooo000000030?ooo`0>0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`070000003oool0
oooo0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0
oooo000000060?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo00D0oooo003o
0?ooool0ooooO03oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool030000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`3oool0203oool02`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000040?ooo`030000003oool0000000D0oooo00`000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000003H0
oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`070000003oool00000
0?ooo`000000oooo000000080?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3o
ool00`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000040?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`0000001`3oool00?l0ooooo`3ooomo0?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`060000003oool0oooo0000003oool000001`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003o
ool0000000L0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000@0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo0000
02X0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000080?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000H0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000P0oooo00L000000?ooo`3oool0oooo0000003oool00000
0080oooo00D000000?ooo`3oool0oooo000000060?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`060000003oool0
oooo0000003oool000000`3oool00`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000070?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool00000103oool01`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooon1
0?ooo`030000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`3oool0oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000001P3oool00`000000oooo000000040?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000002P0
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`000000203oool01@000000oooo0000
003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`030000003oool0oooo
00@0oooo00L000000?ooo`3oool0oooo0000003oool0000000P0oooo00<000000?ooo`3oool0103o
ool01`000000oooo0?ooo`3oool000000?ooo`000000103oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3o
oon10?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?oo
o`0000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00P0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo
0?ooo`3oool000000?ooo`0000004`3oool01@000000oooo0000003oool0000000<0oooo00h00000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00<0
00000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000P0oooo
00D000000?ooo`3oool0oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo00000006
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo0000
00070?ooo`00o`3ooooo0?oooh<0oooo00D000000?ooo`3oool0oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00<000000?ooo`3oool0203oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`030000003oool000000080oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
2P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`000000:03oool00`000000oooo000000040?ooo`070000003oool00000
0?ooo`000000oooo0000000:0?ooo`030000003oool000000080oooo00<000000?ooo`3oool02P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo
0000003oool0000000`0oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0?ooo`030?oo
o`030000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?oo
o`030000003oool0000000@0oooo00D000000?ooo`000000oooo000000060?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool0000000L0oooo003o0?ooool0ooooP`3oool01@000000oooo
0?ooo`3oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0000000:0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000001P3oool00`000000oooo000000050?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool0
000000D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000050?ooo`030000003oool0000000P0oooo00<000000?ooo`000000
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00D0oooo
003o0?ooool0ooooQ`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000003
0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool0
0`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool030000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo000000050?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo
000000060?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`050000003oool0
00000?ooo`000000203oool01@000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000L0oooo
003o0?ooool0ooooQ@3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
oooo00P0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00001P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`050000003o
ool000000?ooo`000000103oool00`000000oooo0?ooo`0e0?ooo`030000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool00000103oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0?oo
o`3oool0000000H0oooo00<000000?ooo`000000203oool00`000000oooo000000050?ooo`030000
003oool0000000@0oooo00<000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool00000103oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo
000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000020?ooo`030000003oool0000000P0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000001`3oool00?l0ooooo`3ooon70?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00<000000?ooo`3oool0203oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool03000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool000000080
oooo00<000000?ooo`000000;@3oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00050?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`0:0000003oool0oooo
0000003oool000000?ooo`000000oooo000000<0oooo00H000000?ooo`3oool000000?ooo`000005
0?ooo`060000003oool0oooo0000003oool000001@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`000000103oool020000000oooo0000003oool000000?oo
o`000000oooo1@0000030?ooo`00o`3ooooo0?ooohL0oooo00h000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00D000000?ooo`000000oooo0000
00030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000040?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`040?ooo`050000003oool0
00000?ooo`000000203oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`03
0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo00000004
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo000000060?ooo`030000003oool0000000<0oooo00`000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
000000020?ooo`050000003oool000000?ooo`0000001P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo003o0?ooool0ooooRP3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00h00000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<0
00000?ooo`3oool02P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool01@000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo
00<000000?ooo`000000:03oool00`000000oooo0?ooo`080?ooo`030000003oool0000000H0oooo
00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?oo
o`0000001P3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
00050?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?oo
o`0000001`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000103o
ool00`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo003o0?ooool0ooooS03oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?oo
o`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`3oool02P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`070000
003oool0oooo0?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`0_0?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`080?ooo`050000003oool00000
0?ooo`000000203oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool010000000oooo0?ooo`0000050?ooo`050000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`030000003o
ool0oooo0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooooo0?oooh`0oooo00D000000?ooo`000000oooo000000060?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0?ooo`080?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`050?ooo`080000
003oool0oooo0000003oool000000?ooo`0000050?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000
oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`000000
0P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000P0oooo00<0
00000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo00000005
0?ooo`030000003oool000000080oooo00<000000?ooo`0000001@3oool01P000000oooo0?ooo`00
0000oooo000000D0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool0
0?l0ooooo`3ooon>0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool02P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0
oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`3oool0;`3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool00000
1P3oool00`000000oooo000000070?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0
oooo0000003oool0000000P0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`030?oo
o`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000103oool01@000000oooo0000
003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool00000
00L0oooo003o0?ooool0ooooSP3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000D0oooo00<00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0?ooo`3oool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000H0oooo00<000000?ooo`3oool0;@3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00h00000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00D0
00000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001P3oool01`000000
oooo0?ooo`3oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000
oooo000000070?ooo`00o`3ooooo0?oooi00oooo00D000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001P3oool00`000000
oooo0?ooo`030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000030?ooo`030000003o
ool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`00
0000103oool00`000000oooo0?ooo`050?ooo`0>0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000020?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`030000
003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000L0oooo003o0?ooool0ooooT03oool01@00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000203oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`000000103oool02`00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo00000004
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo000000040?ooo`030000003oool0000000P0oooo00<000000?ooo`00
0000203oool01`000000oooo0?ooo`3oool000000?ooo`000000203oool01@000000oooo0000003o
ool0000000L0oooo003o0?ooool0ooooTP3oool00`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`030000003oool0oooo00P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`000000
1P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`000000103oool02`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0
oooo000002X0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo
00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo000000050?ooo`030000003oool0oooo0080
oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3o
ool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`06
0000003oool0oooo0000003oool000001`3oool010000000oooo0?ooo`0000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000L0oooo003o0?ooool0ooooTP3oool00`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`070000003oool000000?ooo`00
0000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool03P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000002X0oooo00X000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`05
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`0000000`3oool00`000000oooo000000080?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool00000
0`3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`000000103oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000080?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000001`3oool00?l0ooooo`3ooonD0?ooo`0<0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000003@3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000D0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000002X0oooo00X000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000203oool0
1@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000P0
oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000001P3o
ool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000001@3oool020000000oooo
0?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0
00000?ooo`0000001`3oool00?l0ooooo`3ooonD0?ooo`0<0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`050000003oool000000?ooo`000000
0`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00<000000?ooo`0000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo
00D000000?ooo`000000oooo000000050?ooo`0<0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000P3oool00`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000002l0oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000H0
oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`000000103oool0
1@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool00000
00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool000000?ooo`000000103o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3o
oonG0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000103oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00060?ooo`030000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000001@3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo0?oo
o`000000oooo000002P0oooo00<000000?ooo`000000203oool01@000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000001P3oool01@000000oooo
0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`0000001P3oool01@000000oooo0000003oool0000000D0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000
0P3oool00`000000oooo000000050?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`000000203oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooonI0?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0oooo00X0oooo00D000000?ooo`000000oooo000000030?oo
o`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?oo
o`3oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`020?ooo`050000
003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?oo
o`000000oooo000000<0oooo00<000000?ooo`3oool0103oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool03P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000
oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`050000003oool000000?ooo`000000203oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool01@3oool00?l0ooooo`3ooonI0?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0oooo
00X0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`000000103oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`060000003oool0oooo
0000003oool000000`3oool00`000000oooo000000040?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000]0?oo
o`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0
oooo0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`0>0?ooo`050000003oool0
00000?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`0;0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool01@00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo00000002
0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo003o0?ooool0ooooV`3oool01@000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo000000060?ooo`050000003oool000000?ooo`000000103oool01@000000
oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`020?oo
o`070000003oool000000?ooo`000000oooo0000000<0?ooo`030000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`00
0000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000060?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`060?ooo`05
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?oooi/0oooo00D000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000003`3oool02`000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000002P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool000000080oooo00<000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo0000
00040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`060?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000060?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooonK0?ooo`050000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0?ooo`080?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`0<0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo
000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?oo
o`030000003oool0oooo00D0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000203oool00`000000oooo00000008
0?ooo`030000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool000000080oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000050?ooo`050000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080
oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool000000080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool010000000oooo0?oo
o`0000030?ooo`050000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooonI0?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`3oool02P3oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`3oool0oooo0000003oool0000000X0oooo00<000000?ooo`000000103oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000@0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo02d0oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000000:0?ooo`0:0000003oool0oooo0000
003oool000000?ooo`000000oooo000000H0oooo00L000000?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo00000005
0?ooo`080000003oool0oooo0000003oool000000?ooo`0000080?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0000
00040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0000
003oool0000000L0oooo003o0?ooool0ooooU`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0000000?0?ooo`050000003o
ool0oooo0?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000060?ooo`050000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool00P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0
oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`3oool0oooo0000
003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000050?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`050000003oool000000?ooo`0000000`3oool030000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000080?ooo`050000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00H0
00000?ooo`3oool000000?ooo`0000080?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool01@3oool00?l0ooooo`3ooonB0?ooo`030000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000003`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
0P3oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?oo
o`030000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000D0oooo00`000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`00
00030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0000000X0?ooo`030000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000H0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool000000?oo
o`0000001P3oool01@000000oooo0000003oool0000000D0oooo00@000000?ooo`3oool000001`3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0103oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`000000
103oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo003o0?ooool0ooooT03o
ool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000@0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
oooo00X0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
00000080oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?ooo`3oool0
oooo000000050?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`060?ooo`050000003o
ool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`030000003oool0000000@0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`00
0000203oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000103oool00`000000oooo00000003
0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000060?ooo`030000
003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`030000003oool00000
00@0oooo00D000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000060?ooo`05
0000003oool0oooo0?ooo`0000001`3oool00?l0ooooo`3ooon>0?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0000000<0
oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000d0oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000080?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000040?oo
o`050000003oool000000?ooo`000000303oool01@000000oooo0?ooo`3oool0000000H0oooo00D0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01P000000oooo0?ooo`000000
oooo000002P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`050000003o
ool0oooo0?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`030000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`3oool01`3oool010000000oooo0?ooo`0000050?ooo`030000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000
1`3oool00?l0ooooo`3ooon<0?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo
0?ooo`3oool000000340oooo00<000000?ooo`0000001P3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000
oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`050000003oool0
00000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000H0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000H0oooo
00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`00
00000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00<000000?ooo`3oool01@3oool0
0?l0ooooo`3ooon:0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0000
00020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`3oool0oooo000000050?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool00000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`060000003oool0oooo0000003oool00000:03oool00`000000oooo0?ooo`080?oo
o`050000003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool0000000X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000060?ooo`050000003oool000000?ooo`000000103oool00`000000oooo00000005
0?ooo`030000003oool000000080oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`00
00070?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000001`3oool00?l0ooooo`3ooon70?ooo`0>0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000d0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00`000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000:03o
ool00`000000oooo0000000?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`0000001@3oool020000000oooo
0?ooo`000000oooo0000003oool000002P3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo0?ooo`030?oo
o`050000003oool000000?ooo`000000203oool00`000000oooo000000020?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`000000
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?oo
ohD0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool0203oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000X0oooo00<000000?ooo`000000103oool00`000000oooo000000050?ooo`03
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000002l0oooo00<000000?ooo`3oool01P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000L0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0000003oool0
00001@3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo00000006
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000X0oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`00
0000oooo0?ooo`030?ooo`030000003oool000000080oooo00/000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000000P3oool00`00
0000oooo000000050?ooo`030000003oool0oooo00D0oooo003o0?ooool0ooooP`3oool01@000000
oooo0?ooo`3oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00`0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`0;0?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000:03oool00`000000oooo
000000060?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool00000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000L0oooo003o0?ooool0ooooP@3oool00`000000oooo
000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000002l0oooo00L000000?ooo`3oool0
oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00P0
00000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0203oool01@00
0000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo
00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000080?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool0
1@000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000L0oooo003o0?ooool0
ooooO`3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`0:0?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`05
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool000000340oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`000000303oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool00`000000oooo000000050?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`000005
0?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`00
00001`3oool00?l0ooooo`3oooml0?ooo`080000003oool0oooo0000003oool000000?ooo`000003
0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00X0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3o
ool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0000000X0?ooo`030000003oool0oooo
0080oooo00L000000?ooo`3oool0oooo0000003oool0000000`0oooo00<000000?ooo`000000103o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo
0000003oool0000000H0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo
0000003oool000000`3oool00`000000oooo000000020?ooo`030000003oool0000000D0oooo00@0
00000?ooo`3oool000001@3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool0203oool00`000000oooo000000040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool00?l0ooooo`3ooomh0?ooo`030000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000
oooo000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0oooo00P0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0
oooo00H000000?ooo`3oool000000?ooo`00000X0?ooo`030000003oool0000000@0oooo00<00000
0?ooo`000000303oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D00000
0?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000
oooo000000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000H0oooo00D000000?ooo`000000oooo000000040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo
1@0000030?ooo`00o`3ooooo0?ooogH0oooo00D000000?ooo`000000oooo000000040?ooo`050000
003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`3oool0oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0oooo02l0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3o
ool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`0000001P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
0000000:0?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0000003oool00000
00<0oooo00@000000?ooo`3oool000001`3oool00`000000oooo000000060?ooo`050000003oool0
00000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0
0P3oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo003o0?ooool0ooooM03oool01`000000oooo0000003oool00000
0?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`030000003oool0oooo00P0oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0
oooo000000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool03000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo0000000X0?ooo`030000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?oo
o`3oool0oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo00@0oooo00L000000?ooo`000000oooo0000003oool0000000X0oooo00<000000?oo
o`3oool00P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`000000203oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000050?ooo`0>0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`07
0000003oool0oooo0?ooo`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool0000000L0oooo003o0?ooool0ooooLP3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`030000003oool0000000D0oooo00h000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000
0`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000002d0oooo
00<000000?ooo`000000103oool00`000000oooo000000050?ooo`040000003oool0oooo000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?oo
o`3oool000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0oooo0080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`0000001`3oool00?l0ooooo`3ooom_0?ooo`0<0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool00000103oool01@000000oooo0000003oool0000000<0oooo00@0
00000?ooo`3oool000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000003`3oool01`000000oooo0000003oool000000?ooo`0000000`3oool030000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000P0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000;`3o
ool01@000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool01@000000oooo0?ooo`3oool0000000<0oooo00H000000?ooo`3oool000000?ooo`000007
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000080?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`00
0000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003
0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooooo0?ooof/0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000080?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool0203oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000060?ooo`050000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000@0oooo00<0
00000?ooo`000000:P3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000X0oooo00<0
00000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01`000000
oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0000000:0?ooo`030000003oool000000080oooo00/000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooomY0?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo
00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`00
00000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000P0
oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00X000000?ooo`3oool000000?oo
o`000000oooo0000003oool000001P3oool01`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00/000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooofL0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0oooo00P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`0000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool0
:`3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000
oooo0?ooo`030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo00000008
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`0>0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`050000
003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool00000103oool01@000000oooo0000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00D0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooomT0?ooo`0<0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000000=0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000002d0oooo00<000000?ooo`0000001@3oool00`000000
oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0000003oool0000000`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?oo
o`070000003oool0oooo0?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000001P3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0
00000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000001@3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000004
0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooomP0?oo
o`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<0
00000?ooo`0000001@3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000000]
0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool01@000000oooo0000003oool0000000<0
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000001P3o
ool01`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0
000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1`3oool00?l0ooooo`3ooomN0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00h00000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0oooo00P0oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00`0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`050000003o
ool000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`00
00001@3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000P3oool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000001@3o
ool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool0000000L0oooo003o0?ooool0ooooG03oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000
oooo0?ooo`080?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`050?oo
o`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003o
ool000000?ooo`0000002P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0?ooo`3oool000000?ooo`000000203oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000X0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`0<0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool01@000000oooo
0000003oool0000000H0oooo00<000000?ooo`0000001`3oool020000000oooo0?ooo`000000oooo
0000003oool000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo00000003
0?ooo`030000003oool0000000L0oooo003o0?ooool0ooooE`3oool010000000oooo0?ooo`000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00D000000?ooo`000000oooo0000
00030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool00`000000oooo000000030?ooo`030000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo00P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`030000003oool0000000H0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000@0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000P0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool01@000000oooo0000003o
ool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00@000000?oo
o`3oool000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
000000030?ooo`060000003oool0oooo0000003oool000001`3oool020000000oooo0?ooo`000000
oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo000000070?ooo`00o`3ooooo0?oooeD0oooo00<000000?ooo`3oool0
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo000000050?oo
o`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0
000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00<0oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`000000:03oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool000000?oo
o`000000203oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00P000000?oo
o`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo
000000050?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0
00000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
1@3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000L0oooo
003o0?ooool0ooooD@3oool00`000000oooo0000000:0?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000@0oooo00D000000?ooo`000000oooo00000003
0?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00`000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`05
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00H0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`00o`3ooooo0?ooodl0oooo00D000000?ooo`000000oooo0000000:0?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00D0
00000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`3oool02P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo0000000X0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`00
00030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0oooo00D0
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000H0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000060?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000040?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0
oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000D0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000L0oooo003o0?ooool0oooo
C03oool020000000oooo0?ooo`000000oooo0000003oool00000303oool01@000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`00
00000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool02P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`0000060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000002X0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
0080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00L0
00000?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`000000103oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@00
0000oooo0000003oool0000000L0oooo003o0?ooool0ooooB03oool01@000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo0000000<0?ooo`050000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool03P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000001@3oool0
3P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool00000;`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000X0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`00
0000103oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?ooodH0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000<0?ooo`050000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0000003oool000000`3oool0
1@000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000080?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`060000003oool0oooo0000
003oool00000:03oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000
oooo000000060?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`060?oo
o`030000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000080?ooo`050000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooom20?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000`0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool01@000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`000003
0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`3oool0203oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`00
00000`3oool010000000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01P000000oooo0?oo
o`000000oooo000002P0oooo00<000000?ooo`000000103oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00h000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000X0oooo00D000000?ooo`00
0000oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo00000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000
003oool0000000X0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000L0
oooo003o0?ooool0oooo?@3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo
00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool02P3oool0
1@000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool03P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo02X0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003o
ool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0303oool01@00
0000oooo0?ooo`3oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?oo
o`000000203oool01@000000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000001`3oool00?l0ooooo`3ooolk0?ooo`050000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo0000000>0?ooo`030000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`080?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`000000:P3oool020000000oooo0?oo
o`000000oooo0000003oool000001@3oool02P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000040?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000040?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000001@3oool02P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`0000040?ooo`030000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`040000003o
ool0oooo000000L0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooolg0?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000`0oooo00D000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0oooo00P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`0>0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`00000Z0?oo
o`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool0103oool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`3o
ool0oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000060?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003o
ool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000003o
ool0oooo00X0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000002P3oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000001`3oool00?l0ooooo`3ooold
0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000`0oooo00D000000?ooo`3oool0oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`000000103oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool0203oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000303oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0000003oool0000000@0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool00`000000oooo000000080?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000P0oooo00<0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3oool`0?ooo`050000003oool00000
0?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000`0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo
00D000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo0000000_0?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`00
00030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0
oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00D000000?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000001`3oool00?l0ooooo`3oool/0?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo0000000<0?ooo`030000003oool0000000@0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool0203oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0000000H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000@0oooo00<00000
0?ooo`000000:P3oool00`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool00000
00P0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooolW0?ooo`0>0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000<0?ooo`05
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool01@000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00X0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`000000:03oool00`00
0000oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo000000080?ooo`030000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool01`000000oooo0?ooo`3oool000000?ooo`00
00001P3oool01`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo0000000:0?ooo`030000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3o
oolU0?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000003P3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000`3oool030000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool0203oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo0000000d0?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0
000000H0oooo00D000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool0
00000?ooo`0000030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`000000oooo00000006
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0:0000003o
ool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000003P3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`08
0000003oool0oooo0000003oool000000?ooo`0000060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00?l0ooooo`3ooolQ0?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00`0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`00
0000oooo0?ooo`080?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000
003oool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`030000003oool0000000@0
oooo00D000000?ooo`000000oooo000000060?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000D0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`05
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool00000
00@0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000001`3oool00?l0ooooo`3ooolM0?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000h0
oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool0
0`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool00000
00@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00000h0?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000080?oo
o`030000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003o
ool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000X0oooo
00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
00000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?oo
o`3oool01@3oool00`000000oooo000000020?ooo`030000003oool000000080oooo100000020?oo
o`040000003oool000000?ooo`<0000000D0oooo0000003oool000000?ooo`04000000030?ooo`00
0000oooo00D0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001`3oool00?l0
ooooo`3ooolH0?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000`0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo0?ooo`080?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool0
30000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<00000
0?ooo`3oool0:03oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
0000000:0?ooo`030000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo
0000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`040000003oool0oooo
000000<0oooo00@000000?ooo`000000oooo0P0000000`3oool000000?ooo`020?ooo`<0000000<0
oooo0000003oool00P0000000`3oool000000?ooo`03000000040?ooo`000000oooo000000@0oooo
00L000000?ooo`3oool0oooo0000003oool0000000L0oooo000=0?ooo`030000003oool000000?l0
ooooo`3oool40?ooo`030000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo00000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo0000000<0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`050000003oool000000?oo
o`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`05
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
0?ooo`0:0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000002X0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool0oooo0?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000P3oool00`000000oooo000000030?ooo`050000003oool000000?oo
o`0000001P3oool01@000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00040?ooo`050000003oool000000?ooo`0000001P3oool02`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool0
1P000000oooo0000003oool000000?ooo`8000000`3oool020000000oooo0000003oool000000?oo
o`000000oooo0P0000000`3oool000000?ooo`0200000080oooo00<000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool01@3oool00140oooo00H00000
0?ooo`3oool000000?ooo`00003o0?ooooL0oooo00P000000?ooo`3oool000000?ooo`000000oooo
000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool01@000000oooo0000003oool0000000`0
oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
1@000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`0000040?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool02P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo0000000X0?ooo`030000003oool0oooo00@0oooo00L000000?ooo`3oool0oooo
0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L00000
0?ooo`3oool0oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo000000030?ooo`05
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00X00000
0?ooo`3oool000000?ooo`000000oooo0000003oool000001P3oool01`000000oooo0?ooo`3oool0
00000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`03000000030?ooo`00
0000oooo00<0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0oooo
000H0?ooo`070000003oool000000?ooo`000000oooo0000003o0?ooon/0oooo00D000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`000000303oool01@000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool0
3P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`080?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000002X0oooo00<0
00000?ooo`3oool00P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo000000040?ooo`060000003o
ool000000?ooo`000000oooo0P000000203oool000000?ooo`000000oooo0000003oool000001@3o
ool4000000030?ooo`000000oooo00L0oooo00H000000?ooo`000000oooo0000003oool800000000
8@3oool01@000000oooo0000003oool000000?l0ooooh03oool00`000000oooo000000030?ooo`03
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo0000000>0?ooo`030000003oool0oooo00@0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;`3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?oo
o`3oool0oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0000000P0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0
oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000001@3oool00`000000oooo000000060?ooo`040000003oool0
00000?ooo`80000000H0oooo0000003oool000000?ooo`0000030?ooo`040000003oool000000000
00<0oooo0`0000000`3oool000000?ooo`030?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool01@3oool002L0oooo00<000000?ooo`0000000P3oool00`000000oooo0000003o0?ooom80
oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000103o
ool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo0000000<0?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000080?oo
o`030000003oool0oooo00<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo
00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`0<0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`00000:0?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?oo
o`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000040?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`000000:03oool00`000000oooo00000002
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000203oool01@000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000H0oooo
00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000D0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000020?ooo`080000
003oool0oooo0?ooo`000000oooo0000003oool2000000030?ooo`000000oooo0080oooo00H00000
0?ooo`3oool0oooo0000003oool2000000<0oooo0`000000103oool000000?ooo`0000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000L0oooo000`0?ooo`070000003oool0
00000?ooo`000000oooo0000003o0?ooolP0oooo00<000000?ooo`3oool01P3oool01`000000oooo
0?ooo`3oool000000?ooo`000000103oool00`000000oooo000000030?ooo`0>0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000h0oooo00<000000?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool0203oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`050?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0
000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
0`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0000000Z0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?oo
o`060?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool0
10000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo
0?ooo`0:0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`0<
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool2
000000040?ooo`000000oooo000000D0oooo00L000000?ooo`00000000000?ooo`000000oooo0080
00000P3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool01@3oool003T0oooo00L000000?ooo`000000oooo0000003oool000000?l0oooo]P3oool03000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000303o
ool01@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo
0000003oool0000000H0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000040?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo
0?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool00000
0080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`060000003oool0oooo
0000003oool000000`3oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool0
00000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool010000000oooo0000003oool5
000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000<0000000<0
oooo0000003oool00P3oool010000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`00
00001`3oool00440oooo00P000000?ooo`3oool000000?ooo`000000oooo00000?l0ooooZ@3oool0
0`000000oooo0000000?0?ooo`030000003oool0000000D0oooo00<000000?ooo`000000103oool0
0`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00h000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00D000000?ooo`000000
oooo0000000<0?ooo`030000003oool0000000P0oooo00D000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000
oooo000000080?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo0000000]0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000X0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo000000040?ooo`030000003oool0oooo00<0oooo00X000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00
BP3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`03
0000003oool0000001L0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000h0oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0
00000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo0?oo
o`000000oooo000002X0oooo00<000000?ooo`3oool00P3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool0000000P0oooo00<000000?ooo`000000103oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000H0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool00000
00`0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001`3o
ool005<0oooo00L000000?ooo`000000oooo0000003oool000000?l0ooooS`3oool010000000oooo
0?ooo`00000M0?ooo`050000003oool000000?ooo`000000103oool00`000000oooo000000030?oo
o`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000003P3oool00`00
0000oooo0?ooo`040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo00000003
0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000001P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000X0?ooo`030000
003oool0000000X0oooo00<000000?ooo`0000000P3oool00`000000oooo000000050?ooo`0:0000
003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000060?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`060000003oool0oooo
0000003oool000000`3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`000000
0`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000:
0?ooo`030000003oool0oooo0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00001`3oool005`0oooo00L000000?ooo`000000oooo0000003oool000000?l0ooooQ03oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool03P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`000000303oool01@000000oooo0000
003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0
oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0000000L0oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00002P3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000040?ooo`070000
003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`000000103oool00`000000oooo000000050?ooo`030000003oool0oooo00D0oooo001T0?oo
o`030000003oool000000080oooo00<000000?ooo`000000o`3ooomi0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`0>0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`050000003oool000000?ooo`000000303oool01@000000oooo0?ooo`3oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000
1P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
103oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool0203oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`000005
0?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000002X0oooo00P000000?ooo`3o
ool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00050?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000080?ooo`05
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000H0oooo00<000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`0000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000`3oool010000000oooo0?ooo`0000030?ooo`050000
003oool000000?ooo`0000000P3oool00`000000oooo000000070?ooo`040000003oool0oooo0000
00<0oooo00D000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00K@3oool01`000000
oooo0000003oool000000?ooo`000000o`3ooonH0?ooo`030000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
3P3oool01@000000oooo0?ooo`3oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool01`000000oooo0000003oool000000?ooo`00
0000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000003@3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`030000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00H000000?ooo`3oool000000?ooo`00000X0?ooo`030000003oool0000000@0oooo00D000000?oo
o`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool00000
0?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool00000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`0000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000070?ooo`00MP3oool02@000000oooo0000003oool000000?ooo`000000oooo
0000003o0?ooof80oooo00<000000?ooo`000000:03oool00`000000oooo000000040?ooo`030000
003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool00000
00h0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool00000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
oooo00P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool00`000000oooo0?ooo`0V0?ooo`030000003oool0000000@0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
0000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00@000000?ooo`3o
ool000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000
003oool0000000P0oooo00D000000?ooo`000000oooo000000070?ooo`00P@3oool01`000000oooo
0000003oool000000?ooo`000000o`3ooom90?ooo`0>0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`00000[0?ooo`050000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000H0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000003P3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo
0000003oool000000`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo0000000]0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`0000002P3oool00`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000H0oooo00<000000?ooo`00
00000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000001@3o
ool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01P000000oooo
0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0
000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool0000000L0oooo
00290?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo0000003o0?oooc40oooo
00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000>P3oool01@00
0000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool03P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000h0oooo00<000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000
003oool000000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`070000003oool000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000002X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`0000050?ooo`050000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`00
00000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?oo
o`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo
000000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`08
0000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000070?ooo`00U03oool00`000000oooo000000020?ooo`050000003o
ool000000?ooo`000000o`3ooolI0?ooo`030000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool000000280oooo00<000000?ooo`3oool0903oool00`000000oooo000000040?oo
o`030000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`00
0000oooo000000`0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?oo
o`000000oooo000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0oooo00P0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo
0?ooo`030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000001@3oool020000000oooo0?ooo`000000oooo
0000003oool000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo
00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000
003oool0000000D0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo0?ooo`030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000001`3oool009l0oooo00D000000?ooo`000000oooo000000020?ooo`030000003o
ool000000?l0oooo0`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`000000
<@3oool00`000000oooo0?ooo`0N0?ooo`070000003oool0oooo0?ooo`000000oooo000000040?oo
o`030000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000`0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01@000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3o
ool00`000000oooo0?ooo`040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo
00P0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`000000;`3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00L00000
0?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`03
0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000
0P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000D0oooo00<000000?ooo`0000001P3oool01@000000oooo0000003oool0000000H0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo002Z
0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`3/0?ooo`0:0000003o
ool0oooo0000003oool000000?ooo`000000oooo000003h0oooo00<000000?ooo`3oool0803oool0
0`000000oooo000000040?ooo`030000003oool0000000<0oooo00h000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo0000000:0?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool00000
00<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00H0
00000?ooo`3oool000000?ooo`00000Z0?ooo`060000003oool0oooo0000003oool000000`3oool0
1@000000oooo0?ooo`3oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo0000
00<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool030000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00/000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo000000040?ooo`070000003oool0oooo0?oo
o`000000oooo000000070?ooo`00/`3oool02@000000oooo0000003oool000000?ooo`000000oooo
0000003L0?ooo`070000003oool000000?ooo`000000oooo0000001<0?ooo`030000003oool00000
01L0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000060?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000080?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000H0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
1@3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3o
ool0203oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0:`3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00h000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00D00000
0?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool01@000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`060?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0oooo002n0?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000<P0oooo00L000000?ooo`000000oooo0000003o
ool0000005T0oooo00<000000?ooo`0000004@3oool00`000000oooo0?ooo`030?ooo`050000003o
ool000000?ooo`000000103oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`000000303oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0>0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`0>0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`0>0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`070000003o
ool0oooo0?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003o
ool000000?ooo`000000oooo000000080?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
1@000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool02P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`0000030?ooo`0<0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool01@3oool00<T0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000002b0?ooo`030000003oool000000080oooo00<000000?ooo`000000I@3oool00`00
0000oooo0000000:0?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`080000
003oool0oooo0000003oool000000?ooo`0000060?ooo`0;0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`050000003oool000000?ooo`0000000`3oool02P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`0:0000003oool0oooo0000003o
ool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
10000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00P0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool01P3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000203oool01`000000oooo
0?ooo`3oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`080000003oool0oooo
0000003oool000000?ooo`0000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`030000003oool0000000<0oooo00<000000?ooo`00
00000P3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`030000003oool0oooo00<0oooo00P000000?ooo`3oool000000?ooo`00
0000oooo000000<0oooo00<000000?ooo`3oool01@3oool00=H0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000X@3oool01@000000oooo0000003oool0000007<0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000@0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0
000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000H0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000H0
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000
003oool000000?ooo`000000oooo000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000070?ooo`00h@3oool02@00
0000oooo0000003oool000000?ooo`000000oooo0000002A0?ooo`040000003oool0oooo000007d0
oooo00<000000?ooo`3oool0303oool00`000000oooo000000040?ooo`030000003oool0000000<0
oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000080?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00D000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool00000103oool00`000000oooo000000050?ooo`0>0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool03000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00<000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00h000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool01@000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`000000:P3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000003
0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000040?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool0
3P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000001P3o
ool01@000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00<000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
103oool00`000000oooo0?ooo`030?ooo`080000003oool0oooo0000003oool000000?ooo`000003
0?ooo`030000003oool0oooo00D0oooo003[0?ooo`0<0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool00000OP3oool01@000000oooo0000003oool0000008@0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`0000000`3o
ool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000080?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`040000003oool0oooo000000L0oooo00P000000?ooo`3oool000000?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000P0oooo00<0
00000?ooo`3oool0:03oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`00
0000103oool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool0000000P0oooo00D00000
0?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`0;
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00n03oool02P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`00001^0?ooo`040000003oool0oooo000008`0oooo00<00000
0?ooo`3oool0103oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo
000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000
2P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000070?ooo`060000003oool0oooo0000003oool000000`3oool01@000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?oo
o`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`0<0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
0000103oool00`000000oooo0?ooo`0X0?ooo`060000003oool0oooo0000003oool000000`3oool0
1@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?oo
o`000000oooo0000003oool00000103oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool010000000oooo0?oo
o`0000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool01@3o
ool00?l0oooo103oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
000005d0oooo00<000000?ooo`000000U03oool00`000000oooo000000050?ooo`030000003oool0
000000@0oooo00<000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000002P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000040?ooo`030000003oool0000000D0oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000002P0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3o
ool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool01P3oool01@000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
1@3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000070?oo
o`00o`3ooolA0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
0000CP3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0000000<0oooo00<000000?ooo`00
0000103oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000X0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0>0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000D0oooo00h000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00D000000?ooo`000000oooo000000030?oo
o`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0000000@0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000]0?ooo`0;0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00<000000?ooo`0000001@3oool02P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3o
ool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<0
00000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000080?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo00D0oooo003o0?oooal0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000000o0?ooo`030000003oool0oooo09`0oooo00L000000?ooo`3oool0oooo0000003oool0
000000@0oooo00<000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000`0oooo00D000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool01@000000oooo
0?ooo`3oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`030000003oool0000002P0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00D000000?ooo`000000
oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000`3oool00`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool00`000000oooo000000070?ooo`00o`3oool/0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2P
0?ooo`050000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`0>0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo00D000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000
003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool00000
00<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool0oooo00D0oooo
00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0:03oool00`000000oooo000000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?oo
o`000000203oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`030000003oool000000080oooo00<000000?ooo`3oool0303oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0
oooo00<000000?ooo`3oool00`3oool030000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000080?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo
000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0
oooo00D0oooo003o0?ooocT0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`000000
103oool00`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000`0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1P3oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3o
ool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000103oool01`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?oo
o`050?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool00`000000oooo0000000X0?ooo`030000003oool0
00000080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00L0
00000?ooo`3oool0oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1`3oool00?l0ooooAP3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo0000002l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool03P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000<0?ooo`050000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000050?ooo`03
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000002P0oooo00<000000?ooo`3oool00P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool00`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000070?ooo`00o`3ooomC0?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000002`0?ooo`030000003o
ool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000P3oool01@000000oooo0000003oool00000
00`0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
2P3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool0:03oool00`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`0:0000003oool0oooo0000003o
ool000000?ooo`000000oooo000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooomR0?ooo`030000
003oool0oooo0:`0oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo0000000<0?ooo`050000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000050?ooo`050000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo0000000X0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000@0oooo
00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003o
ool0000000H0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0oooo
003o0?ooool0oooo503oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000`0oooo00D000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000H0oooo
00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000080?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool00`000000oooo0?ooo`0X0?ooo`080000003oool0oooo0000003oool000000?ooo`00
000<0?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000080?ooo`07
0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`04
0000003oool0oooo000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000001@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`060000003oool000000?ooo`000000oooo1@000003
0?ooo`00o`3ooooo0?oooaH0oooo00D000000?ooo`3oool0oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo0000000<0?ooo`050000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`030000003oool0000000D0oooo00<000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`080?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0
oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0000000]0?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00<00000
0?ooo`0000001@3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool00000103oool00`000000oooo000000050?ooo`0<0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`02
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`050000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00L000000?oo
o`3oool0oooo0000003oool0000000L0oooo003o0?ooof@0oooo00<000000?ooo`3oool0/03oool0
0`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
000<0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`050000
003oool0oooo0?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool00000
0?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool02P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00H000000?ooo`3oool00000
0?ooo`00000]0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?oo
o`030000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000`3oool010000000oooo0?ooo`00000:0?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`030000
003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000
oooo000000070?ooo`00o`3ooomW0?ooo`030000003oool0oooo0:l0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`000000303oool01@000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo
00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000004@3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000002P0oooo00<000000?oo
o`3oool00P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000001P3oool0
1@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00D000000?ooo`000000oooo000000030?ooo`06
0000003oool0oooo0000003oool000000`3oool01@000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool01@000000oooo0000003oool0000000L0oooo003o0?ooofT0oooo00<0
00000?ooo`000000/03oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
303oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool01@000000
oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000080oooo00<000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
00000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000P3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0000000X0?ooo`030000003oool0oooo00@0oooo00L00000
0?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`000000203oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool020000000oooo
0?ooo`000000oooo0000003oool000000`3oool00`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000060?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool01@000000oooo0000003oool0000000L0oooo003o0?ooofd0oooo00<0
00000?ooo`3oool0[03oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000<0?oo
o`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`3oool0203oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000050?ooo`0<0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000P3oool00`000000oooo0000000]0?ooo`0;0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`060?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`0>0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00D0oooo003o0?ooofl0oooo00<000000?ooo`000000[03oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000`0oooo00D000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo
0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000P0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool0203oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000@0oooo00<000000?ooo`000000:P3oool03P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01@000000oooo0000003o
ool0000000<0oooo00@000000?ooo`3oool000001@3oool01@000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000001@3oool020000000oooo0?ooo`000000oooo0000
003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00h00000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00D0
00000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000001@3oool00`00
0000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool01@3oool00?l0
ooooM03oool00`000000oooo0000002Y0?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo
00D000000?ooo`3oool0oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@00
0000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0000000Z0?ooo`060000003oool0oooo0000003oool000000`3oool01@000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000@0oooo00<000000?ooo`0000000`3oool00`000000
oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000080oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo0000
00070?ooo`00o`3ooomh0?ooo`030000003oool000000:L0oooo00D000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0
oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000203oool01@000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00X0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?oo
o`030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
000X0?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000060?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0000
00040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`0>0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000050?ooo`03
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`060000003oool0oooo0000003oool000001@3oool00`000000
oooo0?ooo`050?ooo`00o`3oooml0?ooo`060000003oool0oooo0000003oool00000X03oool01@00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`000000303oool01@000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000040?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0:03oool00`000000
oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`0000001P3oool01@000000oooo0000003oool0000000@0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo00000003
0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0000000<0
oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool00000
00D0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000080?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00
o`3ooon30?ooo`050000003oool000000?ooo`000000W03oool00`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo00D00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo
0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`3oool0:03oool020000000oooo0?ooo`000000oooo0000003o
ool00000203oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00D000000?oo
o`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000050?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool00000103oool01`000000oooo0000003oool000000?ooo`0000001`3oool00?l0oooo
R@3oool01P000000oooo0?ooo`000000oooo000009D0oooo00<000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000<0?ooo`050000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?oo
o`080?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`020?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000H0oooo00L00000
0?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo
0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`0<0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo00000003
0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000001`3oool0
0?l0ooooT03oool01@000000oooo0000003oool0000008/0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000003P3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
1@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000@0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo
00P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02H0oooo00<000000?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000060?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool0000000L0oooo003o0?oooiH0oooo00H0
00000?ooo`3oool000000?ooo`0000200?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo0000000<0?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000000=0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000040?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool0;`3oool00`000000oooo000000030?ooo`030000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000001@3o
ool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0
000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001`3oool00?l0oooo
W@3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool0L03oool00`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000G0?oo
o`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000
003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0Z0?ooo`080000003oool0oooo0000
003oool000000?ooo`0000050?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?oo
o`040000003oool0oooo000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`060000003o
ool0oooo0000003oool000000`3oool01@000000oooo0000003oool0000000H0oooo00D000000?oo
o`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool0000000P0oooo00<000000?ooo`0000001`3oool00?l0ooooYP3oool01`000000oooo0000
003oool000000?ooo`000000I03oool01@000000oooo0000003oool0000000<0oooo00h000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000303oool01@000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo
000000030?ooo`060000003oool0oooo0000003oool000000`3oool01@000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`00
0000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`00
0000oooo000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000050?ooo`030000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000X0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`0000070?ooo`00o`3ooon^0?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo00000580oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0
000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
0000303oool00`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@00
0000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00h000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo
000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000050?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`00
00000P3oool00`000000oooo000000050?ooo`030000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000L0oooo003o0?oookT0oooo00P000000?ooo`3oool000000?ooo`000000oooo00000400
oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000103o
ool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000`0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00D000000?ooo`00
0000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0000
00040?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`080?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000;@3o
ool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000P0oooo00<00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000H0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`0<0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00001P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool01@3oool00?l0oooo`P3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`00
0000:P3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000080?ooo`070000
003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00h000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000303oool00`000000oooo
000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool00000
00<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000@0oooo00<000000?ooo`0000000`3oool0
3P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000060?ooo`050000003oool00000
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000H0oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000070?ooo`00
o`3oooo=0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0000000@0?ooo`03
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000002P3o
ool00`000000oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`03
0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`000000303oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
103oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003o
ool0oooo00P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo0000000X0?ooo`030000003oool0oooo00H0oooo
00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0<0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo00D0oooo003o0?ooomP0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo0000000N0?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000<0?ooo`030000
003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000@0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`3oool02P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000103oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
0P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00`000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000P0oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo0000
00040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000L0oooo003o0?ooool0
oooo1`3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`00
00000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
000<0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L00000
0?ooo`3oool0oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
0?ooo`080?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`060000003oool0oooo
0000003oool000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo0000000]0?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool01`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00D000000?ooo`000000oooo000000060?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?oo
o`000000oooo000000080?ooo`050000003oool000000?ooo`0000001`3oool00?l0ooooi@3oool0
1@000000oooo0000003oool000000200oooo00D000000?ooo`000000oooo000000040?ooo`030000
003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`000000303oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?oo
o`050000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003o
ool0oooo00X0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`000000:03oool00`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00
o`3oooo/0?ooo`050000003oool000000?ooo`0000006`3oool00`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo0000000<0?ooo`050000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0oooo00P0oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0000000X0?ooo`030000003oool0oooo
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool0
1@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`0>0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000L0oooo003o
0?oooo80oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000`0oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool03P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000<0?ooo`050000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000002P0oooo00<000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000
003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000P3oool01@000000oooo0000003oool00000
00D0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00D000000?ooo`00
0000oooo000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000L0oooo003o0?ooood0
oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo00D000000?ooo`3oool0oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool00000
00<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000002P0oooo00<000000?ooo`3oool02P3oool00`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool01@000000oooo0000
003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00o`3o
oooo0?ooo`D0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo0000000<0?ooo`050000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0>0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3o
ool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000002X0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool00`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000L0oooo003o0?ooool0oooo3@3oool00`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo0000000<0?ooo`050000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0>0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool0203oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`000000:03oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00h000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`00
00000`3oool00`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo00000007
0?ooo`00o`3ooooo0?oooaH0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo0000000<0?ooo`050000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`000000:03oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000080?ooo`030000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000060?ooo`0;0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo0000000:0?ooo`030000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo000000070?ooo`00o`3ooooo0?oooal0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo0000000<0?ooo`050000003oool000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool03P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool00`000000oooo0?ooo`0:0?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`0>
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`000000oooo000000040?ooo`030000003oool0000000<0oooo00X000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000`3oool030000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1`3oool00?l0ooooo`3ooolW0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`000000303oool01@000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`030000003oool0oooo00P0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?oo
o`050000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?oo
o`0000001@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`05
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3o
ool`0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000`0oooo00D000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0
oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000040?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool03P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
103oool00`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`000000203oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`00
0000oooo000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool01@3oool00?l0ooooo`3oooli0?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000`0oooo00D000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00h000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000040?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000002P0oooo00<000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000080?ooo`050000003o
ool0oooo0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003o
ool000000?ooo`000000oooo000000@0oooo00P000000?ooo`3oool0oooo0000003oool000000?oo
o`D000000`3oool00?l0ooooo`3ooolo0?ooo`0>0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000020?ooo`050000003oool000000?ooo`000000303oool0
1@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000
003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000000=0?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`000000:P3oool02P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo00000004
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000D0oooo00H000000?ooo`3oool000000?ooo`0000080?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000001`3oool00?l0ooooo`3ooom80?ooo`050000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo00D000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000
003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`000000:03oool00`000000oooo0?ooo`020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`050000003oool000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000H0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooomA0?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`040000003oool0oooo000000X0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000002P0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo
00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000060?ooo`030000
003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000
1`3oool00?l0ooooo`3ooomJ0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo
000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0
203oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000040?oo
o`030000003oool0000002P0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000@0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`000000203oool01`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo0000
00070?ooo`00o`3ooooo0?ooof80oooo00<000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`000000:03oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00h000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?oo
o`040000003oool0oooo000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooof/0oooo00D000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`3oool0203oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`000000:P3oool03P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool01`000000oooo0000003oool000000?oo
o`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool01@000000oooo0000003oool0000000P0oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000070?ooo`00o`3ooooo0?ooog@0oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`3oool0203oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool0oooo0?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000X0?ooo`03
0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000H0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`3oool0oooo000000060?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000001`3o
ool00?l0ooooo`3oooml0?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`0>
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000002P0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0
000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000103oool02@000000oooo0000
003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooohD0oooo00<000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool02000
0000oooo0?ooo`000000oooo0000003oool000000`3oool03P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000070?ooo`00o`3ooooo0?oooh`0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000002P0oooo00<000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`0>0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo
000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool00000
00L0oooo003o0?ooool0ooooU03oool030000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`080?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?oooid0oooo00<000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`080?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000X0?ooo`030000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00L000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000H0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000001`3oool00?l0ooooo`3ooonV0?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`3oool0203oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000:03oool00`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000H0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000070?ooo`00o`3o
oooo0?ooojl0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`080?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000002P0oooo
00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00L000000?oo
o`3oool0oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo00D0oooo003o0?ooool0oooo]`3oool00`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0oooo00P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000002P0oooo
00<000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
1`000000oooo0000003oool000000?ooo`0000001P3oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00070?ooo`00o`3ooooo0?oool00oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo0000000X0?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo00000004
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00040?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000001`3oool00?l0ooooo`3oooo90?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`3oool0203oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000Z0?ooo`060000003o
ool0oooo0000003oool000000`3oool01@000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000070?ooo`00o`3ooooo0?ooom40oooo00`000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
0000000X0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000050?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool030000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000L0oooo003o0?ooool0oooof03oool01@000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo00P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool03P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000X0?ooo`030000003o
ool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool00`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool03P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00<00000
0?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool00000
0?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`050?ooo`00o`3ooooo0?ooon40oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`080?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
000_0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00P000000?oo
o`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool0000000L0oooo003o0?ooool0ooooj@3oool030000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
02X0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00D000000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo0?ooo`030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000001`3oool00?l0ooooo`3oooob0?ooo`030000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000002P0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000020?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00`000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00H0oooo00<000000?ooo`0000000`3oool00`000000oooo000000070?ooo`00o`3ooooo0?oooo/0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`000000:03oool00`000000oooo000000020?ooo`030000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0
oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000
0`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?oo
o`D0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000:03oool00`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`0<
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000L0oooo003o0?ooool0ooooo`3oool=0?ooo`0>0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000002X0oooo00h00000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`080000003oool0
oooo0000003oool000000?ooo`0000030?ooo`030000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000L0oooo003o0?ooool0ooooo`3ooolF0?ooo`050000003oool000000?ooo`000000
0P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo0000000X0?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000
0`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo
0?oooal0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000002P0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?oo
o`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo0000
00030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000L0oooo003o0?ooool0ooooo`3ooolX0?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo0000000X0?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000020?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000001`3oool00?l0ooooo`3ooooo0?ooobh0oooo00D000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000002P0oooo00<000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000L0oooo003o0?ooool0ooooo`3ooolg0?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
0000000X0?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?ooool0oooo@03oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`000000:03oool00`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
3P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`000000103oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000L0oooo003o0?ooool0ooooo`3ooom80?ooo`030000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000:03oool00`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00P000000?ooo`000000oooo0000
003oool000000?ooo`D000000`3oool00?l0ooooo`3ooooo0?oooe40oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo0000000V0?ooo`050000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool0
00000?ooo`000000oooo000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000001`3o
ool00?l0ooooo`3ooooo0?oooeX0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo0000000R0?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
30000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?ooof80oooo
00P000000?ooo`3oool000000?ooo`000000oooo000001/0oooo00<000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`07
0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooool0
ooooJ`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000@0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool0
0?l0ooooo`3ooooo0?ooog@0oooo00L000000?ooo`000000oooo0000003oool0000000X0oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?ooogd0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0oooo
o`3ooooo0?oooh<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo0?oooh`0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00`000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00
o`3ooooo0?ooool0ooooU@3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool0
30000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooool0
ooooW@3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`00
00030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00070?ooo`00o`3ooooo0?ooool0ooooYP3oool01@000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0
ooooo`3ooooo0?ooojl0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool00000
0`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000L0oooo
003o0?ooool0ooooo`3ooong0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooool0oooo`03o
ool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000L0oooo003o0?ooool0ooooo`3o
ooo90?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo
0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3o
ool00?l0ooooo`3ooooo0?oooll0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000070?ooo`00o`3ooooo0?ooool0oooof03oool01@000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0ooooo`3ooooo
0?ooon40oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooool0oooojP3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1`3oool00?l0ooooo`3ooooo0?oooo80oooo00<000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000L0oooo003o0?oo
ool0ooooo`3ooook0?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000070?ooo`00o`3ooooo0?ooool0ooooo`3oool50?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00070?ooo`00o`3ooooo0?ooool0ooooo`3oool=0?ooo`0<0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000070?ooo`00o`3ooooo0?ooool0ooooo`3ooolF0?ooo`030000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00001`3oool00?l0ooooo`3ooooo0?ooool0oooo7`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000L0oooo003o0?ooool0ooooo`3ooooo0?ooobD0oooo00`000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000L0oooo003o
0?ooool0ooooo`3ooooo0?ooobh0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000007
0?ooo`00o`3ooooo0?ooool0ooooo`3ooolg0?ooo`060000003oool000000?ooo`000000oooo2000
0000103oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000L0oooo003o0?ooool0ooooo`3ooooo0?oood00oooo0`0000001P3oool000000?ooo`000000
oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001`3oool00?l0
ooooo`3ooooo0?ooool0oooo@@3oool00`000000oooo0?ooo`040?ooo`0<0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000001`3oool00?l0ooooo`3ooooo0?ooool0oooo
@@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000L0oooo003o0?ooool0ooooo`3o
oooo0?oood40oooo00<000000?ooo`3oool03`3oool800000000o`3ooooo0?ooool0ooooo`3ooom1
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooooo0?oo
ool0oooo@@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo003o0?ooool0
ooooo`3ooooo0?ooocl0oooo0`00000A0?ooo`030000003oool0oooo00D0oooo003o0?ooool0oooo
o`3ooooo0?oood40oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`00o`3o
oooo0?ooool0ooooo`3ooomC0?ooo`030000003oool0oooo00D0oooo003o0?ooool0ooooo`3ooooo
0?oooe<0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooooo0?ooool0ooooD`3oool00`00
0000oooo0?ooo`050?ooo`00o`3ooooo0?ooool0ooooo`3ooomC0?ooo`030000003oool0oooo00D0
oooo003o0?ooool0ooooo`3ooooo0?oooe<0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3o
oooo0?ooool0ooooD`3oool00`000000oooo0?ooo`050?ooo`00o`3ooooo0?ooool0ooooo`3ooomC
0?ooo`030000003oool0oooo00D0oooo003o0?ooool0ooooo`3ooooo0?oooe<0oooo00<000000?oo
o`3oool01@3oool00?l0ooooo`3ooooo0?ooool0ooooD`3oool00`000000oooo0?ooo`050?ooo`00
o`3ooooo0?ooool0ooooo`3ooomC0?ooo`030000003oool0oooo00D0oooo003o0?ooool0ooooo`3o
oooo0?oooe<0oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooooo0?ooool0ooooD`3oool0
0`000000oooo0?ooo`050?ooo`00\
\>"],
  ImageRangeCache->{{{0, 1110.56}, {686, 0}} -> {0.797522, -0.0431441, \
0.000275169, 0.00233747}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BifuractionDiagram[\ HatMap[r], \ {r, 0, 1}];\)\)], "Input",
  CellLabel->"In[50]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.0147151 0.589963 [
[.2 .00222 -9 -9 ]
[.2 .00222 9 0 ]
[.4 .00222 -9 -9 ]
[.4 .00222 9 0 ]
[.6 .00222 -9 -9 ]
[.6 .00222 9 0 ]
[.8 .00222 -9 -9 ]
[.8 .00222 9 0 ]
[1 .00222 -3 -9 ]
[1 .00222 3 0 ]
[-0.0125 .13271 -18 -4.5 ]
[-0.0125 .13271 0 4.5 ]
[-0.0125 .2507 -18 -4.5 ]
[-0.0125 .2507 0 4.5 ]
[-0.0125 .36869 -18 -4.5 ]
[-0.0125 .36869 0 4.5 ]
[-0.0125 .48669 -18 -4.5 ]
[-0.0125 .48669 0 4.5 ]
[-0.0125 .60468 -6 -4.5 ]
[-0.0125 .60468 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .01472 m
.2 .02097 L
s
[(0.2)] .2 .00222 0 1 Mshowa
.4 .01472 m
.4 .02097 L
s
[(0.4)] .4 .00222 0 1 Mshowa
.6 .01472 m
.6 .02097 L
s
[(0.6)] .6 .00222 0 1 Mshowa
.8 .01472 m
.8 .02097 L
s
[(0.8)] .8 .00222 0 1 Mshowa
1 .01472 m
1 .02097 L
s
[(1)] 1 .00222 0 1 Mshowa
.125 Mabswid
.05 .01472 m
.05 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.15 .01472 m
.15 .01847 L
s
.25 .01472 m
.25 .01847 L
s
.3 .01472 m
.3 .01847 L
s
.35 .01472 m
.35 .01847 L
s
.45 .01472 m
.45 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.55 .01472 m
.55 .01847 L
s
.65 .01472 m
.65 .01847 L
s
.7 .01472 m
.7 .01847 L
s
.75 .01472 m
.75 .01847 L
s
.85 .01472 m
.85 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.95 .01472 m
.95 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
0 .13271 m
.00625 .13271 L
s
[(0.2)] -0.0125 .13271 1 0 Mshowa
0 .2507 m
.00625 .2507 L
s
[(0.4)] -0.0125 .2507 1 0 Mshowa
0 .36869 m
.00625 .36869 L
s
[(0.6)] -0.0125 .36869 1 0 Mshowa
0 .48669 m
.00625 .48669 L
s
[(0.8)] -0.0125 .48669 1 0 Mshowa
0 .60468 m
.00625 .60468 L
s
[(1)] -0.0125 .60468 1 0 Mshowa
.125 Mabswid
0 .04421 m
.00375 .04421 L
s
0 .07371 m
.00375 .07371 L
s
0 .10321 m
.00375 .10321 L
s
0 .16221 m
.00375 .16221 L
s
0 .1917 m
.00375 .1917 L
s
0 .2212 m
.00375 .2212 L
s
0 .2802 m
.00375 .2802 L
s
0 .3097 m
.00375 .3097 L
s
0 .33919 m
.00375 .33919 L
s
0 .39819 m
.00375 .39819 L
s
0 .42769 m
.00375 .42769 L
s
0 .45719 m
.00375 .45719 L
s
0 .51618 m
.00375 .51618 L
s
0 .54568 m
.00375 .54568 L
s
0 .57518 m
.00375 .57518 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
0 .01472 Mdot
.002 .01472 Mdot
.004 .01472 Mdot
.006 .01472 Mdot
.008 .01472 Mdot
.01 .01472 Mdot
.012 .01472 Mdot
.014 .01472 Mdot
.016 .01472 Mdot
.018 .01472 Mdot
.02 .01472 Mdot
.022 .01472 Mdot
.024 .01472 Mdot
.026 .01472 Mdot
.028 .01472 Mdot
.03 .01472 Mdot
.032 .01472 Mdot
.034 .01472 Mdot
.036 .01472 Mdot
.038 .01472 Mdot
.04 .01472 Mdot
.042 .01472 Mdot
.044 .01472 Mdot
.046 .01472 Mdot
.048 .01472 Mdot
.05 .01472 Mdot
.052 .01472 Mdot
.054 .01472 Mdot
.056 .01472 Mdot
.058 .01472 Mdot
.06 .01472 Mdot
.062 .01472 Mdot
.064 .01472 Mdot
.066 .01472 Mdot
.068 .01472 Mdot
.07 .01472 Mdot
.072 .01472 Mdot
.074 .01472 Mdot
.076 .01472 Mdot
.078 .01472 Mdot
.08 .01472 Mdot
.082 .01472 Mdot
.084 .01472 Mdot
.086 .01472 Mdot
.088 .01472 Mdot
.09 .01472 Mdot
.092 .01472 Mdot
.094 .01472 Mdot
.096 .01472 Mdot
.098 .01472 Mdot
.1 .01472 Mdot
.102 .01472 Mdot
.104 .01472 Mdot
.106 .01472 Mdot
.108 .01472 Mdot
.11 .01472 Mdot
.112 .01472 Mdot
.114 .01472 Mdot
.116 .01472 Mdot
.118 .01472 Mdot
.12 .01472 Mdot
.122 .01472 Mdot
.124 .01472 Mdot
.126 .01472 Mdot
.128 .01472 Mdot
.13 .01472 Mdot
.132 .01472 Mdot
.134 .01472 Mdot
.136 .01472 Mdot
.138 .01472 Mdot
.14 .01472 Mdot
.142 .01472 Mdot
.144 .01472 Mdot
.146 .01472 Mdot
.148 .01472 Mdot
.15 .01472 Mdot
.152 .01472 Mdot
.154 .01472 Mdot
.156 .01472 Mdot
.158 .01472 Mdot
.16 .01472 Mdot
.162 .01472 Mdot
.164 .01472 Mdot
.166 .01472 Mdot
.168 .01472 Mdot
.17 .01472 Mdot
.172 .01472 Mdot
.174 .01472 Mdot
.176 .01472 Mdot
.178 .01472 Mdot
.18 .01472 Mdot
.182 .01472 Mdot
.184 .01472 Mdot
.186 .01472 Mdot
.188 .01472 Mdot
.19 .01472 Mdot
.192 .01472 Mdot
.194 .01472 Mdot
.196 .01472 Mdot
.198 .01472 Mdot
.2 .01472 Mdot
.202 .01472 Mdot
.204 .01472 Mdot
.206 .01472 Mdot
.208 .01472 Mdot
.21 .01472 Mdot
.212 .01472 Mdot
.214 .01472 Mdot
.216 .01472 Mdot
.218 .01472 Mdot
.22 .01472 Mdot
.222 .01472 Mdot
.224 .01472 Mdot
.226 .01472 Mdot
.228 .01472 Mdot
.23 .01472 Mdot
.232 .01472 Mdot
.234 .01472 Mdot
.236 .01472 Mdot
.238 .01472 Mdot
.24 .01472 Mdot
.242 .01472 Mdot
.244 .01472 Mdot
.246 .01472 Mdot
.248 .01472 Mdot
.25 .01472 Mdot
.252 .01472 Mdot
.254 .01472 Mdot
.256 .01472 Mdot
.258 .01472 Mdot
.26 .01472 Mdot
.262 .01472 Mdot
.264 .01472 Mdot
.266 .01472 Mdot
.268 .01472 Mdot
.27 .01472 Mdot
.272 .01472 Mdot
.274 .01472 Mdot
.276 .01472 Mdot
.278 .01472 Mdot
.28 .01472 Mdot
.282 .01472 Mdot
.284 .01472 Mdot
.286 .01472 Mdot
.288 .01472 Mdot
.29 .01472 Mdot
.292 .01472 Mdot
.294 .01472 Mdot
.296 .01472 Mdot
.298 .01472 Mdot
.3 .01472 Mdot
.302 .01472 Mdot
.304 .01472 Mdot
.306 .01472 Mdot
.308 .01472 Mdot
.31 .01472 Mdot
.312 .01472 Mdot
.314 .01472 Mdot
.316 .01472 Mdot
.318 .01472 Mdot
.32 .01472 Mdot
.322 .01472 Mdot
.324 .01472 Mdot
.326 .01472 Mdot
.328 .01472 Mdot
.33 .01472 Mdot
.332 .01472 Mdot
.334 .01472 Mdot
.336 .01472 Mdot
.338 .01472 Mdot
.34 .01472 Mdot
.342 .01472 Mdot
.344 .01472 Mdot
.346 .01472 Mdot
.348 .01472 Mdot
.35 .01472 Mdot
.352 .01472 Mdot
.354 .01472 Mdot
.356 .01472 Mdot
.358 .01472 Mdot
.36 .01472 Mdot
.362 .01472 Mdot
.364 .01472 Mdot
.366 .01472 Mdot
.368 .01472 Mdot
.37 .01472 Mdot
.372 .01472 Mdot
.374 .01472 Mdot
.376 .01472 Mdot
.378 .01472 Mdot
.38 .01472 Mdot
.382 .01472 Mdot
.384 .01472 Mdot
.386 .01472 Mdot
.388 .01472 Mdot
.39 .01472 Mdot
.392 .01472 Mdot
.394 .01472 Mdot
.396 .01472 Mdot
.398 .01472 Mdot
.4 .01472 Mdot
.402 .01472 Mdot
.404 .01472 Mdot
.406 .01472 Mdot
.408 .01472 Mdot
.41 .01472 Mdot
.412 .01472 Mdot
.414 .01472 Mdot
.416 .01472 Mdot
.418 .01472 Mdot
.42 .01472 Mdot
.422 .01472 Mdot
.424 .01472 Mdot
.426 .01472 Mdot
.428 .01472 Mdot
.43 .01472 Mdot
.432 .01472 Mdot
.434 .01472 Mdot
.436 .01472 Mdot
.438 .01472 Mdot
.44 .01472 Mdot
.442 .01472 Mdot
.444 .01472 Mdot
.446 .01472 Mdot
.448 .01472 Mdot
.45 .01472 Mdot
.452 .01472 Mdot
.454 .01472 Mdot
.456 .01472 Mdot
.458 .01472 Mdot
.46 .01472 Mdot
.462 .01472 Mdot
.464 .01472 Mdot
.466 .01472 Mdot
.468 .01472 Mdot
.47 .01472 Mdot
.472 .01472 Mdot
.474 .01472 Mdot
.476 .01472 Mdot
.478 .01472 Mdot
.48 .01472 Mdot
.482 .01472 Mdot
.484 .01472 Mdot
.486 .01472 Mdot
.488 .01472 Mdot
.49 .01472 Mdot
.492 .01472 Mdot
.494 .01472 Mdot
.496 .01472 Mdot
.498 .01472 Mdot
.5 .20251 Mdot
.502 .30969 Mdot
.502 .30969 Mdot
.502 .30969 Mdot
.502 .30969 Mdot
.502 .30969 Mdot
.502 .3097 Mdot
.502 .3097 Mdot
.502 .3097 Mdot
.502 .3097 Mdot
.502 .31087 Mdot
.502 .31087 Mdot
.502 .31087 Mdot
.502 .31087 Mdot
.502 .31087 Mdot
.502 .31088 Mdot
.502 .31088 Mdot
.502 .31088 Mdot
.502 .31088 Mdot
.502 .31088 Mdot
.502 .31088 Mdot
.504 .30968 Mdot
.504 .30968 Mdot
.504 .30968 Mdot
.504 .30968 Mdot
.504 .30968 Mdot
.504 .30968 Mdot
.504 .30968 Mdot
.504 .30968 Mdot
.504 .30968 Mdot
.504 .30968 Mdot
.504 .30968 Mdot
.504 .30968 Mdot
.504 .30968 Mdot
.504 .30968 Mdot
.504 .3097 Mdot
.504 .3097 Mdot
.504 .3097 Mdot
.504 .3097 Mdot
.504 .3097 Mdot
.504 .3097 Mdot
.504 .3097 Mdot
.504 .3097 Mdot
.504 .3097 Mdot
.504 .3097 Mdot
.504 .3097 Mdot
.504 .3097 Mdot
.504 .3097 Mdot
.504 .3097 Mdot
.504 .31204 Mdot
.504 .31204 Mdot
.504 .31204 Mdot
.504 .31204 Mdot
.504 .31204 Mdot
.504 .31204 Mdot
.504 .31204 Mdot
.504 .31204 Mdot
.504 .31204 Mdot
.504 .31204 Mdot
.504 .31204 Mdot
.504 .31204 Mdot
.504 .31204 Mdot
.504 .31204 Mdot
.504 .31204 Mdot
.504 .31206 Mdot
.504 .31206 Mdot
.504 .31206 Mdot
.504 .31206 Mdot
.504 .31206 Mdot
.504 .31206 Mdot
.504 .31206 Mdot
.504 .31206 Mdot
.504 .31206 Mdot
.504 .31206 Mdot
.504 .31206 Mdot
.504 .31206 Mdot
.504 .31206 Mdot
.504 .31206 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30965 Mdot
.506 .30966 Mdot
.506 .30966 Mdot
.506 .30966 Mdot
.506 .30966 Mdot
.506 .30966 Mdot
.506 .30966 Mdot
.506 .30966 Mdot
.506 .30966 Mdot
.506 .30966 Mdot
.506 .30966 Mdot
.506 .30966 Mdot
.506 .30966 Mdot
.506 .30966 Mdot
.506 .30966 Mdot
.506 .30966 Mdot
.506 .30966 Mdot
.506 .30966 Mdot
.506 .30966 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .3097 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31319 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.506 .31324 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .30962 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .3097 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31434 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31441 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.508 .31442 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .30958 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .3097 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31548 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .31559 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.51 .3156 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30953 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .30954 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3097 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .3166 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31661 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31677 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.512 .31678 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30947 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30948 Mdot
.514 .30969 Mdot
.514 .30969 Mdot
.514 .30969 Mdot
.514 .30969 Mdot
.514 .30969 Mdot
.514 .30969 Mdot
.514 .30969 Mdot
.514 .30969 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .3097 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .30971 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31772 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31773 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31794 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31795 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.514 .31796 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .30939 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .3094 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30941 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30942 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .30969 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .3097 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30971 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .30972 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31882 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31883 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31884 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31885 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31912 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31913 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.516 .31914 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30931 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30932 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30934 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .30969 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .3097 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .30972 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31992 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .31995 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32029 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32031 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.518 .32032 Mdot
.52 .30922 Mdot
.52 .30922 Mdot
.52 .30922 Mdot
.52 .30922 Mdot
.52 .30922 Mdot
.52 .30922 Mdot
.52 .30922 Mdot
.52 .30922 Mdot
.52 .30922 Mdot
.52 .30922 Mdot
.52 .30922 Mdot
.52 .30922 Mdot
.52 .30922 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30923 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30926 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30927 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .30969 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .3097 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .30973 Mdot
.52 .321 Mdot
.52 .321 Mdot
.52 .321 Mdot
.52 .321 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32101 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32104 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32105 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32146 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .32149 Mdot
.52 .3215 Mdot
.52 .3215 Mdot
.52 .3215 Mdot
.52 .3215 Mdot
.52 .3215 Mdot
.52 .3215 Mdot
.52 .3215 Mdot
.52 .3215 Mdot
.52 .3215 Mdot
.52 .3215 Mdot
.52 .3215 Mdot
.52 .3215 Mdot
.52 .3215 Mdot
.52 .3215 Mdot
.52 .3215 Mdot
.52 .3215 Mdot
.52 .3215 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30913 Mdot
.522 .30914 Mdot
.522 .30914 Mdot
.522 .30914 Mdot
.522 .30914 Mdot
.522 .30914 Mdot
.522 .30914 Mdot
.522 .30914 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30917 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30918 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .30969 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .3097 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30974 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .30975 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32208 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32209 Mdot
.522 .32212 Mdot
.522 .32212 Mdot
.522 .32212 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32213 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32214 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32262 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32263 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32267 Mdot
.522 .32268 Mdot
.522 .32268 Mdot
.522 .32268 Mdot
.522 .32268 Mdot
.522 .32268 Mdot
.522 .32268 Mdot
.522 .32268 Mdot
.522 .32268 Mdot
.522 .32268 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30902 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30903 Mdot
.524 .30907 Mdot
.524 .30907 Mdot
.524 .30907 Mdot
.524 .30907 Mdot
.524 .30907 Mdot
.524 .30907 Mdot
.524 .30907 Mdot
.524 .30907 Mdot
.524 .30907 Mdot
.524 .30907 Mdot
.524 .30907 Mdot
.524 .30907 Mdot
.524 .30907 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30908 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30909 Mdot
.524 .30968 Mdot
.524 .30968 Mdot
.524 .30968 Mdot
.524 .30968 Mdot
.524 .30968 Mdot
.524 .30968 Mdot
.524 .30968 Mdot
.524 .30968 Mdot
.524 .30968 Mdot
.524 .30968 Mdot
.524 .30968 Mdot
.524 .30968 Mdot
.524 .30968 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .30969 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .3097 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30975 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .30976 Mdot
.524 .32314 Mdot
.524 .32314 Mdot
.524 .32314 Mdot
.524 .32314 Mdot
.524 .32314 Mdot
.524 .32314 Mdot
.524 .32314 Mdot
.524 .32314 Mdot
.524 .32314 Mdot
.524 .32314 Mdot
.524 .32314 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32315 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .32316 Mdot
.524 .3232 Mdot
.524 .3232 Mdot
.524 .3232 Mdot
.524 .3232 Mdot
.524 .3232 Mdot
.524 .3232 Mdot
.524 .3232 Mdot
.524 .3232 Mdot
.524 .3232 Mdot
.524 .3232 Mdot
.524 .3232 Mdot
.524 .3232 Mdot
.524 .3232 Mdot
.524 .3232 Mdot
.524 .3232 Mdot
.524 .3232 Mdot
.524 .3232 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32321 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32322 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .32379 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .3238 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32384 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32385 Mdot
.524 .32386 Mdot
.524 .32386 Mdot
.524 .32386 Mdot
.524 .32386 Mdot
.524 .32386 Mdot
.524 .32386 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .3089 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30891 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30892 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30897 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30898 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30899 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30968 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .30969 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .3097 Mdot
.526 .30971 Mdot
.526 .30971 Mdot
.526 .30971 Mdot
.526 .30971 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30976 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30977 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .30978 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .3242 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32421 Mdot
.526 .32422 Mdot
.526 .32422 Mdot
.526 .32422 Mdot
.526 .32422 Mdot
.526 .32422 Mdot
.526 .32422 Mdot
.526 .32422 Mdot
.526 .32422 Mdot
.526 .32422 Mdot
.526 .32422 Mdot
.526 .32422 Mdot
.526 .32422 Mdot
.526 .32422 Mdot
.526 .32422 Mdot
.526 .32422 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32427 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32428 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .32429 Mdot
.526 .3243 Mdot
.526 .3243 Mdot
.526 .3243 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32495 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32496 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32497 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32502 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32503 Mdot
.526 .32504 Mdot
.526 .32504 Mdot
.526 .32504 Mdot
.526 .32504 Mdot
.528 .30877 Mdot
.528 .30877 Mdot
.528 .30877 Mdot
.528 .30877 Mdot
.528 .30877 Mdot
.528 .30877 Mdot
.528 .30877 Mdot
.528 .30877 Mdot
.528 .30877 Mdot
.528 .30877 Mdot
.528 .30877 Mdot
.528 .30877 Mdot
.528 .30877 Mdot
.528 .30877 Mdot
.528 .30877 Mdot
.528 .30877 Mdot
.528 .30877 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30878 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .30879 Mdot
.528 .3088 Mdot
.528 .3088 Mdot
.528 .3088 Mdot
.528 .3088 Mdot
.528 .3088 Mdot
.528 .3088 Mdot
.528 .3088 Mdot
.528 .3088 Mdot
.528 .3088 Mdot
.528 .3088 Mdot
.528 .3088 Mdot
.528 .3088 Mdot
.528 .3088 Mdot
.528 .3088 Mdot
.528 .3088 Mdot
.528 .3088 Mdot
.528 .30885 Mdot
.528 .30885 Mdot
.528 .30885 Mdot
.528 .30885 Mdot
.528 .30885 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30886 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30887 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30888 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30889 Mdot
.528 .30967 Mdot
.528 .30967 Mdot
.528 .30967 Mdot
.528 .30967 Mdot
.528 .30967 Mdot
.528 .30967 Mdot
.528 .30967 Mdot
.528 .30967 Mdot
.528 .30967 Mdot
.528 .30967 Mdot
.528 .30967 Mdot
.528 .30967 Mdot
.528 .30967 Mdot
.528 .30967 Mdot
.528 .30967 Mdot
.528 .30967 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30968 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .30969 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .3097 Mdot
.528 .30971 Mdot
.528 .30971 Mdot
.528 .30971 Mdot
.528 .30971 Mdot
.528 .30971 Mdot
.528 .30971 Mdot
.528 .30971 Mdot
.528 .30971 Mdot
.528 .30971 Mdot
.528 .30971 Mdot
.528 .30971 Mdot
.528 .30971 Mdot
.528 .30971 Mdot
.528 .30977 Mdot
.528 .30977 Mdot
.528 .30977 Mdot
.528 .30977 Mdot
.528 .30977 Mdot
.528 .30977 Mdot
.528 .30977 Mdot
.528 .30977 Mdot
.528 .30977 Mdot
.528 .30977 Mdot
.528 .30977 Mdot
.528 .30977 Mdot
.528 .30977 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30978 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .30979 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .3098 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32524 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32525 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32526 Mdot
.528 .32527 Mdot
.528 .32527 Mdot
.528 .32527 Mdot
.528 .32527 Mdot
.528 .32527 Mdot
.528 .32527 Mdot
.528 .32527 Mdot
.528 .32527 Mdot
.528 .32527 Mdot
.528 .32527 Mdot
.528 .32527 Mdot
.528 .32527 Mdot
.528 .32527 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32533 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32534 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32535 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .32536 Mdot
.528 .3261 Mdot
.528 .3261 Mdot
.528 .3261 Mdot
.528 .3261 Mdot
.528 .3261 Mdot
.528 .3261 Mdot
.528 .3261 Mdot
.528 .3261 Mdot
.528 .3261 Mdot
.528 .3261 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32611 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32612 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32613 Mdot
.528 .32614 Mdot
.528 .32614 Mdot
.528 .32614 Mdot
.528 .32614 Mdot
.528 .32614 Mdot
.528 .32614 Mdot
.528 .32614 Mdot
.528 .32614 Mdot
.528 .32614 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .32619 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .3262 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32621 Mdot
.528 .32622 Mdot
.528 .32622 Mdot
.528 .32622 Mdot
.528 .32622 Mdot
.528 .32622 Mdot
.53 .30863 Mdot
.53 .30863 Mdot
.53 .30863 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30864 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30865 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30866 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30867 Mdot
.53 .30873 Mdot
.53 .30873 Mdot
.53 .30873 Mdot
.53 .30873 Mdot
.53 .30873 Mdot
.53 .30873 Mdot
.53 .30874 Mdot
.53 .30874 Mdot
.53 .30874 Mdot
.53 .30874 Mdot
.53 .30874 Mdot
.53 .30874 Mdot
.53 .30874 Mdot
.53 .30874 Mdot
.53 .30874 Mdot
.53 .30874 Mdot
.53 .30874 Mdot
.53 .30874 Mdot
.53 .30874 Mdot
.53 .30874 Mdot
.53 .30874 Mdot
.53 .30874 Mdot
.53 .30874 Mdot
.53 .30874 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30875 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30876 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30877 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30878 Mdot
.53 .30966 Mdot
.53 .30966 Mdot
.53 .30966 Mdot
.53 .30966 Mdot
.53 .30966 Mdot
.53 .30966 Mdot
.53 .30966 Mdot
.53 .30966 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30967 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30968 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .30969 Mdot
.53 .3097 Mdot
.53 .3097 Mdot
.53 .3097 Mdot
.53 .3097 Mdot
.53 .3097 Mdot
.53 .3097 Mdot
.53 .3097 Mdot
.53 .3097 Mdot
.53 .3097 Mdot
.53 .3097 Mdot
.53 .3097 Mdot
.53 .3097 Mdot
.53 .3097 Mdot
.53 .3097 Mdot
.53 .3097 Mdot
.53 .3097 Mdot
.53 .3097 Mdot
.53 .30971 Mdot
.53 .30971 Mdot
.53 .30971 Mdot
.53 .30971 Mdot
.53 .30971 Mdot
.53 .30971 Mdot
.53 .30971 Mdot
.53 .30971 Mdot
.53 .30971 Mdot
.53 .30971 Mdot
.53 .30971 Mdot
.53 .30971 Mdot
.53 .30971 Mdot
.53 .30971 Mdot
.53 .30971 Mdot
.53 .30971 Mdot
.53 .30972 Mdot
.53 .30972 Mdot
.53 .30972 Mdot
.53 .30972 Mdot
.53 .30972 Mdot
.53 .30978 Mdot
.53 .30978 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .30979 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .3098 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30981 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30982 Mdot
.53 .30983 Mdot
.53 .30983 Mdot
.53 .30983 Mdot
.53 .30983 Mdot
.53 .30983 Mdot
.53 .30983 Mdot
.53 .30983 Mdot
.53 .30983 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32627 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32628 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .32629 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .3263 Mdot
.53 .32631 Mdot
.53 .32631 Mdot
.53 .32631 Mdot
.53 .32631 Mdot
.53 .32631 Mdot
.53 .32631 Mdot
.53 .32631 Mdot
.53 .32631 Mdot
.53 .32631 Mdot
.53 .32631 Mdot
.53 .32631 Mdot
.53 .32637 Mdot
.53 .32637 Mdot
.53 .32638 Mdot
.53 .32638 Mdot
.53 .32638 Mdot
.53 .32638 Mdot
.53 .32638 Mdot
.53 .32638 Mdot
.53 .32638 Mdot
.53 .32638 Mdot
.53 .32638 Mdot
.53 .32638 Mdot
.53 .32638 Mdot
.53 .32638 Mdot
.53 .32638 Mdot
.53 .32638 Mdot
.53 .32638 Mdot
.53 .32638 Mdot
.53 .32638 Mdot
.53 .32638 Mdot
.53 .32638 Mdot
.53 .32639 Mdot
.53 .32639 Mdot
.53 .32639 Mdot
.53 .32639 Mdot
.53 .32639 Mdot
.53 .32639 Mdot
.53 .32639 Mdot
.53 .32639 Mdot
.53 .32639 Mdot
.53 .32639 Mdot
.53 .32639 Mdot
.53 .32639 Mdot
.53 .32639 Mdot
.53 .32639 Mdot
.53 .32639 Mdot
.53 .32639 Mdot
.53 .32639 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .3264 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32641 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32642 Mdot
.53 .32643 Mdot
.53 .32643 Mdot
.53 .32643 Mdot
.53 .32643 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32726 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32727 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32728 Mdot
.53 .32729 Mdot
.53 .32729 Mdot
.53 .32729 Mdot
.53 .32729 Mdot
.53 .32729 Mdot
.53 .32729 Mdot
.53 .32729 Mdot
.53 .32729 Mdot
.53 .32729 Mdot
.53 .32729 Mdot
.53 .32729 Mdot
.53 .32729 Mdot
.53 .32729 Mdot
.53 .32729 Mdot
.53 .32729 Mdot
.53 .32729 Mdot
.53 .32729 Mdot
.53 .32729 Mdot
.53 .3273 Mdot
.53 .3273 Mdot
.53 .3273 Mdot
.53 .3273 Mdot
.53 .3273 Mdot
.53 .3273 Mdot
.53 .3273 Mdot
.53 .3273 Mdot
.53 .3273 Mdot
.53 .3273 Mdot
.53 .3273 Mdot
.53 .3273 Mdot
.53 .3273 Mdot
.53 .3273 Mdot
.53 .3273 Mdot
.53 .3273 Mdot
.53 .32736 Mdot
.53 .32736 Mdot
.53 .32736 Mdot
.53 .32736 Mdot
.53 .32736 Mdot
.53 .32736 Mdot
.53 .32736 Mdot
.53 .32736 Mdot
.53 .32736 Mdot
.53 .32736 Mdot
.53 .32736 Mdot
.53 .32736 Mdot
.53 .32736 Mdot
.53 .32736 Mdot
.53 .32736 Mdot
.53 .32736 Mdot
.53 .32736 Mdot
.53 .32736 Mdot
.53 .32736 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32737 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32738 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .32739 Mdot
.53 .3274 Mdot
.53 .3274 Mdot
.532 .30849 Mdot
.532 .30849 Mdot
.532 .30849 Mdot
.532 .30849 Mdot
.532 .30849 Mdot
.532 .30849 Mdot
.532 .30849 Mdot
.532 .30849 Mdot
.532 .30849 Mdot
.532 .30849 Mdot
.532 .30849 Mdot
.532 .30849 Mdot
.532 .30849 Mdot
.532 .30849 Mdot
.532 .30849 Mdot
.532 .30849 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .3085 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30851 Mdot
.532 .30852 Mdot
.532 .30852 Mdot
.532 .30852 Mdot
.532 .30852 Mdot
.532 .30852 Mdot
.532 .30852 Mdot
.532 .30852 Mdot
.532 .30852 Mdot
.532 .30852 Mdot
.532 .30852 Mdot
.532 .30852 Mdot
.532 .30852 Mdot
.532 .30852 Mdot
.532 .30852 Mdot
.532 .30852 Mdot
.532 .30852 Mdot
.532 .30852 Mdot
.532 .30852 Mdot
.532 .30852 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30853 Mdot
.532 .30854 Mdot
.532 .30854 Mdot
.532 .30861 Mdot
.532 .30861 Mdot
.532 .30861 Mdot
.532 .30861 Mdot
.532 .30861 Mdot
.532 .30861 Mdot
.532 .30861 Mdot
.532 .30861 Mdot
.532 .30861 Mdot
.532 .30861 Mdot
.532 .30862 Mdot
.532 .30862 Mdot
.532 .30862 Mdot
.532 .30862 Mdot
.532 .30862 Mdot
.532 .30862 Mdot
.532 .30862 Mdot
.532 .30862 Mdot
.532 .30862 Mdot
.532 .30862 Mdot
.532 .30862 Mdot
.532 .30862 Mdot
.532 .30862 Mdot
.532 .30862 Mdot
.532 .30862 Mdot
.532 .30862 Mdot
.532 .30862 Mdot
.532 .30862 Mdot
.532 .30863 Mdot
.532 .30863 Mdot
.532 .30863 Mdot
.532 .30863 Mdot
.532 .30863 Mdot
.532 .30863 Mdot
.532 .30863 Mdot
.532 .30863 Mdot
.532 .30863 Mdot
.532 .30863 Mdot
.532 .30863 Mdot
.532 .30863 Mdot
.532 .30863 Mdot
.532 .30863 Mdot
.532 .30863 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30864 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30865 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30866 Mdot
.532 .30867 Mdot
.532 .30867 Mdot
.532 .30867 Mdot
.532 .30867 Mdot
.532 .30867 Mdot
.532 .30965 Mdot
.532 .30965 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30966 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30967 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30968 Mdot
.532 .30969 Mdot
.532 .30969 Mdot
.532 .30969 Mdot
.532 .30969 Mdot
.532 .30969 Mdot
.532 .30969 Mdot
.532 .30969 Mdot
.532 .30969 Mdot
.532 .30969 Mdot
.532 .30969 Mdot
.532 .30969 Mdot
.532 .30969 Mdot
.532 .30969 Mdot
.532 .30969 Mdot
.532 .30969 Mdot
.532 .30969 Mdot
.532 .30969 Mdot
.532 .30969 Mdot
.532 .30969 Mdot
.532 .3097 Mdot
.532 .3097 Mdot
.532 .3097 Mdot
.532 .3097 Mdot
.532 .3097 Mdot
.532 .3097 Mdot
.532 .3097 Mdot
.532 .3097 Mdot
.532 .3097 Mdot
.532 .3097 Mdot
.532 .3097 Mdot
.532 .3097 Mdot
.532 .3097 Mdot
.532 .30971 Mdot
.532 .30971 Mdot
.532 .30971 Mdot
.532 .30971 Mdot
.532 .30971 Mdot
.532 .30971 Mdot
.532 .30971 Mdot
.532 .30971 Mdot
.532 .30971 Mdot
.532 .30971 Mdot
.532 .30971 Mdot
.532 .30971 Mdot
.532 .30971 Mdot
.532 .30971 Mdot
.532 .30972 Mdot
.532 .30972 Mdot
.532 .30972 Mdot
.532 .30972 Mdot
.532 .30972 Mdot
.532 .30972 Mdot
.532 .30972 Mdot
.532 .3098 Mdot
.532 .3098 Mdot
.532 .3098 Mdot
.532 .3098 Mdot
.532 .3098 Mdot
.532 .30981 Mdot
.532 .30981 Mdot
.532 .30981 Mdot
.532 .30981 Mdot
.532 .30981 Mdot
.532 .30981 Mdot
.532 .30981 Mdot
.532 .30981 Mdot
.532 .30981 Mdot
.532 .30981 Mdot
.532 .30981 Mdot
.532 .30981 Mdot
.532 .30981 Mdot
.532 .30981 Mdot
.532 .30981 Mdot
.532 .30981 Mdot
.532 .30981 Mdot
.532 .30981 Mdot
.532 .30981 Mdot
.532 .30982 Mdot
.532 .30982 Mdot
.532 .30982 Mdot
.532 .30982 Mdot
.532 .30982 Mdot
.532 .30982 Mdot
.532 .30982 Mdot
.532 .30982 Mdot
.532 .30982 Mdot
.532 .30982 Mdot
.532 .30982 Mdot
.532 .30982 Mdot
.532 .30982 Mdot
.532 .30982 Mdot
.532 .30982 Mdot
.532 .30982 Mdot
.532 .30982 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30983 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30984 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .30985 Mdot
.532 .32729 Mdot
.532 .32729 Mdot
.532 .32729 Mdot
.532 .32729 Mdot
.532 .32729 Mdot
.532 .32729 Mdot
.532 .32729 Mdot
.532 .32729 Mdot
.532 .32729 Mdot
.532 .32729 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .3273 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32731 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32732 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32733 Mdot
.532 .32734 Mdot
.532 .32734 Mdot
.532 .32734 Mdot
.532 .32734 Mdot
.532 .32734 Mdot
.532 .32734 Mdot
.532 .32734 Mdot
.532 .32734 Mdot
.532 .32734 Mdot
.532 .32734 Mdot
.532 .32742 Mdot
.532 .32742 Mdot
.532 .32742 Mdot
.532 .32742 Mdot
.532 .32742 Mdot
.532 .32742 Mdot
.532 .32742 Mdot
.532 .32742 Mdot
.532 .32742 Mdot
.532 .32742 Mdot
.532 .32742 Mdot
.532 .32743 Mdot
.532 .32743 Mdot
.532 .32743 Mdot
.532 .32743 Mdot
.532 .32743 Mdot
.532 .32743 Mdot
.532 .32743 Mdot
.532 .32743 Mdot
.532 .32743 Mdot
.532 .32743 Mdot
.532 .32743 Mdot
.532 .32743 Mdot
.532 .32743 Mdot
.532 .32743 Mdot
.532 .32743 Mdot
.532 .32743 Mdot
.532 .32744 Mdot
.532 .32744 Mdot
.532 .32744 Mdot
.532 .32744 Mdot
.532 .32744 Mdot
.532 .32744 Mdot
.532 .32744 Mdot
.532 .32744 Mdot
.532 .32744 Mdot
.532 .32744 Mdot
.532 .32744 Mdot
.532 .32744 Mdot
.532 .32744 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32745 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32746 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32747 Mdot
.532 .32748 Mdot
.532 .32748 Mdot
.532 .32748 Mdot
.532 .32748 Mdot
.532 .32748 Mdot
.532 .32748 Mdot
.532 .32748 Mdot
.532 .32748 Mdot
.532 .32748 Mdot
.532 .32748 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32841 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32842 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32843 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32844 Mdot
.532 .32845 Mdot
.532 .32845 Mdot
.532 .32845 Mdot
.532 .32845 Mdot
.532 .32845 Mdot
.532 .32845 Mdot
.532 .32845 Mdot
.532 .32845 Mdot
.532 .32845 Mdot
.532 .32845 Mdot
.532 .32845 Mdot
.532 .32845 Mdot
.532 .32845 Mdot
.532 .32845 Mdot
.532 .32845 Mdot
.532 .32845 Mdot
.532 .32845 Mdot
.532 .32845 Mdot
.532 .32845 Mdot
.532 .32846 Mdot
.532 .32846 Mdot
.532 .32846 Mdot
.532 .32846 Mdot
.532 .32846 Mdot
.532 .32846 Mdot
.532 .32846 Mdot
.532 .32846 Mdot
.532 .32846 Mdot
.532 .32846 Mdot
.532 .32846 Mdot
.532 .32846 Mdot
.532 .32846 Mdot
.532 .32853 Mdot
.532 .32853 Mdot
.532 .32853 Mdot
.532 .32853 Mdot
.532 .32853 Mdot
.532 .32853 Mdot
.532 .32853 Mdot
.532 .32853 Mdot
.532 .32853 Mdot
.532 .32853 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32854 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32855 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32856 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.532 .32857 Mdot
.534 .30833 Mdot
.534 .30833 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30834 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30835 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30836 Mdot
.534 .30837 Mdot
.534 .30837 Mdot
.534 .30837 Mdot
.534 .30837 Mdot
.534 .30837 Mdot
.534 .30837 Mdot
.534 .30837 Mdot
.534 .30837 Mdot
.534 .30837 Mdot
.534 .30837 Mdot
.534 .30837 Mdot
.534 .30837 Mdot
.534 .30837 Mdot
.534 .30837 Mdot
.534 .30837 Mdot
.534 .30837 Mdot
.534 .30837 Mdot
.534 .30837 Mdot
.534 .30838 Mdot
.534 .30838 Mdot
.534 .30838 Mdot
.534 .30838 Mdot
.534 .30838 Mdot
.534 .30838 Mdot
.534 .30838 Mdot
.534 .30838 Mdot
.534 .30838 Mdot
.534 .30838 Mdot
.534 .30838 Mdot
.534 .30838 Mdot
.534 .30839 Mdot
.534 .30839 Mdot
.534 .30839 Mdot
.534 .30839 Mdot
.534 .30839 Mdot
.534 .30839 Mdot
.534 .30839 Mdot
.534 .30839 Mdot
.534 .30839 Mdot
.534 .30839 Mdot
.534 .30839 Mdot
.534 .30839 Mdot
.534 .30839 Mdot
.534 .30839 Mdot
.534 .30839 Mdot
.534 .30839 Mdot
.534 .3084 Mdot
.534 .3084 Mdot
.534 .30847 Mdot
.534 .30847 Mdot
.534 .30847 Mdot
.534 .30847 Mdot
.534 .30847 Mdot
.534 .30847 Mdot
.534 .30848 Mdot
.534 .30848 Mdot
.534 .30848 Mdot
.534 .30848 Mdot
.534 .30848 Mdot
.534 .30848 Mdot
.534 .30848 Mdot
.534 .30848 Mdot
.534 .30848 Mdot
.534 .30848 Mdot
.534 .30848 Mdot
.534 .30848 Mdot
.534 .30848 Mdot
.534 .30848 Mdot
.534 .30848 Mdot
.534 .30849 Mdot
.534 .30849 Mdot
.534 .30849 Mdot
.534 .30849 Mdot
.534 .30849 Mdot
.534 .30849 Mdot
.534 .3085 Mdot
.534 .3085 Mdot
.534 .3085 Mdot
.534 .3085 Mdot
.534 .3085 Mdot
.534 .3085 Mdot
.534 .3085 Mdot
.534 .3085 Mdot
.534 .3085 Mdot
.534 .3085 Mdot
.534 .3085 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30851 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30852 Mdot
.534 .30853 Mdot
.534 .30853 Mdot
.534 .30853 Mdot
.534 .30853 Mdot
.534 .30853 Mdot
.534 .30853 Mdot
.534 .30853 Mdot
.534 .30853 Mdot
.534 .30853 Mdot
.534 .30853 Mdot
.534 .30853 Mdot
.534 .30853 Mdot
.534 .30853 Mdot
.534 .30853 Mdot
.534 .30853 Mdot
.534 .30853 Mdot
.534 .30853 Mdot
.534 .30853 Mdot
.534 .30853 Mdot
.534 .30854 Mdot
.534 .30854 Mdot
.534 .30854 Mdot
.534 .30854 Mdot
.534 .30854 Mdot
.534 .30854 Mdot
.534 .30854 Mdot
.534 .30854 Mdot
.534 .30854 Mdot
.534 .30854 Mdot
.534 .30854 Mdot
.534 .30854 Mdot
.534 .30854 Mdot
.534 .30854 Mdot
.534 .30854 Mdot
.534 .30854 Mdot
.534 .30854 Mdot
.534 .30854 Mdot
.534 .30855 Mdot
.534 .30855 Mdot
.534 .30855 Mdot
.534 .30855 Mdot
.534 .30855 Mdot
.534 .30855 Mdot
.534 .30964 Mdot
.534 .30964 Mdot
.534 .30964 Mdot
.534 .30964 Mdot
.534 .30964 Mdot
.534 .30964 Mdot
.534 .30965 Mdot
.534 .30965 Mdot
.534 .30965 Mdot
.534 .30965 Mdot
.534 .30965 Mdot
.534 .30965 Mdot
.534 .30965 Mdot
.534 .30965 Mdot
.534 .30965 Mdot
.534 .30965 Mdot
.534 .30965 Mdot
.534 .30965 Mdot
.534 .30965 Mdot
.534 .30965 Mdot
.534 .30965 Mdot
.534 .30965 Mdot
.534 .30965 Mdot
.534 .30966 Mdot
.534 .30966 Mdot
.534 .30966 Mdot
.534 .30966 Mdot
.534 .30966 Mdot
.534 .30966 Mdot
.534 .30966 Mdot
.534 .30966 Mdot
.534 .30966 Mdot
.534 .30966 Mdot
.534 .30966 Mdot
.534 .30966 Mdot
.534 .30966 Mdot
.534 .30967 Mdot
.534 .30967 Mdot
.534 .30967 Mdot
.534 .30967 Mdot
.534 .30967 Mdot
.534 .30967 Mdot
.534 .30967 Mdot
.534 .30967 Mdot
.534 .30967 Mdot
.534 .30967 Mdot
.534 .30967 Mdot
.534 .30967 Mdot
.534 .30967 Mdot
.534 .30967 Mdot
.534 .30967 Mdot
.534 .30967 Mdot
.534 .30967 Mdot
.534 .30967 Mdot
.534 .30967 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30968 Mdot
.534 .30969 Mdot
.534 .30969 Mdot
.534 .30969 Mdot
.534 .30969 Mdot
.534 .30969 Mdot
.534 .30969 Mdot
.534 .30969 Mdot
.534 .30969 Mdot
.534 .30969 Mdot
.534 .30969 Mdot
.534 .30969 Mdot
.534 .30969 Mdot
.534 .30969 Mdot
.534 .30969 Mdot
.534 .3097 Mdot
.534 .3097 Mdot
.534 .3097 Mdot
.534 .3097 Mdot
.534 .3097 Mdot
.534 .3097 Mdot
.534 .3097 Mdot
.534 .3097 Mdot
.534 .3097 Mdot
.534 .3097 Mdot
.534 .30971 Mdot
.534 .30971 Mdot
.534 .30971 Mdot
.534 .30971 Mdot
.534 .30971 Mdot
.534 .30971 Mdot
.534 .30972 Mdot
.534 .30972 Mdot
.534 .30972 Mdot
.534 .30972 Mdot
.534 .30972 Mdot
.534 .30972 Mdot
.534 .30972 Mdot
.534 .30972 Mdot
.534 .30972 Mdot
.534 .30972 Mdot
.534 .30972 Mdot
.534 .30972 Mdot
.534 .30972 Mdot
.534 .30973 Mdot
.534 .30973 Mdot
.534 .30973 Mdot
.534 .30973 Mdot
.534 .30973 Mdot
.534 .30974 Mdot
.534 .30981 Mdot
.534 .30982 Mdot
.534 .30982 Mdot
.534 .30982 Mdot
.534 .30982 Mdot
.534 .30982 Mdot
.534 .30982 Mdot
.534 .30982 Mdot
.534 .30983 Mdot
.534 .30983 Mdot
.534 .30983 Mdot
.534 .30983 Mdot
.534 .30983 Mdot
.534 .30983 Mdot
.534 .30983 Mdot
.534 .30983 Mdot
.534 .30983 Mdot
.534 .30983 Mdot
.534 .30983 Mdot
.534 .30983 Mdot
.534 .30983 Mdot
.534 .30983 Mdot
.534 .30983 Mdot
.534 .30983 Mdot
.534 .30984 Mdot
.534 .30984 Mdot
.534 .30984 Mdot
.534 .30984 Mdot
.534 .30984 Mdot
.534 .30984 Mdot
.534 .30984 Mdot
.534 .30984 Mdot
.534 .30984 Mdot
.534 .30984 Mdot
.534 .30984 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30985 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30986 Mdot
.534 .30987 Mdot
.534 .30987 Mdot
.534 .30987 Mdot
.534 .30987 Mdot
.534 .30987 Mdot
.534 .30987 Mdot
.534 .30987 Mdot
.534 .30987 Mdot
.534 .30987 Mdot
.534 .30987 Mdot
.534 .30987 Mdot
.534 .30987 Mdot
.534 .30987 Mdot
.534 .30987 Mdot
.534 .30987 Mdot
.534 .30987 Mdot
.534 .30987 Mdot
.534 .30987 Mdot
.534 .30987 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30988 Mdot
.534 .30989 Mdot
.534 .30989 Mdot
.534 .3283 Mdot
.534 .3283 Mdot
.534 .3283 Mdot
.534 .3283 Mdot
.534 .3283 Mdot
.534 .3283 Mdot
.534 .3283 Mdot
.534 .3283 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32831 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32832 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32833 Mdot
.534 .32834 Mdot
.534 .32834 Mdot
.534 .32834 Mdot
.534 .32834 Mdot
.534 .32834 Mdot
.534 .32834 Mdot
.534 .32834 Mdot
.534 .32834 Mdot
.534 .32834 Mdot
.534 .32834 Mdot
.534 .32834 Mdot
.534 .32834 Mdot
.534 .32834 Mdot
.534 .32834 Mdot
.534 .32834 Mdot
.534 .32834 Mdot
.534 .32834 Mdot
.534 .32834 Mdot
.534 .32835 Mdot
.534 .32835 Mdot
.534 .32835 Mdot
.534 .32835 Mdot
.534 .32835 Mdot
.534 .32835 Mdot
.534 .32835 Mdot
.534 .32835 Mdot
.534 .32835 Mdot
.534 .32835 Mdot
.534 .32836 Mdot
.534 .32836 Mdot
.534 .32836 Mdot
.534 .32836 Mdot
.534 .32836 Mdot
.534 .32836 Mdot
.534 .32836 Mdot
.534 .32836 Mdot
.534 .32836 Mdot
.534 .32836 Mdot
.534 .32836 Mdot
.534 .32836 Mdot
.534 .32836 Mdot
.534 .32836 Mdot
.534 .32837 Mdot
.534 .32837 Mdot
.534 .32844 Mdot
.534 .32844 Mdot
.534 .32845 Mdot
.534 .32845 Mdot
.534 .32845 Mdot
.534 .32845 Mdot
.534 .32845 Mdot
.534 .32845 Mdot
.534 .32846 Mdot
.534 .32846 Mdot
.534 .32846 Mdot
.534 .32846 Mdot
.534 .32846 Mdot
.534 .32846 Mdot
.534 .32846 Mdot
.534 .32846 Mdot
.534 .32846 Mdot
.534 .32846 Mdot
.534 .32846 Mdot
.534 .32846 Mdot
.534 .32846 Mdot
.534 .32846 Mdot
.534 .32846 Mdot
.534 .32847 Mdot
.534 .32847 Mdot
.534 .32847 Mdot
.534 .32847 Mdot
.534 .32847 Mdot
.534 .32847 Mdot
.534 .32847 Mdot
.534 .32847 Mdot
.534 .32847 Mdot
.534 .32847 Mdot
.534 .32848 Mdot
.534 .32848 Mdot
.534 .32848 Mdot
.534 .32848 Mdot
.534 .32848 Mdot
.534 .32848 Mdot
.534 .32848 Mdot
.534 .32848 Mdot
.534 .32848 Mdot
.534 .32848 Mdot
.534 .32848 Mdot
.534 .32848 Mdot
.534 .32849 Mdot
.534 .32849 Mdot
.534 .32849 Mdot
.534 .32849 Mdot
.534 .32849 Mdot
.534 .32849 Mdot
.534 .32849 Mdot
.534 .32849 Mdot
.534 .32849 Mdot
.534 .32849 Mdot
.534 .32849 Mdot
.534 .32849 Mdot
.534 .32849 Mdot
.534 .32849 Mdot
.534 .32849 Mdot
.534 .32849 Mdot
.534 .32849 Mdot
.534 .32849 Mdot
.534 .32849 Mdot
.534 .3285 Mdot
.534 .3285 Mdot
.534 .3285 Mdot
.534 .3285 Mdot
.534 .3285 Mdot
.534 .3285 Mdot
.534 .3285 Mdot
.534 .3285 Mdot
.534 .3285 Mdot
.534 .3285 Mdot
.534 .3285 Mdot
.534 .3285 Mdot
.534 .3285 Mdot
.534 .3285 Mdot
.534 .3285 Mdot
.534 .3285 Mdot
.534 .3285 Mdot
.534 .3285 Mdot
.534 .3285 Mdot
.534 .32851 Mdot
.534 .32851 Mdot
.534 .32851 Mdot
.534 .32851 Mdot
.534 .32851 Mdot
.534 .32851 Mdot
.534 .32851 Mdot
.534 .32851 Mdot
.534 .32851 Mdot
.534 .32851 Mdot
.534 .32851 Mdot
.534 .32851 Mdot
.534 .32851 Mdot
.534 .32851 Mdot
.534 .32851 Mdot
.534 .32851 Mdot
.534 .32851 Mdot
.534 .32851 Mdot
.534 .32852 Mdot
.534 .32852 Mdot
.534 .32852 Mdot
.534 .32852 Mdot
.534 .32852 Mdot
.534 .32852 Mdot
.534 .32852 Mdot
.534 .32852 Mdot
.534 .32852 Mdot
.534 .32852 Mdot
.534 .32852 Mdot
.534 .32852 Mdot
.534 .32852 Mdot
.534 .32852 Mdot
.534 .32852 Mdot
.534 .32852 Mdot
.534 .32852 Mdot
.534 .32852 Mdot
.534 .32853 Mdot
.534 .32853 Mdot
.534 .32853 Mdot
.534 .32853 Mdot
.534 .32853 Mdot
.534 .32853 Mdot
.534 .32955 Mdot
.534 .32955 Mdot
.534 .32955 Mdot
.534 .32955 Mdot
.534 .32955 Mdot
.534 .32956 Mdot
.534 .32956 Mdot
.534 .32956 Mdot
.534 .32956 Mdot
.534 .32956 Mdot
.534 .32956 Mdot
.534 .32956 Mdot
.534 .32956 Mdot
.534 .32956 Mdot
.534 .32956 Mdot
.534 .32956 Mdot
.534 .32956 Mdot
.534 .32956 Mdot
.534 .32956 Mdot
.534 .32956 Mdot
.534 .32956 Mdot
.534 .32956 Mdot
.534 .32956 Mdot
.534 .32956 Mdot
.534 .32957 Mdot
.534 .32957 Mdot
.534 .32957 Mdot
.534 .32957 Mdot
.534 .32957 Mdot
.534 .32957 Mdot
.534 .32957 Mdot
.534 .32957 Mdot
.534 .32957 Mdot
.534 .32957 Mdot
.534 .32957 Mdot
.534 .32957 Mdot
.534 .32957 Mdot
.534 .32957 Mdot
.534 .32957 Mdot
.534 .32957 Mdot
.534 .32957 Mdot
.534 .32957 Mdot
.534 .32957 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32958 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .32959 Mdot
.534 .3296 Mdot
.534 .3296 Mdot
.534 .3296 Mdot
.534 .3296 Mdot
.534 .3296 Mdot
.534 .3296 Mdot
.534 .3296 Mdot
.534 .3296 Mdot
.534 .3296 Mdot
.534 .3296 Mdot
.534 .3296 Mdot
.534 .3296 Mdot
.534 .32961 Mdot
.534 .32961 Mdot
.534 .32961 Mdot
.534 .32961 Mdot
.534 .32961 Mdot
.534 .32961 Mdot
.534 .32961 Mdot
.534 .32961 Mdot
.534 .32961 Mdot
.534 .32962 Mdot
.534 .32962 Mdot
.534 .32962 Mdot
.534 .32962 Mdot
.534 .32962 Mdot
.534 .32962 Mdot
.534 .32962 Mdot
.534 .32962 Mdot
.534 .32962 Mdot
.534 .32962 Mdot
.534 .32962 Mdot
.534 .32962 Mdot
.534 .32962 Mdot
.534 .32962 Mdot
.534 .32963 Mdot
.534 .32963 Mdot
.534 .32969 Mdot
.534 .3297 Mdot
.534 .3297 Mdot
.534 .3297 Mdot
.534 .3297 Mdot
.534 .3297 Mdot
.534 .3297 Mdot
.534 .3297 Mdot
.534 .3297 Mdot
.534 .3297 Mdot
.534 .3297 Mdot
.534 .3297 Mdot
.534 .3297 Mdot
.534 .3297 Mdot
.534 .3297 Mdot
.534 .3297 Mdot
.534 .32971 Mdot
.534 .32971 Mdot
.534 .32971 Mdot
.534 .32971 Mdot
.534 .32971 Mdot
.534 .32971 Mdot
.534 .32971 Mdot
.534 .32971 Mdot
.534 .32971 Mdot
.534 .32971 Mdot
.534 .32971 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32972 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32973 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32974 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32975 Mdot
.534 .32976 Mdot
.536 .30817 Mdot
.536 .30817 Mdot
.536 .30817 Mdot
.536 .30817 Mdot
.536 .30817 Mdot
.536 .30817 Mdot
.536 .30817 Mdot
.536 .30817 Mdot
.536 .30817 Mdot
.536 .30817 Mdot
.536 .30817 Mdot
.536 .30817 Mdot
.536 .30817 Mdot
.536 .30817 Mdot
.536 .30817 Mdot
.536 .30817 Mdot
.536 .30817 Mdot
.536 .30817 Mdot
.536 .30817 Mdot
.536 .30818 Mdot
.536 .30818 Mdot
.536 .30818 Mdot
.536 .30818 Mdot
.536 .30818 Mdot
.536 .30818 Mdot
.536 .30818 Mdot
.536 .30818 Mdot
.536 .30818 Mdot
.536 .30818 Mdot
.536 .30818 Mdot
.536 .30818 Mdot
.536 .30818 Mdot
.536 .30818 Mdot
.536 .30818 Mdot
.536 .30819 Mdot
.536 .30819 Mdot
.536 .30819 Mdot
.536 .30819 Mdot
.536 .30819 Mdot
.536 .30819 Mdot
.536 .30819 Mdot
.536 .30819 Mdot
.536 .30819 Mdot
.536 .30819 Mdot
.536 .30819 Mdot
.536 .30819 Mdot
.536 .30819 Mdot
.536 .30819 Mdot
.536 .30819 Mdot
.536 .30819 Mdot
.536 .3082 Mdot
.536 .3082 Mdot
.536 .3082 Mdot
.536 .3082 Mdot
.536 .3082 Mdot
.536 .3082 Mdot
.536 .3082 Mdot
.536 .3082 Mdot
.536 .3082 Mdot
.536 .3082 Mdot
.536 .30821 Mdot
.536 .30821 Mdot
.536 .30821 Mdot
.536 .30821 Mdot
.536 .30821 Mdot
.536 .30821 Mdot
.536 .30821 Mdot
.536 .30821 Mdot
.536 .30821 Mdot
.536 .30821 Mdot
.536 .30821 Mdot
.536 .30821 Mdot
.536 .30821 Mdot
.536 .30821 Mdot
.536 .30821 Mdot
.536 .30821 Mdot
.536 .30822 Mdot
.536 .30822 Mdot
.536 .30822 Mdot
.536 .30822 Mdot
.536 .30822 Mdot
.536 .30822 Mdot
.536 .30822 Mdot
.536 .30822 Mdot
.536 .30822 Mdot
.536 .30822 Mdot
.536 .30822 Mdot
.536 .30822 Mdot
.536 .30822 Mdot
.536 .30822 Mdot
.536 .30822 Mdot
.536 .30822 Mdot
.536 .30823 Mdot
.536 .30823 Mdot
.536 .30823 Mdot
.536 .30823 Mdot
.536 .30823 Mdot
.536 .30823 Mdot
.536 .30823 Mdot
.536 .30823 Mdot
.536 .30823 Mdot
.536 .30823 Mdot
.536 .30823 Mdot
.536 .30823 Mdot
.536 .30824 Mdot
.536 .30824 Mdot
.536 .30824 Mdot
.536 .30824 Mdot
.536 .30824 Mdot
.536 .30824 Mdot
.536 .30824 Mdot
.536 .30824 Mdot
.536 .30824 Mdot
.536 .30824 Mdot
.536 .30824 Mdot
.536 .30824 Mdot
.536 .30824 Mdot
.536 .30824 Mdot
.536 .30824 Mdot
.536 .30825 Mdot
.536 .30825 Mdot
.536 .30825 Mdot
.536 .30825 Mdot
.536 .30825 Mdot
.536 .30825 Mdot
.536 .30832 Mdot
.536 .30832 Mdot
.536 .30832 Mdot
.536 .30832 Mdot
.536 .30832 Mdot
.536 .30833 Mdot
.536 .30833 Mdot
.536 .30833 Mdot
.536 .30833 Mdot
.536 .30833 Mdot
.536 .30833 Mdot
.536 .30833 Mdot
.536 .30833 Mdot
.536 .30833 Mdot
.536 .30833 Mdot
.536 .30833 Mdot
.536 .30833 Mdot
.536 .30834 Mdot
.536 .30834 Mdot
.536 .30834 Mdot
.536 .30834 Mdot
.536 .30834 Mdot
.536 .30834 Mdot
.536 .30835 Mdot
.536 .30835 Mdot
.536 .30835 Mdot
.536 .30835 Mdot
.536 .30835 Mdot
.536 .30835 Mdot
.536 .30835 Mdot
.536 .30835 Mdot
.536 .30835 Mdot
.536 .30835 Mdot
.536 .30835 Mdot
.536 .30835 Mdot
.536 .30836 Mdot
.536 .30836 Mdot
.536 .30836 Mdot
.536 .30836 Mdot
.536 .30836 Mdot
.536 .30836 Mdot
.536 .30836 Mdot
.536 .30836 Mdot
.536 .30836 Mdot
.536 .30836 Mdot
.536 .30836 Mdot
.536 .30836 Mdot
.536 .30836 Mdot
.536 .30836 Mdot
.536 .30837 Mdot
.536 .30837 Mdot
.536 .30837 Mdot
.536 .30837 Mdot
.536 .30837 Mdot
.536 .30837 Mdot
.536 .30837 Mdot
.536 .30837 Mdot
.536 .30837 Mdot
.536 .30837 Mdot
.536 .30837 Mdot
.536 .30837 Mdot
.536 .30837 Mdot
.536 .30838 Mdot
.536 .30838 Mdot
.536 .30838 Mdot
.536 .30838 Mdot
.536 .30838 Mdot
.536 .30838 Mdot
.536 .30838 Mdot
.536 .30838 Mdot
.536 .30838 Mdot
.536 .30839 Mdot
.536 .30839 Mdot
.536 .30839 Mdot
.536 .30839 Mdot
.536 .30839 Mdot
.536 .30839 Mdot
.536 .30839 Mdot
.536 .30839 Mdot
.536 .30839 Mdot
.536 .30839 Mdot
.536 .3084 Mdot
.536 .3084 Mdot
.536 .3084 Mdot
.536 .3084 Mdot
.536 .3084 Mdot
.536 .3084 Mdot
.536 .3084 Mdot
.536 .3084 Mdot
.536 .30841 Mdot
.536 .30841 Mdot
.536 .30841 Mdot
.536 .30841 Mdot
.536 .30841 Mdot
.536 .30841 Mdot
.536 .30841 Mdot
.536 .30841 Mdot
.536 .30841 Mdot
.536 .30841 Mdot
.536 .30841 Mdot
.536 .30841 Mdot
.536 .30841 Mdot
.536 .30841 Mdot
.536 .30842 Mdot
.536 .30842 Mdot
.536 .30842 Mdot
.536 .30842 Mdot
.536 .30842 Mdot
.536 .30842 Mdot
.536 .30842 Mdot
.536 .30842 Mdot
.536 .30842 Mdot
.536 .30842 Mdot
.536 .30842 Mdot
.536 .30842 Mdot
.536 .30842 Mdot
.536 .30842 Mdot
.536 .30842 Mdot
.536 .30842 Mdot
.536 .30842 Mdot
.536 .30843 Mdot
.536 .30843 Mdot
.536 .30843 Mdot
.536 .30843 Mdot
.536 .30843 Mdot
.536 .30843 Mdot
.536 .30962 Mdot
.536 .30963 Mdot
.536 .30963 Mdot
.536 .30963 Mdot
.536 .30963 Mdot
.536 .30963 Mdot
.536 .30963 Mdot
.536 .30963 Mdot
.536 .30963 Mdot
.536 .30963 Mdot
.536 .30963 Mdot
.536 .30963 Mdot
.536 .30963 Mdot
.536 .30963 Mdot
.536 .30963 Mdot
.536 .30963 Mdot
.536 .30963 Mdot
.536 .30963 Mdot
.536 .30963 Mdot
.536 .30964 Mdot
.536 .30964 Mdot
.536 .30964 Mdot
.536 .30964 Mdot
.536 .30964 Mdot
.536 .30964 Mdot
.536 .30964 Mdot
.536 .30964 Mdot
.536 .30964 Mdot
.536 .30965 Mdot
.536 .30965 Mdot
.536 .30965 Mdot
.536 .30965 Mdot
.536 .30965 Mdot
.536 .30965 Mdot
.536 .30965 Mdot
.536 .30965 Mdot
.536 .30965 Mdot
.536 .30965 Mdot
.536 .30965 Mdot
.536 .30965 Mdot
.536 .30965 Mdot
.536 .30966 Mdot
.536 .30966 Mdot
.536 .30966 Mdot
.536 .30966 Mdot
.536 .30966 Mdot
.536 .30966 Mdot
.536 .30966 Mdot
.536 .30966 Mdot
.536 .30966 Mdot
.536 .30967 Mdot
.536 .30967 Mdot
.536 .30967 Mdot
.536 .30967 Mdot
.536 .30967 Mdot
.536 .30968 Mdot
.536 .30968 Mdot
.536 .30968 Mdot
.536 .30968 Mdot
.536 .30968 Mdot
.536 .30968 Mdot
.536 .30968 Mdot
.536 .30968 Mdot
.536 .30968 Mdot
.536 .30969 Mdot
.536 .30969 Mdot
.536 .30969 Mdot
.536 .30969 Mdot
.536 .30969 Mdot
.536 .30969 Mdot
.536 .30969 Mdot
.536 .30969 Mdot
.536 .30969 Mdot
.536 .30969 Mdot
.536 .30969 Mdot
.536 .3097 Mdot
.536 .3097 Mdot
.536 .3097 Mdot
.536 .3097 Mdot
.536 .3097 Mdot
.536 .3097 Mdot
.536 .3097 Mdot
.536 .3097 Mdot
.536 .3097 Mdot
.536 .3097 Mdot
.536 .3097 Mdot
.536 .3097 Mdot
.536 .3097 Mdot
.536 .30971 Mdot
.536 .30971 Mdot
.536 .30971 Mdot
.536 .30971 Mdot
.536 .30971 Mdot
.536 .30971 Mdot
.536 .30971 Mdot
.536 .30971 Mdot
.536 .30971 Mdot
.536 .30972 Mdot
.536 .30972 Mdot
.536 .30972 Mdot
.536 .30972 Mdot
.536 .30972 Mdot
.536 .30972 Mdot
.536 .30972 Mdot
.536 .30972 Mdot
.536 .30973 Mdot
.536 .30973 Mdot
.536 .30973 Mdot
.536 .30973 Mdot
.536 .30973 Mdot
.536 .30973 Mdot
.536 .30973 Mdot
.536 .30974 Mdot
.536 .30974 Mdot
.536 .30974 Mdot
.536 .30974 Mdot
.536 .30974 Mdot
.536 .30974 Mdot
.536 .30974 Mdot
.536 .30974 Mdot
.536 .30974 Mdot
.536 .30975 Mdot
.536 .30975 Mdot
.536 .30975 Mdot
.536 .30975 Mdot
.536 .30983 Mdot
.536 .30983 Mdot
.536 .30983 Mdot
.536 .30983 Mdot
.536 .30983 Mdot
.536 .30983 Mdot
.536 .30984 Mdot
.536 .30984 Mdot
.536 .30984 Mdot
.536 .30984 Mdot
.536 .30984 Mdot
.536 .30984 Mdot
.536 .30984 Mdot
.536 .30984 Mdot
.536 .30984 Mdot
.536 .30984 Mdot
.536 .30984 Mdot
.536 .30984 Mdot
.536 .30984 Mdot
.536 .30984 Mdot
.536 .30985 Mdot
.536 .30985 Mdot
.536 .30985 Mdot
.536 .30985 Mdot
.536 .30985 Mdot
.536 .30985 Mdot
.536 .30985 Mdot
.536 .30985 Mdot
.536 .30985 Mdot
.536 .30986 Mdot
.536 .30986 Mdot
.536 .30986 Mdot
.536 .30986 Mdot
.536 .30986 Mdot
.536 .30986 Mdot
.536 .30986 Mdot
.536 .30986 Mdot
.536 .30986 Mdot
.536 .30986 Mdot
.536 .30986 Mdot
.536 .30986 Mdot
.536 .30986 Mdot
.536 .30986 Mdot
.536 .30987 Mdot
.536 .30987 Mdot
.536 .30987 Mdot
.536 .30987 Mdot
.536 .30987 Mdot
.536 .30987 Mdot
.536 .30987 Mdot
.536 .30987 Mdot
.536 .30987 Mdot
.536 .30987 Mdot
.536 .30987 Mdot
.536 .30987 Mdot
.536 .30987 Mdot
.536 .30987 Mdot
.536 .30987 Mdot
.536 .30987 Mdot
.536 .30988 Mdot
.536 .30988 Mdot
.536 .30988 Mdot
.536 .30988 Mdot
.536 .30988 Mdot
.536 .30988 Mdot
.536 .30988 Mdot
.536 .30988 Mdot
.536 .30988 Mdot
.536 .30988 Mdot
.536 .30988 Mdot
.536 .30989 Mdot
.536 .30989 Mdot
.536 .30989 Mdot
.536 .30989 Mdot
.536 .30989 Mdot
.536 .30989 Mdot
.536 .30989 Mdot
.536 .30989 Mdot
.536 .30989 Mdot
.536 .30989 Mdot
.536 .3099 Mdot
.536 .3099 Mdot
.536 .3099 Mdot
.536 .3099 Mdot
.536 .3099 Mdot
.536 .3099 Mdot
.536 .3099 Mdot
.536 .3099 Mdot
.536 .3099 Mdot
.536 .3099 Mdot
.536 .3099 Mdot
.536 .3099 Mdot
.536 .3099 Mdot
.536 .30991 Mdot
.536 .30991 Mdot
.536 .30991 Mdot
.536 .30991 Mdot
.536 .30991 Mdot
.536 .30991 Mdot
.536 .30991 Mdot
.536 .30991 Mdot
.536 .30991 Mdot
.536 .30991 Mdot
.536 .30991 Mdot
.536 .30991 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .30992 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .3293 Mdot
.536 .32931 Mdot
.536 .32931 Mdot
.536 .32931 Mdot
.536 .32931 Mdot
.536 .32931 Mdot
.536 .32931 Mdot
.536 .32931 Mdot
.536 .32931 Mdot
.536 .32931 Mdot
.536 .32931 Mdot
.536 .32931 Mdot
.536 .32931 Mdot
.536 .32931 Mdot
.536 .32931 Mdot
.536 .32932 Mdot
.536 .32932 Mdot
.536 .32932 Mdot
.536 .32932 Mdot
.536 .32932 Mdot
.536 .32932 Mdot
.536 .32932 Mdot
.536 .32932 Mdot
.536 .32932 Mdot
.536 .32932 Mdot
.536 .32932 Mdot
.536 .32932 Mdot
.536 .32932 Mdot
.536 .32932 Mdot
.536 .32932 Mdot
.536 .32933 Mdot
.536 .32933 Mdot
.536 .32933 Mdot
.536 .32933 Mdot
.536 .32933 Mdot
.536 .32933 Mdot
.536 .32933 Mdot
.536 .32933 Mdot
.536 .32934 Mdot
.536 .32934 Mdot
.536 .32934 Mdot
.536 .32934 Mdot
.536 .32934 Mdot
.536 .32934 Mdot
.536 .32934 Mdot
.536 .32934 Mdot
.536 .32934 Mdot
.536 .32934 Mdot
.536 .32934 Mdot
.536 .32934 Mdot
.536 .32934 Mdot
.536 .32934 Mdot
.536 .32934 Mdot
.536 .32935 Mdot
.536 .32935 Mdot
.536 .32935 Mdot
.536 .32935 Mdot
.536 .32935 Mdot
.536 .32935 Mdot
.536 .32935 Mdot
.536 .32935 Mdot
.536 .32935 Mdot
.536 .32935 Mdot
.536 .32935 Mdot
.536 .32935 Mdot
.536 .32935 Mdot
.536 .32935 Mdot
.536 .32935 Mdot
.536 .32935 Mdot
.536 .32935 Mdot
.536 .32935 Mdot
.536 .32936 Mdot
.536 .32936 Mdot
.536 .32936 Mdot
.536 .32936 Mdot
.536 .32936 Mdot
.536 .32936 Mdot
.536 .32936 Mdot
.536 .32936 Mdot
.536 .32936 Mdot
.536 .32936 Mdot
.536 .32936 Mdot
.536 .32936 Mdot
.536 .32937 Mdot
.536 .32937 Mdot
.536 .32937 Mdot
.536 .32937 Mdot
.536 .32937 Mdot
.536 .32937 Mdot
.536 .32937 Mdot
.536 .32937 Mdot
.536 .32937 Mdot
.536 .32937 Mdot
.536 .32938 Mdot
.536 .32938 Mdot
.536 .32938 Mdot
.536 .32938 Mdot
.536 .32938 Mdot
.536 .32938 Mdot
.536 .32938 Mdot
.536 .32938 Mdot
.536 .32938 Mdot
.536 .32938 Mdot
.536 .32938 Mdot
.536 .32938 Mdot
.536 .32939 Mdot
.536 .32946 Mdot
.536 .32946 Mdot
.536 .32946 Mdot
.536 .32946 Mdot
.536 .32946 Mdot
.536 .32947 Mdot
.536 .32947 Mdot
.536 .32947 Mdot
.536 .32947 Mdot
.536 .32947 Mdot
.536 .32947 Mdot
.536 .32947 Mdot
.536 .32947 Mdot
.536 .32947 Mdot
.536 .32947 Mdot
.536 .32948 Mdot
.536 .32948 Mdot
.536 .32948 Mdot
.536 .32948 Mdot
.536 .32948 Mdot
.536 .32948 Mdot
.536 .32948 Mdot
.536 .32949 Mdot
.536 .32949 Mdot
.536 .32949 Mdot
.536 .32949 Mdot
.536 .32949 Mdot
.536 .32949 Mdot
.536 .32949 Mdot
.536 .32949 Mdot
.536 .32949 Mdot
.536 .3295 Mdot
.536 .3295 Mdot
.536 .3295 Mdot
.536 .3295 Mdot
.536 .3295 Mdot
.536 .3295 Mdot
.536 .3295 Mdot
.536 .3295 Mdot
.536 .3295 Mdot
.536 .3295 Mdot
.536 .3295 Mdot
.536 .3295 Mdot
.536 .3295 Mdot
.536 .32951 Mdot
.536 .32951 Mdot
.536 .32951 Mdot
.536 .32951 Mdot
.536 .32951 Mdot
.536 .32951 Mdot
.536 .32951 Mdot
.536 .32951 Mdot
.536 .32951 Mdot
.536 .32951 Mdot
.536 .32951 Mdot
.536 .32951 Mdot
.536 .32951 Mdot
.536 .32951 Mdot
.536 .32951 Mdot
.536 .32952 Mdot
.536 .32952 Mdot
.536 .32952 Mdot
.536 .32952 Mdot
.536 .32952 Mdot
.536 .32952 Mdot
.536 .32952 Mdot
.536 .32952 Mdot
.536 .32952 Mdot
.536 .32953 Mdot
.536 .32953 Mdot
.536 .32953 Mdot
.536 .32953 Mdot
.536 .32953 Mdot
.536 .32953 Mdot
.536 .32954 Mdot
.536 .32954 Mdot
.536 .32954 Mdot
.536 .32954 Mdot
.536 .32954 Mdot
.536 .32954 Mdot
.536 .32955 Mdot
.536 .32955 Mdot
.536 .32955 Mdot
.536 .32955 Mdot
.536 .32955 Mdot
.536 .32955 Mdot
.536 .32955 Mdot
.536 .32955 Mdot
.536 .32955 Mdot
.536 .32955 Mdot
.536 .32955 Mdot
.536 .32955 Mdot
.536 .32955 Mdot
.536 .32955 Mdot
.536 .32955 Mdot
.536 .32956 Mdot
.536 .32956 Mdot
.536 .32956 Mdot
.536 .32956 Mdot
.536 .32956 Mdot
.536 .32956 Mdot
.536 .32956 Mdot
.536 .32956 Mdot
.536 .32956 Mdot
.536 .32956 Mdot
.536 .32957 Mdot
.536 .32957 Mdot
.536 .32957 Mdot
.536 .32957 Mdot
.536 .32957 Mdot
.536 .32957 Mdot
.536 .32957 Mdot
.536 .32957 Mdot
.536 .32957 Mdot
.536 .32957 Mdot
.536 .32957 Mdot
.536 .32957 Mdot
.536 .32957 Mdot
.536 .32957 Mdot
.536 .32957 Mdot
.536 .32957 Mdot
.536 .32957 Mdot
.536 .32957 Mdot
.536 .32958 Mdot
.536 .32958 Mdot
.536 .33069 Mdot
.536 .33069 Mdot
.536 .33069 Mdot
.536 .33069 Mdot
.536 .33069 Mdot
.536 .33069 Mdot
.536 .3307 Mdot
.536 .3307 Mdot
.536 .3307 Mdot
.536 .3307 Mdot
.536 .3307 Mdot
.536 .3307 Mdot
.536 .3307 Mdot
.536 .3307 Mdot
.536 .3307 Mdot
.536 .3307 Mdot
.536 .3307 Mdot
.536 .3307 Mdot
.536 .3307 Mdot
.536 .3307 Mdot
.536 .3307 Mdot
.536 .3307 Mdot
.536 .3307 Mdot
.536 .3307 Mdot
.536 .3307 Mdot
.536 .33071 Mdot
.536 .33071 Mdot
.536 .33071 Mdot
.536 .33071 Mdot
.536 .33071 Mdot
.536 .33071 Mdot
.536 .33071 Mdot
.536 .33071 Mdot
.536 .33071 Mdot
.536 .33071 Mdot
.536 .33071 Mdot
.536 .33071 Mdot
.536 .33071 Mdot
.536 .33071 Mdot
.536 .33072 Mdot
.536 .33072 Mdot
.536 .33072 Mdot
.536 .33072 Mdot
.536 .33072 Mdot
.536 .33072 Mdot
.536 .33072 Mdot
.536 .33072 Mdot
.536 .33072 Mdot
.536 .33072 Mdot
.536 .33072 Mdot
.536 .33073 Mdot
.536 .33073 Mdot
.536 .33073 Mdot
.536 .33073 Mdot
.536 .33073 Mdot
.536 .33073 Mdot
.536 .33074 Mdot
.536 .33074 Mdot
.536 .33074 Mdot
.536 .33074 Mdot
.536 .33074 Mdot
.536 .33074 Mdot
.536 .33074 Mdot
.536 .33074 Mdot
.536 .33074 Mdot
.536 .33074 Mdot
.536 .33075 Mdot
.536 .33075 Mdot
.536 .33075 Mdot
.536 .33075 Mdot
.536 .33075 Mdot
.536 .33075 Mdot
.536 .33075 Mdot
.536 .33075 Mdot
.536 .33075 Mdot
.536 .33075 Mdot
.536 .33075 Mdot
.536 .33075 Mdot
.536 .33075 Mdot
.536 .33075 Mdot
.536 .33075 Mdot
.536 .33075 Mdot
.536 .33075 Mdot
.536 .33076 Mdot
.536 .33076 Mdot
.536 .33076 Mdot
.536 .33076 Mdot
.536 .33076 Mdot
.536 .33076 Mdot
.536 .33076 Mdot
.536 .33076 Mdot
.536 .33076 Mdot
.536 .33076 Mdot
.536 .33076 Mdot
.536 .33076 Mdot
.536 .33076 Mdot
.536 .33077 Mdot
.536 .33077 Mdot
.536 .33077 Mdot
.536 .33077 Mdot
.536 .33077 Mdot
.536 .33077 Mdot
.536 .33077 Mdot
.536 .33077 Mdot
.536 .33077 Mdot
.536 .33078 Mdot
.536 .33078 Mdot
.536 .33078 Mdot
.536 .33078 Mdot
.536 .33078 Mdot
.536 .33078 Mdot
.536 .33078 Mdot
.536 .33078 Mdot
.536 .33078 Mdot
.536 .33078 Mdot
.536 .33078 Mdot
.536 .33078 Mdot
.536 .33078 Mdot
.536 .33079 Mdot
.536 .33079 Mdot
.536 .33079 Mdot
.536 .33079 Mdot
.536 .33079 Mdot
.536 .33079 Mdot
.536 .33079 Mdot
.536 .33086 Mdot
.536 .33086 Mdot
.536 .33086 Mdot
.536 .33086 Mdot
.536 .33086 Mdot
.536 .33086 Mdot
.536 .33086 Mdot
.536 .33086 Mdot
.536 .33086 Mdot
.536 .33086 Mdot
.536 .33087 Mdot
.536 .33087 Mdot
.536 .33087 Mdot
.536 .33087 Mdot
.536 .33087 Mdot
.536 .33087 Mdot
.536 .33087 Mdot
.536 .33087 Mdot
.536 .33087 Mdot
.536 .33087 Mdot
.536 .33087 Mdot
.536 .33087 Mdot
.536 .33087 Mdot
.536 .33088 Mdot
.536 .33088 Mdot
.536 .33088 Mdot
.536 .33088 Mdot
.536 .33088 Mdot
.536 .33088 Mdot
.536 .33088 Mdot
.536 .33088 Mdot
.536 .33088 Mdot
.536 .33088 Mdot
.536 .33088 Mdot
.536 .33088 Mdot
.536 .33088 Mdot
.536 .33088 Mdot
.536 .33088 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .33089 Mdot
.536 .3309 Mdot
.536 .3309 Mdot
.536 .3309 Mdot
.536 .3309 Mdot
.536 .3309 Mdot
.536 .3309 Mdot
.536 .3309 Mdot
.536 .3309 Mdot
.536 .3309 Mdot
.536 .3309 Mdot
.536 .3309 Mdot
.536 .3309 Mdot
.536 .3309 Mdot
.536 .33091 Mdot
.536 .33091 Mdot
.536 .33091 Mdot
.536 .33091 Mdot
.536 .33091 Mdot
.536 .33091 Mdot
.536 .33091 Mdot
.536 .33091 Mdot
.536 .33091 Mdot
.536 .33091 Mdot
.536 .33091 Mdot
.536 .33091 Mdot
.536 .33092 Mdot
.536 .33092 Mdot
.536 .33092 Mdot
.536 .33092 Mdot
.536 .33092 Mdot
.536 .33092 Mdot
.536 .33092 Mdot
.536 .33092 Mdot
.536 .33092 Mdot
.536 .33092 Mdot
.536 .33092 Mdot
.536 .33092 Mdot
.536 .33092 Mdot
.536 .33092 Mdot
.536 .33092 Mdot
.536 .33092 Mdot
.536 .33092 Mdot
.536 .33092 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.536 .33093 Mdot
.538 .30799 Mdot
.538 .30799 Mdot
.538 .30799 Mdot
.538 .308 Mdot
.538 .308 Mdot
.538 .308 Mdot
.538 .308 Mdot
.538 .308 Mdot
.538 .308 Mdot
.538 .308 Mdot
.538 .308 Mdot
.538 .308 Mdot
.538 .308 Mdot
.538 .308 Mdot
.538 .30801 Mdot
.538 .30801 Mdot
.538 .30801 Mdot
.538 .30801 Mdot
.538 .30801 Mdot
.538 .30801 Mdot
.538 .30801 Mdot
.538 .30801 Mdot
.538 .30801 Mdot
.538 .30801 Mdot
.538 .30801 Mdot
.538 .30801 Mdot
.538 .30801 Mdot
.538 .30801 Mdot
.538 .30801 Mdot
.538 .30801 Mdot
.538 .30801 Mdot
.538 .30801 Mdot
.538 .30802 Mdot
.538 .30802 Mdot
.538 .30802 Mdot
.538 .30802 Mdot
.538 .30802 Mdot
.538 .30802 Mdot
.538 .30802 Mdot
.538 .30802 Mdot
.538 .30802 Mdot
.538 .30802 Mdot
.538 .30802 Mdot
.538 .30802 Mdot
.538 .30802 Mdot
.538 .30802 Mdot
.538 .30803 Mdot
.538 .30803 Mdot
.538 .30803 Mdot
.538 .30803 Mdot
.538 .30803 Mdot
.538 .30803 Mdot
.538 .30803 Mdot
.538 .30803 Mdot
.538 .30803 Mdot
.538 .30803 Mdot
.538 .30803 Mdot
.538 .30803 Mdot
.538 .30804 Mdot
.538 .30804 Mdot
.538 .30804 Mdot
.538 .30804 Mdot
.538 .30804 Mdot
.538 .30804 Mdot
.538 .30804 Mdot
.538 .30804 Mdot
.538 .30804 Mdot
.538 .30804 Mdot
.538 .30804 Mdot
.538 .30804 Mdot
.538 .30804 Mdot
.538 .30804 Mdot
.538 .30805 Mdot
.538 .30805 Mdot
.538 .30805 Mdot
.538 .30805 Mdot
.538 .30805 Mdot
.538 .30805 Mdot
.538 .30805 Mdot
.538 .30805 Mdot
.538 .30805 Mdot
.538 .30805 Mdot
.538 .30805 Mdot
.538 .30805 Mdot
.538 .30806 Mdot
.538 .30806 Mdot
.538 .30806 Mdot
.538 .30806 Mdot
.538 .30806 Mdot
.538 .30806 Mdot
.538 .30806 Mdot
.538 .30806 Mdot
.538 .30806 Mdot
.538 .30806 Mdot
.538 .30806 Mdot
.538 .30806 Mdot
.538 .30807 Mdot
.538 .30807 Mdot
.538 .30807 Mdot
.538 .30807 Mdot
.538 .30807 Mdot
.538 .30807 Mdot
.538 .30807 Mdot
.538 .30807 Mdot
.538 .30807 Mdot
.538 .30807 Mdot
.538 .30808 Mdot
.538 .30808 Mdot
.538 .30808 Mdot
.538 .30808 Mdot
.538 .30808 Mdot
.538 .30808 Mdot
.538 .30808 Mdot
.538 .30808 Mdot
.538 .30808 Mdot
.538 .30808 Mdot
.538 .30808 Mdot
.538 .30809 Mdot
.538 .30809 Mdot
.538 .30809 Mdot
.538 .30809 Mdot
.538 .30809 Mdot
.538 .3081 Mdot
.538 .3081 Mdot
.538 .3081 Mdot
.538 .30816 Mdot
.538 .30816 Mdot
.538 .30817 Mdot
.538 .30817 Mdot
.538 .30817 Mdot
.538 .30817 Mdot
.538 .30818 Mdot
.538 .30818 Mdot
.538 .30818 Mdot
.538 .30818 Mdot
.538 .30819 Mdot
.538 .30819 Mdot
.538 .30819 Mdot
.538 .30819 Mdot
.538 .30819 Mdot
.538 .30819 Mdot
.538 .30819 Mdot
.538 .30819 Mdot
.538 .30819 Mdot
.538 .30819 Mdot
.538 .3082 Mdot
.538 .3082 Mdot
.538 .3082 Mdot
.538 .3082 Mdot
.538 .3082 Mdot
.538 .3082 Mdot
.538 .3082 Mdot
.538 .30821 Mdot
.538 .30821 Mdot
.538 .30821 Mdot
.538 .30821 Mdot
.538 .30821 Mdot
.538 .30821 Mdot
.538 .30821 Mdot
.538 .30821 Mdot
.538 .30821 Mdot
.538 .30821 Mdot
.538 .30822 Mdot
.538 .30822 Mdot
.538 .30822 Mdot
.538 .30822 Mdot
.538 .30822 Mdot
.538 .30822 Mdot
.538 .30823 Mdot
.538 .30823 Mdot
.538 .30823 Mdot
.538 .30823 Mdot
.538 .30823 Mdot
.538 .30823 Mdot
.538 .30823 Mdot
.538 .30823 Mdot
.538 .30823 Mdot
.538 .30823 Mdot
.538 .30823 Mdot
.538 .30824 Mdot
.538 .30824 Mdot
.538 .30824 Mdot
.538 .30824 Mdot
.538 .30824 Mdot
.538 .30824 Mdot
.538 .30824 Mdot
.538 .30824 Mdot
.538 .30824 Mdot
.538 .30825 Mdot
.538 .30825 Mdot
.538 .30825 Mdot
.538 .30825 Mdot
.538 .30825 Mdot
.538 .30825 Mdot
.538 .30825 Mdot
.538 .30825 Mdot
.538 .30825 Mdot
.538 .30825 Mdot
.538 .30825 Mdot
.538 .30826 Mdot
.538 .30826 Mdot
.538 .30826 Mdot
.538 .30826 Mdot
.538 .30826 Mdot
.538 .30826 Mdot
.538 .30826 Mdot
.538 .30826 Mdot
.538 .30826 Mdot
.538 .30826 Mdot
.538 .30826 Mdot
.538 .30826 Mdot
.538 .30827 Mdot
.538 .30827 Mdot
.538 .30827 Mdot
.538 .30827 Mdot
.538 .30827 Mdot
.538 .30827 Mdot
.538 .30827 Mdot
.538 .30827 Mdot
.538 .30827 Mdot
.538 .30827 Mdot
.538 .30828 Mdot
.538 .30828 Mdot
.538 .30828 Mdot
.538 .30828 Mdot
.538 .30828 Mdot
.538 .30828 Mdot
.538 .30828 Mdot
.538 .30828 Mdot
.538 .30828 Mdot
.538 .30828 Mdot
.538 .30828 Mdot
.538 .30828 Mdot
.538 .30829 Mdot
.538 .30829 Mdot
.538 .30829 Mdot
.538 .30829 Mdot
.538 .30829 Mdot
.538 .30829 Mdot
.538 .30829 Mdot
.538 .30829 Mdot
.538 .30829 Mdot
.538 .30829 Mdot
.538 .3083 Mdot
.538 .3083 Mdot
.538 .3083 Mdot
.538 .3083 Mdot
.538 .3083 Mdot
.538 .3083 Mdot
.538 .3083 Mdot
.538 .30961 Mdot
.538 .30961 Mdot
.538 .30961 Mdot
.538 .30961 Mdot
.538 .30961 Mdot
.538 .30961 Mdot
.538 .30961 Mdot
.538 .30962 Mdot
.538 .30962 Mdot
.538 .30962 Mdot
.538 .30962 Mdot
.538 .30962 Mdot
.538 .30962 Mdot
.538 .30962 Mdot
.538 .30962 Mdot
.538 .30962 Mdot
.538 .30962 Mdot
.538 .30963 Mdot
.538 .30963 Mdot
.538 .30963 Mdot
.538 .30963 Mdot
.538 .30963 Mdot
.538 .30963 Mdot
.538 .30963 Mdot
.538 .30963 Mdot
.538 .30963 Mdot
.538 .30964 Mdot
.538 .30964 Mdot
.538 .30964 Mdot
.538 .30964 Mdot
.538 .30964 Mdot
.538 .30964 Mdot
.538 .30964 Mdot
.538 .30964 Mdot
.538 .30964 Mdot
.538 .30965 Mdot
.538 .30965 Mdot
.538 .30965 Mdot
.538 .30965 Mdot
.538 .30965 Mdot
.538 .30965 Mdot
.538 .30965 Mdot
.538 .30965 Mdot
.538 .30965 Mdot
.538 .30965 Mdot
.538 .30965 Mdot
.538 .30966 Mdot
.538 .30966 Mdot
.538 .30966 Mdot
.538 .30966 Mdot
.538 .30966 Mdot
.538 .30966 Mdot
.538 .30966 Mdot
.538 .30967 Mdot
.538 .30967 Mdot
.538 .30967 Mdot
.538 .30967 Mdot
.538 .30967 Mdot
.538 .30967 Mdot
.538 .30967 Mdot
.538 .30967 Mdot
.538 .30967 Mdot
.538 .30967 Mdot
.538 .30967 Mdot
.538 .30968 Mdot
.538 .30968 Mdot
.538 .30968 Mdot
.538 .30968 Mdot
.538 .30968 Mdot
.538 .30968 Mdot
.538 .30968 Mdot
.538 .30968 Mdot
.538 .30969 Mdot
.538 .30969 Mdot
.538 .30969 Mdot
.538 .30969 Mdot
.538 .30969 Mdot
.538 .30969 Mdot
.538 .30969 Mdot
.538 .30969 Mdot
.538 .30969 Mdot
.538 .3097 Mdot
.538 .3097 Mdot
.538 .3097 Mdot
.538 .3097 Mdot
.538 .3097 Mdot
.538 .3097 Mdot
.538 .30971 Mdot
.538 .30971 Mdot
.538 .30971 Mdot
.538 .30971 Mdot
.538 .30971 Mdot
.538 .30971 Mdot
.538 .30971 Mdot
.538 .30972 Mdot
.538 .30972 Mdot
.538 .30972 Mdot
.538 .30972 Mdot
.538 .30972 Mdot
.538 .30972 Mdot
.538 .30972 Mdot
.538 .30972 Mdot
.538 .30973 Mdot
.538 .30973 Mdot
.538 .30973 Mdot
.538 .30973 Mdot
.538 .30973 Mdot
.538 .30973 Mdot
.538 .30973 Mdot
.538 .30973 Mdot
.538 .30973 Mdot
.538 .30974 Mdot
.538 .30974 Mdot
.538 .30974 Mdot
.538 .30974 Mdot
.538 .30974 Mdot
.538 .30974 Mdot
.538 .30975 Mdot
.538 .30975 Mdot
.538 .30975 Mdot
.538 .30976 Mdot
.538 .30976 Mdot
.538 .30976 Mdot
.538 .30976 Mdot
.538 .30977 Mdot
.538 .30977 Mdot
.538 .30984 Mdot
.538 .30984 Mdot
.538 .30985 Mdot
.538 .30985 Mdot
.538 .30985 Mdot
.538 .30985 Mdot
.538 .30986 Mdot
.538 .30986 Mdot
.538 .30986 Mdot
.538 .30986 Mdot
.538 .30986 Mdot
.538 .30986 Mdot
.538 .30986 Mdot
.538 .30987 Mdot
.538 .30987 Mdot
.538 .30987 Mdot
.538 .30987 Mdot
.538 .30987 Mdot
.538 .30987 Mdot
.538 .30987 Mdot
.538 .30987 Mdot
.538 .30987 Mdot
.538 .30987 Mdot
.538 .30987 Mdot
.538 .30988 Mdot
.538 .30988 Mdot
.538 .30988 Mdot
.538 .30988 Mdot
.538 .30988 Mdot
.538 .30988 Mdot
.538 .30988 Mdot
.538 .30988 Mdot
.538 .30988 Mdot
.538 .30988 Mdot
.538 .30988 Mdot
.538 .30989 Mdot
.538 .30989 Mdot
.538 .30989 Mdot
.538 .30989 Mdot
.538 .30989 Mdot
.538 .30989 Mdot
.538 .30989 Mdot
.538 .3099 Mdot
.538 .3099 Mdot
.538 .3099 Mdot
.538 .3099 Mdot
.538 .3099 Mdot
.538 .3099 Mdot
.538 .3099 Mdot
.538 .3099 Mdot
.538 .3099 Mdot
.538 .3099 Mdot
.538 .3099 Mdot
.538 .3099 Mdot
.538 .30991 Mdot
.538 .30991 Mdot
.538 .30991 Mdot
.538 .30991 Mdot
.538 .30991 Mdot
.538 .30991 Mdot
.538 .30991 Mdot
.538 .30991 Mdot
.538 .30991 Mdot
.538 .30992 Mdot
.538 .30992 Mdot
.538 .30992 Mdot
.538 .30992 Mdot
.538 .30992 Mdot
.538 .30992 Mdot
.538 .30992 Mdot
.538 .30992 Mdot
.538 .30992 Mdot
.538 .30992 Mdot
.538 .30992 Mdot
.538 .30992 Mdot
.538 .30992 Mdot
.538 .30992 Mdot
.538 .30992 Mdot
.538 .30993 Mdot
.538 .30993 Mdot
.538 .30993 Mdot
.538 .30993 Mdot
.538 .30993 Mdot
.538 .30993 Mdot
.538 .30993 Mdot
.538 .30993 Mdot
.538 .30993 Mdot
.538 .30993 Mdot
.538 .30993 Mdot
.538 .30993 Mdot
.538 .30993 Mdot
.538 .30994 Mdot
.538 .30994 Mdot
.538 .30994 Mdot
.538 .30994 Mdot
.538 .30994 Mdot
.538 .30994 Mdot
.538 .30994 Mdot
.538 .30994 Mdot
.538 .30994 Mdot
.538 .30994 Mdot
.538 .30994 Mdot
.538 .30994 Mdot
.538 .30994 Mdot
.538 .30995 Mdot
.538 .30995 Mdot
.538 .30995 Mdot
.538 .30995 Mdot
.538 .30995 Mdot
.538 .30995 Mdot
.538 .30995 Mdot
.538 .30995 Mdot
.538 .30995 Mdot
.538 .30995 Mdot
.538 .30995 Mdot
.538 .30995 Mdot
.538 .30996 Mdot
.538 .30996 Mdot
.538 .30996 Mdot
.538 .30996 Mdot
.538 .30996 Mdot
.538 .30996 Mdot
.538 .30996 Mdot
.538 .30996 Mdot
.538 .30996 Mdot
.538 .33028 Mdot
.538 .33028 Mdot
.538 .33028 Mdot
.538 .33029 Mdot
.538 .33029 Mdot
.538 .33029 Mdot
.538 .33029 Mdot
.538 .33029 Mdot
.538 .33029 Mdot
.538 .33029 Mdot
.538 .33029 Mdot
.538 .33029 Mdot
.538 .33029 Mdot
.538 .33029 Mdot
.538 .3303 Mdot
.538 .3303 Mdot
.538 .3303 Mdot
.538 .3303 Mdot
.538 .3303 Mdot
.538 .3303 Mdot
.538 .3303 Mdot
.538 .3303 Mdot
.538 .3303 Mdot
.538 .3303 Mdot
.538 .3303 Mdot
.538 .3303 Mdot
.538 .3303 Mdot
.538 .3303 Mdot
.538 .3303 Mdot
.538 .3303 Mdot
.538 .33031 Mdot
.538 .33031 Mdot
.538 .33031 Mdot
.538 .33031 Mdot
.538 .33031 Mdot
.538 .33031 Mdot
.538 .33031 Mdot
.538 .33031 Mdot
.538 .33031 Mdot
.538 .33031 Mdot
.538 .33031 Mdot
.538 .33031 Mdot
.538 .33031 Mdot
.538 .33031 Mdot
.538 .33032 Mdot
.538 .33032 Mdot
.538 .33032 Mdot
.538 .33032 Mdot
.538 .33032 Mdot
.538 .33032 Mdot
.538 .33032 Mdot
.538 .33032 Mdot
.538 .33032 Mdot
.538 .33032 Mdot
.538 .33033 Mdot
.538 .33033 Mdot
.538 .33033 Mdot
.538 .33033 Mdot
.538 .33033 Mdot
.538 .33033 Mdot
.538 .33033 Mdot
.538 .33033 Mdot
.538 .33033 Mdot
.538 .33033 Mdot
.538 .33033 Mdot
.538 .33033 Mdot
.538 .33033 Mdot
.538 .33033 Mdot
.538 .33034 Mdot
.538 .33034 Mdot
.538 .33034 Mdot
.538 .33034 Mdot
.538 .33034 Mdot
.538 .33034 Mdot
.538 .33034 Mdot
.538 .33034 Mdot
.538 .33034 Mdot
.538 .33034 Mdot
.538 .33034 Mdot
.538 .33034 Mdot
.538 .33034 Mdot
.538 .33034 Mdot
.538 .33035 Mdot
.538 .33035 Mdot
.538 .33035 Mdot
.538 .33035 Mdot
.538 .33035 Mdot
.538 .33035 Mdot
.538 .33035 Mdot
.538 .33036 Mdot
.538 .33036 Mdot
.538 .33036 Mdot
.538 .33036 Mdot
.538 .33036 Mdot
.538 .33036 Mdot
.538 .33036 Mdot
.538 .33036 Mdot
.538 .33036 Mdot
.538 .33036 Mdot
.538 .33036 Mdot
.538 .33036 Mdot
.538 .33037 Mdot
.538 .33037 Mdot
.538 .33037 Mdot
.538 .33037 Mdot
.538 .33037 Mdot
.538 .33037 Mdot
.538 .33037 Mdot
.538 .33037 Mdot
.538 .33037 Mdot
.538 .33037 Mdot
.538 .33037 Mdot
.538 .33038 Mdot
.538 .33038 Mdot
.538 .33038 Mdot
.538 .33038 Mdot
.538 .33038 Mdot
.538 .33038 Mdot
.538 .33038 Mdot
.538 .33039 Mdot
.538 .33039 Mdot
.538 .33039 Mdot
.538 .33039 Mdot
.538 .33039 Mdot
.538 .33039 Mdot
.538 .33047 Mdot
.538 .33047 Mdot
.538 .33047 Mdot
.538 .33047 Mdot
.538 .33047 Mdot
.538 .33048 Mdot
.538 .33048 Mdot
.538 .33048 Mdot
.538 .33049 Mdot
.538 .33049 Mdot
.538 .33049 Mdot
.538 .33049 Mdot
.538 .33049 Mdot
.538 .33049 Mdot
.538 .33049 Mdot
.538 .3305 Mdot
.538 .3305 Mdot
.538 .3305 Mdot
.538 .3305 Mdot
.538 .3305 Mdot
.538 .3305 Mdot
.538 .3305 Mdot
.538 .3305 Mdot
.538 .3305 Mdot
.538 .33051 Mdot
.538 .33051 Mdot
.538 .33051 Mdot
.538 .33051 Mdot
.538 .33051 Mdot
.538 .33051 Mdot
.538 .33051 Mdot
.538 .33051 Mdot
.538 .33052 Mdot
.538 .33052 Mdot
.538 .33052 Mdot
.538 .33052 Mdot
.538 .33052 Mdot
.538 .33052 Mdot
.538 .33052 Mdot
.538 .33052 Mdot
.538 .33053 Mdot
.538 .33053 Mdot
.538 .33053 Mdot
.538 .33053 Mdot
.538 .33053 Mdot
.538 .33053 Mdot
.538 .33054 Mdot
.538 .33054 Mdot
.538 .33054 Mdot
.538 .33054 Mdot
.538 .33054 Mdot
.538 .33054 Mdot
.538 .33054 Mdot
.538 .33054 Mdot
.538 .33054 Mdot
.538 .33054 Mdot
.538 .33054 Mdot
.538 .33055 Mdot
.538 .33055 Mdot
.538 .33055 Mdot
.538 .33055 Mdot
.538 .33055 Mdot
.538 .33055 Mdot
.538 .33055 Mdot
.538 .33056 Mdot
.538 .33056 Mdot
.538 .33056 Mdot
.538 .33056 Mdot
.538 .33056 Mdot
.538 .33056 Mdot
.538 .33056 Mdot
.538 .33056 Mdot
.538 .33056 Mdot
.538 .33056 Mdot
.538 .33056 Mdot
.538 .33057 Mdot
.538 .33057 Mdot
.538 .33057 Mdot
.538 .33057 Mdot
.538 .33057 Mdot
.538 .33057 Mdot
.538 .33057 Mdot
.538 .33057 Mdot
.538 .33057 Mdot
.538 .33057 Mdot
.538 .33057 Mdot
.538 .33058 Mdot
.538 .33058 Mdot
.538 .33058 Mdot
.538 .33058 Mdot
.538 .33058 Mdot
.538 .33058 Mdot
.538 .33058 Mdot
.538 .33058 Mdot
.538 .33058 Mdot
.538 .33059 Mdot
.538 .33059 Mdot
.538 .33059 Mdot
.538 .33059 Mdot
.538 .33059 Mdot
.538 .33059 Mdot
.538 .33059 Mdot
.538 .33059 Mdot
.538 .33059 Mdot
.538 .33059 Mdot
.538 .33059 Mdot
.538 .3306 Mdot
.538 .3306 Mdot
.538 .3306 Mdot
.538 .3306 Mdot
.538 .3306 Mdot
.538 .3306 Mdot
.538 .3306 Mdot
.538 .3306 Mdot
.538 .3306 Mdot
.538 .3306 Mdot
.538 .3306 Mdot
.538 .33061 Mdot
.538 .33061 Mdot
.538 .33061 Mdot
.538 .33061 Mdot
.538 .33061 Mdot
.538 .33061 Mdot
.538 .33062 Mdot
.538 .33062 Mdot
.538 .33183 Mdot
.538 .33183 Mdot
.538 .33183 Mdot
.538 .33183 Mdot
.538 .33183 Mdot
.538 .33183 Mdot
.538 .33183 Mdot
.538 .33183 Mdot
.538 .33184 Mdot
.538 .33184 Mdot
.538 .33184 Mdot
.538 .33184 Mdot
.538 .33184 Mdot
.538 .33184 Mdot
.538 .33184 Mdot
.538 .33184 Mdot
.538 .33184 Mdot
.538 .33184 Mdot
.538 .33184 Mdot
.538 .33184 Mdot
.538 .33185 Mdot
.538 .33185 Mdot
.538 .33185 Mdot
.538 .33185 Mdot
.538 .33185 Mdot
.538 .33185 Mdot
.538 .33185 Mdot
.538 .33185 Mdot
.538 .33185 Mdot
.538 .33185 Mdot
.538 .33185 Mdot
.538 .33185 Mdot
.538 .33186 Mdot
.538 .33186 Mdot
.538 .33186 Mdot
.538 .33186 Mdot
.538 .33186 Mdot
.538 .33186 Mdot
.538 .33186 Mdot
.538 .33186 Mdot
.538 .33186 Mdot
.538 .33186 Mdot
.538 .33186 Mdot
.538 .33186 Mdot
.538 .33187 Mdot
.538 .33187 Mdot
.538 .33187 Mdot
.538 .33187 Mdot
.538 .33187 Mdot
.538 .33187 Mdot
.538 .33187 Mdot
.538 .33187 Mdot
.538 .33187 Mdot
.538 .33187 Mdot
.538 .33188 Mdot
.538 .33188 Mdot
.538 .33188 Mdot
.538 .33188 Mdot
.538 .33188 Mdot
.538 .33188 Mdot
.538 .33188 Mdot
.538 .33188 Mdot
.538 .33188 Mdot
.538 .33188 Mdot
.538 .33188 Mdot
.538 .33189 Mdot
.538 .33189 Mdot
.538 .33189 Mdot
.538 .33189 Mdot
.538 .33189 Mdot
.538 .33189 Mdot
.538 .33189 Mdot
.538 .33189 Mdot
.538 .33189 Mdot
.538 .33189 Mdot
.538 .33189 Mdot
.538 .33189 Mdot
.538 .33189 Mdot
.538 .3319 Mdot
.538 .3319 Mdot
.538 .3319 Mdot
.538 .3319 Mdot
.538 .3319 Mdot
.538 .3319 Mdot
.538 .3319 Mdot
.538 .33191 Mdot
.538 .33191 Mdot
.538 .33191 Mdot
.538 .33191 Mdot
.538 .33191 Mdot
.538 .33191 Mdot
.538 .33191 Mdot
.538 .33191 Mdot
.538 .33191 Mdot
.538 .33191 Mdot
.538 .33191 Mdot
.538 .33192 Mdot
.538 .33192 Mdot
.538 .33192 Mdot
.538 .33192 Mdot
.538 .33192 Mdot
.538 .33192 Mdot
.538 .33192 Mdot
.538 .33192 Mdot
.538 .33193 Mdot
.538 .33193 Mdot
.538 .33193 Mdot
.538 .33193 Mdot
.538 .33193 Mdot
.538 .33193 Mdot
.538 .33193 Mdot
.538 .33193 Mdot
.538 .33193 Mdot
.538 .33193 Mdot
.538 .33194 Mdot
.538 .33194 Mdot
.538 .33194 Mdot
.538 .33194 Mdot
.538 .33194 Mdot
.538 .33195 Mdot
.538 .33195 Mdot
.538 .33195 Mdot
.538 .33195 Mdot
.538 .33196 Mdot
.538 .33196 Mdot
.538 .33202 Mdot
.538 .33202 Mdot
.538 .33202 Mdot
.538 .33202 Mdot
.538 .33202 Mdot
.538 .33202 Mdot
.538 .33203 Mdot
.538 .33203 Mdot
.538 .33203 Mdot
.538 .33203 Mdot
.538 .33203 Mdot
.538 .33203 Mdot
.538 .33203 Mdot
.538 .33204 Mdot
.538 .33204 Mdot
.538 .33204 Mdot
.538 .33204 Mdot
.538 .33204 Mdot
.538 .33204 Mdot
.538 .33204 Mdot
.538 .33204 Mdot
.538 .33204 Mdot
.538 .33204 Mdot
.538 .33204 Mdot
.538 .33204 Mdot
.538 .33205 Mdot
.538 .33205 Mdot
.538 .33205 Mdot
.538 .33205 Mdot
.538 .33205 Mdot
.538 .33205 Mdot
.538 .33205 Mdot
.538 .33205 Mdot
.538 .33205 Mdot
.538 .33205 Mdot
.538 .33205 Mdot
.538 .33205 Mdot
.538 .33205 Mdot
.538 .33205 Mdot
.538 .33206 Mdot
.538 .33206 Mdot
.538 .33206 Mdot
.538 .33206 Mdot
.538 .33206 Mdot
.538 .33206 Mdot
.538 .33206 Mdot
.538 .33206 Mdot
.538 .33206 Mdot
.538 .33206 Mdot
.538 .33207 Mdot
.538 .33207 Mdot
.538 .33207 Mdot
.538 .33207 Mdot
.538 .33207 Mdot
.538 .33207 Mdot
.538 .33207 Mdot
.538 .33207 Mdot
.538 .33207 Mdot
.538 .33207 Mdot
.538 .33207 Mdot
.538 .33207 Mdot
.538 .33207 Mdot
.538 .33207 Mdot
.538 .33207 Mdot
.538 .33208 Mdot
.538 .33208 Mdot
.538 .33208 Mdot
.538 .33208 Mdot
.538 .33208 Mdot
.538 .33208 Mdot
.538 .33208 Mdot
.538 .33208 Mdot
.538 .33208 Mdot
.538 .33208 Mdot
.538 .33208 Mdot
.538 .33208 Mdot
.538 .33208 Mdot
.538 .33208 Mdot
.538 .33208 Mdot
.538 .33208 Mdot
.538 .33209 Mdot
.538 .33209 Mdot
.538 .33209 Mdot
.538 .33209 Mdot
.538 .33209 Mdot
.538 .33209 Mdot
.538 .33209 Mdot
.538 .33209 Mdot
.538 .33209 Mdot
.538 .33209 Mdot
.538 .33209 Mdot
.538 .33209 Mdot
.538 .33209 Mdot
.538 .33209 Mdot
.538 .33209 Mdot
.538 .33209 Mdot
.538 .3321 Mdot
.538 .3321 Mdot
.538 .3321 Mdot
.538 .3321 Mdot
.538 .3321 Mdot
.538 .3321 Mdot
.538 .3321 Mdot
.538 .3321 Mdot
.538 .3321 Mdot
.538 .3321 Mdot
.538 .3321 Mdot
.538 .3321 Mdot
.538 .3321 Mdot
.538 .3321 Mdot
.538 .3321 Mdot
.538 .3321 Mdot
.538 .3321 Mdot
.538 .33211 Mdot
.538 .33211 Mdot
.538 .33211 Mdot
.538 .33211 Mdot
.538 .33211 Mdot
.538 .33211 Mdot
.538 .33211 Mdot
.538 .33211 Mdot
.538 .33211 Mdot
.538 .33211 Mdot
.538 .33211 Mdot
.538 .33211 Mdot
.54 .30781 Mdot
.54 .30781 Mdot
.54 .30781 Mdot
.54 .30781 Mdot
.54 .30781 Mdot
.54 .30781 Mdot
.54 .30781 Mdot
.54 .30781 Mdot
.54 .30781 Mdot
.54 .30782 Mdot
.54 .30782 Mdot
.54 .30782 Mdot
.54 .30782 Mdot
.54 .30782 Mdot
.54 .30782 Mdot
.54 .30782 Mdot
.54 .30783 Mdot
.54 .30783 Mdot
.54 .30783 Mdot
.54 .30783 Mdot
.54 .30783 Mdot
.54 .30783 Mdot
.54 .30783 Mdot
.54 .30783 Mdot
.54 .30783 Mdot
.54 .30783 Mdot
.54 .30783 Mdot
.54 .30784 Mdot
.54 .30784 Mdot
.54 .30784 Mdot
.54 .30784 Mdot
.54 .30784 Mdot
.54 .30784 Mdot
.54 .30784 Mdot
.54 .30784 Mdot
.54 .30784 Mdot
.54 .30784 Mdot
.54 .30784 Mdot
.54 .30785 Mdot
.54 .30785 Mdot
.54 .30785 Mdot
.54 .30785 Mdot
.54 .30785 Mdot
.54 .30785 Mdot
.54 .30785 Mdot
.54 .30785 Mdot
.54 .30785 Mdot
.54 .30785 Mdot
.54 .30785 Mdot
.54 .30785 Mdot
.54 .30786 Mdot
.54 .30786 Mdot
.54 .30786 Mdot
.54 .30786 Mdot
.54 .30786 Mdot
.54 .30786 Mdot
.54 .30786 Mdot
.54 .30786 Mdot
.54 .30786 Mdot
.54 .30786 Mdot
.54 .30787 Mdot
.54 .30787 Mdot
.54 .30787 Mdot
.54 .30787 Mdot
.54 .30787 Mdot
.54 .30787 Mdot
.54 .30787 Mdot
.54 .30787 Mdot
.54 .30787 Mdot
.54 .30787 Mdot
.54 .30788 Mdot
.54 .30788 Mdot
.54 .30788 Mdot
.54 .30788 Mdot
.54 .30788 Mdot
.54 .30788 Mdot
.54 .30788 Mdot
.54 .30788 Mdot
.54 .30788 Mdot
.54 .30788 Mdot
.54 .30788 Mdot
.54 .30788 Mdot
.54 .30789 Mdot
.54 .30789 Mdot
.54 .30789 Mdot
.54 .30789 Mdot
.54 .30789 Mdot
.54 .30789 Mdot
.54 .30789 Mdot
.54 .3079 Mdot
.54 .3079 Mdot
.54 .3079 Mdot
.54 .3079 Mdot
.54 .3079 Mdot
.54 .3079 Mdot
.54 .3079 Mdot
.54 .3079 Mdot
.54 .3079 Mdot
.54 .3079 Mdot
.54 .3079 Mdot
.54 .30791 Mdot
.54 .30791 Mdot
.54 .30791 Mdot
.54 .30791 Mdot
.54 .30791 Mdot
.54 .30791 Mdot
.54 .30791 Mdot
.54 .30792 Mdot
.54 .30792 Mdot
.54 .30792 Mdot
.54 .30792 Mdot
.54 .30792 Mdot
.54 .30792 Mdot
.54 .30793 Mdot
.54 .30793 Mdot
.54 .30793 Mdot
.54 .30793 Mdot
.54 .30793 Mdot
.54 .30793 Mdot
.54 .30793 Mdot
.54 .30794 Mdot
.54 .30794 Mdot
.54 .30794 Mdot
.54 .30794 Mdot
.54 .30794 Mdot
.54 .308 Mdot
.54 .308 Mdot
.54 .308 Mdot
.54 .308 Mdot
.54 .308 Mdot
.54 .308 Mdot
.54 .30801 Mdot
.54 .30801 Mdot
.54 .30801 Mdot
.54 .30801 Mdot
.54 .30802 Mdot
.54 .30802 Mdot
.54 .30802 Mdot
.54 .30802 Mdot
.54 .30802 Mdot
.54 .30803 Mdot
.54 .30803 Mdot
.54 .30803 Mdot
.54 .30803 Mdot
.54 .30803 Mdot
.54 .30804 Mdot
.54 .30804 Mdot
.54 .30804 Mdot
.54 .30804 Mdot
.54 .30804 Mdot
.54 .30804 Mdot
.54 .30805 Mdot
.54 .30805 Mdot
.54 .30805 Mdot
.54 .30805 Mdot
.54 .30805 Mdot
.54 .30805 Mdot
.54 .30805 Mdot
.54 .30805 Mdot
.54 .30805 Mdot
.54 .30805 Mdot
.54 .30806 Mdot
.54 .30806 Mdot
.54 .30806 Mdot
.54 .30806 Mdot
.54 .30806 Mdot
.54 .30806 Mdot
.54 .30807 Mdot
.54 .30807 Mdot
.54 .30807 Mdot
.54 .30807 Mdot
.54 .30808 Mdot
.54 .30808 Mdot
.54 .30808 Mdot
.54 .30808 Mdot
.54 .30808 Mdot
.54 .30808 Mdot
.54 .30808 Mdot
.54 .30808 Mdot
.54 .30808 Mdot
.54 .30809 Mdot
.54 .30809 Mdot
.54 .30809 Mdot
.54 .30809 Mdot
.54 .30809 Mdot
.54 .30809 Mdot
.54 .30809 Mdot
.54 .30809 Mdot
.54 .3081 Mdot
.54 .3081 Mdot
.54 .3081 Mdot
.54 .3081 Mdot
.54 .3081 Mdot
.54 .3081 Mdot
.54 .30811 Mdot
.54 .30811 Mdot
.54 .30811 Mdot
.54 .30811 Mdot
.54 .30811 Mdot
.54 .30811 Mdot
.54 .30811 Mdot
.54 .30811 Mdot
.54 .30812 Mdot
.54 .30812 Mdot
.54 .30812 Mdot
.54 .30812 Mdot
.54 .30812 Mdot
.54 .30812 Mdot
.54 .30812 Mdot
.54 .30812 Mdot
.54 .30812 Mdot
.54 .30812 Mdot
.54 .30813 Mdot
.54 .30813 Mdot
.54 .30813 Mdot
.54 .30813 Mdot
.54 .30813 Mdot
.54 .30813 Mdot
.54 .30813 Mdot
.54 .30813 Mdot
.54 .30814 Mdot
.54 .30814 Mdot
.54 .30814 Mdot
.54 .30814 Mdot
.54 .30814 Mdot
.54 .30814 Mdot
.54 .30814 Mdot
.54 .30814 Mdot
.54 .30815 Mdot
.54 .30815 Mdot
.54 .30815 Mdot
.54 .30815 Mdot
.54 .30815 Mdot
.54 .30815 Mdot
.54 .30815 Mdot
.54 .30815 Mdot
.54 .30815 Mdot
.54 .30816 Mdot
.54 .30816 Mdot
.54 .30816 Mdot
.54 .30816 Mdot
.54 .30817 Mdot
.54 .30817 Mdot
.54 .30817 Mdot
.54 .30817 Mdot
.54 .30817 Mdot
.54 .30817 Mdot
.54 .30817 Mdot
.54 .30817 Mdot
.54 .30817 Mdot
.54 .30817 Mdot
.54 .30958 Mdot
.54 .30958 Mdot
.54 .30959 Mdot
.54 .30959 Mdot
.54 .30959 Mdot
.54 .30959 Mdot
.54 .30959 Mdot
.54 .30959 Mdot
.54 .30959 Mdot
.54 .30959 Mdot
.54 .3096 Mdot
.54 .3096 Mdot
.54 .3096 Mdot
.54 .3096 Mdot
.54 .30961 Mdot
.54 .30961 Mdot
.54 .30961 Mdot
.54 .30961 Mdot
.54 .30961 Mdot
.54 .30962 Mdot
.54 .30962 Mdot
.54 .30962 Mdot
.54 .30962 Mdot
.54 .30962 Mdot
.54 .30962 Mdot
.54 .30962 Mdot
.54 .30962 Mdot
.54 .30963 Mdot
.54 .30963 Mdot
.54 .30963 Mdot
.54 .30963 Mdot
.54 .30963 Mdot
.54 .30963 Mdot
.54 .30964 Mdot
.54 .30964 Mdot
.54 .30964 Mdot
.54 .30964 Mdot
.54 .30964 Mdot
.54 .30964 Mdot
.54 .30964 Mdot
.54 .30964 Mdot
.54 .30964 Mdot
.54 .30965 Mdot
.54 .30965 Mdot
.54 .30965 Mdot
.54 .30965 Mdot
.54 .30965 Mdot
.54 .30965 Mdot
.54 .30966 Mdot
.54 .30966 Mdot
.54 .30966 Mdot
.54 .30966 Mdot
.54 .30966 Mdot
.54 .30966 Mdot
.54 .30966 Mdot
.54 .30966 Mdot
.54 .30967 Mdot
.54 .30967 Mdot
.54 .30967 Mdot
.54 .30967 Mdot
.54 .30967 Mdot
.54 .30967 Mdot
.54 .30968 Mdot
.54 .30968 Mdot
.54 .30968 Mdot
.54 .30968 Mdot
.54 .30968 Mdot
.54 .30968 Mdot
.54 .30968 Mdot
.54 .30969 Mdot
.54 .30969 Mdot
.54 .30969 Mdot
.54 .30969 Mdot
.54 .30969 Mdot
.54 .30969 Mdot
.54 .3097 Mdot
.54 .3097 Mdot
.54 .3097 Mdot
.54 .3097 Mdot
.54 .3097 Mdot
.54 .3097 Mdot
.54 .3097 Mdot
.54 .30971 Mdot
.54 .30971 Mdot
.54 .30971 Mdot
.54 .30971 Mdot
.54 .30972 Mdot
.54 .30972 Mdot
.54 .30972 Mdot
.54 .30972 Mdot
.54 .30972 Mdot
.54 .30973 Mdot
.54 .30973 Mdot
.54 .30973 Mdot
.54 .30973 Mdot
.54 .30973 Mdot
.54 .30973 Mdot
.54 .30973 Mdot
.54 .30973 Mdot
.54 .30974 Mdot
.54 .30974 Mdot
.54 .30974 Mdot
.54 .30974 Mdot
.54 .30975 Mdot
.54 .30975 Mdot
.54 .30975 Mdot
.54 .30975 Mdot
.54 .30975 Mdot
.54 .30975 Mdot
.54 .30976 Mdot
.54 .30976 Mdot
.54 .30976 Mdot
.54 .30977 Mdot
.54 .30977 Mdot
.54 .30977 Mdot
.54 .30977 Mdot
.54 .30978 Mdot
.54 .30978 Mdot
.54 .30978 Mdot
.54 .30978 Mdot
.54 .30978 Mdot
.54 .30979 Mdot
.54 .30979 Mdot
.54 .30979 Mdot
.54 .30979 Mdot
.54 .30986 Mdot
.54 .30986 Mdot
.54 .30986 Mdot
.54 .30986 Mdot
.54 .30986 Mdot
.54 .30986 Mdot
.54 .30987 Mdot
.54 .30987 Mdot
.54 .30987 Mdot
.54 .30987 Mdot
.54 .30987 Mdot
.54 .30987 Mdot
.54 .30988 Mdot
.54 .30988 Mdot
.54 .30988 Mdot
.54 .30988 Mdot
.54 .30988 Mdot
.54 .30989 Mdot
.54 .30989 Mdot
.54 .30989 Mdot
.54 .30989 Mdot
.54 .30989 Mdot
.54 .30989 Mdot
.54 .3099 Mdot
.54 .3099 Mdot
.54 .3099 Mdot
.54 .3099 Mdot
.54 .3099 Mdot
.54 .3099 Mdot
.54 .3099 Mdot
.54 .3099 Mdot
.54 .30991 Mdot
.54 .30991 Mdot
.54 .30991 Mdot
.54 .30991 Mdot
.54 .30991 Mdot
.54 .30991 Mdot
.54 .30991 Mdot
.54 .30991 Mdot
.54 .30991 Mdot
.54 .30991 Mdot
.54 .30992 Mdot
.54 .30992 Mdot
.54 .30992 Mdot
.54 .30992 Mdot
.54 .30992 Mdot
.54 .30993 Mdot
.54 .30993 Mdot
.54 .30993 Mdot
.54 .30993 Mdot
.54 .30993 Mdot
.54 .30993 Mdot
.54 .30993 Mdot
.54 .30993 Mdot
.54 .30993 Mdot
.54 .30993 Mdot
.54 .30994 Mdot
.54 .30994 Mdot
.54 .30994 Mdot
.54 .30994 Mdot
.54 .30994 Mdot
.54 .30994 Mdot
.54 .30994 Mdot
.54 .30994 Mdot
.54 .30994 Mdot
.54 .30995 Mdot
.54 .30995 Mdot
.54 .30995 Mdot
.54 .30995 Mdot
.54 .30995 Mdot
.54 .30995 Mdot
.54 .30995 Mdot
.54 .30995 Mdot
.54 .30995 Mdot
.54 .30996 Mdot
.54 .30996 Mdot
.54 .30996 Mdot
.54 .30996 Mdot
.54 .30996 Mdot
.54 .30996 Mdot
.54 .30996 Mdot
.54 .30996 Mdot
.54 .30996 Mdot
.54 .30997 Mdot
.54 .30997 Mdot
.54 .30997 Mdot
.54 .30997 Mdot
.54 .30997 Mdot
.54 .30997 Mdot
.54 .30997 Mdot
.54 .30997 Mdot
.54 .30997 Mdot
.54 .30997 Mdot
.54 .30997 Mdot
.54 .30998 Mdot
.54 .30998 Mdot
.54 .30998 Mdot
.54 .30998 Mdot
.54 .30998 Mdot
.54 .30998 Mdot
.54 .30998 Mdot
.54 .30998 Mdot
.54 .30998 Mdot
.54 .30999 Mdot
.54 .30999 Mdot
.54 .30999 Mdot
.54 .30999 Mdot
.54 .30999 Mdot
.54 .30999 Mdot
.54 .30999 Mdot
.54 .30999 Mdot
.54 .30999 Mdot
.54 .31 Mdot
.54 .31 Mdot
.54 .31 Mdot
.54 .31 Mdot
.54 .31 Mdot
.54 .31 Mdot
.54 .31001 Mdot
.54 .31001 Mdot
.54 .31001 Mdot
.54 .31001 Mdot
.54 .31001 Mdot
.54 .31001 Mdot
.54 .31001 Mdot
.54 .33126 Mdot
.54 .33126 Mdot
.54 .33126 Mdot
.54 .33126 Mdot
.54 .33126 Mdot
.54 .33126 Mdot
.54 .33126 Mdot
.54 .33126 Mdot
.54 .33126 Mdot
.54 .33127 Mdot
.54 .33127 Mdot
.54 .33127 Mdot
.54 .33127 Mdot
.54 .33127 Mdot
.54 .33127 Mdot
.54 .33127 Mdot
.54 .33128 Mdot
.54 .33128 Mdot
.54 .33128 Mdot
.54 .33128 Mdot
.54 .33128 Mdot
.54 .33128 Mdot
.54 .33128 Mdot
.54 .33128 Mdot
.54 .33128 Mdot
.54 .33128 Mdot
.54 .33128 Mdot
.54 .33128 Mdot
.54 .33128 Mdot
.54 .33129 Mdot
.54 .33129 Mdot
.54 .33129 Mdot
.54 .33129 Mdot
.54 .33129 Mdot
.54 .33129 Mdot
.54 .33129 Mdot
.54 .33129 Mdot
.54 .33129 Mdot
.54 .3313 Mdot
.54 .3313 Mdot
.54 .3313 Mdot
.54 .3313 Mdot
.54 .3313 Mdot
.54 .3313 Mdot
.54 .3313 Mdot
.54 .3313 Mdot
.54 .3313 Mdot
.54 .3313 Mdot
.54 .33131 Mdot
.54 .33131 Mdot
.54 .33131 Mdot
.54 .33131 Mdot
.54 .33131 Mdot
.54 .33131 Mdot
.54 .33131 Mdot
.54 .33131 Mdot
.54 .33131 Mdot
.54 .33132 Mdot
.54 .33132 Mdot
.54 .33132 Mdot
.54 .33132 Mdot
.54 .33132 Mdot
.54 .33132 Mdot
.54 .33132 Mdot
.54 .33132 Mdot
.54 .33132 Mdot
.54 .33132 Mdot
.54 .33132 Mdot
.54 .33132 Mdot
.54 .33133 Mdot
.54 .33133 Mdot
.54 .33133 Mdot
.54 .33133 Mdot
.54 .33133 Mdot
.54 .33133 Mdot
.54 .33133 Mdot
.54 .33133 Mdot
.54 .33133 Mdot
.54 .33133 Mdot
.54 .33134 Mdot
.54 .33134 Mdot
.54 .33134 Mdot
.54 .33134 Mdot
.54 .33134 Mdot
.54 .33135 Mdot
.54 .33135 Mdot
.54 .33135 Mdot
.54 .33135 Mdot
.54 .33135 Mdot
.54 .33135 Mdot
.54 .33135 Mdot
.54 .33135 Mdot
.54 .33135 Mdot
.54 .33135 Mdot
.54 .33136 Mdot
.54 .33136 Mdot
.54 .33136 Mdot
.54 .33136 Mdot
.54 .33136 Mdot
.54 .33136 Mdot
.54 .33136 Mdot
.54 .33136 Mdot
.54 .33137 Mdot
.54 .33137 Mdot
.54 .33137 Mdot
.54 .33137 Mdot
.54 .33137 Mdot
.54 .33137 Mdot
.54 .33137 Mdot
.54 .33137 Mdot
.54 .33138 Mdot
.54 .33138 Mdot
.54 .33138 Mdot
.54 .33138 Mdot
.54 .33138 Mdot
.54 .33139 Mdot
.54 .33139 Mdot
.54 .33139 Mdot
.54 .33139 Mdot
.54 .33139 Mdot
.54 .33139 Mdot
.54 .3314 Mdot
.54 .3314 Mdot
.54 .3314 Mdot
.54 .3314 Mdot
.54 .33146 Mdot
.54 .33146 Mdot
.54 .33146 Mdot
.54 .33146 Mdot
.54 .33146 Mdot
.54 .33147 Mdot
.54 .33147 Mdot
.54 .33147 Mdot
.54 .33147 Mdot
.54 .33148 Mdot
.54 .33148 Mdot
.54 .33148 Mdot
.54 .33148 Mdot
.54 .33149 Mdot
.54 .33149 Mdot
.54 .33149 Mdot
.54 .33149 Mdot
.54 .3315 Mdot
.54 .3315 Mdot
.54 .3315 Mdot
.54 .3315 Mdot
.54 .3315 Mdot
.54 .3315 Mdot
.54 .33151 Mdot
.54 .33151 Mdot
.54 .33151 Mdot
.54 .33151 Mdot
.54 .33151 Mdot
.54 .33151 Mdot
.54 .33152 Mdot
.54 .33152 Mdot
.54 .33152 Mdot
.54 .33152 Mdot
.54 .33152 Mdot
.54 .33152 Mdot
.54 .33152 Mdot
.54 .33153 Mdot
.54 .33153 Mdot
.54 .33153 Mdot
.54 .33153 Mdot
.54 .33153 Mdot
.54 .33153 Mdot
.54 .33153 Mdot
.54 .33154 Mdot
.54 .33154 Mdot
.54 .33154 Mdot
.54 .33155 Mdot
.54 .33155 Mdot
.54 .33155 Mdot
.54 .33155 Mdot
.54 .33155 Mdot
.54 .33155 Mdot
.54 .33155 Mdot
.54 .33155 Mdot
.54 .33155 Mdot
.54 .33156 Mdot
.54 .33156 Mdot
.54 .33156 Mdot
.54 .33156 Mdot
.54 .33156 Mdot
.54 .33156 Mdot
.54 .33156 Mdot
.54 .33157 Mdot
.54 .33157 Mdot
.54 .33157 Mdot
.54 .33157 Mdot
.54 .33157 Mdot
.54 .33157 Mdot
.54 .33157 Mdot
.54 .33158 Mdot
.54 .33158 Mdot
.54 .33158 Mdot
.54 .33158 Mdot
.54 .33158 Mdot
.54 .33158 Mdot
.54 .33158 Mdot
.54 .33158 Mdot
.54 .33159 Mdot
.54 .33159 Mdot
.54 .33159 Mdot
.54 .33159 Mdot
.54 .33159 Mdot
.54 .33159 Mdot
.54 .33159 Mdot
.54 .33159 Mdot
.54 .3316 Mdot
.54 .3316 Mdot
.54 .3316 Mdot
.54 .3316 Mdot
.54 .3316 Mdot
.54 .3316 Mdot
.54 .3316 Mdot
.54 .3316 Mdot
.54 .33161 Mdot
.54 .33161 Mdot
.54 .33161 Mdot
.54 .33161 Mdot
.54 .33161 Mdot
.54 .33161 Mdot
.54 .33162 Mdot
.54 .33162 Mdot
.54 .33162 Mdot
.54 .33162 Mdot
.54 .33162 Mdot
.54 .33162 Mdot
.54 .33162 Mdot
.54 .33162 Mdot
.54 .33162 Mdot
.54 .33163 Mdot
.54 .33163 Mdot
.54 .33163 Mdot
.54 .33163 Mdot
.54 .33164 Mdot
.54 .33164 Mdot
.54 .33164 Mdot
.54 .33164 Mdot
.54 .33164 Mdot
.54 .33165 Mdot
.54 .33165 Mdot
.54 .33165 Mdot
.54 .33165 Mdot
.54 .33165 Mdot
.54 .33165 Mdot
.54 .33165 Mdot
.54 .33165 Mdot
.54 .33296 Mdot
.54 .33296 Mdot
.54 .33296 Mdot
.54 .33296 Mdot
.54 .33296 Mdot
.54 .33296 Mdot
.54 .33296 Mdot
.54 .33296 Mdot
.54 .33296 Mdot
.54 .33297 Mdot
.54 .33297 Mdot
.54 .33297 Mdot
.54 .33297 Mdot
.54 .33298 Mdot
.54 .33298 Mdot
.54 .33298 Mdot
.54 .33298 Mdot
.54 .33298 Mdot
.54 .33298 Mdot
.54 .33298 Mdot
.54 .33298 Mdot
.54 .33298 Mdot
.54 .33298 Mdot
.54 .33298 Mdot
.54 .33298 Mdot
.54 .33299 Mdot
.54 .33299 Mdot
.54 .33299 Mdot
.54 .33299 Mdot
.54 .33299 Mdot
.54 .33299 Mdot
.54 .33299 Mdot
.54 .333 Mdot
.54 .333 Mdot
.54 .333 Mdot
.54 .333 Mdot
.54 .333 Mdot
.54 .333 Mdot
.54 .333 Mdot
.54 .333 Mdot
.54 .333 Mdot
.54 .333 Mdot
.54 .333 Mdot
.54 .33301 Mdot
.54 .33301 Mdot
.54 .33301 Mdot
.54 .33301 Mdot
.54 .33301 Mdot
.54 .33301 Mdot
.54 .33301 Mdot
.54 .33301 Mdot
.54 .33302 Mdot
.54 .33302 Mdot
.54 .33302 Mdot
.54 .33302 Mdot
.54 .33302 Mdot
.54 .33302 Mdot
.54 .33302 Mdot
.54 .33302 Mdot
.54 .33303 Mdot
.54 .33303 Mdot
.54 .33303 Mdot
.54 .33303 Mdot
.54 .33303 Mdot
.54 .33303 Mdot
.54 .33303 Mdot
.54 .33303 Mdot
.54 .33303 Mdot
.54 .33303 Mdot
.54 .33304 Mdot
.54 .33304 Mdot
.54 .33304 Mdot
.54 .33304 Mdot
.54 .33304 Mdot
.54 .33304 Mdot
.54 .33304 Mdot
.54 .33305 Mdot
.54 .33305 Mdot
.54 .33305 Mdot
.54 .33305 Mdot
.54 .33305 Mdot
.54 .33305 Mdot
.54 .33306 Mdot
.54 .33306 Mdot
.54 .33306 Mdot
.54 .33306 Mdot
.54 .33306 Mdot
.54 .33306 Mdot
.54 .33306 Mdot
.54 .33307 Mdot
.54 .33307 Mdot
.54 .33307 Mdot
.54 .33307 Mdot
.54 .33307 Mdot
.54 .33307 Mdot
.54 .33307 Mdot
.54 .33307 Mdot
.54 .33307 Mdot
.54 .33308 Mdot
.54 .33308 Mdot
.54 .33308 Mdot
.54 .33308 Mdot
.54 .33308 Mdot
.54 .33308 Mdot
.54 .33308 Mdot
.54 .33309 Mdot
.54 .33309 Mdot
.54 .33309 Mdot
.54 .33309 Mdot
.54 .33309 Mdot
.54 .33309 Mdot
.54 .3331 Mdot
.54 .3331 Mdot
.54 .3331 Mdot
.54 .3331 Mdot
.54 .33311 Mdot
.54 .33311 Mdot
.54 .33311 Mdot
.54 .33311 Mdot
.54 .33311 Mdot
.54 .33312 Mdot
.54 .33312 Mdot
.54 .33312 Mdot
.54 .33312 Mdot
.54 .33312 Mdot
.54 .33317 Mdot
.54 .33317 Mdot
.54 .33317 Mdot
.54 .33318 Mdot
.54 .33318 Mdot
.54 .33318 Mdot
.54 .33318 Mdot
.54 .33318 Mdot
.54 .33318 Mdot
.54 .33318 Mdot
.54 .33319 Mdot
.54 .33319 Mdot
.54 .33319 Mdot
.54 .33319 Mdot
.54 .33319 Mdot
.54 .33319 Mdot
.54 .33319 Mdot
.54 .3332 Mdot
.54 .3332 Mdot
.54 .3332 Mdot
.54 .3332 Mdot
.54 .3332 Mdot
.54 .3332 Mdot
.54 .3332 Mdot
.54 .3332 Mdot
.54 .33321 Mdot
.54 .33321 Mdot
.54 .33321 Mdot
.54 .33321 Mdot
.54 .33321 Mdot
.54 .33321 Mdot
.54 .33321 Mdot
.54 .33321 Mdot
.54 .33321 Mdot
.54 .33321 Mdot
.54 .33321 Mdot
.54 .33322 Mdot
.54 .33322 Mdot
.54 .33322 Mdot
.54 .33322 Mdot
.54 .33322 Mdot
.54 .33322 Mdot
.54 .33322 Mdot
.54 .33322 Mdot
.54 .33323 Mdot
.54 .33323 Mdot
.54 .33323 Mdot
.54 .33323 Mdot
.54 .33323 Mdot
.54 .33323 Mdot
.54 .33323 Mdot
.54 .33323 Mdot
.54 .33323 Mdot
.54 .33323 Mdot
.54 .33323 Mdot
.54 .33323 Mdot
.54 .33324 Mdot
.54 .33324 Mdot
.54 .33324 Mdot
.54 .33324 Mdot
.54 .33324 Mdot
.54 .33324 Mdot
.54 .33324 Mdot
.54 .33324 Mdot
.54 .33324 Mdot
.54 .33324 Mdot
.54 .33324 Mdot
.54 .33324 Mdot
.54 .33325 Mdot
.54 .33325 Mdot
.54 .33325 Mdot
.54 .33325 Mdot
.54 .33325 Mdot
.54 .33325 Mdot
.54 .33325 Mdot
.54 .33325 Mdot
.54 .33325 Mdot
.54 .33325 Mdot
.54 .33325 Mdot
.54 .33326 Mdot
.54 .33326 Mdot
.54 .33326 Mdot
.54 .33326 Mdot
.54 .33326 Mdot
.54 .33326 Mdot
.54 .33326 Mdot
.54 .33326 Mdot
.54 .33326 Mdot
.54 .33326 Mdot
.54 .33326 Mdot
.54 .33326 Mdot
.54 .33326 Mdot
.54 .33326 Mdot
.54 .33327 Mdot
.54 .33327 Mdot
.54 .33327 Mdot
.54 .33327 Mdot
.54 .33327 Mdot
.54 .33327 Mdot
.54 .33327 Mdot
.54 .33327 Mdot
.54 .33327 Mdot
.54 .33327 Mdot
.54 .33327 Mdot
.54 .33328 Mdot
.54 .33328 Mdot
.54 .33328 Mdot
.54 .33328 Mdot
.54 .33328 Mdot
.54 .33328 Mdot
.54 .33328 Mdot
.54 .33328 Mdot
.54 .33328 Mdot
.54 .33329 Mdot
.54 .33329 Mdot
.54 .33329 Mdot
.54 .33329 Mdot
.54 .33329 Mdot
.54 .33329 Mdot
.54 .33329 Mdot
.54 .33329 Mdot
.54 .33329 Mdot
.54 .33329 Mdot
.54 .33329 Mdot
.54 .33329 Mdot
.542 .30762 Mdot
.542 .30762 Mdot
.542 .30762 Mdot
.542 .30762 Mdot
.542 .30762 Mdot
.542 .30762 Mdot
.542 .30762 Mdot
.542 .30762 Mdot
.542 .30762 Mdot
.542 .30762 Mdot
.542 .30763 Mdot
.542 .30763 Mdot
.542 .30763 Mdot
.542 .30763 Mdot
.542 .30763 Mdot
.542 .30763 Mdot
.542 .30764 Mdot
.542 .30764 Mdot
.542 .30764 Mdot
.542 .30764 Mdot
.542 .30764 Mdot
.542 .30765 Mdot
.542 .30765 Mdot
.542 .30765 Mdot
.542 .30765 Mdot
.542 .30765 Mdot
.542 .30765 Mdot
.542 .30765 Mdot
.542 .30765 Mdot
.542 .30765 Mdot
.542 .30765 Mdot
.542 .30766 Mdot
.542 .30766 Mdot
.542 .30766 Mdot
.542 .30766 Mdot
.542 .30766 Mdot
.542 .30766 Mdot
.542 .30766 Mdot
.542 .30766 Mdot
.542 .30766 Mdot
.542 .30767 Mdot
.542 .30767 Mdot
.542 .30767 Mdot
.542 .30767 Mdot
.542 .30767 Mdot
.542 .30767 Mdot
.542 .30767 Mdot
.542 .30767 Mdot
.542 .30767 Mdot
.542 .30767 Mdot
.542 .30767 Mdot
.542 .30767 Mdot
.542 .30767 Mdot
.542 .30767 Mdot
.542 .30767 Mdot
.542 .30768 Mdot
.542 .30768 Mdot
.542 .30768 Mdot
.542 .30768 Mdot
.542 .30768 Mdot
.542 .30768 Mdot
.542 .30768 Mdot
.542 .30768 Mdot
.542 .30768 Mdot
.542 .30769 Mdot
.542 .30769 Mdot
.542 .30769 Mdot
.542 .3077 Mdot
.542 .3077 Mdot
.542 .3077 Mdot
.542 .3077 Mdot
.542 .3077 Mdot
.542 .3077 Mdot
.542 .3077 Mdot
.542 .3077 Mdot
.542 .3077 Mdot
.542 .30771 Mdot
.542 .30771 Mdot
.542 .30771 Mdot
.542 .30771 Mdot
.542 .30771 Mdot
.542 .30771 Mdot
.542 .30771 Mdot
.542 .30772 Mdot
.542 .30772 Mdot
.542 .30772 Mdot
.542 .30772 Mdot
.542 .30772 Mdot
.542 .30772 Mdot
.542 .30772 Mdot
.542 .30772 Mdot
.542 .30772 Mdot
.542 .30772 Mdot
.542 .30773 Mdot
.542 .30773 Mdot
.542 .30773 Mdot
.542 .30773 Mdot
.542 .30773 Mdot
.542 .30773 Mdot
.542 .30773 Mdot
.542 .30773 Mdot
.542 .30773 Mdot
.542 .30774 Mdot
.542 .30774 Mdot
.542 .30775 Mdot
.542 .30775 Mdot
.542 .30775 Mdot
.542 .30775 Mdot
.542 .30775 Mdot
.542 .30775 Mdot
.542 .30776 Mdot
.542 .30776 Mdot
.542 .30776 Mdot
.542 .30776 Mdot
.542 .30776 Mdot
.542 .30776 Mdot
.542 .30776 Mdot
.542 .30776 Mdot
.542 .30776 Mdot
.542 .30777 Mdot
.542 .30777 Mdot
.542 .30777 Mdot
.542 .30778 Mdot
.542 .30778 Mdot
.542 .30778 Mdot
.542 .30782 Mdot
.542 .30782 Mdot
.542 .30782 Mdot
.542 .30782 Mdot
.542 .30783 Mdot
.542 .30783 Mdot
.542 .30784 Mdot
.542 .30784 Mdot
.542 .30784 Mdot
.542 .30784 Mdot
.542 .30784 Mdot
.542 .30784 Mdot
.542 .30784 Mdot
.542 .30785 Mdot
.542 .30785 Mdot
.542 .30785 Mdot
.542 .30786 Mdot
.542 .30786 Mdot
.542 .30786 Mdot
.542 .30786 Mdot
.542 .30786 Mdot
.542 .30786 Mdot
.542 .30787 Mdot
.542 .30788 Mdot
.542 .30788 Mdot
.542 .30788 Mdot
.542 .30788 Mdot
.542 .30788 Mdot
.542 .30788 Mdot
.542 .30788 Mdot
.542 .30789 Mdot
.542 .30789 Mdot
.542 .30789 Mdot
.542 .30789 Mdot
.542 .3079 Mdot
.542 .3079 Mdot
.542 .3079 Mdot
.542 .3079 Mdot
.542 .3079 Mdot
.542 .3079 Mdot
.542 .3079 Mdot
.542 .3079 Mdot
.542 .3079 Mdot
.542 .30791 Mdot
.542 .30791 Mdot
.542 .30791 Mdot
.542 .30791 Mdot
.542 .30792 Mdot
.542 .30792 Mdot
.542 .30792 Mdot
.542 .30792 Mdot
.542 .30792 Mdot
.542 .30792 Mdot
.542 .30792 Mdot
.542 .30793 Mdot
.542 .30793 Mdot
.542 .30793 Mdot
.542 .30793 Mdot
.542 .30793 Mdot
.542 .30794 Mdot
.542 .30794 Mdot
.542 .30795 Mdot
.542 .30795 Mdot
.542 .30795 Mdot
.542 .30795 Mdot
.542 .30795 Mdot
.542 .30795 Mdot
.542 .30795 Mdot
.542 .30796 Mdot
.542 .30796 Mdot
.542 .30796 Mdot
.542 .30796 Mdot
.542 .30796 Mdot
.542 .30796 Mdot
.542 .30796 Mdot
.542 .30796 Mdot
.542 .30796 Mdot
.542 .30797 Mdot
.542 .30797 Mdot
.542 .30797 Mdot
.542 .30797 Mdot
.542 .30797 Mdot
.542 .30797 Mdot
.542 .30797 Mdot
.542 .30797 Mdot
.542 .30797 Mdot
.542 .30797 Mdot
.542 .30798 Mdot
.542 .30798 Mdot
.542 .30798 Mdot
.542 .30798 Mdot
.542 .30799 Mdot
.542 .30799 Mdot
.542 .30799 Mdot
.542 .30799 Mdot
.542 .30799 Mdot
.542 .30799 Mdot
.542 .30799 Mdot
.542 .30799 Mdot
.542 .308 Mdot
.542 .308 Mdot
.542 .308 Mdot
.542 .308 Mdot
.542 .308 Mdot
.542 .308 Mdot
.542 .308 Mdot
.542 .308 Mdot
.542 .308 Mdot
.542 .30801 Mdot
.542 .30801 Mdot
.542 .30802 Mdot
.542 .30802 Mdot
.542 .30802 Mdot
.542 .30802 Mdot
.542 .30803 Mdot
.542 .30803 Mdot
.542 .30803 Mdot
.542 .30803 Mdot
.542 .30803 Mdot
.542 .30803 Mdot
.542 .30804 Mdot
.542 .30804 Mdot
.542 .30804 Mdot
.542 .30804 Mdot
.542 .30804 Mdot
.542 .30804 Mdot
.542 .30956 Mdot
.542 .30956 Mdot
.542 .30956 Mdot
.542 .30956 Mdot
.542 .30956 Mdot
.542 .30956 Mdot
.542 .30957 Mdot
.542 .30957 Mdot
.542 .30957 Mdot
.542 .30957 Mdot
.542 .30957 Mdot
.542 .30958 Mdot
.542 .30958 Mdot
.542 .30958 Mdot
.542 .30959 Mdot
.542 .30959 Mdot
.542 .3096 Mdot
.542 .3096 Mdot
.542 .3096 Mdot
.542 .30961 Mdot
.542 .30961 Mdot
.542 .30961 Mdot
.542 .30961 Mdot
.542 .30961 Mdot
.542 .30961 Mdot
.542 .30961 Mdot
.542 .30961 Mdot
.542 .30962 Mdot
.542 .30962 Mdot
.542 .30962 Mdot
.542 .30962 Mdot
.542 .30962 Mdot
.542 .30962 Mdot
.542 .30962 Mdot
.542 .30963 Mdot
.542 .30963 Mdot
.542 .30963 Mdot
.542 .30964 Mdot
.542 .30964 Mdot
.542 .30964 Mdot
.542 .30964 Mdot
.542 .30964 Mdot
.542 .30964 Mdot
.542 .30964 Mdot
.542 .30964 Mdot
.542 .30965 Mdot
.542 .30965 Mdot
.542 .30965 Mdot
.542 .30965 Mdot
.542 .30965 Mdot
.542 .30965 Mdot
.542 .30965 Mdot
.542 .30965 Mdot
.542 .30965 Mdot
.542 .30965 Mdot
.542 .30966 Mdot
.542 .30966 Mdot
.542 .30966 Mdot
.542 .30966 Mdot
.542 .30966 Mdot
.542 .30966 Mdot
.542 .30967 Mdot
.542 .30967 Mdot
.542 .30967 Mdot
.542 .30967 Mdot
.542 .30967 Mdot
.542 .30968 Mdot
.542 .30969 Mdot
.542 .30969 Mdot
.542 .30969 Mdot
.542 .3097 Mdot
.542 .3097 Mdot
.542 .3097 Mdot
.542 .3097 Mdot
.542 .3097 Mdot
.542 .3097 Mdot
.542 .3097 Mdot
.542 .30971 Mdot
.542 .30971 Mdot
.542 .30971 Mdot
.542 .30971 Mdot
.542 .30971 Mdot
.542 .30972 Mdot
.542 .30972 Mdot
.542 .30972 Mdot
.542 .30972 Mdot
.542 .30972 Mdot
.542 .30972 Mdot
.542 .30973 Mdot
.542 .30973 Mdot
.542 .30973 Mdot
.542 .30973 Mdot
.542 .30973 Mdot
.542 .30974 Mdot
.542 .30974 Mdot
.542 .30974 Mdot
.542 .30974 Mdot
.542 .30974 Mdot
.542 .30975 Mdot
.542 .30975 Mdot
.542 .30975 Mdot
.542 .30975 Mdot
.542 .30975 Mdot
.542 .30977 Mdot
.542 .30977 Mdot
.542 .30977 Mdot
.542 .30977 Mdot
.542 .30978 Mdot
.542 .30978 Mdot
.542 .30978 Mdot
.542 .30979 Mdot
.542 .30979 Mdot
.542 .30979 Mdot
.542 .30979 Mdot
.542 .30979 Mdot
.542 .3098 Mdot
.542 .3098 Mdot
.542 .3098 Mdot
.542 .3098 Mdot
.542 .30981 Mdot
.542 .30981 Mdot
.542 .30981 Mdot
.542 .30982 Mdot
.542 .30982 Mdot
.542 .30982 Mdot
.542 .30987 Mdot
.542 .30987 Mdot
.542 .30987 Mdot
.542 .30987 Mdot
.542 .30988 Mdot
.542 .30988 Mdot
.542 .30989 Mdot
.542 .30989 Mdot
.542 .30989 Mdot
.542 .30989 Mdot
.542 .30989 Mdot
.542 .30989 Mdot
.542 .30989 Mdot
.542 .30989 Mdot
.542 .3099 Mdot
.542 .3099 Mdot
.542 .3099 Mdot
.542 .3099 Mdot
.542 .3099 Mdot
.542 .30991 Mdot
.542 .30991 Mdot
.542 .30991 Mdot
.542 .30992 Mdot
.542 .30992 Mdot
.542 .30992 Mdot
.542 .30992 Mdot
.542 .30992 Mdot
.542 .30993 Mdot
.542 .30993 Mdot
.542 .30993 Mdot
.542 .30993 Mdot
.542 .30993 Mdot
.542 .30993 Mdot
.542 .30993 Mdot
.542 .30994 Mdot
.542 .30994 Mdot
.542 .30994 Mdot
.542 .30994 Mdot
.542 .30994 Mdot
.542 .30994 Mdot
.542 .30994 Mdot
.542 .30994 Mdot
.542 .30995 Mdot
.542 .30995 Mdot
.542 .30995 Mdot
.542 .30995 Mdot
.542 .30995 Mdot
.542 .30995 Mdot
.542 .30995 Mdot
.542 .30996 Mdot
.542 .30996 Mdot
.542 .30996 Mdot
.542 .30996 Mdot
.542 .30996 Mdot
.542 .30996 Mdot
.542 .30996 Mdot
.542 .30996 Mdot
.542 .30997 Mdot
.542 .30997 Mdot
.542 .30998 Mdot
.542 .30998 Mdot
.542 .30998 Mdot
.542 .30998 Mdot
.542 .30998 Mdot
.542 .30998 Mdot
.542 .30998 Mdot
.542 .30999 Mdot
.542 .30999 Mdot
.542 .30999 Mdot
.542 .30999 Mdot
.542 .30999 Mdot
.542 .30999 Mdot
.542 .30999 Mdot
.542 .30999 Mdot
.542 .30999 Mdot
.542 .30999 Mdot
.542 .30999 Mdot
.542 .31 Mdot
.542 .31 Mdot
.542 .31 Mdot
.542 .31 Mdot
.542 .31 Mdot
.542 .31 Mdot
.542 .31 Mdot
.542 .31 Mdot
.542 .31 Mdot
.542 .31 Mdot
.542 .31 Mdot
.542 .31001 Mdot
.542 .31001 Mdot
.542 .31001 Mdot
.542 .31001 Mdot
.542 .31001 Mdot
.542 .31001 Mdot
.542 .31001 Mdot
.542 .31002 Mdot
.542 .31002 Mdot
.542 .31002 Mdot
.542 .31002 Mdot
.542 .31002 Mdot
.542 .31002 Mdot
.542 .31002 Mdot
.542 .31002 Mdot
.542 .31002 Mdot
.542 .31003 Mdot
.542 .31003 Mdot
.542 .31003 Mdot
.542 .31003 Mdot
.542 .31003 Mdot
.542 .31004 Mdot
.542 .31004 Mdot
.542 .31004 Mdot
.542 .31004 Mdot
.542 .31005 Mdot
.542 .31005 Mdot
.542 .31005 Mdot
.542 .31005 Mdot
.542 .31005 Mdot
.542 .31005 Mdot
.542 .31006 Mdot
.542 .31006 Mdot
.542 .31006 Mdot
.542 .31006 Mdot
.542 .31006 Mdot
.542 .31006 Mdot
.542 .33222 Mdot
.542 .33222 Mdot
.542 .33222 Mdot
.542 .33222 Mdot
.542 .33222 Mdot
.542 .33222 Mdot
.542 .33223 Mdot
.542 .33223 Mdot
.542 .33223 Mdot
.542 .33223 Mdot
.542 .33223 Mdot
.542 .33223 Mdot
.542 .33224 Mdot
.542 .33224 Mdot
.542 .33224 Mdot
.542 .33224 Mdot
.542 .33225 Mdot
.542 .33225 Mdot
.542 .33225 Mdot
.542 .33225 Mdot
.542 .33225 Mdot
.542 .33225 Mdot
.542 .33225 Mdot
.542 .33225 Mdot
.542 .33225 Mdot
.542 .33225 Mdot
.542 .33226 Mdot
.542 .33226 Mdot
.542 .33226 Mdot
.542 .33226 Mdot
.542 .33226 Mdot
.542 .33226 Mdot
.542 .33226 Mdot
.542 .33226 Mdot
.542 .33226 Mdot
.542 .33227 Mdot
.542 .33227 Mdot
.542 .33227 Mdot
.542 .33227 Mdot
.542 .33227 Mdot
.542 .33227 Mdot
.542 .33227 Mdot
.542 .33227 Mdot
.542 .33228 Mdot
.542 .33228 Mdot
.542 .33228 Mdot
.542 .33228 Mdot
.542 .33228 Mdot
.542 .33228 Mdot
.542 .33228 Mdot
.542 .33228 Mdot
.542 .33228 Mdot
.542 .33228 Mdot
.542 .33228 Mdot
.542 .33228 Mdot
.542 .33228 Mdot
.542 .33229 Mdot
.542 .33229 Mdot
.542 .33229 Mdot
.542 .33229 Mdot
.542 .33229 Mdot
.542 .33229 Mdot
.542 .33229 Mdot
.542 .33229 Mdot
.542 .3323 Mdot
.542 .3323 Mdot
.542 .3323 Mdot
.542 .33231 Mdot
.542 .33231 Mdot
.542 .33231 Mdot
.542 .33231 Mdot
.542 .33231 Mdot
.542 .33231 Mdot
.542 .33231 Mdot
.542 .33232 Mdot
.542 .33232 Mdot
.542 .33232 Mdot
.542 .33232 Mdot
.542 .33232 Mdot
.542 .33232 Mdot
.542 .33232 Mdot
.542 .33232 Mdot
.542 .33233 Mdot
.542 .33233 Mdot
.542 .33233 Mdot
.542 .33233 Mdot
.542 .33233 Mdot
.542 .33233 Mdot
.542 .33233 Mdot
.542 .33233 Mdot
.542 .33233 Mdot
.542 .33233 Mdot
.542 .33234 Mdot
.542 .33234 Mdot
.542 .33234 Mdot
.542 .33234 Mdot
.542 .33234 Mdot
.542 .33234 Mdot
.542 .33234 Mdot
.542 .33235 Mdot
.542 .33235 Mdot
.542 .33235 Mdot
.542 .33235 Mdot
.542 .33236 Mdot
.542 .33236 Mdot
.542 .33236 Mdot
.542 .33236 Mdot
.542 .33236 Mdot
.542 .33236 Mdot
.542 .33237 Mdot
.542 .33237 Mdot
.542 .33237 Mdot
.542 .33238 Mdot
.542 .33238 Mdot
.542 .33238 Mdot
.542 .33238 Mdot
.542 .33238 Mdot
.542 .33238 Mdot
.542 .33238 Mdot
.542 .33239 Mdot
.542 .33239 Mdot
.542 .33239 Mdot
.542 .33239 Mdot
.542 .33239 Mdot
.542 .33239 Mdot
.542 .33244 Mdot
.542 .33244 Mdot
.542 .33244 Mdot
.542 .33245 Mdot
.542 .33245 Mdot
.542 .33245 Mdot
.542 .33246 Mdot
.542 .33246 Mdot
.542 .33246 Mdot
.542 .33246 Mdot
.542 .33246 Mdot
.542 .33246 Mdot
.542 .33247 Mdot
.542 .33247 Mdot
.542 .33247 Mdot
.542 .33247 Mdot
.542 .33248 Mdot
.542 .33248 Mdot
.542 .33248 Mdot
.542 .33248 Mdot
.542 .33248 Mdot
.542 .33249 Mdot
.542 .3325 Mdot
.542 .3325 Mdot
.542 .33251 Mdot
.542 .33251 Mdot
.542 .33251 Mdot
.542 .33251 Mdot
.542 .33251 Mdot
.542 .33251 Mdot
.542 .33251 Mdot
.542 .33252 Mdot
.542 .33252 Mdot
.542 .33252 Mdot
.542 .33252 Mdot
.542 .33253 Mdot
.542 .33253 Mdot
.542 .33253 Mdot
.542 .33253 Mdot
.542 .33253 Mdot
.542 .33253 Mdot
.542 .33253 Mdot
.542 .33254 Mdot
.542 .33254 Mdot
.542 .33254 Mdot
.542 .33254 Mdot
.542 .33255 Mdot
.542 .33255 Mdot
.542 .33255 Mdot
.542 .33255 Mdot
.542 .33255 Mdot
.542 .33255 Mdot
.542 .33255 Mdot
.542 .33256 Mdot
.542 .33256 Mdot
.542 .33256 Mdot
.542 .33256 Mdot
.542 .33256 Mdot
.542 .33257 Mdot
.542 .33258 Mdot
.542 .33258 Mdot
.542 .33258 Mdot
.542 .33258 Mdot
.542 .33258 Mdot
.542 .33259 Mdot
.542 .33259 Mdot
.542 .33259 Mdot
.542 .33259 Mdot
.542 .33259 Mdot
.542 .33259 Mdot
.542 .33259 Mdot
.542 .33259 Mdot
.542 .3326 Mdot
.542 .3326 Mdot
.542 .3326 Mdot
.542 .3326 Mdot
.542 .3326 Mdot
.542 .3326 Mdot
.542 .3326 Mdot
.542 .3326 Mdot
.542 .3326 Mdot
.542 .3326 Mdot
.542 .33261 Mdot
.542 .33261 Mdot
.542 .33261 Mdot
.542 .33261 Mdot
.542 .33261 Mdot
.542 .33261 Mdot
.542 .33262 Mdot
.542 .33262 Mdot
.542 .33262 Mdot
.542 .33262 Mdot
.542 .33262 Mdot
.542 .33262 Mdot
.542 .33262 Mdot
.542 .33263 Mdot
.542 .33263 Mdot
.542 .33263 Mdot
.542 .33263 Mdot
.542 .33263 Mdot
.542 .33263 Mdot
.542 .33263 Mdot
.542 .33264 Mdot
.542 .33264 Mdot
.542 .33264 Mdot
.542 .33264 Mdot
.542 .33264 Mdot
.542 .33264 Mdot
.542 .33265 Mdot
.542 .33266 Mdot
.542 .33266 Mdot
.542 .33266 Mdot
.542 .33266 Mdot
.542 .33267 Mdot
.542 .33267 Mdot
.542 .33267 Mdot
.542 .33267 Mdot
.542 .33267 Mdot
.542 .33267 Mdot
.542 .33268 Mdot
.542 .33268 Mdot
.542 .33268 Mdot
.542 .33268 Mdot
.542 .33268 Mdot
.542 .33268 Mdot
.542 .33408 Mdot
.542 .33408 Mdot
.542 .33408 Mdot
.542 .33408 Mdot
.542 .33408 Mdot
.542 .33409 Mdot
.542 .33409 Mdot
.542 .33409 Mdot
.542 .33409 Mdot
.542 .33409 Mdot
.542 .33409 Mdot
.542 .33409 Mdot
.542 .3341 Mdot
.542 .3341 Mdot
.542 .3341 Mdot
.542 .3341 Mdot
.542 .33411 Mdot
.542 .33411 Mdot
.542 .33412 Mdot
.542 .33412 Mdot
.542 .33412 Mdot
.542 .33412 Mdot
.542 .33412 Mdot
.542 .33412 Mdot
.542 .33412 Mdot
.542 .33412 Mdot
.542 .33412 Mdot
.542 .33413 Mdot
.542 .33413 Mdot
.542 .33413 Mdot
.542 .33413 Mdot
.542 .33413 Mdot
.542 .33413 Mdot
.542 .33413 Mdot
.542 .33413 Mdot
.542 .33413 Mdot
.542 .33414 Mdot
.542 .33414 Mdot
.542 .33414 Mdot
.542 .33414 Mdot
.542 .33414 Mdot
.542 .33415 Mdot
.542 .33415 Mdot
.542 .33415 Mdot
.542 .33415 Mdot
.542 .33415 Mdot
.542 .33415 Mdot
.542 .33415 Mdot
.542 .33415 Mdot
.542 .33415 Mdot
.542 .33415 Mdot
.542 .33415 Mdot
.542 .33415 Mdot
.542 .33416 Mdot
.542 .33416 Mdot
.542 .33416 Mdot
.542 .33416 Mdot
.542 .33416 Mdot
.542 .33416 Mdot
.542 .33416 Mdot
.542 .33416 Mdot
.542 .33417 Mdot
.542 .33417 Mdot
.542 .33417 Mdot
.542 .33417 Mdot
.542 .33417 Mdot
.542 .33418 Mdot
.542 .33418 Mdot
.542 .33419 Mdot
.542 .33419 Mdot
.542 .33419 Mdot
.542 .33419 Mdot
.542 .33419 Mdot
.542 .33419 Mdot
.542 .33419 Mdot
.542 .33419 Mdot
.542 .33419 Mdot
.542 .3342 Mdot
.542 .3342 Mdot
.542 .3342 Mdot
.542 .3342 Mdot
.542 .3342 Mdot
.542 .33421 Mdot
.542 .33421 Mdot
.542 .33421 Mdot
.542 .33421 Mdot
.542 .33421 Mdot
.542 .33421 Mdot
.542 .33421 Mdot
.542 .33421 Mdot
.542 .33422 Mdot
.542 .33422 Mdot
.542 .33422 Mdot
.542 .33422 Mdot
.542 .33422 Mdot
.542 .33422 Mdot
.542 .33423 Mdot
.542 .33423 Mdot
.542 .33423 Mdot
.542 .33423 Mdot
.542 .33423 Mdot
.542 .33423 Mdot
.542 .33423 Mdot
.542 .33424 Mdot
.542 .33425 Mdot
.542 .33425 Mdot
.542 .33425 Mdot
.542 .33425 Mdot
.542 .33425 Mdot
.542 .33426 Mdot
.542 .33426 Mdot
.542 .33426 Mdot
.542 .33426 Mdot
.542 .33427 Mdot
.542 .33427 Mdot
.542 .33427 Mdot
.542 .33427 Mdot
.542 .33427 Mdot
.542 .33427 Mdot
.542 .33428 Mdot
.542 .33428 Mdot
.542 .33428 Mdot
.542 .33429 Mdot
.542 .33429 Mdot
.542 .33429 Mdot
.542 .33433 Mdot
.542 .33433 Mdot
.542 .33433 Mdot
.542 .33433 Mdot
.542 .33433 Mdot
.542 .33433 Mdot
.542 .33434 Mdot
.542 .33434 Mdot
.542 .33434 Mdot
.542 .33434 Mdot
.542 .33434 Mdot
.542 .33434 Mdot
.542 .33434 Mdot
.542 .33434 Mdot
.542 .33435 Mdot
.542 .33435 Mdot
.542 .33435 Mdot
.542 .33435 Mdot
.542 .33435 Mdot
.542 .33435 Mdot
.542 .33435 Mdot
.542 .33436 Mdot
.542 .33436 Mdot
.542 .33436 Mdot
.542 .33437 Mdot
.542 .33437 Mdot
.542 .33437 Mdot
.542 .33437 Mdot
.542 .33437 Mdot
.542 .33437 Mdot
.542 .33437 Mdot
.542 .33437 Mdot
.542 .33437 Mdot
.542 .33438 Mdot
.542 .33438 Mdot
.542 .33438 Mdot
.542 .33438 Mdot
.542 .33438 Mdot
.542 .33438 Mdot
.542 .33438 Mdot
.542 .33438 Mdot
.542 .33438 Mdot
.542 .33438 Mdot
.542 .33439 Mdot
.542 .33439 Mdot
.542 .33439 Mdot
.542 .33439 Mdot
.542 .33439 Mdot
.542 .33439 Mdot
.542 .33439 Mdot
.542 .33439 Mdot
.542 .33439 Mdot
.542 .3344 Mdot
.542 .3344 Mdot
.542 .3344 Mdot
.542 .3344 Mdot
.542 .3344 Mdot
.542 .3344 Mdot
.542 .3344 Mdot
.542 .33441 Mdot
.542 .33441 Mdot
.542 .33441 Mdot
.542 .33441 Mdot
.542 .33441 Mdot
.542 .33441 Mdot
.542 .33442 Mdot
.542 .33442 Mdot
.542 .33442 Mdot
.542 .33442 Mdot
.542 .33442 Mdot
.542 .33442 Mdot
.542 .33442 Mdot
.542 .33442 Mdot
.542 .33442 Mdot
.542 .33442 Mdot
.542 .33442 Mdot
.542 .33442 Mdot
.542 .33442 Mdot
.542 .33442 Mdot
.542 .33443 Mdot
.542 .33443 Mdot
.542 .33443 Mdot
.542 .33443 Mdot
.542 .33443 Mdot
.542 .33443 Mdot
.542 .33443 Mdot
.542 .33443 Mdot
.542 .33443 Mdot
.542 .33443 Mdot
.542 .33444 Mdot
.542 .33444 Mdot
.542 .33444 Mdot
.542 .33444 Mdot
.542 .33444 Mdot
.542 .33444 Mdot
.542 .33444 Mdot
.542 .33444 Mdot
.542 .33444 Mdot
.542 .33444 Mdot
.542 .33444 Mdot
.542 .33444 Mdot
.542 .33445 Mdot
.542 .33445 Mdot
.542 .33445 Mdot
.542 .33445 Mdot
.542 .33445 Mdot
.542 .33445 Mdot
.542 .33445 Mdot
.542 .33445 Mdot
.542 .33446 Mdot
.542 .33446 Mdot
.542 .33446 Mdot
.542 .33446 Mdot
.542 .33446 Mdot
.542 .33447 Mdot
.542 .33447 Mdot
.542 .33447 Mdot
.542 .33447 Mdot
.542 .33447 Mdot
.542 .33447 Mdot
.542 .33447 Mdot
.542 .33447 Mdot
.542 .33447 Mdot
.542 .33447 Mdot
.542 .33447 Mdot
.544 .30741 Mdot
.544 .30742 Mdot
.544 .30742 Mdot
.544 .30742 Mdot
.544 .30742 Mdot
.544 .30742 Mdot
.544 .30742 Mdot
.544 .30742 Mdot
.544 .30742 Mdot
.544 .30742 Mdot
.544 .30742 Mdot
.544 .30743 Mdot
.544 .30743 Mdot
.544 .30743 Mdot
.544 .30743 Mdot
.544 .30743 Mdot
.544 .30743 Mdot
.544 .30743 Mdot
.544 .30743 Mdot
.544 .30743 Mdot
.544 .30743 Mdot
.544 .30744 Mdot
.544 .30744 Mdot
.544 .30744 Mdot
.544 .30745 Mdot
.544 .30745 Mdot
.544 .30745 Mdot
.544 .30746 Mdot
.544 .30746 Mdot
.544 .30746 Mdot
.544 .30746 Mdot
.544 .30746 Mdot
.544 .30746 Mdot
.544 .30746 Mdot
.544 .30746 Mdot
.544 .30746 Mdot
.544 .30746 Mdot
.544 .30747 Mdot
.544 .30747 Mdot
.544 .30747 Mdot
.544 .30747 Mdot
.544 .30748 Mdot
.544 .30748 Mdot
.544 .30748 Mdot
.544 .30749 Mdot
.544 .30749 Mdot
.544 .30749 Mdot
.544 .30749 Mdot
.544 .30749 Mdot
.544 .3075 Mdot
.544 .3075 Mdot
.544 .3075 Mdot
.544 .3075 Mdot
.544 .3075 Mdot
.544 .30751 Mdot
.544 .30751 Mdot
.544 .30751 Mdot
.544 .30751 Mdot
.544 .30751 Mdot
.544 .30751 Mdot
.544 .30751 Mdot
.544 .30751 Mdot
.544 .30751 Mdot
.544 .30752 Mdot
.544 .30752 Mdot
.544 .30752 Mdot
.544 .30752 Mdot
.544 .30752 Mdot
.544 .30752 Mdot
.544 .30752 Mdot
.544 .30752 Mdot
.544 .30753 Mdot
.544 .30753 Mdot
.544 .30753 Mdot
.544 .30753 Mdot
.544 .30753 Mdot
.544 .30754 Mdot
.544 .30754 Mdot
.544 .30754 Mdot
.544 .30754 Mdot
.544 .30754 Mdot
.544 .30754 Mdot
.544 .30754 Mdot
.544 .30755 Mdot
.544 .30755 Mdot
.544 .30755 Mdot
.544 .30755 Mdot
.544 .30755 Mdot
.544 .30756 Mdot
.544 .30756 Mdot
.544 .30756 Mdot
.544 .30756 Mdot
.544 .30756 Mdot
.544 .30756 Mdot
.544 .30756 Mdot
.544 .30757 Mdot
.544 .30757 Mdot
.544 .30757 Mdot
.544 .30757 Mdot
.544 .30757 Mdot
.544 .30758 Mdot
.544 .30758 Mdot
.544 .30758 Mdot
.544 .30758 Mdot
.544 .30758 Mdot
.544 .30758 Mdot
.544 .30758 Mdot
.544 .30758 Mdot
.544 .30758 Mdot
.544 .30758 Mdot
.544 .30759 Mdot
.544 .30759 Mdot
.544 .30759 Mdot
.544 .30759 Mdot
.544 .30759 Mdot
.544 .30759 Mdot
.544 .30759 Mdot
.544 .30759 Mdot
.544 .30759 Mdot
.544 .3076 Mdot
.544 .3076 Mdot
.544 .3076 Mdot
.544 .3076 Mdot
.544 .3076 Mdot
.544 .30761 Mdot
.544 .30763 Mdot
.544 .30764 Mdot
.544 .30764 Mdot
.544 .30764 Mdot
.544 .30765 Mdot
.544 .30765 Mdot
.544 .30765 Mdot
.544 .30765 Mdot
.544 .30766 Mdot
.544 .30766 Mdot
.544 .30766 Mdot
.544 .30766 Mdot
.544 .30766 Mdot
.544 .30767 Mdot
.544 .30767 Mdot
.544 .30767 Mdot
.544 .30767 Mdot
.544 .30767 Mdot
.544 .30767 Mdot
.544 .30768 Mdot
.544 .30768 Mdot
.544 .30768 Mdot
.544 .30768 Mdot
.544 .30768 Mdot
.544 .30768 Mdot
.544 .30768 Mdot
.544 .30769 Mdot
.544 .30769 Mdot
.544 .30769 Mdot
.544 .30769 Mdot
.544 .3077 Mdot
.544 .3077 Mdot
.544 .3077 Mdot
.544 .3077 Mdot
.544 .3077 Mdot
.544 .3077 Mdot
.544 .3077 Mdot
.544 .30771 Mdot
.544 .30771 Mdot
.544 .30771 Mdot
.544 .30772 Mdot
.544 .30772 Mdot
.544 .30773 Mdot
.544 .30773 Mdot
.544 .30773 Mdot
.544 .30773 Mdot
.544 .30773 Mdot
.544 .30773 Mdot
.544 .30773 Mdot
.544 .30774 Mdot
.544 .30774 Mdot
.544 .30774 Mdot
.544 .30775 Mdot
.544 .30775 Mdot
.544 .30775 Mdot
.544 .30775 Mdot
.544 .30776 Mdot
.544 .30776 Mdot
.544 .30776 Mdot
.544 .30776 Mdot
.544 .30776 Mdot
.544 .30776 Mdot
.544 .30777 Mdot
.544 .30777 Mdot
.544 .30777 Mdot
.544 .30777 Mdot
.544 .30777 Mdot
.544 .30777 Mdot
.544 .30778 Mdot
.544 .30778 Mdot
.544 .30778 Mdot
.544 .30778 Mdot
.544 .30778 Mdot
.544 .30778 Mdot
.544 .30778 Mdot
.544 .30778 Mdot
.544 .3078 Mdot
.544 .3078 Mdot
.544 .3078 Mdot
.544 .30781 Mdot
.544 .30781 Mdot
.544 .30781 Mdot
.544 .30782 Mdot
.544 .30782 Mdot
.544 .30782 Mdot
.544 .30783 Mdot
.544 .30783 Mdot
.544 .30783 Mdot
.544 .30784 Mdot
.544 .30784 Mdot
.544 .30784 Mdot
.544 .30784 Mdot
.544 .30784 Mdot
.544 .30784 Mdot
.544 .30784 Mdot
.544 .30784 Mdot
.544 .30784 Mdot
.544 .30785 Mdot
.544 .30785 Mdot
.544 .30786 Mdot
.544 .30786 Mdot
.544 .30787 Mdot
.544 .30787 Mdot
.544 .30788 Mdot
.544 .30788 Mdot
.544 .30788 Mdot
.544 .30788 Mdot
.544 .30788 Mdot
.544 .30788 Mdot
.544 .30789 Mdot
.544 .30789 Mdot
.544 .30789 Mdot
.544 .30789 Mdot
.544 .30789 Mdot
.544 .30789 Mdot
.544 .30789 Mdot
.544 .30789 Mdot
.544 .3079 Mdot
.544 .3079 Mdot
.544 .3079 Mdot
.544 .3079 Mdot
.544 .3079 Mdot
.544 .3079 Mdot
.544 .3079 Mdot
.544 .30791 Mdot
.544 .30953 Mdot
.544 .30953 Mdot
.544 .30954 Mdot
.544 .30954 Mdot
.544 .30954 Mdot
.544 .30954 Mdot
.544 .30954 Mdot
.544 .30954 Mdot
.544 .30955 Mdot
.544 .30955 Mdot
.544 .30955 Mdot
.544 .30955 Mdot
.544 .30955 Mdot
.544 .30955 Mdot
.544 .30955 Mdot
.544 .30956 Mdot
.544 .30956 Mdot
.544 .30956 Mdot
.544 .30956 Mdot
.544 .30956 Mdot
.544 .30956 Mdot
.544 .30957 Mdot
.544 .30957 Mdot
.544 .30957 Mdot
.544 .30959 Mdot
.544 .30959 Mdot
.544 .30959 Mdot
.544 .3096 Mdot
.544 .30961 Mdot
.544 .30961 Mdot
.544 .30961 Mdot
.544 .30961 Mdot
.544 .30961 Mdot
.544 .30961 Mdot
.544 .30961 Mdot
.544 .30961 Mdot
.544 .30962 Mdot
.544 .30962 Mdot
.544 .30962 Mdot
.544 .30962 Mdot
.544 .30963 Mdot
.544 .30963 Mdot
.544 .30964 Mdot
.544 .30964 Mdot
.544 .30965 Mdot
.544 .30965 Mdot
.544 .30966 Mdot
.544 .30966 Mdot
.544 .30966 Mdot
.544 .30967 Mdot
.544 .30968 Mdot
.544 .30968 Mdot
.544 .30968 Mdot
.544 .30968 Mdot
.544 .30968 Mdot
.544 .30968 Mdot
.544 .30969 Mdot
.544 .30969 Mdot
.544 .30969 Mdot
.544 .30969 Mdot
.544 .30969 Mdot
.544 .30969 Mdot
.544 .3097 Mdot
.544 .3097 Mdot
.544 .3097 Mdot
.544 .3097 Mdot
.544 .3097 Mdot
.544 .30971 Mdot
.544 .30971 Mdot
.544 .30971 Mdot
.544 .30971 Mdot
.544 .30972 Mdot
.544 .30972 Mdot
.544 .30973 Mdot
.544 .30973 Mdot
.544 .30973 Mdot
.544 .30974 Mdot
.544 .30974 Mdot
.544 .30974 Mdot
.544 .30974 Mdot
.544 .30974 Mdot
.544 .30974 Mdot
.544 .30974 Mdot
.544 .30975 Mdot
.544 .30975 Mdot
.544 .30976 Mdot
.544 .30976 Mdot
.544 .30976 Mdot
.544 .30977 Mdot
.544 .30977 Mdot
.544 .30977 Mdot
.544 .30978 Mdot
.544 .30978 Mdot
.544 .30978 Mdot
.544 .30978 Mdot
.544 .30978 Mdot
.544 .30979 Mdot
.544 .30979 Mdot
.544 .30979 Mdot
.544 .30979 Mdot
.544 .3098 Mdot
.544 .3098 Mdot
.544 .3098 Mdot
.544 .3098 Mdot
.544 .3098 Mdot
.544 .3098 Mdot
.544 .30981 Mdot
.544 .30981 Mdot
.544 .30981 Mdot
.544 .30981 Mdot
.544 .30982 Mdot
.544 .30982 Mdot
.544 .30982 Mdot
.544 .30982 Mdot
.544 .30982 Mdot
.544 .30982 Mdot
.544 .30983 Mdot
.544 .30983 Mdot
.544 .30983 Mdot
.544 .30983 Mdot
.544 .30984 Mdot
.544 .30984 Mdot
.544 .30984 Mdot
.544 .30985 Mdot
.544 .30985 Mdot
.544 .30988 Mdot
.544 .30989 Mdot
.544 .30989 Mdot
.544 .30989 Mdot
.544 .3099 Mdot
.544 .3099 Mdot
.544 .3099 Mdot
.544 .3099 Mdot
.544 .3099 Mdot
.544 .30991 Mdot
.544 .30991 Mdot
.544 .30991 Mdot
.544 .30991 Mdot
.544 .30991 Mdot
.544 .30991 Mdot
.544 .30991 Mdot
.544 .30991 Mdot
.544 .30992 Mdot
.544 .30992 Mdot
.544 .30992 Mdot
.544 .30992 Mdot
.544 .30992 Mdot
.544 .30992 Mdot
.544 .30992 Mdot
.544 .30992 Mdot
.544 .30993 Mdot
.544 .30993 Mdot
.544 .30993 Mdot
.544 .30993 Mdot
.544 .30993 Mdot
.544 .30994 Mdot
.544 .30994 Mdot
.544 .30994 Mdot
.544 .30994 Mdot
.544 .30994 Mdot
.544 .30994 Mdot
.544 .30994 Mdot
.544 .30995 Mdot
.544 .30995 Mdot
.544 .30995 Mdot
.544 .30996 Mdot
.544 .30996 Mdot
.544 .30996 Mdot
.544 .30996 Mdot
.544 .30997 Mdot
.544 .30997 Mdot
.544 .30997 Mdot
.544 .30997 Mdot
.544 .30997 Mdot
.544 .30997 Mdot
.544 .30997 Mdot
.544 .30997 Mdot
.544 .30998 Mdot
.544 .30998 Mdot
.544 .30998 Mdot
.544 .30999 Mdot
.544 .30999 Mdot
.544 .30999 Mdot
.544 .30999 Mdot
.544 .30999 Mdot
.544 .30999 Mdot
.544 .30999 Mdot
.544 .30999 Mdot
.544 .31 Mdot
.544 .31 Mdot
.544 .31 Mdot
.544 .31 Mdot
.544 .31 Mdot
.544 .31 Mdot
.544 .31001 Mdot
.544 .31001 Mdot
.544 .31001 Mdot
.544 .31001 Mdot
.544 .31001 Mdot
.544 .31001 Mdot
.544 .31001 Mdot
.544 .31002 Mdot
.544 .31002 Mdot
.544 .31003 Mdot
.544 .31003 Mdot
.544 .31003 Mdot
.544 .31003 Mdot
.544 .31004 Mdot
.544 .31004 Mdot
.544 .31004 Mdot
.544 .31005 Mdot
.544 .31005 Mdot
.544 .31005 Mdot
.544 .31005 Mdot
.544 .31005 Mdot
.544 .31006 Mdot
.544 .31006 Mdot
.544 .31006 Mdot
.544 .31006 Mdot
.544 .31006 Mdot
.544 .31006 Mdot
.544 .31006 Mdot
.544 .31006 Mdot
.544 .31007 Mdot
.544 .31007 Mdot
.544 .31007 Mdot
.544 .31009 Mdot
.544 .31009 Mdot
.544 .31009 Mdot
.544 .31009 Mdot
.544 .31009 Mdot
.544 .31009 Mdot
.544 .3101 Mdot
.544 .3101 Mdot
.544 .3101 Mdot
.544 .3101 Mdot
.544 .3101 Mdot
.544 .3101 Mdot
.544 .3101 Mdot
.544 .3101 Mdot
.544 .3101 Mdot
.544 .3101 Mdot
.544 .3101 Mdot
.544 .31011 Mdot
.544 .31011 Mdot
.544 .31011 Mdot
.544 .31011 Mdot
.544 .31011 Mdot
.544 .31011 Mdot
.544 .31011 Mdot
.544 .33317 Mdot
.544 .33317 Mdot
.544 .33317 Mdot
.544 .33317 Mdot
.544 .33318 Mdot
.544 .33318 Mdot
.544 .33318 Mdot
.544 .33318 Mdot
.544 .33318 Mdot
.544 .33318 Mdot
.544 .33318 Mdot
.544 .33318 Mdot
.544 .33319 Mdot
.544 .33319 Mdot
.544 .33319 Mdot
.544 .33319 Mdot
.544 .33319 Mdot
.544 .33319 Mdot
.544 .33319 Mdot
.544 .33319 Mdot
.544 .33319 Mdot
.544 .3332 Mdot
.544 .3332 Mdot
.544 .3332 Mdot
.544 .33321 Mdot
.544 .33321 Mdot
.544 .33321 Mdot
.544 .33322 Mdot
.544 .33322 Mdot
.544 .33322 Mdot
.544 .33322 Mdot
.544 .33322 Mdot
.544 .33322 Mdot
.544 .33322 Mdot
.544 .33323 Mdot
.544 .33323 Mdot
.544 .33323 Mdot
.544 .33323 Mdot
.544 .33323 Mdot
.544 .33323 Mdot
.544 .33324 Mdot
.544 .33324 Mdot
.544 .33324 Mdot
.544 .33324 Mdot
.544 .33325 Mdot
.544 .33325 Mdot
.544 .33325 Mdot
.544 .33325 Mdot
.544 .33325 Mdot
.544 .33327 Mdot
.544 .33327 Mdot
.544 .33327 Mdot
.544 .33327 Mdot
.544 .33327 Mdot
.544 .33327 Mdot
.544 .33327 Mdot
.544 .33327 Mdot
.544 .33327 Mdot
.544 .33327 Mdot
.544 .33328 Mdot
.544 .33328 Mdot
.544 .33328 Mdot
.544 .33328 Mdot
.544 .33328 Mdot
.544 .33328 Mdot
.544 .33328 Mdot
.544 .33329 Mdot
.544 .33329 Mdot
.544 .33329 Mdot
.544 .33329 Mdot
.544 .33329 Mdot
.544 .33329 Mdot
.544 .33329 Mdot
.544 .3333 Mdot
.544 .3333 Mdot
.544 .3333 Mdot
.544 .33331 Mdot
.544 .33331 Mdot
.544 .33331 Mdot
.544 .33331 Mdot
.544 .33331 Mdot
.544 .33331 Mdot
.544 .33331 Mdot
.544 .33331 Mdot
.544 .33332 Mdot
.544 .33332 Mdot
.544 .33332 Mdot
.544 .33332 Mdot
.544 .33333 Mdot
.544 .33333 Mdot
.544 .33333 Mdot
.544 .33333 Mdot
.544 .33333 Mdot
.544 .33333 Mdot
.544 .33334 Mdot
.544 .33334 Mdot
.544 .33334 Mdot
.544 .33334 Mdot
.544 .33334 Mdot
.544 .33334 Mdot
.544 .33335 Mdot
.544 .33335 Mdot
.544 .33335 Mdot
.544 .33335 Mdot
.544 .33335 Mdot
.544 .33335 Mdot
.544 .33335 Mdot
.544 .33335 Mdot
.544 .33335 Mdot
.544 .33336 Mdot
.544 .33336 Mdot
.544 .33336 Mdot
.544 .33336 Mdot
.544 .33336 Mdot
.544 .33336 Mdot
.544 .33336 Mdot
.544 .33337 Mdot
.544 .33337 Mdot
.544 .33337 Mdot
.544 .33337 Mdot
.544 .33337 Mdot
.544 .33338 Mdot
.544 .33338 Mdot
.544 .33338 Mdot
.544 .33338 Mdot
.544 .33341 Mdot
.544 .33342 Mdot
.544 .33342 Mdot
.544 .33342 Mdot
.544 .33343 Mdot
.544 .33343 Mdot
.544 .33343 Mdot
.544 .33343 Mdot
.544 .33344 Mdot
.544 .33344 Mdot
.544 .33344 Mdot
.544 .33344 Mdot
.544 .33344 Mdot
.544 .33345 Mdot
.544 .33345 Mdot
.544 .33345 Mdot
.544 .33345 Mdot
.544 .33345 Mdot
.544 .33345 Mdot
.544 .33346 Mdot
.544 .33346 Mdot
.544 .33346 Mdot
.544 .33346 Mdot
.544 .33346 Mdot
.544 .33346 Mdot
.544 .33347 Mdot
.544 .33347 Mdot
.544 .33347 Mdot
.544 .33347 Mdot
.544 .33348 Mdot
.544 .33348 Mdot
.544 .33348 Mdot
.544 .33348 Mdot
.544 .33348 Mdot
.544 .33348 Mdot
.544 .33348 Mdot
.544 .33349 Mdot
.544 .3335 Mdot
.544 .3335 Mdot
.544 .3335 Mdot
.544 .3335 Mdot
.544 .33351 Mdot
.544 .33351 Mdot
.544 .33351 Mdot
.544 .33352 Mdot
.544 .33352 Mdot
.544 .33352 Mdot
.544 .33352 Mdot
.544 .33352 Mdot
.544 .33352 Mdot
.544 .33353 Mdot
.544 .33353 Mdot
.544 .33354 Mdot
.544 .33354 Mdot
.544 .33354 Mdot
.544 .33354 Mdot
.544 .33354 Mdot
.544 .33355 Mdot
.544 .33355 Mdot
.544 .33355 Mdot
.544 .33355 Mdot
.544 .33355 Mdot
.544 .33355 Mdot
.544 .33356 Mdot
.544 .33356 Mdot
.544 .33356 Mdot
.544 .33356 Mdot
.544 .33356 Mdot
.544 .33357 Mdot
.544 .33357 Mdot
.544 .33357 Mdot
.544 .33357 Mdot
.544 .33357 Mdot
.544 .33357 Mdot
.544 .33357 Mdot
.544 .33358 Mdot
.544 .33359 Mdot
.544 .33359 Mdot
.544 .33359 Mdot
.544 .3336 Mdot
.544 .3336 Mdot
.544 .3336 Mdot
.544 .33361 Mdot
.544 .33361 Mdot
.544 .33362 Mdot
.544 .33363 Mdot
.544 .33363 Mdot
.544 .33363 Mdot
.544 .33363 Mdot
.544 .33363 Mdot
.544 .33363 Mdot
.544 .33363 Mdot
.544 .33364 Mdot
.544 .33364 Mdot
.544 .33364 Mdot
.544 .33364 Mdot
.544 .33364 Mdot
.544 .33364 Mdot
.544 .33365 Mdot
.544 .33365 Mdot
.544 .33365 Mdot
.544 .33367 Mdot
.544 .33367 Mdot
.544 .33367 Mdot
.544 .33368 Mdot
.544 .33368 Mdot
.544 .33368 Mdot
.544 .33368 Mdot
.544 .33368 Mdot
.544 .33368 Mdot
.544 .33369 Mdot
.544 .33369 Mdot
.544 .33369 Mdot
.544 .33369 Mdot
.544 .33369 Mdot
.544 .33369 Mdot
.544 .33369 Mdot
.544 .33369 Mdot
.544 .3337 Mdot
.544 .3337 Mdot
.544 .3337 Mdot
.544 .3337 Mdot
.544 .3337 Mdot
.544 .3337 Mdot
.544 .33371 Mdot
.544 .3352 Mdot
.544 .3352 Mdot
.544 .3352 Mdot
.544 .3352 Mdot
.544 .33521 Mdot
.544 .33521 Mdot
.544 .33521 Mdot
.544 .33521 Mdot
.544 .33521 Mdot
.544 .33521 Mdot
.544 .33521 Mdot
.544 .33522 Mdot
.544 .33522 Mdot
.544 .33522 Mdot
.544 .33522 Mdot
.544 .33522 Mdot
.544 .33522 Mdot
.544 .33522 Mdot
.544 .33522 Mdot
.544 .33522 Mdot
.544 .33522 Mdot
.544 .33523 Mdot
.544 .33523 Mdot
.544 .33523 Mdot
.544 .33525 Mdot
.544 .33525 Mdot
.544 .33525 Mdot
.544 .33526 Mdot
.544 .33526 Mdot
.544 .33526 Mdot
.544 .33526 Mdot
.544 .33526 Mdot
.544 .33526 Mdot
.544 .33526 Mdot
.544 .33526 Mdot
.544 .33527 Mdot
.544 .33527 Mdot
.544 .33527 Mdot
.544 .33527 Mdot
.544 .33527 Mdot
.544 .33528 Mdot
.544 .33528 Mdot
.544 .33528 Mdot
.544 .33529 Mdot
.544 .33529 Mdot
.544 .33529 Mdot
.544 .3353 Mdot
.544 .3353 Mdot
.544 .3353 Mdot
.544 .33531 Mdot
.544 .33532 Mdot
.544 .33532 Mdot
.544 .33532 Mdot
.544 .33532 Mdot
.544 .33532 Mdot
.544 .33532 Mdot
.544 .33532 Mdot
.544 .33532 Mdot
.544 .33532 Mdot
.544 .33532 Mdot
.544 .33533 Mdot
.544 .33533 Mdot
.544 .33533 Mdot
.544 .33533 Mdot
.544 .33533 Mdot
.544 .33533 Mdot
.544 .33534 Mdot
.544 .33534 Mdot
.544 .33534 Mdot
.544 .33534 Mdot
.544 .33534 Mdot
.544 .33534 Mdot
.544 .33535 Mdot
.544 .33535 Mdot
.544 .33535 Mdot
.544 .33536 Mdot
.544 .33536 Mdot
.544 .33536 Mdot
.544 .33536 Mdot
.544 .33536 Mdot
.544 .33536 Mdot
.544 .33536 Mdot
.544 .33536 Mdot
.544 .33537 Mdot
.544 .33537 Mdot
.544 .33538 Mdot
.544 .33538 Mdot
.544 .33538 Mdot
.544 .33539 Mdot
.544 .33539 Mdot
.544 .33539 Mdot
.544 .33539 Mdot
.544 .33539 Mdot
.544 .33539 Mdot
.544 .33539 Mdot
.544 .3354 Mdot
.544 .3354 Mdot
.544 .3354 Mdot
.544 .3354 Mdot
.544 .3354 Mdot
.544 .33541 Mdot
.544 .33541 Mdot
.544 .33541 Mdot
.544 .33541 Mdot
.544 .33541 Mdot
.544 .33541 Mdot
.544 .33541 Mdot
.544 .33542 Mdot
.544 .33542 Mdot
.544 .33542 Mdot
.544 .33542 Mdot
.544 .33542 Mdot
.544 .33543 Mdot
.544 .33543 Mdot
.544 .33543 Mdot
.544 .33543 Mdot
.544 .33543 Mdot
.544 .33543 Mdot
.544 .33543 Mdot
.544 .33544 Mdot
.544 .33544 Mdot
.544 .33544 Mdot
.544 .33544 Mdot
.544 .33544 Mdot
.544 .33545 Mdot
.544 .33548 Mdot
.544 .33548 Mdot
.544 .33548 Mdot
.544 .33548 Mdot
.544 .33548 Mdot
.544 .33549 Mdot
.544 .33549 Mdot
.544 .33549 Mdot
.544 .33549 Mdot
.544 .33549 Mdot
.544 .33549 Mdot
.544 .33549 Mdot
.544 .33549 Mdot
.544 .3355 Mdot
.544 .3355 Mdot
.544 .3355 Mdot
.544 .3355 Mdot
.544 .3355 Mdot
.544 .3355 Mdot
.544 .3355 Mdot
.544 .3355 Mdot
.544 .3355 Mdot
.544 .3355 Mdot
.544 .3355 Mdot
.544 .33551 Mdot
.544 .33551 Mdot
.544 .33551 Mdot
.544 .33551 Mdot
.544 .33551 Mdot
.544 .33551 Mdot
.544 .33551 Mdot
.544 .33552 Mdot
.544 .33552 Mdot
.544 .33552 Mdot
.544 .33552 Mdot
.544 .33552 Mdot
.544 .33552 Mdot
.544 .33553 Mdot
.544 .33553 Mdot
.544 .33553 Mdot
.544 .33553 Mdot
.544 .33553 Mdot
.544 .33554 Mdot
.544 .33554 Mdot
.544 .33554 Mdot
.544 .33554 Mdot
.544 .33554 Mdot
.544 .33554 Mdot
.544 .33554 Mdot
.544 .33554 Mdot
.544 .33554 Mdot
.544 .33554 Mdot
.544 .33555 Mdot
.544 .33555 Mdot
.544 .33555 Mdot
.544 .33555 Mdot
.544 .33555 Mdot
.544 .33556 Mdot
.544 .33556 Mdot
.544 .33556 Mdot
.544 .33556 Mdot
.544 .33556 Mdot
.544 .33556 Mdot
.544 .33556 Mdot
.544 .33556 Mdot
.544 .33556 Mdot
.544 .33557 Mdot
.544 .33557 Mdot
.544 .33557 Mdot
.544 .33557 Mdot
.544 .33557 Mdot
.544 .33557 Mdot
.544 .33557 Mdot
.544 .33557 Mdot
.544 .33557 Mdot
.544 .33557 Mdot
.544 .33557 Mdot
.544 .33558 Mdot
.544 .33558 Mdot
.544 .33558 Mdot
.544 .33559 Mdot
.544 .33559 Mdot
.544 .33559 Mdot
.544 .33559 Mdot
.544 .3356 Mdot
.544 .3356 Mdot
.544 .3356 Mdot
.544 .3356 Mdot
.544 .33561 Mdot
.544 .33561 Mdot
.544 .33561 Mdot
.544 .33561 Mdot
.544 .33561 Mdot
.544 .33561 Mdot
.544 .33561 Mdot
.544 .33561 Mdot
.544 .33561 Mdot
.544 .33561 Mdot
.544 .33561 Mdot
.544 .33562 Mdot
.544 .33562 Mdot
.544 .33562 Mdot
.544 .33563 Mdot
.544 .33563 Mdot
.544 .33563 Mdot
.544 .33564 Mdot
.544 .33564 Mdot
.544 .33564 Mdot
.544 .33564 Mdot
.544 .33564 Mdot
.544 .33564 Mdot
.544 .33564 Mdot
.544 .33564 Mdot
.544 .33564 Mdot
.544 .33564 Mdot
.544 .33564 Mdot
.544 .33564 Mdot
.544 .33564 Mdot
.544 .33565 Mdot
.544 .33565 Mdot
.544 .33565 Mdot
.544 .33565 Mdot
.544 .33565 Mdot
.544 .33565 Mdot
.544 .33565 Mdot
.544 .33565 Mdot
.546 .3072 Mdot
.546 .3072 Mdot
.546 .30721 Mdot
.546 .30721 Mdot
.546 .30721 Mdot
.546 .30721 Mdot
.546 .30722 Mdot
.546 .30722 Mdot
.546 .30722 Mdot
.546 .30722 Mdot
.546 .30722 Mdot
.546 .30722 Mdot
.546 .30722 Mdot
.546 .30723 Mdot
.546 .30723 Mdot
.546 .30723 Mdot
.546 .30723 Mdot
.546 .30723 Mdot
.546 .30724 Mdot
.546 .30724 Mdot
.546 .30724 Mdot
.546 .30725 Mdot
.546 .30725 Mdot
.546 .30725 Mdot
.546 .30725 Mdot
.546 .30725 Mdot
.546 .30725 Mdot
.546 .30725 Mdot
.546 .30725 Mdot
.546 .30726 Mdot
.546 .30726 Mdot
.546 .30726 Mdot
.546 .30727 Mdot
.546 .30727 Mdot
.546 .30727 Mdot
.546 .30727 Mdot
.546 .30728 Mdot
.546 .30728 Mdot
.546 .30728 Mdot
.546 .30728 Mdot
.546 .30728 Mdot
.546 .30729 Mdot
.546 .30729 Mdot
.546 .3073 Mdot
.546 .3073 Mdot
.546 .3073 Mdot
.546 .3073 Mdot
.546 .3073 Mdot
.546 .3073 Mdot
.546 .30731 Mdot
.546 .30731 Mdot
.546 .30731 Mdot
.546 .30731 Mdot
.546 .30731 Mdot
.546 .30732 Mdot
.546 .30732 Mdot
.546 .30732 Mdot
.546 .30732 Mdot
.546 .30732 Mdot
.546 .30732 Mdot
.546 .30733 Mdot
.546 .30733 Mdot
.546 .30733 Mdot
.546 .30733 Mdot
.546 .30733 Mdot
.546 .30734 Mdot
.546 .30734 Mdot
.546 .30734 Mdot
.546 .30734 Mdot
.546 .30734 Mdot
.546 .30735 Mdot
.546 .30735 Mdot
.546 .30735 Mdot
.546 .30735 Mdot
.546 .30735 Mdot
.546 .30735 Mdot
.546 .30736 Mdot
.546 .30736 Mdot
.546 .30736 Mdot
.546 .30737 Mdot
.546 .30737 Mdot
.546 .30737 Mdot
.546 .30737 Mdot
.546 .30737 Mdot
.546 .30737 Mdot
.546 .30737 Mdot
.546 .30738 Mdot
.546 .30738 Mdot
.546 .30738 Mdot
.546 .30738 Mdot
.546 .30738 Mdot
.546 .30738 Mdot
.546 .30738 Mdot
.546 .30739 Mdot
.546 .30739 Mdot
.546 .30739 Mdot
.546 .3074 Mdot
.546 .3074 Mdot
.546 .3074 Mdot
.546 .3074 Mdot
.546 .3074 Mdot
.546 .30741 Mdot
.546 .30741 Mdot
.546 .30741 Mdot
.546 .30741 Mdot
.546 .30741 Mdot
.546 .30741 Mdot
.546 .30741 Mdot
.546 .30742 Mdot
.546 .30742 Mdot
.546 .30742 Mdot
.546 .30742 Mdot
.546 .30742 Mdot
.546 .30742 Mdot
.546 .30743 Mdot
.546 .30743 Mdot
.546 .30743 Mdot
.546 .30743 Mdot
.546 .30743 Mdot
.546 .30743 Mdot
.546 .30743 Mdot
.546 .30743 Mdot
.546 .30744 Mdot
.546 .30744 Mdot
.546 .30744 Mdot
.546 .30744 Mdot
.546 .30744 Mdot
.546 .30744 Mdot
.546 .30744 Mdot
.546 .30744 Mdot
.546 .30744 Mdot
.546 .30744 Mdot
.546 .30745 Mdot
.546 .30745 Mdot
.546 .30745 Mdot
.546 .30745 Mdot
.546 .30745 Mdot
.546 .30746 Mdot
.546 .30746 Mdot
.546 .30746 Mdot
.546 .30746 Mdot
.546 .30747 Mdot
.546 .30747 Mdot
.546 .30747 Mdot
.546 .30747 Mdot
.546 .30748 Mdot
.546 .30748 Mdot
.546 .30748 Mdot
.546 .30748 Mdot
.546 .30748 Mdot
.546 .30749 Mdot
.546 .30749 Mdot
.546 .30749 Mdot
.546 .30749 Mdot
.546 .3075 Mdot
.546 .3075 Mdot
.546 .3075 Mdot
.546 .30751 Mdot
.546 .30751 Mdot
.546 .30751 Mdot
.546 .30752 Mdot
.546 .30752 Mdot
.546 .30752 Mdot
.546 .30752 Mdot
.546 .30753 Mdot
.546 .30753 Mdot
.546 .30753 Mdot
.546 .30753 Mdot
.546 .30753 Mdot
.546 .30754 Mdot
.546 .30754 Mdot
.546 .30754 Mdot
.546 .30754 Mdot
.546 .30755 Mdot
.546 .30755 Mdot
.546 .30755 Mdot
.546 .30756 Mdot
.546 .30756 Mdot
.546 .30757 Mdot
.546 .30757 Mdot
.546 .30757 Mdot
.546 .30757 Mdot
.546 .30757 Mdot
.546 .30757 Mdot
.546 .30757 Mdot
.546 .30758 Mdot
.546 .30758 Mdot
.546 .30759 Mdot
.546 .30759 Mdot
.546 .30759 Mdot
.546 .3076 Mdot
.546 .3076 Mdot
.546 .3076 Mdot
.546 .3076 Mdot
.546 .3076 Mdot
.546 .30761 Mdot
.546 .30762 Mdot
.546 .30762 Mdot
.546 .30762 Mdot
.546 .30762 Mdot
.546 .30762 Mdot
.546 .30763 Mdot
.546 .30763 Mdot
.546 .30763 Mdot
.546 .30763 Mdot
.546 .30764 Mdot
.546 .30764 Mdot
.546 .30764 Mdot
.546 .30765 Mdot
.546 .30765 Mdot
.546 .30766 Mdot
.546 .30766 Mdot
.546 .30766 Mdot
.546 .30766 Mdot
.546 .30767 Mdot
.546 .30767 Mdot
.546 .30767 Mdot
.546 .30768 Mdot
.546 .30768 Mdot
.546 .30769 Mdot
.546 .30769 Mdot
.546 .3077 Mdot
.546 .3077 Mdot
.546 .3077 Mdot
.546 .3077 Mdot
.546 .3077 Mdot
.546 .30771 Mdot
.546 .30771 Mdot
.546 .30771 Mdot
.546 .30771 Mdot
.546 .30772 Mdot
.546 .30772 Mdot
.546 .30772 Mdot
.546 .30772 Mdot
.546 .30773 Mdot
.546 .30773 Mdot
.546 .30774 Mdot
.546 .30774 Mdot
.546 .30774 Mdot
.546 .30774 Mdot
.546 .30774 Mdot
.546 .30775 Mdot
.546 .30775 Mdot
.546 .30775 Mdot
.546 .30776 Mdot
.546 .30776 Mdot
.546 .30776 Mdot
.546 .30776 Mdot
.546 .30777 Mdot
.546 .30777 Mdot
.546 .3095 Mdot
.546 .3095 Mdot
.546 .3095 Mdot
.546 .3095 Mdot
.546 .30951 Mdot
.546 .30951 Mdot
.546 .30952 Mdot
.546 .30952 Mdot
.546 .30952 Mdot
.546 .30953 Mdot
.546 .30953 Mdot
.546 .30953 Mdot
.546 .30953 Mdot
.546 .30954 Mdot
.546 .30954 Mdot
.546 .30955 Mdot
.546 .30955 Mdot
.546 .30955 Mdot
.546 .30956 Mdot
.546 .30956 Mdot
.546 .30957 Mdot
.546 .30957 Mdot
.546 .30957 Mdot
.546 .30957 Mdot
.546 .30958 Mdot
.546 .30958 Mdot
.546 .30958 Mdot
.546 .30958 Mdot
.546 .30958 Mdot
.546 .30959 Mdot
.546 .3096 Mdot
.546 .3096 Mdot
.546 .30961 Mdot
.546 .30961 Mdot
.546 .30961 Mdot
.546 .30962 Mdot
.546 .30962 Mdot
.546 .30963 Mdot
.546 .30963 Mdot
.546 .30963 Mdot
.546 .30964 Mdot
.546 .30964 Mdot
.546 .30965 Mdot
.546 .30966 Mdot
.546 .30966 Mdot
.546 .30966 Mdot
.546 .30967 Mdot
.546 .30967 Mdot
.546 .30967 Mdot
.546 .30968 Mdot
.546 .30968 Mdot
.546 .30968 Mdot
.546 .30968 Mdot
.546 .30968 Mdot
.546 .30969 Mdot
.546 .3097 Mdot
.546 .3097 Mdot
.546 .3097 Mdot
.546 .3097 Mdot
.546 .3097 Mdot
.546 .30971 Mdot
.546 .30971 Mdot
.546 .30971 Mdot
.546 .30972 Mdot
.546 .30972 Mdot
.546 .30973 Mdot
.546 .30974 Mdot
.546 .30974 Mdot
.546 .30974 Mdot
.546 .30974 Mdot
.546 .30974 Mdot
.546 .30974 Mdot
.546 .30975 Mdot
.546 .30975 Mdot
.546 .30975 Mdot
.546 .30976 Mdot
.546 .30977 Mdot
.546 .30977 Mdot
.546 .30978 Mdot
.546 .30978 Mdot
.546 .30978 Mdot
.546 .30979 Mdot
.546 .30979 Mdot
.546 .30979 Mdot
.546 .30979 Mdot
.546 .30979 Mdot
.546 .3098 Mdot
.546 .3098 Mdot
.546 .3098 Mdot
.546 .3098 Mdot
.546 .3098 Mdot
.546 .3098 Mdot
.546 .30981 Mdot
.546 .30982 Mdot
.546 .30982 Mdot
.546 .30983 Mdot
.546 .30983 Mdot
.546 .30983 Mdot
.546 .30984 Mdot
.546 .30984 Mdot
.546 .30984 Mdot
.546 .30984 Mdot
.546 .30985 Mdot
.546 .30985 Mdot
.546 .30985 Mdot
.546 .30985 Mdot
.546 .30985 Mdot
.546 .30986 Mdot
.546 .30986 Mdot
.546 .30987 Mdot
.546 .30987 Mdot
.546 .30987 Mdot
.546 .30987 Mdot
.546 .30988 Mdot
.546 .30988 Mdot
.546 .30988 Mdot
.546 .30988 Mdot
.546 .30988 Mdot
.546 .30989 Mdot
.546 .30989 Mdot
.546 .30989 Mdot
.546 .30989 Mdot
.546 .30989 Mdot
.546 .30989 Mdot
.546 .30989 Mdot
.546 .3099 Mdot
.546 .3099 Mdot
.546 .3099 Mdot
.546 .3099 Mdot
.546 .3099 Mdot
.546 .3099 Mdot
.546 .3099 Mdot
.546 .3099 Mdot
.546 .3099 Mdot
.546 .3099 Mdot
.546 .30991 Mdot
.546 .30991 Mdot
.546 .30991 Mdot
.546 .30991 Mdot
.546 .30991 Mdot
.546 .30991 Mdot
.546 .30992 Mdot
.546 .30992 Mdot
.546 .30993 Mdot
.546 .30993 Mdot
.546 .30993 Mdot
.546 .30993 Mdot
.546 .30993 Mdot
.546 .30993 Mdot
.546 .30993 Mdot
.546 .30994 Mdot
.546 .30994 Mdot
.546 .30994 Mdot
.546 .30994 Mdot
.546 .30995 Mdot
.546 .30995 Mdot
.546 .30995 Mdot
.546 .30996 Mdot
.546 .30996 Mdot
.546 .30996 Mdot
.546 .30996 Mdot
.546 .30996 Mdot
.546 .30996 Mdot
.546 .30997 Mdot
.546 .30997 Mdot
.546 .30997 Mdot
.546 .30997 Mdot
.546 .30997 Mdot
.546 .30997 Mdot
.546 .30998 Mdot
.546 .30998 Mdot
.546 .30998 Mdot
.546 .30999 Mdot
.546 .30999 Mdot
.546 .30999 Mdot
.546 .30999 Mdot
.546 .31 Mdot
.546 .31 Mdot
.546 .31 Mdot
.546 .31 Mdot
.546 .31001 Mdot
.546 .31001 Mdot
.546 .31001 Mdot
.546 .31001 Mdot
.546 .31001 Mdot
.546 .31002 Mdot
.546 .31002 Mdot
.546 .31002 Mdot
.546 .31002 Mdot
.546 .31003 Mdot
.546 .31003 Mdot
.546 .31003 Mdot
.546 .31003 Mdot
.546 .31003 Mdot
.546 .31003 Mdot
.546 .31004 Mdot
.546 .31005 Mdot
.546 .31005 Mdot
.546 .31005 Mdot
.546 .31005 Mdot
.546 .31005 Mdot
.546 .31005 Mdot
.546 .31005 Mdot
.546 .31006 Mdot
.546 .31006 Mdot
.546 .31006 Mdot
.546 .31006 Mdot
.546 .31007 Mdot
.546 .31007 Mdot
.546 .31008 Mdot
.546 .31008 Mdot
.546 .31008 Mdot
.546 .31008 Mdot
.546 .31009 Mdot
.546 .31009 Mdot
.546 .31009 Mdot
.546 .31009 Mdot
.546 .3101 Mdot
.546 .3101 Mdot
.546 .31011 Mdot
.546 .31011 Mdot
.546 .31011 Mdot
.546 .31011 Mdot
.546 .31012 Mdot
.546 .31012 Mdot
.546 .31012 Mdot
.546 .31012 Mdot
.546 .31012 Mdot
.546 .31012 Mdot
.546 .31013 Mdot
.546 .31013 Mdot
.546 .31013 Mdot
.546 .31014 Mdot
.546 .31014 Mdot
.546 .31014 Mdot
.546 .31014 Mdot
.546 .31015 Mdot
.546 .31015 Mdot
.546 .31015 Mdot
.546 .31015 Mdot
.546 .31015 Mdot
.546 .31016 Mdot
.546 .31016 Mdot
.546 .31016 Mdot
.546 .31017 Mdot
.546 .31017 Mdot
.546 .31017 Mdot
.546 .31017 Mdot
.546 .31017 Mdot
.546 .31017 Mdot
.546 .33411 Mdot
.546 .33411 Mdot
.546 .33411 Mdot
.546 .33412 Mdot
.546 .33412 Mdot
.546 .33412 Mdot
.546 .33413 Mdot
.546 .33413 Mdot
.546 .33413 Mdot
.546 .33413 Mdot
.546 .33413 Mdot
.546 .33413 Mdot
.546 .33413 Mdot
.546 .33414 Mdot
.546 .33414 Mdot
.546 .33414 Mdot
.546 .33415 Mdot
.546 .33415 Mdot
.546 .33415 Mdot
.546 .33415 Mdot
.546 .33416 Mdot
.546 .33416 Mdot
.546 .33416 Mdot
.546 .33416 Mdot
.546 .33416 Mdot
.546 .33416 Mdot
.546 .33416 Mdot
.546 .33417 Mdot
.546 .33417 Mdot
.546 .33417 Mdot
.546 .33417 Mdot
.546 .33418 Mdot
.546 .33418 Mdot
.546 .33418 Mdot
.546 .33419 Mdot
.546 .33419 Mdot
.546 .33419 Mdot
.546 .33419 Mdot
.546 .3342 Mdot
.546 .3342 Mdot
.546 .3342 Mdot
.546 .3342 Mdot
.546 .33421 Mdot
.546 .33421 Mdot
.546 .33421 Mdot
.546 .33422 Mdot
.546 .33422 Mdot
.546 .33422 Mdot
.546 .33422 Mdot
.546 .33423 Mdot
.546 .33423 Mdot
.546 .33423 Mdot
.546 .33423 Mdot
.546 .33423 Mdot
.546 .33424 Mdot
.546 .33424 Mdot
.546 .33424 Mdot
.546 .33424 Mdot
.546 .33424 Mdot
.546 .33424 Mdot
.546 .33425 Mdot
.546 .33425 Mdot
.546 .33425 Mdot
.546 .33425 Mdot
.546 .33426 Mdot
.546 .33426 Mdot
.546 .33426 Mdot
.546 .33426 Mdot
.546 .33427 Mdot
.546 .33427 Mdot
.546 .33427 Mdot
.546 .33427 Mdot
.546 .33427 Mdot
.546 .33427 Mdot
.546 .33428 Mdot
.546 .33428 Mdot
.546 .33428 Mdot
.546 .33428 Mdot
.546 .33428 Mdot
.546 .33429 Mdot
.546 .33429 Mdot
.546 .33429 Mdot
.546 .3343 Mdot
.546 .3343 Mdot
.546 .3343 Mdot
.546 .3343 Mdot
.546 .3343 Mdot
.546 .33431 Mdot
.546 .33431 Mdot
.546 .33431 Mdot
.546 .33431 Mdot
.546 .33431 Mdot
.546 .33431 Mdot
.546 .33432 Mdot
.546 .33432 Mdot
.546 .33432 Mdot
.546 .33432 Mdot
.546 .33432 Mdot
.546 .33433 Mdot
.546 .33433 Mdot
.546 .33433 Mdot
.546 .33433 Mdot
.546 .33433 Mdot
.546 .33434 Mdot
.546 .33434 Mdot
.546 .33434 Mdot
.546 .33434 Mdot
.546 .33434 Mdot
.546 .33434 Mdot
.546 .33435 Mdot
.546 .33435 Mdot
.546 .33435 Mdot
.546 .33435 Mdot
.546 .33435 Mdot
.546 .33436 Mdot
.546 .33436 Mdot
.546 .33436 Mdot
.546 .33436 Mdot
.546 .33436 Mdot
.546 .33436 Mdot
.546 .33436 Mdot
.546 .33437 Mdot
.546 .33437 Mdot
.546 .33437 Mdot
.546 .33437 Mdot
.546 .33437 Mdot
.546 .33437 Mdot
.546 .33437 Mdot
.546 .33437 Mdot
.546 .33437 Mdot
.546 .33437 Mdot
.546 .33438 Mdot
.546 .33438 Mdot
.546 .33438 Mdot
.546 .33438 Mdot
.546 .33438 Mdot
.546 .33438 Mdot
.546 .33439 Mdot
.546 .33439 Mdot
.546 .33439 Mdot
.546 .33439 Mdot
.546 .3344 Mdot
.546 .3344 Mdot
.546 .33441 Mdot
.546 .33441 Mdot
.546 .33441 Mdot
.546 .33441 Mdot
.546 .33441 Mdot
.546 .33442 Mdot
.546 .33442 Mdot
.546 .33442 Mdot
.546 .33442 Mdot
.546 .33442 Mdot
.546 .33443 Mdot
.546 .33443 Mdot
.546 .33443 Mdot
.546 .33444 Mdot
.546 .33444 Mdot
.546 .33445 Mdot
.546 .33445 Mdot
.546 .33445 Mdot
.546 .33445 Mdot
.546 .33445 Mdot
.546 .33445 Mdot
.546 .33446 Mdot
.546 .33446 Mdot
.546 .33446 Mdot
.546 .33447 Mdot
.546 .33447 Mdot
.546 .33447 Mdot
.546 .33447 Mdot
.546 .33447 Mdot
.546 .33448 Mdot
.546 .33449 Mdot
.546 .33449 Mdot
.546 .33449 Mdot
.546 .3345 Mdot
.546 .3345 Mdot
.546 .3345 Mdot
.546 .33451 Mdot
.546 .33451 Mdot
.546 .33451 Mdot
.546 .33451 Mdot
.546 .33451 Mdot
.546 .33451 Mdot
.546 .33451 Mdot
.546 .33453 Mdot
.546 .33453 Mdot
.546 .33453 Mdot
.546 .33454 Mdot
.546 .33454 Mdot
.546 .33454 Mdot
.546 .33454 Mdot
.546 .33454 Mdot
.546 .33454 Mdot
.546 .33455 Mdot
.546 .33455 Mdot
.546 .33456 Mdot
.546 .33456 Mdot
.546 .33456 Mdot
.546 .33457 Mdot
.546 .33457 Mdot
.546 .33457 Mdot
.546 .33457 Mdot
.546 .33458 Mdot
.546 .33458 Mdot
.546 .33458 Mdot
.546 .33459 Mdot
.546 .33459 Mdot
.546 .3346 Mdot
.546 .3346 Mdot
.546 .33461 Mdot
.546 .33461 Mdot
.546 .33461 Mdot
.546 .33462 Mdot
.546 .33462 Mdot
.546 .33462 Mdot
.546 .33463 Mdot
.546 .33463 Mdot
.546 .33463 Mdot
.546 .33464 Mdot
.546 .33464 Mdot
.546 .33465 Mdot
.546 .33465 Mdot
.546 .33466 Mdot
.546 .33466 Mdot
.546 .33466 Mdot
.546 .33466 Mdot
.546 .33466 Mdot
.546 .33466 Mdot
.546 .33467 Mdot
.546 .33467 Mdot
.546 .33468 Mdot
.546 .33468 Mdot
.546 .33468 Mdot
.546 .33469 Mdot
.546 .33469 Mdot
.546 .33469 Mdot
.546 .3347 Mdot
.546 .3347 Mdot
.546 .3347 Mdot
.546 .3347 Mdot
.546 .33471 Mdot
.546 .33471 Mdot
.546 .33471 Mdot
.546 .33472 Mdot
.546 .33472 Mdot
.546 .33472 Mdot
.546 .33472 Mdot
.546 .33473 Mdot
.546 .33473 Mdot
.546 .33631 Mdot
.546 .33632 Mdot
.546 .33632 Mdot
.546 .33632 Mdot
.546 .33632 Mdot
.546 .33632 Mdot
.546 .33633 Mdot
.546 .33633 Mdot
.546 .33633 Mdot
.546 .33634 Mdot
.546 .33634 Mdot
.546 .33634 Mdot
.546 .33634 Mdot
.546 .33634 Mdot
.546 .33635 Mdot
.546 .33635 Mdot
.546 .33635 Mdot
.546 .33635 Mdot
.546 .33636 Mdot
.546 .33636 Mdot
.546 .33637 Mdot
.546 .33637 Mdot
.546 .33637 Mdot
.546 .33637 Mdot
.546 .33637 Mdot
.546 .33637 Mdot
.546 .33637 Mdot
.546 .33638 Mdot
.546 .33638 Mdot
.546 .33639 Mdot
.546 .33639 Mdot
.546 .33639 Mdot
.546 .3364 Mdot
.546 .3364 Mdot
.546 .3364 Mdot
.546 .33641 Mdot
.546 .33641 Mdot
.546 .33641 Mdot
.546 .33642 Mdot
.546 .33642 Mdot
.546 .33642 Mdot
.546 .33642 Mdot
.546 .33643 Mdot
.546 .33643 Mdot
.546 .33644 Mdot
.546 .33644 Mdot
.546 .33644 Mdot
.546 .33644 Mdot
.546 .33644 Mdot
.546 .33645 Mdot
.546 .33645 Mdot
.546 .33645 Mdot
.546 .33645 Mdot
.546 .33645 Mdot
.546 .33646 Mdot
.546 .33647 Mdot
.546 .33647 Mdot
.546 .33647 Mdot
.546 .33647 Mdot
.546 .33647 Mdot
.546 .33648 Mdot
.546 .33648 Mdot
.546 .33648 Mdot
.546 .33648 Mdot
.546 .33649 Mdot
.546 .33649 Mdot
.546 .3365 Mdot
.546 .3365 Mdot
.546 .3365 Mdot
.546 .3365 Mdot
.546 .3365 Mdot
.546 .3365 Mdot
.546 .3365 Mdot
.546 .3365 Mdot
.546 .33651 Mdot
.546 .33651 Mdot
.546 .33652 Mdot
.546 .33652 Mdot
.546 .33652 Mdot
.546 .33653 Mdot
.546 .33653 Mdot
.546 .33653 Mdot
.546 .33653 Mdot
.546 .33654 Mdot
.546 .33654 Mdot
.546 .33654 Mdot
.546 .33654 Mdot
.546 .33654 Mdot
.546 .33654 Mdot
.546 .33655 Mdot
.546 .33655 Mdot
.546 .33655 Mdot
.546 .33655 Mdot
.546 .33656 Mdot
.546 .33656 Mdot
.546 .33656 Mdot
.546 .33656 Mdot
.546 .33657 Mdot
.546 .33657 Mdot
.546 .33657 Mdot
.546 .33658 Mdot
.546 .33658 Mdot
.546 .33658 Mdot
.546 .33658 Mdot
.546 .33658 Mdot
.546 .33658 Mdot
.546 .33658 Mdot
.546 .33659 Mdot
.546 .33659 Mdot
.546 .3366 Mdot
.546 .3366 Mdot
.546 .3366 Mdot
.546 .3366 Mdot
.546 .3366 Mdot
.546 .3366 Mdot
.546 .33661 Mdot
.546 .33661 Mdot
.546 .33661 Mdot
.546 .33661 Mdot
.546 .33661 Mdot
.546 .33661 Mdot
.546 .33662 Mdot
.546 .33662 Mdot
.546 .33662 Mdot
.546 .33662 Mdot
.546 .33662 Mdot
.546 .33662 Mdot
.546 .33662 Mdot
.546 .33662 Mdot
.546 .33662 Mdot
.546 .33662 Mdot
.546 .33662 Mdot
.546 .33662 Mdot
.546 .33662 Mdot
.546 .33663 Mdot
.546 .33663 Mdot
.546 .33663 Mdot
.546 .33663 Mdot
.546 .33663 Mdot
.546 .33663 Mdot
.546 .33663 Mdot
.546 .33664 Mdot
.546 .33664 Mdot
.546 .33664 Mdot
.546 .33664 Mdot
.546 .33664 Mdot
.546 .33664 Mdot
.546 .33664 Mdot
.546 .33665 Mdot
.546 .33665 Mdot
.546 .33665 Mdot
.546 .33665 Mdot
.546 .33665 Mdot
.546 .33666 Mdot
.546 .33666 Mdot
.546 .33666 Mdot
.546 .33666 Mdot
.546 .33667 Mdot
.546 .33667 Mdot
.546 .33667 Mdot
.546 .33667 Mdot
.546 .33667 Mdot
.546 .33667 Mdot
.546 .33667 Mdot
.546 .33668 Mdot
.546 .33668 Mdot
.546 .33668 Mdot
.546 .33668 Mdot
.546 .33668 Mdot
.546 .33668 Mdot
.546 .33668 Mdot
.546 .33669 Mdot
.546 .33669 Mdot
.546 .33669 Mdot
.546 .33669 Mdot
.546 .33669 Mdot
.546 .3367 Mdot
.546 .3367 Mdot
.546 .3367 Mdot
.546 .3367 Mdot
.546 .3367 Mdot
.546 .3367 Mdot
.546 .3367 Mdot
.546 .3367 Mdot
.546 .33671 Mdot
.546 .33671 Mdot
.546 .33671 Mdot
.546 .33672 Mdot
.546 .33672 Mdot
.546 .33672 Mdot
.546 .33672 Mdot
.546 .33672 Mdot
.546 .33672 Mdot
.546 .33672 Mdot
.546 .33672 Mdot
.546 .33673 Mdot
.546 .33673 Mdot
.546 .33673 Mdot
.546 .33674 Mdot
.546 .33674 Mdot
.546 .33674 Mdot
.546 .33674 Mdot
.546 .33674 Mdot
.546 .33674 Mdot
.546 .33674 Mdot
.546 .33675 Mdot
.546 .33675 Mdot
.546 .33675 Mdot
.546 .33675 Mdot
.546 .33676 Mdot
.546 .33676 Mdot
.546 .33676 Mdot
.546 .33676 Mdot
.546 .33676 Mdot
.546 .33677 Mdot
.546 .33677 Mdot
.546 .33677 Mdot
.546 .33677 Mdot
.546 .33677 Mdot
.546 .33678 Mdot
.546 .33678 Mdot
.546 .33679 Mdot
.546 .33679 Mdot
.546 .33679 Mdot
.546 .33679 Mdot
.546 .33679 Mdot
.546 .33679 Mdot
.546 .33679 Mdot
.546 .33679 Mdot
.546 .33679 Mdot
.546 .3368 Mdot
.546 .3368 Mdot
.546 .3368 Mdot
.546 .3368 Mdot
.546 .33681 Mdot
.546 .33681 Mdot
.546 .33681 Mdot
.546 .33681 Mdot
.546 .33681 Mdot
.546 .33682 Mdot
.546 .33682 Mdot
.546 .33682 Mdot
.546 .33682 Mdot
.546 .33682 Mdot
.546 .33683 Mdot
.546 .33683 Mdot
.546 .33683 Mdot
.546 .33683 Mdot
.546 .33683 Mdot
.546 .33683 Mdot
.548 .30698 Mdot
.548 .30698 Mdot
.548 .30698 Mdot
.548 .30698 Mdot
.548 .30698 Mdot
.548 .30698 Mdot
.548 .30699 Mdot
.548 .30699 Mdot
.548 .30699 Mdot
.548 .30699 Mdot
.548 .30699 Mdot
.548 .307 Mdot
.548 .307 Mdot
.548 .307 Mdot
.548 .307 Mdot
.548 .30701 Mdot
.548 .30701 Mdot
.548 .30701 Mdot
.548 .30701 Mdot
.548 .30702 Mdot
.548 .30703 Mdot
.548 .30703 Mdot
.548 .30704 Mdot
.548 .30704 Mdot
.548 .30705 Mdot
.548 .30705 Mdot
.548 .30705 Mdot
.548 .30705 Mdot
.548 .30707 Mdot
.548 .30707 Mdot
.548 .30707 Mdot
.548 .30708 Mdot
.548 .30708 Mdot
.548 .30708 Mdot
.548 .30709 Mdot
.548 .30709 Mdot
.548 .30709 Mdot
.548 .30711 Mdot
.548 .30711 Mdot
.548 .30712 Mdot
.548 .30712 Mdot
.548 .30712 Mdot
.548 .30712 Mdot
.548 .30712 Mdot
.548 .30712 Mdot
.548 .30712 Mdot
.548 .30712 Mdot
.548 .30712 Mdot
.548 .30713 Mdot
.548 .30713 Mdot
.548 .30713 Mdot
.548 .30713 Mdot
.548 .30713 Mdot
.548 .30713 Mdot
.548 .30713 Mdot
.548 .30713 Mdot
.548 .30714 Mdot
.548 .30714 Mdot
.548 .30715 Mdot
.548 .30715 Mdot
.548 .30716 Mdot
.548 .30716 Mdot
.548 .30717 Mdot
.548 .30717 Mdot
.548 .30717 Mdot
.548 .30718 Mdot
.548 .30718 Mdot
.548 .30718 Mdot
.548 .30718 Mdot
.548 .30719 Mdot
.548 .30719 Mdot
.548 .30719 Mdot
.548 .30719 Mdot
.548 .30719 Mdot
.548 .30719 Mdot
.548 .30719 Mdot
.548 .30719 Mdot
.548 .30719 Mdot
.548 .3072 Mdot
.548 .3072 Mdot
.548 .30721 Mdot
.548 .30721 Mdot
.548 .30721 Mdot
.548 .30721 Mdot
.548 .30722 Mdot
.548 .30722 Mdot
.548 .30722 Mdot
.548 .30722 Mdot
.548 .30722 Mdot
.548 .30722 Mdot
.548 .30722 Mdot
.548 .30722 Mdot
.548 .30722 Mdot
.548 .30722 Mdot
.548 .30722 Mdot
.548 .30723 Mdot
.548 .30723 Mdot
.548 .30723 Mdot
.548 .30723 Mdot
.548 .30723 Mdot
.548 .30723 Mdot
.548 .30723 Mdot
.548 .30723 Mdot
.548 .30724 Mdot
.548 .30724 Mdot
.548 .30724 Mdot
.548 .30724 Mdot
.548 .30724 Mdot
.548 .30724 Mdot
.548 .30724 Mdot
.548 .30724 Mdot
.548 .30724 Mdot
.548 .30724 Mdot
.548 .30724 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30725 Mdot
.548 .30726 Mdot
.548 .30726 Mdot
.548 .30726 Mdot
.548 .30726 Mdot
.548 .30726 Mdot
.548 .30726 Mdot
.548 .30727 Mdot
.548 .30727 Mdot
.548 .30727 Mdot
.548 .30727 Mdot
.548 .30727 Mdot
.548 .30727 Mdot
.548 .30727 Mdot
.548 .30727 Mdot
.548 .30727 Mdot
.548 .30727 Mdot
.548 .30727 Mdot
.548 .30728 Mdot
.548 .30728 Mdot
.548 .30728 Mdot
.548 .30729 Mdot
.548 .30729 Mdot
.548 .30729 Mdot
.548 .30729 Mdot
.548 .30729 Mdot
.548 .30729 Mdot
.548 .30729 Mdot
.548 .30729 Mdot
.548 .30729 Mdot
.548 .30729 Mdot
.548 .3073 Mdot
.548 .3073 Mdot
.548 .30731 Mdot
.548 .30731 Mdot
.548 .30731 Mdot
.548 .30732 Mdot
.548 .30732 Mdot
.548 .30732 Mdot
.548 .30733 Mdot
.548 .30733 Mdot
.548 .30733 Mdot
.548 .30733 Mdot
.548 .30733 Mdot
.548 .30733 Mdot
.548 .30734 Mdot
.548 .30734 Mdot
.548 .30734 Mdot
.548 .30734 Mdot
.548 .30734 Mdot
.548 .30736 Mdot
.548 .30736 Mdot
.548 .30736 Mdot
.548 .30737 Mdot
.548 .30737 Mdot
.548 .30738 Mdot
.548 .30739 Mdot
.548 .3074 Mdot
.548 .30741 Mdot
.548 .30741 Mdot
.548 .30741 Mdot
.548 .30741 Mdot
.548 .30741 Mdot
.548 .30742 Mdot
.548 .30742 Mdot
.548 .30742 Mdot
.548 .30742 Mdot
.548 .30742 Mdot
.548 .30742 Mdot
.548 .30743 Mdot
.548 .30743 Mdot
.548 .30743 Mdot
.548 .30743 Mdot
.548 .30743 Mdot
.548 .30743 Mdot
.548 .30744 Mdot
.548 .30744 Mdot
.548 .30744 Mdot
.548 .30747 Mdot
.548 .30748 Mdot
.548 .30748 Mdot
.548 .30748 Mdot
.548 .30748 Mdot
.548 .30749 Mdot
.548 .3075 Mdot
.548 .30751 Mdot
.548 .30751 Mdot
.548 .30753 Mdot
.548 .30753 Mdot
.548 .30753 Mdot
.548 .30754 Mdot
.548 .30754 Mdot
.548 .30754 Mdot
.548 .30755 Mdot
.548 .30757 Mdot
.548 .30758 Mdot
.548 .30758 Mdot
.548 .30758 Mdot
.548 .30759 Mdot
.548 .30759 Mdot
.548 .3076 Mdot
.548 .30761 Mdot
.548 .30761 Mdot
.548 .30761 Mdot
.548 .30762 Mdot
.548 .30762 Mdot
.548 .30762 Mdot
.548 .30762 Mdot
.548 .30763 Mdot
.548 .30763 Mdot
.548 .30763 Mdot
.548 .30763 Mdot
.548 .30763 Mdot
.548 .30763 Mdot
.548 .30945 Mdot
.548 .30946 Mdot
.548 .30946 Mdot
.548 .30946 Mdot
.548 .30946 Mdot
.548 .30946 Mdot
.548 .30947 Mdot
.548 .30947 Mdot
.548 .30948 Mdot
.548 .30948 Mdot
.548 .30948 Mdot
.548 .30948 Mdot
.548 .30948 Mdot
.548 .30949 Mdot
.548 .3095 Mdot
.548 .30951 Mdot
.548 .30951 Mdot
.548 .30952 Mdot
.548 .30952 Mdot
.548 .30954 Mdot
.548 .30955 Mdot
.548 .30957 Mdot
.548 .30957 Mdot
.548 .30957 Mdot
.548 .30958 Mdot
.548 .30958 Mdot
.548 .30958 Mdot
.548 .30961 Mdot
.548 .30961 Mdot
.548 .30962 Mdot
.548 .30962 Mdot
.548 .30964 Mdot
.548 .30964 Mdot
.548 .30964 Mdot
.548 .30964 Mdot
.548 .30965 Mdot
.548 .30969 Mdot
.548 .30969 Mdot
.548 .30969 Mdot
.548 .3097 Mdot
.548 .3097 Mdot
.548 .3097 Mdot
.548 .3097 Mdot
.548 .3097 Mdot
.548 .30971 Mdot
.548 .30971 Mdot
.548 .30971 Mdot
.548 .30971 Mdot
.548 .30971 Mdot
.548 .30972 Mdot
.548 .30972 Mdot
.548 .30972 Mdot
.548 .30972 Mdot
.548 .30973 Mdot
.548 .30973 Mdot
.548 .30973 Mdot
.548 .30974 Mdot
.548 .30975 Mdot
.548 .30976 Mdot
.548 .30977 Mdot
.548 .30977 Mdot
.548 .30978 Mdot
.548 .30978 Mdot
.548 .30979 Mdot
.548 .30981 Mdot
.548 .30981 Mdot
.548 .30981 Mdot
.548 .30981 Mdot
.548 .30981 Mdot
.548 .30982 Mdot
.548 .30982 Mdot
.548 .30982 Mdot
.548 .30982 Mdot
.548 .30982 Mdot
.548 .30982 Mdot
.548 .30983 Mdot
.548 .30983 Mdot
.548 .30983 Mdot
.548 .30984 Mdot
.548 .30985 Mdot
.548 .30985 Mdot
.548 .30985 Mdot
.548 .30986 Mdot
.548 .30987 Mdot
.548 .30987 Mdot
.548 .30987 Mdot
.548 .30987 Mdot
.548 .30987 Mdot
.548 .30987 Mdot
.548 .30987 Mdot
.548 .30987 Mdot
.548 .30987 Mdot
.548 .30987 Mdot
.548 .30988 Mdot
.548 .30989 Mdot
.548 .30989 Mdot
.548 .30989 Mdot
.548 .30989 Mdot
.548 .30989 Mdot
.548 .3099 Mdot
.548 .3099 Mdot
.548 .3099 Mdot
.548 .3099 Mdot
.548 .3099 Mdot
.548 .3099 Mdot
.548 .3099 Mdot
.548 .3099 Mdot
.548 .3099 Mdot
.548 .3099 Mdot
.548 .30991 Mdot
.548 .30991 Mdot
.548 .30991 Mdot
.548 .30991 Mdot
.548 .30991 Mdot
.548 .30991 Mdot
.548 .30991 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30992 Mdot
.548 .30993 Mdot
.548 .30993 Mdot
.548 .30993 Mdot
.548 .30993 Mdot
.548 .30993 Mdot
.548 .30993 Mdot
.548 .30993 Mdot
.548 .30994 Mdot
.548 .30994 Mdot
.548 .30994 Mdot
.548 .30994 Mdot
.548 .30994 Mdot
.548 .30994 Mdot
.548 .30994 Mdot
.548 .30994 Mdot
.548 .30995 Mdot
.548 .30995 Mdot
.548 .30995 Mdot
.548 .30995 Mdot
.548 .30995 Mdot
.548 .30995 Mdot
.548 .30995 Mdot
.548 .30996 Mdot
.548 .30996 Mdot
.548 .30996 Mdot
.548 .30996 Mdot
.548 .30996 Mdot
.548 .30997 Mdot
.548 .30997 Mdot
.548 .30997 Mdot
.548 .30997 Mdot
.548 .30998 Mdot
.548 .30998 Mdot
.548 .30998 Mdot
.548 .30999 Mdot
.548 .30999 Mdot
.548 .30999 Mdot
.548 .30999 Mdot
.548 .30999 Mdot
.548 .30999 Mdot
.548 .30999 Mdot
.548 .30999 Mdot
.548 .31 Mdot
.548 .31 Mdot
.548 .31 Mdot
.548 .31001 Mdot
.548 .31001 Mdot
.548 .31002 Mdot
.548 .31002 Mdot
.548 .31002 Mdot
.548 .31003 Mdot
.548 .31004 Mdot
.548 .31005 Mdot
.548 .31005 Mdot
.548 .31005 Mdot
.548 .31006 Mdot
.548 .31006 Mdot
.548 .31006 Mdot
.548 .31006 Mdot
.548 .31006 Mdot
.548 .31007 Mdot
.548 .31007 Mdot
.548 .31007 Mdot
.548 .31007 Mdot
.548 .31007 Mdot
.548 .31007 Mdot
.548 .31007 Mdot
.548 .31008 Mdot
.548 .31008 Mdot
.548 .31008 Mdot
.548 .31008 Mdot
.548 .31008 Mdot
.548 .31008 Mdot
.548 .31011 Mdot
.548 .31011 Mdot
.548 .31011 Mdot
.548 .31012 Mdot
.548 .31012 Mdot
.548 .31013 Mdot
.548 .31013 Mdot
.548 .31014 Mdot
.548 .31014 Mdot
.548 .31016 Mdot
.548 .31016 Mdot
.548 .31016 Mdot
.548 .31016 Mdot
.548 .31016 Mdot
.548 .31017 Mdot
.548 .31018 Mdot
.548 .31019 Mdot
.548 .3102 Mdot
.548 .3102 Mdot
.548 .3102 Mdot
.548 .3102 Mdot
.548 .31021 Mdot
.548 .31022 Mdot
.548 .31022 Mdot
.548 .31022 Mdot
.548 .31022 Mdot
.548 .31023 Mdot
.548 .31023 Mdot
.548 .31023 Mdot
.548 .31023 Mdot
.548 .31023 Mdot
.548 .31024 Mdot
.548 .31024 Mdot
.548 .31024 Mdot
.548 .31024 Mdot
.548 .31024 Mdot
.548 .31024 Mdot
.548 .33504 Mdot
.548 .33504 Mdot
.548 .33504 Mdot
.548 .33504 Mdot
.548 .33504 Mdot
.548 .33504 Mdot
.548 .33505 Mdot
.548 .33505 Mdot
.548 .33505 Mdot
.548 .33505 Mdot
.548 .33505 Mdot
.548 .33505 Mdot
.548 .33505 Mdot
.548 .33506 Mdot
.548 .33506 Mdot
.548 .33507 Mdot
.548 .33507 Mdot
.548 .33507 Mdot
.548 .33507 Mdot
.548 .33508 Mdot
.548 .33509 Mdot
.548 .3351 Mdot
.548 .33511 Mdot
.548 .33511 Mdot
.548 .33511 Mdot
.548 .33511 Mdot
.548 .33511 Mdot
.548 .33512 Mdot
.548 .33513 Mdot
.548 .33513 Mdot
.548 .33514 Mdot
.548 .33514 Mdot
.548 .33515 Mdot
.548 .33515 Mdot
.548 .33515 Mdot
.548 .33515 Mdot
.548 .33516 Mdot
.548 .33518 Mdot
.548 .33518 Mdot
.548 .33519 Mdot
.548 .33519 Mdot
.548 .33519 Mdot
.548 .33519 Mdot
.548 .33519 Mdot
.548 .33519 Mdot
.548 .33519 Mdot
.548 .33519 Mdot
.548 .3352 Mdot
.548 .3352 Mdot
.548 .3352 Mdot
.548 .3352 Mdot
.548 .3352 Mdot
.548 .3352 Mdot
.548 .33521 Mdot
.548 .33521 Mdot
.548 .33521 Mdot
.548 .33521 Mdot
.548 .33521 Mdot
.548 .33522 Mdot
.548 .33523 Mdot
.548 .33523 Mdot
.548 .33524 Mdot
.548 .33524 Mdot
.548 .33524 Mdot
.548 .33525 Mdot
.548 .33526 Mdot
.548 .33526 Mdot
.548 .33526 Mdot
.548 .33526 Mdot
.548 .33526 Mdot
.548 .33526 Mdot
.548 .33526 Mdot
.548 .33527 Mdot
.548 .33527 Mdot
.548 .33527 Mdot
.548 .33527 Mdot
.548 .33527 Mdot
.548 .33527 Mdot
.548 .33527 Mdot
.548 .33528 Mdot
.548 .33528 Mdot
.548 .33529 Mdot
.548 .33529 Mdot
.548 .33529 Mdot
.548 .3353 Mdot
.548 .3353 Mdot
.548 .3353 Mdot
.548 .3353 Mdot
.548 .3353 Mdot
.548 .3353 Mdot
.548 .3353 Mdot
.548 .3353 Mdot
.548 .3353 Mdot
.548 .3353 Mdot
.548 .3353 Mdot
.548 .33531 Mdot
.548 .33531 Mdot
.548 .33531 Mdot
.548 .33531 Mdot
.548 .33531 Mdot
.548 .33531 Mdot
.548 .33532 Mdot
.548 .33532 Mdot
.548 .33532 Mdot
.548 .33532 Mdot
.548 .33532 Mdot
.548 .33532 Mdot
.548 .33532 Mdot
.548 .33532 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33533 Mdot
.548 .33534 Mdot
.548 .33534 Mdot
.548 .33534 Mdot
.548 .33534 Mdot
.548 .33534 Mdot
.548 .33534 Mdot
.548 .33534 Mdot
.548 .33535 Mdot
.548 .33535 Mdot
.548 .33535 Mdot
.548 .33535 Mdot
.548 .33535 Mdot
.548 .33535 Mdot
.548 .33535 Mdot
.548 .33535 Mdot
.548 .33535 Mdot
.548 .33535 Mdot
.548 .33535 Mdot
.548 .33536 Mdot
.548 .33536 Mdot
.548 .33536 Mdot
.548 .33537 Mdot
.548 .33537 Mdot
.548 .33537 Mdot
.548 .33537 Mdot
.548 .33537 Mdot
.548 .33537 Mdot
.548 .33538 Mdot
.548 .33538 Mdot
.548 .33538 Mdot
.548 .33538 Mdot
.548 .33538 Mdot
.548 .33539 Mdot
.548 .33539 Mdot
.548 .33539 Mdot
.548 .3354 Mdot
.548 .3354 Mdot
.548 .33541 Mdot
.548 .33541 Mdot
.548 .33541 Mdot
.548 .33542 Mdot
.548 .33542 Mdot
.548 .33542 Mdot
.548 .33542 Mdot
.548 .33542 Mdot
.548 .33542 Mdot
.548 .33543 Mdot
.548 .33543 Mdot
.548 .33543 Mdot
.548 .33543 Mdot
.548 .33543 Mdot
.548 .33545 Mdot
.548 .33545 Mdot
.548 .33545 Mdot
.548 .33546 Mdot
.548 .33547 Mdot
.548 .33548 Mdot
.548 .33548 Mdot
.548 .3355 Mdot
.548 .3355 Mdot
.548 .33551 Mdot
.548 .33551 Mdot
.548 .33551 Mdot
.548 .33551 Mdot
.548 .33552 Mdot
.548 .33552 Mdot
.548 .33552 Mdot
.548 .33552 Mdot
.548 .33552 Mdot
.548 .33553 Mdot
.548 .33553 Mdot
.548 .33553 Mdot
.548 .33553 Mdot
.548 .33553 Mdot
.548 .33553 Mdot
.548 .33554 Mdot
.548 .33554 Mdot
.548 .33554 Mdot
.548 .33554 Mdot
.548 .33558 Mdot
.548 .33558 Mdot
.548 .33558 Mdot
.548 .33559 Mdot
.548 .33559 Mdot
.548 .3356 Mdot
.548 .33561 Mdot
.548 .33562 Mdot
.548 .33562 Mdot
.548 .33564 Mdot
.548 .33564 Mdot
.548 .33564 Mdot
.548 .33565 Mdot
.548 .33565 Mdot
.548 .33565 Mdot
.548 .33567 Mdot
.548 .33568 Mdot
.548 .33569 Mdot
.548 .3357 Mdot
.548 .3357 Mdot
.548 .3357 Mdot
.548 .33571 Mdot
.548 .33572 Mdot
.548 .33573 Mdot
.548 .33573 Mdot
.548 .33573 Mdot
.548 .33574 Mdot
.548 .33574 Mdot
.548 .33574 Mdot
.548 .33574 Mdot
.548 .33575 Mdot
.548 .33575 Mdot
.548 .33575 Mdot
.548 .33575 Mdot
.548 .33575 Mdot
.548 .33575 Mdot
.548 .33742 Mdot
.548 .33742 Mdot
.548 .33742 Mdot
.548 .33742 Mdot
.548 .33742 Mdot
.548 .33742 Mdot
.548 .33743 Mdot
.548 .33743 Mdot
.548 .33743 Mdot
.548 .33743 Mdot
.548 .33743 Mdot
.548 .33744 Mdot
.548 .33744 Mdot
.548 .33745 Mdot
.548 .33745 Mdot
.548 .33745 Mdot
.548 .33746 Mdot
.548 .33746 Mdot
.548 .33746 Mdot
.548 .33747 Mdot
.548 .33748 Mdot
.548 .33749 Mdot
.548 .3375 Mdot
.548 .3375 Mdot
.548 .33751 Mdot
.548 .33751 Mdot
.548 .33751 Mdot
.548 .33751 Mdot
.548 .33753 Mdot
.548 .33753 Mdot
.548 .33754 Mdot
.548 .33754 Mdot
.548 .33755 Mdot
.548 .33755 Mdot
.548 .33756 Mdot
.548 .33756 Mdot
.548 .33756 Mdot
.548 .33759 Mdot
.548 .33759 Mdot
.548 .3376 Mdot
.548 .3376 Mdot
.548 .3376 Mdot
.548 .3376 Mdot
.548 .3376 Mdot
.548 .3376 Mdot
.548 .33761 Mdot
.548 .33761 Mdot
.548 .33761 Mdot
.548 .33761 Mdot
.548 .33761 Mdot
.548 .33761 Mdot
.548 .33761 Mdot
.548 .33762 Mdot
.548 .33762 Mdot
.548 .33762 Mdot
.548 .33762 Mdot
.548 .33762 Mdot
.548 .33763 Mdot
.548 .33764 Mdot
.548 .33765 Mdot
.548 .33765 Mdot
.548 .33766 Mdot
.548 .33767 Mdot
.548 .33767 Mdot
.548 .33767 Mdot
.548 .33768 Mdot
.548 .33768 Mdot
.548 .33769 Mdot
.548 .33769 Mdot
.548 .33769 Mdot
.548 .33769 Mdot
.548 .33769 Mdot
.548 .33769 Mdot
.548 .33769 Mdot
.548 .33769 Mdot
.548 .33769 Mdot
.548 .3377 Mdot
.548 .3377 Mdot
.548 .3377 Mdot
.548 .33771 Mdot
.548 .33771 Mdot
.548 .33772 Mdot
.548 .33772 Mdot
.548 .33772 Mdot
.548 .33773 Mdot
.548 .33773 Mdot
.548 .33773 Mdot
.548 .33773 Mdot
.548 .33773 Mdot
.548 .33773 Mdot
.548 .33773 Mdot
.548 .33773 Mdot
.548 .33773 Mdot
.548 .33773 Mdot
.548 .33774 Mdot
.548 .33774 Mdot
.548 .33774 Mdot
.548 .33775 Mdot
.548 .33775 Mdot
.548 .33775 Mdot
.548 .33775 Mdot
.548 .33775 Mdot
.548 .33775 Mdot
.548 .33775 Mdot
.548 .33775 Mdot
.548 .33775 Mdot
.548 .33775 Mdot
.548 .33775 Mdot
.548 .33776 Mdot
.548 .33776 Mdot
.548 .33776 Mdot
.548 .33776 Mdot
.548 .33776 Mdot
.548 .33776 Mdot
.548 .33776 Mdot
.548 .33776 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33777 Mdot
.548 .33778 Mdot
.548 .33778 Mdot
.548 .33778 Mdot
.548 .33778 Mdot
.548 .33778 Mdot
.548 .33778 Mdot
.548 .33778 Mdot
.548 .33778 Mdot
.548 .33778 Mdot
.548 .33779 Mdot
.548 .33779 Mdot
.548 .33779 Mdot
.548 .33779 Mdot
.548 .33779 Mdot
.548 .33779 Mdot
.548 .33779 Mdot
.548 .3378 Mdot
.548 .3378 Mdot
.548 .3378 Mdot
.548 .3378 Mdot
.548 .3378 Mdot
.548 .3378 Mdot
.548 .3378 Mdot
.548 .3378 Mdot
.548 .3378 Mdot
.548 .33781 Mdot
.548 .33781 Mdot
.548 .33781 Mdot
.548 .33782 Mdot
.548 .33782 Mdot
.548 .33782 Mdot
.548 .33782 Mdot
.548 .33782 Mdot
.548 .33782 Mdot
.548 .33782 Mdot
.548 .33782 Mdot
.548 .33782 Mdot
.548 .33783 Mdot
.548 .33783 Mdot
.548 .33783 Mdot
.548 .33783 Mdot
.548 .33783 Mdot
.548 .33784 Mdot
.548 .33784 Mdot
.548 .33784 Mdot
.548 .33785 Mdot
.548 .33785 Mdot
.548 .33786 Mdot
.548 .33786 Mdot
.548 .33787 Mdot
.548 .33787 Mdot
.548 .33787 Mdot
.548 .33787 Mdot
.548 .33787 Mdot
.548 .33787 Mdot
.548 .33788 Mdot
.548 .33788 Mdot
.548 .33788 Mdot
.548 .33788 Mdot
.548 .33788 Mdot
.548 .33788 Mdot
.548 .33788 Mdot
.548 .33789 Mdot
.548 .33789 Mdot
.548 .33789 Mdot
.548 .33789 Mdot
.548 .33789 Mdot
.548 .33789 Mdot
.548 .33789 Mdot
.548 .33789 Mdot
.548 .33791 Mdot
.548 .33792 Mdot
.548 .33792 Mdot
.548 .33792 Mdot
.548 .33792 Mdot
.548 .33793 Mdot
.548 .33793 Mdot
.548 .33793 Mdot
.548 .33793 Mdot
.548 .33795 Mdot
.548 .33795 Mdot
.548 .33795 Mdot
.548 .33795 Mdot
.548 .33795 Mdot
.548 .33796 Mdot
.548 .33796 Mdot
.548 .33797 Mdot
.548 .33798 Mdot
.548 .33798 Mdot
.548 .33798 Mdot
.548 .33799 Mdot
.548 .33799 Mdot
.548 .33799 Mdot
.548 .33799 Mdot
.548 .338 Mdot
.548 .338 Mdot
.548 .338 Mdot
.548 .338 Mdot
.548 .338 Mdot
.548 .338 Mdot
.548 .338 Mdot
.548 .33801 Mdot
.548 .33801 Mdot
.548 .33801 Mdot
.548 .33801 Mdot
.548 .33801 Mdot
.548 .33801 Mdot
.55 .30675 Mdot
.55 .30675 Mdot
.55 .30675 Mdot
.55 .30676 Mdot
.55 .30676 Mdot
.55 .30677 Mdot
.55 .30677 Mdot
.55 .30678 Mdot
.55 .30679 Mdot
.55 .30679 Mdot
.55 .30679 Mdot
.55 .30679 Mdot
.55 .30679 Mdot
.55 .30679 Mdot
.55 .30679 Mdot
.55 .30679 Mdot
.55 .30679 Mdot
.55 .3068 Mdot
.55 .3068 Mdot
.55 .3068 Mdot
.55 .3068 Mdot
.55 .3068 Mdot
.55 .3068 Mdot
.55 .30681 Mdot
.55 .30681 Mdot
.55 .30682 Mdot
.55 .30682 Mdot
.55 .30682 Mdot
.55 .30682 Mdot
.55 .30682 Mdot
.55 .30682 Mdot
.55 .30682 Mdot
.55 .30683 Mdot
.55 .30683 Mdot
.55 .30684 Mdot
.55 .30684 Mdot
.55 .30684 Mdot
.55 .30684 Mdot
.55 .30685 Mdot
.55 .30685 Mdot
.55 .30685 Mdot
.55 .30685 Mdot
.55 .30685 Mdot
.55 .30686 Mdot
.55 .30686 Mdot
.55 .30686 Mdot
.55 .30686 Mdot
.55 .30686 Mdot
.55 .30687 Mdot
.55 .30687 Mdot
.55 .30687 Mdot
.55 .30687 Mdot
.55 .30687 Mdot
.55 .30689 Mdot
.55 .30689 Mdot
.55 .30689 Mdot
.55 .30689 Mdot
.55 .30689 Mdot
.55 .30689 Mdot
.55 .3069 Mdot
.55 .3069 Mdot
.55 .30691 Mdot
.55 .30691 Mdot
.55 .30691 Mdot
.55 .30691 Mdot
.55 .30692 Mdot
.55 .30693 Mdot
.55 .30693 Mdot
.55 .30693 Mdot
.55 .30693 Mdot
.55 .30693 Mdot
.55 .30693 Mdot
.55 .30693 Mdot
.55 .30693 Mdot
.55 .30693 Mdot
.55 .30693 Mdot
.55 .30694 Mdot
.55 .30694 Mdot
.55 .30694 Mdot
.55 .30694 Mdot
.55 .30695 Mdot
.55 .30695 Mdot
.55 .30695 Mdot
.55 .30695 Mdot
.55 .30696 Mdot
.55 .30696 Mdot
.55 .30696 Mdot
.55 .30696 Mdot
.55 .30696 Mdot
.55 .30696 Mdot
.55 .30697 Mdot
.55 .30697 Mdot
.55 .30698 Mdot
.55 .30698 Mdot
.55 .30698 Mdot
.55 .30698 Mdot
.55 .30698 Mdot
.55 .30699 Mdot
.55 .30699 Mdot
.55 .30699 Mdot
.55 .307 Mdot
.55 .307 Mdot
.55 .307 Mdot
.55 .307 Mdot
.55 .307 Mdot
.55 .307 Mdot
.55 .307 Mdot
.55 .30701 Mdot
.55 .30701 Mdot
.55 .30701 Mdot
.55 .30701 Mdot
.55 .30701 Mdot
.55 .30701 Mdot
.55 .30701 Mdot
.55 .30702 Mdot
.55 .30702 Mdot
.55 .30703 Mdot
.55 .30703 Mdot
.55 .30703 Mdot
.55 .30704 Mdot
.55 .30704 Mdot
.55 .30704 Mdot
.55 .30705 Mdot
.55 .30706 Mdot
.55 .30706 Mdot
.55 .30706 Mdot
.55 .30707 Mdot
.55 .30707 Mdot
.55 .30707 Mdot
.55 .30708 Mdot
.55 .30708 Mdot
.55 .30708 Mdot
.55 .30709 Mdot
.55 .30709 Mdot
.55 .30709 Mdot
.55 .3071 Mdot
.55 .3071 Mdot
.55 .30711 Mdot
.55 .30711 Mdot
.55 .30711 Mdot
.55 .30711 Mdot
.55 .30711 Mdot
.55 .30712 Mdot
.55 .30712 Mdot
.55 .30712 Mdot
.55 .30712 Mdot
.55 .30712 Mdot
.55 .30712 Mdot
.55 .30713 Mdot
.55 .30713 Mdot
.55 .30713 Mdot
.55 .30713 Mdot
.55 .30714 Mdot
.55 .30714 Mdot
.55 .30715 Mdot
.55 .30715 Mdot
.55 .30715 Mdot
.55 .30716 Mdot
.55 .30716 Mdot
.55 .30716 Mdot
.55 .30717 Mdot
.55 .30718 Mdot
.55 .30718 Mdot
.55 .30718 Mdot
.55 .30719 Mdot
.55 .30719 Mdot
.55 .30719 Mdot
.55 .30719 Mdot
.55 .30719 Mdot
.55 .3072 Mdot
.55 .30721 Mdot
.55 .30721 Mdot
.55 .30721 Mdot
.55 .30722 Mdot
.55 .30722 Mdot
.55 .30722 Mdot
.55 .30722 Mdot
.55 .30722 Mdot
.55 .30723 Mdot
.55 .30723 Mdot
.55 .30723 Mdot
.55 .30723 Mdot
.55 .30723 Mdot
.55 .30723 Mdot
.55 .30724 Mdot
.55 .30725 Mdot
.55 .30726 Mdot
.55 .30726 Mdot
.55 .30726 Mdot
.55 .30727 Mdot
.55 .30727 Mdot
.55 .30729 Mdot
.55 .30729 Mdot
.55 .30729 Mdot
.55 .30729 Mdot
.55 .30729 Mdot
.55 .30729 Mdot
.55 .30731 Mdot
.55 .30731 Mdot
.55 .30731 Mdot
.55 .30731 Mdot
.55 .30731 Mdot
.55 .30732 Mdot
.55 .30732 Mdot
.55 .30733 Mdot
.55 .30733 Mdot
.55 .30734 Mdot
.55 .30734 Mdot
.55 .30734 Mdot
.55 .30734 Mdot
.55 .30734 Mdot
.55 .30735 Mdot
.55 .30735 Mdot
.55 .30735 Mdot
.55 .30736 Mdot
.55 .30736 Mdot
.55 .30737 Mdot
.55 .30738 Mdot
.55 .30738 Mdot
.55 .30738 Mdot
.55 .30738 Mdot
.55 .30738 Mdot
.55 .30739 Mdot
.55 .30739 Mdot
.55 .30739 Mdot
.55 .30741 Mdot
.55 .30741 Mdot
.55 .30741 Mdot
.55 .30742 Mdot
.55 .30742 Mdot
.55 .30742 Mdot
.55 .30742 Mdot
.55 .30742 Mdot
.55 .30743 Mdot
.55 .30743 Mdot
.55 .30743 Mdot
.55 .30744 Mdot
.55 .30744 Mdot
.55 .30744 Mdot
.55 .30744 Mdot
.55 .30744 Mdot
.55 .30744 Mdot
.55 .30744 Mdot
.55 .30746 Mdot
.55 .30746 Mdot
.55 .30747 Mdot
.55 .30748 Mdot
.55 .30749 Mdot
.55 .30749 Mdot
.55 .30749 Mdot
.55 .30941 Mdot
.55 .30942 Mdot
.55 .30942 Mdot
.55 .30943 Mdot
.55 .30944 Mdot
.55 .30945 Mdot
.55 .30945 Mdot
.55 .30947 Mdot
.55 .30948 Mdot
.55 .30948 Mdot
.55 .30948 Mdot
.55 .30948 Mdot
.55 .30948 Mdot
.55 .30948 Mdot
.55 .30948 Mdot
.55 .30949 Mdot
.55 .30949 Mdot
.55 .3095 Mdot
.55 .3095 Mdot
.55 .3095 Mdot
.55 .3095 Mdot
.55 .30951 Mdot
.55 .30951 Mdot
.55 .30952 Mdot
.55 .30952 Mdot
.55 .30954 Mdot
.55 .30954 Mdot
.55 .30954 Mdot
.55 .30955 Mdot
.55 .30955 Mdot
.55 .30955 Mdot
.55 .30955 Mdot
.55 .30955 Mdot
.55 .30956 Mdot
.55 .30958 Mdot
.55 .30958 Mdot
.55 .30958 Mdot
.55 .30958 Mdot
.55 .30959 Mdot
.55 .30959 Mdot
.55 .30959 Mdot
.55 .30959 Mdot
.55 .3096 Mdot
.55 .3096 Mdot
.55 .30961 Mdot
.55 .30961 Mdot
.55 .30962 Mdot
.55 .30962 Mdot
.55 .30963 Mdot
.55 .30963 Mdot
.55 .30963 Mdot
.55 .30963 Mdot
.55 .30963 Mdot
.55 .30966 Mdot
.55 .30966 Mdot
.55 .30966 Mdot
.55 .30966 Mdot
.55 .30966 Mdot
.55 .30966 Mdot
.55 .30968 Mdot
.55 .30968 Mdot
.55 .30969 Mdot
.55 .30969 Mdot
.55 .30969 Mdot
.55 .30971 Mdot
.55 .30972 Mdot
.55 .30973 Mdot
.55 .30973 Mdot
.55 .30973 Mdot
.55 .30973 Mdot
.55 .30973 Mdot
.55 .30973 Mdot
.55 .30974 Mdot
.55 .30974 Mdot
.55 .30974 Mdot
.55 .30974 Mdot
.55 .30975 Mdot
.55 .30975 Mdot
.55 .30976 Mdot
.55 .30976 Mdot
.55 .30976 Mdot
.55 .30977 Mdot
.55 .30978 Mdot
.55 .30978 Mdot
.55 .30978 Mdot
.55 .30978 Mdot
.55 .30978 Mdot
.55 .30979 Mdot
.55 .30979 Mdot
.55 .30979 Mdot
.55 .3098 Mdot
.55 .30981 Mdot
.55 .30981 Mdot
.55 .30982 Mdot
.55 .30982 Mdot
.55 .30983 Mdot
.55 .30983 Mdot
.55 .30984 Mdot
.55 .30984 Mdot
.55 .30985 Mdot
.55 .30985 Mdot
.55 .30985 Mdot
.55 .30985 Mdot
.55 .30986 Mdot
.55 .30986 Mdot
.55 .30986 Mdot
.55 .30986 Mdot
.55 .30987 Mdot
.55 .30987 Mdot
.55 .30987 Mdot
.55 .30987 Mdot
.55 .30987 Mdot
.55 .30987 Mdot
.55 .30988 Mdot
.55 .30989 Mdot
.55 .30989 Mdot
.55 .3099 Mdot
.55 .3099 Mdot
.55 .3099 Mdot
.55 .30991 Mdot
.55 .30991 Mdot
.55 .30992 Mdot
.55 .30992 Mdot
.55 .30993 Mdot
.55 .30993 Mdot
.55 .30993 Mdot
.55 .30994 Mdot
.55 .30994 Mdot
.55 .30995 Mdot
.55 .30996 Mdot
.55 .30996 Mdot
.55 .30997 Mdot
.55 .30997 Mdot
.55 .30998 Mdot
.55 .30998 Mdot
.55 .30999 Mdot
.55 .30999 Mdot
.55 .30999 Mdot
.55 .31 Mdot
.55 .31 Mdot
.55 .31 Mdot
.55 .31 Mdot
.55 .31 Mdot
.55 .31 Mdot
.55 .31 Mdot
.55 .31001 Mdot
.55 .31001 Mdot
.55 .31001 Mdot
.55 .31001 Mdot
.55 .31001 Mdot
.55 .31001 Mdot
.55 .31002 Mdot
.55 .31002 Mdot
.55 .31002 Mdot
.55 .31003 Mdot
.55 .31003 Mdot
.55 .31003 Mdot
.55 .31003 Mdot
.55 .31004 Mdot
.55 .31004 Mdot
.55 .31005 Mdot
.55 .31005 Mdot
.55 .31006 Mdot
.55 .31006 Mdot
.55 .31006 Mdot
.55 .31006 Mdot
.55 .31006 Mdot
.55 .31006 Mdot
.55 .31007 Mdot
.55 .31007 Mdot
.55 .31008 Mdot
.55 .31008 Mdot
.55 .31008 Mdot
.55 .31008 Mdot
.55 .31009 Mdot
.55 .31009 Mdot
.55 .31009 Mdot
.55 .31009 Mdot
.55 .3101 Mdot
.55 .3101 Mdot
.55 .3101 Mdot
.55 .3101 Mdot
.55 .3101 Mdot
.55 .3101 Mdot
.55 .31011 Mdot
.55 .31011 Mdot
.55 .31012 Mdot
.55 .31012 Mdot
.55 .31012 Mdot
.55 .31013 Mdot
.55 .31013 Mdot
.55 .31014 Mdot
.55 .31014 Mdot
.55 .31014 Mdot
.55 .31015 Mdot
.55 .31015 Mdot
.55 .31015 Mdot
.55 .31016 Mdot
.55 .31016 Mdot
.55 .31016 Mdot
.55 .31016 Mdot
.55 .31016 Mdot
.55 .31017 Mdot
.55 .31017 Mdot
.55 .31018 Mdot
.55 .31018 Mdot
.55 .31018 Mdot
.55 .31019 Mdot
.55 .31019 Mdot
.55 .31019 Mdot
.55 .31019 Mdot
.55 .31019 Mdot
.55 .3102 Mdot
.55 .3102 Mdot
.55 .3102 Mdot
.55 .3102 Mdot
.55 .31021 Mdot
.55 .31022 Mdot
.55 .31022 Mdot
.55 .31022 Mdot
.55 .31022 Mdot
.55 .31022 Mdot
.55 .31022 Mdot
.55 .31023 Mdot
.55 .31023 Mdot
.55 .31024 Mdot
.55 .31024 Mdot
.55 .31025 Mdot
.55 .31025 Mdot
.55 .31025 Mdot
.55 .31025 Mdot
.55 .31026 Mdot
.55 .31026 Mdot
.55 .31026 Mdot
.55 .31026 Mdot
.55 .31026 Mdot
.55 .31027 Mdot
.55 .31027 Mdot
.55 .31027 Mdot
.55 .31027 Mdot
.55 .31027 Mdot
.55 .31027 Mdot
.55 .31027 Mdot
.55 .31029 Mdot
.55 .31029 Mdot
.55 .3103 Mdot
.55 .3103 Mdot
.55 .31031 Mdot
.55 .31031 Mdot
.55 .31031 Mdot
.55 .33595 Mdot
.55 .33595 Mdot
.55 .33595 Mdot
.55 .33596 Mdot
.55 .33597 Mdot
.55 .33598 Mdot
.55 .33598 Mdot
.55 .33599 Mdot
.55 .33599 Mdot
.55 .33599 Mdot
.55 .33599 Mdot
.55 .33599 Mdot
.55 .336 Mdot
.55 .336 Mdot
.55 .336 Mdot
.55 .336 Mdot
.55 .336 Mdot
.55 .336 Mdot
.55 .336 Mdot
.55 .33601 Mdot
.55 .33601 Mdot
.55 .33601 Mdot
.55 .33601 Mdot
.55 .33602 Mdot
.55 .33602 Mdot
.55 .33603 Mdot
.55 .33603 Mdot
.55 .33603 Mdot
.55 .33603 Mdot
.55 .33604 Mdot
.55 .33604 Mdot
.55 .33604 Mdot
.55 .33604 Mdot
.55 .33605 Mdot
.55 .33605 Mdot
.55 .33606 Mdot
.55 .33606 Mdot
.55 .33606 Mdot
.55 .33606 Mdot
.55 .33606 Mdot
.55 .33606 Mdot
.55 .33606 Mdot
.55 .33607 Mdot
.55 .33607 Mdot
.55 .33607 Mdot
.55 .33608 Mdot
.55 .33608 Mdot
.55 .33608 Mdot
.55 .33609 Mdot
.55 .33609 Mdot
.55 .33609 Mdot
.55 .33609 Mdot
.55 .33609 Mdot
.55 .3361 Mdot
.55 .3361 Mdot
.55 .3361 Mdot
.55 .33611 Mdot
.55 .33611 Mdot
.55 .33611 Mdot
.55 .33612 Mdot
.55 .33612 Mdot
.55 .33613 Mdot
.55 .33613 Mdot
.55 .33613 Mdot
.55 .33613 Mdot
.55 .33614 Mdot
.55 .33615 Mdot
.55 .33615 Mdot
.55 .33615 Mdot
.55 .33615 Mdot
.55 .33615 Mdot
.55 .33615 Mdot
.55 .33615 Mdot
.55 .33616 Mdot
.55 .33616 Mdot
.55 .33616 Mdot
.55 .33616 Mdot
.55 .33616 Mdot
.55 .33617 Mdot
.55 .33617 Mdot
.55 .33617 Mdot
.55 .33617 Mdot
.55 .33618 Mdot
.55 .33618 Mdot
.55 .33618 Mdot
.55 .33618 Mdot
.55 .33618 Mdot
.55 .33618 Mdot
.55 .33619 Mdot
.55 .33619 Mdot
.55 .33619 Mdot
.55 .3362 Mdot
.55 .3362 Mdot
.55 .33621 Mdot
.55 .33621 Mdot
.55 .33621 Mdot
.55 .33621 Mdot
.55 .33621 Mdot
.55 .33622 Mdot
.55 .33622 Mdot
.55 .33622 Mdot
.55 .33622 Mdot
.55 .33623 Mdot
.55 .33623 Mdot
.55 .33623 Mdot
.55 .33623 Mdot
.55 .33623 Mdot
.55 .33623 Mdot
.55 .33623 Mdot
.55 .33624 Mdot
.55 .33624 Mdot
.55 .33624 Mdot
.55 .33624 Mdot
.55 .33624 Mdot
.55 .33625 Mdot
.55 .33625 Mdot
.55 .33626 Mdot
.55 .33626 Mdot
.55 .33626 Mdot
.55 .33627 Mdot
.55 .33627 Mdot
.55 .33628 Mdot
.55 .33628 Mdot
.55 .33629 Mdot
.55 .3363 Mdot
.55 .3363 Mdot
.55 .3363 Mdot
.55 .3363 Mdot
.55 .33631 Mdot
.55 .33631 Mdot
.55 .33632 Mdot
.55 .33632 Mdot
.55 .33632 Mdot
.55 .33633 Mdot
.55 .33633 Mdot
.55 .33633 Mdot
.55 .33634 Mdot
.55 .33635 Mdot
.55 .33635 Mdot
.55 .33635 Mdot
.55 .33635 Mdot
.55 .33635 Mdot
.55 .33636 Mdot
.55 .33636 Mdot
.55 .33636 Mdot
.55 .33636 Mdot
.55 .33636 Mdot
.55 .33636 Mdot
.55 .33637 Mdot
.55 .33637 Mdot
.55 .33637 Mdot
.55 .33638 Mdot
.55 .33638 Mdot
.55 .33639 Mdot
.55 .33639 Mdot
.55 .33639 Mdot
.55 .3364 Mdot
.55 .3364 Mdot
.55 .33641 Mdot
.55 .33641 Mdot
.55 .33642 Mdot
.55 .33642 Mdot
.55 .33643 Mdot
.55 .33643 Mdot
.55 .33644 Mdot
.55 .33644 Mdot
.55 .33644 Mdot
.55 .33644 Mdot
.55 .33644 Mdot
.55 .33645 Mdot
.55 .33645 Mdot
.55 .33645 Mdot
.55 .33646 Mdot
.55 .33647 Mdot
.55 .33647 Mdot
.55 .33647 Mdot
.55 .33647 Mdot
.55 .33647 Mdot
.55 .33647 Mdot
.55 .33648 Mdot
.55 .33648 Mdot
.55 .33648 Mdot
.55 .33648 Mdot
.55 .33648 Mdot
.55 .33649 Mdot
.55 .33649 Mdot
.55 .3365 Mdot
.55 .33652 Mdot
.55 .33652 Mdot
.55 .33652 Mdot
.55 .33652 Mdot
.55 .33653 Mdot
.55 .33654 Mdot
.55 .33654 Mdot
.55 .33654 Mdot
.55 .33655 Mdot
.55 .33655 Mdot
.55 .33655 Mdot
.55 .33657 Mdot
.55 .33657 Mdot
.55 .33657 Mdot
.55 .33657 Mdot
.55 .33657 Mdot
.55 .33658 Mdot
.55 .33659 Mdot
.55 .33659 Mdot
.55 .33659 Mdot
.55 .3366 Mdot
.55 .3366 Mdot
.55 .33661 Mdot
.55 .33661 Mdot
.55 .33661 Mdot
.55 .33661 Mdot
.55 .33662 Mdot
.55 .33662 Mdot
.55 .33662 Mdot
.55 .33662 Mdot
.55 .33663 Mdot
.55 .33665 Mdot
.55 .33665 Mdot
.55 .33665 Mdot
.55 .33665 Mdot
.55 .33665 Mdot
.55 .33665 Mdot
.55 .33665 Mdot
.55 .33665 Mdot
.55 .33667 Mdot
.55 .33668 Mdot
.55 .33668 Mdot
.55 .33669 Mdot
.55 .33669 Mdot
.55 .33669 Mdot
.55 .33669 Mdot
.55 .3367 Mdot
.55 .3367 Mdot
.55 .3367 Mdot
.55 .33671 Mdot
.55 .33671 Mdot
.55 .33671 Mdot
.55 .33671 Mdot
.55 .33671 Mdot
.55 .33671 Mdot
.55 .33671 Mdot
.55 .33672 Mdot
.55 .33674 Mdot
.55 .33674 Mdot
.55 .33675 Mdot
.55 .33675 Mdot
.55 .33677 Mdot
.55 .33677 Mdot
.55 .33677 Mdot
.55 .33852 Mdot
.55 .33852 Mdot
.55 .33852 Mdot
.55 .33853 Mdot
.55 .33853 Mdot
.55 .33854 Mdot
.55 .33855 Mdot
.55 .33856 Mdot
.55 .33857 Mdot
.55 .33857 Mdot
.55 .33857 Mdot
.55 .33857 Mdot
.55 .33857 Mdot
.55 .33857 Mdot
.55 .33857 Mdot
.55 .33857 Mdot
.55 .33858 Mdot
.55 .33858 Mdot
.55 .33858 Mdot
.55 .33858 Mdot
.55 .33858 Mdot
.55 .33859 Mdot
.55 .33859 Mdot
.55 .33859 Mdot
.55 .3386 Mdot
.55 .33861 Mdot
.55 .33861 Mdot
.55 .33861 Mdot
.55 .33862 Mdot
.55 .33862 Mdot
.55 .33862 Mdot
.55 .33862 Mdot
.55 .33862 Mdot
.55 .33863 Mdot
.55 .33864 Mdot
.55 .33864 Mdot
.55 .33864 Mdot
.55 .33864 Mdot
.55 .33865 Mdot
.55 .33865 Mdot
.55 .33865 Mdot
.55 .33865 Mdot
.55 .33866 Mdot
.55 .33866 Mdot
.55 .33866 Mdot
.55 .33866 Mdot
.55 .33867 Mdot
.55 .33867 Mdot
.55 .33868 Mdot
.55 .33868 Mdot
.55 .33868 Mdot
.55 .33868 Mdot
.55 .33868 Mdot
.55 .3387 Mdot
.55 .3387 Mdot
.55 .3387 Mdot
.55 .3387 Mdot
.55 .3387 Mdot
.55 .3387 Mdot
.55 .33871 Mdot
.55 .33872 Mdot
.55 .33873 Mdot
.55 .33873 Mdot
.55 .33873 Mdot
.55 .33874 Mdot
.55 .33874 Mdot
.55 .33875 Mdot
.55 .33875 Mdot
.55 .33875 Mdot
.55 .33875 Mdot
.55 .33875 Mdot
.55 .33876 Mdot
.55 .33876 Mdot
.55 .33876 Mdot
.55 .33876 Mdot
.55 .33876 Mdot
.55 .33877 Mdot
.55 .33878 Mdot
.55 .33878 Mdot
.55 .33878 Mdot
.55 .33878 Mdot
.55 .33879 Mdot
.55 .33879 Mdot
.55 .33879 Mdot
.55 .33879 Mdot
.55 .33879 Mdot
.55 .3388 Mdot
.55 .3388 Mdot
.55 .3388 Mdot
.55 .33881 Mdot
.55 .33882 Mdot
.55 .33882 Mdot
.55 .33882 Mdot
.55 .33883 Mdot
.55 .33883 Mdot
.55 .33883 Mdot
.55 .33883 Mdot
.55 .33884 Mdot
.55 .33884 Mdot
.55 .33884 Mdot
.55 .33885 Mdot
.55 .33885 Mdot
.55 .33885 Mdot
.55 .33885 Mdot
.55 .33885 Mdot
.55 .33886 Mdot
.55 .33886 Mdot
.55 .33886 Mdot
.55 .33886 Mdot
.55 .33886 Mdot
.55 .33886 Mdot
.55 .33886 Mdot
.55 .33887 Mdot
.55 .33887 Mdot
.55 .33888 Mdot
.55 .33888 Mdot
.55 .33888 Mdot
.55 .33889 Mdot
.55 .33889 Mdot
.55 .33889 Mdot
.55 .33889 Mdot
.55 .3389 Mdot
.55 .3389 Mdot
.55 .3389 Mdot
.55 .33891 Mdot
.55 .33891 Mdot
.55 .33891 Mdot
.55 .33892 Mdot
.55 .33893 Mdot
.55 .33893 Mdot
.55 .33893 Mdot
.55 .33893 Mdot
.55 .33894 Mdot
.55 .33894 Mdot
.55 .33895 Mdot
.55 .33895 Mdot
.55 .33895 Mdot
.55 .33896 Mdot
.55 .33896 Mdot
.55 .33896 Mdot
.55 .33896 Mdot
.55 .33896 Mdot
.55 .33896 Mdot
.55 .33896 Mdot
.55 .33896 Mdot
.55 .33896 Mdot
.55 .33896 Mdot
.55 .33897 Mdot
.55 .33897 Mdot
.55 .33897 Mdot
.55 .33897 Mdot
.55 .33897 Mdot
.55 .33898 Mdot
.55 .33898 Mdot
.55 .33898 Mdot
.55 .33898 Mdot
.55 .33898 Mdot
.55 .33899 Mdot
.55 .33899 Mdot
.55 .33899 Mdot
.55 .339 Mdot
.55 .339 Mdot
.55 .339 Mdot
.55 .339 Mdot
.55 .339 Mdot
.55 .339 Mdot
.55 .33901 Mdot
.55 .33901 Mdot
.55 .33901 Mdot
.55 .33901 Mdot
.55 .33901 Mdot
.55 .33902 Mdot
.55 .33902 Mdot
.55 .33902 Mdot
.55 .33902 Mdot
.55 .33902 Mdot
.55 .33902 Mdot
.55 .33903 Mdot
.55 .33903 Mdot
.55 .33903 Mdot
.55 .33903 Mdot
.55 .33903 Mdot
.55 .33903 Mdot
.55 .33903 Mdot
.55 .33904 Mdot
.55 .33904 Mdot
.55 .33905 Mdot
.55 .33905 Mdot
.55 .33905 Mdot
.55 .33905 Mdot
.55 .33906 Mdot
.55 .33906 Mdot
.55 .33906 Mdot
.55 .33907 Mdot
.55 .33907 Mdot
.55 .33907 Mdot
.55 .33907 Mdot
.55 .33908 Mdot
.55 .33908 Mdot
.55 .33908 Mdot
.55 .33908 Mdot
.55 .33908 Mdot
.55 .33909 Mdot
.55 .33909 Mdot
.55 .33909 Mdot
.55 .33909 Mdot
.55 .33909 Mdot
.55 .3391 Mdot
.55 .3391 Mdot
.55 .3391 Mdot
.55 .3391 Mdot
.55 .3391 Mdot
.55 .33911 Mdot
.55 .33911 Mdot
.55 .33911 Mdot
.55 .33911 Mdot
.55 .33912 Mdot
.55 .33912 Mdot
.55 .33912 Mdot
.55 .33912 Mdot
.55 .33912 Mdot
.55 .33912 Mdot
.55 .33913 Mdot
.55 .33913 Mdot
.55 .33913 Mdot
.55 .33914 Mdot
.55 .33914 Mdot
.55 .33914 Mdot
.55 .33914 Mdot
.55 .33915 Mdot
.55 .33915 Mdot
.55 .33915 Mdot
.55 .33915 Mdot
.55 .33915 Mdot
.55 .33916 Mdot
.55 .33916 Mdot
.55 .33916 Mdot
.55 .33916 Mdot
.55 .33916 Mdot
.55 .33916 Mdot
.55 .33916 Mdot
.55 .33916 Mdot
.55 .33916 Mdot
.55 .33917 Mdot
.55 .33917 Mdot
.55 .33918 Mdot
.55 .33918 Mdot
.55 .33919 Mdot
.55 .33919 Mdot
.55 .33919 Mdot
.552 .30651 Mdot
.552 .30651 Mdot
.552 .30652 Mdot
.552 .30652 Mdot
.552 .30652 Mdot
.552 .30653 Mdot
.552 .30653 Mdot
.552 .30653 Mdot
.552 .30653 Mdot
.552 .30654 Mdot
.552 .30654 Mdot
.552 .30654 Mdot
.552 .30655 Mdot
.552 .30655 Mdot
.552 .30657 Mdot
.552 .30658 Mdot
.552 .30658 Mdot
.552 .30658 Mdot
.552 .30658 Mdot
.552 .30658 Mdot
.552 .30659 Mdot
.552 .30659 Mdot
.552 .30659 Mdot
.552 .30659 Mdot
.552 .30659 Mdot
.552 .30659 Mdot
.552 .30659 Mdot
.552 .3066 Mdot
.552 .3066 Mdot
.552 .3066 Mdot
.552 .3066 Mdot
.552 .3066 Mdot
.552 .30661 Mdot
.552 .30661 Mdot
.552 .30661 Mdot
.552 .30661 Mdot
.552 .30663 Mdot
.552 .30663 Mdot
.552 .30663 Mdot
.552 .30663 Mdot
.552 .30663 Mdot
.552 .30664 Mdot
.552 .30664 Mdot
.552 .30664 Mdot
.552 .30665 Mdot
.552 .30665 Mdot
.552 .30665 Mdot
.552 .30665 Mdot
.552 .30665 Mdot
.552 .30665 Mdot
.552 .30666 Mdot
.552 .30666 Mdot
.552 .30667 Mdot
.552 .30668 Mdot
.552 .30668 Mdot
.552 .30669 Mdot
.552 .30669 Mdot
.552 .30669 Mdot
.552 .30669 Mdot
.552 .30669 Mdot
.552 .3067 Mdot
.552 .3067 Mdot
.552 .30671 Mdot
.552 .30671 Mdot
.552 .30672 Mdot
.552 .30672 Mdot
.552 .30673 Mdot
.552 .30673 Mdot
.552 .30673 Mdot
.552 .30673 Mdot
.552 .30673 Mdot
.552 .30673 Mdot
.552 .30673 Mdot
.552 .30673 Mdot
.552 .30674 Mdot
.552 .30674 Mdot
.552 .30674 Mdot
.552 .30674 Mdot
.552 .30675 Mdot
.552 .30675 Mdot
.552 .30675 Mdot
.552 .30675 Mdot
.552 .30676 Mdot
.552 .30676 Mdot
.552 .30676 Mdot
.552 .30676 Mdot
.552 .30676 Mdot
.552 .30677 Mdot
.552 .30677 Mdot
.552 .30677 Mdot
.552 .30678 Mdot
.552 .30678 Mdot
.552 .30679 Mdot
.552 .30679 Mdot
.552 .30679 Mdot
.552 .30679 Mdot
.552 .30679 Mdot
.552 .30679 Mdot
.552 .3068 Mdot
.552 .3068 Mdot
.552 .30681 Mdot
.552 .30681 Mdot
.552 .30682 Mdot
.552 .30682 Mdot
.552 .30682 Mdot
.552 .30682 Mdot
.552 .30682 Mdot
.552 .30683 Mdot
.552 .30683 Mdot
.552 .30684 Mdot
.552 .30684 Mdot
.552 .30684 Mdot
.552 .30684 Mdot
.552 .30684 Mdot
.552 .30684 Mdot
.552 .30684 Mdot
.552 .30685 Mdot
.552 .30685 Mdot
.552 .30685 Mdot
.552 .30685 Mdot
.552 .30685 Mdot
.552 .30685 Mdot
.552 .30685 Mdot
.552 .30685 Mdot
.552 .30685 Mdot
.552 .30685 Mdot
.552 .30685 Mdot
.552 .30686 Mdot
.552 .30686 Mdot
.552 .30686 Mdot
.552 .30686 Mdot
.552 .30686 Mdot
.552 .30686 Mdot
.552 .30686 Mdot
.552 .30687 Mdot
.552 .30687 Mdot
.552 .30688 Mdot
.552 .30688 Mdot
.552 .30688 Mdot
.552 .30688 Mdot
.552 .30688 Mdot
.552 .30689 Mdot
.552 .30689 Mdot
.552 .30689 Mdot
.552 .30689 Mdot
.552 .30689 Mdot
.552 .3069 Mdot
.552 .3069 Mdot
.552 .3069 Mdot
.552 .30691 Mdot
.552 .30691 Mdot
.552 .30692 Mdot
.552 .30692 Mdot
.552 .30693 Mdot
.552 .30693 Mdot
.552 .30693 Mdot
.552 .30693 Mdot
.552 .30693 Mdot
.552 .30695 Mdot
.552 .30695 Mdot
.552 .30696 Mdot
.552 .30696 Mdot
.552 .30697 Mdot
.552 .30698 Mdot
.552 .30698 Mdot
.552 .30698 Mdot
.552 .30698 Mdot
.552 .30699 Mdot
.552 .30699 Mdot
.552 .30699 Mdot
.552 .307 Mdot
.552 .307 Mdot
.552 .30701 Mdot
.552 .30701 Mdot
.552 .30701 Mdot
.552 .30702 Mdot
.552 .30702 Mdot
.552 .30702 Mdot
.552 .30702 Mdot
.552 .30703 Mdot
.552 .30703 Mdot
.552 .30703 Mdot
.552 .30703 Mdot
.552 .30703 Mdot
.552 .30704 Mdot
.552 .30705 Mdot
.552 .30705 Mdot
.552 .30706 Mdot
.552 .30706 Mdot
.552 .30707 Mdot
.552 .30708 Mdot
.552 .30708 Mdot
.552 .30709 Mdot
.552 .30709 Mdot
.552 .30709 Mdot
.552 .3071 Mdot
.552 .3071 Mdot
.552 .30711 Mdot
.552 .30713 Mdot
.552 .30713 Mdot
.552 .30714 Mdot
.552 .30714 Mdot
.552 .30714 Mdot
.552 .30714 Mdot
.552 .30715 Mdot
.552 .30715 Mdot
.552 .30715 Mdot
.552 .30716 Mdot
.552 .30716 Mdot
.552 .30717 Mdot
.552 .30717 Mdot
.552 .30717 Mdot
.552 .30718 Mdot
.552 .30718 Mdot
.552 .3072 Mdot
.552 .3072 Mdot
.552 .3072 Mdot
.552 .3072 Mdot
.552 .30721 Mdot
.552 .30721 Mdot
.552 .30722 Mdot
.552 .30722 Mdot
.552 .30722 Mdot
.552 .30723 Mdot
.552 .30723 Mdot
.552 .30723 Mdot
.552 .30723 Mdot
.552 .30723 Mdot
.552 .30723 Mdot
.552 .30724 Mdot
.552 .30724 Mdot
.552 .30725 Mdot
.552 .30725 Mdot
.552 .30725 Mdot
.552 .30725 Mdot
.552 .30726 Mdot
.552 .30729 Mdot
.552 .30729 Mdot
.552 .3073 Mdot
.552 .30731 Mdot
.552 .30731 Mdot
.552 .30731 Mdot
.552 .30731 Mdot
.552 .30732 Mdot
.552 .30733 Mdot
.552 .30733 Mdot
.552 .30733 Mdot
.552 .30734 Mdot
.552 .30734 Mdot
.552 .30735 Mdot
.552 .30936 Mdot
.552 .30937 Mdot
.552 .30937 Mdot
.552 .30938 Mdot
.552 .30939 Mdot
.552 .30939 Mdot
.552 .3094 Mdot
.552 .30941 Mdot
.552 .30941 Mdot
.552 .30941 Mdot
.552 .30942 Mdot
.552 .30942 Mdot
.552 .30944 Mdot
.552 .30945 Mdot
.552 .30947 Mdot
.552 .30949 Mdot
.552 .30949 Mdot
.552 .30949 Mdot
.552 .30949 Mdot
.552 .3095 Mdot
.552 .3095 Mdot
.552 .30951 Mdot
.552 .30951 Mdot
.552 .30951 Mdot
.552 .30951 Mdot
.552 .30951 Mdot
.552 .30952 Mdot
.552 .30952 Mdot
.552 .30952 Mdot
.552 .30953 Mdot
.552 .30953 Mdot
.552 .30953 Mdot
.552 .30955 Mdot
.552 .30955 Mdot
.552 .30955 Mdot
.552 .30955 Mdot
.552 .30957 Mdot
.552 .30957 Mdot
.552 .30958 Mdot
.552 .30958 Mdot
.552 .30959 Mdot
.552 .30959 Mdot
.552 .30959 Mdot
.552 .30961 Mdot
.552 .30961 Mdot
.552 .30961 Mdot
.552 .30962 Mdot
.552 .30962 Mdot
.552 .30963 Mdot
.552 .30963 Mdot
.552 .30963 Mdot
.552 .30963 Mdot
.552 .30966 Mdot
.552 .30967 Mdot
.552 .30967 Mdot
.552 .30968 Mdot
.552 .30968 Mdot
.552 .30969 Mdot
.552 .30969 Mdot
.552 .3097 Mdot
.552 .30971 Mdot
.552 .30972 Mdot
.552 .30972 Mdot
.552 .30973 Mdot
.552 .30974 Mdot
.552 .30975 Mdot
.552 .30976 Mdot
.552 .30976 Mdot
.552 .30976 Mdot
.552 .30976 Mdot
.552 .30976 Mdot
.552 .30976 Mdot
.552 .30976 Mdot
.552 .30977 Mdot
.552 .30977 Mdot
.552 .30978 Mdot
.552 .30978 Mdot
.552 .30978 Mdot
.552 .30979 Mdot
.552 .30979 Mdot
.552 .3098 Mdot
.552 .3098 Mdot
.552 .30981 Mdot
.552 .30981 Mdot
.552 .30982 Mdot
.552 .30982 Mdot
.552 .30982 Mdot
.552 .30983 Mdot
.552 .30984 Mdot
.552 .30984 Mdot
.552 .30985 Mdot
.552 .30986 Mdot
.552 .30988 Mdot
.552 .30988 Mdot
.552 .30988 Mdot
.552 .30988 Mdot
.552 .30988 Mdot
.552 .30989 Mdot
.552 .30989 Mdot
.552 .3099 Mdot
.552 .30991 Mdot
.552 .30991 Mdot
.552 .30991 Mdot
.552 .30992 Mdot
.552 .30992 Mdot
.552 .30993 Mdot
.552 .30993 Mdot
.552 .30993 Mdot
.552 .30993 Mdot
.552 .30993 Mdot
.552 .30993 Mdot
.552 .30994 Mdot
.552 .30994 Mdot
.552 .30994 Mdot
.552 .30995 Mdot
.552 .30996 Mdot
.552 .30996 Mdot
.552 .30996 Mdot
.552 .30996 Mdot
.552 .30996 Mdot
.552 .30997 Mdot
.552 .30997 Mdot
.552 .30997 Mdot
.552 .30997 Mdot
.552 .30997 Mdot
.552 .30997 Mdot
.552 .30998 Mdot
.552 .30998 Mdot
.552 .30998 Mdot
.552 .30998 Mdot
.552 .30998 Mdot
.552 .30998 Mdot
.552 .30998 Mdot
.552 .30998 Mdot
.552 .30998 Mdot
.552 .30998 Mdot
.552 .30999 Mdot
.552 .30999 Mdot
.552 .30999 Mdot
.552 .30999 Mdot
.552 .30999 Mdot
.552 .31 Mdot
.552 .31 Mdot
.552 .31001 Mdot
.552 .31001 Mdot
.552 .31001 Mdot
.552 .31001 Mdot
.552 .31001 Mdot
.552 .31002 Mdot
.552 .31003 Mdot
.552 .31003 Mdot
.552 .31003 Mdot
.552 .31004 Mdot
.552 .31004 Mdot
.552 .31004 Mdot
.552 .31004 Mdot
.552 .31004 Mdot
.552 .31005 Mdot
.552 .31006 Mdot
.552 .31006 Mdot
.552 .31007 Mdot
.552 .31007 Mdot
.552 .31007 Mdot
.552 .31008 Mdot
.552 .31008 Mdot
.552 .31009 Mdot
.552 .31009 Mdot
.552 .31009 Mdot
.552 .31009 Mdot
.552 .3101 Mdot
.552 .3101 Mdot
.552 .3101 Mdot
.552 .31011 Mdot
.552 .31011 Mdot
.552 .31011 Mdot
.552 .31012 Mdot
.552 .31012 Mdot
.552 .31012 Mdot
.552 .31012 Mdot
.552 .31012 Mdot
.552 .31013 Mdot
.552 .31013 Mdot
.552 .31013 Mdot
.552 .31013 Mdot
.552 .31013 Mdot
.552 .31014 Mdot
.552 .31015 Mdot
.552 .31015 Mdot
.552 .31015 Mdot
.552 .31016 Mdot
.552 .31017 Mdot
.552 .31017 Mdot
.552 .31017 Mdot
.552 .31017 Mdot
.552 .31017 Mdot
.552 .31018 Mdot
.552 .31018 Mdot
.552 .31019 Mdot
.552 .31021 Mdot
.552 .31021 Mdot
.552 .31021 Mdot
.552 .31021 Mdot
.552 .31022 Mdot
.552 .31022 Mdot
.552 .31022 Mdot
.552 .31022 Mdot
.552 .31023 Mdot
.552 .31023 Mdot
.552 .31023 Mdot
.552 .31024 Mdot
.552 .31024 Mdot
.552 .31024 Mdot
.552 .31025 Mdot
.552 .31025 Mdot
.552 .31026 Mdot
.552 .31027 Mdot
.552 .31027 Mdot
.552 .31027 Mdot
.552 .31028 Mdot
.552 .31028 Mdot
.552 .31028 Mdot
.552 .31028 Mdot
.552 .31029 Mdot
.552 .31029 Mdot
.552 .31029 Mdot
.552 .31029 Mdot
.552 .31029 Mdot
.552 .31029 Mdot
.552 .31029 Mdot
.552 .3103 Mdot
.552 .3103 Mdot
.552 .3103 Mdot
.552 .31031 Mdot
.552 .31031 Mdot
.552 .31031 Mdot
.552 .31032 Mdot
.552 .31034 Mdot
.552 .31034 Mdot
.552 .31035 Mdot
.552 .31036 Mdot
.552 .31036 Mdot
.552 .31036 Mdot
.552 .31036 Mdot
.552 .31037 Mdot
.552 .31037 Mdot
.552 .31038 Mdot
.552 .31038 Mdot
.552 .31038 Mdot
.552 .31038 Mdot
.552 .31039 Mdot
.552 .33685 Mdot
.552 .33686 Mdot
.552 .33686 Mdot
.552 .33687 Mdot
.552 .33687 Mdot
.552 .33687 Mdot
.552 .33688 Mdot
.552 .33688 Mdot
.552 .33688 Mdot
.552 .33689 Mdot
.552 .33689 Mdot
.552 .33689 Mdot
.552 .3369 Mdot
.552 .33691 Mdot
.552 .33692 Mdot
.552 .33693 Mdot
.552 .33693 Mdot
.552 .33693 Mdot
.552 .33693 Mdot
.552 .33694 Mdot
.552 .33694 Mdot
.552 .33694 Mdot
.552 .33694 Mdot
.552 .33694 Mdot
.552 .33695 Mdot
.552 .33695 Mdot
.552 .33695 Mdot
.552 .33695 Mdot
.552 .33695 Mdot
.552 .33696 Mdot
.552 .33696 Mdot
.552 .33696 Mdot
.552 .33697 Mdot
.552 .33697 Mdot
.552 .33697 Mdot
.552 .33697 Mdot
.552 .33698 Mdot
.552 .33698 Mdot
.552 .33699 Mdot
.552 .33699 Mdot
.552 .33699 Mdot
.552 .337 Mdot
.552 .337 Mdot
.552 .337 Mdot
.552 .33701 Mdot
.552 .33701 Mdot
.552 .33701 Mdot
.552 .33701 Mdot
.552 .33702 Mdot
.552 .33702 Mdot
.552 .33702 Mdot
.552 .33702 Mdot
.552 .33704 Mdot
.552 .33704 Mdot
.552 .33704 Mdot
.552 .33705 Mdot
.552 .33705 Mdot
.552 .33705 Mdot
.552 .33705 Mdot
.552 .33706 Mdot
.552 .33707 Mdot
.552 .33707 Mdot
.552 .33707 Mdot
.552 .33708 Mdot
.552 .33708 Mdot
.552 .33709 Mdot
.552 .33709 Mdot
.552 .33709 Mdot
.552 .3371 Mdot
.552 .3371 Mdot
.552 .3371 Mdot
.552 .3371 Mdot
.552 .3371 Mdot
.552 .3371 Mdot
.552 .33711 Mdot
.552 .33711 Mdot
.552 .33711 Mdot
.552 .33711 Mdot
.552 .33712 Mdot
.552 .33712 Mdot
.552 .33712 Mdot
.552 .33712 Mdot
.552 .33713 Mdot
.552 .33713 Mdot
.552 .33713 Mdot
.552 .33713 Mdot
.552 .33713 Mdot
.552 .33714 Mdot
.552 .33715 Mdot
.552 .33715 Mdot
.552 .33715 Mdot
.552 .33716 Mdot
.552 .33717 Mdot
.552 .33717 Mdot
.552 .33717 Mdot
.552 .33717 Mdot
.552 .33717 Mdot
.552 .33717 Mdot
.552 .33718 Mdot
.552 .33718 Mdot
.552 .33719 Mdot
.552 .33719 Mdot
.552 .3372 Mdot
.552 .3372 Mdot
.552 .3372 Mdot
.552 .3372 Mdot
.552 .3372 Mdot
.552 .33721 Mdot
.552 .33721 Mdot
.552 .33722 Mdot
.552 .33722 Mdot
.552 .33722 Mdot
.552 .33722 Mdot
.552 .33722 Mdot
.552 .33722 Mdot
.552 .33723 Mdot
.552 .33723 Mdot
.552 .33723 Mdot
.552 .33723 Mdot
.552 .33723 Mdot
.552 .33723 Mdot
.552 .33723 Mdot
.552 .33723 Mdot
.552 .33723 Mdot
.552 .33723 Mdot
.552 .33723 Mdot
.552 .33724 Mdot
.552 .33724 Mdot
.552 .33724 Mdot
.552 .33724 Mdot
.552 .33724 Mdot
.552 .33725 Mdot
.552 .33725 Mdot
.552 .33725 Mdot
.552 .33725 Mdot
.552 .33725 Mdot
.552 .33726 Mdot
.552 .33726 Mdot
.552 .33726 Mdot
.552 .33727 Mdot
.552 .33727 Mdot
.552 .33727 Mdot
.552 .33727 Mdot
.552 .33727 Mdot
.552 .33727 Mdot
.552 .33728 Mdot
.552 .33728 Mdot
.552 .33729 Mdot
.552 .33729 Mdot
.552 .3373 Mdot
.552 .3373 Mdot
.552 .33731 Mdot
.552 .33731 Mdot
.552 .33732 Mdot
.552 .33732 Mdot
.552 .33732 Mdot
.552 .33732 Mdot
.552 .33732 Mdot
.552 .33734 Mdot
.552 .33734 Mdot
.552 .33735 Mdot
.552 .33736 Mdot
.552 .33736 Mdot
.552 .33737 Mdot
.552 .33737 Mdot
.552 .33738 Mdot
.552 .33738 Mdot
.552 .33738 Mdot
.552 .33739 Mdot
.552 .33739 Mdot
.552 .3374 Mdot
.552 .3374 Mdot
.552 .33741 Mdot
.552 .33741 Mdot
.552 .33741 Mdot
.552 .33742 Mdot
.552 .33742 Mdot
.552 .33742 Mdot
.552 .33742 Mdot
.552 .33743 Mdot
.552 .33743 Mdot
.552 .33743 Mdot
.552 .33743 Mdot
.552 .33743 Mdot
.552 .33744 Mdot
.552 .33745 Mdot
.552 .33746 Mdot
.552 .33746 Mdot
.552 .33747 Mdot
.552 .33747 Mdot
.552 .33748 Mdot
.552 .33749 Mdot
.552 .33749 Mdot
.552 .3375 Mdot
.552 .3375 Mdot
.552 .33751 Mdot
.552 .33751 Mdot
.552 .33752 Mdot
.552 .33755 Mdot
.552 .33755 Mdot
.552 .33755 Mdot
.552 .33755 Mdot
.552 .33755 Mdot
.552 .33756 Mdot
.552 .33756 Mdot
.552 .33756 Mdot
.552 .33757 Mdot
.552 .33758 Mdot
.552 .33758 Mdot
.552 .33758 Mdot
.552 .33759 Mdot
.552 .33759 Mdot
.552 .33759 Mdot
.552 .3376 Mdot
.552 .33761 Mdot
.552 .33762 Mdot
.552 .33762 Mdot
.552 .33762 Mdot
.552 .33763 Mdot
.552 .33763 Mdot
.552 .33764 Mdot
.552 .33764 Mdot
.552 .33765 Mdot
.552 .33765 Mdot
.552 .33765 Mdot
.552 .33765 Mdot
.552 .33765 Mdot
.552 .33766 Mdot
.552 .33766 Mdot
.552 .33766 Mdot
.552 .33767 Mdot
.552 .33767 Mdot
.552 .33767 Mdot
.552 .33767 Mdot
.552 .33767 Mdot
.552 .33769 Mdot
.552 .33771 Mdot
.552 .33772 Mdot
.552 .33773 Mdot
.552 .33774 Mdot
.552 .33774 Mdot
.552 .33774 Mdot
.552 .33774 Mdot
.552 .33775 Mdot
.552 .33776 Mdot
.552 .33777 Mdot
.552 .33777 Mdot
.552 .33778 Mdot
.552 .33778 Mdot
.552 .33779 Mdot
.552 .33961 Mdot
.552 .33962 Mdot
.552 .33962 Mdot
.552 .33962 Mdot
.552 .33962 Mdot
.552 .33963 Mdot
.552 .33963 Mdot
.552 .33964 Mdot
.552 .33964 Mdot
.552 .33965 Mdot
.552 .33965 Mdot
.552 .33965 Mdot
.552 .33966 Mdot
.552 .33967 Mdot
.552 .33969 Mdot
.552 .3397 Mdot
.552 .3397 Mdot
.552 .3397 Mdot
.552 .3397 Mdot
.552 .33971 Mdot
.552 .33971 Mdot
.552 .33971 Mdot
.552 .33972 Mdot
.552 .33972 Mdot
.552 .33972 Mdot
.552 .33972 Mdot
.552 .33972 Mdot
.552 .33972 Mdot
.552 .33973 Mdot
.552 .33973 Mdot
.552 .33973 Mdot
.552 .33974 Mdot
.552 .33974 Mdot
.552 .33974 Mdot
.552 .33975 Mdot
.552 .33975 Mdot
.552 .33976 Mdot
.552 .33977 Mdot
.552 .33977 Mdot
.552 .33977 Mdot
.552 .33978 Mdot
.552 .33978 Mdot
.552 .33978 Mdot
.552 .33979 Mdot
.552 .33979 Mdot
.552 .33979 Mdot
.552 .3398 Mdot
.552 .3398 Mdot
.552 .3398 Mdot
.552 .3398 Mdot
.552 .3398 Mdot
.552 .33981 Mdot
.552 .33983 Mdot
.552 .33984 Mdot
.552 .33984 Mdot
.552 .33985 Mdot
.552 .33985 Mdot
.552 .33985 Mdot
.552 .33985 Mdot
.552 .33986 Mdot
.552 .33987 Mdot
.552 .33987 Mdot
.552 .33988 Mdot
.552 .33988 Mdot
.552 .33989 Mdot
.552 .33989 Mdot
.552 .3399 Mdot
.552 .3399 Mdot
.552 .3399 Mdot
.552 .3399 Mdot
.552 .3399 Mdot
.552 .33991 Mdot
.552 .33991 Mdot
.552 .33991 Mdot
.552 .33991 Mdot
.552 .33991 Mdot
.552 .33992 Mdot
.552 .33992 Mdot
.552 .33993 Mdot
.552 .33993 Mdot
.552 .33993 Mdot
.552 .33994 Mdot
.552 .33994 Mdot
.552 .33994 Mdot
.552 .33995 Mdot
.552 .33995 Mdot
.552 .33995 Mdot
.552 .33996 Mdot
.552 .33996 Mdot
.552 .33997 Mdot
.552 .33997 Mdot
.552 .33998 Mdot
.552 .33999 Mdot
.552 .33999 Mdot
.552 .33999 Mdot
.552 .33999 Mdot
.552 .33999 Mdot
.552 .33999 Mdot
.552 .34 Mdot
.552 .34 Mdot
.552 .34001 Mdot
.552 .34001 Mdot
.552 .34002 Mdot
.552 .34002 Mdot
.552 .34002 Mdot
.552 .34002 Mdot
.552 .34003 Mdot
.552 .34003 Mdot
.552 .34003 Mdot
.552 .34003 Mdot
.552 .34003 Mdot
.552 .34003 Mdot
.552 .34004 Mdot
.552 .34004 Mdot
.552 .34004 Mdot
.552 .34005 Mdot
.552 .34005 Mdot
.552 .34005 Mdot
.552 .34005 Mdot
.552 .34005 Mdot
.552 .34005 Mdot
.552 .34006 Mdot
.552 .34006 Mdot
.552 .34006 Mdot
.552 .34006 Mdot
.552 .34006 Mdot
.552 .34006 Mdot
.552 .34006 Mdot
.552 .34006 Mdot
.552 .34006 Mdot
.552 .34006 Mdot
.552 .34006 Mdot
.552 .34007 Mdot
.552 .34007 Mdot
.552 .34007 Mdot
.552 .34007 Mdot
.552 .34007 Mdot
.552 .34007 Mdot
.552 .34007 Mdot
.552 .34007 Mdot
.552 .34007 Mdot
.552 .34007 Mdot
.552 .34008 Mdot
.552 .34008 Mdot
.552 .34009 Mdot
.552 .34009 Mdot
.552 .34009 Mdot
.552 .34009 Mdot
.552 .34009 Mdot
.552 .3401 Mdot
.552 .3401 Mdot
.552 .3401 Mdot
.552 .34011 Mdot
.552 .34011 Mdot
.552 .34011 Mdot
.552 .34011 Mdot
.552 .34011 Mdot
.552 .34011 Mdot
.552 .34011 Mdot
.552 .34012 Mdot
.552 .34013 Mdot
.552 .34013 Mdot
.552 .34013 Mdot
.552 .34014 Mdot
.552 .34014 Mdot
.552 .34014 Mdot
.552 .34014 Mdot
.552 .34015 Mdot
.552 .34015 Mdot
.552 .34015 Mdot
.552 .34015 Mdot
.552 .34016 Mdot
.552 .34016 Mdot
.552 .34016 Mdot
.552 .34016 Mdot
.552 .34017 Mdot
.552 .34017 Mdot
.552 .34017 Mdot
.552 .34017 Mdot
.552 .34017 Mdot
.552 .34017 Mdot
.552 .34017 Mdot
.552 .34018 Mdot
.552 .34018 Mdot
.552 .34018 Mdot
.552 .34018 Mdot
.552 .34019 Mdot
.552 .34019 Mdot
.552 .34019 Mdot
.552 .3402 Mdot
.552 .3402 Mdot
.552 .3402 Mdot
.552 .34021 Mdot
.552 .34021 Mdot
.552 .34021 Mdot
.552 .34021 Mdot
.552 .34022 Mdot
.552 .34022 Mdot
.552 .34022 Mdot
.552 .34024 Mdot
.552 .34024 Mdot
.552 .34024 Mdot
.552 .34024 Mdot
.552 .34024 Mdot
.552 .34024 Mdot
.552 .34025 Mdot
.552 .34025 Mdot
.552 .34025 Mdot
.552 .34026 Mdot
.552 .34026 Mdot
.552 .34026 Mdot
.552 .34026 Mdot
.552 .34026 Mdot
.552 .34027 Mdot
.552 .34027 Mdot
.552 .34028 Mdot
.552 .34028 Mdot
.552 .34028 Mdot
.552 .34028 Mdot
.552 .34029 Mdot
.552 .34029 Mdot
.552 .34029 Mdot
.552 .34029 Mdot
.552 .34029 Mdot
.552 .3403 Mdot
.552 .3403 Mdot
.552 .3403 Mdot
.552 .3403 Mdot
.552 .3403 Mdot
.552 .3403 Mdot
.552 .3403 Mdot
.552 .34031 Mdot
.552 .34031 Mdot
.552 .34031 Mdot
.552 .34031 Mdot
.552 .34031 Mdot
.552 .34032 Mdot
.552 .34033 Mdot
.552 .34034 Mdot
.552 .34034 Mdot
.552 .34035 Mdot
.552 .34035 Mdot
.552 .34035 Mdot
.552 .34035 Mdot
.552 .34035 Mdot
.552 .34036 Mdot
.552 .34036 Mdot
.552 .34036 Mdot
.552 .34037 Mdot
.552 .34037 Mdot
.552 .34037 Mdot
.554 .30626 Mdot
.554 .30626 Mdot
.554 .30626 Mdot
.554 .30627 Mdot
.554 .30628 Mdot
.554 .30629 Mdot
.554 .30629 Mdot
.554 .30629 Mdot
.554 .3063 Mdot
.554 .3063 Mdot
.554 .30631 Mdot
.554 .30631 Mdot
.554 .30631 Mdot
.554 .30631 Mdot
.554 .30632 Mdot
.554 .30632 Mdot
.554 .30632 Mdot
.554 .30632 Mdot
.554 .30633 Mdot
.554 .30633 Mdot
.554 .30633 Mdot
.554 .30634 Mdot
.554 .30634 Mdot
.554 .30634 Mdot
.554 .30635 Mdot
.554 .30635 Mdot
.554 .30636 Mdot
.554 .30636 Mdot
.554 .30636 Mdot
.554 .30636 Mdot
.554 .30636 Mdot
.554 .30636 Mdot
.554 .30637 Mdot
.554 .30637 Mdot
.554 .30637 Mdot
.554 .30638 Mdot
.554 .30638 Mdot
.554 .30638 Mdot
.554 .30639 Mdot
.554 .30639 Mdot
.554 .3064 Mdot
.554 .3064 Mdot
.554 .3064 Mdot
.554 .30641 Mdot
.554 .30641 Mdot
.554 .30642 Mdot
.554 .30642 Mdot
.554 .30642 Mdot
.554 .30642 Mdot
.554 .30642 Mdot
.554 .30643 Mdot
.554 .30644 Mdot
.554 .30644 Mdot
.554 .30645 Mdot
.554 .30646 Mdot
.554 .30647 Mdot
.554 .30647 Mdot
.554 .30647 Mdot
.554 .30648 Mdot
.554 .30648 Mdot
.554 .30648 Mdot
.554 .30649 Mdot
.554 .30649 Mdot
.554 .30649 Mdot
.554 .3065 Mdot
.554 .3065 Mdot
.554 .3065 Mdot
.554 .3065 Mdot
.554 .3065 Mdot
.554 .3065 Mdot
.554 .3065 Mdot
.554 .3065 Mdot
.554 .30651 Mdot
.554 .30651 Mdot
.554 .30651 Mdot
.554 .30651 Mdot
.554 .30651 Mdot
.554 .30651 Mdot
.554 .30652 Mdot
.554 .30652 Mdot
.554 .30652 Mdot
.554 .30652 Mdot
.554 .30653 Mdot
.554 .30653 Mdot
.554 .30653 Mdot
.554 .30653 Mdot
.554 .30654 Mdot
.554 .30654 Mdot
.554 .30654 Mdot
.554 .30654 Mdot
.554 .30654 Mdot
.554 .30655 Mdot
.554 .30657 Mdot
.554 .30657 Mdot
.554 .30657 Mdot
.554 .30658 Mdot
.554 .30658 Mdot
.554 .30658 Mdot
.554 .30658 Mdot
.554 .30658 Mdot
.554 .30658 Mdot
.554 .30658 Mdot
.554 .30659 Mdot
.554 .30659 Mdot
.554 .30659 Mdot
.554 .30659 Mdot
.554 .3066 Mdot
.554 .3066 Mdot
.554 .30661 Mdot
.554 .30661 Mdot
.554 .30661 Mdot
.554 .30661 Mdot
.554 .30661 Mdot
.554 .30662 Mdot
.554 .30662 Mdot
.554 .30662 Mdot
.554 .30663 Mdot
.554 .30663 Mdot
.554 .30663 Mdot
.554 .30663 Mdot
.554 .30664 Mdot
.554 .30665 Mdot
.554 .30665 Mdot
.554 .30665 Mdot
.554 .30665 Mdot
.554 .30666 Mdot
.554 .30667 Mdot
.554 .30667 Mdot
.554 .30667 Mdot
.554 .30667 Mdot
.554 .30668 Mdot
.554 .30668 Mdot
.554 .30668 Mdot
.554 .30668 Mdot
.554 .30668 Mdot
.554 .30668 Mdot
.554 .30669 Mdot
.554 .30669 Mdot
.554 .3067 Mdot
.554 .30671 Mdot
.554 .30671 Mdot
.554 .30671 Mdot
.554 .30671 Mdot
.554 .30672 Mdot
.554 .30672 Mdot
.554 .30672 Mdot
.554 .30672 Mdot
.554 .30673 Mdot
.554 .30673 Mdot
.554 .30673 Mdot
.554 .30673 Mdot
.554 .30673 Mdot
.554 .30673 Mdot
.554 .30673 Mdot
.554 .30674 Mdot
.554 .30674 Mdot
.554 .30675 Mdot
.554 .30675 Mdot
.554 .30677 Mdot
.554 .30678 Mdot
.554 .30678 Mdot
.554 .30678 Mdot
.554 .30679 Mdot
.554 .30679 Mdot
.554 .3068 Mdot
.554 .3068 Mdot
.554 .3068 Mdot
.554 .30681 Mdot
.554 .30681 Mdot
.554 .30682 Mdot
.554 .30683 Mdot
.554 .30683 Mdot
.554 .30683 Mdot
.554 .30683 Mdot
.554 .30683 Mdot
.554 .30684 Mdot
.554 .30684 Mdot
.554 .30684 Mdot
.554 .30684 Mdot
.554 .30685 Mdot
.554 .30685 Mdot
.554 .30685 Mdot
.554 .30685 Mdot
.554 .30686 Mdot
.554 .30686 Mdot
.554 .30686 Mdot
.554 .30686 Mdot
.554 .30687 Mdot
.554 .30687 Mdot
.554 .30687 Mdot
.554 .30687 Mdot
.554 .30688 Mdot
.554 .30689 Mdot
.554 .30689 Mdot
.554 .3069 Mdot
.554 .30691 Mdot
.554 .30693 Mdot
.554 .30693 Mdot
.554 .30694 Mdot
.554 .30696 Mdot
.554 .30696 Mdot
.554 .30697 Mdot
.554 .30697 Mdot
.554 .30697 Mdot
.554 .30697 Mdot
.554 .30698 Mdot
.554 .30698 Mdot
.554 .307 Mdot
.554 .307 Mdot
.554 .30701 Mdot
.554 .30702 Mdot
.554 .30702 Mdot
.554 .30703 Mdot
.554 .30703 Mdot
.554 .30704 Mdot
.554 .30704 Mdot
.554 .30705 Mdot
.554 .30705 Mdot
.554 .30705 Mdot
.554 .30705 Mdot
.554 .30706 Mdot
.554 .30706 Mdot
.554 .30706 Mdot
.554 .30707 Mdot
.554 .30707 Mdot
.554 .30708 Mdot
.554 .30708 Mdot
.554 .30708 Mdot
.554 .30709 Mdot
.554 .30709 Mdot
.554 .3071 Mdot
.554 .30711 Mdot
.554 .30711 Mdot
.554 .30712 Mdot
.554 .30713 Mdot
.554 .30713 Mdot
.554 .30713 Mdot
.554 .30713 Mdot
.554 .30713 Mdot
.554 .30714 Mdot
.554 .30715 Mdot
.554 .30715 Mdot
.554 .30717 Mdot
.554 .30717 Mdot
.554 .30717 Mdot
.554 .30717 Mdot
.554 .30719 Mdot
.554 .30721 Mdot
.554 .30721 Mdot
.554 .30721 Mdot
.554 .3093 Mdot
.554 .30931 Mdot
.554 .30931 Mdot
.554 .30933 Mdot
.554 .30935 Mdot
.554 .30935 Mdot
.554 .30935 Mdot
.554 .30936 Mdot
.554 .30938 Mdot
.554 .30938 Mdot
.554 .30939 Mdot
.554 .3094 Mdot
.554 .3094 Mdot
.554 .30941 Mdot
.554 .30941 Mdot
.554 .30941 Mdot
.554 .30942 Mdot
.554 .30943 Mdot
.554 .30943 Mdot
.554 .30944 Mdot
.554 .30946 Mdot
.554 .30946 Mdot
.554 .30946 Mdot
.554 .30947 Mdot
.554 .30947 Mdot
.554 .30948 Mdot
.554 .30949 Mdot
.554 .30949 Mdot
.554 .30949 Mdot
.554 .3095 Mdot
.554 .3095 Mdot
.554 .3095 Mdot
.554 .30951 Mdot
.554 .30951 Mdot
.554 .30951 Mdot
.554 .30952 Mdot
.554 .30952 Mdot
.554 .30953 Mdot
.554 .30954 Mdot
.554 .30954 Mdot
.554 .30956 Mdot
.554 .30956 Mdot
.554 .30956 Mdot
.554 .30959 Mdot
.554 .30959 Mdot
.554 .3096 Mdot
.554 .30961 Mdot
.554 .30961 Mdot
.554 .30961 Mdot
.554 .30961 Mdot
.554 .30961 Mdot
.554 .30963 Mdot
.554 .30965 Mdot
.554 .30966 Mdot
.554 .30967 Mdot
.554 .30969 Mdot
.554 .3097 Mdot
.554 .3097 Mdot
.554 .30971 Mdot
.554 .30972 Mdot
.554 .30972 Mdot
.554 .30972 Mdot
.554 .30973 Mdot
.554 .30973 Mdot
.554 .30974 Mdot
.554 .30974 Mdot
.554 .30974 Mdot
.554 .30975 Mdot
.554 .30975 Mdot
.554 .30975 Mdot
.554 .30976 Mdot
.554 .30976 Mdot
.554 .30977 Mdot
.554 .30977 Mdot
.554 .30977 Mdot
.554 .30977 Mdot
.554 .30977 Mdot
.554 .30978 Mdot
.554 .30978 Mdot
.554 .30978 Mdot
.554 .30979 Mdot
.554 .3098 Mdot
.554 .3098 Mdot
.554 .30981 Mdot
.554 .30981 Mdot
.554 .30981 Mdot
.554 .30982 Mdot
.554 .30982 Mdot
.554 .30983 Mdot
.554 .30983 Mdot
.554 .30983 Mdot
.554 .30984 Mdot
.554 .30987 Mdot
.554 .30988 Mdot
.554 .30988 Mdot
.554 .30989 Mdot
.554 .30989 Mdot
.554 .30989 Mdot
.554 .30989 Mdot
.554 .3099 Mdot
.554 .3099 Mdot
.554 .3099 Mdot
.554 .3099 Mdot
.554 .3099 Mdot
.554 .30991 Mdot
.554 .30991 Mdot
.554 .30991 Mdot
.554 .30992 Mdot
.554 .30992 Mdot
.554 .30993 Mdot
.554 .30993 Mdot
.554 .30993 Mdot
.554 .30995 Mdot
.554 .30995 Mdot
.554 .30996 Mdot
.554 .30996 Mdot
.554 .30996 Mdot
.554 .30996 Mdot
.554 .30996 Mdot
.554 .30996 Mdot
.554 .30997 Mdot
.554 .30997 Mdot
.554 .30997 Mdot
.554 .30997 Mdot
.554 .30999 Mdot
.554 .30999 Mdot
.554 .30999 Mdot
.554 .31 Mdot
.554 .31 Mdot
.554 .31 Mdot
.554 .31002 Mdot
.554 .31002 Mdot
.554 .31002 Mdot
.554 .31002 Mdot
.554 .31003 Mdot
.554 .31004 Mdot
.554 .31004 Mdot
.554 .31004 Mdot
.554 .31004 Mdot
.554 .31004 Mdot
.554 .31005 Mdot
.554 .31005 Mdot
.554 .31006 Mdot
.554 .31006 Mdot
.554 .31007 Mdot
.554 .31007 Mdot
.554 .31007 Mdot
.554 .31007 Mdot
.554 .31008 Mdot
.554 .31008 Mdot
.554 .31008 Mdot
.554 .31008 Mdot
.554 .31008 Mdot
.554 .31008 Mdot
.554 .31009 Mdot
.554 .31009 Mdot
.554 .3101 Mdot
.554 .3101 Mdot
.554 .31012 Mdot
.554 .31013 Mdot
.554 .31013 Mdot
.554 .31013 Mdot
.554 .31013 Mdot
.554 .31013 Mdot
.554 .31014 Mdot
.554 .31014 Mdot
.554 .31014 Mdot
.554 .31015 Mdot
.554 .31015 Mdot
.554 .31015 Mdot
.554 .31016 Mdot
.554 .31016 Mdot
.554 .31016 Mdot
.554 .31017 Mdot
.554 .31017 Mdot
.554 .31017 Mdot
.554 .31017 Mdot
.554 .31017 Mdot
.554 .31018 Mdot
.554 .31018 Mdot
.554 .31018 Mdot
.554 .31018 Mdot
.554 .31018 Mdot
.554 .31019 Mdot
.554 .31019 Mdot
.554 .31019 Mdot
.554 .31019 Mdot
.554 .31019 Mdot
.554 .3102 Mdot
.554 .3102 Mdot
.554 .3102 Mdot
.554 .31021 Mdot
.554 .31021 Mdot
.554 .31022 Mdot
.554 .31022 Mdot
.554 .31023 Mdot
.554 .31024 Mdot
.554 .31025 Mdot
.554 .31026 Mdot
.554 .31027 Mdot
.554 .31027 Mdot
.554 .31027 Mdot
.554 .31028 Mdot
.554 .31028 Mdot
.554 .31028 Mdot
.554 .31029 Mdot
.554 .31029 Mdot
.554 .3103 Mdot
.554 .31031 Mdot
.554 .31031 Mdot
.554 .31032 Mdot
.554 .31032 Mdot
.554 .31033 Mdot
.554 .31033 Mdot
.554 .31033 Mdot
.554 .31034 Mdot
.554 .31034 Mdot
.554 .31034 Mdot
.554 .31035 Mdot
.554 .31035 Mdot
.554 .31035 Mdot
.554 .31035 Mdot
.554 .31035 Mdot
.554 .31036 Mdot
.554 .31036 Mdot
.554 .31037 Mdot
.554 .31037 Mdot
.554 .31037 Mdot
.554 .31037 Mdot
.554 .31038 Mdot
.554 .31039 Mdot
.554 .31039 Mdot
.554 .31039 Mdot
.554 .3104 Mdot
.554 .3104 Mdot
.554 .31041 Mdot
.554 .31041 Mdot
.554 .31041 Mdot
.554 .31041 Mdot
.554 .31041 Mdot
.554 .31042 Mdot
.554 .31043 Mdot
.554 .31043 Mdot
.554 .31044 Mdot
.554 .31044 Mdot
.554 .31044 Mdot
.554 .31044 Mdot
.554 .31046 Mdot
.554 .31047 Mdot
.554 .31048 Mdot
.554 .31048 Mdot
.554 .33774 Mdot
.554 .33775 Mdot
.554 .33775 Mdot
.554 .33776 Mdot
.554 .33777 Mdot
.554 .33777 Mdot
.554 .33778 Mdot
.554 .33778 Mdot
.554 .33779 Mdot
.554 .33779 Mdot
.554 .3378 Mdot
.554 .3378 Mdot
.554 .33781 Mdot
.554 .33781 Mdot
.554 .33781 Mdot
.554 .33781 Mdot
.554 .33781 Mdot
.554 .33782 Mdot
.554 .33782 Mdot
.554 .33783 Mdot
.554 .33783 Mdot
.554 .33784 Mdot
.554 .33784 Mdot
.554 .33784 Mdot
.554 .33784 Mdot
.554 .33785 Mdot
.554 .33785 Mdot
.554 .33785 Mdot
.554 .33786 Mdot
.554 .33786 Mdot
.554 .33786 Mdot
.554 .33786 Mdot
.554 .33786 Mdot
.554 .33787 Mdot
.554 .33787 Mdot
.554 .33787 Mdot
.554 .33788 Mdot
.554 .33788 Mdot
.554 .33789 Mdot
.554 .33789 Mdot
.554 .3379 Mdot
.554 .3379 Mdot
.554 .3379 Mdot
.554 .33792 Mdot
.554 .33792 Mdot
.554 .33792 Mdot
.554 .33793 Mdot
.554 .33793 Mdot
.554 .33793 Mdot
.554 .33793 Mdot
.554 .33793 Mdot
.554 .33794 Mdot
.554 .33795 Mdot
.554 .33796 Mdot
.554 .33797 Mdot
.554 .33798 Mdot
.554 .33798 Mdot
.554 .33798 Mdot
.554 .33799 Mdot
.554 .33799 Mdot
.554 .33799 Mdot
.554 .338 Mdot
.554 .338 Mdot
.554 .338 Mdot
.554 .33801 Mdot
.554 .33801 Mdot
.554 .33801 Mdot
.554 .33801 Mdot
.554 .33801 Mdot
.554 .33801 Mdot
.554 .33802 Mdot
.554 .33802 Mdot
.554 .33802 Mdot
.554 .33802 Mdot
.554 .33802 Mdot
.554 .33803 Mdot
.554 .33803 Mdot
.554 .33803 Mdot
.554 .33803 Mdot
.554 .33803 Mdot
.554 .33804 Mdot
.554 .33804 Mdot
.554 .33804 Mdot
.554 .33805 Mdot
.554 .33805 Mdot
.554 .33805 Mdot
.554 .33806 Mdot
.554 .33806 Mdot
.554 .33806 Mdot
.554 .33806 Mdot
.554 .33806 Mdot
.554 .33807 Mdot
.554 .33809 Mdot
.554 .33809 Mdot
.554 .33809 Mdot
.554 .3381 Mdot
.554 .3381 Mdot
.554 .3381 Mdot
.554 .3381 Mdot
.554 .3381 Mdot
.554 .3381 Mdot
.554 .33811 Mdot
.554 .33811 Mdot
.554 .33811 Mdot
.554 .33811 Mdot
.554 .33811 Mdot
.554 .33812 Mdot
.554 .33812 Mdot
.554 .33813 Mdot
.554 .33813 Mdot
.554 .33814 Mdot
.554 .33814 Mdot
.554 .33814 Mdot
.554 .33814 Mdot
.554 .33814 Mdot
.554 .33814 Mdot
.554 .33815 Mdot
.554 .33816 Mdot
.554 .33816 Mdot
.554 .33816 Mdot
.554 .33817 Mdot
.554 .33817 Mdot
.554 .33818 Mdot
.554 .33818 Mdot
.554 .33818 Mdot
.554 .33819 Mdot
.554 .3382 Mdot
.554 .3382 Mdot
.554 .3382 Mdot
.554 .33821 Mdot
.554 .33821 Mdot
.554 .33821 Mdot
.554 .33821 Mdot
.554 .33821 Mdot
.554 .33821 Mdot
.554 .33821 Mdot
.554 .33822 Mdot
.554 .33822 Mdot
.554 .33824 Mdot
.554 .33824 Mdot
.554 .33824 Mdot
.554 .33825 Mdot
.554 .33825 Mdot
.554 .33825 Mdot
.554 .33825 Mdot
.554 .33826 Mdot
.554 .33826 Mdot
.554 .33826 Mdot
.554 .33826 Mdot
.554 .33827 Mdot
.554 .33827 Mdot
.554 .33827 Mdot
.554 .33827 Mdot
.554 .33827 Mdot
.554 .33828 Mdot
.554 .33828 Mdot
.554 .33829 Mdot
.554 .33829 Mdot
.554 .33832 Mdot
.554 .33833 Mdot
.554 .33833 Mdot
.554 .33833 Mdot
.554 .33833 Mdot
.554 .33833 Mdot
.554 .33834 Mdot
.554 .33835 Mdot
.554 .33835 Mdot
.554 .33836 Mdot
.554 .33836 Mdot
.554 .33837 Mdot
.554 .33837 Mdot
.554 .33837 Mdot
.554 .33838 Mdot
.554 .33838 Mdot
.554 .33838 Mdot
.554 .33838 Mdot
.554 .33838 Mdot
.554 .33839 Mdot
.554 .33839 Mdot
.554 .3384 Mdot
.554 .3384 Mdot
.554 .3384 Mdot
.554 .3384 Mdot
.554 .33841 Mdot
.554 .33841 Mdot
.554 .33841 Mdot
.554 .33842 Mdot
.554 .33842 Mdot
.554 .33842 Mdot
.554 .33843 Mdot
.554 .33843 Mdot
.554 .33844 Mdot
.554 .33845 Mdot
.554 .33845 Mdot
.554 .33845 Mdot
.554 .33847 Mdot
.554 .33849 Mdot
.554 .33849 Mdot
.554 .33851 Mdot
.554 .33852 Mdot
.554 .33853 Mdot
.554 .33853 Mdot
.554 .33853 Mdot
.554 .33853 Mdot
.554 .33854 Mdot
.554 .33854 Mdot
.554 .33855 Mdot
.554 .33857 Mdot
.554 .33857 Mdot
.554 .33857 Mdot
.554 .33859 Mdot
.554 .33859 Mdot
.554 .3386 Mdot
.554 .33861 Mdot
.554 .33861 Mdot
.554 .33862 Mdot
.554 .33862 Mdot
.554 .33862 Mdot
.554 .33863 Mdot
.554 .33863 Mdot
.554 .33863 Mdot
.554 .33863 Mdot
.554 .33864 Mdot
.554 .33864 Mdot
.554 .33864 Mdot
.554 .33865 Mdot
.554 .33865 Mdot
.554 .33866 Mdot
.554 .33866 Mdot
.554 .33867 Mdot
.554 .33868 Mdot
.554 .33869 Mdot
.554 .33869 Mdot
.554 .3387 Mdot
.554 .33871 Mdot
.554 .33871 Mdot
.554 .33871 Mdot
.554 .33871 Mdot
.554 .33871 Mdot
.554 .33872 Mdot
.554 .33873 Mdot
.554 .33874 Mdot
.554 .33875 Mdot
.554 .33876 Mdot
.554 .33876 Mdot
.554 .33876 Mdot
.554 .33878 Mdot
.554 .3388 Mdot
.554 .3388 Mdot
.554 .3388 Mdot
.554 .34069 Mdot
.554 .34069 Mdot
.554 .34069 Mdot
.554 .34071 Mdot
.554 .34073 Mdot
.554 .34073 Mdot
.554 .34073 Mdot
.554 .34073 Mdot
.554 .34075 Mdot
.554 .34075 Mdot
.554 .34075 Mdot
.554 .34076 Mdot
.554 .34076 Mdot
.554 .34076 Mdot
.554 .34077 Mdot
.554 .34077 Mdot
.554 .34078 Mdot
.554 .34078 Mdot
.554 .34079 Mdot
.554 .34079 Mdot
.554 .3408 Mdot
.554 .34081 Mdot
.554 .34081 Mdot
.554 .34081 Mdot
.554 .34081 Mdot
.554 .34082 Mdot
.554 .34082 Mdot
.554 .34083 Mdot
.554 .34083 Mdot
.554 .34083 Mdot
.554 .34083 Mdot
.554 .34084 Mdot
.554 .34084 Mdot
.554 .34084 Mdot
.554 .34084 Mdot
.554 .34085 Mdot
.554 .34085 Mdot
.554 .34086 Mdot
.554 .34086 Mdot
.554 .34087 Mdot
.554 .34088 Mdot
.554 .34088 Mdot
.554 .34088 Mdot
.554 .3409 Mdot
.554 .3409 Mdot
.554 .34091 Mdot
.554 .34091 Mdot
.554 .34091 Mdot
.554 .34091 Mdot
.554 .34092 Mdot
.554 .34092 Mdot
.554 .34093 Mdot
.554 .34094 Mdot
.554 .34095 Mdot
.554 .34096 Mdot
.554 .34098 Mdot
.554 .34098 Mdot
.554 .34098 Mdot
.554 .34099 Mdot
.554 .341 Mdot
.554 .341 Mdot
.554 .341 Mdot
.554 .341 Mdot
.554 .34101 Mdot
.554 .34101 Mdot
.554 .34101 Mdot
.554 .34101 Mdot
.554 .34101 Mdot
.554 .34102 Mdot
.554 .34102 Mdot
.554 .34102 Mdot
.554 .34102 Mdot
.554 .34103 Mdot
.554 .34103 Mdot
.554 .34103 Mdot
.554 .34103 Mdot
.554 .34103 Mdot
.554 .34104 Mdot
.554 .34104 Mdot
.554 .34104 Mdot
.554 .34105 Mdot
.554 .34105 Mdot
.554 .34105 Mdot
.554 .34106 Mdot
.554 .34106 Mdot
.554 .34106 Mdot
.554 .34107 Mdot
.554 .34107 Mdot
.554 .34108 Mdot
.554 .34108 Mdot
.554 .34108 Mdot
.554 .34109 Mdot
.554 .34111 Mdot
.554 .34111 Mdot
.554 .34111 Mdot
.554 .34112 Mdot
.554 .34112 Mdot
.554 .34112 Mdot
.554 .34112 Mdot
.554 .34113 Mdot
.554 .34113 Mdot
.554 .34113 Mdot
.554 .34113 Mdot
.554 .34113 Mdot
.554 .34113 Mdot
.554 .34114 Mdot
.554 .34114 Mdot
.554 .34114 Mdot
.554 .34114 Mdot
.554 .34115 Mdot
.554 .34115 Mdot
.554 .34115 Mdot
.554 .34116 Mdot
.554 .34117 Mdot
.554 .34117 Mdot
.554 .34117 Mdot
.554 .34117 Mdot
.554 .34117 Mdot
.554 .34117 Mdot
.554 .34118 Mdot
.554 .34118 Mdot
.554 .34118 Mdot
.554 .34118 Mdot
.554 .34118 Mdot
.554 .34119 Mdot
.554 .3412 Mdot
.554 .3412 Mdot
.554 .3412 Mdot
.554 .3412 Mdot
.554 .34121 Mdot
.554 .34121 Mdot
.554 .34122 Mdot
.554 .34122 Mdot
.554 .34122 Mdot
.554 .34123 Mdot
.554 .34123 Mdot
.554 .34123 Mdot
.554 .34123 Mdot
.554 .34123 Mdot
.554 .34123 Mdot
.554 .34124 Mdot
.554 .34124 Mdot
.554 .34125 Mdot
.554 .34125 Mdot
.554 .34125 Mdot
.554 .34125 Mdot
.554 .34125 Mdot
.554 .34126 Mdot
.554 .34126 Mdot
.554 .34126 Mdot
.554 .34126 Mdot
.554 .34126 Mdot
.554 .34126 Mdot
.554 .34126 Mdot
.554 .34127 Mdot
.554 .34127 Mdot
.554 .34127 Mdot
.554 .34127 Mdot
.554 .34129 Mdot
.554 .34129 Mdot
.554 .34129 Mdot
.554 .34129 Mdot
.554 .3413 Mdot
.554 .3413 Mdot
.554 .3413 Mdot
.554 .3413 Mdot
.554 .34131 Mdot
.554 .34131 Mdot
.554 .34131 Mdot
.554 .34132 Mdot
.554 .34132 Mdot
.554 .34132 Mdot
.554 .34132 Mdot
.554 .34132 Mdot
.554 .34132 Mdot
.554 .34133 Mdot
.554 .34133 Mdot
.554 .34133 Mdot
.554 .34133 Mdot
.554 .34133 Mdot
.554 .34133 Mdot
.554 .34133 Mdot
.554 .34134 Mdot
.554 .34134 Mdot
.554 .34134 Mdot
.554 .34134 Mdot
.554 .34134 Mdot
.554 .34134 Mdot
.554 .34135 Mdot
.554 .34135 Mdot
.554 .34135 Mdot
.554 .34135 Mdot
.554 .34136 Mdot
.554 .34136 Mdot
.554 .34136 Mdot
.554 .34137 Mdot
.554 .34138 Mdot
.554 .34138 Mdot
.554 .34139 Mdot
.554 .3414 Mdot
.554 .3414 Mdot
.554 .3414 Mdot
.554 .3414 Mdot
.554 .3414 Mdot
.554 .34141 Mdot
.554 .34141 Mdot
.554 .34141 Mdot
.554 .34143 Mdot
.554 .34143 Mdot
.554 .34143 Mdot
.554 .34144 Mdot
.554 .34144 Mdot
.554 .34144 Mdot
.554 .34145 Mdot
.554 .34145 Mdot
.554 .34145 Mdot
.554 .34145 Mdot
.554 .34146 Mdot
.554 .34146 Mdot
.554 .34146 Mdot
.554 .34146 Mdot
.554 .34146 Mdot
.554 .34146 Mdot
.554 .34146 Mdot
.554 .34147 Mdot
.554 .34147 Mdot
.554 .34148 Mdot
.554 .34148 Mdot
.554 .34148 Mdot
.554 .34149 Mdot
.554 .34149 Mdot
.554 .34149 Mdot
.554 .34149 Mdot
.554 .3415 Mdot
.554 .3415 Mdot
.554 .3415 Mdot
.554 .3415 Mdot
.554 .3415 Mdot
.554 .3415 Mdot
.554 .34151 Mdot
.554 .34151 Mdot
.554 .34152 Mdot
.554 .34152 Mdot
.554 .34153 Mdot
.554 .34153 Mdot
.554 .34153 Mdot
.554 .34154 Mdot
.554 .34155 Mdot
.554 .34155 Mdot
.554 .34155 Mdot
.556 .306 Mdot
.556 .306 Mdot
.556 .30602 Mdot
.556 .30602 Mdot
.556 .30602 Mdot
.556 .30602 Mdot
.556 .30603 Mdot
.556 .30604 Mdot
.556 .30605 Mdot
.556 .30605 Mdot
.556 .30606 Mdot
.556 .30606 Mdot
.556 .30606 Mdot
.556 .30606 Mdot
.556 .30607 Mdot
.556 .30607 Mdot
.556 .30607 Mdot
.556 .30608 Mdot
.556 .30608 Mdot
.556 .30608 Mdot
.556 .30609 Mdot
.556 .3061 Mdot
.556 .3061 Mdot
.556 .30611 Mdot
.556 .30611 Mdot
.556 .30611 Mdot
.556 .30611 Mdot
.556 .30612 Mdot
.556 .30612 Mdot
.556 .30613 Mdot
.556 .30614 Mdot
.556 .30614 Mdot
.556 .30614 Mdot
.556 .30614 Mdot
.556 .30615 Mdot
.556 .30615 Mdot
.556 .30616 Mdot
.556 .30616 Mdot
.556 .30616 Mdot
.556 .30617 Mdot
.556 .30617 Mdot
.556 .30618 Mdot
.556 .30618 Mdot
.556 .30618 Mdot
.556 .30619 Mdot
.556 .30619 Mdot
.556 .3062 Mdot
.556 .3062 Mdot
.556 .30621 Mdot
.556 .30621 Mdot
.556 .30621 Mdot
.556 .30622 Mdot
.556 .30622 Mdot
.556 .30623 Mdot
.556 .30623 Mdot
.556 .30623 Mdot
.556 .30623 Mdot
.556 .30623 Mdot
.556 .30624 Mdot
.556 .30624 Mdot
.556 .30627 Mdot
.556 .30627 Mdot
.556 .30627 Mdot
.556 .30627 Mdot
.556 .30627 Mdot
.556 .30627 Mdot
.556 .30628 Mdot
.556 .30628 Mdot
.556 .30629 Mdot
.556 .30629 Mdot
.556 .30629 Mdot
.556 .30629 Mdot
.556 .3063 Mdot
.556 .3063 Mdot
.556 .3063 Mdot
.556 .3063 Mdot
.556 .30631 Mdot
.556 .30631 Mdot
.556 .30631 Mdot
.556 .30631 Mdot
.556 .30632 Mdot
.556 .30632 Mdot
.556 .30633 Mdot
.556 .30633 Mdot
.556 .30634 Mdot
.556 .30634 Mdot
.556 .30635 Mdot
.556 .30636 Mdot
.556 .30636 Mdot
.556 .30636 Mdot
.556 .30636 Mdot
.556 .30637 Mdot
.556 .30637 Mdot
.556 .30637 Mdot
.556 .30638 Mdot
.556 .30638 Mdot
.556 .30638 Mdot
.556 .30639 Mdot
.556 .30639 Mdot
.556 .30639 Mdot
.556 .30639 Mdot
.556 .3064 Mdot
.556 .3064 Mdot
.556 .3064 Mdot
.556 .3064 Mdot
.556 .3064 Mdot
.556 .30641 Mdot
.556 .30641 Mdot
.556 .30641 Mdot
.556 .30641 Mdot
.556 .30642 Mdot
.556 .30642 Mdot
.556 .30642 Mdot
.556 .30642 Mdot
.556 .30642 Mdot
.556 .30642 Mdot
.556 .30642 Mdot
.556 .30642 Mdot
.556 .30642 Mdot
.556 .30642 Mdot
.556 .30642 Mdot
.556 .30642 Mdot
.556 .30642 Mdot
.556 .30642 Mdot
.556 .30643 Mdot
.556 .30643 Mdot
.556 .30643 Mdot
.556 .30643 Mdot
.556 .30643 Mdot
.556 .30643 Mdot
.556 .30643 Mdot
.556 .30644 Mdot
.556 .30644 Mdot
.556 .30644 Mdot
.556 .30645 Mdot
.556 .30645 Mdot
.556 .30645 Mdot
.556 .30645 Mdot
.556 .30646 Mdot
.556 .30646 Mdot
.556 .30646 Mdot
.556 .30647 Mdot
.556 .30647 Mdot
.556 .30647 Mdot
.556 .30648 Mdot
.556 .30648 Mdot
.556 .30648 Mdot
.556 .30649 Mdot
.556 .3065 Mdot
.556 .3065 Mdot
.556 .3065 Mdot
.556 .3065 Mdot
.556 .3065 Mdot
.556 .30651 Mdot
.556 .30651 Mdot
.556 .30651 Mdot
.556 .30651 Mdot
.556 .30652 Mdot
.556 .30652 Mdot
.556 .30652 Mdot
.556 .30653 Mdot
.556 .30653 Mdot
.556 .30654 Mdot
.556 .30655 Mdot
.556 .30655 Mdot
.556 .30656 Mdot
.556 .30656 Mdot
.556 .30656 Mdot
.556 .30657 Mdot
.556 .30658 Mdot
.556 .30658 Mdot
.556 .30659 Mdot
.556 .3066 Mdot
.556 .3066 Mdot
.556 .3066 Mdot
.556 .30661 Mdot
.556 .30661 Mdot
.556 .30662 Mdot
.556 .30662 Mdot
.556 .30662 Mdot
.556 .30663 Mdot
.556 .30663 Mdot
.556 .30663 Mdot
.556 .30665 Mdot
.556 .30665 Mdot
.556 .30665 Mdot
.556 .30666 Mdot
.556 .30666 Mdot
.556 .30666 Mdot
.556 .30666 Mdot
.556 .30667 Mdot
.556 .3067 Mdot
.556 .30671 Mdot
.556 .30672 Mdot
.556 .30672 Mdot
.556 .30672 Mdot
.556 .30672 Mdot
.556 .30672 Mdot
.556 .30674 Mdot
.556 .30674 Mdot
.556 .30675 Mdot
.556 .30675 Mdot
.556 .30676 Mdot
.556 .30676 Mdot
.556 .30677 Mdot
.556 .30678 Mdot
.556 .30678 Mdot
.556 .3068 Mdot
.556 .3068 Mdot
.556 .3068 Mdot
.556 .30681 Mdot
.556 .30682 Mdot
.556 .30682 Mdot
.556 .30683 Mdot
.556 .30683 Mdot
.556 .30684 Mdot
.556 .30685 Mdot
.556 .30686 Mdot
.556 .30686 Mdot
.556 .30686 Mdot
.556 .30686 Mdot
.556 .30688 Mdot
.556 .30688 Mdot
.556 .30689 Mdot
.556 .3069 Mdot
.556 .3069 Mdot
.556 .3069 Mdot
.556 .30691 Mdot
.556 .30692 Mdot
.556 .30692 Mdot
.556 .30694 Mdot
.556 .30694 Mdot
.556 .30695 Mdot
.556 .30695 Mdot
.556 .30696 Mdot
.556 .30696 Mdot
.556 .30697 Mdot
.556 .30697 Mdot
.556 .30697 Mdot
.556 .30698 Mdot
.556 .30698 Mdot
.556 .30699 Mdot
.556 .30699 Mdot
.556 .307 Mdot
.556 .30703 Mdot
.556 .30703 Mdot
.556 .30704 Mdot
.556 .30704 Mdot
.556 .30705 Mdot
.556 .30707 Mdot
.556 .30708 Mdot
.556 .30924 Mdot
.556 .30925 Mdot
.556 .30927 Mdot
.556 .30928 Mdot
.556 .30928 Mdot
.556 .30929 Mdot
.556 .30929 Mdot
.556 .30932 Mdot
.556 .30934 Mdot
.556 .30934 Mdot
.556 .30935 Mdot
.556 .30935 Mdot
.556 .30936 Mdot
.556 .30936 Mdot
.556 .30937 Mdot
.556 .30937 Mdot
.556 .30938 Mdot
.556 .30939 Mdot
.556 .30939 Mdot
.556 .3094 Mdot
.556 .3094 Mdot
.556 .30943 Mdot
.556 .30943 Mdot
.556 .30944 Mdot
.556 .30945 Mdot
.556 .30946 Mdot
.556 .30946 Mdot
.556 .30947 Mdot
.556 .30947 Mdot
.556 .30948 Mdot
.556 .3095 Mdot
.556 .30951 Mdot
.556 .30951 Mdot
.556 .30951 Mdot
.556 .30952 Mdot
.556 .30953 Mdot
.556 .30954 Mdot
.556 .30954 Mdot
.556 .30955 Mdot
.556 .30956 Mdot
.556 .30956 Mdot
.556 .30958 Mdot
.556 .30958 Mdot
.556 .30958 Mdot
.556 .3096 Mdot
.556 .30961 Mdot
.556 .30961 Mdot
.556 .30962 Mdot
.556 .30963 Mdot
.556 .30964 Mdot
.556 .30964 Mdot
.556 .30965 Mdot
.556 .30966 Mdot
.556 .30967 Mdot
.556 .30967 Mdot
.556 .30968 Mdot
.556 .30968 Mdot
.556 .30968 Mdot
.556 .3097 Mdot
.556 .3097 Mdot
.556 .30974 Mdot
.556 .30975 Mdot
.556 .30975 Mdot
.556 .30975 Mdot
.556 .30976 Mdot
.556 .30976 Mdot
.556 .30977 Mdot
.556 .30977 Mdot
.556 .30978 Mdot
.556 .30979 Mdot
.556 .30979 Mdot
.556 .3098 Mdot
.556 .3098 Mdot
.556 .3098 Mdot
.556 .30981 Mdot
.556 .30982 Mdot
.556 .30982 Mdot
.556 .30983 Mdot
.556 .30983 Mdot
.556 .30983 Mdot
.556 .30984 Mdot
.556 .30984 Mdot
.556 .30987 Mdot
.556 .30987 Mdot
.556 .30987 Mdot
.556 .30988 Mdot
.556 .30988 Mdot
.556 .30988 Mdot
.556 .3099 Mdot
.556 .30991 Mdot
.556 .30992 Mdot
.556 .30992 Mdot
.556 .30992 Mdot
.556 .30993 Mdot
.556 .30993 Mdot
.556 .30994 Mdot
.556 .30994 Mdot
.556 .30994 Mdot
.556 .30995 Mdot
.556 .30995 Mdot
.556 .30995 Mdot
.556 .30995 Mdot
.556 .30996 Mdot
.556 .30997 Mdot
.556 .30997 Mdot
.556 .30997 Mdot
.556 .30998 Mdot
.556 .30999 Mdot
.556 .30999 Mdot
.556 .31 Mdot
.556 .31 Mdot
.556 .31 Mdot
.556 .31001 Mdot
.556 .31001 Mdot
.556 .31001 Mdot
.556 .31002 Mdot
.556 .31002 Mdot
.556 .31002 Mdot
.556 .31003 Mdot
.556 .31003 Mdot
.556 .31003 Mdot
.556 .31004 Mdot
.556 .31004 Mdot
.556 .31004 Mdot
.556 .31004 Mdot
.556 .31004 Mdot
.556 .31004 Mdot
.556 .31004 Mdot
.556 .31004 Mdot
.556 .31004 Mdot
.556 .31004 Mdot
.556 .31004 Mdot
.556 .31004 Mdot
.556 .31004 Mdot
.556 .31004 Mdot
.556 .31004 Mdot
.556 .31004 Mdot
.556 .31005 Mdot
.556 .31005 Mdot
.556 .31005 Mdot
.556 .31005 Mdot
.556 .31006 Mdot
.556 .31006 Mdot
.556 .31006 Mdot
.556 .31007 Mdot
.556 .31007 Mdot
.556 .31007 Mdot
.556 .31008 Mdot
.556 .31008 Mdot
.556 .31008 Mdot
.556 .31009 Mdot
.556 .31009 Mdot
.556 .31009 Mdot
.556 .3101 Mdot
.556 .3101 Mdot
.556 .3101 Mdot
.556 .31011 Mdot
.556 .31011 Mdot
.556 .31011 Mdot
.556 .31012 Mdot
.556 .31012 Mdot
.556 .31013 Mdot
.556 .31013 Mdot
.556 .31014 Mdot
.556 .31015 Mdot
.556 .31015 Mdot
.556 .31015 Mdot
.556 .31016 Mdot
.556 .31017 Mdot
.556 .31017 Mdot
.556 .31018 Mdot
.556 .31018 Mdot
.556 .31018 Mdot
.556 .31018 Mdot
.556 .31019 Mdot
.556 .31019 Mdot
.556 .3102 Mdot
.556 .3102 Mdot
.556 .3102 Mdot
.556 .31021 Mdot
.556 .31021 Mdot
.556 .31021 Mdot
.556 .31022 Mdot
.556 .31022 Mdot
.556 .31023 Mdot
.556 .31023 Mdot
.556 .31023 Mdot
.556 .31024 Mdot
.556 .31024 Mdot
.556 .31024 Mdot
.556 .31027 Mdot
.556 .31027 Mdot
.556 .31028 Mdot
.556 .31028 Mdot
.556 .31028 Mdot
.556 .31028 Mdot
.556 .31029 Mdot
.556 .31029 Mdot
.556 .3103 Mdot
.556 .31031 Mdot
.556 .31031 Mdot
.556 .31031 Mdot
.556 .31032 Mdot
.556 .31032 Mdot
.556 .31033 Mdot
.556 .31033 Mdot
.556 .31034 Mdot
.556 .31034 Mdot
.556 .31035 Mdot
.556 .31036 Mdot
.556 .31036 Mdot
.556 .31037 Mdot
.556 .31037 Mdot
.556 .31037 Mdot
.556 .31038 Mdot
.556 .31039 Mdot
.556 .31039 Mdot
.556 .31039 Mdot
.556 .31039 Mdot
.556 .3104 Mdot
.556 .31041 Mdot
.556 .31041 Mdot
.556 .31042 Mdot
.556 .31042 Mdot
.556 .31043 Mdot
.556 .31043 Mdot
.556 .31043 Mdot
.556 .31044 Mdot
.556 .31045 Mdot
.556 .31046 Mdot
.556 .31046 Mdot
.556 .31047 Mdot
.556 .31047 Mdot
.556 .31047 Mdot
.556 .31048 Mdot
.556 .31048 Mdot
.556 .31049 Mdot
.556 .31049 Mdot
.556 .3105 Mdot
.556 .3105 Mdot
.556 .3105 Mdot
.556 .3105 Mdot
.556 .31051 Mdot
.556 .31053 Mdot
.556 .31054 Mdot
.556 .31054 Mdot
.556 .31054 Mdot
.556 .31055 Mdot
.556 .31056 Mdot
.556 .31057 Mdot
.556 .33862 Mdot
.556 .33863 Mdot
.556 .33864 Mdot
.556 .33865 Mdot
.556 .33865 Mdot
.556 .33865 Mdot
.556 .33865 Mdot
.556 .33867 Mdot
.556 .33868 Mdot
.556 .33868 Mdot
.556 .33869 Mdot
.556 .33869 Mdot
.556 .3387 Mdot
.556 .3387 Mdot
.556 .3387 Mdot
.556 .3387 Mdot
.556 .33871 Mdot
.556 .33871 Mdot
.556 .33871 Mdot
.556 .33872 Mdot
.556 .33872 Mdot
.556 .33873 Mdot
.556 .33874 Mdot
.556 .33874 Mdot
.556 .33875 Mdot
.556 .33875 Mdot
.556 .33875 Mdot
.556 .33876 Mdot
.556 .33876 Mdot
.556 .33876 Mdot
.556 .33878 Mdot
.556 .33878 Mdot
.556 .33878 Mdot
.556 .33878 Mdot
.556 .33879 Mdot
.556 .3388 Mdot
.556 .3388 Mdot
.556 .3388 Mdot
.556 .3388 Mdot
.556 .33881 Mdot
.556 .33881 Mdot
.556 .33882 Mdot
.556 .33882 Mdot
.556 .33883 Mdot
.556 .33884 Mdot
.556 .33884 Mdot
.556 .33884 Mdot
.556 .33885 Mdot
.556 .33885 Mdot
.556 .33886 Mdot
.556 .33886 Mdot
.556 .33887 Mdot
.556 .33887 Mdot
.556 .33888 Mdot
.556 .33888 Mdot
.556 .33888 Mdot
.556 .33888 Mdot
.556 .33888 Mdot
.556 .33889 Mdot
.556 .3389 Mdot
.556 .33892 Mdot
.556 .33892 Mdot
.556 .33892 Mdot
.556 .33892 Mdot
.556 .33893 Mdot
.556 .33893 Mdot
.556 .33893 Mdot
.556 .33893 Mdot
.556 .33894 Mdot
.556 .33895 Mdot
.556 .33895 Mdot
.556 .33895 Mdot
.556 .33895 Mdot
.556 .33895 Mdot
.556 .33896 Mdot
.556 .33896 Mdot
.556 .33897 Mdot
.556 .33897 Mdot
.556 .33897 Mdot
.556 .33897 Mdot
.556 .33898 Mdot
.556 .33898 Mdot
.556 .33899 Mdot
.556 .33899 Mdot
.556 .339 Mdot
.556 .339 Mdot
.556 .33901 Mdot
.556 .33902 Mdot
.556 .33902 Mdot
.556 .33902 Mdot
.556 .33903 Mdot
.556 .33903 Mdot
.556 .33904 Mdot
.556 .33904 Mdot
.556 .33904 Mdot
.556 .33904 Mdot
.556 .33905 Mdot
.556 .33905 Mdot
.556 .33905 Mdot
.556 .33906 Mdot
.556 .33906 Mdot
.556 .33906 Mdot
.556 .33906 Mdot
.556 .33907 Mdot
.556 .33907 Mdot
.556 .33907 Mdot
.556 .33908 Mdot
.556 .33908 Mdot
.556 .33908 Mdot
.556 .33909 Mdot
.556 .33909 Mdot
.556 .33909 Mdot
.556 .33909 Mdot
.556 .33909 Mdot
.556 .33909 Mdot
.556 .33909 Mdot
.556 .3391 Mdot
.556 .3391 Mdot
.556 .3391 Mdot
.556 .3391 Mdot
.556 .3391 Mdot
.556 .3391 Mdot
.556 .3391 Mdot
.556 .3391 Mdot
.556 .3391 Mdot
.556 .3391 Mdot
.556 .3391 Mdot
.556 .3391 Mdot
.556 .3391 Mdot
.556 .3391 Mdot
.556 .33911 Mdot
.556 .33911 Mdot
.556 .33911 Mdot
.556 .33911 Mdot
.556 .33912 Mdot
.556 .33912 Mdot
.556 .33912 Mdot
.556 .33913 Mdot
.556 .33913 Mdot
.556 .33913 Mdot
.556 .33914 Mdot
.556 .33914 Mdot
.556 .33914 Mdot
.556 .33915 Mdot
.556 .33916 Mdot
.556 .33916 Mdot
.556 .33916 Mdot
.556 .33917 Mdot
.556 .33918 Mdot
.556 .33918 Mdot
.556 .33918 Mdot
.556 .33918 Mdot
.556 .33918 Mdot
.556 .33919 Mdot
.556 .33919 Mdot
.556 .3392 Mdot
.556 .3392 Mdot
.556 .3392 Mdot
.556 .33921 Mdot
.556 .33921 Mdot
.556 .33921 Mdot
.556 .33923 Mdot
.556 .33924 Mdot
.556 .33924 Mdot
.556 .33925 Mdot
.556 .33925 Mdot
.556 .33925 Mdot
.556 .33925 Mdot
.556 .33927 Mdot
.556 .33927 Mdot
.556 .33928 Mdot
.556 .33929 Mdot
.556 .33929 Mdot
.556 .33929 Mdot
.556 .3393 Mdot
.556 .3393 Mdot
.556 .33931 Mdot
.556 .33931 Mdot
.556 .33932 Mdot
.556 .33932 Mdot
.556 .33932 Mdot
.556 .33933 Mdot
.556 .33934 Mdot
.556 .33935 Mdot
.556 .33935 Mdot
.556 .33935 Mdot
.556 .33936 Mdot
.556 .33936 Mdot
.556 .33936 Mdot
.556 .33936 Mdot
.556 .3394 Mdot
.556 .33941 Mdot
.556 .33942 Mdot
.556 .33942 Mdot
.556 .33943 Mdot
.556 .33943 Mdot
.556 .33943 Mdot
.556 .33944 Mdot
.556 .33945 Mdot
.556 .33946 Mdot
.556 .33946 Mdot
.556 .33947 Mdot
.556 .33947 Mdot
.556 .33948 Mdot
.556 .33949 Mdot
.556 .33949 Mdot
.556 .33951 Mdot
.556 .33951 Mdot
.556 .33951 Mdot
.556 .33953 Mdot
.556 .33953 Mdot
.556 .33954 Mdot
.556 .33955 Mdot
.556 .33955 Mdot
.556 .33955 Mdot
.556 .33957 Mdot
.556 .33958 Mdot
.556 .33958 Mdot
.556 .33958 Mdot
.556 .33958 Mdot
.556 .3396 Mdot
.556 .33961 Mdot
.556 .33961 Mdot
.556 .33962 Mdot
.556 .33962 Mdot
.556 .33962 Mdot
.556 .33963 Mdot
.556 .33964 Mdot
.556 .33965 Mdot
.556 .33967 Mdot
.556 .33967 Mdot
.556 .33968 Mdot
.556 .33968 Mdot
.556 .33969 Mdot
.556 .3397 Mdot
.556 .3397 Mdot
.556 .33971 Mdot
.556 .33971 Mdot
.556 .33972 Mdot
.556 .33972 Mdot
.556 .33972 Mdot
.556 .33973 Mdot
.556 .33974 Mdot
.556 .33977 Mdot
.556 .33977 Mdot
.556 .33978 Mdot
.556 .33978 Mdot
.556 .33979 Mdot
.556 .33981 Mdot
.556 .33982 Mdot
.556 .34176 Mdot
.556 .34177 Mdot
.556 .34179 Mdot
.556 .34179 Mdot
.556 .3418 Mdot
.556 .3418 Mdot
.556 .3418 Mdot
.556 .34183 Mdot
.556 .34184 Mdot
.556 .34184 Mdot
.556 .34185 Mdot
.556 .34185 Mdot
.556 .34186 Mdot
.556 .34186 Mdot
.556 .34186 Mdot
.556 .34186 Mdot
.556 .34187 Mdot
.556 .34187 Mdot
.556 .34188 Mdot
.556 .34188 Mdot
.556 .34188 Mdot
.556 .3419 Mdot
.556 .34191 Mdot
.556 .34191 Mdot
.556 .34192 Mdot
.556 .34192 Mdot
.556 .34192 Mdot
.556 .34193 Mdot
.556 .34194 Mdot
.556 .34194 Mdot
.556 .34195 Mdot
.556 .34196 Mdot
.556 .34196 Mdot
.556 .34196 Mdot
.556 .34197 Mdot
.556 .34198 Mdot
.556 .34198 Mdot
.556 .34198 Mdot
.556 .34199 Mdot
.556 .342 Mdot
.556 .342 Mdot
.556 .34201 Mdot
.556 .34201 Mdot
.556 .34202 Mdot
.556 .34203 Mdot
.556 .34203 Mdot
.556 .34204 Mdot
.556 .34205 Mdot
.556 .34205 Mdot
.556 .34205 Mdot
.556 .34206 Mdot
.556 .34207 Mdot
.556 .34207 Mdot
.556 .34208 Mdot
.556 .34208 Mdot
.556 .34208 Mdot
.556 .34208 Mdot
.556 .34209 Mdot
.556 .3421 Mdot
.556 .3421 Mdot
.556 .34213 Mdot
.556 .34213 Mdot
.556 .34213 Mdot
.556 .34214 Mdot
.556 .34214 Mdot
.556 .34214 Mdot
.556 .34215 Mdot
.556 .34215 Mdot
.556 .34216 Mdot
.556 .34217 Mdot
.556 .34217 Mdot
.556 .34217 Mdot
.556 .34217 Mdot
.556 .34217 Mdot
.556 .34218 Mdot
.556 .34219 Mdot
.556 .34219 Mdot
.556 .34219 Mdot
.556 .34219 Mdot
.556 .3422 Mdot
.556 .34221 Mdot
.556 .34221 Mdot
.556 .34222 Mdot
.556 .34222 Mdot
.556 .34222 Mdot
.556 .34223 Mdot
.556 .34223 Mdot
.556 .34223 Mdot
.556 .34224 Mdot
.556 .34226 Mdot
.556 .34226 Mdot
.556 .34226 Mdot
.556 .34226 Mdot
.556 .34226 Mdot
.556 .34227 Mdot
.556 .34227 Mdot
.556 .34227 Mdot
.556 .34228 Mdot
.556 .34228 Mdot
.556 .34228 Mdot
.556 .34228 Mdot
.556 .34228 Mdot
.556 .34228 Mdot
.556 .34229 Mdot
.556 .3423 Mdot
.556 .3423 Mdot
.556 .3423 Mdot
.556 .3423 Mdot
.556 .34231 Mdot
.556 .34231 Mdot
.556 .34232 Mdot
.556 .34232 Mdot
.556 .34232 Mdot
.556 .34232 Mdot
.556 .34233 Mdot
.556 .34233 Mdot
.556 .34233 Mdot
.556 .34234 Mdot
.556 .34234 Mdot
.556 .34234 Mdot
.556 .34234 Mdot
.556 .34234 Mdot
.556 .34234 Mdot
.556 .34235 Mdot
.556 .34235 Mdot
.556 .34235 Mdot
.556 .34235 Mdot
.556 .34235 Mdot
.556 .34235 Mdot
.556 .34235 Mdot
.556 .34235 Mdot
.556 .34235 Mdot
.556 .34235 Mdot
.556 .34235 Mdot
.556 .34235 Mdot
.556 .34235 Mdot
.556 .34235 Mdot
.556 .34235 Mdot
.556 .34235 Mdot
.556 .34235 Mdot
.556 .34236 Mdot
.556 .34236 Mdot
.556 .34236 Mdot
.556 .34236 Mdot
.556 .34236 Mdot
.556 .34237 Mdot
.556 .34237 Mdot
.556 .34237 Mdot
.556 .34238 Mdot
.556 .34238 Mdot
.556 .34238 Mdot
.556 .34238 Mdot
.556 .34238 Mdot
.556 .34238 Mdot
.556 .34239 Mdot
.556 .34239 Mdot
.556 .34239 Mdot
.556 .3424 Mdot
.556 .3424 Mdot
.556 .3424 Mdot
.556 .34241 Mdot
.556 .34241 Mdot
.556 .34241 Mdot
.556 .34241 Mdot
.556 .34242 Mdot
.556 .34243 Mdot
.556 .34243 Mdot
.556 .34243 Mdot
.556 .34243 Mdot
.556 .34244 Mdot
.556 .34244 Mdot
.556 .34245 Mdot
.556 .34245 Mdot
.556 .34245 Mdot
.556 .34245 Mdot
.556 .34246 Mdot
.556 .34246 Mdot
.556 .34246 Mdot
.556 .34247 Mdot
.556 .34247 Mdot
.556 .34247 Mdot
.556 .34247 Mdot
.556 .34247 Mdot
.556 .34248 Mdot
.556 .34248 Mdot
.556 .34248 Mdot
.556 .34249 Mdot
.556 .34249 Mdot
.556 .34249 Mdot
.556 .34249 Mdot
.556 .34249 Mdot
.556 .34251 Mdot
.556 .34251 Mdot
.556 .34252 Mdot
.556 .34252 Mdot
.556 .34252 Mdot
.556 .34253 Mdot
.556 .34253 Mdot
.556 .34253 Mdot
.556 .34254 Mdot
.556 .34254 Mdot
.556 .34254 Mdot
.556 .34255 Mdot
.556 .34255 Mdot
.556 .34256 Mdot
.556 .34256 Mdot
.556 .34257 Mdot
.556 .34257 Mdot
.556 .34257 Mdot
.556 .34258 Mdot
.556 .34258 Mdot
.556 .34259 Mdot
.556 .34259 Mdot
.556 .34259 Mdot
.556 .34259 Mdot
.556 .3426 Mdot
.556 .3426 Mdot
.556 .3426 Mdot
.556 .34261 Mdot
.556 .34261 Mdot
.556 .34262 Mdot
.556 .34262 Mdot
.556 .34262 Mdot
.556 .34263 Mdot
.556 .34263 Mdot
.556 .34263 Mdot
.556 .34263 Mdot
.556 .34264 Mdot
.556 .34264 Mdot
.556 .34265 Mdot
.556 .34265 Mdot
.556 .34266 Mdot
.556 .34266 Mdot
.556 .34266 Mdot
.556 .34267 Mdot
.556 .34267 Mdot
.556 .34267 Mdot
.556 .34267 Mdot
.556 .34268 Mdot
.556 .34268 Mdot
.556 .34268 Mdot
.556 .34268 Mdot
.556 .34269 Mdot
.556 .34271 Mdot
.556 .34271 Mdot
.556 .34271 Mdot
.556 .34271 Mdot
.556 .34272 Mdot
.556 .34273 Mdot
.556 .34273 Mdot
.558 .30574 Mdot
.558 .30574 Mdot
.558 .30575 Mdot
.558 .30576 Mdot
.558 .30577 Mdot
.558 .30578 Mdot
.558 .30579 Mdot
.558 .30579 Mdot
.558 .3058 Mdot
.558 .3058 Mdot
.558 .3058 Mdot
.558 .30581 Mdot
.558 .30581 Mdot
.558 .30582 Mdot
.558 .30582 Mdot
.558 .30582 Mdot
.558 .30582 Mdot
.558 .30583 Mdot
.558 .30583 Mdot
.558 .30583 Mdot
.558 .30584 Mdot
.558 .30584 Mdot
.558 .30584 Mdot
.558 .30585 Mdot
.558 .30585 Mdot
.558 .30585 Mdot
.558 .30585 Mdot
.558 .30586 Mdot
.558 .30587 Mdot
.558 .30587 Mdot
.558 .30587 Mdot
.558 .30587 Mdot
.558 .30587 Mdot
.558 .30588 Mdot
.558 .30588 Mdot
.558 .3059 Mdot
.558 .30591 Mdot
.558 .30591 Mdot
.558 .30591 Mdot
.558 .30592 Mdot
.558 .30592 Mdot
.558 .30592 Mdot
.558 .30593 Mdot
.558 .30593 Mdot
.558 .30594 Mdot
.558 .30595 Mdot
.558 .30595 Mdot
.558 .30595 Mdot
.558 .30596 Mdot
.558 .30596 Mdot
.558 .30596 Mdot
.558 .30596 Mdot
.558 .30597 Mdot
.558 .30597 Mdot
.558 .30597 Mdot
.558 .30598 Mdot
.558 .30598 Mdot
.558 .30598 Mdot
.558 .30598 Mdot
.558 .306 Mdot
.558 .30601 Mdot
.558 .30601 Mdot
.558 .30602 Mdot
.558 .30602 Mdot
.558 .30603 Mdot
.558 .30603 Mdot
.558 .30604 Mdot
.558 .30604 Mdot
.558 .30604 Mdot
.558 .30605 Mdot
.558 .30605 Mdot
.558 .30605 Mdot
.558 .30605 Mdot
.558 .30605 Mdot
.558 .30606 Mdot
.558 .30606 Mdot
.558 .30606 Mdot
.558 .30606 Mdot
.558 .30607 Mdot
.558 .30607 Mdot
.558 .30608 Mdot
.558 .30608 Mdot
.558 .30608 Mdot
.558 .30609 Mdot
.558 .3061 Mdot
.558 .3061 Mdot
.558 .3061 Mdot
.558 .3061 Mdot
.558 .30611 Mdot
.558 .30611 Mdot
.558 .30611 Mdot
.558 .30612 Mdot
.558 .30612 Mdot
.558 .30612 Mdot
.558 .30613 Mdot
.558 .30613 Mdot
.558 .30613 Mdot
.558 .30614 Mdot
.558 .30614 Mdot
.558 .30614 Mdot
.558 .30614 Mdot
.558 .30615 Mdot
.558 .30615 Mdot
.558 .30615 Mdot
.558 .30615 Mdot
.558 .30616 Mdot
.558 .30616 Mdot
.558 .30616 Mdot
.558 .30617 Mdot
.558 .30617 Mdot
.558 .30617 Mdot
.558 .30618 Mdot
.558 .30618 Mdot
.558 .30618 Mdot
.558 .30619 Mdot
.558 .30619 Mdot
.558 .3062 Mdot
.558 .3062 Mdot
.558 .3062 Mdot
.558 .3062 Mdot
.558 .3062 Mdot
.558 .30621 Mdot
.558 .30621 Mdot
.558 .30621 Mdot
.558 .30622 Mdot
.558 .30622 Mdot
.558 .30622 Mdot
.558 .30623 Mdot
.558 .30623 Mdot
.558 .30624 Mdot
.558 .30624 Mdot
.558 .30624 Mdot
.558 .30624 Mdot
.558 .30624 Mdot
.558 .30625 Mdot
.558 .30625 Mdot
.558 .30626 Mdot
.558 .30626 Mdot
.558 .30627 Mdot
.558 .30627 Mdot
.558 .30628 Mdot
.558 .30628 Mdot
.558 .30628 Mdot
.558 .30629 Mdot
.558 .30629 Mdot
.558 .30629 Mdot
.558 .3063 Mdot
.558 .3063 Mdot
.558 .3063 Mdot
.558 .3063 Mdot
.558 .30631 Mdot
.558 .30631 Mdot
.558 .30632 Mdot
.558 .30632 Mdot
.558 .30632 Mdot
.558 .30633 Mdot
.558 .30633 Mdot
.558 .30635 Mdot
.558 .30635 Mdot
.558 .30635 Mdot
.558 .30635 Mdot
.558 .30635 Mdot
.558 .30636 Mdot
.558 .30636 Mdot
.558 .30636 Mdot
.558 .30636 Mdot
.558 .30637 Mdot
.558 .30638 Mdot
.558 .30639 Mdot
.558 .30639 Mdot
.558 .30639 Mdot
.558 .30639 Mdot
.558 .30641 Mdot
.558 .30641 Mdot
.558 .30642 Mdot
.558 .30642 Mdot
.558 .30643 Mdot
.558 .30643 Mdot
.558 .30643 Mdot
.558 .30644 Mdot
.558 .30644 Mdot
.558 .30644 Mdot
.558 .30645 Mdot
.558 .30645 Mdot
.558 .30646 Mdot
.558 .30646 Mdot
.558 .30648 Mdot
.558 .30648 Mdot
.558 .30649 Mdot
.558 .3065 Mdot
.558 .3065 Mdot
.558 .30652 Mdot
.558 .30655 Mdot
.558 .30655 Mdot
.558 .30655 Mdot
.558 .30656 Mdot
.558 .30656 Mdot
.558 .30657 Mdot
.558 .30657 Mdot
.558 .30658 Mdot
.558 .30658 Mdot
.558 .30658 Mdot
.558 .30659 Mdot
.558 .30659 Mdot
.558 .3066 Mdot
.558 .3066 Mdot
.558 .30661 Mdot
.558 .30662 Mdot
.558 .30663 Mdot
.558 .30664 Mdot
.558 .30664 Mdot
.558 .30665 Mdot
.558 .30665 Mdot
.558 .30665 Mdot
.558 .30666 Mdot
.558 .30667 Mdot
.558 .3067 Mdot
.558 .3067 Mdot
.558 .30671 Mdot
.558 .30672 Mdot
.558 .30672 Mdot
.558 .30672 Mdot
.558 .30673 Mdot
.558 .30674 Mdot
.558 .30675 Mdot
.558 .30675 Mdot
.558 .30676 Mdot
.558 .30676 Mdot
.558 .30677 Mdot
.558 .30677 Mdot
.558 .30677 Mdot
.558 .30678 Mdot
.558 .30678 Mdot
.558 .30678 Mdot
.558 .30679 Mdot
.558 .30679 Mdot
.558 .3068 Mdot
.558 .3068 Mdot
.558 .30681 Mdot
.558 .30682 Mdot
.558 .30683 Mdot
.558 .30683 Mdot
.558 .30683 Mdot
.558 .30684 Mdot
.558 .30684 Mdot
.558 .30687 Mdot
.558 .30687 Mdot
.558 .30688 Mdot
.558 .30691 Mdot
.558 .30691 Mdot
.558 .30692 Mdot
.558 .30918 Mdot
.558 .30919 Mdot
.558 .3092 Mdot
.558 .30923 Mdot
.558 .30924 Mdot
.558 .30925 Mdot
.558 .30928 Mdot
.558 .30929 Mdot
.558 .30929 Mdot
.558 .3093 Mdot
.558 .3093 Mdot
.558 .30932 Mdot
.558 .30932 Mdot
.558 .30933 Mdot
.558 .30934 Mdot
.558 .30934 Mdot
.558 .30935 Mdot
.558 .30935 Mdot
.558 .30936 Mdot
.558 .30936 Mdot
.558 .30937 Mdot
.558 .30938 Mdot
.558 .30938 Mdot
.558 .30939 Mdot
.558 .30939 Mdot
.558 .30939 Mdot
.558 .30939 Mdot
.558 .30941 Mdot
.558 .30943 Mdot
.558 .30943 Mdot
.558 .30944 Mdot
.558 .30944 Mdot
.558 .30944 Mdot
.558 .30946 Mdot
.558 .30946 Mdot
.558 .30949 Mdot
.558 .30951 Mdot
.558 .30952 Mdot
.558 .30952 Mdot
.558 .30952 Mdot
.558 .30953 Mdot
.558 .30954 Mdot
.558 .30955 Mdot
.558 .30956 Mdot
.558 .30957 Mdot
.558 .30958 Mdot
.558 .30959 Mdot
.558 .30959 Mdot
.558 .3096 Mdot
.558 .30961 Mdot
.558 .30961 Mdot
.558 .30961 Mdot
.558 .30962 Mdot
.558 .30962 Mdot
.558 .30964 Mdot
.558 .30964 Mdot
.558 .30964 Mdot
.558 .30964 Mdot
.558 .30965 Mdot
.558 .30969 Mdot
.558 .30971 Mdot
.558 .30971 Mdot
.558 .30973 Mdot
.558 .30973 Mdot
.558 .30974 Mdot
.558 .30976 Mdot
.558 .30976 Mdot
.558 .30977 Mdot
.558 .30977 Mdot
.558 .30978 Mdot
.558 .30978 Mdot
.558 .30979 Mdot
.558 .30979 Mdot
.558 .30979 Mdot
.558 .30979 Mdot
.558 .30981 Mdot
.558 .30981 Mdot
.558 .30981 Mdot
.558 .30982 Mdot
.558 .30984 Mdot
.558 .30985 Mdot
.558 .30985 Mdot
.558 .30985 Mdot
.558 .30985 Mdot
.558 .30988 Mdot
.558 .30988 Mdot
.558 .30988 Mdot
.558 .30988 Mdot
.558 .30989 Mdot
.558 .30989 Mdot
.558 .3099 Mdot
.558 .3099 Mdot
.558 .3099 Mdot
.558 .3099 Mdot
.558 .30992 Mdot
.558 .30993 Mdot
.558 .30993 Mdot
.558 .30993 Mdot
.558 .30994 Mdot
.558 .30995 Mdot
.558 .30995 Mdot
.558 .30995 Mdot
.558 .30995 Mdot
.558 .30996 Mdot
.558 .30996 Mdot
.558 .30997 Mdot
.558 .30997 Mdot
.558 .30997 Mdot
.558 .30998 Mdot
.558 .30998 Mdot
.558 .30998 Mdot
.558 .31 Mdot
.558 .31 Mdot
.558 .31 Mdot
.558 .31001 Mdot
.558 .31001 Mdot
.558 .31002 Mdot
.558 .31003 Mdot
.558 .31003 Mdot
.558 .31003 Mdot
.558 .31003 Mdot
.558 .31004 Mdot
.558 .31004 Mdot
.558 .31005 Mdot
.558 .31005 Mdot
.558 .31006 Mdot
.558 .31006 Mdot
.558 .31007 Mdot
.558 .31007 Mdot
.558 .31007 Mdot
.558 .31008 Mdot
.558 .31008 Mdot
.558 .31008 Mdot
.558 .31008 Mdot
.558 .31009 Mdot
.558 .31009 Mdot
.558 .3101 Mdot
.558 .3101 Mdot
.558 .31011 Mdot
.558 .31011 Mdot
.558 .31011 Mdot
.558 .31012 Mdot
.558 .31012 Mdot
.558 .31013 Mdot
.558 .31013 Mdot
.558 .31013 Mdot
.558 .31014 Mdot
.558 .31014 Mdot
.558 .31015 Mdot
.558 .31015 Mdot
.558 .31015 Mdot
.558 .31015 Mdot
.558 .31016 Mdot
.558 .31016 Mdot
.558 .31016 Mdot
.558 .31017 Mdot
.558 .31017 Mdot
.558 .31018 Mdot
.558 .31018 Mdot
.558 .31018 Mdot
.558 .31019 Mdot
.558 .3102 Mdot
.558 .3102 Mdot
.558 .3102 Mdot
.558 .3102 Mdot
.558 .3102 Mdot
.558 .31021 Mdot
.558 .31022 Mdot
.558 .31023 Mdot
.558 .31023 Mdot
.558 .31023 Mdot
.558 .31024 Mdot
.558 .31025 Mdot
.558 .31025 Mdot
.558 .31025 Mdot
.558 .31026 Mdot
.558 .31026 Mdot
.558 .31026 Mdot
.558 .31027 Mdot
.558 .31027 Mdot
.558 .31027 Mdot
.558 .31027 Mdot
.558 .31028 Mdot
.558 .31028 Mdot
.558 .31028 Mdot
.558 .3103 Mdot
.558 .3103 Mdot
.558 .31031 Mdot
.558 .31031 Mdot
.558 .31032 Mdot
.558 .31033 Mdot
.558 .31036 Mdot
.558 .31036 Mdot
.558 .31036 Mdot
.558 .31036 Mdot
.558 .31036 Mdot
.558 .31037 Mdot
.558 .31037 Mdot
.558 .31038 Mdot
.558 .31038 Mdot
.558 .31038 Mdot
.558 .31039 Mdot
.558 .31039 Mdot
.558 .3104 Mdot
.558 .3104 Mdot
.558 .3104 Mdot
.558 .31041 Mdot
.558 .31042 Mdot
.558 .31043 Mdot
.558 .31043 Mdot
.558 .31044 Mdot
.558 .31044 Mdot
.558 .31044 Mdot
.558 .31044 Mdot
.558 .31045 Mdot
.558 .31048 Mdot
.558 .31048 Mdot
.558 .31049 Mdot
.558 .31049 Mdot
.558 .31049 Mdot
.558 .31049 Mdot
.558 .3105 Mdot
.558 .31051 Mdot
.558 .31052 Mdot
.558 .31052 Mdot
.558 .31052 Mdot
.558 .31052 Mdot
.558 .31053 Mdot
.558 .31053 Mdot
.558 .31053 Mdot
.558 .31054 Mdot
.558 .31054 Mdot
.558 .31055 Mdot
.558 .31055 Mdot
.558 .31055 Mdot
.558 .31056 Mdot
.558 .31056 Mdot
.558 .31057 Mdot
.558 .31057 Mdot
.558 .31058 Mdot
.558 .31058 Mdot
.558 .31058 Mdot
.558 .31059 Mdot
.558 .31059 Mdot
.558 .31061 Mdot
.558 .31062 Mdot
.558 .31063 Mdot
.558 .31065 Mdot
.558 .31065 Mdot
.558 .31065 Mdot
.558 .3395 Mdot
.558 .3395 Mdot
.558 .33951 Mdot
.558 .33953 Mdot
.558 .33953 Mdot
.558 .33954 Mdot
.558 .33956 Mdot
.558 .33956 Mdot
.558 .33956 Mdot
.558 .33956 Mdot
.558 .33957 Mdot
.558 .33957 Mdot
.558 .33958 Mdot
.558 .33958 Mdot
.558 .33959 Mdot
.558 .33959 Mdot
.558 .33959 Mdot
.558 .3396 Mdot
.558 .3396 Mdot
.558 .3396 Mdot
.558 .33961 Mdot
.558 .33961 Mdot
.558 .33961 Mdot
.558 .33962 Mdot
.558 .33962 Mdot
.558 .33962 Mdot
.558 .33962 Mdot
.558 .33963 Mdot
.558 .33964 Mdot
.558 .33964 Mdot
.558 .33964 Mdot
.558 .33965 Mdot
.558 .33965 Mdot
.558 .33966 Mdot
.558 .33966 Mdot
.558 .33968 Mdot
.558 .33969 Mdot
.558 .33969 Mdot
.558 .33969 Mdot
.558 .3397 Mdot
.558 .3397 Mdot
.558 .3397 Mdot
.558 .33971 Mdot
.558 .33971 Mdot
.558 .33972 Mdot
.558 .33973 Mdot
.558 .33973 Mdot
.558 .33973 Mdot
.558 .33974 Mdot
.558 .33974 Mdot
.558 .33974 Mdot
.558 .33975 Mdot
.558 .33975 Mdot
.558 .33975 Mdot
.558 .33976 Mdot
.558 .33976 Mdot
.558 .33976 Mdot
.558 .33976 Mdot
.558 .33977 Mdot
.558 .33979 Mdot
.558 .3398 Mdot
.558 .3398 Mdot
.558 .33981 Mdot
.558 .33982 Mdot
.558 .33982 Mdot
.558 .33983 Mdot
.558 .33983 Mdot
.558 .33984 Mdot
.558 .33984 Mdot
.558 .33984 Mdot
.558 .33984 Mdot
.558 .33985 Mdot
.558 .33985 Mdot
.558 .33985 Mdot
.558 .33985 Mdot
.558 .33986 Mdot
.558 .33986 Mdot
.558 .33986 Mdot
.558 .33987 Mdot
.558 .33988 Mdot
.558 .33988 Mdot
.558 .33988 Mdot
.558 .33988 Mdot
.558 .3399 Mdot
.558 .3399 Mdot
.558 .3399 Mdot
.558 .33991 Mdot
.558 .33991 Mdot
.558 .33991 Mdot
.558 .33991 Mdot
.558 .33992 Mdot
.558 .33993 Mdot
.558 .33993 Mdot
.558 .33993 Mdot
.558 .33993 Mdot
.558 .33994 Mdot
.558 .33994 Mdot
.558 .33994 Mdot
.558 .33995 Mdot
.558 .33995 Mdot
.558 .33995 Mdot
.558 .33995 Mdot
.558 .33996 Mdot
.558 .33996 Mdot
.558 .33997 Mdot
.558 .33997 Mdot
.558 .33997 Mdot
.558 .33998 Mdot
.558 .33998 Mdot
.558 .33998 Mdot
.558 .33999 Mdot
.558 .33999 Mdot
.558 .33999 Mdot
.558 .34 Mdot
.558 .34 Mdot
.558 .34001 Mdot
.558 .34001 Mdot
.558 .34001 Mdot
.558 .34001 Mdot
.558 .34002 Mdot
.558 .34002 Mdot
.558 .34002 Mdot
.558 .34003 Mdot
.558 .34003 Mdot
.558 .34004 Mdot
.558 .34004 Mdot
.558 .34004 Mdot
.558 .34005 Mdot
.558 .34005 Mdot
.558 .34006 Mdot
.558 .34006 Mdot
.558 .34006 Mdot
.558 .34006 Mdot
.558 .34006 Mdot
.558 .34007 Mdot
.558 .34008 Mdot
.558 .34008 Mdot
.558 .34009 Mdot
.558 .34009 Mdot
.558 .3401 Mdot
.558 .3401 Mdot
.558 .3401 Mdot
.558 .34011 Mdot
.558 .34011 Mdot
.558 .34011 Mdot
.558 .34012 Mdot
.558 .34012 Mdot
.558 .34013 Mdot
.558 .34013 Mdot
.558 .34013 Mdot
.558 .34013 Mdot
.558 .34014 Mdot
.558 .34015 Mdot
.558 .34015 Mdot
.558 .34015 Mdot
.558 .34016 Mdot
.558 .34018 Mdot
.558 .34018 Mdot
.558 .34018 Mdot
.558 .34018 Mdot
.558 .34018 Mdot
.558 .34019 Mdot
.558 .34019 Mdot
.558 .34019 Mdot
.558 .34019 Mdot
.558 .3402 Mdot
.558 .34022 Mdot
.558 .34022 Mdot
.558 .34022 Mdot
.558 .34022 Mdot
.558 .34023 Mdot
.558 .34025 Mdot
.558 .34025 Mdot
.558 .34025 Mdot
.558 .34026 Mdot
.558 .34027 Mdot
.558 .34027 Mdot
.558 .34027 Mdot
.558 .34028 Mdot
.558 .34028 Mdot
.558 .34029 Mdot
.558 .34029 Mdot
.558 .34029 Mdot
.558 .3403 Mdot
.558 .3403 Mdot
.558 .34032 Mdot
.558 .34033 Mdot
.558 .34033 Mdot
.558 .34034 Mdot
.558 .34035 Mdot
.558 .34037 Mdot
.558 .3404 Mdot
.558 .3404 Mdot
.558 .34041 Mdot
.558 .34041 Mdot
.558 .34041 Mdot
.558 .34042 Mdot
.558 .34043 Mdot
.558 .34043 Mdot
.558 .34044 Mdot
.558 .34044 Mdot
.558 .34044 Mdot
.558 .34045 Mdot
.558 .34046 Mdot
.558 .34046 Mdot
.558 .34047 Mdot
.558 .34048 Mdot
.558 .34049 Mdot
.558 .3405 Mdot
.558 .34051 Mdot
.558 .34051 Mdot
.558 .34051 Mdot
.558 .34052 Mdot
.558 .34052 Mdot
.558 .34054 Mdot
.558 .34057 Mdot
.558 .34057 Mdot
.558 .34058 Mdot
.558 .34059 Mdot
.558 .34059 Mdot
.558 .34059 Mdot
.558 .3406 Mdot
.558 .34061 Mdot
.558 .34063 Mdot
.558 .34063 Mdot
.558 .34063 Mdot
.558 .34063 Mdot
.558 .34064 Mdot
.558 .34065 Mdot
.558 .34065 Mdot
.558 .34066 Mdot
.558 .34066 Mdot
.558 .34066 Mdot
.558 .34067 Mdot
.558 .34067 Mdot
.558 .34068 Mdot
.558 .34068 Mdot
.558 .34069 Mdot
.558 .3407 Mdot
.558 .34071 Mdot
.558 .34072 Mdot
.558 .34072 Mdot
.558 .34073 Mdot
.558 .34073 Mdot
.558 .34076 Mdot
.558 .34076 Mdot
.558 .34078 Mdot
.558 .3408 Mdot
.558 .34081 Mdot
.558 .34082 Mdot
.558 .34284 Mdot
.558 .34285 Mdot
.558 .34285 Mdot
.558 .34288 Mdot
.558 .34289 Mdot
.558 .34289 Mdot
.558 .34292 Mdot
.558 .34292 Mdot
.558 .34292 Mdot
.558 .34293 Mdot
.558 .34293 Mdot
.558 .34294 Mdot
.558 .34294 Mdot
.558 .34295 Mdot
.558 .34295 Mdot
.558 .34296 Mdot
.558 .34296 Mdot
.558 .34297 Mdot
.558 .34297 Mdot
.558 .34297 Mdot
.558 .34298 Mdot
.558 .34298 Mdot
.558 .34298 Mdot
.558 .34299 Mdot
.558 .34299 Mdot
.558 .343 Mdot
.558 .343 Mdot
.558 .34301 Mdot
.558 .34302 Mdot
.558 .34302 Mdot
.558 .34303 Mdot
.558 .34303 Mdot
.558 .34303 Mdot
.558 .34304 Mdot
.558 .34304 Mdot
.558 .34307 Mdot
.558 .34308 Mdot
.558 .34309 Mdot
.558 .34309 Mdot
.558 .34309 Mdot
.558 .34309 Mdot
.558 .3431 Mdot
.558 .34311 Mdot
.558 .34311 Mdot
.558 .34312 Mdot
.558 .34313 Mdot
.558 .34313 Mdot
.558 .34314 Mdot
.558 .34314 Mdot
.558 .34315 Mdot
.558 .34315 Mdot
.558 .34315 Mdot
.558 .34316 Mdot
.558 .34316 Mdot
.558 .34317 Mdot
.558 .34317 Mdot
.558 .34317 Mdot
.558 .34318 Mdot
.558 .34318 Mdot
.558 .34321 Mdot
.558 .34322 Mdot
.558 .34322 Mdot
.558 .34323 Mdot
.558 .34324 Mdot
.558 .34324 Mdot
.558 .34326 Mdot
.558 .34326 Mdot
.558 .34326 Mdot
.558 .34327 Mdot
.558 .34327 Mdot
.558 .34327 Mdot
.558 .34328 Mdot
.558 .34328 Mdot
.558 .34328 Mdot
.558 .34328 Mdot
.558 .3433 Mdot
.558 .3433 Mdot
.558 .3433 Mdot
.558 .3433 Mdot
.558 .34332 Mdot
.558 .34332 Mdot
.558 .34332 Mdot
.558 .34332 Mdot
.558 .34334 Mdot
.558 .34335 Mdot
.558 .34335 Mdot
.558 .34335 Mdot
.558 .34335 Mdot
.558 .34335 Mdot
.558 .34336 Mdot
.558 .34336 Mdot
.558 .34336 Mdot
.558 .34336 Mdot
.558 .34337 Mdot
.558 .34338 Mdot
.558 .34338 Mdot
.558 .34338 Mdot
.558 .34339 Mdot
.558 .34339 Mdot
.558 .34339 Mdot
.558 .3434 Mdot
.558 .3434 Mdot
.558 .3434 Mdot
.558 .3434 Mdot
.558 .34341 Mdot
.558 .34341 Mdot
.558 .34341 Mdot
.558 .34342 Mdot
.558 .34342 Mdot
.558 .34342 Mdot
.558 .34343 Mdot
.558 .34343 Mdot
.558 .34343 Mdot
.558 .34344 Mdot
.558 .34344 Mdot
.558 .34345 Mdot
.558 .34345 Mdot
.558 .34345 Mdot
.558 .34345 Mdot
.558 .34346 Mdot
.558 .34346 Mdot
.558 .34346 Mdot
.558 .34347 Mdot
.558 .34347 Mdot
.558 .34347 Mdot
.558 .34347 Mdot
.558 .34348 Mdot
.558 .34348 Mdot
.558 .34349 Mdot
.558 .34349 Mdot
.558 .34349 Mdot
.558 .34349 Mdot
.558 .34349 Mdot
.558 .34349 Mdot
.558 .3435 Mdot
.558 .3435 Mdot
.558 .34351 Mdot
.558 .34351 Mdot
.558 .34351 Mdot
.558 .34351 Mdot
.558 .34352 Mdot
.558 .34352 Mdot
.558 .34352 Mdot
.558 .34353 Mdot
.558 .34353 Mdot
.558 .34353 Mdot
.558 .34353 Mdot
.558 .34354 Mdot
.558 .34354 Mdot
.558 .34354 Mdot
.558 .34354 Mdot
.558 .34355 Mdot
.558 .34355 Mdot
.558 .34355 Mdot
.558 .34355 Mdot
.558 .34356 Mdot
.558 .34356 Mdot
.558 .34356 Mdot
.558 .34356 Mdot
.558 .34357 Mdot
.558 .34357 Mdot
.558 .34357 Mdot
.558 .34358 Mdot
.558 .34358 Mdot
.558 .34358 Mdot
.558 .34358 Mdot
.558 .34359 Mdot
.558 .34359 Mdot
.558 .3436 Mdot
.558 .3436 Mdot
.558 .34361 Mdot
.558 .34361 Mdot
.558 .34361 Mdot
.558 .34361 Mdot
.558 .34362 Mdot
.558 .34362 Mdot
.558 .34362 Mdot
.558 .34362 Mdot
.558 .34363 Mdot
.558 .34363 Mdot
.558 .34363 Mdot
.558 .34363 Mdot
.558 .34363 Mdot
.558 .34364 Mdot
.558 .34365 Mdot
.558 .34365 Mdot
.558 .34365 Mdot
.558 .34365 Mdot
.558 .34366 Mdot
.558 .34366 Mdot
.558 .34367 Mdot
.558 .34369 Mdot
.558 .34369 Mdot
.558 .34369 Mdot
.558 .34369 Mdot
.558 .34369 Mdot
.558 .3437 Mdot
.558 .3437 Mdot
.558 .3437 Mdot
.558 .34371 Mdot
.558 .34371 Mdot
.558 .34371 Mdot
.558 .34371 Mdot
.558 .34372 Mdot
.558 .34372 Mdot
.558 .34372 Mdot
.558 .34373 Mdot
.558 .34373 Mdot
.558 .34374 Mdot
.558 .34374 Mdot
.558 .34374 Mdot
.558 .34375 Mdot
.558 .34375 Mdot
.558 .34375 Mdot
.558 .34376 Mdot
.558 .34378 Mdot
.558 .34378 Mdot
.558 .34378 Mdot
.558 .34379 Mdot
.558 .34379 Mdot
.558 .34379 Mdot
.558 .34379 Mdot
.558 .3438 Mdot
.558 .34381 Mdot
.558 .34381 Mdot
.558 .34381 Mdot
.558 .34381 Mdot
.558 .34381 Mdot
.558 .34381 Mdot
.558 .34382 Mdot
.558 .34382 Mdot
.558 .34382 Mdot
.558 .34382 Mdot
.558 .34383 Mdot
.558 .34383 Mdot
.558 .34383 Mdot
.558 .34383 Mdot
.558 .34384 Mdot
.558 .34384 Mdot
.558 .34385 Mdot
.558 .34385 Mdot
.558 .34385 Mdot
.558 .34386 Mdot
.558 .34386 Mdot
.558 .34387 Mdot
.558 .34388 Mdot
.558 .34388 Mdot
.558 .3439 Mdot
.558 .3439 Mdot
.558 .3439 Mdot
.56 .30545 Mdot
.56 .30546 Mdot
.56 .30546 Mdot
.56 .30547 Mdot
.56 .30547 Mdot
.56 .30547 Mdot
.56 .30548 Mdot
.56 .30548 Mdot
.56 .30548 Mdot
.56 .30549 Mdot
.56 .30549 Mdot
.56 .3055 Mdot
.56 .3055 Mdot
.56 .3055 Mdot
.56 .3055 Mdot
.56 .30551 Mdot
.56 .30551 Mdot
.56 .30551 Mdot
.56 .30552 Mdot
.56 .30555 Mdot
.56 .30555 Mdot
.56 .30555 Mdot
.56 .30556 Mdot
.56 .30557 Mdot
.56 .30558 Mdot
.56 .30558 Mdot
.56 .30559 Mdot
.56 .30559 Mdot
.56 .3056 Mdot
.56 .3056 Mdot
.56 .3056 Mdot
.56 .3056 Mdot
.56 .3056 Mdot
.56 .30563 Mdot
.56 .30563 Mdot
.56 .30564 Mdot
.56 .30564 Mdot
.56 .30564 Mdot
.56 .30564 Mdot
.56 .30565 Mdot
.56 .30565 Mdot
.56 .30565 Mdot
.56 .30566 Mdot
.56 .30566 Mdot
.56 .30567 Mdot
.56 .30567 Mdot
.56 .30567 Mdot
.56 .30567 Mdot
.56 .30567 Mdot
.56 .30567 Mdot
.56 .30568 Mdot
.56 .30568 Mdot
.56 .30569 Mdot
.56 .30569 Mdot
.56 .30569 Mdot
.56 .3057 Mdot
.56 .3057 Mdot
.56 .3057 Mdot
.56 .3057 Mdot
.56 .3057 Mdot
.56 .30571 Mdot
.56 .30571 Mdot
.56 .30572 Mdot
.56 .30572 Mdot
.56 .30573 Mdot
.56 .30574 Mdot
.56 .30574 Mdot
.56 .30574 Mdot
.56 .30574 Mdot
.56 .30575 Mdot
.56 .30575 Mdot
.56 .30575 Mdot
.56 .30575 Mdot
.56 .30575 Mdot
.56 .30576 Mdot
.56 .30577 Mdot
.56 .30577 Mdot
.56 .30577 Mdot
.56 .30578 Mdot
.56 .30578 Mdot
.56 .30578 Mdot
.56 .30578 Mdot
.56 .30579 Mdot
.56 .3058 Mdot
.56 .3058 Mdot
.56 .3058 Mdot
.56 .30583 Mdot
.56 .30584 Mdot
.56 .30584 Mdot
.56 .30585 Mdot
.56 .30585 Mdot
.56 .30585 Mdot
.56 .30586 Mdot
.56 .30586 Mdot
.56 .30587 Mdot
.56 .30587 Mdot
.56 .30588 Mdot
.56 .30589 Mdot
.56 .30589 Mdot
.56 .30589 Mdot
.56 .3059 Mdot
.56 .30591 Mdot
.56 .30593 Mdot
.56 .30594 Mdot
.56 .30594 Mdot
.56 .30594 Mdot
.56 .30595 Mdot
.56 .30596 Mdot
.56 .30596 Mdot
.56 .30596 Mdot
.56 .30597 Mdot
.56 .30597 Mdot
.56 .30597 Mdot
.56 .30597 Mdot
.56 .30598 Mdot
.56 .30598 Mdot
.56 .30598 Mdot
.56 .30598 Mdot
.56 .30598 Mdot
.56 .30599 Mdot
.56 .30599 Mdot
.56 .306 Mdot
.56 .306 Mdot
.56 .30602 Mdot
.56 .30603 Mdot
.56 .30603 Mdot
.56 .30604 Mdot
.56 .30605 Mdot
.56 .30605 Mdot
.56 .30607 Mdot
.56 .30608 Mdot
.56 .30608 Mdot
.56 .30609 Mdot
.56 .3061 Mdot
.56 .3061 Mdot
.56 .3061 Mdot
.56 .3061 Mdot
.56 .30611 Mdot
.56 .30611 Mdot
.56 .30611 Mdot
.56 .30612 Mdot
.56 .30612 Mdot
.56 .30612 Mdot
.56 .30613 Mdot
.56 .30614 Mdot
.56 .30614 Mdot
.56 .30615 Mdot
.56 .30615 Mdot
.56 .30615 Mdot
.56 .30615 Mdot
.56 .30616 Mdot
.56 .30617 Mdot
.56 .30617 Mdot
.56 .30617 Mdot
.56 .30617 Mdot
.56 .30618 Mdot
.56 .30618 Mdot
.56 .30619 Mdot
.56 .30619 Mdot
.56 .30619 Mdot
.56 .30619 Mdot
.56 .30621 Mdot
.56 .30622 Mdot
.56 .30624 Mdot
.56 .30625 Mdot
.56 .30625 Mdot
.56 .30627 Mdot
.56 .30628 Mdot
.56 .30628 Mdot
.56 .30628 Mdot
.56 .30628 Mdot
.56 .3063 Mdot
.56 .3063 Mdot
.56 .3063 Mdot
.56 .30631 Mdot
.56 .30632 Mdot
.56 .30633 Mdot
.56 .30633 Mdot
.56 .30633 Mdot
.56 .30633 Mdot
.56 .30634 Mdot
.56 .30634 Mdot
.56 .30635 Mdot
.56 .30635 Mdot
.56 .30635 Mdot
.56 .30638 Mdot
.56 .30638 Mdot
.56 .30639 Mdot
.56 .3064 Mdot
.56 .3064 Mdot
.56 .3064 Mdot
.56 .30641 Mdot
.56 .30641 Mdot
.56 .30641 Mdot
.56 .30642 Mdot
.56 .30643 Mdot
.56 .30643 Mdot
.56 .30644 Mdot
.56 .30644 Mdot
.56 .30645 Mdot
.56 .30645 Mdot
.56 .30645 Mdot
.56 .30646 Mdot
.56 .30646 Mdot
.56 .30646 Mdot
.56 .30646 Mdot
.56 .30647 Mdot
.56 .30647 Mdot
.56 .30648 Mdot
.56 .30649 Mdot
.56 .3065 Mdot
.56 .3065 Mdot
.56 .3065 Mdot
.56 .3065 Mdot
.56 .3065 Mdot
.56 .30652 Mdot
.56 .30652 Mdot
.56 .30656 Mdot
.56 .30656 Mdot
.56 .30656 Mdot
.56 .30657 Mdot
.56 .30657 Mdot
.56 .30657 Mdot
.56 .30658 Mdot
.56 .30659 Mdot
.56 .3066 Mdot
.56 .30662 Mdot
.56 .30662 Mdot
.56 .30664 Mdot
.56 .30665 Mdot
.56 .30665 Mdot
.56 .30669 Mdot
.56 .30671 Mdot
.56 .30671 Mdot
.56 .30671 Mdot
.56 .30672 Mdot
.56 .30672 Mdot
.56 .30672 Mdot
.56 .30673 Mdot
.56 .30674 Mdot
.56 .30674 Mdot
.56 .30675 Mdot
.56 .30675 Mdot
.56 .30675 Mdot
.56 .30677 Mdot
.56 .30677 Mdot
.56 .30677 Mdot
.56 .30678 Mdot
.56 .30678 Mdot
.56 .3068 Mdot
.56 .30908 Mdot
.56 .30911 Mdot
.56 .30911 Mdot
.56 .30912 Mdot
.56 .30912 Mdot
.56 .30912 Mdot
.56 .30914 Mdot
.56 .30914 Mdot
.56 .30915 Mdot
.56 .30916 Mdot
.56 .30916 Mdot
.56 .30917 Mdot
.56 .30918 Mdot
.56 .30918 Mdot
.56 .30918 Mdot
.56 .30919 Mdot
.56 .30919 Mdot
.56 .3092 Mdot
.56 .30921 Mdot
.56 .30927 Mdot
.56 .30928 Mdot
.56 .30928 Mdot
.56 .30931 Mdot
.56 .30931 Mdot
.56 .30934 Mdot
.56 .30934 Mdot
.56 .30936 Mdot
.56 .30936 Mdot
.56 .30937 Mdot
.56 .30938 Mdot
.56 .30938 Mdot
.56 .30938 Mdot
.56 .30938 Mdot
.56 .30943 Mdot
.56 .30944 Mdot
.56 .30945 Mdot
.56 .30946 Mdot
.56 .30946 Mdot
.56 .30946 Mdot
.56 .30946 Mdot
.56 .30947 Mdot
.56 .30948 Mdot
.56 .30949 Mdot
.56 .3095 Mdot
.56 .3095 Mdot
.56 .30951 Mdot
.56 .30951 Mdot
.56 .30951 Mdot
.56 .30952 Mdot
.56 .30952 Mdot
.56 .30952 Mdot
.56 .30953 Mdot
.56 .30954 Mdot
.56 .30954 Mdot
.56 .30955 Mdot
.56 .30955 Mdot
.56 .30957 Mdot
.56 .30957 Mdot
.56 .30958 Mdot
.56 .30958 Mdot
.56 .30958 Mdot
.56 .30959 Mdot
.56 .30959 Mdot
.56 .3096 Mdot
.56 .3096 Mdot
.56 .30964 Mdot
.56 .30965 Mdot
.56 .30965 Mdot
.56 .30966 Mdot
.56 .30966 Mdot
.56 .30967 Mdot
.56 .30967 Mdot
.56 .30967 Mdot
.56 .30968 Mdot
.56 .30968 Mdot
.56 .3097 Mdot
.56 .30971 Mdot
.56 .30971 Mdot
.56 .30971 Mdot
.56 .30973 Mdot
.56 .30973 Mdot
.56 .30974 Mdot
.56 .30974 Mdot
.56 .30974 Mdot
.56 .30978 Mdot
.56 .30978 Mdot
.56 .30978 Mdot
.56 .30981 Mdot
.56 .30982 Mdot
.56 .30985 Mdot
.56 .30985 Mdot
.56 .30985 Mdot
.56 .30985 Mdot
.56 .30987 Mdot
.56 .30987 Mdot
.56 .30987 Mdot
.56 .30987 Mdot
.56 .30987 Mdot
.56 .30988 Mdot
.56 .30989 Mdot
.56 .3099 Mdot
.56 .3099 Mdot
.56 .3099 Mdot
.56 .3099 Mdot
.56 .3099 Mdot
.56 .30991 Mdot
.56 .30993 Mdot
.56 .30993 Mdot
.56 .30993 Mdot
.56 .30994 Mdot
.56 .30995 Mdot
.56 .30995 Mdot
.56 .30995 Mdot
.56 .30996 Mdot
.56 .30996 Mdot
.56 .30996 Mdot
.56 .30997 Mdot
.56 .30998 Mdot
.56 .30998 Mdot
.56 .30998 Mdot
.56 .31 Mdot
.56 .31002 Mdot
.56 .31003 Mdot
.56 .31004 Mdot
.56 .31005 Mdot
.56 .31005 Mdot
.56 .31006 Mdot
.56 .31008 Mdot
.56 .31009 Mdot
.56 .31009 Mdot
.56 .3101 Mdot
.56 .31011 Mdot
.56 .31011 Mdot
.56 .31011 Mdot
.56 .31011 Mdot
.56 .31011 Mdot
.56 .31012 Mdot
.56 .31012 Mdot
.56 .31012 Mdot
.56 .31013 Mdot
.56 .31013 Mdot
.56 .31013 Mdot
.56 .31014 Mdot
.56 .31015 Mdot
.56 .31016 Mdot
.56 .31016 Mdot
.56 .31016 Mdot
.56 .31017 Mdot
.56 .3102 Mdot
.56 .31021 Mdot
.56 .31022 Mdot
.56 .31022 Mdot
.56 .31023 Mdot
.56 .31023 Mdot
.56 .31025 Mdot
.56 .31025 Mdot
.56 .31026 Mdot
.56 .31026 Mdot
.56 .31027 Mdot
.56 .31027 Mdot
.56 .31028 Mdot
.56 .31028 Mdot
.56 .31029 Mdot
.56 .3103 Mdot
.56 .31033 Mdot
.56 .31033 Mdot
.56 .31033 Mdot
.56 .31035 Mdot
.56 .31036 Mdot
.56 .31036 Mdot
.56 .31036 Mdot
.56 .31036 Mdot
.56 .31037 Mdot
.56 .31038 Mdot
.56 .31038 Mdot
.56 .31038 Mdot
.56 .31039 Mdot
.56 .3104 Mdot
.56 .3104 Mdot
.56 .3104 Mdot
.56 .3104 Mdot
.56 .31041 Mdot
.56 .31041 Mdot
.56 .31041 Mdot
.56 .31042 Mdot
.56 .31042 Mdot
.56 .31044 Mdot
.56 .31044 Mdot
.56 .31045 Mdot
.56 .31045 Mdot
.56 .31046 Mdot
.56 .31046 Mdot
.56 .31046 Mdot
.56 .31046 Mdot
.56 .31046 Mdot
.56 .31047 Mdot
.56 .31048 Mdot
.56 .31048 Mdot
.56 .31048 Mdot
.56 .31049 Mdot
.56 .3105 Mdot
.56 .3105 Mdot
.56 .3105 Mdot
.56 .3105 Mdot
.56 .3105 Mdot
.56 .3105 Mdot
.56 .31051 Mdot
.56 .31051 Mdot
.56 .31051 Mdot
.56 .31052 Mdot
.56 .31053 Mdot
.56 .31053 Mdot
.56 .31054 Mdot
.56 .31054 Mdot
.56 .31054 Mdot
.56 .31054 Mdot
.56 .31055 Mdot
.56 .31055 Mdot
.56 .31058 Mdot
.56 .31058 Mdot
.56 .31059 Mdot
.56 .31059 Mdot
.56 .31059 Mdot
.56 .31059 Mdot
.56 .3106 Mdot
.56 .31061 Mdot
.56 .31061 Mdot
.56 .31063 Mdot
.56 .31063 Mdot
.56 .31065 Mdot
.56 .31065 Mdot
.56 .31065 Mdot
.56 .31069 Mdot
.56 .3107 Mdot
.56 .31071 Mdot
.56 .31071 Mdot
.56 .31071 Mdot
.56 .31071 Mdot
.56 .31071 Mdot
.56 .31072 Mdot
.56 .31072 Mdot
.56 .31073 Mdot
.56 .31073 Mdot
.56 .31074 Mdot
.56 .31074 Mdot
.56 .31075 Mdot
.56 .31075 Mdot
.56 .31075 Mdot
.56 .31076 Mdot
.56 .31076 Mdot
.56 .31077 Mdot
.56 .34034 Mdot
.56 .34035 Mdot
.56 .34035 Mdot
.56 .34036 Mdot
.56 .34036 Mdot
.56 .34036 Mdot
.56 .34037 Mdot
.56 .34037 Mdot
.56 .34038 Mdot
.56 .34038 Mdot
.56 .34038 Mdot
.56 .34039 Mdot
.56 .34039 Mdot
.56 .34039 Mdot
.56 .3404 Mdot
.56 .3404 Mdot
.56 .3404 Mdot
.56 .34041 Mdot
.56 .34042 Mdot
.56 .34045 Mdot
.56 .34045 Mdot
.56 .34045 Mdot
.56 .34047 Mdot
.56 .34047 Mdot
.56 .34049 Mdot
.56 .34049 Mdot
.56 .3405 Mdot
.56 .3405 Mdot
.56 .3405 Mdot
.56 .34051 Mdot
.56 .34051 Mdot
.56 .34051 Mdot
.56 .34051 Mdot
.56 .34054 Mdot
.56 .34054 Mdot
.56 .34055 Mdot
.56 .34055 Mdot
.56 .34055 Mdot
.56 .34055 Mdot
.56 .34056 Mdot
.56 .34056 Mdot
.56 .34057 Mdot
.56 .34057 Mdot
.56 .34057 Mdot
.56 .34058 Mdot
.56 .34058 Mdot
.56 .34058 Mdot
.56 .34059 Mdot
.56 .34059 Mdot
.56 .34059 Mdot
.56 .3406 Mdot
.56 .3406 Mdot
.56 .3406 Mdot
.56 .34061 Mdot
.56 .34061 Mdot
.56 .34062 Mdot
.56 .34062 Mdot
.56 .34062 Mdot
.56 .34062 Mdot
.56 .34062 Mdot
.56 .34063 Mdot
.56 .34063 Mdot
.56 .34064 Mdot
.56 .34064 Mdot
.56 .34066 Mdot
.56 .34066 Mdot
.56 .34066 Mdot
.56 .34067 Mdot
.56 .34067 Mdot
.56 .34067 Mdot
.56 .34067 Mdot
.56 .34067 Mdot
.56 .34068 Mdot
.56 .34068 Mdot
.56 .34069 Mdot
.56 .3407 Mdot
.56 .3407 Mdot
.56 .3407 Mdot
.56 .34071 Mdot
.56 .34071 Mdot
.56 .34071 Mdot
.56 .34071 Mdot
.56 .34071 Mdot
.56 .34073 Mdot
.56 .34073 Mdot
.56 .34074 Mdot
.56 .34076 Mdot
.56 .34078 Mdot
.56 .34078 Mdot
.56 .34078 Mdot
.56 .34079 Mdot
.56 .34079 Mdot
.56 .3408 Mdot
.56 .3408 Mdot
.56 .3408 Mdot
.56 .34081 Mdot
.56 .34082 Mdot
.56 .34083 Mdot
.56 .34083 Mdot
.56 .34083 Mdot
.56 .34084 Mdot
.56 .34085 Mdot
.56 .34088 Mdot
.56 .34088 Mdot
.56 .34089 Mdot
.56 .34089 Mdot
.56 .3409 Mdot
.56 .34091 Mdot
.56 .34091 Mdot
.56 .34091 Mdot
.56 .34092 Mdot
.56 .34092 Mdot
.56 .34092 Mdot
.56 .34092 Mdot
.56 .34093 Mdot
.56 .34093 Mdot
.56 .34093 Mdot
.56 .34093 Mdot
.56 .34094 Mdot
.56 .34094 Mdot
.56 .34095 Mdot
.56 .34095 Mdot
.56 .34096 Mdot
.56 .34098 Mdot
.56 .34099 Mdot
.56 .34099 Mdot
.56 .34099 Mdot
.56 .341 Mdot
.56 .34101 Mdot
.56 .34103 Mdot
.56 .34105 Mdot
.56 .34105 Mdot
.56 .34105 Mdot
.56 .34106 Mdot
.56 .34106 Mdot
.56 .34107 Mdot
.56 .34107 Mdot
.56 .34107 Mdot
.56 .34107 Mdot
.56 .34108 Mdot
.56 .34108 Mdot
.56 .34109 Mdot
.56 .34109 Mdot
.56 .3411 Mdot
.56 .34111 Mdot
.56 .34112 Mdot
.56 .34112 Mdot
.56 .34112 Mdot
.56 .34112 Mdot
.56 .34112 Mdot
.56 .34113 Mdot
.56 .34114 Mdot
.56 .34114 Mdot
.56 .34115 Mdot
.56 .34115 Mdot
.56 .34115 Mdot
.56 .34115 Mdot
.56 .34116 Mdot
.56 .34116 Mdot
.56 .34116 Mdot
.56 .34117 Mdot
.56 .34119 Mdot
.56 .3412 Mdot
.56 .34123 Mdot
.56 .34123 Mdot
.56 .34123 Mdot
.56 .34126 Mdot
.56 .34126 Mdot
.56 .34127 Mdot
.56 .34127 Mdot
.56 .34127 Mdot
.56 .34129 Mdot
.56 .34129 Mdot
.56 .34129 Mdot
.56 .3413 Mdot
.56 .34132 Mdot
.56 .34132 Mdot
.56 .34132 Mdot
.56 .34133 Mdot
.56 .34133 Mdot
.56 .34134 Mdot
.56 .34134 Mdot
.56 .34134 Mdot
.56 .34135 Mdot
.56 .34135 Mdot
.56 .34138 Mdot
.56 .34138 Mdot
.56 .3414 Mdot
.56 .3414 Mdot
.56 .3414 Mdot
.56 .34141 Mdot
.56 .34141 Mdot
.56 .34141 Mdot
.56 .34141 Mdot
.56 .34143 Mdot
.56 .34143 Mdot
.56 .34144 Mdot
.56 .34144 Mdot
.56 .34145 Mdot
.56 .34146 Mdot
.56 .34146 Mdot
.56 .34146 Mdot
.56 .34147 Mdot
.56 .34147 Mdot
.56 .34147 Mdot
.56 .34147 Mdot
.56 .34148 Mdot
.56 .34148 Mdot
.56 .34149 Mdot
.56 .3415 Mdot
.56 .34151 Mdot
.56 .34152 Mdot
.56 .34152 Mdot
.56 .34152 Mdot
.56 .34152 Mdot
.56 .34153 Mdot
.56 .34154 Mdot
.56 .34158 Mdot
.56 .34158 Mdot
.56 .34159 Mdot
.56 .34159 Mdot
.56 .34159 Mdot
.56 .3416 Mdot
.56 .3416 Mdot
.56 .34162 Mdot
.56 .34162 Mdot
.56 .34165 Mdot
.56 .34165 Mdot
.56 .34167 Mdot
.56 .34168 Mdot
.56 .34168 Mdot
.56 .34173 Mdot
.56 .34174 Mdot
.56 .34175 Mdot
.56 .34175 Mdot
.56 .34176 Mdot
.56 .34177 Mdot
.56 .34177 Mdot
.56 .34177 Mdot
.56 .34178 Mdot
.56 .34178 Mdot
.56 .34179 Mdot
.56 .3418 Mdot
.56 .3418 Mdot
.56 .34181 Mdot
.56 .34182 Mdot
.56 .34182 Mdot
.56 .34183 Mdot
.56 .34183 Mdot
.56 .34185 Mdot
.56 .34389 Mdot
.56 .34391 Mdot
.56 .34391 Mdot
.56 .34391 Mdot
.56 .34391 Mdot
.56 .34392 Mdot
.56 .34393 Mdot
.56 .34393 Mdot
.56 .34393 Mdot
.56 .34394 Mdot
.56 .34394 Mdot
.56 .34395 Mdot
.56 .34396 Mdot
.56 .34396 Mdot
.56 .34396 Mdot
.56 .34396 Mdot
.56 .34396 Mdot
.56 .34397 Mdot
.56 .34398 Mdot
.56 .34402 Mdot
.56 .34403 Mdot
.56 .34403 Mdot
.56 .34405 Mdot
.56 .34405 Mdot
.56 .34407 Mdot
.56 .34407 Mdot
.56 .34409 Mdot
.56 .34409 Mdot
.56 .34409 Mdot
.56 .3441 Mdot
.56 .3441 Mdot
.56 .3441 Mdot
.56 .3441 Mdot
.56 .34413 Mdot
.56 .34414 Mdot
.56 .34415 Mdot
.56 .34415 Mdot
.56 .34415 Mdot
.56 .34415 Mdot
.56 .34416 Mdot
.56 .34416 Mdot
.56 .34417 Mdot
.56 .34418 Mdot
.56 .34418 Mdot
.56 .34419 Mdot
.56 .34419 Mdot
.56 .34419 Mdot
.56 .34419 Mdot
.56 .3442 Mdot
.56 .3442 Mdot
.56 .3442 Mdot
.56 .34421 Mdot
.56 .34421 Mdot
.56 .34422 Mdot
.56 .34422 Mdot
.56 .34422 Mdot
.56 .34424 Mdot
.56 .34424 Mdot
.56 .34424 Mdot
.56 .34424 Mdot
.56 .34424 Mdot
.56 .34425 Mdot
.56 .34425 Mdot
.56 .34426 Mdot
.56 .34426 Mdot
.56 .34429 Mdot
.56 .34429 Mdot
.56 .34429 Mdot
.56 .3443 Mdot
.56 .3443 Mdot
.56 .34431 Mdot
.56 .34431 Mdot
.56 .34431 Mdot
.56 .34431 Mdot
.56 .34431 Mdot
.56 .34433 Mdot
.56 .34433 Mdot
.56 .34433 Mdot
.56 .34434 Mdot
.56 .34435 Mdot
.56 .34435 Mdot
.56 .34435 Mdot
.56 .34435 Mdot
.56 .34436 Mdot
.56 .34438 Mdot
.56 .34438 Mdot
.56 .34438 Mdot
.56 .34441 Mdot
.56 .34441 Mdot
.56 .34443 Mdot
.56 .34443 Mdot
.56 .34443 Mdot
.56 .34444 Mdot
.56 .34445 Mdot
.56 .34445 Mdot
.56 .34445 Mdot
.56 .34445 Mdot
.56 .34445 Mdot
.56 .34445 Mdot
.56 .34446 Mdot
.56 .34447 Mdot
.56 .34447 Mdot
.56 .34447 Mdot
.56 .34447 Mdot
.56 .34447 Mdot
.56 .34448 Mdot
.56 .34449 Mdot
.56 .34449 Mdot
.56 .34449 Mdot
.56 .3445 Mdot
.56 .3445 Mdot
.56 .34451 Mdot
.56 .34451 Mdot
.56 .34451 Mdot
.56 .34451 Mdot
.56 .34451 Mdot
.56 .34452 Mdot
.56 .34453 Mdot
.56 .34453 Mdot
.56 .34453 Mdot
.56 .34454 Mdot
.56 .34455 Mdot
.56 .34456 Mdot
.56 .34457 Mdot
.56 .34457 Mdot
.56 .34458 Mdot
.56 .34458 Mdot
.56 .3446 Mdot
.56 .3446 Mdot
.56 .34461 Mdot
.56 .34461 Mdot
.56 .34462 Mdot
.56 .34462 Mdot
.56 .34462 Mdot
.56 .34462 Mdot
.56 .34462 Mdot
.56 .34463 Mdot
.56 .34463 Mdot
.56 .34463 Mdot
.56 .34463 Mdot
.56 .34463 Mdot
.56 .34464 Mdot
.56 .34464 Mdot
.56 .34465 Mdot
.56 .34465 Mdot
.56 .34466 Mdot
.56 .34466 Mdot
.56 .34466 Mdot
.56 .34469 Mdot
.56 .34469 Mdot
.56 .3447 Mdot
.56 .3447 Mdot
.56 .3447 Mdot
.56 .34471 Mdot
.56 .34472 Mdot
.56 .34472 Mdot
.56 .34472 Mdot
.56 .34473 Mdot
.56 .34473 Mdot
.56 .34473 Mdot
.56 .34474 Mdot
.56 .34474 Mdot
.56 .34474 Mdot
.56 .34476 Mdot
.56 .34478 Mdot
.56 .34478 Mdot
.56 .34478 Mdot
.56 .34479 Mdot
.56 .34479 Mdot
.56 .3448 Mdot
.56 .3448 Mdot
.56 .3448 Mdot
.56 .34481 Mdot
.56 .34481 Mdot
.56 .34481 Mdot
.56 .34481 Mdot
.56 .34482 Mdot
.56 .34482 Mdot
.56 .34483 Mdot
.56 .34483 Mdot
.56 .34483 Mdot
.56 .34483 Mdot
.56 .34483 Mdot
.56 .34483 Mdot
.56 .34484 Mdot
.56 .34484 Mdot
.56 .34486 Mdot
.56 .34486 Mdot
.56 .34486 Mdot
.56 .34486 Mdot
.56 .34487 Mdot
.56 .34487 Mdot
.56 .34487 Mdot
.56 .34487 Mdot
.56 .34487 Mdot
.56 .34488 Mdot
.56 .34488 Mdot
.56 .34488 Mdot
.56 .34489 Mdot
.56 .34489 Mdot
.56 .34489 Mdot
.56 .34489 Mdot
.56 .34489 Mdot
.56 .3449 Mdot
.56 .3449 Mdot
.56 .3449 Mdot
.56 .3449 Mdot
.56 .34491 Mdot
.56 .34491 Mdot
.56 .34492 Mdot
.56 .34492 Mdot
.56 .34492 Mdot
.56 .34492 Mdot
.56 .34492 Mdot
.56 .34492 Mdot
.56 .34493 Mdot
.56 .34493 Mdot
.56 .34496 Mdot
.56 .34496 Mdot
.56 .34496 Mdot
.56 .34496 Mdot
.56 .34496 Mdot
.56 .34496 Mdot
.56 .34496 Mdot
.56 .34497 Mdot
.56 .34498 Mdot
.56 .34499 Mdot
.56 .34499 Mdot
.56 .345 Mdot
.56 .345 Mdot
.56 .34501 Mdot
.56 .34503 Mdot
.56 .34504 Mdot
.56 .34504 Mdot
.56 .34504 Mdot
.56 .34505 Mdot
.56 .34505 Mdot
.56 .34505 Mdot
.56 .34505 Mdot
.56 .34506 Mdot
.56 .34506 Mdot
.56 .34506 Mdot
.56 .34506 Mdot
.56 .34507 Mdot
.56 .34507 Mdot
.56 .34507 Mdot
.56 .34508 Mdot
.56 .34508 Mdot
.56 .34508 Mdot
.56 .34509 Mdot
.562 .30517 Mdot
.562 .30518 Mdot
.562 .3052 Mdot
.562 .30521 Mdot
.562 .30521 Mdot
.562 .30522 Mdot
.562 .30522 Mdot
.562 .30522 Mdot
.562 .30522 Mdot
.562 .30524 Mdot
.562 .30525 Mdot
.562 .30526 Mdot
.562 .30526 Mdot
.562 .30526 Mdot
.562 .30527 Mdot
.562 .30527 Mdot
.562 .30528 Mdot
.562 .30528 Mdot
.562 .30529 Mdot
.562 .30529 Mdot
.562 .30529 Mdot
.562 .30529 Mdot
.562 .3053 Mdot
.562 .30531 Mdot
.562 .30531 Mdot
.562 .30533 Mdot
.562 .30533 Mdot
.562 .30533 Mdot
.562 .30534 Mdot
.562 .30534 Mdot
.562 .30534 Mdot
.562 .30535 Mdot
.562 .30536 Mdot
.562 .30536 Mdot
.562 .30537 Mdot
.562 .30538 Mdot
.562 .30538 Mdot
.562 .30538 Mdot
.562 .30538 Mdot
.562 .30539 Mdot
.562 .30539 Mdot
.562 .30539 Mdot
.562 .3054 Mdot
.562 .30542 Mdot
.562 .30543 Mdot
.562 .30543 Mdot
.562 .30544 Mdot
.562 .30544 Mdot
.562 .30544 Mdot
.562 .30545 Mdot
.562 .30546 Mdot
.562 .30546 Mdot
.562 .30546 Mdot
.562 .30547 Mdot
.562 .30547 Mdot
.562 .30547 Mdot
.562 .30548 Mdot
.562 .30548 Mdot
.562 .30548 Mdot
.562 .30548 Mdot
.562 .30549 Mdot
.562 .30549 Mdot
.562 .30549 Mdot
.562 .30549 Mdot
.562 .3055 Mdot
.562 .30551 Mdot
.562 .30551 Mdot
.562 .30554 Mdot
.562 .30554 Mdot
.562 .30556 Mdot
.562 .30556 Mdot
.562 .30557 Mdot
.562 .30557 Mdot
.562 .30558 Mdot
.562 .30558 Mdot
.562 .30558 Mdot
.562 .30559 Mdot
.562 .30559 Mdot
.562 .3056 Mdot
.562 .3056 Mdot
.562 .3056 Mdot
.562 .30561 Mdot
.562 .30562 Mdot
.562 .30562 Mdot
.562 .30562 Mdot
.562 .30563 Mdot
.562 .30563 Mdot
.562 .30564 Mdot
.562 .30564 Mdot
.562 .30564 Mdot
.562 .30564 Mdot
.562 .30565 Mdot
.562 .30567 Mdot
.562 .30568 Mdot
.562 .30568 Mdot
.562 .30568 Mdot
.562 .30569 Mdot
.562 .30569 Mdot
.562 .30569 Mdot
.562 .30569 Mdot
.562 .3057 Mdot
.562 .3057 Mdot
.562 .3057 Mdot
.562 .30572 Mdot
.562 .30572 Mdot
.562 .30572 Mdot
.562 .30572 Mdot
.562 .30573 Mdot
.562 .30573 Mdot
.562 .30573 Mdot
.562 .30573 Mdot
.562 .30574 Mdot
.562 .30574 Mdot
.562 .30574 Mdot
.562 .30574 Mdot
.562 .30574 Mdot
.562 .30574 Mdot
.562 .30575 Mdot
.562 .30575 Mdot
.562 .30575 Mdot
.562 .30575 Mdot
.562 .30575 Mdot
.562 .30576 Mdot
.562 .30576 Mdot
.562 .30577 Mdot
.562 .30577 Mdot
.562 .30577 Mdot
.562 .30577 Mdot
.562 .30577 Mdot
.562 .30578 Mdot
.562 .30578 Mdot
.562 .30578 Mdot
.562 .30579 Mdot
.562 .3058 Mdot
.562 .3058 Mdot
.562 .30581 Mdot
.562 .30581 Mdot
.562 .30581 Mdot
.562 .30581 Mdot
.562 .30582 Mdot
.562 .30583 Mdot
.562 .30583 Mdot
.562 .30583 Mdot
.562 .30584 Mdot
.562 .30584 Mdot
.562 .30584 Mdot
.562 .30584 Mdot
.562 .30585 Mdot
.562 .30587 Mdot
.562 .30589 Mdot
.562 .3059 Mdot
.562 .3059 Mdot
.562 .3059 Mdot
.562 .30591 Mdot
.562 .30591 Mdot
.562 .30591 Mdot
.562 .30591 Mdot
.562 .30592 Mdot
.562 .30592 Mdot
.562 .30593 Mdot
.562 .30593 Mdot
.562 .30593 Mdot
.562 .30594 Mdot
.562 .30594 Mdot
.562 .30594 Mdot
.562 .30595 Mdot
.562 .30596 Mdot
.562 .30597 Mdot
.562 .30597 Mdot
.562 .30597 Mdot
.562 .30598 Mdot
.562 .30599 Mdot
.562 .30599 Mdot
.562 .306 Mdot
.562 .306 Mdot
.562 .30601 Mdot
.562 .30602 Mdot
.562 .30602 Mdot
.562 .30603 Mdot
.562 .30603 Mdot
.562 .30604 Mdot
.562 .30607 Mdot
.562 .30607 Mdot
.562 .30611 Mdot
.562 .30612 Mdot
.562 .30613 Mdot
.562 .30614 Mdot
.562 .30614 Mdot
.562 .30614 Mdot
.562 .30614 Mdot
.562 .30615 Mdot
.562 .30616 Mdot
.562 .30617 Mdot
.562 .30617 Mdot
.562 .30617 Mdot
.562 .30617 Mdot
.562 .30618 Mdot
.562 .30619 Mdot
.562 .30619 Mdot
.562 .3062 Mdot
.562 .30621 Mdot
.562 .30622 Mdot
.562 .30623 Mdot
.562 .30623 Mdot
.562 .30624 Mdot
.562 .30624 Mdot
.562 .30625 Mdot
.562 .30625 Mdot
.562 .30628 Mdot
.562 .3063 Mdot
.562 .3063 Mdot
.562 .30631 Mdot
.562 .30631 Mdot
.562 .30631 Mdot
.562 .30632 Mdot
.562 .30632 Mdot
.562 .30634 Mdot
.562 .30636 Mdot
.562 .30636 Mdot
.562 .30636 Mdot
.562 .30638 Mdot
.562 .30638 Mdot
.562 .30638 Mdot
.562 .30639 Mdot
.562 .3064 Mdot
.562 .30641 Mdot
.562 .30644 Mdot
.562 .30644 Mdot
.562 .30646 Mdot
.562 .30646 Mdot
.562 .30647 Mdot
.562 .30647 Mdot
.562 .30647 Mdot
.562 .30647 Mdot
.562 .30649 Mdot
.562 .30649 Mdot
.562 .3065 Mdot
.562 .30651 Mdot
.562 .30651 Mdot
.562 .30652 Mdot
.562 .30653 Mdot
.562 .30655 Mdot
.562 .30657 Mdot
.562 .30658 Mdot
.562 .30658 Mdot
.562 .30658 Mdot
.562 .30659 Mdot
.562 .30659 Mdot
.562 .30661 Mdot
.562 .30665 Mdot
.562 .30665 Mdot
.562 .30901 Mdot
.562 .30901 Mdot
.562 .30906 Mdot
.562 .30908 Mdot
.562 .30909 Mdot
.562 .3091 Mdot
.562 .3091 Mdot
.562 .3091 Mdot
.562 .30911 Mdot
.562 .30914 Mdot
.562 .30916 Mdot
.562 .30918 Mdot
.562 .30918 Mdot
.562 .30919 Mdot
.562 .3092 Mdot
.562 .30921 Mdot
.562 .30922 Mdot
.562 .30923 Mdot
.562 .30924 Mdot
.562 .30924 Mdot
.562 .30924 Mdot
.562 .30925 Mdot
.562 .30926 Mdot
.562 .30928 Mdot
.562 .30928 Mdot
.562 .30932 Mdot
.562 .30933 Mdot
.562 .30933 Mdot
.562 .30935 Mdot
.562 .30935 Mdot
.562 .30936 Mdot
.562 .30937 Mdot
.562 .30938 Mdot
.562 .30938 Mdot
.562 .3094 Mdot
.562 .30942 Mdot
.562 .30942 Mdot
.562 .30943 Mdot
.562 .30944 Mdot
.562 .30944 Mdot
.562 .30945 Mdot
.562 .30946 Mdot
.562 .30947 Mdot
.562 .30951 Mdot
.562 .30952 Mdot
.562 .30953 Mdot
.562 .30953 Mdot
.562 .30954 Mdot
.562 .30954 Mdot
.562 .30955 Mdot
.562 .30956 Mdot
.562 .30958 Mdot
.562 .3096 Mdot
.562 .3096 Mdot
.562 .30961 Mdot
.562 .30961 Mdot
.562 .30962 Mdot
.562 .30962 Mdot
.562 .30962 Mdot
.562 .30963 Mdot
.562 .30964 Mdot
.562 .30965 Mdot
.562 .30965 Mdot
.562 .30966 Mdot
.562 .30966 Mdot
.562 .30967 Mdot
.562 .30968 Mdot
.562 .30969 Mdot
.562 .30974 Mdot
.562 .30975 Mdot
.562 .30979 Mdot
.562 .30979 Mdot
.562 .3098 Mdot
.562 .3098 Mdot
.562 .3098 Mdot
.562 .30981 Mdot
.562 .30983 Mdot
.562 .30983 Mdot
.562 .30984 Mdot
.562 .30984 Mdot
.562 .30985 Mdot
.562 .30987 Mdot
.562 .30987 Mdot
.562 .30987 Mdot
.562 .30988 Mdot
.562 .30989 Mdot
.562 .30991 Mdot
.562 .30991 Mdot
.562 .30991 Mdot
.562 .30992 Mdot
.562 .30992 Mdot
.562 .30992 Mdot
.562 .30993 Mdot
.562 .30994 Mdot
.562 .30994 Mdot
.562 .30994 Mdot
.562 .30995 Mdot
.562 .30995 Mdot
.562 .30995 Mdot
.562 .30996 Mdot
.562 .30996 Mdot
.562 .30996 Mdot
.562 .31 Mdot
.562 .31002 Mdot
.562 .31003 Mdot
.562 .31003 Mdot
.562 .31003 Mdot
.562 .31003 Mdot
.562 .31005 Mdot
.562 .31005 Mdot
.562 .31006 Mdot
.562 .31006 Mdot
.562 .31007 Mdot
.562 .31007 Mdot
.562 .31007 Mdot
.562 .31008 Mdot
.562 .31008 Mdot
.562 .3101 Mdot
.562 .31011 Mdot
.562 .31011 Mdot
.562 .31011 Mdot
.562 .31012 Mdot
.562 .31012 Mdot
.562 .31012 Mdot
.562 .31012 Mdot
.562 .31013 Mdot
.562 .31014 Mdot
.562 .31014 Mdot
.562 .31014 Mdot
.562 .31014 Mdot
.562 .31015 Mdot
.562 .31015 Mdot
.562 .31015 Mdot
.562 .31015 Mdot
.562 .31016 Mdot
.562 .31016 Mdot
.562 .31016 Mdot
.562 .31016 Mdot
.562 .31016 Mdot
.562 .31017 Mdot
.562 .31017 Mdot
.562 .31018 Mdot
.562 .31018 Mdot
.562 .31018 Mdot
.562 .31019 Mdot
.562 .31019 Mdot
.562 .31019 Mdot
.562 .3102 Mdot
.562 .31021 Mdot
.562 .31021 Mdot
.562 .31022 Mdot
.562 .31022 Mdot
.562 .31022 Mdot
.562 .31023 Mdot
.562 .31023 Mdot
.562 .31023 Mdot
.562 .31024 Mdot
.562 .31024 Mdot
.562 .31028 Mdot
.562 .31028 Mdot
.562 .31028 Mdot
.562 .31029 Mdot
.562 .31029 Mdot
.562 .3103 Mdot
.562 .3103 Mdot
.562 .31031 Mdot
.562 .31031 Mdot
.562 .31031 Mdot
.562 .31032 Mdot
.562 .31033 Mdot
.562 .31033 Mdot
.562 .31034 Mdot
.562 .31035 Mdot
.562 .31036 Mdot
.562 .31036 Mdot
.562 .31036 Mdot
.562 .31036 Mdot
.562 .31037 Mdot
.562 .31038 Mdot
.562 .31038 Mdot
.562 .31039 Mdot
.562 .31041 Mdot
.562 .31042 Mdot
.562 .31045 Mdot
.562 .31045 Mdot
.562 .31046 Mdot
.562 .31047 Mdot
.562 .31047 Mdot
.562 .31047 Mdot
.562 .31047 Mdot
.562 .31048 Mdot
.562 .31049 Mdot
.562 .31049 Mdot
.562 .31049 Mdot
.562 .31049 Mdot
.562 .3105 Mdot
.562 .3105 Mdot
.562 .31051 Mdot
.562 .31051 Mdot
.562 .31052 Mdot
.562 .31053 Mdot
.562 .31054 Mdot
.562 .31054 Mdot
.562 .31054 Mdot
.562 .31055 Mdot
.562 .31055 Mdot
.562 .31056 Mdot
.562 .31058 Mdot
.562 .3106 Mdot
.562 .3106 Mdot
.562 .3106 Mdot
.562 .31061 Mdot
.562 .31061 Mdot
.562 .31062 Mdot
.562 .31062 Mdot
.562 .31063 Mdot
.562 .31064 Mdot
.562 .31064 Mdot
.562 .31065 Mdot
.562 .31066 Mdot
.562 .31066 Mdot
.562 .31066 Mdot
.562 .31067 Mdot
.562 .31067 Mdot
.562 .31068 Mdot
.562 .31071 Mdot
.562 .31071 Mdot
.562 .31072 Mdot
.562 .31072 Mdot
.562 .31073 Mdot
.562 .31073 Mdot
.562 .31073 Mdot
.562 .31074 Mdot
.562 .31075 Mdot
.562 .31075 Mdot
.562 .31075 Mdot
.562 .31076 Mdot
.562 .31077 Mdot
.562 .31077 Mdot
.562 .31078 Mdot
.562 .3108 Mdot
.562 .31081 Mdot
.562 .31082 Mdot
.562 .31082 Mdot
.562 .31082 Mdot
.562 .31083 Mdot
.562 .31083 Mdot
.562 .31084 Mdot
.562 .31087 Mdot
.562 .31087 Mdot
.562 .34119 Mdot
.562 .34119 Mdot
.562 .34122 Mdot
.562 .34123 Mdot
.562 .34123 Mdot
.562 .34124 Mdot
.562 .34124 Mdot
.562 .34124 Mdot
.562 .34125 Mdot
.562 .34126 Mdot
.562 .34127 Mdot
.562 .34128 Mdot
.562 .34129 Mdot
.562 .34129 Mdot
.562 .3413 Mdot
.562 .3413 Mdot
.562 .34131 Mdot
.562 .34131 Mdot
.562 .34132 Mdot
.562 .34132 Mdot
.562 .34132 Mdot
.562 .34133 Mdot
.562 .34133 Mdot
.562 .34134 Mdot
.562 .34134 Mdot
.562 .34136 Mdot
.562 .34137 Mdot
.562 .34137 Mdot
.562 .34138 Mdot
.562 .34138 Mdot
.562 .34138 Mdot
.562 .34139 Mdot
.562 .3414 Mdot
.562 .3414 Mdot
.562 .34141 Mdot
.562 .34142 Mdot
.562 .34142 Mdot
.562 .34143 Mdot
.562 .34143 Mdot
.562 .34143 Mdot
.562 .34144 Mdot
.562 .34144 Mdot
.562 .34145 Mdot
.562 .34147 Mdot
.562 .34148 Mdot
.562 .34148 Mdot
.562 .34149 Mdot
.562 .34149 Mdot
.562 .34149 Mdot
.562 .3415 Mdot
.562 .34151 Mdot
.562 .34152 Mdot
.562 .34152 Mdot
.562 .34152 Mdot
.562 .34153 Mdot
.562 .34153 Mdot
.562 .34153 Mdot
.562 .34153 Mdot
.562 .34154 Mdot
.562 .34154 Mdot
.562 .34155 Mdot
.562 .34155 Mdot
.562 .34155 Mdot
.562 .34155 Mdot
.562 .34156 Mdot
.562 .34157 Mdot
.562 .34157 Mdot
.562 .3416 Mdot
.562 .3416 Mdot
.562 .34162 Mdot
.562 .34163 Mdot
.562 .34163 Mdot
.562 .34164 Mdot
.562 .34165 Mdot
.562 .34165 Mdot
.562 .34165 Mdot
.562 .34165 Mdot
.562 .34166 Mdot
.562 .34167 Mdot
.562 .34167 Mdot
.562 .34167 Mdot
.562 .34168 Mdot
.562 .34169 Mdot
.562 .34169 Mdot
.562 .34169 Mdot
.562 .3417 Mdot
.562 .3417 Mdot
.562 .34171 Mdot
.562 .34171 Mdot
.562 .34172 Mdot
.562 .34172 Mdot
.562 .34172 Mdot
.562 .34175 Mdot
.562 .34176 Mdot
.562 .34176 Mdot
.562 .34176 Mdot
.562 .34177 Mdot
.562 .34177 Mdot
.562 .34177 Mdot
.562 .34177 Mdot
.562 .34178 Mdot
.562 .34178 Mdot
.562 .34179 Mdot
.562 .3418 Mdot
.562 .3418 Mdot
.562 .3418 Mdot
.562 .34181 Mdot
.562 .34181 Mdot
.562 .34181 Mdot
.562 .34182 Mdot
.562 .34182 Mdot
.562 .34182 Mdot
.562 .34182 Mdot
.562 .34183 Mdot
.562 .34183 Mdot
.562 .34183 Mdot
.562 .34183 Mdot
.562 .34183 Mdot
.562 .34184 Mdot
.562 .34184 Mdot
.562 .34184 Mdot
.562 .34184 Mdot
.562 .34185 Mdot
.562 .34185 Mdot
.562 .34186 Mdot
.562 .34186 Mdot
.562 .34186 Mdot
.562 .34186 Mdot
.562 .34187 Mdot
.562 .34187 Mdot
.562 .34187 Mdot
.562 .34187 Mdot
.562 .34188 Mdot
.562 .3419 Mdot
.562 .3419 Mdot
.562 .3419 Mdot
.562 .3419 Mdot
.562 .34191 Mdot
.562 .34191 Mdot
.562 .34192 Mdot
.562 .34192 Mdot
.562 .34193 Mdot
.562 .34194 Mdot
.562 .34194 Mdot
.562 .34194 Mdot
.562 .34194 Mdot
.562 .34195 Mdot
.562 .34197 Mdot
.562 .342 Mdot
.562 .342 Mdot
.562 .342 Mdot
.562 .34201 Mdot
.562 .34202 Mdot
.562 .34202 Mdot
.562 .34202 Mdot
.562 .34202 Mdot
.562 .34203 Mdot
.562 .34203 Mdot
.562 .34204 Mdot
.562 .34204 Mdot
.562 .34204 Mdot
.562 .34205 Mdot
.562 .34205 Mdot
.562 .34205 Mdot
.562 .34207 Mdot
.562 .34207 Mdot
.562 .34208 Mdot
.562 .34208 Mdot
.562 .34209 Mdot
.562 .3421 Mdot
.562 .34211 Mdot
.562 .34211 Mdot
.562 .34212 Mdot
.562 .34212 Mdot
.562 .34214 Mdot
.562 .34214 Mdot
.562 .34215 Mdot
.562 .34215 Mdot
.562 .34215 Mdot
.562 .34216 Mdot
.562 .34219 Mdot
.562 .3422 Mdot
.562 .34225 Mdot
.562 .34225 Mdot
.562 .34227 Mdot
.562 .34227 Mdot
.562 .34227 Mdot
.562 .34228 Mdot
.562 .34228 Mdot
.562 .34229 Mdot
.562 .3423 Mdot
.562 .34231 Mdot
.562 .34231 Mdot
.562 .34231 Mdot
.562 .34231 Mdot
.562 .34232 Mdot
.562 .34233 Mdot
.562 .34233 Mdot
.562 .34234 Mdot
.562 .34236 Mdot
.562 .34237 Mdot
.562 .34237 Mdot
.562 .34238 Mdot
.562 .34238 Mdot
.562 .34239 Mdot
.562 .3424 Mdot
.562 .3424 Mdot
.562 .34244 Mdot
.562 .34245 Mdot
.562 .34246 Mdot
.562 .34246 Mdot
.562 .34247 Mdot
.562 .34247 Mdot
.562 .34248 Mdot
.562 .34248 Mdot
.562 .3425 Mdot
.562 .34252 Mdot
.562 .34252 Mdot
.562 .34253 Mdot
.562 .34254 Mdot
.562 .34255 Mdot
.562 .34255 Mdot
.562 .34256 Mdot
.562 .34256 Mdot
.562 .34258 Mdot
.562 .34261 Mdot
.562 .34261 Mdot
.562 .34263 Mdot
.562 .34263 Mdot
.562 .34264 Mdot
.562 .34265 Mdot
.562 .34265 Mdot
.562 .34265 Mdot
.562 .34267 Mdot
.562 .34267 Mdot
.562 .34268 Mdot
.562 .34269 Mdot
.562 .3427 Mdot
.562 .3427 Mdot
.562 .34272 Mdot
.562 .34274 Mdot
.562 .34276 Mdot
.562 .34277 Mdot
.562 .34277 Mdot
.562 .34277 Mdot
.562 .34278 Mdot
.562 .34278 Mdot
.562 .3428 Mdot
.562 .34285 Mdot
.562 .34285 Mdot
.562 .34495 Mdot
.562 .34495 Mdot
.562 .34499 Mdot
.562 .345 Mdot
.562 .345 Mdot
.562 .34501 Mdot
.562 .34501 Mdot
.562 .34502 Mdot
.562 .34502 Mdot
.562 .34504 Mdot
.562 .34505 Mdot
.562 .34507 Mdot
.562 .34507 Mdot
.562 .34507 Mdot
.562 .34508 Mdot
.562 .34509 Mdot
.562 .34509 Mdot
.562 .34511 Mdot
.562 .34511 Mdot
.562 .34511 Mdot
.562 .34511 Mdot
.562 .34512 Mdot
.562 .34512 Mdot
.562 .34514 Mdot
.562 .34514 Mdot
.562 .34517 Mdot
.562 .34518 Mdot
.562 .34518 Mdot
.562 .34519 Mdot
.562 .34519 Mdot
.562 .34519 Mdot
.562 .3452 Mdot
.562 .34521 Mdot
.562 .34521 Mdot
.562 .34522 Mdot
.562 .34524 Mdot
.562 .34524 Mdot
.562 .34525 Mdot
.562 .34525 Mdot
.562 .34525 Mdot
.562 .34526 Mdot
.562 .34526 Mdot
.562 .34528 Mdot
.562 .34531 Mdot
.562 .34531 Mdot
.562 .34532 Mdot
.562 .34532 Mdot
.562 .34533 Mdot
.562 .34533 Mdot
.562 .34534 Mdot
.562 .34535 Mdot
.562 .34536 Mdot
.562 .34536 Mdot
.562 .34537 Mdot
.562 .34537 Mdot
.562 .34538 Mdot
.562 .34538 Mdot
.562 .34538 Mdot
.562 .34539 Mdot
.562 .34539 Mdot
.562 .3454 Mdot
.562 .3454 Mdot
.562 .3454 Mdot
.562 .34541 Mdot
.562 .34541 Mdot
.562 .34542 Mdot
.562 .34543 Mdot
.562 .34547 Mdot
.562 .34547 Mdot
.562 .3455 Mdot
.562 .3455 Mdot
.562 .3455 Mdot
.562 .34551 Mdot
.562 .34551 Mdot
.562 .34551 Mdot
.562 .34552 Mdot
.562 .34553 Mdot
.562 .34553 Mdot
.562 .34553 Mdot
.562 .34554 Mdot
.562 .34555 Mdot
.562 .34556 Mdot
.562 .34556 Mdot
.562 .34556 Mdot
.562 .34557 Mdot
.562 .34558 Mdot
.562 .34558 Mdot
.562 .34558 Mdot
.562 .34559 Mdot
.562 .34559 Mdot
.562 .34559 Mdot
.562 .3456 Mdot
.562 .3456 Mdot
.562 .3456 Mdot
.562 .34561 Mdot
.562 .34561 Mdot
.562 .34561 Mdot
.562 .34561 Mdot
.562 .34562 Mdot
.562 .34562 Mdot
.562 .34562 Mdot
.562 .34564 Mdot
.562 .34566 Mdot
.562 .34567 Mdot
.562 .34567 Mdot
.562 .34567 Mdot
.562 .34567 Mdot
.562 .34568 Mdot
.562 .34568 Mdot
.562 .34568 Mdot
.562 .34569 Mdot
.562 .34569 Mdot
.562 .34569 Mdot
.562 .3457 Mdot
.562 .3457 Mdot
.562 .3457 Mdot
.562 .3457 Mdot
.562 .34572 Mdot
.562 .34572 Mdot
.562 .34572 Mdot
.562 .34572 Mdot
.562 .34573 Mdot
.562 .34573 Mdot
.562 .34573 Mdot
.562 .34573 Mdot
.562 .34574 Mdot
.562 .34574 Mdot
.562 .34574 Mdot
.562 .34575 Mdot
.562 .34575 Mdot
.562 .34575 Mdot
.562 .34575 Mdot
.562 .34575 Mdot
.562 .34575 Mdot
.562 .34576 Mdot
.562 .34576 Mdot
.562 .34576 Mdot
.562 .34576 Mdot
.562 .34576 Mdot
.562 .34577 Mdot
.562 .34577 Mdot
.562 .34577 Mdot
.562 .34577 Mdot
.562 .34578 Mdot
.562 .34578 Mdot
.562 .34578 Mdot
.562 .34578 Mdot
.562 .34579 Mdot
.562 .34579 Mdot
.562 .34579 Mdot
.562 .3458 Mdot
.562 .3458 Mdot
.562 .3458 Mdot
.562 .34581 Mdot
.562 .34581 Mdot
.562 .34581 Mdot
.562 .34581 Mdot
.562 .34582 Mdot
.562 .34584 Mdot
.562 .34584 Mdot
.562 .34585 Mdot
.562 .34585 Mdot
.562 .34585 Mdot
.562 .34586 Mdot
.562 .34586 Mdot
.562 .34586 Mdot
.562 .34587 Mdot
.562 .34587 Mdot
.562 .34588 Mdot
.562 .34588 Mdot
.562 .34588 Mdot
.562 .34588 Mdot
.562 .34589 Mdot
.562 .3459 Mdot
.562 .3459 Mdot
.562 .3459 Mdot
.562 .3459 Mdot
.562 .34591 Mdot
.562 .34591 Mdot
.562 .34592 Mdot
.562 .34592 Mdot
.562 .34594 Mdot
.562 .34594 Mdot
.562 .34596 Mdot
.562 .34597 Mdot
.562 .34597 Mdot
.562 .34598 Mdot
.562 .34598 Mdot
.562 .34598 Mdot
.562 .34598 Mdot
.562 .34599 Mdot
.562 .34599 Mdot
.562 .34599 Mdot
.562 .34599 Mdot
.562 .346 Mdot
.562 .346 Mdot
.562 .346 Mdot
.562 .346 Mdot
.562 .346 Mdot
.562 .34601 Mdot
.562 .34602 Mdot
.562 .34602 Mdot
.562 .34603 Mdot
.562 .34603 Mdot
.562 .34603 Mdot
.562 .34604 Mdot
.562 .34604 Mdot
.562 .34606 Mdot
.562 .34607 Mdot
.562 .34607 Mdot
.562 .34607 Mdot
.562 .34608 Mdot
.562 .34608 Mdot
.562 .34608 Mdot
.562 .34608 Mdot
.562 .34609 Mdot
.562 .3461 Mdot
.562 .3461 Mdot
.562 .3461 Mdot
.562 .34611 Mdot
.562 .34611 Mdot
.562 .34611 Mdot
.562 .34612 Mdot
.562 .34612 Mdot
.562 .34613 Mdot
.562 .34614 Mdot
.562 .34614 Mdot
.562 .34615 Mdot
.562 .34616 Mdot
.562 .34616 Mdot
.562 .34616 Mdot
.562 .34616 Mdot
.562 .34617 Mdot
.562 .34617 Mdot
.562 .34617 Mdot
.562 .34618 Mdot
.562 .34618 Mdot
.562 .34619 Mdot
.562 .34619 Mdot
.562 .3462 Mdot
.562 .34621 Mdot
.562 .34622 Mdot
.562 .34622 Mdot
.562 .34622 Mdot
.562 .34622 Mdot
.562 .34623 Mdot
.562 .34623 Mdot
.562 .34624 Mdot
.562 .34626 Mdot
.562 .34626 Mdot
.564 .30487 Mdot
.564 .30489 Mdot
.564 .3049 Mdot
.564 .30491 Mdot
.564 .30492 Mdot
.564 .30492 Mdot
.564 .30492 Mdot
.564 .30492 Mdot
.564 .30492 Mdot
.564 .30493 Mdot
.564 .30496 Mdot
.564 .30496 Mdot
.564 .30497 Mdot
.564 .30497 Mdot
.564 .30497 Mdot
.564 .30498 Mdot
.564 .305 Mdot
.564 .305 Mdot
.564 .305 Mdot
.564 .30501 Mdot
.564 .30502 Mdot
.564 .30502 Mdot
.564 .30502 Mdot
.564 .30503 Mdot
.564 .30504 Mdot
.564 .30504 Mdot
.564 .30504 Mdot
.564 .30506 Mdot
.564 .30506 Mdot
.564 .30507 Mdot
.564 .30507 Mdot
.564 .30508 Mdot
.564 .30508 Mdot
.564 .30509 Mdot
.564 .30509 Mdot
.564 .30509 Mdot
.564 .3051 Mdot
.564 .3051 Mdot
.564 .3051 Mdot
.564 .30511 Mdot
.564 .30511 Mdot
.564 .30512 Mdot
.564 .30512 Mdot
.564 .30513 Mdot
.564 .30514 Mdot
.564 .30514 Mdot
.564 .30514 Mdot
.564 .30514 Mdot
.564 .30514 Mdot
.564 .30515 Mdot
.564 .30515 Mdot
.564 .30515 Mdot
.564 .30515 Mdot
.564 .30515 Mdot
.564 .30516 Mdot
.564 .30516 Mdot
.564 .30517 Mdot
.564 .30517 Mdot
.564 .30518 Mdot
.564 .30518 Mdot
.564 .30519 Mdot
.564 .3052 Mdot
.564 .30521 Mdot
.564 .30522 Mdot
.564 .30524 Mdot
.564 .30524 Mdot
.564 .30525 Mdot
.564 .30526 Mdot
.564 .30527 Mdot
.564 .30528 Mdot
.564 .30528 Mdot
.564 .30528 Mdot
.564 .30528 Mdot
.564 .30528 Mdot
.564 .3053 Mdot
.564 .3053 Mdot
.564 .3053 Mdot
.564 .3053 Mdot
.564 .30531 Mdot
.564 .30531 Mdot
.564 .30532 Mdot
.564 .30532 Mdot
.564 .30532 Mdot
.564 .30533 Mdot
.564 .30533 Mdot
.564 .30534 Mdot
.564 .30535 Mdot
.564 .30535 Mdot
.564 .30535 Mdot
.564 .30535 Mdot
.564 .30536 Mdot
.564 .30537 Mdot
.564 .30537 Mdot
.564 .30537 Mdot
.564 .30537 Mdot
.564 .30539 Mdot
.564 .3054 Mdot
.564 .30542 Mdot
.564 .30543 Mdot
.564 .30543 Mdot
.564 .30543 Mdot
.564 .30544 Mdot
.564 .30544 Mdot
.564 .30544 Mdot
.564 .30545 Mdot
.564 .30545 Mdot
.564 .30545 Mdot
.564 .30545 Mdot
.564 .30547 Mdot
.564 .30548 Mdot
.564 .30548 Mdot
.564 .30548 Mdot
.564 .30549 Mdot
.564 .3055 Mdot
.564 .3055 Mdot
.564 .3055 Mdot
.564 .3055 Mdot
.564 .30551 Mdot
.564 .30551 Mdot
.564 .30552 Mdot
.564 .30552 Mdot
.564 .30553 Mdot
.564 .30554 Mdot
.564 .30554 Mdot
.564 .30554 Mdot
.564 .30554 Mdot
.564 .30555 Mdot
.564 .30556 Mdot
.564 .30559 Mdot
.564 .30559 Mdot
.564 .30559 Mdot
.564 .30559 Mdot
.564 .3056 Mdot
.564 .3056 Mdot
.564 .3056 Mdot
.564 .30561 Mdot
.564 .30561 Mdot
.564 .30561 Mdot
.564 .30562 Mdot
.564 .30562 Mdot
.564 .30563 Mdot
.564 .30563 Mdot
.564 .30564 Mdot
.564 .30564 Mdot
.564 .30565 Mdot
.564 .30568 Mdot
.564 .30569 Mdot
.564 .30572 Mdot
.564 .30572 Mdot
.564 .30572 Mdot
.564 .30572 Mdot
.564 .30572 Mdot
.564 .30573 Mdot
.564 .30574 Mdot
.564 .30574 Mdot
.564 .30575 Mdot
.564 .30575 Mdot
.564 .30575 Mdot
.564 .30576 Mdot
.564 .30576 Mdot
.564 .30576 Mdot
.564 .30577 Mdot
.564 .30577 Mdot
.564 .30579 Mdot
.564 .30579 Mdot
.564 .30579 Mdot
.564 .30579 Mdot
.564 .3058 Mdot
.564 .3058 Mdot
.564 .30581 Mdot
.564 .30581 Mdot
.564 .30581 Mdot
.564 .30583 Mdot
.564 .30583 Mdot
.564 .30583 Mdot
.564 .30583 Mdot
.564 .30584 Mdot
.564 .30586 Mdot
.564 .30586 Mdot
.564 .30587 Mdot
.564 .30587 Mdot
.564 .30587 Mdot
.564 .30588 Mdot
.564 .3059 Mdot
.564 .30591 Mdot
.564 .30593 Mdot
.564 .30593 Mdot
.564 .30596 Mdot
.564 .30598 Mdot
.564 .306 Mdot
.564 .30602 Mdot
.564 .30602 Mdot
.564 .30603 Mdot
.564 .30604 Mdot
.564 .30605 Mdot
.564 .30605 Mdot
.564 .30606 Mdot
.564 .30607 Mdot
.564 .30607 Mdot
.564 .30607 Mdot
.564 .30608 Mdot
.564 .30608 Mdot
.564 .30608 Mdot
.564 .30608 Mdot
.564 .30609 Mdot
.564 .30609 Mdot
.564 .3061 Mdot
.564 .3061 Mdot
.564 .30613 Mdot
.564 .30613 Mdot
.564 .30614 Mdot
.564 .30614 Mdot
.564 .30615 Mdot
.564 .30616 Mdot
.564 .30616 Mdot
.564 .30617 Mdot
.564 .30617 Mdot
.564 .30618 Mdot
.564 .30618 Mdot
.564 .30619 Mdot
.564 .3062 Mdot
.564 .30621 Mdot
.564 .30622 Mdot
.564 .30623 Mdot
.564 .30625 Mdot
.564 .30625 Mdot
.564 .30625 Mdot
.564 .30626 Mdot
.564 .30628 Mdot
.564 .30628 Mdot
.564 .30629 Mdot
.564 .3063 Mdot
.564 .30631 Mdot
.564 .30632 Mdot
.564 .30632 Mdot
.564 .30635 Mdot
.564 .30636 Mdot
.564 .30636 Mdot
.564 .30636 Mdot
.564 .30638 Mdot
.564 .30638 Mdot
.564 .30643 Mdot
.564 .30644 Mdot
.564 .30645 Mdot
.564 .30645 Mdot
.564 .30645 Mdot
.564 .30646 Mdot
.564 .30647 Mdot
.564 .30648 Mdot
.564 .3065 Mdot
.564 .30653 Mdot
.564 .30894 Mdot
.564 .30895 Mdot
.564 .30897 Mdot
.564 .30899 Mdot
.564 .30899 Mdot
.564 .30899 Mdot
.564 .30899 Mdot
.564 .30901 Mdot
.564 .30902 Mdot
.564 .30908 Mdot
.564 .30909 Mdot
.564 .3091 Mdot
.564 .30911 Mdot
.564 .30911 Mdot
.564 .30912 Mdot
.564 .30916 Mdot
.564 .30917 Mdot
.564 .30917 Mdot
.564 .30918 Mdot
.564 .30919 Mdot
.564 .30921 Mdot
.564 .30921 Mdot
.564 .30923 Mdot
.564 .30925 Mdot
.564 .30925 Mdot
.564 .30925 Mdot
.564 .30928 Mdot
.564 .30928 Mdot
.564 .3093 Mdot
.564 .30931 Mdot
.564 .30932 Mdot
.564 .30934 Mdot
.564 .30934 Mdot
.564 .30935 Mdot
.564 .30936 Mdot
.564 .30937 Mdot
.564 .30937 Mdot
.564 .30937 Mdot
.564 .30939 Mdot
.564 .30939 Mdot
.564 .3094 Mdot
.564 .3094 Mdot
.564 .30943 Mdot
.564 .30944 Mdot
.564 .30945 Mdot
.564 .30945 Mdot
.564 .30946 Mdot
.564 .30946 Mdot
.564 .30947 Mdot
.564 .30947 Mdot
.564 .30948 Mdot
.564 .30948 Mdot
.564 .30948 Mdot
.564 .30949 Mdot
.564 .3095 Mdot
.564 .3095 Mdot
.564 .30952 Mdot
.564 .30953 Mdot
.564 .30954 Mdot
.564 .30955 Mdot
.564 .30957 Mdot
.564 .30959 Mdot
.564 .30962 Mdot
.564 .30965 Mdot
.564 .30966 Mdot
.564 .30968 Mdot
.564 .30969 Mdot
.564 .30972 Mdot
.564 .30973 Mdot
.564 .30974 Mdot
.564 .30974 Mdot
.564 .30974 Mdot
.564 .30975 Mdot
.564 .30977 Mdot
.564 .30978 Mdot
.564 .30978 Mdot
.564 .30978 Mdot
.564 .30979 Mdot
.564 .3098 Mdot
.564 .30981 Mdot
.564 .30981 Mdot
.564 .30982 Mdot
.564 .30982 Mdot
.564 .30983 Mdot
.564 .30984 Mdot
.564 .30984 Mdot
.564 .30984 Mdot
.564 .30986 Mdot
.564 .30987 Mdot
.564 .30987 Mdot
.564 .30987 Mdot
.564 .30988 Mdot
.564 .30988 Mdot
.564 .30988 Mdot
.564 .30988 Mdot
.564 .30989 Mdot
.564 .30989 Mdot
.564 .30991 Mdot
.564 .30992 Mdot
.564 .30992 Mdot
.564 .30992 Mdot
.564 .30992 Mdot
.564 .30993 Mdot
.564 .30997 Mdot
.564 .30998 Mdot
.564 .31002 Mdot
.564 .31002 Mdot
.564 .31003 Mdot
.564 .31004 Mdot
.564 .31004 Mdot
.564 .31005 Mdot
.564 .31005 Mdot
.564 .31006 Mdot
.564 .31006 Mdot
.564 .31006 Mdot
.564 .31008 Mdot
.564 .31008 Mdot
.564 .31008 Mdot
.564 .31009 Mdot
.564 .31009 Mdot
.564 .31009 Mdot
.564 .31009 Mdot
.564 .31013 Mdot
.564 .31014 Mdot
.564 .31015 Mdot
.564 .31015 Mdot
.564 .31016 Mdot
.564 .31016 Mdot
.564 .31016 Mdot
.564 .31017 Mdot
.564 .31018 Mdot
.564 .31019 Mdot
.564 .3102 Mdot
.564 .3102 Mdot
.564 .3102 Mdot
.564 .3102 Mdot
.564 .31021 Mdot
.564 .31022 Mdot
.564 .31022 Mdot
.564 .31022 Mdot
.564 .31023 Mdot
.564 .31024 Mdot
.564 .31026 Mdot
.564 .31026 Mdot
.564 .31027 Mdot
.564 .31027 Mdot
.564 .31027 Mdot
.564 .31027 Mdot
.564 .31028 Mdot
.564 .31029 Mdot
.564 .3103 Mdot
.564 .3103 Mdot
.564 .31031 Mdot
.564 .31034 Mdot
.564 .31034 Mdot
.564 .31037 Mdot
.564 .31037 Mdot
.564 .31037 Mdot
.564 .31037 Mdot
.564 .31038 Mdot
.564 .31039 Mdot
.564 .31039 Mdot
.564 .31039 Mdot
.564 .3104 Mdot
.564 .31041 Mdot
.564 .31042 Mdot
.564 .31042 Mdot
.564 .31043 Mdot
.564 .31043 Mdot
.564 .31044 Mdot
.564 .31044 Mdot
.564 .31044 Mdot
.564 .31045 Mdot
.564 .31046 Mdot
.564 .31046 Mdot
.564 .31046 Mdot
.564 .31048 Mdot
.564 .31048 Mdot
.564 .31048 Mdot
.564 .31048 Mdot
.564 .31049 Mdot
.564 .31049 Mdot
.564 .31051 Mdot
.564 .31052 Mdot
.564 .31053 Mdot
.564 .31054 Mdot
.564 .31056 Mdot
.564 .31057 Mdot
.564 .31059 Mdot
.564 .3106 Mdot
.564 .3106 Mdot
.564 .31061 Mdot
.564 .31062 Mdot
.564 .31063 Mdot
.564 .31063 Mdot
.564 .31064 Mdot
.564 .31064 Mdot
.564 .31064 Mdot
.564 .31065 Mdot
.564 .31065 Mdot
.564 .31065 Mdot
.564 .31065 Mdot
.564 .31066 Mdot
.564 .31066 Mdot
.564 .31066 Mdot
.564 .31067 Mdot
.564 .31067 Mdot
.564 .31069 Mdot
.564 .31069 Mdot
.564 .3107 Mdot
.564 .3107 Mdot
.564 .31071 Mdot
.564 .31071 Mdot
.564 .31071 Mdot
.564 .31072 Mdot
.564 .31072 Mdot
.564 .31073 Mdot
.564 .31073 Mdot
.564 .31074 Mdot
.564 .31075 Mdot
.564 .31076 Mdot
.564 .31077 Mdot
.564 .31077 Mdot
.564 .31078 Mdot
.564 .31078 Mdot
.564 .31079 Mdot
.564 .3108 Mdot
.564 .31081 Mdot
.564 .31081 Mdot
.564 .31082 Mdot
.564 .31083 Mdot
.564 .31084 Mdot
.564 .31084 Mdot
.564 .31084 Mdot
.564 .31087 Mdot
.564 .31087 Mdot
.564 .31087 Mdot
.564 .31088 Mdot
.564 .31089 Mdot
.564 .31089 Mdot
.564 .31093 Mdot
.564 .31094 Mdot
.564 .31094 Mdot
.564 .31094 Mdot
.564 .31095 Mdot
.564 .31095 Mdot
.564 .31096 Mdot
.564 .31097 Mdot
.564 .31098 Mdot
.564 .31101 Mdot
.564 .34201 Mdot
.564 .34203 Mdot
.564 .34204 Mdot
.564 .34205 Mdot
.564 .34206 Mdot
.564 .34206 Mdot
.564 .34206 Mdot
.564 .34206 Mdot
.564 .34207 Mdot
.564 .34208 Mdot
.564 .34211 Mdot
.564 .34211 Mdot
.564 .34212 Mdot
.564 .34213 Mdot
.564 .34213 Mdot
.564 .34213 Mdot
.564 .34215 Mdot
.564 .34216 Mdot
.564 .34216 Mdot
.564 .34217 Mdot
.564 .34217 Mdot
.564 .34218 Mdot
.564 .34218 Mdot
.564 .3422 Mdot
.564 .3422 Mdot
.564 .3422 Mdot
.564 .34221 Mdot
.564 .34222 Mdot
.564 .34222 Mdot
.564 .34223 Mdot
.564 .34224 Mdot
.564 .34225 Mdot
.564 .34225 Mdot
.564 .34225 Mdot
.564 .34226 Mdot
.564 .34226 Mdot
.564 .34227 Mdot
.564 .34227 Mdot
.564 .34227 Mdot
.564 .34228 Mdot
.564 .34228 Mdot
.564 .34229 Mdot
.564 .34229 Mdot
.564 .3423 Mdot
.564 .34231 Mdot
.564 .34231 Mdot
.564 .34232 Mdot
.564 .34232 Mdot
.564 .34232 Mdot
.564 .34232 Mdot
.564 .34232 Mdot
.564 .34233 Mdot
.564 .34233 Mdot
.564 .34233 Mdot
.564 .34233 Mdot
.564 .34234 Mdot
.564 .34234 Mdot
.564 .34235 Mdot
.564 .34236 Mdot
.564 .34236 Mdot
.564 .34237 Mdot
.564 .34238 Mdot
.564 .34239 Mdot
.564 .34241 Mdot
.564 .34243 Mdot
.564 .34243 Mdot
.564 .34244 Mdot
.564 .34245 Mdot
.564 .34246 Mdot
.564 .34247 Mdot
.564 .34247 Mdot
.564 .34247 Mdot
.564 .34247 Mdot
.564 .34248 Mdot
.564 .34249 Mdot
.564 .3425 Mdot
.564 .3425 Mdot
.564 .3425 Mdot
.564 .34251 Mdot
.564 .34251 Mdot
.564 .34251 Mdot
.564 .34252 Mdot
.564 .34252 Mdot
.564 .34252 Mdot
.564 .34253 Mdot
.564 .34254 Mdot
.564 .34255 Mdot
.564 .34255 Mdot
.564 .34255 Mdot
.564 .34256 Mdot
.564 .34257 Mdot
.564 .34257 Mdot
.564 .34257 Mdot
.564 .34257 Mdot
.564 .34257 Mdot
.564 .3426 Mdot
.564 .3426 Mdot
.564 .34263 Mdot
.564 .34264 Mdot
.564 .34264 Mdot
.564 .34264 Mdot
.564 .34265 Mdot
.564 .34266 Mdot
.564 .34266 Mdot
.564 .34266 Mdot
.564 .34267 Mdot
.564 .34267 Mdot
.564 .34267 Mdot
.564 .34269 Mdot
.564 .3427 Mdot
.564 .3427 Mdot
.564 .3427 Mdot
.564 .34271 Mdot
.564 .34272 Mdot
.564 .34272 Mdot
.564 .34272 Mdot
.564 .34273 Mdot
.564 .34273 Mdot
.564 .34273 Mdot
.564 .34274 Mdot
.564 .34275 Mdot
.564 .34276 Mdot
.564 .34276 Mdot
.564 .34276 Mdot
.564 .34276 Mdot
.564 .34276 Mdot
.564 .34278 Mdot
.564 .34278 Mdot
.564 .34282 Mdot
.564 .34282 Mdot
.564 .34282 Mdot
.564 .34282 Mdot
.564 .34283 Mdot
.564 .34283 Mdot
.564 .34283 Mdot
.564 .34285 Mdot
.564 .34285 Mdot
.564 .34285 Mdot
.564 .34285 Mdot
.564 .34286 Mdot
.564 .34286 Mdot
.564 .34286 Mdot
.564 .34288 Mdot
.564 .34288 Mdot
.564 .34288 Mdot
.564 .34292 Mdot
.564 .34293 Mdot
.564 .34297 Mdot
.564 .34297 Mdot
.564 .34297 Mdot
.564 .34297 Mdot
.564 .34297 Mdot
.564 .34298 Mdot
.564 .34299 Mdot
.564 .343 Mdot
.564 .343 Mdot
.564 .343 Mdot
.564 .34301 Mdot
.564 .34301 Mdot
.564 .34301 Mdot
.564 .34302 Mdot
.564 .34302 Mdot
.564 .34303 Mdot
.564 .34304 Mdot
.564 .34304 Mdot
.564 .34305 Mdot
.564 .34305 Mdot
.564 .34306 Mdot
.564 .34306 Mdot
.564 .34307 Mdot
.564 .34307 Mdot
.564 .34307 Mdot
.564 .34309 Mdot
.564 .34309 Mdot
.564 .34309 Mdot
.564 .34309 Mdot
.564 .3431 Mdot
.564 .34312 Mdot
.564 .34313 Mdot
.564 .34313 Mdot
.564 .34313 Mdot
.564 .34314 Mdot
.564 .34315 Mdot
.564 .34317 Mdot
.564 .34319 Mdot
.564 .34321 Mdot
.564 .34321 Mdot
.564 .34324 Mdot
.564 .34326 Mdot
.564 .34328 Mdot
.564 .3433 Mdot
.564 .3433 Mdot
.564 .34331 Mdot
.564 .34333 Mdot
.564 .34334 Mdot
.564 .34335 Mdot
.564 .34336 Mdot
.564 .34336 Mdot
.564 .34336 Mdot
.564 .34336 Mdot
.564 .34337 Mdot
.564 .34337 Mdot
.564 .34338 Mdot
.564 .34338 Mdot
.564 .34338 Mdot
.564 .34339 Mdot
.564 .34339 Mdot
.564 .3434 Mdot
.564 .34343 Mdot
.564 .34343 Mdot
.564 .34344 Mdot
.564 .34344 Mdot
.564 .34346 Mdot
.564 .34346 Mdot
.564 .34346 Mdot
.564 .34347 Mdot
.564 .34347 Mdot
.564 .34348 Mdot
.564 .34349 Mdot
.564 .3435 Mdot
.564 .34351 Mdot
.564 .34352 Mdot
.564 .34354 Mdot
.564 .34354 Mdot
.564 .34356 Mdot
.564 .34356 Mdot
.564 .34357 Mdot
.564 .34358 Mdot
.564 .3436 Mdot
.564 .3436 Mdot
.564 .34361 Mdot
.564 .34362 Mdot
.564 .34364 Mdot
.564 .34364 Mdot
.564 .34365 Mdot
.564 .34368 Mdot
.564 .34369 Mdot
.564 .34369 Mdot
.564 .3437 Mdot
.564 .34371 Mdot
.564 .34371 Mdot
.564 .34377 Mdot
.564 .34378 Mdot
.564 .34379 Mdot
.564 .34379 Mdot
.564 .3438 Mdot
.564 .3438 Mdot
.564 .34381 Mdot
.564 .34383 Mdot
.564 .34384 Mdot
.564 .34598 Mdot
.564 .34601 Mdot
.564 .34602 Mdot
.564 .34603 Mdot
.564 .34604 Mdot
.564 .34605 Mdot
.564 .34605 Mdot
.564 .34605 Mdot
.564 .34606 Mdot
.564 .34607 Mdot
.564 .34611 Mdot
.564 .34611 Mdot
.564 .34612 Mdot
.564 .34613 Mdot
.564 .34613 Mdot
.564 .34613 Mdot
.564 .34616 Mdot
.564 .34617 Mdot
.564 .34617 Mdot
.564 .34618 Mdot
.564 .34619 Mdot
.564 .3462 Mdot
.564 .3462 Mdot
.564 .34621 Mdot
.564 .34622 Mdot
.564 .34623 Mdot
.564 .34623 Mdot
.564 .34625 Mdot
.564 .34625 Mdot
.564 .34626 Mdot
.564 .34627 Mdot
.564 .34628 Mdot
.564 .34629 Mdot
.564 .34629 Mdot
.564 .3463 Mdot
.564 .3463 Mdot
.564 .34631 Mdot
.564 .34631 Mdot
.564 .34631 Mdot
.564 .34632 Mdot
.564 .34633 Mdot
.564 .34633 Mdot
.564 .34633 Mdot
.564 .34635 Mdot
.564 .34636 Mdot
.564 .34636 Mdot
.564 .34637 Mdot
.564 .34637 Mdot
.564 .34637 Mdot
.564 .34638 Mdot
.564 .34638 Mdot
.564 .34638 Mdot
.564 .34638 Mdot
.564 .34639 Mdot
.564 .34639 Mdot
.564 .3464 Mdot
.564 .3464 Mdot
.564 .34641 Mdot
.564 .34642 Mdot
.564 .34643 Mdot
.564 .34643 Mdot
.564 .34645 Mdot
.564 .34646 Mdot
.564 .34648 Mdot
.564 .34651 Mdot
.564 .34651 Mdot
.564 .34652 Mdot
.564 .34653 Mdot
.564 .34656 Mdot
.564 .34656 Mdot
.564 .34657 Mdot
.564 .34657 Mdot
.564 .34657 Mdot
.564 .34657 Mdot
.564 .34659 Mdot
.564 .3466 Mdot
.564 .3466 Mdot
.564 .3466 Mdot
.564 .3466 Mdot
.564 .34661 Mdot
.564 .34661 Mdot
.564 .34662 Mdot
.564 .34662 Mdot
.564 .34662 Mdot
.564 .34663 Mdot
.564 .34663 Mdot
.564 .34664 Mdot
.564 .34664 Mdot
.564 .34665 Mdot
.564 .34665 Mdot
.564 .34666 Mdot
.564 .34666 Mdot
.564 .34666 Mdot
.564 .34667 Mdot
.564 .34667 Mdot
.564 .34667 Mdot
.564 .34667 Mdot
.564 .34667 Mdot
.564 .34669 Mdot
.564 .34669 Mdot
.564 .34669 Mdot
.564 .34669 Mdot
.564 .34669 Mdot
.564 .3467 Mdot
.564 .34673 Mdot
.564 .34673 Mdot
.564 .34676 Mdot
.564 .34676 Mdot
.564 .34677 Mdot
.564 .34678 Mdot
.564 .34678 Mdot
.564 .34678 Mdot
.564 .34679 Mdot
.564 .34679 Mdot
.564 .34679 Mdot
.564 .34679 Mdot
.564 .3468 Mdot
.564 .3468 Mdot
.564 .3468 Mdot
.564 .34681 Mdot
.564 .34681 Mdot
.564 .34681 Mdot
.564 .34681 Mdot
.564 .34684 Mdot
.564 .34684 Mdot
.564 .34685 Mdot
.564 .34685 Mdot
.564 .34686 Mdot
.564 .34686 Mdot
.564 .34686 Mdot
.564 .34687 Mdot
.564 .34687 Mdot
.564 .34688 Mdot
.564 .34688 Mdot
.564 .34689 Mdot
.564 .34689 Mdot
.564 .34689 Mdot
.564 .34689 Mdot
.564 .3469 Mdot
.564 .3469 Mdot
.564 .34691 Mdot
.564 .34691 Mdot
.564 .34692 Mdot
.564 .34693 Mdot
.564 .34693 Mdot
.564 .34693 Mdot
.564 .34693 Mdot
.564 .34694 Mdot
.564 .34694 Mdot
.564 .34695 Mdot
.564 .34695 Mdot
.564 .34695 Mdot
.564 .34696 Mdot
.564 .34696 Mdot
.564 .34698 Mdot
.564 .34699 Mdot
.564 .347 Mdot
.564 .34701 Mdot
.564 .34701 Mdot
.564 .34701 Mdot
.564 .34701 Mdot
.564 .34702 Mdot
.564 .34702 Mdot
.564 .34702 Mdot
.564 .34702 Mdot
.564 .34703 Mdot
.564 .34704 Mdot
.564 .34704 Mdot
.564 .34705 Mdot
.564 .34705 Mdot
.564 .34705 Mdot
.564 .34705 Mdot
.564 .34706 Mdot
.564 .34706 Mdot
.564 .34707 Mdot
.564 .34707 Mdot
.564 .34707 Mdot
.564 .34708 Mdot
.564 .34708 Mdot
.564 .34709 Mdot
.564 .34709 Mdot
.564 .34709 Mdot
.564 .34709 Mdot
.564 .34711 Mdot
.564 .34711 Mdot
.564 .34712 Mdot
.564 .34712 Mdot
.564 .34714 Mdot
.564 .34715 Mdot
.564 .34716 Mdot
.564 .34717 Mdot
.564 .34717 Mdot
.564 .34718 Mdot
.564 .34719 Mdot
.564 .34719 Mdot
.564 .34719 Mdot
.564 .3472 Mdot
.564 .3472 Mdot
.564 .3472 Mdot
.564 .3472 Mdot
.564 .3472 Mdot
.564 .3472 Mdot
.564 .34721 Mdot
.564 .34721 Mdot
.564 .34721 Mdot
.564 .34721 Mdot
.564 .34722 Mdot
.564 .34723 Mdot
.564 .34723 Mdot
.564 .34723 Mdot
.564 .34724 Mdot
.564 .34724 Mdot
.564 .34724 Mdot
.564 .34725 Mdot
.564 .34725 Mdot
.564 .34725 Mdot
.564 .34726 Mdot
.564 .34726 Mdot
.564 .34726 Mdot
.564 .34727 Mdot
.564 .34727 Mdot
.564 .34728 Mdot
.564 .34728 Mdot
.564 .34729 Mdot
.564 .3473 Mdot
.564 .3473 Mdot
.564 .3473 Mdot
.564 .34731 Mdot
.564 .34731 Mdot
.564 .34732 Mdot
.564 .34732 Mdot
.564 .34733 Mdot
.564 .34733 Mdot
.564 .34734 Mdot
.564 .34735 Mdot
.564 .34736 Mdot
.564 .34736 Mdot
.564 .34736 Mdot
.564 .34737 Mdot
.564 .34737 Mdot
.564 .34739 Mdot
.564 .3474 Mdot
.564 .34741 Mdot
.564 .34741 Mdot
.564 .34741 Mdot
.564 .34741 Mdot
.564 .34742 Mdot
.564 .34742 Mdot
.564 .34743 Mdot
.564 .34745 Mdot
.566 .30456 Mdot
.566 .30457 Mdot
.566 .30457 Mdot
.566 .30457 Mdot
.566 .30457 Mdot
.566 .30458 Mdot
.566 .30458 Mdot
.566 .30459 Mdot
.566 .30459 Mdot
.566 .30459 Mdot
.566 .30459 Mdot
.566 .30459 Mdot
.566 .30459 Mdot
.566 .30459 Mdot
.566 .3046 Mdot
.566 .3046 Mdot
.566 .3046 Mdot
.566 .3046 Mdot
.566 .30461 Mdot
.566 .30461 Mdot
.566 .30461 Mdot
.566 .30462 Mdot
.566 .30462 Mdot
.566 .30464 Mdot
.566 .30464 Mdot
.566 .30464 Mdot
.566 .30464 Mdot
.566 .30464 Mdot
.566 .30465 Mdot
.566 .30465 Mdot
.566 .30466 Mdot
.566 .30466 Mdot
.566 .30467 Mdot
.566 .30467 Mdot
.566 .30468 Mdot
.566 .30468 Mdot
.566 .30468 Mdot
.566 .30469 Mdot
.566 .3047 Mdot
.566 .30471 Mdot
.566 .30471 Mdot
.566 .30473 Mdot
.566 .30474 Mdot
.566 .30475 Mdot
.566 .30475 Mdot
.566 .30478 Mdot
.566 .30479 Mdot
.566 .30482 Mdot
.566 .30482 Mdot
.566 .30484 Mdot
.566 .30484 Mdot
.566 .30484 Mdot
.566 .30484 Mdot
.566 .30485 Mdot
.566 .30485 Mdot
.566 .30486 Mdot
.566 .30486 Mdot
.566 .30487 Mdot
.566 .30487 Mdot
.566 .30487 Mdot
.566 .30488 Mdot
.566 .30488 Mdot
.566 .30488 Mdot
.566 .30489 Mdot
.566 .30489 Mdot
.566 .3049 Mdot
.566 .3049 Mdot
.566 .30492 Mdot
.566 .30493 Mdot
.566 .30493 Mdot
.566 .30494 Mdot
.566 .30494 Mdot
.566 .30495 Mdot
.566 .30495 Mdot
.566 .30496 Mdot
.566 .30496 Mdot
.566 .30497 Mdot
.566 .30497 Mdot
.566 .30498 Mdot
.566 .30498 Mdot
.566 .30499 Mdot
.566 .30499 Mdot
.566 .30499 Mdot
.566 .30499 Mdot
.566 .30499 Mdot
.566 .305 Mdot
.566 .30501 Mdot
.566 .30503 Mdot
.566 .30503 Mdot
.566 .30504 Mdot
.566 .30504 Mdot
.566 .30508 Mdot
.566 .30512 Mdot
.566 .30512 Mdot
.566 .30514 Mdot
.566 .30515 Mdot
.566 .30515 Mdot
.566 .30515 Mdot
.566 .30516 Mdot
.566 .30518 Mdot
.566 .30521 Mdot
.566 .30522 Mdot
.566 .30522 Mdot
.566 .30523 Mdot
.566 .30525 Mdot
.566 .30528 Mdot
.566 .30529 Mdot
.566 .30531 Mdot
.566 .30532 Mdot
.566 .30532 Mdot
.566 .30533 Mdot
.566 .30533 Mdot
.566 .30534 Mdot
.566 .30536 Mdot
.566 .30539 Mdot
.566 .30539 Mdot
.566 .30541 Mdot
.566 .30541 Mdot
.566 .30542 Mdot
.566 .30542 Mdot
.566 .30543 Mdot
.566 .30544 Mdot
.566 .30544 Mdot
.566 .30544 Mdot
.566 .30545 Mdot
.566 .30546 Mdot
.566 .30546 Mdot
.566 .30546 Mdot
.566 .30548 Mdot
.566 .30549 Mdot
.566 .30549 Mdot
.566 .3055 Mdot
.566 .30551 Mdot
.566 .30551 Mdot
.566 .30551 Mdot
.566 .30551 Mdot
.566 .30552 Mdot
.566 .30554 Mdot
.566 .30557 Mdot
.566 .30559 Mdot
.566 .30561 Mdot
.566 .30561 Mdot
.566 .30561 Mdot
.566 .30562 Mdot
.566 .30562 Mdot
.566 .30562 Mdot
.566 .30562 Mdot
.566 .30563 Mdot
.566 .30563 Mdot
.566 .30563 Mdot
.566 .30563 Mdot
.566 .30565 Mdot
.566 .30565 Mdot
.566 .30566 Mdot
.566 .30566 Mdot
.566 .30567 Mdot
.566 .30567 Mdot
.566 .30567 Mdot
.566 .30567 Mdot
.566 .30568 Mdot
.566 .30568 Mdot
.566 .30568 Mdot
.566 .30569 Mdot
.566 .3057 Mdot
.566 .3057 Mdot
.566 .3057 Mdot
.566 .30571 Mdot
.566 .30571 Mdot
.566 .30571 Mdot
.566 .30571 Mdot
.566 .30571 Mdot
.566 .30572 Mdot
.566 .30572 Mdot
.566 .30573 Mdot
.566 .30574 Mdot
.566 .30574 Mdot
.566 .30574 Mdot
.566 .30576 Mdot
.566 .30577 Mdot
.566 .30578 Mdot
.566 .30579 Mdot
.566 .3058 Mdot
.566 .3058 Mdot
.566 .30582 Mdot
.566 .30585 Mdot
.566 .30585 Mdot
.566 .30586 Mdot
.566 .30587 Mdot
.566 .30588 Mdot
.566 .30588 Mdot
.566 .30588 Mdot
.566 .30589 Mdot
.566 .30589 Mdot
.566 .30589 Mdot
.566 .3059 Mdot
.566 .30592 Mdot
.566 .30593 Mdot
.566 .30593 Mdot
.566 .30595 Mdot
.566 .30595 Mdot
.566 .30595 Mdot
.566 .30595 Mdot
.566 .30597 Mdot
.566 .30597 Mdot
.566 .30603 Mdot
.566 .30605 Mdot
.566 .30609 Mdot
.566 .30609 Mdot
.566 .30611 Mdot
.566 .30613 Mdot
.566 .30615 Mdot
.566 .30616 Mdot
.566 .30618 Mdot
.566 .30619 Mdot
.566 .30621 Mdot
.566 .30621 Mdot
.566 .30621 Mdot
.566 .30622 Mdot
.566 .30623 Mdot
.566 .30623 Mdot
.566 .30624 Mdot
.566 .30626 Mdot
.566 .30626 Mdot
.566 .30627 Mdot
.566 .30627 Mdot
.566 .30627 Mdot
.566 .30627 Mdot
.566 .30627 Mdot
.566 .3063 Mdot
.566 .30631 Mdot
.566 .30632 Mdot
.566 .30633 Mdot
.566 .30633 Mdot
.566 .30633 Mdot
.566 .30633 Mdot
.566 .30634 Mdot
.566 .30634 Mdot
.566 .30635 Mdot
.566 .30635 Mdot
.566 .30636 Mdot
.566 .30636 Mdot
.566 .30636 Mdot
.566 .30636 Mdot
.566 .30636 Mdot
.566 .30637 Mdot
.566 .30637 Mdot
.566 .30638 Mdot
.566 .30639 Mdot
.566 .30639 Mdot
.566 .30639 Mdot
.566 .3064 Mdot
.566 .30878 Mdot
.566 .30879 Mdot
.566 .30879 Mdot
.566 .30879 Mdot
.566 .3088 Mdot
.566 .30882 Mdot
.566 .30882 Mdot
.566 .30883 Mdot
.566 .30883 Mdot
.566 .30883 Mdot
.566 .30884 Mdot
.566 .30884 Mdot
.566 .30884 Mdot
.566 .30884 Mdot
.566 .30886 Mdot
.566 .30886 Mdot
.566 .30887 Mdot
.566 .30887 Mdot
.566 .30887 Mdot
.566 .30887 Mdot
.566 .30888 Mdot
.566 .30889 Mdot
.566 .30891 Mdot
.566 .30895 Mdot
.566 .30895 Mdot
.566 .30895 Mdot
.566 .30895 Mdot
.566 .30895 Mdot
.566 .30896 Mdot
.566 .30896 Mdot
.566 .30899 Mdot
.566 .309 Mdot
.566 .309 Mdot
.566 .30901 Mdot
.566 .30902 Mdot
.566 .30903 Mdot
.566 .30903 Mdot
.566 .30905 Mdot
.566 .30907 Mdot
.566 .30909 Mdot
.566 .3091 Mdot
.566 .30912 Mdot
.566 .30916 Mdot
.566 .30918 Mdot
.566 .30918 Mdot
.566 .30923 Mdot
.566 .30926 Mdot
.566 .30933 Mdot
.566 .30933 Mdot
.566 .30936 Mdot
.566 .30936 Mdot
.566 .30936 Mdot
.566 .30936 Mdot
.566 .30938 Mdot
.566 .30938 Mdot
.566 .3094 Mdot
.566 .30942 Mdot
.566 .30943 Mdot
.566 .30943 Mdot
.566 .30943 Mdot
.566 .30944 Mdot
.566 .30945 Mdot
.566 .30945 Mdot
.566 .30946 Mdot
.566 .30948 Mdot
.566 .30949 Mdot
.566 .30949 Mdot
.566 .30953 Mdot
.566 .30954 Mdot
.566 .30955 Mdot
.566 .30956 Mdot
.566 .30958 Mdot
.566 .30959 Mdot
.566 .3096 Mdot
.566 .30962 Mdot
.566 .30963 Mdot
.566 .30963 Mdot
.566 .30964 Mdot
.566 .30966 Mdot
.566 .30966 Mdot
.566 .30966 Mdot
.566 .30966 Mdot
.566 .30967 Mdot
.566 .30967 Mdot
.566 .30967 Mdot
.566 .30967 Mdot
.566 .30967 Mdot
.566 .30968 Mdot
.566 .30969 Mdot
.566 .3097 Mdot
.566 .3097 Mdot
.566 .30971 Mdot
.566 .30972 Mdot
.566 .30972 Mdot
.566 .30972 Mdot
.566 .30972 Mdot
.566 .30973 Mdot
.566 .30973 Mdot
.566 .30974 Mdot
.566 .30974 Mdot
.566 .30976 Mdot
.566 .30977 Mdot
.566 .30977 Mdot
.566 .30977 Mdot
.566 .30978 Mdot
.566 .30978 Mdot
.566 .30978 Mdot
.566 .30979 Mdot
.566 .30979 Mdot
.566 .30979 Mdot
.566 .3098 Mdot
.566 .30982 Mdot
.566 .30985 Mdot
.566 .30988 Mdot
.566 .30991 Mdot
.566 .30992 Mdot
.566 .30992 Mdot
.566 .30992 Mdot
.566 .30992 Mdot
.566 .30994 Mdot
.566 .30994 Mdot
.566 .30995 Mdot
.566 .30995 Mdot
.566 .30998 Mdot
.566 .30999 Mdot
.566 .30999 Mdot
.566 .31 Mdot
.566 .31001 Mdot
.566 .31001 Mdot
.566 .31001 Mdot
.566 .31003 Mdot
.566 .31003 Mdot
.566 .31004 Mdot
.566 .31004 Mdot
.566 .31005 Mdot
.566 .31007 Mdot
.566 .31007 Mdot
.566 .31011 Mdot
.566 .31014 Mdot
.566 .31015 Mdot
.566 .31016 Mdot
.566 .31016 Mdot
.566 .31016 Mdot
.566 .31018 Mdot
.566 .3102 Mdot
.566 .31022 Mdot
.566 .31026 Mdot
.566 .31028 Mdot
.566 .3103 Mdot
.566 .3103 Mdot
.566 .31031 Mdot
.566 .31035 Mdot
.566 .31037 Mdot
.566 .31038 Mdot
.566 .31038 Mdot
.566 .31039 Mdot
.566 .3104 Mdot
.566 .31042 Mdot
.566 .31042 Mdot
.566 .31047 Mdot
.566 .31052 Mdot
.566 .31053 Mdot
.566 .31054 Mdot
.566 .31054 Mdot
.566 .31057 Mdot
.566 .31057 Mdot
.566 .31058 Mdot
.566 .31058 Mdot
.566 .31059 Mdot
.566 .31059 Mdot
.566 .31059 Mdot
.566 .31059 Mdot
.566 .3106 Mdot
.566 .31062 Mdot
.566 .31062 Mdot
.566 .31062 Mdot
.566 .31064 Mdot
.566 .31064 Mdot
.566 .31065 Mdot
.566 .31066 Mdot
.566 .31067 Mdot
.566 .31067 Mdot
.566 .31068 Mdot
.566 .3107 Mdot
.566 .3107 Mdot
.566 .31071 Mdot
.566 .31072 Mdot
.566 .31073 Mdot
.566 .31073 Mdot
.566 .31073 Mdot
.566 .31074 Mdot
.566 .31074 Mdot
.566 .31074 Mdot
.566 .31075 Mdot
.566 .31076 Mdot
.566 .31077 Mdot
.566 .31077 Mdot
.566 .31078 Mdot
.566 .31078 Mdot
.566 .31078 Mdot
.566 .31078 Mdot
.566 .3108 Mdot
.566 .3108 Mdot
.566 .31084 Mdot
.566 .31086 Mdot
.566 .31089 Mdot
.566 .31089 Mdot
.566 .31091 Mdot
.566 .31093 Mdot
.566 .31094 Mdot
.566 .31095 Mdot
.566 .31096 Mdot
.566 .31097 Mdot
.566 .31098 Mdot
.566 .31099 Mdot
.566 .31099 Mdot
.566 .311 Mdot
.566 .311 Mdot
.566 .311 Mdot
.566 .31101 Mdot
.566 .31102 Mdot
.566 .31102 Mdot
.566 .31103 Mdot
.566 .31103 Mdot
.566 .31103 Mdot
.566 .31103 Mdot
.566 .31103 Mdot
.566 .31106 Mdot
.566 .31107 Mdot
.566 .31108 Mdot
.566 .31108 Mdot
.566 .31108 Mdot
.566 .31108 Mdot
.566 .31108 Mdot
.566 .31109 Mdot
.566 .31109 Mdot
.566 .3111 Mdot
.566 .3111 Mdot
.566 .3111 Mdot
.566 .3111 Mdot
.566 .3111 Mdot
.566 .31111 Mdot
.566 .31111 Mdot
.566 .31111 Mdot
.566 .31111 Mdot
.566 .31112 Mdot
.566 .31113 Mdot
.566 .31113 Mdot
.566 .31113 Mdot
.566 .31113 Mdot
.566 .34282 Mdot
.566 .34283 Mdot
.566 .34283 Mdot
.566 .34283 Mdot
.566 .34283 Mdot
.566 .34284 Mdot
.566 .34284 Mdot
.566 .34285 Mdot
.566 .34285 Mdot
.566 .34285 Mdot
.566 .34285 Mdot
.566 .34285 Mdot
.566 .34285 Mdot
.566 .34286 Mdot
.566 .34286 Mdot
.566 .34287 Mdot
.566 .34287 Mdot
.566 .34287 Mdot
.566 .34287 Mdot
.566 .34287 Mdot
.566 .34288 Mdot
.566 .34288 Mdot
.566 .34289 Mdot
.566 .34291 Mdot
.566 .34291 Mdot
.566 .34291 Mdot
.566 .34292 Mdot
.566 .34292 Mdot
.566 .34292 Mdot
.566 .34292 Mdot
.566 .34294 Mdot
.566 .34294 Mdot
.566 .34294 Mdot
.566 .34295 Mdot
.566 .34295 Mdot
.566 .34296 Mdot
.566 .34296 Mdot
.566 .34297 Mdot
.566 .34298 Mdot
.566 .34299 Mdot
.566 .34299 Mdot
.566 .34301 Mdot
.566 .34303 Mdot
.566 .34304 Mdot
.566 .34304 Mdot
.566 .34306 Mdot
.566 .34308 Mdot
.566 .34312 Mdot
.566 .34312 Mdot
.566 .34313 Mdot
.566 .34313 Mdot
.566 .34314 Mdot
.566 .34314 Mdot
.566 .34314 Mdot
.566 .34314 Mdot
.566 .34315 Mdot
.566 .34316 Mdot
.566 .34317 Mdot
.566 .34317 Mdot
.566 .34317 Mdot
.566 .34318 Mdot
.566 .34318 Mdot
.566 .34318 Mdot
.566 .34319 Mdot
.566 .3432 Mdot
.566 .3432 Mdot
.566 .3432 Mdot
.566 .34322 Mdot
.566 .34323 Mdot
.566 .34324 Mdot
.566 .34324 Mdot
.566 .34325 Mdot
.566 .34326 Mdot
.566 .34326 Mdot
.566 .34328 Mdot
.566 .34328 Mdot
.566 .34328 Mdot
.566 .34329 Mdot
.566 .3433 Mdot
.566 .3433 Mdot
.566 .3433 Mdot
.566 .3433 Mdot
.566 .34331 Mdot
.566 .34331 Mdot
.566 .34332 Mdot
.566 .34333 Mdot
.566 .34335 Mdot
.566 .34335 Mdot
.566 .34336 Mdot
.566 .34336 Mdot
.566 .34341 Mdot
.566 .34345 Mdot
.566 .34345 Mdot
.566 .34347 Mdot
.566 .34348 Mdot
.566 .34349 Mdot
.566 .34349 Mdot
.566 .3435 Mdot
.566 .34352 Mdot
.566 .34355 Mdot
.566 .34356 Mdot
.566 .34356 Mdot
.566 .34358 Mdot
.566 .3436 Mdot
.566 .34363 Mdot
.566 .34365 Mdot
.566 .34367 Mdot
.566 .34368 Mdot
.566 .34369 Mdot
.566 .34369 Mdot
.566 .34369 Mdot
.566 .3437 Mdot
.566 .34373 Mdot
.566 .34376 Mdot
.566 .34376 Mdot
.566 .34378 Mdot
.566 .34379 Mdot
.566 .34379 Mdot
.566 .3438 Mdot
.566 .3438 Mdot
.566 .34381 Mdot
.566 .34381 Mdot
.566 .34382 Mdot
.566 .34383 Mdot
.566 .34383 Mdot
.566 .34384 Mdot
.566 .34384 Mdot
.566 .34387 Mdot
.566 .34387 Mdot
.566 .34388 Mdot
.566 .34388 Mdot
.566 .34389 Mdot
.566 .34389 Mdot
.566 .3439 Mdot
.566 .3439 Mdot
.566 .3439 Mdot
.566 .34393 Mdot
.566 .34396 Mdot
.566 .34398 Mdot
.566 .344 Mdot
.566 .34401 Mdot
.566 .34401 Mdot
.566 .34401 Mdot
.566 .34402 Mdot
.566 .34402 Mdot
.566 .34402 Mdot
.566 .34403 Mdot
.566 .34403 Mdot
.566 .34403 Mdot
.566 .34403 Mdot
.566 .34405 Mdot
.566 .34406 Mdot
.566 .34406 Mdot
.566 .34406 Mdot
.566 .34407 Mdot
.566 .34407 Mdot
.566 .34408 Mdot
.566 .34408 Mdot
.566 .34409 Mdot
.566 .34409 Mdot
.566 .34409 Mdot
.566 .3441 Mdot
.566 .3441 Mdot
.566 .34411 Mdot
.566 .34411 Mdot
.566 .34412 Mdot
.566 .34412 Mdot
.566 .34412 Mdot
.566 .34413 Mdot
.566 .34413 Mdot
.566 .34413 Mdot
.566 .34413 Mdot
.566 .34414 Mdot
.566 .34415 Mdot
.566 .34415 Mdot
.566 .34416 Mdot
.566 .34418 Mdot
.566 .34419 Mdot
.566 .3442 Mdot
.566 .34421 Mdot
.566 .34422 Mdot
.566 .34423 Mdot
.566 .34424 Mdot
.566 .34428 Mdot
.566 .34428 Mdot
.566 .34429 Mdot
.566 .3443 Mdot
.566 .34431 Mdot
.566 .34431 Mdot
.566 .34432 Mdot
.566 .34433 Mdot
.566 .34433 Mdot
.566 .34433 Mdot
.566 .34434 Mdot
.566 .34436 Mdot
.566 .34438 Mdot
.566 .34438 Mdot
.566 .34439 Mdot
.566 .34439 Mdot
.566 .34439 Mdot
.566 .34439 Mdot
.566 .34442 Mdot
.566 .34442 Mdot
.566 .34448 Mdot
.566 .34451 Mdot
.566 .34455 Mdot
.566 .34455 Mdot
.566 .34457 Mdot
.566 .3446 Mdot
.566 .34462 Mdot
.566 .34463 Mdot
.566 .34465 Mdot
.566 .34467 Mdot
.566 .34468 Mdot
.566 .34469 Mdot
.566 .34469 Mdot
.566 .3447 Mdot
.566 .34471 Mdot
.566 .34471 Mdot
.566 .34472 Mdot
.566 .34474 Mdot
.566 .34474 Mdot
.566 .34475 Mdot
.566 .34475 Mdot
.566 .34475 Mdot
.566 .34475 Mdot
.566 .34475 Mdot
.566 .34479 Mdot
.566 .34481 Mdot
.566 .34482 Mdot
.566 .34482 Mdot
.566 .34482 Mdot
.566 .34483 Mdot
.566 .34483 Mdot
.566 .34483 Mdot
.566 .34483 Mdot
.566 .34485 Mdot
.566 .34485 Mdot
.566 .34485 Mdot
.566 .34485 Mdot
.566 .34486 Mdot
.566 .34486 Mdot
.566 .34486 Mdot
.566 .34487 Mdot
.566 .34487 Mdot
.566 .34488 Mdot
.566 .34489 Mdot
.566 .34489 Mdot
.566 .34489 Mdot
.566 .3449 Mdot
.566 .34701 Mdot
.566 .34701 Mdot
.566 .34701 Mdot
.566 .34701 Mdot
.566 .34702 Mdot
.566 .34703 Mdot
.566 .34703 Mdot
.566 .34704 Mdot
.566 .34704 Mdot
.566 .34704 Mdot
.566 .34704 Mdot
.566 .34704 Mdot
.566 .34705 Mdot
.566 .34705 Mdot
.566 .34706 Mdot
.566 .34706 Mdot
.566 .34707 Mdot
.566 .34707 Mdot
.566 .34707 Mdot
.566 .34707 Mdot
.566 .34707 Mdot
.566 .34708 Mdot
.566 .34709 Mdot
.566 .34712 Mdot
.566 .34712 Mdot
.566 .34712 Mdot
.566 .34712 Mdot
.566 .34712 Mdot
.566 .34713 Mdot
.566 .34713 Mdot
.566 .34715 Mdot
.566 .34715 Mdot
.566 .34716 Mdot
.566 .34716 Mdot
.566 .34717 Mdot
.566 .34718 Mdot
.566 .34718 Mdot
.566 .34719 Mdot
.566 .3472 Mdot
.566 .34722 Mdot
.566 .34723 Mdot
.566 .34724 Mdot
.566 .34727 Mdot
.566 .34728 Mdot
.566 .34728 Mdot
.566 .34731 Mdot
.566 .34734 Mdot
.566 .34738 Mdot
.566 .34738 Mdot
.566 .3474 Mdot
.566 .34741 Mdot
.566 .34741 Mdot
.566 .34741 Mdot
.566 .34742 Mdot
.566 .34742 Mdot
.566 .34743 Mdot
.566 .34744 Mdot
.566 .34745 Mdot
.566 .34745 Mdot
.566 .34746 Mdot
.566 .34746 Mdot
.566 .34747 Mdot
.566 .34747 Mdot
.566 .34748 Mdot
.566 .34749 Mdot
.566 .34749 Mdot
.566 .34749 Mdot
.566 .34752 Mdot
.566 .34753 Mdot
.566 .34754 Mdot
.566 .34755 Mdot
.566 .34755 Mdot
.566 .34756 Mdot
.566 .34757 Mdot
.566 .34759 Mdot
.566 .34759 Mdot
.566 .34759 Mdot
.566 .3476 Mdot
.566 .34761 Mdot
.566 .34761 Mdot
.566 .34761 Mdot
.566 .34761 Mdot
.566 .34762 Mdot
.566 .34762 Mdot
.566 .34762 Mdot
.566 .34762 Mdot
.566 .34762 Mdot
.566 .34763 Mdot
.566 .34763 Mdot
.566 .34764 Mdot
.566 .34764 Mdot
.566 .34764 Mdot
.566 .34765 Mdot
.566 .34765 Mdot
.566 .34765 Mdot
.566 .34765 Mdot
.566 .34766 Mdot
.566 .34766 Mdot
.566 .34766 Mdot
.566 .34767 Mdot
.566 .34768 Mdot
.566 .34768 Mdot
.566 .34768 Mdot
.566 .34769 Mdot
.566 .34769 Mdot
.566 .3477 Mdot
.566 .3477 Mdot
.566 .3477 Mdot
.566 .3477 Mdot
.566 .3477 Mdot
.566 .34771 Mdot
.566 .34772 Mdot
.566 .34774 Mdot
.566 .34776 Mdot
.566 .34779 Mdot
.566 .34779 Mdot
.566 .34779 Mdot
.566 .34779 Mdot
.566 .34779 Mdot
.566 .3478 Mdot
.566 .34781 Mdot
.566 .34781 Mdot
.566 .34781 Mdot
.566 .34784 Mdot
.566 .34784 Mdot
.566 .34784 Mdot
.566 .34785 Mdot
.566 .34785 Mdot
.566 .34786 Mdot
.566 .34786 Mdot
.566 .34786 Mdot
.566 .34787 Mdot
.566 .34787 Mdot
.566 .34788 Mdot
.566 .34788 Mdot
.566 .3479 Mdot
.566 .3479 Mdot
.566 .34792 Mdot
.566 .34794 Mdot
.566 .34795 Mdot
.566 .34795 Mdot
.566 .34796 Mdot
.566 .34796 Mdot
.566 .34797 Mdot
.566 .34799 Mdot
.566 .348 Mdot
.566 .34802 Mdot
.566 .34804 Mdot
.566 .34805 Mdot
.566 .34805 Mdot
.566 .34806 Mdot
.566 .34809 Mdot
.566 .3481 Mdot
.566 .34811 Mdot
.566 .34811 Mdot
.566 .34811 Mdot
.566 .34812 Mdot
.566 .34814 Mdot
.566 .34814 Mdot
.566 .34817 Mdot
.566 .34821 Mdot
.566 .34821 Mdot
.566 .34822 Mdot
.566 .34822 Mdot
.566 .34824 Mdot
.566 .34824 Mdot
.566 .34825 Mdot
.566 .34825 Mdot
.566 .34825 Mdot
.566 .34825 Mdot
.566 .34826 Mdot
.566 .34826 Mdot
.566 .34826 Mdot
.566 .34827 Mdot
.566 .34827 Mdot
.566 .34827 Mdot
.566 .34828 Mdot
.566 .34828 Mdot
.566 .34829 Mdot
.566 .34829 Mdot
.566 .3483 Mdot
.566 .3483 Mdot
.566 .34831 Mdot
.566 .34832 Mdot
.566 .34833 Mdot
.566 .34833 Mdot
.566 .34834 Mdot
.566 .34834 Mdot
.566 .34835 Mdot
.566 .34835 Mdot
.566 .34835 Mdot
.566 .34836 Mdot
.566 .34836 Mdot
.566 .34836 Mdot
.566 .34837 Mdot
.566 .34838 Mdot
.566 .34838 Mdot
.566 .34838 Mdot
.566 .34838 Mdot
.566 .34839 Mdot
.566 .34839 Mdot
.566 .3484 Mdot
.566 .3484 Mdot
.566 .34843 Mdot
.566 .34844 Mdot
.566 .34846 Mdot
.566 .34846 Mdot
.566 .34847 Mdot
.566 .34848 Mdot
.566 .34849 Mdot
.566 .3485 Mdot
.566 .34851 Mdot
.566 .34852 Mdot
.566 .34852 Mdot
.566 .34853 Mdot
.566 .34853 Mdot
.566 .34853 Mdot
.566 .34854 Mdot
.566 .34854 Mdot
.566 .34854 Mdot
.566 .34855 Mdot
.566 .34855 Mdot
.566 .34856 Mdot
.566 .34856 Mdot
.566 .34856 Mdot
.566 .34856 Mdot
.566 .34856 Mdot
.566 .34857 Mdot
.566 .34858 Mdot
.566 .34859 Mdot
.566 .34859 Mdot
.566 .34859 Mdot
.566 .34859 Mdot
.566 .34859 Mdot
.566 .3486 Mdot
.566 .3486 Mdot
.566 .3486 Mdot
.566 .3486 Mdot
.566 .34861 Mdot
.566 .34861 Mdot
.566 .34861 Mdot
.566 .34861 Mdot
.566 .34861 Mdot
.566 .34861 Mdot
.566 .34861 Mdot
.566 .34862 Mdot
.566 .34862 Mdot
.566 .34862 Mdot
.566 .34862 Mdot
.566 .34863 Mdot
.568 .30425 Mdot
.568 .30425 Mdot
.568 .30426 Mdot
.568 .30426 Mdot
.568 .30427 Mdot
.568 .30429 Mdot
.568 .30429 Mdot
.568 .3043 Mdot
.568 .30432 Mdot
.568 .30432 Mdot
.568 .30434 Mdot
.568 .30434 Mdot
.568 .30435 Mdot
.568 .30436 Mdot
.568 .30436 Mdot
.568 .30437 Mdot
.568 .30437 Mdot
.568 .30437 Mdot
.568 .30438 Mdot
.568 .30438 Mdot
.568 .30438 Mdot
.568 .30439 Mdot
.568 .3044 Mdot
.568 .30441 Mdot
.568 .30441 Mdot
.568 .30442 Mdot
.568 .30443 Mdot
.568 .30443 Mdot
.568 .30443 Mdot
.568 .30443 Mdot
.568 .30446 Mdot
.568 .30447 Mdot
.568 .30447 Mdot
.568 .30447 Mdot
.568 .30448 Mdot
.568 .30448 Mdot
.568 .3045 Mdot
.568 .30451 Mdot
.568 .30451 Mdot
.568 .30451 Mdot
.568 .30452 Mdot
.568 .30452 Mdot
.568 .30452 Mdot
.568 .30452 Mdot
.568 .30452 Mdot
.568 .30453 Mdot
.568 .30453 Mdot
.568 .30453 Mdot
.568 .30456 Mdot
.568 .30456 Mdot
.568 .30457 Mdot
.568 .30457 Mdot
.568 .30458 Mdot
.568 .30458 Mdot
.568 .30461 Mdot
.568 .30461 Mdot
.568 .30463 Mdot
.568 .30463 Mdot
.568 .30463 Mdot
.568 .30463 Mdot
.568 .30465 Mdot
.568 .30466 Mdot
.568 .30466 Mdot
.568 .30467 Mdot
.568 .30467 Mdot
.568 .30468 Mdot
.568 .30468 Mdot
.568 .30469 Mdot
.568 .30469 Mdot
.568 .3047 Mdot
.568 .3047 Mdot
.568 .3047 Mdot
.568 .30471 Mdot
.568 .30471 Mdot
.568 .30472 Mdot
.568 .30473 Mdot
.568 .30474 Mdot
.568 .30478 Mdot
.568 .30479 Mdot
.568 .30479 Mdot
.568 .30479 Mdot
.568 .30481 Mdot
.568 .30481 Mdot
.568 .30482 Mdot
.568 .30483 Mdot
.568 .30483 Mdot
.568 .30483 Mdot
.568 .30483 Mdot
.568 .30483 Mdot
.568 .30484 Mdot
.568 .30485 Mdot
.568 .30485 Mdot
.568 .30486 Mdot
.568 .30487 Mdot
.568 .30487 Mdot
.568 .30489 Mdot
.568 .30489 Mdot
.568 .3049 Mdot
.568 .3049 Mdot
.568 .3049 Mdot
.568 .30491 Mdot
.568 .30491 Mdot
.568 .30495 Mdot
.568 .30495 Mdot
.568 .30496 Mdot
.568 .30497 Mdot
.568 .30497 Mdot
.568 .30499 Mdot
.568 .305 Mdot
.568 .30501 Mdot
.568 .30501 Mdot
.568 .30502 Mdot
.568 .30504 Mdot
.568 .30507 Mdot
.568 .30507 Mdot
.568 .30507 Mdot
.568 .30507 Mdot
.568 .30508 Mdot
.568 .30508 Mdot
.568 .30509 Mdot
.568 .3051 Mdot
.568 .30511 Mdot
.568 .30511 Mdot
.568 .30512 Mdot
.568 .30514 Mdot
.568 .30515 Mdot
.568 .30517 Mdot
.568 .30517 Mdot
.568 .30518 Mdot
.568 .30518 Mdot
.568 .30519 Mdot
.568 .3052 Mdot
.568 .3052 Mdot
.568 .3052 Mdot
.568 .30521 Mdot
.568 .30521 Mdot
.568 .30522 Mdot
.568 .30523 Mdot
.568 .30524 Mdot
.568 .30524 Mdot
.568 .30524 Mdot
.568 .30524 Mdot
.568 .30525 Mdot
.568 .30526 Mdot
.568 .30527 Mdot
.568 .30527 Mdot
.568 .30528 Mdot
.568 .30529 Mdot
.568 .3053 Mdot
.568 .3053 Mdot
.568 .3053 Mdot
.568 .30531 Mdot
.568 .30531 Mdot
.568 .30531 Mdot
.568 .30532 Mdot
.568 .30533 Mdot
.568 .30533 Mdot
.568 .30533 Mdot
.568 .30533 Mdot
.568 .30534 Mdot
.568 .30536 Mdot
.568 .30537 Mdot
.568 .30538 Mdot
.568 .30539 Mdot
.568 .30539 Mdot
.568 .30539 Mdot
.568 .30544 Mdot
.568 .30545 Mdot
.568 .30546 Mdot
.568 .30546 Mdot
.568 .30547 Mdot
.568 .30548 Mdot
.568 .3055 Mdot
.568 .3055 Mdot
.568 .30551 Mdot
.568 .30552 Mdot
.568 .30553 Mdot
.568 .30553 Mdot
.568 .30553 Mdot
.568 .30554 Mdot
.568 .30554 Mdot
.568 .30555 Mdot
.568 .30555 Mdot
.568 .30555 Mdot
.568 .30557 Mdot
.568 .30557 Mdot
.568 .30558 Mdot
.568 .30558 Mdot
.568 .30558 Mdot
.568 .30558 Mdot
.568 .30561 Mdot
.568 .30564 Mdot
.568 .30564 Mdot
.568 .30564 Mdot
.568 .30564 Mdot
.568 .30566 Mdot
.568 .30567 Mdot
.568 .30571 Mdot
.568 .30573 Mdot
.568 .30573 Mdot
.568 .30573 Mdot
.568 .30575 Mdot
.568 .30575 Mdot
.568 .3058 Mdot
.568 .3058 Mdot
.568 .30581 Mdot
.568 .30581 Mdot
.568 .30582 Mdot
.568 .30582 Mdot
.568 .30582 Mdot
.568 .30582 Mdot
.568 .30583 Mdot
.568 .30584 Mdot
.568 .30584 Mdot
.568 .30586 Mdot
.568 .30589 Mdot
.568 .3059 Mdot
.568 .30591 Mdot
.568 .30591 Mdot
.568 .30593 Mdot
.568 .30596 Mdot
.568 .30597 Mdot
.568 .30597 Mdot
.568 .30597 Mdot
.568 .30599 Mdot
.568 .306 Mdot
.568 .30601 Mdot
.568 .30601 Mdot
.568 .30603 Mdot
.568 .30605 Mdot
.568 .30605 Mdot
.568 .30605 Mdot
.568 .30607 Mdot
.568 .30607 Mdot
.568 .30607 Mdot
.568 .30608 Mdot
.568 .30609 Mdot
.568 .30611 Mdot
.568 .30612 Mdot
.568 .30612 Mdot
.568 .30612 Mdot
.568 .30616 Mdot
.568 .30616 Mdot
.568 .30619 Mdot
.568 .3062 Mdot
.568 .30621 Mdot
.568 .30624 Mdot
.568 .30625 Mdot
.568 .30626 Mdot
.568 .30627 Mdot
.568 .30628 Mdot
.568 .30866 Mdot
.568 .30866 Mdot
.568 .30868 Mdot
.568 .30869 Mdot
.568 .3087 Mdot
.568 .30874 Mdot
.568 .30875 Mdot
.568 .30877 Mdot
.568 .30881 Mdot
.568 .30881 Mdot
.568 .30885 Mdot
.568 .30885 Mdot
.568 .30886 Mdot
.568 .30887 Mdot
.568 .3089 Mdot
.568 .3089 Mdot
.568 .30892 Mdot
.568 .30893 Mdot
.568 .30893 Mdot
.568 .30894 Mdot
.568 .30894 Mdot
.568 .30894 Mdot
.568 .30897 Mdot
.568 .309 Mdot
.568 .309 Mdot
.568 .30902 Mdot
.568 .30902 Mdot
.568 .30905 Mdot
.568 .30905 Mdot
.568 .30905 Mdot
.568 .30906 Mdot
.568 .3091 Mdot
.568 .30913 Mdot
.568 .30913 Mdot
.568 .30914 Mdot
.568 .30915 Mdot
.568 .30919 Mdot
.568 .30921 Mdot
.568 .30921 Mdot
.568 .30923 Mdot
.568 .30924 Mdot
.568 .30924 Mdot
.568 .30924 Mdot
.568 .30924 Mdot
.568 .30925 Mdot
.568 .30926 Mdot
.568 .30927 Mdot
.568 .30927 Mdot
.568 .30933 Mdot
.568 .30934 Mdot
.568 .30935 Mdot
.568 .30936 Mdot
.568 .30936 Mdot
.568 .30938 Mdot
.568 .30944 Mdot
.568 .30945 Mdot
.568 .30947 Mdot
.568 .30947 Mdot
.568 .30948 Mdot
.568 .30948 Mdot
.568 .30952 Mdot
.568 .30955 Mdot
.568 .30955 Mdot
.568 .30955 Mdot
.568 .30955 Mdot
.568 .30956 Mdot
.568 .30957 Mdot
.568 .30959 Mdot
.568 .30959 Mdot
.568 .30959 Mdot
.568 .3096 Mdot
.568 .3096 Mdot
.568 .30961 Mdot
.568 .30962 Mdot
.568 .30962 Mdot
.568 .30964 Mdot
.568 .30964 Mdot
.568 .30965 Mdot
.568 .30966 Mdot
.568 .30968 Mdot
.568 .30969 Mdot
.568 .3097 Mdot
.568 .30971 Mdot
.568 .30972 Mdot
.568 .30974 Mdot
.568 .3098 Mdot
.568 .3098 Mdot
.568 .3098 Mdot
.568 .30981 Mdot
.568 .30983 Mdot
.568 .30983 Mdot
.568 .30986 Mdot
.568 .30987 Mdot
.568 .30988 Mdot
.568 .30988 Mdot
.568 .30988 Mdot
.568 .30989 Mdot
.568 .3099 Mdot
.568 .3099 Mdot
.568 .30991 Mdot
.568 .30991 Mdot
.568 .30991 Mdot
.568 .30991 Mdot
.568 .30992 Mdot
.568 .30995 Mdot
.568 .30995 Mdot
.568 .30995 Mdot
.568 .30996 Mdot
.568 .30998 Mdot
.568 .30999 Mdot
.568 .31 Mdot
.568 .31 Mdot
.568 .31 Mdot
.568 .31 Mdot
.568 .31002 Mdot
.568 .31002 Mdot
.568 .31003 Mdot
.568 .31004 Mdot
.568 .31005 Mdot
.568 .31005 Mdot
.568 .31006 Mdot
.568 .31006 Mdot
.568 .31007 Mdot
.568 .31008 Mdot
.568 .31008 Mdot
.568 .31011 Mdot
.568 .31013 Mdot
.568 .31015 Mdot
.568 .31015 Mdot
.568 .31016 Mdot
.568 .31017 Mdot
.568 .31018 Mdot
.568 .3102 Mdot
.568 .3102 Mdot
.568 .31021 Mdot
.568 .31021 Mdot
.568 .31021 Mdot
.568 .31022 Mdot
.568 .31025 Mdot
.568 .31028 Mdot
.568 .31029 Mdot
.568 .31029 Mdot
.568 .3103 Mdot
.568 .31032 Mdot
.568 .31034 Mdot
.568 .31034 Mdot
.568 .31035 Mdot
.568 .31036 Mdot
.568 .31037 Mdot
.568 .31042 Mdot
.568 .31042 Mdot
.568 .31043 Mdot
.568 .31043 Mdot
.568 .31044 Mdot
.568 .31044 Mdot
.568 .31044 Mdot
.568 .31047 Mdot
.568 .31047 Mdot
.568 .31048 Mdot
.568 .31049 Mdot
.568 .3105 Mdot
.568 .31051 Mdot
.568 .31052 Mdot
.568 .31052 Mdot
.568 .31052 Mdot
.568 .31052 Mdot
.568 .31052 Mdot
.568 .31053 Mdot
.568 .31054 Mdot
.568 .31055 Mdot
.568 .31057 Mdot
.568 .31057 Mdot
.568 .31058 Mdot
.568 .31059 Mdot
.568 .31064 Mdot
.568 .31065 Mdot
.568 .31066 Mdot
.568 .31067 Mdot
.568 .31068 Mdot
.568 .31068 Mdot
.568 .31068 Mdot
.568 .31069 Mdot
.568 .3107 Mdot
.568 .31071 Mdot
.568 .31071 Mdot
.568 .31071 Mdot
.568 .31072 Mdot
.568 .31073 Mdot
.568 .31074 Mdot
.568 .31074 Mdot
.568 .31075 Mdot
.568 .31078 Mdot
.568 .31078 Mdot
.568 .31078 Mdot
.568 .31078 Mdot
.568 .3108 Mdot
.568 .3108 Mdot
.568 .31084 Mdot
.568 .31085 Mdot
.568 .31085 Mdot
.568 .31085 Mdot
.568 .31086 Mdot
.568 .31087 Mdot
.568 .3109 Mdot
.568 .3109 Mdot
.568 .31091 Mdot
.568 .31092 Mdot
.568 .31092 Mdot
.568 .31092 Mdot
.568 .31092 Mdot
.568 .31092 Mdot
.568 .31093 Mdot
.568 .31094 Mdot
.568 .31094 Mdot
.568 .31095 Mdot
.568 .31098 Mdot
.568 .31098 Mdot
.568 .31099 Mdot
.568 .31099 Mdot
.568 .311 Mdot
.568 .31103 Mdot
.568 .31103 Mdot
.568 .31104 Mdot
.568 .31104 Mdot
.568 .31105 Mdot
.568 .31106 Mdot
.568 .31106 Mdot
.568 .31107 Mdot
.568 .31108 Mdot
.568 .3111 Mdot
.568 .3111 Mdot
.568 .3111 Mdot
.568 .31111 Mdot
.568 .31111 Mdot
.568 .31111 Mdot
.568 .31112 Mdot
.568 .31113 Mdot
.568 .31114 Mdot
.568 .31115 Mdot
.568 .31115 Mdot
.568 .31118 Mdot
.568 .31118 Mdot
.568 .3112 Mdot
.568 .31121 Mdot
.568 .31122 Mdot
.568 .31125 Mdot
.568 .31125 Mdot
.568 .31126 Mdot
.568 .31127 Mdot
.568 .31127 Mdot
.568 .34362 Mdot
.568 .34362 Mdot
.568 .34364 Mdot
.568 .34364 Mdot
.568 .34365 Mdot
.568 .34367 Mdot
.568 .34368 Mdot
.568 .34368 Mdot
.568 .3437 Mdot
.568 .3437 Mdot
.568 .34373 Mdot
.568 .34373 Mdot
.568 .34374 Mdot
.568 .34375 Mdot
.568 .34375 Mdot
.568 .34377 Mdot
.568 .34377 Mdot
.568 .34377 Mdot
.568 .34377 Mdot
.568 .34377 Mdot
.568 .34378 Mdot
.568 .34379 Mdot
.568 .3438 Mdot
.568 .34381 Mdot
.568 .34381 Mdot
.568 .34382 Mdot
.568 .34383 Mdot
.568 .34383 Mdot
.568 .34383 Mdot
.568 .34384 Mdot
.568 .34386 Mdot
.568 .34387 Mdot
.568 .34388 Mdot
.568 .34388 Mdot
.568 .34388 Mdot
.568 .34391 Mdot
.568 .34392 Mdot
.568 .34392 Mdot
.568 .34392 Mdot
.568 .34393 Mdot
.568 .34393 Mdot
.568 .34393 Mdot
.568 .34393 Mdot
.568 .34394 Mdot
.568 .34394 Mdot
.568 .34395 Mdot
.568 .34395 Mdot
.568 .34398 Mdot
.568 .34398 Mdot
.568 .34399 Mdot
.568 .34399 Mdot
.568 .344 Mdot
.568 .34401 Mdot
.568 .34404 Mdot
.568 .34404 Mdot
.568 .34405 Mdot
.568 .34406 Mdot
.568 .34406 Mdot
.568 .34406 Mdot
.568 .34408 Mdot
.568 .34409 Mdot
.568 .3441 Mdot
.568 .3441 Mdot
.568 .34411 Mdot
.568 .34412 Mdot
.568 .34412 Mdot
.568 .34412 Mdot
.568 .34413 Mdot
.568 .34413 Mdot
.568 .34414 Mdot
.568 .34414 Mdot
.568 .34415 Mdot
.568 .34415 Mdot
.568 .34417 Mdot
.568 .34418 Mdot
.568 .34418 Mdot
.568 .34423 Mdot
.568 .34424 Mdot
.568 .34424 Mdot
.568 .34424 Mdot
.568 .34426 Mdot
.568 .34427 Mdot
.568 .34428 Mdot
.568 .34428 Mdot
.568 .34428 Mdot
.568 .34428 Mdot
.568 .34429 Mdot
.568 .34429 Mdot
.568 .34429 Mdot
.568 .34431 Mdot
.568 .34431 Mdot
.568 .34432 Mdot
.568 .34433 Mdot
.568 .34433 Mdot
.568 .34436 Mdot
.568 .34436 Mdot
.568 .34436 Mdot
.568 .34436 Mdot
.568 .34437 Mdot
.568 .34438 Mdot
.568 .34438 Mdot
.568 .34442 Mdot
.568 .34442 Mdot
.568 .34443 Mdot
.568 .34444 Mdot
.568 .34445 Mdot
.568 .34446 Mdot
.568 .34448 Mdot
.568 .34448 Mdot
.568 .34449 Mdot
.568 .3445 Mdot
.568 .34453 Mdot
.568 .34455 Mdot
.568 .34456 Mdot
.568 .34456 Mdot
.568 .34456 Mdot
.568 .34456 Mdot
.568 .34457 Mdot
.568 .34458 Mdot
.568 .34459 Mdot
.568 .3446 Mdot
.568 .34461 Mdot
.568 .34461 Mdot
.568 .34463 Mdot
.568 .34464 Mdot
.568 .34467 Mdot
.568 .34467 Mdot
.568 .34468 Mdot
.568 .34469 Mdot
.568 .3447 Mdot
.568 .3447 Mdot
.568 .3447 Mdot
.568 .34471 Mdot
.568 .34472 Mdot
.568 .34472 Mdot
.568 .34472 Mdot
.568 .34475 Mdot
.568 .34475 Mdot
.568 .34475 Mdot
.568 .34475 Mdot
.568 .34476 Mdot
.568 .34476 Mdot
.568 .34478 Mdot
.568 .34478 Mdot
.568 .34479 Mdot
.568 .34479 Mdot
.568 .34481 Mdot
.568 .34482 Mdot
.568 .34482 Mdot
.568 .34482 Mdot
.568 .34483 Mdot
.568 .34483 Mdot
.568 .34483 Mdot
.568 .34484 Mdot
.568 .34485 Mdot
.568 .34485 Mdot
.568 .34485 Mdot
.568 .34486 Mdot
.568 .34486 Mdot
.568 .34489 Mdot
.568 .3449 Mdot
.568 .34491 Mdot
.568 .34492 Mdot
.568 .34492 Mdot
.568 .34492 Mdot
.568 .34498 Mdot
.568 .34499 Mdot
.568 .345 Mdot
.568 .34501 Mdot
.568 .34502 Mdot
.568 .34502 Mdot
.568 .34504 Mdot
.568 .34505 Mdot
.568 .34506 Mdot
.568 .34506 Mdot
.568 .34508 Mdot
.568 .34508 Mdot
.568 .34508 Mdot
.568 .34509 Mdot
.568 .34509 Mdot
.568 .3451 Mdot
.568 .34511 Mdot
.568 .34511 Mdot
.568 .34512 Mdot
.568 .34513 Mdot
.568 .34514 Mdot
.568 .34514 Mdot
.568 .34514 Mdot
.568 .34514 Mdot
.568 .34517 Mdot
.568 .3452 Mdot
.568 .3452 Mdot
.568 .34521 Mdot
.568 .34521 Mdot
.568 .34523 Mdot
.568 .34524 Mdot
.568 .34529 Mdot
.568 .34531 Mdot
.568 .34531 Mdot
.568 .34531 Mdot
.568 .34533 Mdot
.568 .34533 Mdot
.568 .34538 Mdot
.568 .34539 Mdot
.568 .3454 Mdot
.568 .3454 Mdot
.568 .34541 Mdot
.568 .34541 Mdot
.568 .34541 Mdot
.568 .34541 Mdot
.568 .34542 Mdot
.568 .34544 Mdot
.568 .34544 Mdot
.568 .34546 Mdot
.568 .34549 Mdot
.568 .3455 Mdot
.568 .34551 Mdot
.568 .34551 Mdot
.568 .34553 Mdot
.568 .34557 Mdot
.568 .34558 Mdot
.568 .34558 Mdot
.568 .34558 Mdot
.568 .34561 Mdot
.568 .34561 Mdot
.568 .34562 Mdot
.568 .34563 Mdot
.568 .34565 Mdot
.568 .34567 Mdot
.568 .34568 Mdot
.568 .34568 Mdot
.568 .34569 Mdot
.568 .34569 Mdot
.568 .34569 Mdot
.568 .34571 Mdot
.568 .34571 Mdot
.568 .34573 Mdot
.568 .34575 Mdot
.568 .34575 Mdot
.568 .34576 Mdot
.568 .34579 Mdot
.568 .34579 Mdot
.568 .34583 Mdot
.568 .34584 Mdot
.568 .34585 Mdot
.568 .34589 Mdot
.568 .3459 Mdot
.568 .34591 Mdot
.568 .34593 Mdot
.568 .34593 Mdot
.568 .34802 Mdot
.568 .34802 Mdot
.568 .34804 Mdot
.568 .34805 Mdot
.568 .34805 Mdot
.568 .34808 Mdot
.568 .34809 Mdot
.568 .3481 Mdot
.568 .34813 Mdot
.568 .34813 Mdot
.568 .34816 Mdot
.568 .34816 Mdot
.568 .34817 Mdot
.568 .34819 Mdot
.568 .34819 Mdot
.568 .34821 Mdot
.568 .34821 Mdot
.568 .34821 Mdot
.568 .34822 Mdot
.568 .34822 Mdot
.568 .34822 Mdot
.568 .34824 Mdot
.568 .34825 Mdot
.568 .34826 Mdot
.568 .34827 Mdot
.568 .34827 Mdot
.568 .34829 Mdot
.568 .34829 Mdot
.568 .34829 Mdot
.568 .3483 Mdot
.568 .34833 Mdot
.568 .34835 Mdot
.568 .34835 Mdot
.568 .34835 Mdot
.568 .34836 Mdot
.568 .34839 Mdot
.568 .3484 Mdot
.568 .3484 Mdot
.568 .34841 Mdot
.568 .34842 Mdot
.568 .34842 Mdot
.568 .34842 Mdot
.568 .34842 Mdot
.568 .34843 Mdot
.568 .34843 Mdot
.568 .34844 Mdot
.568 .34844 Mdot
.568 .34848 Mdot
.568 .34849 Mdot
.568 .3485 Mdot
.568 .3485 Mdot
.568 .3485 Mdot
.568 .34852 Mdot
.568 .34856 Mdot
.568 .34856 Mdot
.568 .34858 Mdot
.568 .34858 Mdot
.568 .34858 Mdot
.568 .34859 Mdot
.568 .34861 Mdot
.568 .34863 Mdot
.568 .34863 Mdot
.568 .34863 Mdot
.568 .34863 Mdot
.568 .34864 Mdot
.568 .34865 Mdot
.568 .34866 Mdot
.568 .34866 Mdot
.568 .34866 Mdot
.568 .34867 Mdot
.568 .34867 Mdot
.568 .34868 Mdot
.568 .34868 Mdot
.568 .34868 Mdot
.568 .34869 Mdot
.568 .34869 Mdot
.568 .3487 Mdot
.568 .34871 Mdot
.568 .34872 Mdot
.568 .34873 Mdot
.568 .34874 Mdot
.568 .34874 Mdot
.568 .34875 Mdot
.568 .34876 Mdot
.568 .3488 Mdot
.568 .3488 Mdot
.568 .34881 Mdot
.568 .34881 Mdot
.568 .34882 Mdot
.568 .34882 Mdot
.568 .34885 Mdot
.568 .34885 Mdot
.568 .34886 Mdot
.568 .34886 Mdot
.568 .34886 Mdot
.568 .34887 Mdot
.568 .34887 Mdot
.568 .34887 Mdot
.568 .34888 Mdot
.568 .34888 Mdot
.568 .34888 Mdot
.568 .34888 Mdot
.568 .34889 Mdot
.568 .3489 Mdot
.568 .34891 Mdot
.568 .34891 Mdot
.568 .34891 Mdot
.568 .34893 Mdot
.568 .34893 Mdot
.568 .34894 Mdot
.568 .34894 Mdot
.568 .34894 Mdot
.568 .34894 Mdot
.568 .34896 Mdot
.568 .34896 Mdot
.568 .34896 Mdot
.568 .34897 Mdot
.568 .34897 Mdot
.568 .34897 Mdot
.568 .34898 Mdot
.568 .34898 Mdot
.568 .34899 Mdot
.568 .34899 Mdot
.568 .349 Mdot
.568 .34902 Mdot
.568 .34903 Mdot
.568 .34904 Mdot
.568 .34905 Mdot
.568 .34905 Mdot
.568 .34906 Mdot
.568 .34907 Mdot
.568 .34908 Mdot
.568 .34908 Mdot
.568 .34908 Mdot
.568 .34908 Mdot
.568 .34909 Mdot
.568 .34909 Mdot
.568 .34911 Mdot
.568 .34913 Mdot
.568 .34913 Mdot
.568 .34914 Mdot
.568 .34914 Mdot
.568 .34916 Mdot
.568 .34917 Mdot
.568 .34917 Mdot
.568 .34918 Mdot
.568 .34919 Mdot
.568 .34919 Mdot
.568 .34922 Mdot
.568 .34923 Mdot
.568 .34923 Mdot
.568 .34923 Mdot
.568 .34924 Mdot
.568 .34924 Mdot
.568 .34924 Mdot
.568 .34926 Mdot
.568 .34926 Mdot
.568 .34926 Mdot
.568 .34928 Mdot
.568 .34928 Mdot
.568 .34929 Mdot
.568 .34929 Mdot
.568 .34929 Mdot
.568 .3493 Mdot
.568 .3493 Mdot
.568 .3493 Mdot
.568 .3493 Mdot
.568 .34931 Mdot
.568 .34931 Mdot
.568 .34933 Mdot
.568 .34933 Mdot
.568 .34933 Mdot
.568 .34934 Mdot
.568 .34937 Mdot
.568 .34938 Mdot
.568 .34939 Mdot
.568 .3494 Mdot
.568 .3494 Mdot
.568 .34941 Mdot
.568 .34941 Mdot
.568 .34941 Mdot
.568 .34942 Mdot
.568 .34942 Mdot
.568 .34942 Mdot
.568 .34943 Mdot
.568 .34943 Mdot
.568 .34944 Mdot
.568 .34944 Mdot
.568 .34944 Mdot
.568 .34945 Mdot
.568 .34947 Mdot
.568 .34947 Mdot
.568 .34947 Mdot
.568 .34947 Mdot
.568 .34948 Mdot
.568 .34949 Mdot
.568 .34951 Mdot
.568 .34952 Mdot
.568 .34952 Mdot
.568 .34952 Mdot
.568 .34953 Mdot
.568 .34953 Mdot
.568 .34956 Mdot
.568 .34956 Mdot
.568 .34956 Mdot
.568 .34956 Mdot
.568 .34957 Mdot
.568 .34957 Mdot
.568 .34957 Mdot
.568 .34957 Mdot
.568 .34957 Mdot
.568 .34958 Mdot
.568 .34958 Mdot
.568 .34959 Mdot
.568 .3496 Mdot
.568 .34961 Mdot
.568 .34961 Mdot
.568 .34961 Mdot
.568 .34961 Mdot
.568 .34962 Mdot
.568 .34964 Mdot
.568 .34965 Mdot
.568 .34965 Mdot
.568 .34965 Mdot
.568 .34966 Mdot
.568 .34966 Mdot
.568 .34967 Mdot
.568 .34967 Mdot
.568 .34968 Mdot
.568 .34969 Mdot
.568 .34969 Mdot
.568 .34969 Mdot
.568 .3497 Mdot
.568 .3497 Mdot
.568 .3497 Mdot
.568 .34971 Mdot
.568 .34971 Mdot
.568 .34972 Mdot
.568 .34973 Mdot
.568 .34973 Mdot
.568 .34975 Mdot
.568 .34975 Mdot
.568 .34976 Mdot
.568 .34977 Mdot
.568 .34977 Mdot
.568 .34979 Mdot
.568 .34979 Mdot
.568 .3498 Mdot
.568 .34981 Mdot
.568 .34981 Mdot
.57 .30392 Mdot
.57 .30393 Mdot
.57 .30394 Mdot
.57 .30396 Mdot
.57 .30396 Mdot
.57 .30396 Mdot
.57 .30397 Mdot
.57 .30398 Mdot
.57 .30398 Mdot
.57 .30401 Mdot
.57 .30402 Mdot
.57 .30403 Mdot
.57 .30403 Mdot
.57 .30403 Mdot
.57 .30404 Mdot
.57 .30405 Mdot
.57 .30405 Mdot
.57 .30407 Mdot
.57 .30407 Mdot
.57 .30408 Mdot
.57 .30409 Mdot
.57 .30409 Mdot
.57 .30412 Mdot
.57 .30413 Mdot
.57 .30413 Mdot
.57 .30414 Mdot
.57 .30415 Mdot
.57 .30415 Mdot
.57 .30416 Mdot
.57 .30417 Mdot
.57 .30417 Mdot
.57 .30417 Mdot
.57 .30418 Mdot
.57 .30418 Mdot
.57 .30419 Mdot
.57 .30419 Mdot
.57 .30419 Mdot
.57 .3042 Mdot
.57 .30422 Mdot
.57 .30422 Mdot
.57 .30423 Mdot
.57 .30424 Mdot
.57 .30424 Mdot
.57 .30424 Mdot
.57 .30425 Mdot
.57 .30426 Mdot
.57 .30426 Mdot
.57 .30426 Mdot
.57 .30427 Mdot
.57 .30427 Mdot
.57 .30427 Mdot
.57 .30429 Mdot
.57 .3043 Mdot
.57 .30432 Mdot
.57 .30435 Mdot
.57 .30435 Mdot
.57 .30435 Mdot
.57 .30436 Mdot
.57 .30436 Mdot
.57 .30437 Mdot
.57 .30438 Mdot
.57 .30441 Mdot
.57 .30444 Mdot
.57 .30444 Mdot
.57 .30445 Mdot
.57 .30446 Mdot
.57 .30447 Mdot
.57 .30448 Mdot
.57 .30449 Mdot
.57 .3045 Mdot
.57 .3045 Mdot
.57 .3045 Mdot
.57 .30452 Mdot
.57 .30453 Mdot
.57 .30454 Mdot
.57 .30454 Mdot
.57 .30454 Mdot
.57 .30455 Mdot
.57 .30455 Mdot
.57 .30457 Mdot
.57 .30457 Mdot
.57 .30457 Mdot
.57 .30457 Mdot
.57 .30458 Mdot
.57 .30458 Mdot
.57 .30458 Mdot
.57 .30458 Mdot
.57 .30458 Mdot
.57 .3046 Mdot
.57 .30461 Mdot
.57 .30462 Mdot
.57 .30464 Mdot
.57 .30465 Mdot
.57 .30466 Mdot
.57 .30466 Mdot
.57 .30468 Mdot
.57 .30468 Mdot
.57 .30469 Mdot
.57 .30469 Mdot
.57 .30469 Mdot
.57 .30469 Mdot
.57 .30469 Mdot
.57 .3047 Mdot
.57 .3047 Mdot
.57 .30472 Mdot
.57 .30472 Mdot
.57 .30473 Mdot
.57 .30473 Mdot
.57 .30473 Mdot
.57 .30474 Mdot
.57 .30474 Mdot
.57 .30476 Mdot
.57 .30476 Mdot
.57 .30477 Mdot
.57 .30478 Mdot
.57 .30479 Mdot
.57 .30479 Mdot
.57 .30479 Mdot
.57 .3048 Mdot
.57 .3048 Mdot
.57 .3048 Mdot
.57 .30481 Mdot
.57 .30483 Mdot
.57 .30484 Mdot
.57 .30485 Mdot
.57 .30485 Mdot
.57 .30486 Mdot
.57 .30486 Mdot
.57 .30486 Mdot
.57 .30486 Mdot
.57 .30486 Mdot
.57 .30487 Mdot
.57 .30488 Mdot
.57 .30488 Mdot
.57 .3049 Mdot
.57 .3049 Mdot
.57 .30492 Mdot
.57 .30494 Mdot
.57 .30496 Mdot
.57 .30498 Mdot
.57 .30498 Mdot
.57 .30499 Mdot
.57 .30499 Mdot
.57 .30501 Mdot
.57 .30502 Mdot
.57 .30504 Mdot
.57 .30504 Mdot
.57 .30504 Mdot
.57 .30505 Mdot
.57 .30505 Mdot
.57 .30505 Mdot
.57 .30505 Mdot
.57 .30506 Mdot
.57 .30506 Mdot
.57 .30508 Mdot
.57 .30509 Mdot
.57 .30509 Mdot
.57 .3051 Mdot
.57 .3051 Mdot
.57 .30511 Mdot
.57 .30511 Mdot
.57 .30511 Mdot
.57 .30512 Mdot
.57 .30513 Mdot
.57 .30514 Mdot
.57 .30515 Mdot
.57 .30515 Mdot
.57 .30517 Mdot
.57 .30518 Mdot
.57 .30518 Mdot
.57 .30519 Mdot
.57 .30519 Mdot
.57 .30521 Mdot
.57 .30521 Mdot
.57 .30524 Mdot
.57 .30524 Mdot
.57 .30526 Mdot
.57 .30527 Mdot
.57 .30528 Mdot
.57 .30528 Mdot
.57 .30528 Mdot
.57 .30532 Mdot
.57 .30532 Mdot
.57 .30533 Mdot
.57 .30534 Mdot
.57 .30534 Mdot
.57 .30537 Mdot
.57 .30539 Mdot
.57 .3054 Mdot
.57 .30541 Mdot
.57 .30541 Mdot
.57 .30541 Mdot
.57 .30543 Mdot
.57 .30543 Mdot
.57 .30544 Mdot
.57 .30545 Mdot
.57 .30548 Mdot
.57 .30551 Mdot
.57 .30553 Mdot
.57 .30556 Mdot
.57 .30556 Mdot
.57 .30557 Mdot
.57 .30558 Mdot
.57 .30559 Mdot
.57 .30559 Mdot
.57 .30561 Mdot
.57 .30561 Mdot
.57 .30562 Mdot
.57 .30562 Mdot
.57 .30564 Mdot
.57 .30564 Mdot
.57 .30565 Mdot
.57 .30568 Mdot
.57 .3057 Mdot
.57 .30571 Mdot
.57 .30571 Mdot
.57 .30572 Mdot
.57 .30572 Mdot
.57 .30573 Mdot
.57 .30574 Mdot
.57 .30574 Mdot
.57 .30575 Mdot
.57 .30576 Mdot
.57 .30577 Mdot
.57 .30578 Mdot
.57 .30581 Mdot
.57 .30581 Mdot
.57 .30582 Mdot
.57 .30586 Mdot
.57 .30588 Mdot
.57 .30588 Mdot
.57 .3059 Mdot
.57 .30591 Mdot
.57 .30594 Mdot
.57 .30594 Mdot
.57 .30595 Mdot
.57 .30596 Mdot
.57 .30598 Mdot
.57 .30598 Mdot
.57 .30599 Mdot
.57 .30601 Mdot
.57 .30605 Mdot
.57 .30605 Mdot
.57 .30608 Mdot
.57 .30608 Mdot
.57 .30608 Mdot
.57 .30609 Mdot
.57 .30612 Mdot
.57 .30613 Mdot
.57 .30616 Mdot
.57 .30851 Mdot
.57 .30855 Mdot
.57 .30856 Mdot
.57 .3086 Mdot
.57 .30861 Mdot
.57 .30861 Mdot
.57 .30862 Mdot
.57 .30865 Mdot
.57 .30865 Mdot
.57 .3087 Mdot
.57 .30873 Mdot
.57 .30875 Mdot
.57 .30875 Mdot
.57 .30877 Mdot
.57 .30879 Mdot
.57 .30879 Mdot
.57 .3088 Mdot
.57 .30883 Mdot
.57 .30884 Mdot
.57 .30887 Mdot
.57 .30888 Mdot
.57 .30889 Mdot
.57 .30896 Mdot
.57 .30897 Mdot
.57 .30897 Mdot
.57 .30901 Mdot
.57 .30902 Mdot
.57 .30903 Mdot
.57 .30904 Mdot
.57 .30906 Mdot
.57 .30906 Mdot
.57 .30907 Mdot
.57 .30908 Mdot
.57 .30909 Mdot
.57 .3091 Mdot
.57 .3091 Mdot
.57 .30911 Mdot
.57 .30914 Mdot
.57 .30917 Mdot
.57 .30918 Mdot
.57 .30919 Mdot
.57 .30921 Mdot
.57 .30921 Mdot
.57 .30922 Mdot
.57 .30923 Mdot
.57 .30925 Mdot
.57 .30925 Mdot
.57 .30926 Mdot
.57 .30927 Mdot
.57 .30929 Mdot
.57 .30929 Mdot
.57 .30934 Mdot
.57 .30935 Mdot
.57 .3094 Mdot
.57 .30943 Mdot
.57 .30945 Mdot
.57 .30946 Mdot
.57 .30946 Mdot
.57 .30948 Mdot
.57 .30949 Mdot
.57 .30949 Mdot
.57 .3095 Mdot
.57 .30951 Mdot
.57 .30953 Mdot
.57 .30958 Mdot
.57 .30958 Mdot
.57 .30959 Mdot
.57 .3096 Mdot
.57 .3096 Mdot
.57 .30966 Mdot
.57 .30966 Mdot
.57 .30966 Mdot
.57 .30966 Mdot
.57 .30968 Mdot
.57 .3097 Mdot
.57 .30971 Mdot
.57 .30975 Mdot
.57 .30975 Mdot
.57 .30977 Mdot
.57 .30978 Mdot
.57 .30978 Mdot
.57 .30978 Mdot
.57 .3098 Mdot
.57 .30983 Mdot
.57 .30983 Mdot
.57 .30983 Mdot
.57 .30986 Mdot
.57 .30986 Mdot
.57 .30987 Mdot
.57 .30988 Mdot
.57 .30988 Mdot
.57 .30989 Mdot
.57 .30989 Mdot
.57 .3099 Mdot
.57 .30991 Mdot
.57 .30992 Mdot
.57 .30993 Mdot
.57 .30995 Mdot
.57 .30995 Mdot
.57 .30995 Mdot
.57 .30996 Mdot
.57 .30996 Mdot
.57 .30997 Mdot
.57 .30997 Mdot
.57 .30997 Mdot
.57 .30999 Mdot
.57 .31001 Mdot
.57 .31003 Mdot
.57 .31003 Mdot
.57 .31004 Mdot
.57 .31005 Mdot
.57 .31007 Mdot
.57 .3101 Mdot
.57 .31012 Mdot
.57 .31014 Mdot
.57 .31014 Mdot
.57 .31018 Mdot
.57 .31018 Mdot
.57 .31019 Mdot
.57 .3102 Mdot
.57 .3102 Mdot
.57 .3102 Mdot
.57 .3102 Mdot
.57 .31021 Mdot
.57 .31021 Mdot
.57 .31021 Mdot
.57 .31023 Mdot
.57 .31024 Mdot
.57 .31026 Mdot
.57 .31027 Mdot
.57 .31027 Mdot
.57 .31028 Mdot
.57 .31029 Mdot
.57 .31029 Mdot
.57 .31029 Mdot
.57 .3103 Mdot
.57 .31032 Mdot
.57 .31032 Mdot
.57 .31032 Mdot
.57 .31035 Mdot
.57 .31035 Mdot
.57 .31037 Mdot
.57 .31037 Mdot
.57 .31037 Mdot
.57 .31038 Mdot
.57 .31038 Mdot
.57 .3104 Mdot
.57 .3104 Mdot
.57 .31042 Mdot
.57 .31042 Mdot
.57 .31042 Mdot
.57 .31042 Mdot
.57 .31042 Mdot
.57 .31043 Mdot
.57 .31044 Mdot
.57 .31046 Mdot
.57 .31046 Mdot
.57 .31047 Mdot
.57 .31048 Mdot
.57 .31052 Mdot
.57 .31052 Mdot
.57 .31054 Mdot
.57 .31056 Mdot
.57 .31056 Mdot
.57 .31056 Mdot
.57 .31057 Mdot
.57 .31057 Mdot
.57 .31057 Mdot
.57 .31057 Mdot
.57 .31057 Mdot
.57 .31058 Mdot
.57 .3106 Mdot
.57 .31061 Mdot
.57 .31061 Mdot
.57 .31062 Mdot
.57 .31062 Mdot
.57 .31063 Mdot
.57 .31064 Mdot
.57 .31067 Mdot
.57 .31067 Mdot
.57 .31067 Mdot
.57 .31068 Mdot
.57 .31069 Mdot
.57 .31071 Mdot
.57 .31072 Mdot
.57 .31073 Mdot
.57 .31074 Mdot
.57 .31075 Mdot
.57 .31079 Mdot
.57 .31082 Mdot
.57 .31084 Mdot
.57 .31084 Mdot
.57 .31085 Mdot
.57 .31086 Mdot
.57 .31086 Mdot
.57 .31087 Mdot
.57 .3109 Mdot
.57 .31093 Mdot
.57 .31094 Mdot
.57 .31096 Mdot
.57 .31097 Mdot
.57 .31097 Mdot
.57 .31098 Mdot
.57 .31098 Mdot
.57 .31099 Mdot
.57 .311 Mdot
.57 .311 Mdot
.57 .31101 Mdot
.57 .31101 Mdot
.57 .31102 Mdot
.57 .31103 Mdot
.57 .31103 Mdot
.57 .31105 Mdot
.57 .31107 Mdot
.57 .31107 Mdot
.57 .31108 Mdot
.57 .31108 Mdot
.57 .31109 Mdot
.57 .31109 Mdot
.57 .3111 Mdot
.57 .3111 Mdot
.57 .31111 Mdot
.57 .31112 Mdot
.57 .31112 Mdot
.57 .31113 Mdot
.57 .31115 Mdot
.57 .31115 Mdot
.57 .31116 Mdot
.57 .3112 Mdot
.57 .31121 Mdot
.57 .31121 Mdot
.57 .31123 Mdot
.57 .31123 Mdot
.57 .31125 Mdot
.57 .31126 Mdot
.57 .31126 Mdot
.57 .31127 Mdot
.57 .31128 Mdot
.57 .31128 Mdot
.57 .31129 Mdot
.57 .31131 Mdot
.57 .31134 Mdot
.57 .31134 Mdot
.57 .31136 Mdot
.57 .31136 Mdot
.57 .31137 Mdot
.57 .31137 Mdot
.57 .3114 Mdot
.57 .3114 Mdot
.57 .31142 Mdot
.57 .34441 Mdot
.57 .34442 Mdot
.57 .34443 Mdot
.57 .34445 Mdot
.57 .34446 Mdot
.57 .34446 Mdot
.57 .34446 Mdot
.57 .34448 Mdot
.57 .34448 Mdot
.57 .34451 Mdot
.57 .34452 Mdot
.57 .34453 Mdot
.57 .34453 Mdot
.57 .34454 Mdot
.57 .34455 Mdot
.57 .34455 Mdot
.57 .34456 Mdot
.57 .34457 Mdot
.57 .34458 Mdot
.57 .34459 Mdot
.57 .3446 Mdot
.57 .34461 Mdot
.57 .34464 Mdot
.57 .34464 Mdot
.57 .34465 Mdot
.57 .34466 Mdot
.57 .34467 Mdot
.57 .34468 Mdot
.57 .34468 Mdot
.57 .34469 Mdot
.57 .34469 Mdot
.57 .3447 Mdot
.57 .3447 Mdot
.57 .34471 Mdot
.57 .34471 Mdot
.57 .34471 Mdot
.57 .34472 Mdot
.57 .34473 Mdot
.57 .34475 Mdot
.57 .34475 Mdot
.57 .34476 Mdot
.57 .34477 Mdot
.57 .34477 Mdot
.57 .34478 Mdot
.57 .34478 Mdot
.57 .34479 Mdot
.57 .34479 Mdot
.57 .3448 Mdot
.57 .3448 Mdot
.57 .34481 Mdot
.57 .34481 Mdot
.57 .34484 Mdot
.57 .34484 Mdot
.57 .34487 Mdot
.57 .34489 Mdot
.57 .3449 Mdot
.57 .3449 Mdot
.57 .34491 Mdot
.57 .34492 Mdot
.57 .34492 Mdot
.57 .34494 Mdot
.57 .34496 Mdot
.57 .345 Mdot
.57 .345 Mdot
.57 .34501 Mdot
.57 .34502 Mdot
.57 .34503 Mdot
.57 .34505 Mdot
.57 .34506 Mdot
.57 .34506 Mdot
.57 .34507 Mdot
.57 .34507 Mdot
.57 .34509 Mdot
.57 .34511 Mdot
.57 .34511 Mdot
.57 .34512 Mdot
.57 .34512 Mdot
.57 .34512 Mdot
.57 .34513 Mdot
.57 .34515 Mdot
.57 .34515 Mdot
.57 .34515 Mdot
.57 .34515 Mdot
.57 .34516 Mdot
.57 .34516 Mdot
.57 .34516 Mdot
.57 .34516 Mdot
.57 .34517 Mdot
.57 .34519 Mdot
.57 .3452 Mdot
.57 .3452 Mdot
.57 .34523 Mdot
.57 .34524 Mdot
.57 .34526 Mdot
.57 .34526 Mdot
.57 .34527 Mdot
.57 .34528 Mdot
.57 .34529 Mdot
.57 .34529 Mdot
.57 .34529 Mdot
.57 .34529 Mdot
.57 .34529 Mdot
.57 .3453 Mdot
.57 .3453 Mdot
.57 .34532 Mdot
.57 .34532 Mdot
.57 .34533 Mdot
.57 .34533 Mdot
.57 .34533 Mdot
.57 .34535 Mdot
.57 .34535 Mdot
.57 .34537 Mdot
.57 .34537 Mdot
.57 .34538 Mdot
.57 .34539 Mdot
.57 .3454 Mdot
.57 .3454 Mdot
.57 .3454 Mdot
.57 .34541 Mdot
.57 .34542 Mdot
.57 .34542 Mdot
.57 .34543 Mdot
.57 .34545 Mdot
.57 .34545 Mdot
.57 .34547 Mdot
.57 .34547 Mdot
.57 .34547 Mdot
.57 .34548 Mdot
.57 .34548 Mdot
.57 .34548 Mdot
.57 .34548 Mdot
.57 .34549 Mdot
.57 .3455 Mdot
.57 .3455 Mdot
.57 .34553 Mdot
.57 .34553 Mdot
.57 .34555 Mdot
.57 .34557 Mdot
.57 .34559 Mdot
.57 .34562 Mdot
.57 .34562 Mdot
.57 .34563 Mdot
.57 .34563 Mdot
.57 .34565 Mdot
.57 .34567 Mdot
.57 .34568 Mdot
.57 .34568 Mdot
.57 .34569 Mdot
.57 .34569 Mdot
.57 .34569 Mdot
.57 .3457 Mdot
.57 .3457 Mdot
.57 .3457 Mdot
.57 .34571 Mdot
.57 .34573 Mdot
.57 .34574 Mdot
.57 .34575 Mdot
.57 .34575 Mdot
.57 .34575 Mdot
.57 .34576 Mdot
.57 .34576 Mdot
.57 .34577 Mdot
.57 .34578 Mdot
.57 .34578 Mdot
.57 .3458 Mdot
.57 .34581 Mdot
.57 .34581 Mdot
.57 .34583 Mdot
.57 .34585 Mdot
.57 .34585 Mdot
.57 .34585 Mdot
.57 .34586 Mdot
.57 .34588 Mdot
.57 .34588 Mdot
.57 .34591 Mdot
.57 .34592 Mdot
.57 .34594 Mdot
.57 .34595 Mdot
.57 .34596 Mdot
.57 .34596 Mdot
.57 .34596 Mdot
.57 .346 Mdot
.57 .34601 Mdot
.57 .34601 Mdot
.57 .34602 Mdot
.57 .34603 Mdot
.57 .34607 Mdot
.57 .34609 Mdot
.57 .34609 Mdot
.57 .3461 Mdot
.57 .34611 Mdot
.57 .34611 Mdot
.57 .34613 Mdot
.57 .34613 Mdot
.57 .34614 Mdot
.57 .34616 Mdot
.57 .34618 Mdot
.57 .34623 Mdot
.57 .34624 Mdot
.57 .34628 Mdot
.57 .34628 Mdot
.57 .34629 Mdot
.57 .3463 Mdot
.57 .34631 Mdot
.57 .34631 Mdot
.57 .34633 Mdot
.57 .34634 Mdot
.57 .34634 Mdot
.57 .34635 Mdot
.57 .34637 Mdot
.57 .34637 Mdot
.57 .34639 Mdot
.57 .34641 Mdot
.57 .34644 Mdot
.57 .34644 Mdot
.57 .34645 Mdot
.57 .34646 Mdot
.57 .34647 Mdot
.57 .34647 Mdot
.57 .34648 Mdot
.57 .34648 Mdot
.57 .3465 Mdot
.57 .34651 Mdot
.57 .34652 Mdot
.57 .34653 Mdot
.57 .34656 Mdot
.57 .34656 Mdot
.57 .34657 Mdot
.57 .34663 Mdot
.57 .34664 Mdot
.57 .34665 Mdot
.57 .34667 Mdot
.57 .34668 Mdot
.57 .34671 Mdot
.57 .34671 Mdot
.57 .34672 Mdot
.57 .34674 Mdot
.57 .34675 Mdot
.57 .34676 Mdot
.57 .34677 Mdot
.57 .34679 Mdot
.57 .34684 Mdot
.57 .34684 Mdot
.57 .34687 Mdot
.57 .34687 Mdot
.57 .34688 Mdot
.57 .34688 Mdot
.57 .34692 Mdot
.57 .34693 Mdot
.57 .34696 Mdot
.57 .34903 Mdot
.57 .34905 Mdot
.57 .34906 Mdot
.57 .34908 Mdot
.57 .34909 Mdot
.57 .34909 Mdot
.57 .3491 Mdot
.57 .34912 Mdot
.57 .34912 Mdot
.57 .34915 Mdot
.57 .34917 Mdot
.57 .34918 Mdot
.57 .34918 Mdot
.57 .3492 Mdot
.57 .34921 Mdot
.57 .34922 Mdot
.57 .34922 Mdot
.57 .34924 Mdot
.57 .34925 Mdot
.57 .34927 Mdot
.57 .34927 Mdot
.57 .34928 Mdot
.57 .34933 Mdot
.57 .34933 Mdot
.57 .34934 Mdot
.57 .34936 Mdot
.57 .34937 Mdot
.57 .34937 Mdot
.57 .34938 Mdot
.57 .34939 Mdot
.57 .34939 Mdot
.57 .3494 Mdot
.57 .34941 Mdot
.57 .34941 Mdot
.57 .34942 Mdot
.57 .34942 Mdot
.57 .34943 Mdot
.57 .34945 Mdot
.57 .34947 Mdot
.57 .34948 Mdot
.57 .34948 Mdot
.57 .3495 Mdot
.57 .3495 Mdot
.57 .3495 Mdot
.57 .34951 Mdot
.57 .34952 Mdot
.57 .34953 Mdot
.57 .34953 Mdot
.57 .34954 Mdot
.57 .34955 Mdot
.57 .34955 Mdot
.57 .34958 Mdot
.57 .34959 Mdot
.57 .34962 Mdot
.57 .34965 Mdot
.57 .34966 Mdot
.57 .34966 Mdot
.57 .34967 Mdot
.57 .34968 Mdot
.57 .34968 Mdot
.57 .34969 Mdot
.57 .34969 Mdot
.57 .3497 Mdot
.57 .34971 Mdot
.57 .34974 Mdot
.57 .34975 Mdot
.57 .34976 Mdot
.57 .34976 Mdot
.57 .34976 Mdot
.57 .3498 Mdot
.57 .3498 Mdot
.57 .3498 Mdot
.57 .3498 Mdot
.57 .34981 Mdot
.57 .34983 Mdot
.57 .34983 Mdot
.57 .34986 Mdot
.57 .34986 Mdot
.57 .34987 Mdot
.57 .34988 Mdot
.57 .34988 Mdot
.57 .34988 Mdot
.57 .3499 Mdot
.57 .34991 Mdot
.57 .34991 Mdot
.57 .34992 Mdot
.57 .34993 Mdot
.57 .34993 Mdot
.57 .34994 Mdot
.57 .34995 Mdot
.57 .34995 Mdot
.57 .34996 Mdot
.57 .34996 Mdot
.57 .34996 Mdot
.57 .34997 Mdot
.57 .34997 Mdot
.57 .34999 Mdot
.57 .34999 Mdot
.57 .34999 Mdot
.57 .35 Mdot
.57 .35 Mdot
.57 .35 Mdot
.57 .35001 Mdot
.57 .35001 Mdot
.57 .35001 Mdot
.57 .35001 Mdot
.57 .35002 Mdot
.57 .35004 Mdot
.57 .35005 Mdot
.57 .35005 Mdot
.57 .35006 Mdot
.57 .35006 Mdot
.57 .35008 Mdot
.57 .3501 Mdot
.57 .35011 Mdot
.57 .35013 Mdot
.57 .35013 Mdot
.57 .35015 Mdot
.57 .35015 Mdot
.57 .35015 Mdot
.57 .35016 Mdot
.57 .35017 Mdot
.57 .35017 Mdot
.57 .35017 Mdot
.57 .35017 Mdot
.57 .35017 Mdot
.57 .35017 Mdot
.57 .35019 Mdot
.57 .35019 Mdot
.57 .35021 Mdot
.57 .35021 Mdot
.57 .35021 Mdot
.57 .35022 Mdot
.57 .35023 Mdot
.57 .35023 Mdot
.57 .35023 Mdot
.57 .35023 Mdot
.57 .35024 Mdot
.57 .35025 Mdot
.57 .35025 Mdot
.57 .35027 Mdot
.57 .35027 Mdot
.57 .35028 Mdot
.57 .35028 Mdot
.57 .35028 Mdot
.57 .35029 Mdot
.57 .35029 Mdot
.57 .3503 Mdot
.57 .3503 Mdot
.57 .35031 Mdot
.57 .35031 Mdot
.57 .35031 Mdot
.57 .35031 Mdot
.57 .35031 Mdot
.57 .35032 Mdot
.57 .35033 Mdot
.57 .35034 Mdot
.57 .35034 Mdot
.57 .35035 Mdot
.57 .35036 Mdot
.57 .35038 Mdot
.57 .35038 Mdot
.57 .35039 Mdot
.57 .35041 Mdot
.57 .35041 Mdot
.57 .35041 Mdot
.57 .35041 Mdot
.57 .35041 Mdot
.57 .35042 Mdot
.57 .35042 Mdot
.57 .35042 Mdot
.57 .35042 Mdot
.57 .35044 Mdot
.57 .35044 Mdot
.57 .35044 Mdot
.57 .35044 Mdot
.57 .35045 Mdot
.57 .35045 Mdot
.57 .35046 Mdot
.57 .35048 Mdot
.57 .35048 Mdot
.57 .35048 Mdot
.57 .35049 Mdot
.57 .3505 Mdot
.57 .35051 Mdot
.57 .35052 Mdot
.57 .35052 Mdot
.57 .35053 Mdot
.57 .35053 Mdot
.57 .35056 Mdot
.57 .35058 Mdot
.57 .35059 Mdot
.57 .3506 Mdot
.57 .3506 Mdot
.57 .35061 Mdot
.57 .35061 Mdot
.57 .35062 Mdot
.57 .35064 Mdot
.57 .35066 Mdot
.57 .35066 Mdot
.57 .35068 Mdot
.57 .35068 Mdot
.57 .35069 Mdot
.57 .35069 Mdot
.57 .35069 Mdot
.57 .3507 Mdot
.57 .3507 Mdot
.57 .35071 Mdot
.57 .35071 Mdot
.57 .35071 Mdot
.57 .35072 Mdot
.57 .35072 Mdot
.57 .35073 Mdot
.57 .35074 Mdot
.57 .35075 Mdot
.57 .35075 Mdot
.57 .35076 Mdot
.57 .35076 Mdot
.57 .35076 Mdot
.57 .35077 Mdot
.57 .35077 Mdot
.57 .35077 Mdot
.57 .35078 Mdot
.57 .35078 Mdot
.57 .35079 Mdot
.57 .35079 Mdot
.57 .35081 Mdot
.57 .35081 Mdot
.57 .35081 Mdot
.57 .35084 Mdot
.57 .35084 Mdot
.57 .35085 Mdot
.57 .35086 Mdot
.57 .35086 Mdot
.57 .35087 Mdot
.57 .35088 Mdot
.57 .35088 Mdot
.57 .35089 Mdot
.57 .3509 Mdot
.57 .3509 Mdot
.57 .3509 Mdot
.57 .35091 Mdot
.57 .35093 Mdot
.57 .35094 Mdot
.57 .35095 Mdot
.57 .35095 Mdot
.57 .35095 Mdot
.57 .35096 Mdot
.57 .35097 Mdot
.57 .35098 Mdot
.57 .35099 Mdot
.572 .30358 Mdot
.572 .30359 Mdot
.572 .30362 Mdot
.572 .30362 Mdot
.572 .30362 Mdot
.572 .30362 Mdot
.572 .30364 Mdot
.572 .30364 Mdot
.572 .30364 Mdot
.572 .30365 Mdot
.572 .30366 Mdot
.572 .30367 Mdot
.572 .30368 Mdot
.572 .30368 Mdot
.572 .30369 Mdot
.572 .3037 Mdot
.572 .3037 Mdot
.572 .30373 Mdot
.572 .30374 Mdot
.572 .30375 Mdot
.572 .30377 Mdot
.572 .30377 Mdot
.572 .3038 Mdot
.572 .30382 Mdot
.572 .30383 Mdot
.572 .30383 Mdot
.572 .30384 Mdot
.572 .30384 Mdot
.572 .30384 Mdot
.572 .30384 Mdot
.572 .30384 Mdot
.572 .30386 Mdot
.572 .30386 Mdot
.572 .30387 Mdot
.572 .30388 Mdot
.572 .30389 Mdot
.572 .3039 Mdot
.572 .3039 Mdot
.572 .3039 Mdot
.572 .30391 Mdot
.572 .30393 Mdot
.572 .30393 Mdot
.572 .30393 Mdot
.572 .30393 Mdot
.572 .30393 Mdot
.572 .30394 Mdot
.572 .30394 Mdot
.572 .30394 Mdot
.572 .30396 Mdot
.572 .30397 Mdot
.572 .30398 Mdot
.572 .30398 Mdot
.572 .30399 Mdot
.572 .304 Mdot
.572 .30401 Mdot
.572 .30402 Mdot
.572 .30402 Mdot
.572 .30405 Mdot
.572 .30406 Mdot
.572 .30408 Mdot
.572 .30409 Mdot
.572 .30409 Mdot
.572 .30409 Mdot
.572 .3041 Mdot
.572 .30412 Mdot
.572 .30413 Mdot
.572 .30415 Mdot
.572 .30416 Mdot
.572 .30416 Mdot
.572 .30418 Mdot
.572 .30419 Mdot
.572 .3042 Mdot
.572 .30421 Mdot
.572 .30421 Mdot
.572 .30422 Mdot
.572 .30422 Mdot
.572 .30427 Mdot
.572 .30427 Mdot
.572 .30428 Mdot
.572 .30428 Mdot
.572 .30429 Mdot
.572 .30429 Mdot
.572 .30429 Mdot
.572 .3043 Mdot
.572 .3043 Mdot
.572 .3043 Mdot
.572 .3043 Mdot
.572 .30431 Mdot
.572 .30432 Mdot
.572 .30432 Mdot
.572 .30433 Mdot
.572 .30433 Mdot
.572 .30433 Mdot
.572 .30435 Mdot
.572 .30436 Mdot
.572 .30438 Mdot
.572 .30439 Mdot
.572 .3044 Mdot
.572 .3044 Mdot
.572 .3044 Mdot
.572 .30441 Mdot
.572 .30442 Mdot
.572 .30442 Mdot
.572 .30443 Mdot
.572 .30446 Mdot
.572 .30446 Mdot
.572 .30447 Mdot
.572 .30448 Mdot
.572 .30451 Mdot
.572 .30451 Mdot
.572 .30453 Mdot
.572 .30453 Mdot
.572 .30454 Mdot
.572 .30455 Mdot
.572 .30457 Mdot
.572 .30457 Mdot
.572 .30458 Mdot
.572 .30458 Mdot
.572 .30459 Mdot
.572 .3046 Mdot
.572 .3046 Mdot
.572 .30461 Mdot
.572 .30461 Mdot
.572 .30461 Mdot
.572 .30462 Mdot
.572 .30463 Mdot
.572 .30465 Mdot
.572 .30465 Mdot
.572 .30465 Mdot
.572 .30466 Mdot
.572 .30467 Mdot
.572 .30468 Mdot
.572 .30472 Mdot
.572 .30472 Mdot
.572 .30477 Mdot
.572 .30477 Mdot
.572 .30477 Mdot
.572 .30477 Mdot
.572 .30478 Mdot
.572 .30479 Mdot
.572 .30479 Mdot
.572 .3048 Mdot
.572 .30481 Mdot
.572 .30481 Mdot
.572 .30482 Mdot
.572 .30482 Mdot
.572 .30483 Mdot
.572 .30483 Mdot
.572 .30484 Mdot
.572 .30484 Mdot
.572 .30485 Mdot
.572 .30485 Mdot
.572 .30486 Mdot
.572 .30487 Mdot
.572 .30488 Mdot
.572 .30491 Mdot
.572 .30495 Mdot
.572 .30495 Mdot
.572 .30496 Mdot
.572 .30496 Mdot
.572 .30497 Mdot
.572 .30499 Mdot
.572 .30499 Mdot
.572 .305 Mdot
.572 .305 Mdot
.572 .30502 Mdot
.572 .30503 Mdot
.572 .30504 Mdot
.572 .30505 Mdot
.572 .30506 Mdot
.572 .30506 Mdot
.572 .30507 Mdot
.572 .30509 Mdot
.572 .30511 Mdot
.572 .30511 Mdot
.572 .30512 Mdot
.572 .30513 Mdot
.572 .30515 Mdot
.572 .30517 Mdot
.572 .30517 Mdot
.572 .30517 Mdot
.572 .30517 Mdot
.572 .30518 Mdot
.572 .30518 Mdot
.572 .30519 Mdot
.572 .30521 Mdot
.572 .30522 Mdot
.572 .30523 Mdot
.572 .30523 Mdot
.572 .30523 Mdot
.572 .30525 Mdot
.572 .3053 Mdot
.572 .3053 Mdot
.572 .30532 Mdot
.572 .30532 Mdot
.572 .30532 Mdot
.572 .30534 Mdot
.572 .30534 Mdot
.572 .30536 Mdot
.572 .30536 Mdot
.572 .30538 Mdot
.572 .30539 Mdot
.572 .30543 Mdot
.572 .30543 Mdot
.572 .30544 Mdot
.572 .30544 Mdot
.572 .30544 Mdot
.572 .30545 Mdot
.572 .30545 Mdot
.572 .30546 Mdot
.572 .30549 Mdot
.572 .3055 Mdot
.572 .3055 Mdot
.572 .30551 Mdot
.572 .30551 Mdot
.572 .30554 Mdot
.572 .30555 Mdot
.572 .30557 Mdot
.572 .30558 Mdot
.572 .3056 Mdot
.572 .3056 Mdot
.572 .30561 Mdot
.572 .30561 Mdot
.572 .30561 Mdot
.572 .30562 Mdot
.572 .30562 Mdot
.572 .30564 Mdot
.572 .30567 Mdot
.572 .30572 Mdot
.572 .30573 Mdot
.572 .30576 Mdot
.572 .30578 Mdot
.572 .3058 Mdot
.572 .30585 Mdot
.572 .30585 Mdot
.572 .30587 Mdot
.572 .30588 Mdot
.572 .30588 Mdot
.572 .3059 Mdot
.572 .30592 Mdot
.572 .30593 Mdot
.572 .30595 Mdot
.572 .30595 Mdot
.572 .30596 Mdot
.572 .30597 Mdot
.572 .30598 Mdot
.572 .30599 Mdot
.572 .30599 Mdot
.572 .30604 Mdot
.572 .30605 Mdot
.572 .30835 Mdot
.572 .30837 Mdot
.572 .30844 Mdot
.572 .30844 Mdot
.572 .30844 Mdot
.572 .30845 Mdot
.572 .30848 Mdot
.572 .30848 Mdot
.572 .30848 Mdot
.572 .30851 Mdot
.572 .30853 Mdot
.572 .30855 Mdot
.572 .30857 Mdot
.572 .30858 Mdot
.572 .30859 Mdot
.572 .30861 Mdot
.572 .30862 Mdot
.572 .30868 Mdot
.572 .3087 Mdot
.572 .30873 Mdot
.572 .30877 Mdot
.572 .30878 Mdot
.572 .30885 Mdot
.572 .30889 Mdot
.572 .30891 Mdot
.572 .30892 Mdot
.572 .30892 Mdot
.572 .30893 Mdot
.572 .30893 Mdot
.572 .30894 Mdot
.572 .30894 Mdot
.572 .30897 Mdot
.572 .30899 Mdot
.572 .30901 Mdot
.572 .30902 Mdot
.572 .30905 Mdot
.572 .30906 Mdot
.572 .30907 Mdot
.572 .30907 Mdot
.572 .30908 Mdot
.572 .30913 Mdot
.572 .30913 Mdot
.572 .30914 Mdot
.572 .30914 Mdot
.572 .30915 Mdot
.572 .30915 Mdot
.572 .30916 Mdot
.572 .30917 Mdot
.572 .30921 Mdot
.572 .30922 Mdot
.572 .30926 Mdot
.572 .30926 Mdot
.572 .30928 Mdot
.572 .30928 Mdot
.572 .3093 Mdot
.572 .3093 Mdot
.572 .30931 Mdot
.572 .30933 Mdot
.572 .30934 Mdot
.572 .3094 Mdot
.572 .30942 Mdot
.572 .30943 Mdot
.572 .30943 Mdot
.572 .30943 Mdot
.572 .30945 Mdot
.572 .30948 Mdot
.572 .30949 Mdot
.572 .3095 Mdot
.572 .3095 Mdot
.572 .3095 Mdot
.572 .3095 Mdot
.572 .30951 Mdot
.572 .30953 Mdot
.572 .30955 Mdot
.572 .30957 Mdot
.572 .30958 Mdot
.572 .30958 Mdot
.572 .30961 Mdot
.572 .30964 Mdot
.572 .30964 Mdot
.572 .30965 Mdot
.572 .30966 Mdot
.572 .30967 Mdot
.572 .30969 Mdot
.572 .3097 Mdot
.572 .30973 Mdot
.572 .30973 Mdot
.572 .30974 Mdot
.572 .30974 Mdot
.572 .30976 Mdot
.572 .30977 Mdot
.572 .30977 Mdot
.572 .30979 Mdot
.572 .30979 Mdot
.572 .30984 Mdot
.572 .30988 Mdot
.572 .30989 Mdot
.572 .30991 Mdot
.572 .30992 Mdot
.572 .30992 Mdot
.572 .30994 Mdot
.572 .30994 Mdot
.572 .30994 Mdot
.572 .30995 Mdot
.572 .30996 Mdot
.572 .30997 Mdot
.572 .30997 Mdot
.572 .30997 Mdot
.572 .30999 Mdot
.572 .31001 Mdot
.572 .31001 Mdot
.572 .31001 Mdot
.572 .31002 Mdot
.572 .31002 Mdot
.572 .31003 Mdot
.572 .31003 Mdot
.572 .31009 Mdot
.572 .3101 Mdot
.572 .31014 Mdot
.572 .31016 Mdot
.572 .31017 Mdot
.572 .31018 Mdot
.572 .31019 Mdot
.572 .31019 Mdot
.572 .3102 Mdot
.572 .31022 Mdot
.572 .31023 Mdot
.572 .31024 Mdot
.572 .31024 Mdot
.572 .31025 Mdot
.572 .31026 Mdot
.572 .31026 Mdot
.572 .31027 Mdot
.572 .31027 Mdot
.572 .31029 Mdot
.572 .31029 Mdot
.572 .31032 Mdot
.572 .31032 Mdot
.572 .31034 Mdot
.572 .31035 Mdot
.572 .31037 Mdot
.572 .31037 Mdot
.572 .31041 Mdot
.572 .31042 Mdot
.572 .31043 Mdot
.572 .31044 Mdot
.572 .31047 Mdot
.572 .31048 Mdot
.572 .31049 Mdot
.572 .31049 Mdot
.572 .31051 Mdot
.572 .31051 Mdot
.572 .31052 Mdot
.572 .31053 Mdot
.572 .31053 Mdot
.572 .31057 Mdot
.572 .31057 Mdot
.572 .3106 Mdot
.572 .3106 Mdot
.572 .31061 Mdot
.572 .31061 Mdot
.572 .31062 Mdot
.572 .31063 Mdot
.572 .31064 Mdot
.572 .31064 Mdot
.572 .31064 Mdot
.572 .31064 Mdot
.572 .31065 Mdot
.572 .31066 Mdot
.572 .31066 Mdot
.572 .31067 Mdot
.572 .31067 Mdot
.572 .31068 Mdot
.572 .31068 Mdot
.572 .31075 Mdot
.572 .31075 Mdot
.572 .31075 Mdot
.572 .31075 Mdot
.572 .31077 Mdot
.572 .31078 Mdot
.572 .3108 Mdot
.572 .31082 Mdot
.572 .31083 Mdot
.572 .31083 Mdot
.572 .31087 Mdot
.572 .31088 Mdot
.572 .3109 Mdot
.572 .31091 Mdot
.572 .31091 Mdot
.572 .31091 Mdot
.572 .31093 Mdot
.572 .31096 Mdot
.572 .31097 Mdot
.572 .31101 Mdot
.572 .31101 Mdot
.572 .31103 Mdot
.572 .31103 Mdot
.572 .31104 Mdot
.572 .31105 Mdot
.572 .31106 Mdot
.572 .31108 Mdot
.572 .31108 Mdot
.572 .31111 Mdot
.572 .31111 Mdot
.572 .31112 Mdot
.572 .31112 Mdot
.572 .31112 Mdot
.572 .31112 Mdot
.572 .31113 Mdot
.572 .31113 Mdot
.572 .31116 Mdot
.572 .31116 Mdot
.572 .31116 Mdot
.572 .31117 Mdot
.572 .31117 Mdot
.572 .3112 Mdot
.572 .3112 Mdot
.572 .31121 Mdot
.572 .31122 Mdot
.572 .31124 Mdot
.572 .31124 Mdot
.572 .31125 Mdot
.572 .31125 Mdot
.572 .31125 Mdot
.572 .31125 Mdot
.572 .31126 Mdot
.572 .31127 Mdot
.572 .31129 Mdot
.572 .31133 Mdot
.572 .31134 Mdot
.572 .31136 Mdot
.572 .31138 Mdot
.572 .31139 Mdot
.572 .31143 Mdot
.572 .31143 Mdot
.572 .31144 Mdot
.572 .31145 Mdot
.572 .31145 Mdot
.572 .31147 Mdot
.572 .31148 Mdot
.572 .31149 Mdot
.572 .31151 Mdot
.572 .31151 Mdot
.572 .31151 Mdot
.572 .31153 Mdot
.572 .31153 Mdot
.572 .31153 Mdot
.572 .31153 Mdot
.572 .31157 Mdot
.572 .31158 Mdot
.572 .34518 Mdot
.572 .34519 Mdot
.572 .34522 Mdot
.572 .34522 Mdot
.572 .34522 Mdot
.572 .34523 Mdot
.572 .34524 Mdot
.572 .34524 Mdot
.572 .34524 Mdot
.572 .34526 Mdot
.572 .34527 Mdot
.572 .34528 Mdot
.572 .34529 Mdot
.572 .34529 Mdot
.572 .3453 Mdot
.572 .34531 Mdot
.572 .34531 Mdot
.572 .34534 Mdot
.572 .34536 Mdot
.572 .34537 Mdot
.572 .34539 Mdot
.572 .3454 Mdot
.572 .34543 Mdot
.572 .34545 Mdot
.572 .34546 Mdot
.572 .34546 Mdot
.572 .34547 Mdot
.572 .34547 Mdot
.572 .34547 Mdot
.572 .34548 Mdot
.572 .34548 Mdot
.572 .34549 Mdot
.572 .3455 Mdot
.572 .34551 Mdot
.572 .34552 Mdot
.572 .34554 Mdot
.572 .34554 Mdot
.572 .34554 Mdot
.572 .34554 Mdot
.572 .34555 Mdot
.572 .34557 Mdot
.572 .34558 Mdot
.572 .34558 Mdot
.572 .34558 Mdot
.572 .34558 Mdot
.572 .34559 Mdot
.572 .34559 Mdot
.572 .34559 Mdot
.572 .34562 Mdot
.572 .34562 Mdot
.572 .34564 Mdot
.572 .34564 Mdot
.572 .34565 Mdot
.572 .34566 Mdot
.572 .34566 Mdot
.572 .34568 Mdot
.572 .34568 Mdot
.572 .34571 Mdot
.572 .34572 Mdot
.572 .34575 Mdot
.572 .34576 Mdot
.572 .34576 Mdot
.572 .34576 Mdot
.572 .34578 Mdot
.572 .3458 Mdot
.572 .3458 Mdot
.572 .34583 Mdot
.572 .34584 Mdot
.572 .34584 Mdot
.572 .34586 Mdot
.572 .34588 Mdot
.572 .34589 Mdot
.572 .3459 Mdot
.572 .3459 Mdot
.572 .34591 Mdot
.572 .34591 Mdot
.572 .34596 Mdot
.572 .34597 Mdot
.572 .34598 Mdot
.572 .34598 Mdot
.572 .34599 Mdot
.572 .34599 Mdot
.572 .34599 Mdot
.572 .346 Mdot
.572 .346 Mdot
.572 .346 Mdot
.572 .346 Mdot
.572 .34601 Mdot
.572 .34602 Mdot
.572 .34602 Mdot
.572 .34603 Mdot
.572 .34603 Mdot
.572 .34604 Mdot
.572 .34606 Mdot
.572 .34607 Mdot
.572 .3461 Mdot
.572 .3461 Mdot
.572 .34611 Mdot
.572 .34611 Mdot
.572 .34611 Mdot
.572 .34613 Mdot
.572 .34614 Mdot
.572 .34614 Mdot
.572 .34615 Mdot
.572 .34618 Mdot
.572 .34618 Mdot
.572 .34619 Mdot
.572 .3462 Mdot
.572 .34624 Mdot
.572 .34624 Mdot
.572 .34626 Mdot
.572 .34626 Mdot
.572 .34628 Mdot
.572 .34629 Mdot
.572 .34631 Mdot
.572 .34631 Mdot
.572 .34633 Mdot
.572 .34633 Mdot
.572 .34633 Mdot
.572 .34634 Mdot
.572 .34634 Mdot
.572 .34635 Mdot
.572 .34635 Mdot
.572 .34636 Mdot
.572 .34637 Mdot
.572 .34638 Mdot
.572 .3464 Mdot
.572 .3464 Mdot
.572 .3464 Mdot
.572 .34642 Mdot
.572 .34643 Mdot
.572 .34644 Mdot
.572 .34648 Mdot
.572 .34648 Mdot
.572 .34653 Mdot
.572 .34653 Mdot
.572 .34654 Mdot
.572 .34654 Mdot
.572 .34655 Mdot
.572 .34656 Mdot
.572 .34656 Mdot
.572 .34657 Mdot
.572 .34658 Mdot
.572 .34659 Mdot
.572 .34659 Mdot
.572 .34659 Mdot
.572 .34661 Mdot
.572 .34661 Mdot
.572 .34662 Mdot
.572 .34662 Mdot
.572 .34663 Mdot
.572 .34663 Mdot
.572 .34664 Mdot
.572 .34666 Mdot
.572 .34667 Mdot
.572 .3467 Mdot
.572 .34675 Mdot
.572 .34675 Mdot
.572 .34676 Mdot
.572 .34676 Mdot
.572 .34677 Mdot
.572 .34679 Mdot
.572 .34679 Mdot
.572 .3468 Mdot
.572 .3468 Mdot
.572 .34683 Mdot
.572 .34683 Mdot
.572 .34685 Mdot
.572 .34686 Mdot
.572 .34686 Mdot
.572 .34687 Mdot
.572 .34688 Mdot
.572 .3469 Mdot
.572 .34693 Mdot
.572 .34693 Mdot
.572 .34694 Mdot
.572 .34695 Mdot
.572 .34698 Mdot
.572 .34699 Mdot
.572 .347 Mdot
.572 .347 Mdot
.572 .347 Mdot
.572 .347 Mdot
.572 .347 Mdot
.572 .34702 Mdot
.572 .34704 Mdot
.572 .34706 Mdot
.572 .34706 Mdot
.572 .34706 Mdot
.572 .34707 Mdot
.572 .34709 Mdot
.572 .34714 Mdot
.572 .34715 Mdot
.572 .34716 Mdot
.572 .34717 Mdot
.572 .34717 Mdot
.572 .34719 Mdot
.572 .34719 Mdot
.572 .34721 Mdot
.572 .34721 Mdot
.572 .34724 Mdot
.572 .34725 Mdot
.572 .34729 Mdot
.572 .34729 Mdot
.572 .3473 Mdot
.572 .34731 Mdot
.572 .34731 Mdot
.572 .34731 Mdot
.572 .34732 Mdot
.572 .34732 Mdot
.572 .34736 Mdot
.572 .34737 Mdot
.572 .34737 Mdot
.572 .34738 Mdot
.572 .34739 Mdot
.572 .34742 Mdot
.572 .34743 Mdot
.572 .34745 Mdot
.572 .34746 Mdot
.572 .34749 Mdot
.572 .34749 Mdot
.572 .3475 Mdot
.572 .3475 Mdot
.572 .3475 Mdot
.572 .34751 Mdot
.572 .34751 Mdot
.572 .34753 Mdot
.572 .34756 Mdot
.572 .34762 Mdot
.572 .34763 Mdot
.572 .34767 Mdot
.572 .3477 Mdot
.572 .34772 Mdot
.572 .34777 Mdot
.572 .34778 Mdot
.572 .34779 Mdot
.572 .34781 Mdot
.572 .34781 Mdot
.572 .34783 Mdot
.572 .34785 Mdot
.572 .34786 Mdot
.572 .34789 Mdot
.572 .34789 Mdot
.572 .34789 Mdot
.572 .34792 Mdot
.572 .34793 Mdot
.572 .34793 Mdot
.572 .34793 Mdot
.572 .34799 Mdot
.572 .348 Mdot
.572 .35001 Mdot
.572 .35003 Mdot
.572 .35007 Mdot
.572 .35007 Mdot
.572 .35007 Mdot
.572 .35008 Mdot
.572 .3501 Mdot
.572 .3501 Mdot
.572 .3501 Mdot
.572 .35012 Mdot
.572 .35013 Mdot
.572 .35014 Mdot
.572 .35016 Mdot
.572 .35016 Mdot
.572 .35017 Mdot
.572 .35019 Mdot
.572 .35019 Mdot
.572 .35023 Mdot
.572 .35025 Mdot
.572 .35027 Mdot
.572 .3503 Mdot
.572 .3503 Mdot
.572 .35035 Mdot
.572 .35037 Mdot
.572 .35039 Mdot
.572 .35039 Mdot
.572 .3504 Mdot
.572 .3504 Mdot
.572 .3504 Mdot
.572 .35041 Mdot
.572 .35041 Mdot
.572 .35043 Mdot
.572 .35044 Mdot
.572 .35045 Mdot
.572 .35046 Mdot
.572 .35048 Mdot
.572 .35049 Mdot
.572 .35049 Mdot
.572 .3505 Mdot
.572 .3505 Mdot
.572 .35053 Mdot
.572 .35054 Mdot
.572 .35054 Mdot
.572 .35054 Mdot
.572 .35055 Mdot
.572 .35055 Mdot
.572 .35055 Mdot
.572 .35056 Mdot
.572 .35059 Mdot
.572 .3506 Mdot
.572 .35062 Mdot
.572 .35062 Mdot
.572 .35063 Mdot
.572 .35064 Mdot
.572 .35065 Mdot
.572 .35065 Mdot
.572 .35066 Mdot
.572 .35067 Mdot
.572 .35067 Mdot
.572 .35071 Mdot
.572 .35073 Mdot
.572 .35073 Mdot
.572 .35073 Mdot
.572 .35074 Mdot
.572 .35075 Mdot
.572 .35077 Mdot
.572 .35078 Mdot
.572 .35078 Mdot
.572 .35078 Mdot
.572 .35078 Mdot
.572 .35078 Mdot
.572 .35079 Mdot
.572 .3508 Mdot
.572 .35082 Mdot
.572 .35082 Mdot
.572 .35083 Mdot
.572 .35084 Mdot
.572 .35086 Mdot
.572 .35087 Mdot
.572 .35088 Mdot
.572 .35088 Mdot
.572 .35089 Mdot
.572 .35089 Mdot
.572 .35091 Mdot
.572 .35091 Mdot
.572 .35093 Mdot
.572 .35093 Mdot
.572 .35094 Mdot
.572 .35094 Mdot
.572 .35096 Mdot
.572 .35096 Mdot
.572 .35096 Mdot
.572 .35097 Mdot
.572 .35097 Mdot
.572 .35101 Mdot
.572 .35104 Mdot
.572 .35104 Mdot
.572 .35105 Mdot
.572 .35106 Mdot
.572 .35106 Mdot
.572 .35107 Mdot
.572 .35107 Mdot
.572 .35108 Mdot
.572 .35108 Mdot
.572 .35109 Mdot
.572 .35109 Mdot
.572 .3511 Mdot
.572 .3511 Mdot
.572 .35111 Mdot
.572 .35112 Mdot
.572 .35112 Mdot
.572 .35112 Mdot
.572 .35113 Mdot
.572 .35113 Mdot
.572 .35114 Mdot
.572 .35114 Mdot
.572 .35117 Mdot
.572 .35118 Mdot
.572 .35121 Mdot
.572 .35122 Mdot
.572 .35123 Mdot
.572 .35124 Mdot
.572 .35124 Mdot
.572 .35124 Mdot
.572 .35125 Mdot
.572 .35126 Mdot
.572 .35127 Mdot
.572 .35127 Mdot
.572 .35127 Mdot
.572 .35128 Mdot
.572 .35129 Mdot
.572 .35129 Mdot
.572 .3513 Mdot
.572 .3513 Mdot
.572 .35131 Mdot
.572 .35131 Mdot
.572 .35133 Mdot
.572 .35133 Mdot
.572 .35134 Mdot
.572 .35135 Mdot
.572 .35136 Mdot
.572 .35136 Mdot
.572 .35139 Mdot
.572 .3514 Mdot
.572 .3514 Mdot
.572 .35141 Mdot
.572 .35143 Mdot
.572 .35144 Mdot
.572 .35144 Mdot
.572 .35144 Mdot
.572 .35146 Mdot
.572 .35146 Mdot
.572 .35146 Mdot
.572 .35147 Mdot
.572 .35147 Mdot
.572 .35149 Mdot
.572 .3515 Mdot
.572 .35152 Mdot
.572 .35152 Mdot
.572 .35152 Mdot
.572 .35153 Mdot
.572 .35153 Mdot
.572 .35153 Mdot
.572 .35154 Mdot
.572 .35154 Mdot
.572 .35154 Mdot
.572 .35154 Mdot
.572 .35155 Mdot
.572 .35155 Mdot
.572 .35156 Mdot
.572 .35156 Mdot
.572 .35156 Mdot
.572 .35157 Mdot
.572 .35157 Mdot
.572 .35159 Mdot
.572 .35161 Mdot
.572 .35161 Mdot
.572 .35162 Mdot
.572 .35162 Mdot
.572 .35163 Mdot
.572 .35164 Mdot
.572 .35165 Mdot
.572 .35167 Mdot
.572 .35167 Mdot
.572 .35167 Mdot
.572 .3517 Mdot
.572 .3517 Mdot
.572 .35172 Mdot
.572 .35172 Mdot
.572 .35173 Mdot
.572 .35173 Mdot
.572 .35173 Mdot
.572 .35176 Mdot
.572 .35176 Mdot
.572 .35179 Mdot
.572 .35179 Mdot
.572 .3518 Mdot
.572 .3518 Mdot
.572 .35181 Mdot
.572 .35182 Mdot
.572 .35182 Mdot
.572 .35183 Mdot
.572 .35184 Mdot
.572 .35186 Mdot
.572 .35186 Mdot
.572 .35186 Mdot
.572 .35186 Mdot
.572 .35186 Mdot
.572 .35186 Mdot
.572 .35187 Mdot
.572 .35187 Mdot
.572 .35189 Mdot
.572 .35189 Mdot
.572 .35189 Mdot
.572 .3519 Mdot
.572 .3519 Mdot
.572 .35191 Mdot
.572 .35192 Mdot
.572 .35193 Mdot
.572 .35193 Mdot
.572 .35194 Mdot
.572 .35194 Mdot
.572 .35195 Mdot
.572 .35195 Mdot
.572 .35195 Mdot
.572 .35195 Mdot
.572 .35196 Mdot
.572 .35196 Mdot
.572 .35198 Mdot
.572 .352 Mdot
.572 .35201 Mdot
.572 .35202 Mdot
.572 .35204 Mdot
.572 .35205 Mdot
.572 .35207 Mdot
.572 .35207 Mdot
.572 .35208 Mdot
.572 .35209 Mdot
.572 .35209 Mdot
.572 .3521 Mdot
.572 .3521 Mdot
.572 .35211 Mdot
.572 .35212 Mdot
.572 .35212 Mdot
.572 .35212 Mdot
.572 .35213 Mdot
.572 .35214 Mdot
.572 .35214 Mdot
.572 .35214 Mdot
.572 .35217 Mdot
.572 .35217 Mdot
.574 .30324 Mdot
.574 .30324 Mdot
.574 .30325 Mdot
.574 .30325 Mdot
.574 .30326 Mdot
.574 .30328 Mdot
.574 .30329 Mdot
.574 .3033 Mdot
.574 .3033 Mdot
.574 .30332 Mdot
.574 .30332 Mdot
.574 .30334 Mdot
.574 .30334 Mdot
.574 .30334 Mdot
.574 .30334 Mdot
.574 .30335 Mdot
.574 .30335 Mdot
.574 .30335 Mdot
.574 .30336 Mdot
.574 .30336 Mdot
.574 .30338 Mdot
.574 .30339 Mdot
.574 .30339 Mdot
.574 .3034 Mdot
.574 .3034 Mdot
.574 .3034 Mdot
.574 .30341 Mdot
.574 .30343 Mdot
.574 .30344 Mdot
.574 .30344 Mdot
.574 .30344 Mdot
.574 .30345 Mdot
.574 .30346 Mdot
.574 .30346 Mdot
.574 .30348 Mdot
.574 .30349 Mdot
.574 .30349 Mdot
.574 .30351 Mdot
.574 .30353 Mdot
.574 .30354 Mdot
.574 .30355 Mdot
.574 .30356 Mdot
.574 .30356 Mdot
.574 .30356 Mdot
.574 .30357 Mdot
.574 .30358 Mdot
.574 .3036 Mdot
.574 .3036 Mdot
.574 .30361 Mdot
.574 .30363 Mdot
.574 .30364 Mdot
.574 .30364 Mdot
.574 .30367 Mdot
.574 .30367 Mdot
.574 .30368 Mdot
.574 .30368 Mdot
.574 .30368 Mdot
.574 .3037 Mdot
.574 .30373 Mdot
.574 .30375 Mdot
.574 .30375 Mdot
.574 .30376 Mdot
.574 .30379 Mdot
.574 .3038 Mdot
.574 .30382 Mdot
.574 .30383 Mdot
.574 .30383 Mdot
.574 .30384 Mdot
.574 .30386 Mdot
.574 .30389 Mdot
.574 .3039 Mdot
.574 .3039 Mdot
.574 .30391 Mdot
.574 .30391 Mdot
.574 .30392 Mdot
.574 .30392 Mdot
.574 .30393 Mdot
.574 .30393 Mdot
.574 .30394 Mdot
.574 .30395 Mdot
.574 .30395 Mdot
.574 .30396 Mdot
.574 .30398 Mdot
.574 .30399 Mdot
.574 .30401 Mdot
.574 .30402 Mdot
.574 .30402 Mdot
.574 .30403 Mdot
.574 .30406 Mdot
.574 .30409 Mdot
.574 .30409 Mdot
.574 .3041 Mdot
.574 .30412 Mdot
.574 .30412 Mdot
.574 .30413 Mdot
.574 .30414 Mdot
.574 .30415 Mdot
.574 .30417 Mdot
.574 .30418 Mdot
.574 .30418 Mdot
.574 .30419 Mdot
.574 .30421 Mdot
.574 .30422 Mdot
.574 .30423 Mdot
.574 .30425 Mdot
.574 .30425 Mdot
.574 .30426 Mdot
.574 .30427 Mdot
.574 .30428 Mdot
.574 .30428 Mdot
.574 .30429 Mdot
.574 .3043 Mdot
.574 .30432 Mdot
.574 .30434 Mdot
.574 .30435 Mdot
.574 .30437 Mdot
.574 .30438 Mdot
.574 .30439 Mdot
.574 .3044 Mdot
.574 .3044 Mdot
.574 .30443 Mdot
.574 .30445 Mdot
.574 .30445 Mdot
.574 .30447 Mdot
.574 .30448 Mdot
.574 .3045 Mdot
.574 .30451 Mdot
.574 .30454 Mdot
.574 .30454 Mdot
.574 .30456 Mdot
.574 .30458 Mdot
.574 .30458 Mdot
.574 .30459 Mdot
.574 .3046 Mdot
.574 .3046 Mdot
.574 .30461 Mdot
.574 .30461 Mdot
.574 .30462 Mdot
.574 .30465 Mdot
.574 .30465 Mdot
.574 .30467 Mdot
.574 .3047 Mdot
.574 .3047 Mdot
.574 .30471 Mdot
.574 .30472 Mdot
.574 .30472 Mdot
.574 .30473 Mdot
.574 .30473 Mdot
.574 .30474 Mdot
.574 .30474 Mdot
.574 .30474 Mdot
.574 .30476 Mdot
.574 .30476 Mdot
.574 .30476 Mdot
.574 .30477 Mdot
.574 .30478 Mdot
.574 .30479 Mdot
.574 .30479 Mdot
.574 .3048 Mdot
.574 .3048 Mdot
.574 .30484 Mdot
.574 .30486 Mdot
.574 .30486 Mdot
.574 .30486 Mdot
.574 .30488 Mdot
.574 .30489 Mdot
.574 .30489 Mdot
.574 .3049 Mdot
.574 .3049 Mdot
.574 .30491 Mdot
.574 .30491 Mdot
.574 .30492 Mdot
.574 .30493 Mdot
.574 .30493 Mdot
.574 .30493 Mdot
.574 .30495 Mdot
.574 .30497 Mdot
.574 .30498 Mdot
.574 .30498 Mdot
.574 .30502 Mdot
.574 .30503 Mdot
.574 .30504 Mdot
.574 .30505 Mdot
.574 .30505 Mdot
.574 .30506 Mdot
.574 .30509 Mdot
.574 .3051 Mdot
.574 .30513 Mdot
.574 .30514 Mdot
.574 .30517 Mdot
.574 .30517 Mdot
.574 .30518 Mdot
.574 .30518 Mdot
.574 .30519 Mdot
.574 .30519 Mdot
.574 .3052 Mdot
.574 .3052 Mdot
.574 .30522 Mdot
.574 .30523 Mdot
.574 .30524 Mdot
.574 .30525 Mdot
.574 .30529 Mdot
.574 .30531 Mdot
.574 .30531 Mdot
.574 .30534 Mdot
.574 .30536 Mdot
.574 .30538 Mdot
.574 .30538 Mdot
.574 .30539 Mdot
.574 .3054 Mdot
.574 .30543 Mdot
.574 .30546 Mdot
.574 .3055 Mdot
.574 .30551 Mdot
.574 .30552 Mdot
.574 .30554 Mdot
.574 .30555 Mdot
.574 .30557 Mdot
.574 .30558 Mdot
.574 .30558 Mdot
.574 .30559 Mdot
.574 .30561 Mdot
.574 .30564 Mdot
.574 .30565 Mdot
.574 .30566 Mdot
.574 .30566 Mdot
.574 .30567 Mdot
.574 .30568 Mdot
.574 .30569 Mdot
.574 .30572 Mdot
.574 .30573 Mdot
.574 .30573 Mdot
.574 .30574 Mdot
.574 .30575 Mdot
.574 .30575 Mdot
.574 .30576 Mdot
.574 .30576 Mdot
.574 .30577 Mdot
.574 .30577 Mdot
.574 .30579 Mdot
.574 .3058 Mdot
.574 .30583 Mdot
.574 .30583 Mdot
.574 .30585 Mdot
.574 .30587 Mdot
.574 .30589 Mdot
.574 .30592 Mdot
.574 .30592 Mdot
.574 .30593 Mdot
.574 .30594 Mdot
.574 .30819 Mdot
.574 .3082 Mdot
.574 .30821 Mdot
.574 .30821 Mdot
.574 .30825 Mdot
.574 .30828 Mdot
.574 .30831 Mdot
.574 .30832 Mdot
.574 .30833 Mdot
.574 .30837 Mdot
.574 .30838 Mdot
.574 .30841 Mdot
.574 .30841 Mdot
.574 .30842 Mdot
.574 .30842 Mdot
.574 .30844 Mdot
.574 .30844 Mdot
.574 .30845 Mdot
.574 .30846 Mdot
.574 .30846 Mdot
.574 .30848 Mdot
.574 .30852 Mdot
.574 .30853 Mdot
.574 .30854 Mdot
.574 .30856 Mdot
.574 .30856 Mdot
.574 .30857 Mdot
.574 .30859 Mdot
.574 .30862 Mdot
.574 .30865 Mdot
.574 .30866 Mdot
.574 .30866 Mdot
.574 .30867 Mdot
.574 .3087 Mdot
.574 .30871 Mdot
.574 .30874 Mdot
.574 .30876 Mdot
.574 .30876 Mdot
.574 .30882 Mdot
.574 .30886 Mdot
.574 .3089 Mdot
.574 .30891 Mdot
.574 .30893 Mdot
.574 .30893 Mdot
.574 .30895 Mdot
.574 .30897 Mdot
.574 .30901 Mdot
.574 .30902 Mdot
.574 .30905 Mdot
.574 .30909 Mdot
.574 .3091 Mdot
.574 .30912 Mdot
.574 .30913 Mdot
.574 .30916 Mdot
.574 .30916 Mdot
.574 .30917 Mdot
.574 .30917 Mdot
.574 .30918 Mdot
.574 .30919 Mdot
.574 .3092 Mdot
.574 .3092 Mdot
.574 .30924 Mdot
.574 .30926 Mdot
.574 .30929 Mdot
.574 .30931 Mdot
.574 .30934 Mdot
.574 .30936 Mdot
.574 .30936 Mdot
.574 .30937 Mdot
.574 .30939 Mdot
.574 .30939 Mdot
.574 .30945 Mdot
.574 .30945 Mdot
.574 .30946 Mdot
.574 .30949 Mdot
.574 .30951 Mdot
.574 .30952 Mdot
.574 .30952 Mdot
.574 .30953 Mdot
.574 .30954 Mdot
.574 .30954 Mdot
.574 .30955 Mdot
.574 .30956 Mdot
.574 .30957 Mdot
.574 .30957 Mdot
.574 .30958 Mdot
.574 .30961 Mdot
.574 .30961 Mdot
.574 .30961 Mdot
.574 .30963 Mdot
.574 .30969 Mdot
.574 .30969 Mdot
.574 .3097 Mdot
.574 .30971 Mdot
.574 .30972 Mdot
.574 .30973 Mdot
.574 .30974 Mdot
.574 .30974 Mdot
.574 .30975 Mdot
.574 .30976 Mdot
.574 .30977 Mdot
.574 .30977 Mdot
.574 .30978 Mdot
.574 .30978 Mdot
.574 .30979 Mdot
.574 .30979 Mdot
.574 .30981 Mdot
.574 .30982 Mdot
.574 .30982 Mdot
.574 .30985 Mdot
.574 .30989 Mdot
.574 .30989 Mdot
.574 .30992 Mdot
.574 .30993 Mdot
.574 .30994 Mdot
.574 .30995 Mdot
.574 .30996 Mdot
.574 .30997 Mdot
.574 .30997 Mdot
.574 .30998 Mdot
.574 .31 Mdot
.574 .31003 Mdot
.574 .31003 Mdot
.574 .31007 Mdot
.574 .31009 Mdot
.574 .31012 Mdot
.574 .31013 Mdot
.574 .31015 Mdot
.574 .31015 Mdot
.574 .31017 Mdot
.574 .31021 Mdot
.574 .31021 Mdot
.574 .31022 Mdot
.574 .31024 Mdot
.574 .31025 Mdot
.574 .31028 Mdot
.574 .31029 Mdot
.574 .31032 Mdot
.574 .31035 Mdot
.574 .31036 Mdot
.574 .31037 Mdot
.574 .31037 Mdot
.574 .31039 Mdot
.574 .31041 Mdot
.574 .31041 Mdot
.574 .31042 Mdot
.574 .31043 Mdot
.574 .31045 Mdot
.574 .31047 Mdot
.574 .31049 Mdot
.574 .3105 Mdot
.574 .3105 Mdot
.574 .31052 Mdot
.574 .31054 Mdot
.574 .31056 Mdot
.574 .31057 Mdot
.574 .31058 Mdot
.574 .31058 Mdot
.574 .31061 Mdot
.574 .31062 Mdot
.574 .31062 Mdot
.574 .31066 Mdot
.574 .3107 Mdot
.574 .31071 Mdot
.574 .31072 Mdot
.574 .31073 Mdot
.574 .31075 Mdot
.574 .31077 Mdot
.574 .31079 Mdot
.574 .31081 Mdot
.574 .31081 Mdot
.574 .31083 Mdot
.574 .31083 Mdot
.574 .31083 Mdot
.574 .31084 Mdot
.574 .31085 Mdot
.574 .31085 Mdot
.574 .31086 Mdot
.574 .31088 Mdot
.574 .31088 Mdot
.574 .31088 Mdot
.574 .31093 Mdot
.574 .31096 Mdot
.574 .31096 Mdot
.574 .31097 Mdot
.574 .31099 Mdot
.574 .311 Mdot
.574 .31102 Mdot
.574 .31105 Mdot
.574 .31107 Mdot
.574 .31107 Mdot
.574 .3111 Mdot
.574 .31113 Mdot
.574 .31117 Mdot
.574 .31117 Mdot
.574 .31117 Mdot
.574 .31117 Mdot
.574 .31118 Mdot
.574 .31121 Mdot
.574 .31122 Mdot
.574 .31123 Mdot
.574 .31125 Mdot
.574 .31127 Mdot
.574 .31127 Mdot
.574 .3113 Mdot
.574 .31131 Mdot
.574 .31132 Mdot
.574 .31132 Mdot
.574 .31133 Mdot
.574 .31134 Mdot
.574 .31136 Mdot
.574 .31138 Mdot
.574 .31142 Mdot
.574 .31142 Mdot
.574 .31143 Mdot
.574 .31145 Mdot
.574 .31145 Mdot
.574 .31147 Mdot
.574 .31148 Mdot
.574 .31148 Mdot
.574 .31148 Mdot
.574 .3115 Mdot
.574 .31152 Mdot
.574 .31153 Mdot
.574 .31153 Mdot
.574 .31153 Mdot
.574 .31154 Mdot
.574 .31155 Mdot
.574 .31156 Mdot
.574 .31158 Mdot
.574 .31159 Mdot
.574 .31159 Mdot
.574 .3116 Mdot
.574 .3116 Mdot
.574 .3116 Mdot
.574 .31161 Mdot
.574 .31161 Mdot
.574 .31162 Mdot
.574 .31162 Mdot
.574 .31164 Mdot
.574 .31164 Mdot
.574 .31166 Mdot
.574 .31167 Mdot
.574 .31168 Mdot
.574 .31169 Mdot
.574 .31171 Mdot
.574 .31173 Mdot
.574 .31174 Mdot
.574 .31174 Mdot
.574 .31175 Mdot
.574 .34594 Mdot
.574 .34595 Mdot
.574 .34595 Mdot
.574 .34595 Mdot
.574 .34597 Mdot
.574 .34599 Mdot
.574 .346 Mdot
.574 .34601 Mdot
.574 .34601 Mdot
.574 .34603 Mdot
.574 .34603 Mdot
.574 .34605 Mdot
.574 .34605 Mdot
.574 .34606 Mdot
.574 .34606 Mdot
.574 .34607 Mdot
.574 .34607 Mdot
.574 .34607 Mdot
.574 .34608 Mdot
.574 .34608 Mdot
.574 .34608 Mdot
.574 .3461 Mdot
.574 .34611 Mdot
.574 .34612 Mdot
.574 .34612 Mdot
.574 .34613 Mdot
.574 .34613 Mdot
.574 .34614 Mdot
.574 .34616 Mdot
.574 .34617 Mdot
.574 .34617 Mdot
.574 .34618 Mdot
.574 .34618 Mdot
.574 .3462 Mdot
.574 .3462 Mdot
.574 .34621 Mdot
.574 .34622 Mdot
.574 .34623 Mdot
.574 .34625 Mdot
.574 .34627 Mdot
.574 .34629 Mdot
.574 .3463 Mdot
.574 .3463 Mdot
.574 .34631 Mdot
.574 .34631 Mdot
.574 .34632 Mdot
.574 .34633 Mdot
.574 .34635 Mdot
.574 .34635 Mdot
.574 .34637 Mdot
.574 .34639 Mdot
.574 .3464 Mdot
.574 .34641 Mdot
.574 .34643 Mdot
.574 .34644 Mdot
.574 .34644 Mdot
.574 .34644 Mdot
.574 .34644 Mdot
.574 .34647 Mdot
.574 .3465 Mdot
.574 .34653 Mdot
.574 .34653 Mdot
.574 .34654 Mdot
.574 .34657 Mdot
.574 .34659 Mdot
.574 .3466 Mdot
.574 .34662 Mdot
.574 .34662 Mdot
.574 .34663 Mdot
.574 .34665 Mdot
.574 .34669 Mdot
.574 .34669 Mdot
.574 .3467 Mdot
.574 .34671 Mdot
.574 .34672 Mdot
.574 .34672 Mdot
.574 .34673 Mdot
.574 .34673 Mdot
.574 .34673 Mdot
.574 .34674 Mdot
.574 .34675 Mdot
.574 .34675 Mdot
.574 .34677 Mdot
.574 .34679 Mdot
.574 .34681 Mdot
.574 .34683 Mdot
.574 .34683 Mdot
.574 .34684 Mdot
.574 .34685 Mdot
.574 .34688 Mdot
.574 .34692 Mdot
.574 .34692 Mdot
.574 .34693 Mdot
.574 .34695 Mdot
.574 .34696 Mdot
.574 .34697 Mdot
.574 .34697 Mdot
.574 .34699 Mdot
.574 .34701 Mdot
.574 .34702 Mdot
.574 .34703 Mdot
.574 .34703 Mdot
.574 .34705 Mdot
.574 .34706 Mdot
.574 .34708 Mdot
.574 .3471 Mdot
.574 .3471 Mdot
.574 .34711 Mdot
.574 .34712 Mdot
.574 .34714 Mdot
.574 .34714 Mdot
.574 .34715 Mdot
.574 .34716 Mdot
.574 .34718 Mdot
.574 .34721 Mdot
.574 .34721 Mdot
.574 .34724 Mdot
.574 .34725 Mdot
.574 .34727 Mdot
.574 .34727 Mdot
.574 .34728 Mdot
.574 .34731 Mdot
.574 .34733 Mdot
.574 .34733 Mdot
.574 .34735 Mdot
.574 .34736 Mdot
.574 .34739 Mdot
.574 .3474 Mdot
.574 .34743 Mdot
.574 .34744 Mdot
.574 .34746 Mdot
.574 .34748 Mdot
.574 .34749 Mdot
.574 .34749 Mdot
.574 .3475 Mdot
.574 .3475 Mdot
.574 .34751 Mdot
.574 .34752 Mdot
.574 .34753 Mdot
.574 .34756 Mdot
.574 .34756 Mdot
.574 .34759 Mdot
.574 .34762 Mdot
.574 .34762 Mdot
.574 .34763 Mdot
.574 .34764 Mdot
.574 .34764 Mdot
.574 .34766 Mdot
.574 .34766 Mdot
.574 .34766 Mdot
.574 .34766 Mdot
.574 .34767 Mdot
.574 .34768 Mdot
.574 .34768 Mdot
.574 .34769 Mdot
.574 .3477 Mdot
.574 .34771 Mdot
.574 .34772 Mdot
.574 .34772 Mdot
.574 .34773 Mdot
.574 .34773 Mdot
.574 .34778 Mdot
.574 .3478 Mdot
.574 .3478 Mdot
.574 .3478 Mdot
.574 .34782 Mdot
.574 .34783 Mdot
.574 .34784 Mdot
.574 .34784 Mdot
.574 .34785 Mdot
.574 .34786 Mdot
.574 .34786 Mdot
.574 .34787 Mdot
.574 .34788 Mdot
.574 .34788 Mdot
.574 .34789 Mdot
.574 .34791 Mdot
.574 .34793 Mdot
.574 .34794 Mdot
.574 .34794 Mdot
.574 .34799 Mdot
.574 .348 Mdot
.574 .34801 Mdot
.574 .34802 Mdot
.574 .34802 Mdot
.574 .34804 Mdot
.574 .34807 Mdot
.574 .34808 Mdot
.574 .34811 Mdot
.574 .34812 Mdot
.574 .34816 Mdot
.574 .34816 Mdot
.574 .34816 Mdot
.574 .34817 Mdot
.574 .34818 Mdot
.574 .34818 Mdot
.574 .34819 Mdot
.574 .34819 Mdot
.574 .34822 Mdot
.574 .34823 Mdot
.574 .34824 Mdot
.574 .34825 Mdot
.574 .34829 Mdot
.574 .34832 Mdot
.574 .34832 Mdot
.574 .34836 Mdot
.574 .34838 Mdot
.574 .34839 Mdot
.574 .3484 Mdot
.574 .34841 Mdot
.574 .34842 Mdot
.574 .34846 Mdot
.574 .34849 Mdot
.574 .34854 Mdot
.574 .34855 Mdot
.574 .34856 Mdot
.574 .34859 Mdot
.574 .34859 Mdot
.574 .34862 Mdot
.574 .34863 Mdot
.574 .34863 Mdot
.574 .34864 Mdot
.574 .34866 Mdot
.574 .34869 Mdot
.574 .34871 Mdot
.574 .34872 Mdot
.574 .34872 Mdot
.574 .34873 Mdot
.574 .34874 Mdot
.574 .34875 Mdot
.574 .34879 Mdot
.574 .3488 Mdot
.574 .3488 Mdot
.574 .34881 Mdot
.574 .34882 Mdot
.574 .34882 Mdot
.574 .34883 Mdot
.574 .34884 Mdot
.574 .34884 Mdot
.574 .34884 Mdot
.574 .34887 Mdot
.574 .34888 Mdot
.574 .34891 Mdot
.574 .34892 Mdot
.574 .34893 Mdot
.574 .34896 Mdot
.574 .34899 Mdot
.574 .34902 Mdot
.574 .34902 Mdot
.574 .34903 Mdot
.574 .34904 Mdot
.574 .351 Mdot
.574 .35101 Mdot
.574 .35101 Mdot
.574 .35101 Mdot
.574 .35104 Mdot
.574 .35106 Mdot
.574 .35108 Mdot
.574 .35109 Mdot
.574 .3511 Mdot
.574 .35112 Mdot
.574 .35113 Mdot
.574 .35115 Mdot
.574 .35115 Mdot
.574 .35115 Mdot
.574 .35115 Mdot
.574 .35117 Mdot
.574 .35117 Mdot
.574 .35117 Mdot
.574 .35118 Mdot
.574 .35118 Mdot
.574 .35119 Mdot
.574 .35122 Mdot
.574 .35122 Mdot
.574 .35123 Mdot
.574 .35124 Mdot
.574 .35124 Mdot
.574 .35125 Mdot
.574 .35126 Mdot
.574 .35129 Mdot
.574 .3513 Mdot
.574 .35131 Mdot
.574 .35131 Mdot
.574 .35132 Mdot
.574 .35134 Mdot
.574 .35134 Mdot
.574 .35136 Mdot
.574 .35137 Mdot
.574 .35138 Mdot
.574 .35142 Mdot
.574 .35144 Mdot
.574 .35147 Mdot
.574 .35148 Mdot
.574 .35149 Mdot
.574 .35149 Mdot
.574 .3515 Mdot
.574 .35152 Mdot
.574 .35154 Mdot
.574 .35155 Mdot
.574 .35157 Mdot
.574 .3516 Mdot
.574 .3516 Mdot
.574 .35162 Mdot
.574 .35162 Mdot
.574 .35164 Mdot
.574 .35164 Mdot
.574 .35165 Mdot
.574 .35165 Mdot
.574 .35166 Mdot
.574 .35166 Mdot
.574 .35166 Mdot
.574 .35167 Mdot
.574 .35169 Mdot
.574 .3517 Mdot
.574 .35173 Mdot
.574 .35174 Mdot
.574 .35176 Mdot
.574 .35177 Mdot
.574 .35177 Mdot
.574 .35178 Mdot
.574 .35179 Mdot
.574 .3518 Mdot
.574 .35183 Mdot
.574 .35184 Mdot
.574 .35184 Mdot
.574 .35186 Mdot
.574 .35187 Mdot
.574 .35188 Mdot
.574 .35188 Mdot
.574 .35189 Mdot
.574 .35189 Mdot
.574 .35189 Mdot
.574 .3519 Mdot
.574 .35191 Mdot
.574 .35191 Mdot
.574 .35191 Mdot
.574 .35192 Mdot
.574 .35194 Mdot
.574 .35194 Mdot
.574 .35194 Mdot
.574 .35195 Mdot
.574 .35199 Mdot
.574 .35199 Mdot
.574 .352 Mdot
.574 .352 Mdot
.574 .35201 Mdot
.574 .35202 Mdot
.574 .35202 Mdot
.574 .35203 Mdot
.574 .35203 Mdot
.574 .35204 Mdot
.574 .35205 Mdot
.574 .35205 Mdot
.574 .35205 Mdot
.574 .35205 Mdot
.574 .35206 Mdot
.574 .35206 Mdot
.574 .35207 Mdot
.574 .35207 Mdot
.574 .35208 Mdot
.574 .3521 Mdot
.574 .35212 Mdot
.574 .35212 Mdot
.574 .35214 Mdot
.574 .35215 Mdot
.574 .35216 Mdot
.574 .35216 Mdot
.574 .35217 Mdot
.574 .35218 Mdot
.574 .35218 Mdot
.574 .35219 Mdot
.574 .3522 Mdot
.574 .35222 Mdot
.574 .35222 Mdot
.574 .35224 Mdot
.574 .35225 Mdot
.574 .35227 Mdot
.574 .35228 Mdot
.574 .35229 Mdot
.574 .3523 Mdot
.574 .35231 Mdot
.574 .35234 Mdot
.574 .35234 Mdot
.574 .35234 Mdot
.574 .35235 Mdot
.574 .35236 Mdot
.574 .35238 Mdot
.574 .35239 Mdot
.574 .35241 Mdot
.574 .35243 Mdot
.574 .35243 Mdot
.574 .35244 Mdot
.574 .35244 Mdot
.574 .35246 Mdot
.574 .35246 Mdot
.574 .35247 Mdot
.574 .35247 Mdot
.574 .35248 Mdot
.574 .3525 Mdot
.574 .35251 Mdot
.574 .35252 Mdot
.574 .35253 Mdot
.574 .35253 Mdot
.574 .35254 Mdot
.574 .35255 Mdot
.574 .35257 Mdot
.574 .35257 Mdot
.574 .35258 Mdot
.574 .35258 Mdot
.574 .3526 Mdot
.574 .35261 Mdot
.574 .35261 Mdot
.574 .35264 Mdot
.574 .35266 Mdot
.574 .35267 Mdot
.574 .35267 Mdot
.574 .35268 Mdot
.574 .35269 Mdot
.574 .3527 Mdot
.574 .35272 Mdot
.574 .35273 Mdot
.574 .35274 Mdot
.574 .35274 Mdot
.574 .35275 Mdot
.574 .35275 Mdot
.574 .35275 Mdot
.574 .35276 Mdot
.574 .35276 Mdot
.574 .35277 Mdot
.574 .35278 Mdot
.574 .35278 Mdot
.574 .35278 Mdot
.574 .35281 Mdot
.574 .35283 Mdot
.574 .35283 Mdot
.574 .35284 Mdot
.574 .35285 Mdot
.574 .35286 Mdot
.574 .35287 Mdot
.574 .35289 Mdot
.574 .35291 Mdot
.574 .35291 Mdot
.574 .35293 Mdot
.574 .35295 Mdot
.574 .35297 Mdot
.574 .35297 Mdot
.574 .35297 Mdot
.574 .35297 Mdot
.574 .35298 Mdot
.574 .353 Mdot
.574 .353 Mdot
.574 .35301 Mdot
.574 .35303 Mdot
.574 .35304 Mdot
.574 .35304 Mdot
.574 .35305 Mdot
.574 .35306 Mdot
.574 .35307 Mdot
.574 .35307 Mdot
.574 .35308 Mdot
.574 .35308 Mdot
.574 .35309 Mdot
.574 .3531 Mdot
.574 .35311 Mdot
.574 .35313 Mdot
.574 .35314 Mdot
.574 .35314 Mdot
.574 .35315 Mdot
.574 .35316 Mdot
.574 .35317 Mdot
.574 .35317 Mdot
.574 .35317 Mdot
.574 .35318 Mdot
.574 .35319 Mdot
.574 .3532 Mdot
.574 .35321 Mdot
.574 .35321 Mdot
.574 .35321 Mdot
.574 .35322 Mdot
.574 .35322 Mdot
.574 .35323 Mdot
.574 .35324 Mdot
.574 .35325 Mdot
.574 .35325 Mdot
.574 .35326 Mdot
.574 .35326 Mdot
.574 .35326 Mdot
.574 .35326 Mdot
.574 .35327 Mdot
.574 .35327 Mdot
.574 .35328 Mdot
.574 .35328 Mdot
.574 .3533 Mdot
.574 .3533 Mdot
.574 .35331 Mdot
.574 .35332 Mdot
.574 .35333 Mdot
.574 .35334 Mdot
.574 .35334 Mdot
.574 .35335 Mdot
.574 .35335 Mdot
.576 .30289 Mdot
.576 .3029 Mdot
.576 .30292 Mdot
.576 .30292 Mdot
.576 .30293 Mdot
.576 .30293 Mdot
.576 .30295 Mdot
.576 .30295 Mdot
.576 .30296 Mdot
.576 .30297 Mdot
.576 .30299 Mdot
.576 .303 Mdot
.576 .30301 Mdot
.576 .30304 Mdot
.576 .30307 Mdot
.576 .3031 Mdot
.576 .30313 Mdot
.576 .30315 Mdot
.576 .30316 Mdot
.576 .30316 Mdot
.576 .30317 Mdot
.576 .30317 Mdot
.576 .30317 Mdot
.576 .30317 Mdot
.576 .30318 Mdot
.576 .30318 Mdot
.576 .30319 Mdot
.576 .3032 Mdot
.576 .3032 Mdot
.576 .30321 Mdot
.576 .30322 Mdot
.576 .30322 Mdot
.576 .30325 Mdot
.576 .30325 Mdot
.576 .30325 Mdot
.576 .30327 Mdot
.576 .30328 Mdot
.576 .30329 Mdot
.576 .3033 Mdot
.576 .3033 Mdot
.576 .30331 Mdot
.576 .30332 Mdot
.576 .30333 Mdot
.576 .30334 Mdot
.576 .30334 Mdot
.576 .30336 Mdot
.576 .30336 Mdot
.576 .3034 Mdot
.576 .30341 Mdot
.576 .30341 Mdot
.576 .30342 Mdot
.576 .30342 Mdot
.576 .30342 Mdot
.576 .30343 Mdot
.576 .30344 Mdot
.576 .30345 Mdot
.576 .30345 Mdot
.576 .30346 Mdot
.576 .30347 Mdot
.576 .30347 Mdot
.576 .30348 Mdot
.576 .30349 Mdot
.576 .30349 Mdot
.576 .30349 Mdot
.576 .3035 Mdot
.576 .30351 Mdot
.576 .30351 Mdot
.576 .30352 Mdot
.576 .30352 Mdot
.576 .30354 Mdot
.576 .30356 Mdot
.576 .30356 Mdot
.576 .30359 Mdot
.576 .3036 Mdot
.576 .3036 Mdot
.576 .3036 Mdot
.576 .30363 Mdot
.576 .30363 Mdot
.576 .30363 Mdot
.576 .30364 Mdot
.576 .30364 Mdot
.576 .30369 Mdot
.576 .3037 Mdot
.576 .3037 Mdot
.576 .3037 Mdot
.576 .3037 Mdot
.576 .3037 Mdot
.576 .30371 Mdot
.576 .30371 Mdot
.576 .30373 Mdot
.576 .30374 Mdot
.576 .30375 Mdot
.576 .30376 Mdot
.576 .30378 Mdot
.576 .30378 Mdot
.576 .30381 Mdot
.576 .30381 Mdot
.576 .30383 Mdot
.576 .30384 Mdot
.576 .30385 Mdot
.576 .30387 Mdot
.576 .30387 Mdot
.576 .30388 Mdot
.576 .30389 Mdot
.576 .30389 Mdot
.576 .3039 Mdot
.576 .30393 Mdot
.576 .30399 Mdot
.576 .30399 Mdot
.576 .30399 Mdot
.576 .304 Mdot
.576 .30405 Mdot
.576 .30406 Mdot
.576 .30407 Mdot
.576 .30408 Mdot
.576 .30409 Mdot
.576 .30409 Mdot
.576 .3041 Mdot
.576 .3041 Mdot
.576 .30413 Mdot
.576 .30414 Mdot
.576 .30414 Mdot
.576 .30416 Mdot
.576 .30416 Mdot
.576 .30417 Mdot
.576 .30418 Mdot
.576 .3042 Mdot
.576 .3042 Mdot
.576 .30421 Mdot
.576 .30422 Mdot
.576 .30422 Mdot
.576 .30423 Mdot
.576 .30424 Mdot
.576 .30425 Mdot
.576 .30425 Mdot
.576 .30425 Mdot
.576 .30425 Mdot
.576 .30426 Mdot
.576 .3043 Mdot
.576 .30431 Mdot
.576 .30431 Mdot
.576 .30433 Mdot
.576 .30434 Mdot
.576 .30437 Mdot
.576 .30438 Mdot
.576 .30438 Mdot
.576 .30439 Mdot
.576 .30439 Mdot
.576 .30439 Mdot
.576 .3044 Mdot
.576 .3044 Mdot
.576 .30442 Mdot
.576 .30445 Mdot
.576 .3045 Mdot
.576 .30451 Mdot
.576 .30452 Mdot
.576 .30452 Mdot
.576 .30452 Mdot
.576 .30453 Mdot
.576 .30455 Mdot
.576 .30457 Mdot
.576 .30458 Mdot
.576 .30458 Mdot
.576 .30459 Mdot
.576 .30463 Mdot
.576 .30464 Mdot
.576 .30465 Mdot
.576 .30469 Mdot
.576 .30471 Mdot
.576 .30472 Mdot
.576 .30472 Mdot
.576 .30473 Mdot
.576 .30474 Mdot
.576 .30474 Mdot
.576 .30475 Mdot
.576 .30477 Mdot
.576 .30477 Mdot
.576 .30477 Mdot
.576 .30479 Mdot
.576 .30479 Mdot
.576 .3048 Mdot
.576 .3048 Mdot
.576 .30482 Mdot
.576 .30484 Mdot
.576 .30484 Mdot
.576 .30486 Mdot
.576 .30486 Mdot
.576 .30487 Mdot
.576 .30488 Mdot
.576 .30488 Mdot
.576 .30489 Mdot
.576 .3049 Mdot
.576 .30491 Mdot
.576 .30491 Mdot
.576 .30491 Mdot
.576 .30492 Mdot
.576 .30493 Mdot
.576 .30497 Mdot
.576 .30497 Mdot
.576 .30499 Mdot
.576 .30499 Mdot
.576 .30502 Mdot
.576 .30503 Mdot
.576 .30503 Mdot
.576 .30503 Mdot
.576 .30505 Mdot
.576 .30507 Mdot
.576 .30509 Mdot
.576 .30509 Mdot
.576 .3051 Mdot
.576 .3051 Mdot
.576 .30511 Mdot
.576 .30512 Mdot
.576 .30514 Mdot
.576 .30516 Mdot
.576 .30519 Mdot
.576 .30519 Mdot
.576 .3052 Mdot
.576 .30525 Mdot
.576 .30525 Mdot
.576 .30527 Mdot
.576 .30527 Mdot
.576 .30529 Mdot
.576 .3053 Mdot
.576 .30531 Mdot
.576 .30532 Mdot
.576 .30532 Mdot
.576 .30532 Mdot
.576 .30534 Mdot
.576 .30534 Mdot
.576 .30534 Mdot
.576 .30534 Mdot
.576 .30537 Mdot
.576 .30541 Mdot
.576 .30545 Mdot
.576 .30551 Mdot
.576 .30555 Mdot
.576 .30561 Mdot
.576 .30562 Mdot
.576 .30564 Mdot
.576 .30568 Mdot
.576 .3057 Mdot
.576 .30571 Mdot
.576 .30573 Mdot
.576 .30575 Mdot
.576 .30575 Mdot
.576 .30577 Mdot
.576 .30578 Mdot
.576 .30581 Mdot
.576 .30582 Mdot
.576 .30802 Mdot
.576 .30803 Mdot
.576 .30808 Mdot
.576 .30809 Mdot
.576 .30812 Mdot
.576 .30813 Mdot
.576 .30815 Mdot
.576 .30817 Mdot
.576 .30818 Mdot
.576 .30821 Mdot
.576 .30826 Mdot
.576 .30829 Mdot
.576 .30831 Mdot
.576 .30838 Mdot
.576 .30844 Mdot
.576 .30851 Mdot
.576 .30857 Mdot
.576 .30862 Mdot
.576 .30866 Mdot
.576 .30866 Mdot
.576 .30867 Mdot
.576 .30867 Mdot
.576 .30868 Mdot
.576 .30869 Mdot
.576 .30869 Mdot
.576 .3087 Mdot
.576 .30872 Mdot
.576 .30873 Mdot
.576 .30875 Mdot
.576 .30876 Mdot
.576 .30878 Mdot
.576 .30878 Mdot
.576 .30885 Mdot
.576 .30886 Mdot
.576 .30886 Mdot
.576 .30891 Mdot
.576 .30893 Mdot
.576 .30895 Mdot
.576 .30897 Mdot
.576 .30898 Mdot
.576 .30898 Mdot
.576 .30899 Mdot
.576 .309 Mdot
.576 .30902 Mdot
.576 .30905 Mdot
.576 .30907 Mdot
.576 .30908 Mdot
.576 .30908 Mdot
.576 .30909 Mdot
.576 .30913 Mdot
.576 .30913 Mdot
.576 .30915 Mdot
.576 .30916 Mdot
.576 .3092 Mdot
.576 .30922 Mdot
.576 .30923 Mdot
.576 .30924 Mdot
.576 .30924 Mdot
.576 .30925 Mdot
.576 .30926 Mdot
.576 .30927 Mdot
.576 .30927 Mdot
.576 .30929 Mdot
.576 .3093 Mdot
.576 .3093 Mdot
.576 .30933 Mdot
.576 .30933 Mdot
.576 .30935 Mdot
.576 .30938 Mdot
.576 .30938 Mdot
.576 .30939 Mdot
.576 .3094 Mdot
.576 .30942 Mdot
.576 .30942 Mdot
.576 .30942 Mdot
.576 .30944 Mdot
.576 .30945 Mdot
.576 .30946 Mdot
.576 .30948 Mdot
.576 .30948 Mdot
.576 .30948 Mdot
.576 .3095 Mdot
.576 .30953 Mdot
.576 .30957 Mdot
.576 .3096 Mdot
.576 .3096 Mdot
.576 .30966 Mdot
.576 .30967 Mdot
.576 .30967 Mdot
.576 .30969 Mdot
.576 .30971 Mdot
.576 .30974 Mdot
.576 .30975 Mdot
.576 .30975 Mdot
.576 .30976 Mdot
.576 .30976 Mdot
.576 .30978 Mdot
.576 .30984 Mdot
.576 .30988 Mdot
.576 .30991 Mdot
.576 .30991 Mdot
.576 .30992 Mdot
.576 .30992 Mdot
.576 .30992 Mdot
.576 .30993 Mdot
.576 .30994 Mdot
.576 .30995 Mdot
.576 .30999 Mdot
.576 .31001 Mdot
.576 .31002 Mdot
.576 .31003 Mdot
.576 .31004 Mdot
.576 .3101 Mdot
.576 .3101 Mdot
.576 .31011 Mdot
.576 .31011 Mdot
.576 .31011 Mdot
.576 .31012 Mdot
.576 .31014 Mdot
.576 .31014 Mdot
.576 .31015 Mdot
.576 .31017 Mdot
.576 .31017 Mdot
.576 .31018 Mdot
.576 .3102 Mdot
.576 .31021 Mdot
.576 .31023 Mdot
.576 .31024 Mdot
.576 .31026 Mdot
.576 .31026 Mdot
.576 .31027 Mdot
.576 .31031 Mdot
.576 .31031 Mdot
.576 .31032 Mdot
.576 .31032 Mdot
.576 .31034 Mdot
.576 .31035 Mdot
.576 .31036 Mdot
.576 .31038 Mdot
.576 .31044 Mdot
.576 .31045 Mdot
.576 .31045 Mdot
.576 .31046 Mdot
.576 .31053 Mdot
.576 .31058 Mdot
.576 .31059 Mdot
.576 .31059 Mdot
.576 .3106 Mdot
.576 .31061 Mdot
.576 .31061 Mdot
.576 .31064 Mdot
.576 .31066 Mdot
.576 .31067 Mdot
.576 .31069 Mdot
.576 .31069 Mdot
.576 .31073 Mdot
.576 .31073 Mdot
.576 .31077 Mdot
.576 .31078 Mdot
.576 .31079 Mdot
.576 .3108 Mdot
.576 .31082 Mdot
.576 .31083 Mdot
.576 .31083 Mdot
.576 .31084 Mdot
.576 .31084 Mdot
.576 .31084 Mdot
.576 .31084 Mdot
.576 .31086 Mdot
.576 .31091 Mdot
.576 .31092 Mdot
.576 .31093 Mdot
.576 .31093 Mdot
.576 .31093 Mdot
.576 .31097 Mdot
.576 .31098 Mdot
.576 .31098 Mdot
.576 .31098 Mdot
.576 .31102 Mdot
.576 .31103 Mdot
.576 .31106 Mdot
.576 .31108 Mdot
.576 .31108 Mdot
.576 .31109 Mdot
.576 .31109 Mdot
.576 .3111 Mdot
.576 .31112 Mdot
.576 .31112 Mdot
.576 .31112 Mdot
.576 .31114 Mdot
.576 .31114 Mdot
.576 .31114 Mdot
.576 .31116 Mdot
.576 .31117 Mdot
.576 .31117 Mdot
.576 .31119 Mdot
.576 .31119 Mdot
.576 .31121 Mdot
.576 .31121 Mdot
.576 .31121 Mdot
.576 .31122 Mdot
.576 .31123 Mdot
.576 .31123 Mdot
.576 .31128 Mdot
.576 .31129 Mdot
.576 .31131 Mdot
.576 .31132 Mdot
.576 .31133 Mdot
.576 .31135 Mdot
.576 .31136 Mdot
.576 .31137 Mdot
.576 .31138 Mdot
.576 .31139 Mdot
.576 .3114 Mdot
.576 .31141 Mdot
.576 .31144 Mdot
.576 .31144 Mdot
.576 .31144 Mdot
.576 .31148 Mdot
.576 .31148 Mdot
.576 .3115 Mdot
.576 .3115 Mdot
.576 .31151 Mdot
.576 .31152 Mdot
.576 .31153 Mdot
.576 .31153 Mdot
.576 .31154 Mdot
.576 .31154 Mdot
.576 .31155 Mdot
.576 .31155 Mdot
.576 .31155 Mdot
.576 .31155 Mdot
.576 .31157 Mdot
.576 .3116 Mdot
.576 .31164 Mdot
.576 .31168 Mdot
.576 .31171 Mdot
.576 .31175 Mdot
.576 .31176 Mdot
.576 .31178 Mdot
.576 .31181 Mdot
.576 .31182 Mdot
.576 .31183 Mdot
.576 .31184 Mdot
.576 .31185 Mdot
.576 .31186 Mdot
.576 .31188 Mdot
.576 .31188 Mdot
.576 .31191 Mdot
.576 .31191 Mdot
.576 .34669 Mdot
.576 .3467 Mdot
.576 .34672 Mdot
.576 .34673 Mdot
.576 .34674 Mdot
.576 .34674 Mdot
.576 .34676 Mdot
.576 .34677 Mdot
.576 .34677 Mdot
.576 .34678 Mdot
.576 .34681 Mdot
.576 .34682 Mdot
.576 .34684 Mdot
.576 .34687 Mdot
.576 .3469 Mdot
.576 .34693 Mdot
.576 .34697 Mdot
.576 .34699 Mdot
.576 .34701 Mdot
.576 .34701 Mdot
.576 .34701 Mdot
.576 .34701 Mdot
.576 .34702 Mdot
.576 .34702 Mdot
.576 .34702 Mdot
.576 .34703 Mdot
.576 .34704 Mdot
.576 .34704 Mdot
.576 .34705 Mdot
.576 .34706 Mdot
.576 .34707 Mdot
.576 .34707 Mdot
.576 .3471 Mdot
.576 .34711 Mdot
.576 .34711 Mdot
.576 .34713 Mdot
.576 .34714 Mdot
.576 .34715 Mdot
.576 .34716 Mdot
.576 .34717 Mdot
.576 .34717 Mdot
.576 .34718 Mdot
.576 .3472 Mdot
.576 .34721 Mdot
.576 .34721 Mdot
.576 .34724 Mdot
.576 .34724 Mdot
.576 .34728 Mdot
.576 .34729 Mdot
.576 .34729 Mdot
.576 .3473 Mdot
.576 .34731 Mdot
.576 .34731 Mdot
.576 .34732 Mdot
.576 .34732 Mdot
.576 .34734 Mdot
.576 .34734 Mdot
.576 .34735 Mdot
.576 .34736 Mdot
.576 .34736 Mdot
.576 .34737 Mdot
.576 .34738 Mdot
.576 .34738 Mdot
.576 .34738 Mdot
.576 .3474 Mdot
.576 .3474 Mdot
.576 .34741 Mdot
.576 .34741 Mdot
.576 .34742 Mdot
.576 .34744 Mdot
.576 .34746 Mdot
.576 .34747 Mdot
.576 .3475 Mdot
.576 .34751 Mdot
.576 .34751 Mdot
.576 .34752 Mdot
.576 .34754 Mdot
.576 .34755 Mdot
.576 .34755 Mdot
.576 .34755 Mdot
.576 .34756 Mdot
.576 .34761 Mdot
.576 .34762 Mdot
.576 .34763 Mdot
.576 .34763 Mdot
.576 .34763 Mdot
.576 .34763 Mdot
.576 .34764 Mdot
.576 .34764 Mdot
.576 .34766 Mdot
.576 .34767 Mdot
.576 .34768 Mdot
.576 .34769 Mdot
.576 .34772 Mdot
.576 .34772 Mdot
.576 .34775 Mdot
.576 .34776 Mdot
.576 .34777 Mdot
.576 .34778 Mdot
.576 .3478 Mdot
.576 .34782 Mdot
.576 .34782 Mdot
.576 .34783 Mdot
.576 .34784 Mdot
.576 .34784 Mdot
.576 .34785 Mdot
.576 .34789 Mdot
.576 .34796 Mdot
.576 .34796 Mdot
.576 .34796 Mdot
.576 .34797 Mdot
.576 .34803 Mdot
.576 .34805 Mdot
.576 .34805 Mdot
.576 .34806 Mdot
.576 .34808 Mdot
.576 .34808 Mdot
.576 .34808 Mdot
.576 .34808 Mdot
.576 .34812 Mdot
.576 .34813 Mdot
.576 .34813 Mdot
.576 .34815 Mdot
.576 .34815 Mdot
.576 .34817 Mdot
.576 .34818 Mdot
.576 .3482 Mdot
.576 .3482 Mdot
.576 .34821 Mdot
.576 .34822 Mdot
.576 .34823 Mdot
.576 .34823 Mdot
.576 .34825 Mdot
.576 .34826 Mdot
.576 .34826 Mdot
.576 .34826 Mdot
.576 .34826 Mdot
.576 .34827 Mdot
.576 .34832 Mdot
.576 .34832 Mdot
.576 .34833 Mdot
.576 .34835 Mdot
.576 .34836 Mdot
.576 .3484 Mdot
.576 .34841 Mdot
.576 .34841 Mdot
.576 .34842 Mdot
.576 .34842 Mdot
.576 .34843 Mdot
.576 .34843 Mdot
.576 .34843 Mdot
.576 .34846 Mdot
.576 .3485 Mdot
.576 .34854 Mdot
.576 .34856 Mdot
.576 .34857 Mdot
.576 .34857 Mdot
.576 .34858 Mdot
.576 .34858 Mdot
.576 .34861 Mdot
.576 .34862 Mdot
.576 .34864 Mdot
.576 .34864 Mdot
.576 .34865 Mdot
.576 .3487 Mdot
.576 .3487 Mdot
.576 .34872 Mdot
.576 .34876 Mdot
.576 .34879 Mdot
.576 .3488 Mdot
.576 .3488 Mdot
.576 .34881 Mdot
.576 .34882 Mdot
.576 .34883 Mdot
.576 .34884 Mdot
.576 .34886 Mdot
.576 .34886 Mdot
.576 .34886 Mdot
.576 .34888 Mdot
.576 .34888 Mdot
.576 .34889 Mdot
.576 .3489 Mdot
.576 .34892 Mdot
.576 .34893 Mdot
.576 .34893 Mdot
.576 .34896 Mdot
.576 .34896 Mdot
.576 .34897 Mdot
.576 .34899 Mdot
.576 .34899 Mdot
.576 .349 Mdot
.576 .349 Mdot
.576 .34901 Mdot
.576 .34901 Mdot
.576 .34902 Mdot
.576 .34903 Mdot
.576 .34905 Mdot
.576 .34908 Mdot
.576 .34909 Mdot
.576 .34911 Mdot
.576 .34911 Mdot
.576 .34914 Mdot
.576 .34915 Mdot
.576 .34916 Mdot
.576 .34916 Mdot
.576 .34918 Mdot
.576 .34921 Mdot
.576 .34923 Mdot
.576 .34923 Mdot
.576 .34924 Mdot
.576 .34924 Mdot
.576 .34925 Mdot
.576 .34927 Mdot
.576 .34928 Mdot
.576 .3493 Mdot
.576 .34934 Mdot
.576 .34934 Mdot
.576 .34935 Mdot
.576 .34941 Mdot
.576 .34941 Mdot
.576 .34943 Mdot
.576 .34944 Mdot
.576 .34945 Mdot
.576 .34947 Mdot
.576 .34948 Mdot
.576 .34949 Mdot
.576 .3495 Mdot
.576 .3495 Mdot
.576 .34951 Mdot
.576 .34951 Mdot
.576 .34951 Mdot
.576 .34952 Mdot
.576 .34955 Mdot
.576 .34959 Mdot
.576 .34965 Mdot
.576 .34971 Mdot
.576 .34976 Mdot
.576 .34982 Mdot
.576 .34984 Mdot
.576 .34986 Mdot
.576 .34991 Mdot
.576 .34993 Mdot
.576 .34994 Mdot
.576 .34996 Mdot
.576 .34998 Mdot
.576 .34998 Mdot
.576 .35002 Mdot
.576 .35002 Mdot
.576 .35006 Mdot
.576 .35007 Mdot
.576 .35198 Mdot
.576 .35199 Mdot
.576 .35202 Mdot
.576 .35202 Mdot
.576 .35205 Mdot
.576 .35205 Mdot
.576 .35206 Mdot
.576 .35208 Mdot
.576 .35209 Mdot
.576 .3521 Mdot
.576 .35214 Mdot
.576 .35215 Mdot
.576 .35217 Mdot
.576 .35221 Mdot
.576 .35225 Mdot
.576 .3523 Mdot
.576 .35234 Mdot
.576 .35237 Mdot
.576 .3524 Mdot
.576 .3524 Mdot
.576 .3524 Mdot
.576 .3524 Mdot
.576 .35241 Mdot
.576 .35241 Mdot
.576 .35242 Mdot
.576 .35242 Mdot
.576 .35244 Mdot
.576 .35245 Mdot
.576 .35246 Mdot
.576 .35246 Mdot
.576 .35248 Mdot
.576 .35248 Mdot
.576 .35252 Mdot
.576 .35253 Mdot
.576 .35253 Mdot
.576 .35256 Mdot
.576 .35257 Mdot
.576 .35259 Mdot
.576 .3526 Mdot
.576 .3526 Mdot
.576 .35261 Mdot
.576 .35262 Mdot
.576 .35262 Mdot
.576 .35263 Mdot
.576 .35265 Mdot
.576 .35267 Mdot
.576 .35267 Mdot
.576 .35267 Mdot
.576 .35268 Mdot
.576 .3527 Mdot
.576 .35271 Mdot
.576 .35272 Mdot
.576 .35272 Mdot
.576 .35275 Mdot
.576 .35276 Mdot
.576 .35277 Mdot
.576 .35278 Mdot
.576 .35278 Mdot
.576 .35279 Mdot
.576 .35279 Mdot
.576 .35279 Mdot
.576 .35279 Mdot
.576 .35281 Mdot
.576 .35282 Mdot
.576 .35282 Mdot
.576 .35284 Mdot
.576 .35284 Mdot
.576 .35285 Mdot
.576 .35287 Mdot
.576 .35287 Mdot
.576 .35288 Mdot
.576 .35288 Mdot
.576 .35289 Mdot
.576 .35289 Mdot
.576 .3529 Mdot
.576 .35291 Mdot
.576 .35292 Mdot
.576 .35292 Mdot
.576 .35293 Mdot
.576 .35293 Mdot
.576 .35294 Mdot
.576 .35294 Mdot
.576 .35297 Mdot
.576 .353 Mdot
.576 .35301 Mdot
.576 .35301 Mdot
.576 .35305 Mdot
.576 .35306 Mdot
.576 .35306 Mdot
.576 .35307 Mdot
.576 .35308 Mdot
.576 .3531 Mdot
.576 .35311 Mdot
.576 .35311 Mdot
.576 .35311 Mdot
.576 .35312 Mdot
.576 .35313 Mdot
.576 .35317 Mdot
.576 .3532 Mdot
.576 .35322 Mdot
.576 .35322 Mdot
.576 .35322 Mdot
.576 .35322 Mdot
.576 .35322 Mdot
.576 .35323 Mdot
.576 .35323 Mdot
.576 .35324 Mdot
.576 .35327 Mdot
.576 .35328 Mdot
.576 .35329 Mdot
.576 .3533 Mdot
.576 .3533 Mdot
.576 .35334 Mdot
.576 .35334 Mdot
.576 .35334 Mdot
.576 .35334 Mdot
.576 .35335 Mdot
.576 .35335 Mdot
.576 .35337 Mdot
.576 .35337 Mdot
.576 .35338 Mdot
.576 .35338 Mdot
.576 .35339 Mdot
.576 .35339 Mdot
.576 .35341 Mdot
.576 .35341 Mdot
.576 .35342 Mdot
.576 .35343 Mdot
.576 .35344 Mdot
.576 .35344 Mdot
.576 .35345 Mdot
.576 .35348 Mdot
.576 .35348 Mdot
.576 .35348 Mdot
.576 .35348 Mdot
.576 .35349 Mdot
.576 .3535 Mdot
.576 .35351 Mdot
.576 .35352 Mdot
.576 .35356 Mdot
.576 .35357 Mdot
.576 .35357 Mdot
.576 .35357 Mdot
.576 .35362 Mdot
.576 .35365 Mdot
.576 .35366 Mdot
.576 .35366 Mdot
.576 .35367 Mdot
.576 .35367 Mdot
.576 .35367 Mdot
.576 .35369 Mdot
.576 .3537 Mdot
.576 .35371 Mdot
.576 .35372 Mdot
.576 .35373 Mdot
.576 .35375 Mdot
.576 .35375 Mdot
.576 .35377 Mdot
.576 .35378 Mdot
.576 .35379 Mdot
.576 .35379 Mdot
.576 .35381 Mdot
.576 .35382 Mdot
.576 .35382 Mdot
.576 .35382 Mdot
.576 .35382 Mdot
.576 .35382 Mdot
.576 .35382 Mdot
.576 .35383 Mdot
.576 .35387 Mdot
.576 .35388 Mdot
.576 .35388 Mdot
.576 .35388 Mdot
.576 .35389 Mdot
.576 .35391 Mdot
.576 .35391 Mdot
.576 .35391 Mdot
.576 .35392 Mdot
.576 .35394 Mdot
.576 .35395 Mdot
.576 .35396 Mdot
.576 .35398 Mdot
.576 .35398 Mdot
.576 .35399 Mdot
.576 .35399 Mdot
.576 .35399 Mdot
.576 .35401 Mdot
.576 .35401 Mdot
.576 .35401 Mdot
.576 .35402 Mdot
.576 .35402 Mdot
.576 .35402 Mdot
.576 .35403 Mdot
.576 .35404 Mdot
.576 .35404 Mdot
.576 .35405 Mdot
.576 .35405 Mdot
.576 .35406 Mdot
.576 .35406 Mdot
.576 .35406 Mdot
.576 .35407 Mdot
.576 .35407 Mdot
.576 .35408 Mdot
.576 .35408 Mdot
.576 .35411 Mdot
.576 .35411 Mdot
.576 .35413 Mdot
.576 .35414 Mdot
.576 .35414 Mdot
.576 .35416 Mdot
.576 .35416 Mdot
.576 .35417 Mdot
.576 .35417 Mdot
.576 .35418 Mdot
.576 .35419 Mdot
.576 .3542 Mdot
.576 .35421 Mdot
.576 .35421 Mdot
.576 .35422 Mdot
.576 .35424 Mdot
.576 .35424 Mdot
.576 .35425 Mdot
.576 .35425 Mdot
.576 .35426 Mdot
.576 .35427 Mdot
.576 .35427 Mdot
.576 .35428 Mdot
.576 .35428 Mdot
.576 .35428 Mdot
.576 .35429 Mdot
.576 .35429 Mdot
.576 .35429 Mdot
.576 .35429 Mdot
.576 .3543 Mdot
.576 .35432 Mdot
.576 .35434 Mdot
.576 .35437 Mdot
.576 .35439 Mdot
.576 .35442 Mdot
.576 .35443 Mdot
.576 .35444 Mdot
.576 .35446 Mdot
.576 .35447 Mdot
.576 .35447 Mdot
.576 .35448 Mdot
.576 .35449 Mdot
.576 .35449 Mdot
.576 .3545 Mdot
.576 .3545 Mdot
.576 .35452 Mdot
.576 .35453 Mdot
.578 .30252 Mdot
.578 .30255 Mdot
.578 .30256 Mdot
.578 .30257 Mdot
.578 .3026 Mdot
.578 .3026 Mdot
.578 .30261 Mdot
.578 .30261 Mdot
.578 .30263 Mdot
.578 .30263 Mdot
.578 .30264 Mdot
.578 .30266 Mdot
.578 .30266 Mdot
.578 .30267 Mdot
.578 .30267 Mdot
.578 .30269 Mdot
.578 .30269 Mdot
.578 .30269 Mdot
.578 .3027 Mdot
.578 .3027 Mdot
.578 .30272 Mdot
.578 .30273 Mdot
.578 .30274 Mdot
.578 .30275 Mdot
.578 .30276 Mdot
.578 .30277 Mdot
.578 .30278 Mdot
.578 .30278 Mdot
.578 .30279 Mdot
.578 .30279 Mdot
.578 .30279 Mdot
.578 .30281 Mdot
.578 .30282 Mdot
.578 .30283 Mdot
.578 .30285 Mdot
.578 .30285 Mdot
.578 .30286 Mdot
.578 .30286 Mdot
.578 .3029 Mdot
.578 .30291 Mdot
.578 .30293 Mdot
.578 .30293 Mdot
.578 .30293 Mdot
.578 .30295 Mdot
.578 .30296 Mdot
.578 .30297 Mdot
.578 .303 Mdot
.578 .30301 Mdot
.578 .30301 Mdot
.578 .30304 Mdot
.578 .30304 Mdot
.578 .30306 Mdot
.578 .30306 Mdot
.578 .30308 Mdot
.578 .30308 Mdot
.578 .30309 Mdot
.578 .30311 Mdot
.578 .30312 Mdot
.578 .30313 Mdot
.578 .30314 Mdot
.578 .30315 Mdot
.578 .30316 Mdot
.578 .30317 Mdot
.578 .30318 Mdot
.578 .30319 Mdot
.578 .30321 Mdot
.578 .30322 Mdot
.578 .30325 Mdot
.578 .30325 Mdot
.578 .30326 Mdot
.578 .30326 Mdot
.578 .30326 Mdot
.578 .30327 Mdot
.578 .30328 Mdot
.578 .30328 Mdot
.578 .30331 Mdot
.578 .30332 Mdot
.578 .30334 Mdot
.578 .30334 Mdot
.578 .30334 Mdot
.578 .30337 Mdot
.578 .30338 Mdot
.578 .30339 Mdot
.578 .3034 Mdot
.578 .3034 Mdot
.578 .30343 Mdot
.578 .30348 Mdot
.578 .30348 Mdot
.578 .30349 Mdot
.578 .30349 Mdot
.578 .30351 Mdot
.578 .30354 Mdot
.578 .30354 Mdot
.578 .30354 Mdot
.578 .30355 Mdot
.578 .30357 Mdot
.578 .30357 Mdot
.578 .30359 Mdot
.578 .30362 Mdot
.578 .30363 Mdot
.578 .30363 Mdot
.578 .30364 Mdot
.578 .30366 Mdot
.578 .3037 Mdot
.578 .30372 Mdot
.578 .30374 Mdot
.578 .30375 Mdot
.578 .30375 Mdot
.578 .30375 Mdot
.578 .30375 Mdot
.578 .30378 Mdot
.578 .30379 Mdot
.578 .30381 Mdot
.578 .30383 Mdot
.578 .30384 Mdot
.578 .30386 Mdot
.578 .30387 Mdot
.578 .30391 Mdot
.578 .30391 Mdot
.578 .30391 Mdot
.578 .30391 Mdot
.578 .30396 Mdot
.578 .30397 Mdot
.578 .30397 Mdot
.578 .30399 Mdot
.578 .304 Mdot
.578 .30401 Mdot
.578 .30401 Mdot
.578 .30402 Mdot
.578 .30403 Mdot
.578 .30407 Mdot
.578 .3041 Mdot
.578 .30411 Mdot
.578 .30413 Mdot
.578 .30417 Mdot
.578 .30417 Mdot
.578 .30417 Mdot
.578 .30418 Mdot
.578 .30419 Mdot
.578 .30419 Mdot
.578 .3042 Mdot
.578 .30423 Mdot
.578 .30423 Mdot
.578 .30423 Mdot
.578 .30424 Mdot
.578 .30427 Mdot
.578 .30427 Mdot
.578 .30428 Mdot
.578 .30428 Mdot
.578 .3043 Mdot
.578 .30431 Mdot
.578 .30433 Mdot
.578 .30435 Mdot
.578 .30438 Mdot
.578 .30439 Mdot
.578 .30439 Mdot
.578 .30441 Mdot
.578 .30441 Mdot
.578 .30441 Mdot
.578 .30443 Mdot
.578 .30443 Mdot
.578 .30444 Mdot
.578 .30444 Mdot
.578 .30447 Mdot
.578 .30447 Mdot
.578 .30449 Mdot
.578 .30449 Mdot
.578 .30451 Mdot
.578 .30451 Mdot
.578 .30451 Mdot
.578 .30455 Mdot
.578 .30456 Mdot
.578 .30456 Mdot
.578 .30457 Mdot
.578 .30457 Mdot
.578 .30459 Mdot
.578 .3046 Mdot
.578 .3046 Mdot
.578 .30462 Mdot
.578 .30463 Mdot
.578 .30465 Mdot
.578 .30467 Mdot
.578 .30467 Mdot
.578 .30469 Mdot
.578 .3047 Mdot
.578 .30471 Mdot
.578 .30472 Mdot
.578 .30473 Mdot
.578 .30474 Mdot
.578 .30475 Mdot
.578 .30475 Mdot
.578 .30477 Mdot
.578 .30478 Mdot
.578 .30479 Mdot
.578 .3048 Mdot
.578 .30481 Mdot
.578 .30482 Mdot
.578 .30487 Mdot
.578 .30487 Mdot
.578 .30488 Mdot
.578 .3049 Mdot
.578 .30491 Mdot
.578 .30494 Mdot
.578 .30495 Mdot
.578 .30495 Mdot
.578 .30497 Mdot
.578 .305 Mdot
.578 .30501 Mdot
.578 .30501 Mdot
.578 .30504 Mdot
.578 .30505 Mdot
.578 .30507 Mdot
.578 .30513 Mdot
.578 .30514 Mdot
.578 .30515 Mdot
.578 .30516 Mdot
.578 .3052 Mdot
.578 .30521 Mdot
.578 .30523 Mdot
.578 .30525 Mdot
.578 .30526 Mdot
.578 .30526 Mdot
.578 .30528 Mdot
.578 .30528 Mdot
.578 .30529 Mdot
.578 .30531 Mdot
.578 .30532 Mdot
.578 .30535 Mdot
.578 .30537 Mdot
.578 .30538 Mdot
.578 .30542 Mdot
.578 .30542 Mdot
.578 .30543 Mdot
.578 .30544 Mdot
.578 .30544 Mdot
.578 .30547 Mdot
.578 .30547 Mdot
.578 .30549 Mdot
.578 .30549 Mdot
.578 .30553 Mdot
.578 .30555 Mdot
.578 .30555 Mdot
.578 .30557 Mdot
.578 .30557 Mdot
.578 .30559 Mdot
.578 .3056 Mdot
.578 .30566 Mdot
.578 .30567 Mdot
.578 .30569 Mdot
.578 .30574 Mdot
.578 .3078 Mdot
.578 .30788 Mdot
.578 .3079 Mdot
.578 .30791 Mdot
.578 .30799 Mdot
.578 .308 Mdot
.578 .30803 Mdot
.578 .30803 Mdot
.578 .30806 Mdot
.578 .30806 Mdot
.578 .30808 Mdot
.578 .30814 Mdot
.578 .30814 Mdot
.578 .30817 Mdot
.578 .30817 Mdot
.578 .3082 Mdot
.578 .30821 Mdot
.578 .30822 Mdot
.578 .30824 Mdot
.578 .30824 Mdot
.578 .30828 Mdot
.578 .3083 Mdot
.578 .30832 Mdot
.578 .30836 Mdot
.578 .30838 Mdot
.578 .3084 Mdot
.578 .30842 Mdot
.578 .30842 Mdot
.578 .30845 Mdot
.578 .30845 Mdot
.578 .30846 Mdot
.578 .30849 Mdot
.578 .30852 Mdot
.578 .30853 Mdot
.578 .30858 Mdot
.578 .3086 Mdot
.578 .30861 Mdot
.578 .30862 Mdot
.578 .30871 Mdot
.578 .30873 Mdot
.578 .30875 Mdot
.578 .30877 Mdot
.578 .30879 Mdot
.578 .30879 Mdot
.578 .30884 Mdot
.578 .30886 Mdot
.578 .30886 Mdot
.578 .30887 Mdot
.578 .30891 Mdot
.578 .30893 Mdot
.578 .30895 Mdot
.578 .30897 Mdot
.578 .30897 Mdot
.578 .30904 Mdot
.578 .30905 Mdot
.578 .30906 Mdot
.578 .30908 Mdot
.578 .30909 Mdot
.578 .3091 Mdot
.578 .30913 Mdot
.578 .30913 Mdot
.578 .30914 Mdot
.578 .30915 Mdot
.578 .30917 Mdot
.578 .30918 Mdot
.578 .30919 Mdot
.578 .30921 Mdot
.578 .30923 Mdot
.578 .30924 Mdot
.578 .30926 Mdot
.578 .30929 Mdot
.578 .30931 Mdot
.578 .30933 Mdot
.578 .30933 Mdot
.578 .30934 Mdot
.578 .30936 Mdot
.578 .30937 Mdot
.578 .30938 Mdot
.578 .30939 Mdot
.578 .3094 Mdot
.578 .30944 Mdot
.578 .30945 Mdot
.578 .30945 Mdot
.578 .30947 Mdot
.578 .30947 Mdot
.578 .30948 Mdot
.578 .3095 Mdot
.578 .30951 Mdot
.578 .30954 Mdot
.578 .30955 Mdot
.578 .30956 Mdot
.578 .30956 Mdot
.578 .30958 Mdot
.578 .30958 Mdot
.578 .30959 Mdot
.578 .30961 Mdot
.578 .30961 Mdot
.578 .30962 Mdot
.578 .30966 Mdot
.578 .3097 Mdot
.578 .30972 Mdot
.578 .30973 Mdot
.578 .30976 Mdot
.578 .30976 Mdot
.578 .30977 Mdot
.578 .30977 Mdot
.578 .3098 Mdot
.578 .30982 Mdot
.578 .30982 Mdot
.578 .30983 Mdot
.578 .30986 Mdot
.578 .30987 Mdot
.578 .30988 Mdot
.578 .30989 Mdot
.578 .3099 Mdot
.578 .3099 Mdot
.578 .3099 Mdot
.578 .30995 Mdot
.578 .30998 Mdot
.578 .31 Mdot
.578 .31003 Mdot
.578 .31009 Mdot
.578 .3101 Mdot
.578 .31011 Mdot
.578 .31012 Mdot
.578 .31013 Mdot
.578 .31015 Mdot
.578 .31017 Mdot
.578 .31018 Mdot
.578 .31019 Mdot
.578 .31024 Mdot
.578 .31025 Mdot
.578 .31025 Mdot
.578 .31025 Mdot
.578 .31031 Mdot
.578 .31031 Mdot
.578 .31034 Mdot
.578 .31036 Mdot
.578 .31038 Mdot
.578 .31041 Mdot
.578 .31042 Mdot
.578 .31046 Mdot
.578 .31046 Mdot
.578 .31046 Mdot
.578 .31048 Mdot
.578 .3105 Mdot
.578 .31053 Mdot
.578 .31058 Mdot
.578 .31062 Mdot
.578 .31062 Mdot
.578 .31062 Mdot
.578 .31064 Mdot
.578 .31068 Mdot
.578 .3107 Mdot
.578 .3107 Mdot
.578 .31074 Mdot
.578 .31074 Mdot
.578 .31074 Mdot
.578 .31074 Mdot
.578 .31078 Mdot
.578 .31081 Mdot
.578 .31081 Mdot
.578 .31082 Mdot
.578 .31083 Mdot
.578 .31089 Mdot
.578 .31093 Mdot
.578 .31093 Mdot
.578 .31095 Mdot
.578 .31096 Mdot
.578 .31097 Mdot
.578 .31101 Mdot
.578 .31101 Mdot
.578 .31102 Mdot
.578 .31103 Mdot
.578 .31105 Mdot
.578 .31109 Mdot
.578 .3111 Mdot
.578 .31111 Mdot
.578 .31111 Mdot
.578 .31113 Mdot
.578 .31113 Mdot
.578 .31113 Mdot
.578 .31114 Mdot
.578 .31117 Mdot
.578 .31119 Mdot
.578 .31121 Mdot
.578 .31123 Mdot
.578 .31123 Mdot
.578 .31125 Mdot
.578 .31127 Mdot
.578 .31128 Mdot
.578 .3113 Mdot
.578 .3113 Mdot
.578 .31132 Mdot
.578 .31134 Mdot
.578 .31135 Mdot
.578 .31137 Mdot
.578 .31138 Mdot
.578 .31139 Mdot
.578 .31141 Mdot
.578 .31142 Mdot
.578 .31145 Mdot
.578 .31146 Mdot
.578 .31147 Mdot
.578 .31151 Mdot
.578 .31152 Mdot
.578 .31153 Mdot
.578 .31155 Mdot
.578 .31156 Mdot
.578 .31156 Mdot
.578 .31158 Mdot
.578 .3116 Mdot
.578 .31165 Mdot
.578 .31166 Mdot
.578 .31166 Mdot
.578 .31167 Mdot
.578 .3117 Mdot
.578 .31171 Mdot
.578 .31172 Mdot
.578 .31174 Mdot
.578 .31174 Mdot
.578 .31175 Mdot
.578 .31177 Mdot
.578 .31177 Mdot
.578 .31177 Mdot
.578 .31178 Mdot
.578 .3118 Mdot
.578 .31182 Mdot
.578 .31183 Mdot
.578 .31184 Mdot
.578 .31187 Mdot
.578 .31187 Mdot
.578 .31188 Mdot
.578 .31188 Mdot
.578 .31189 Mdot
.578 .3119 Mdot
.578 .3119 Mdot
.578 .31192 Mdot
.578 .31192 Mdot
.578 .31195 Mdot
.578 .31196 Mdot
.578 .31197 Mdot
.578 .31198 Mdot
.578 .31198 Mdot
.578 .312 Mdot
.578 .31201 Mdot
.578 .31205 Mdot
.578 .31205 Mdot
.578 .31207 Mdot
.578 .31211 Mdot
.578 .34742 Mdot
.578 .34745 Mdot
.578 .34747 Mdot
.578 .34747 Mdot
.578 .34751 Mdot
.578 .34751 Mdot
.578 .34752 Mdot
.578 .34753 Mdot
.578 .34754 Mdot
.578 .34754 Mdot
.578 .34755 Mdot
.578 .34758 Mdot
.578 .34758 Mdot
.578 .34759 Mdot
.578 .3476 Mdot
.578 .34761 Mdot
.578 .34761 Mdot
.578 .34762 Mdot
.578 .34763 Mdot
.578 .34763 Mdot
.578 .34765 Mdot
.578 .34766 Mdot
.578 .34767 Mdot
.578 .34769 Mdot
.578 .3477 Mdot
.578 .34771 Mdot
.578 .34771 Mdot
.578 .34771 Mdot
.578 .34773 Mdot
.578 .34773 Mdot
.578 .34773 Mdot
.578 .34775 Mdot
.578 .34776 Mdot
.578 .34777 Mdot
.578 .34779 Mdot
.578 .3478 Mdot
.578 .34781 Mdot
.578 .34781 Mdot
.578 .34785 Mdot
.578 .34787 Mdot
.578 .34789 Mdot
.578 .34789 Mdot
.578 .3479 Mdot
.578 .34792 Mdot
.578 .34793 Mdot
.578 .34794 Mdot
.578 .34797 Mdot
.578 .34798 Mdot
.578 .34798 Mdot
.578 .34801 Mdot
.578 .34802 Mdot
.578 .34804 Mdot
.578 .34805 Mdot
.578 .34806 Mdot
.578 .34807 Mdot
.578 .34808 Mdot
.578 .3481 Mdot
.578 .34811 Mdot
.578 .34812 Mdot
.578 .34814 Mdot
.578 .34815 Mdot
.578 .34816 Mdot
.578 .34817 Mdot
.578 .34818 Mdot
.578 .34819 Mdot
.578 .34821 Mdot
.578 .34823 Mdot
.578 .34826 Mdot
.578 .34826 Mdot
.578 .34827 Mdot
.578 .34827 Mdot
.578 .34828 Mdot
.578 .34828 Mdot
.578 .34829 Mdot
.578 .34829 Mdot
.578 .34833 Mdot
.578 .34835 Mdot
.578 .34836 Mdot
.578 .34836 Mdot
.578 .34837 Mdot
.578 .3484 Mdot
.578 .34841 Mdot
.578 .34842 Mdot
.578 .34843 Mdot
.578 .34843 Mdot
.578 .34847 Mdot
.578 .34852 Mdot
.578 .34853 Mdot
.578 .34854 Mdot
.578 .34854 Mdot
.578 .34857 Mdot
.578 .3486 Mdot
.578 .3486 Mdot
.578 .3486 Mdot
.578 .3486 Mdot
.578 .34863 Mdot
.578 .34863 Mdot
.578 .34865 Mdot
.578 .34869 Mdot
.578 .34871 Mdot
.578 .34871 Mdot
.578 .34871 Mdot
.578 .34874 Mdot
.578 .34878 Mdot
.578 .34881 Mdot
.578 .34882 Mdot
.578 .34884 Mdot
.578 .34884 Mdot
.578 .34884 Mdot
.578 .34884 Mdot
.578 .34888 Mdot
.578 .34888 Mdot
.578 .34891 Mdot
.578 .34893 Mdot
.578 .34894 Mdot
.578 .34897 Mdot
.578 .34897 Mdot
.578 .34902 Mdot
.578 .34903 Mdot
.578 .34903 Mdot
.578 .34903 Mdot
.578 .34908 Mdot
.578 .34909 Mdot
.578 .34909 Mdot
.578 .34911 Mdot
.578 .34913 Mdot
.578 .34914 Mdot
.578 .34914 Mdot
.578 .34915 Mdot
.578 .34917 Mdot
.578 .34921 Mdot
.578 .34924 Mdot
.578 .34926 Mdot
.578 .34928 Mdot
.578 .34932 Mdot
.578 .34933 Mdot
.578 .34933 Mdot
.578 .34934 Mdot
.578 .34934 Mdot
.578 .34935 Mdot
.578 .34936 Mdot
.578 .34939 Mdot
.578 .34939 Mdot
.578 .34939 Mdot
.578 .34941 Mdot
.578 .34944 Mdot
.578 .34944 Mdot
.578 .34945 Mdot
.578 .34945 Mdot
.578 .34948 Mdot
.578 .34948 Mdot
.578 .3495 Mdot
.578 .34953 Mdot
.578 .34957 Mdot
.578 .34958 Mdot
.578 .34958 Mdot
.578 .3496 Mdot
.578 .3496 Mdot
.578 .3496 Mdot
.578 .34962 Mdot
.578 .34962 Mdot
.578 .34963 Mdot
.578 .34964 Mdot
.578 .34967 Mdot
.578 .34967 Mdot
.578 .34969 Mdot
.578 .3497 Mdot
.578 .3497 Mdot
.578 .34972 Mdot
.578 .34972 Mdot
.578 .34972 Mdot
.578 .34976 Mdot
.578 .34977 Mdot
.578 .34977 Mdot
.578 .34979 Mdot
.578 .34979 Mdot
.578 .34982 Mdot
.578 .34982 Mdot
.578 .34982 Mdot
.578 .34984 Mdot
.578 .34985 Mdot
.578 .34989 Mdot
.578 .3499 Mdot
.578 .34991 Mdot
.578 .34993 Mdot
.578 .34994 Mdot
.578 .34995 Mdot
.578 .34996 Mdot
.578 .34998 Mdot
.578 .34999 Mdot
.578 .34999 Mdot
.578 .35 Mdot
.578 .35002 Mdot
.578 .35002 Mdot
.578 .35004 Mdot
.578 .35005 Mdot
.578 .35007 Mdot
.578 .35007 Mdot
.578 .35013 Mdot
.578 .35013 Mdot
.578 .35015 Mdot
.578 .35017 Mdot
.578 .35018 Mdot
.578 .35022 Mdot
.578 .35023 Mdot
.578 .35023 Mdot
.578 .35024 Mdot
.578 .35028 Mdot
.578 .35029 Mdot
.578 .3503 Mdot
.578 .35033 Mdot
.578 .35034 Mdot
.578 .35036 Mdot
.578 .35043 Mdot
.578 .35044 Mdot
.578 .35045 Mdot
.578 .35047 Mdot
.578 .35051 Mdot
.578 .35053 Mdot
.578 .35055 Mdot
.578 .35057 Mdot
.578 .35058 Mdot
.578 .35058 Mdot
.578 .35061 Mdot
.578 .35061 Mdot
.578 .35062 Mdot
.578 .35064 Mdot
.578 .35066 Mdot
.578 .35069 Mdot
.578 .35071 Mdot
.578 .35073 Mdot
.578 .35077 Mdot
.578 .35077 Mdot
.578 .35078 Mdot
.578 .35079 Mdot
.578 .3508 Mdot
.578 .35082 Mdot
.578 .35082 Mdot
.578 .35085 Mdot
.578 .35085 Mdot
.578 .3509 Mdot
.578 .35092 Mdot
.578 .35092 Mdot
.578 .35095 Mdot
.578 .35095 Mdot
.578 .35097 Mdot
.578 .35098 Mdot
.578 .35105 Mdot
.578 .35105 Mdot
.578 .35108 Mdot
.578 .35114 Mdot
.578 .35292 Mdot
.578 .35297 Mdot
.578 .35299 Mdot
.578 .353 Mdot
.578 .35304 Mdot
.578 .35305 Mdot
.578 .35307 Mdot
.578 .35307 Mdot
.578 .35309 Mdot
.578 .35309 Mdot
.578 .35311 Mdot
.578 .35314 Mdot
.578 .35314 Mdot
.578 .35316 Mdot
.578 .35316 Mdot
.578 .35318 Mdot
.578 .35319 Mdot
.578 .35319 Mdot
.578 .35321 Mdot
.578 .35321 Mdot
.578 .35323 Mdot
.578 .35325 Mdot
.578 .35326 Mdot
.578 .35329 Mdot
.578 .3533 Mdot
.578 .35331 Mdot
.578 .35332 Mdot
.578 .35332 Mdot
.578 .35334 Mdot
.578 .35335 Mdot
.578 .35335 Mdot
.578 .35337 Mdot
.578 .35339 Mdot
.578 .3534 Mdot
.578 .35343 Mdot
.578 .35344 Mdot
.578 .35345 Mdot
.578 .35345 Mdot
.578 .35351 Mdot
.578 .35352 Mdot
.578 .35354 Mdot
.578 .35355 Mdot
.578 .35356 Mdot
.578 .35357 Mdot
.578 .3536 Mdot
.578 .35361 Mdot
.578 .35361 Mdot
.578 .35362 Mdot
.578 .35364 Mdot
.578 .35365 Mdot
.578 .35367 Mdot
.578 .35368 Mdot
.578 .35368 Mdot
.578 .35372 Mdot
.578 .35373 Mdot
.578 .35374 Mdot
.578 .35375 Mdot
.578 .35376 Mdot
.578 .35377 Mdot
.578 .35378 Mdot
.578 .35378 Mdot
.578 .35379 Mdot
.578 .3538 Mdot
.578 .35381 Mdot
.578 .35382 Mdot
.578 .35383 Mdot
.578 .35383 Mdot
.578 .35385 Mdot
.578 .35386 Mdot
.578 .35387 Mdot
.578 .35389 Mdot
.578 .3539 Mdot
.578 .35391 Mdot
.578 .35391 Mdot
.578 .35392 Mdot
.578 .35394 Mdot
.578 .35394 Mdot
.578 .35395 Mdot
.578 .35395 Mdot
.578 .35396 Mdot
.578 .35399 Mdot
.578 .35399 Mdot
.578 .35399 Mdot
.578 .35401 Mdot
.578 .35401 Mdot
.578 .35403 Mdot
.578 .35403 Mdot
.578 .35405 Mdot
.578 .35405 Mdot
.578 .35406 Mdot
.578 .35406 Mdot
.578 .35408 Mdot
.578 .35408 Mdot
.578 .35408 Mdot
.578 .35409 Mdot
.578 .3541 Mdot
.578 .3541 Mdot
.578 .35413 Mdot
.578 .35415 Mdot
.578 .35417 Mdot
.578 .35417 Mdot
.578 .35419 Mdot
.578 .35419 Mdot
.578 .3542 Mdot
.578 .3542 Mdot
.578 .35422 Mdot
.578 .35423 Mdot
.578 .35423 Mdot
.578 .35424 Mdot
.578 .35426 Mdot
.578 .35426 Mdot
.578 .35427 Mdot
.578 .35428 Mdot
.578 .35428 Mdot
.578 .35428 Mdot
.578 .35428 Mdot
.578 .35432 Mdot
.578 .35433 Mdot
.578 .35435 Mdot
.578 .35437 Mdot
.578 .3544 Mdot
.578 .35441 Mdot
.578 .35442 Mdot
.578 .35442 Mdot
.578 .35443 Mdot
.578 .35444 Mdot
.578 .35446 Mdot
.578 .35446 Mdot
.578 .35447 Mdot
.578 .35451 Mdot
.578 .35451 Mdot
.578 .35451 Mdot
.578 .35451 Mdot
.578 .35455 Mdot
.578 .35455 Mdot
.578 .35457 Mdot
.578 .35458 Mdot
.578 .35459 Mdot
.578 .35462 Mdot
.578 .35462 Mdot
.578 .35465 Mdot
.578 .35465 Mdot
.578 .35465 Mdot
.578 .35465 Mdot
.578 .35466 Mdot
.578 .35467 Mdot
.578 .35469 Mdot
.578 .35472 Mdot
.578 .35475 Mdot
.578 .35475 Mdot
.578 .35475 Mdot
.578 .35476 Mdot
.578 .35479 Mdot
.578 .3548 Mdot
.578 .3548 Mdot
.578 .35482 Mdot
.578 .35483 Mdot
.578 .35483 Mdot
.578 .35483 Mdot
.578 .35485 Mdot
.578 .35487 Mdot
.578 .35487 Mdot
.578 .35488 Mdot
.578 .35488 Mdot
.578 .35492 Mdot
.578 .35495 Mdot
.578 .35495 Mdot
.578 .35496 Mdot
.578 .35497 Mdot
.578 .35498 Mdot
.578 .355 Mdot
.578 .355 Mdot
.578 .355 Mdot
.578 .35502 Mdot
.578 .35503 Mdot
.578 .35506 Mdot
.578 .35506 Mdot
.578 .35506 Mdot
.578 .35507 Mdot
.578 .35508 Mdot
.578 .35508 Mdot
.578 .35508 Mdot
.578 .35508 Mdot
.578 .3551 Mdot
.578 .35512 Mdot
.578 .35513 Mdot
.578 .35514 Mdot
.578 .35515 Mdot
.578 .35516 Mdot
.578 .35517 Mdot
.578 .35517 Mdot
.578 .35519 Mdot
.578 .35519 Mdot
.578 .3552 Mdot
.578 .35522 Mdot
.578 .35522 Mdot
.578 .35523 Mdot
.578 .35524 Mdot
.578 .35524 Mdot
.578 .35526 Mdot
.578 .35526 Mdot
.578 .35529 Mdot
.578 .35529 Mdot
.578 .3553 Mdot
.578 .35532 Mdot
.578 .35533 Mdot
.578 .35534 Mdot
.578 .35535 Mdot
.578 .35536 Mdot
.578 .35536 Mdot
.578 .35537 Mdot
.578 .35538 Mdot
.578 .35542 Mdot
.578 .35542 Mdot
.578 .35542 Mdot
.578 .35543 Mdot
.578 .35545 Mdot
.578 .35545 Mdot
.578 .35546 Mdot
.578 .35547 Mdot
.578 .35548 Mdot
.578 .35548 Mdot
.578 .35549 Mdot
.578 .35549 Mdot
.578 .35549 Mdot
.578 .3555 Mdot
.578 .35551 Mdot
.578 .35552 Mdot
.578 .35553 Mdot
.578 .35554 Mdot
.578 .35555 Mdot
.578 .35556 Mdot
.578 .35556 Mdot
.578 .35557 Mdot
.578 .35557 Mdot
.578 .35558 Mdot
.578 .35558 Mdot
.578 .35559 Mdot
.578 .35559 Mdot
.578 .35561 Mdot
.578 .35562 Mdot
.578 .35562 Mdot
.578 .35563 Mdot
.578 .35563 Mdot
.578 .35564 Mdot
.578 .35565 Mdot
.578 .35567 Mdot
.578 .35568 Mdot
.578 .35569 Mdot
.578 .35571 Mdot
.58 .30218 Mdot
.58 .30219 Mdot
.58 .30221 Mdot
.58 .30221 Mdot
.58 .30222 Mdot
.58 .30223 Mdot
.58 .30224 Mdot
.58 .30228 Mdot
.58 .30229 Mdot
.58 .30229 Mdot
.58 .30231 Mdot
.58 .30231 Mdot
.58 .30233 Mdot
.58 .30233 Mdot
.58 .30235 Mdot
.58 .30236 Mdot
.58 .30237 Mdot
.58 .30238 Mdot
.58 .3024 Mdot
.58 .30241 Mdot
.58 .30244 Mdot
.58 .30245 Mdot
.58 .30245 Mdot
.58 .30246 Mdot
.58 .30246 Mdot
.58 .30249 Mdot
.58 .3025 Mdot
.58 .30252 Mdot
.58 .30253 Mdot
.58 .30254 Mdot
.58 .30254 Mdot
.58 .30256 Mdot
.58 .30258 Mdot
.58 .30259 Mdot
.58 .30259 Mdot
.58 .3026 Mdot
.58 .30261 Mdot
.58 .30264 Mdot
.58 .30266 Mdot
.58 .30266 Mdot
.58 .30266 Mdot
.58 .30269 Mdot
.58 .3027 Mdot
.58 .30271 Mdot
.58 .30273 Mdot
.58 .30273 Mdot
.58 .30274 Mdot
.58 .30275 Mdot
.58 .30278 Mdot
.58 .30278 Mdot
.58 .30278 Mdot
.58 .30279 Mdot
.58 .3028 Mdot
.58 .30281 Mdot
.58 .30282 Mdot
.58 .30282 Mdot
.58 .30282 Mdot
.58 .30283 Mdot
.58 .30283 Mdot
.58 .30287 Mdot
.58 .30288 Mdot
.58 .30288 Mdot
.58 .30289 Mdot
.58 .30291 Mdot
.58 .30291 Mdot
.58 .30292 Mdot
.58 .30294 Mdot
.58 .30295 Mdot
.58 .30298 Mdot
.58 .30299 Mdot
.58 .30299 Mdot
.58 .303 Mdot
.58 .30303 Mdot
.58 .30305 Mdot
.58 .30306 Mdot
.58 .30306 Mdot
.58 .30307 Mdot
.58 .30308 Mdot
.58 .3031 Mdot
.58 .30311 Mdot
.58 .30311 Mdot
.58 .30314 Mdot
.58 .30315 Mdot
.58 .30316 Mdot
.58 .30317 Mdot
.58 .30317 Mdot
.58 .30318 Mdot
.58 .30318 Mdot
.58 .30319 Mdot
.58 .30321 Mdot
.58 .30322 Mdot
.58 .30322 Mdot
.58 .30324 Mdot
.58 .30325 Mdot
.58 .30327 Mdot
.58 .30328 Mdot
.58 .30329 Mdot
.58 .30331 Mdot
.58 .30331 Mdot
.58 .30333 Mdot
.58 .30333 Mdot
.58 .30336 Mdot
.58 .30336 Mdot
.58 .30337 Mdot
.58 .30338 Mdot
.58 .30341 Mdot
.58 .30341 Mdot
.58 .30342 Mdot
.58 .30343 Mdot
.58 .30346 Mdot
.58 .30346 Mdot
.58 .30348 Mdot
.58 .30349 Mdot
.58 .30351 Mdot
.58 .30352 Mdot
.58 .30352 Mdot
.58 .30352 Mdot
.58 .30354 Mdot
.58 .30355 Mdot
.58 .30355 Mdot
.58 .30356 Mdot
.58 .30357 Mdot
.58 .30358 Mdot
.58 .30359 Mdot
.58 .30362 Mdot
.58 .30362 Mdot
.58 .30365 Mdot
.58 .30368 Mdot
.58 .30368 Mdot
.58 .3037 Mdot
.58 .30371 Mdot
.58 .30371 Mdot
.58 .30372 Mdot
.58 .30373 Mdot
.58 .30375 Mdot
.58 .30376 Mdot
.58 .30377 Mdot
.58 .30378 Mdot
.58 .3038 Mdot
.58 .3038 Mdot
.58 .30381 Mdot
.58 .30383 Mdot
.58 .30384 Mdot
.58 .30386 Mdot
.58 .30387 Mdot
.58 .30391 Mdot
.58 .30391 Mdot
.58 .30392 Mdot
.58 .30396 Mdot
.58 .30396 Mdot
.58 .30397 Mdot
.58 .30398 Mdot
.58 .30398 Mdot
.58 .30399 Mdot
.58 .30399 Mdot
.58 .30401 Mdot
.58 .30401 Mdot
.58 .30403 Mdot
.58 .30405 Mdot
.58 .30411 Mdot
.58 .30411 Mdot
.58 .30412 Mdot
.58 .30413 Mdot
.58 .30414 Mdot
.58 .30417 Mdot
.58 .3042 Mdot
.58 .30422 Mdot
.58 .30423 Mdot
.58 .30425 Mdot
.58 .30426 Mdot
.58 .30427 Mdot
.58 .30428 Mdot
.58 .3043 Mdot
.58 .3043 Mdot
.58 .30432 Mdot
.58 .30432 Mdot
.58 .30433 Mdot
.58 .30434 Mdot
.58 .30437 Mdot
.58 .30439 Mdot
.58 .30441 Mdot
.58 .30441 Mdot
.58 .30443 Mdot
.58 .30444 Mdot
.58 .30444 Mdot
.58 .30445 Mdot
.58 .30446 Mdot
.58 .30446 Mdot
.58 .30449 Mdot
.58 .3045 Mdot
.58 .3045 Mdot
.58 .30451 Mdot
.58 .30451 Mdot
.58 .30453 Mdot
.58 .30455 Mdot
.58 .30456 Mdot
.58 .30459 Mdot
.58 .30459 Mdot
.58 .30459 Mdot
.58 .30464 Mdot
.58 .30466 Mdot
.58 .30466 Mdot
.58 .30467 Mdot
.58 .3047 Mdot
.58 .30472 Mdot
.58 .30473 Mdot
.58 .30473 Mdot
.58 .30474 Mdot
.58 .30477 Mdot
.58 .30478 Mdot
.58 .30479 Mdot
.58 .30482 Mdot
.58 .30483 Mdot
.58 .30484 Mdot
.58 .30485 Mdot
.58 .30485 Mdot
.58 .30486 Mdot
.58 .30487 Mdot
.58 .3049 Mdot
.58 .30493 Mdot
.58 .30495 Mdot
.58 .30495 Mdot
.58 .30497 Mdot
.58 .30502 Mdot
.58 .30504 Mdot
.58 .30509 Mdot
.58 .30509 Mdot
.58 .3051 Mdot
.58 .30511 Mdot
.58 .30513 Mdot
.58 .30517 Mdot
.58 .3052 Mdot
.58 .30524 Mdot
.58 .30525 Mdot
.58 .30527 Mdot
.58 .30528 Mdot
.58 .30531 Mdot
.58 .30532 Mdot
.58 .30536 Mdot
.58 .30536 Mdot
.58 .30539 Mdot
.58 .3054 Mdot
.58 .30542 Mdot
.58 .30548 Mdot
.58 .30549 Mdot
.58 .30552 Mdot
.58 .30554 Mdot
.58 .30554 Mdot
.58 .30557 Mdot
.58 .30558 Mdot
.58 .30768 Mdot
.58 .30769 Mdot
.58 .30773 Mdot
.58 .30774 Mdot
.58 .30777 Mdot
.58 .3078 Mdot
.58 .30782 Mdot
.58 .3079 Mdot
.58 .30792 Mdot
.58 .30794 Mdot
.58 .30798 Mdot
.58 .30798 Mdot
.58 .30803 Mdot
.58 .30804 Mdot
.58 .30808 Mdot
.58 .30809 Mdot
.58 .30813 Mdot
.58 .30814 Mdot
.58 .30819 Mdot
.58 .30824 Mdot
.58 .30829 Mdot
.58 .30832 Mdot
.58 .30833 Mdot
.58 .30834 Mdot
.58 .30835 Mdot
.58 .30841 Mdot
.58 .30844 Mdot
.58 .30851 Mdot
.58 .30853 Mdot
.58 .30853 Mdot
.58 .30855 Mdot
.58 .3086 Mdot
.58 .30864 Mdot
.58 .30865 Mdot
.58 .30866 Mdot
.58 .30867 Mdot
.58 .30868 Mdot
.58 .3087 Mdot
.58 .3087 Mdot
.58 .30875 Mdot
.58 .30876 Mdot
.58 .30878 Mdot
.58 .30882 Mdot
.58 .30883 Mdot
.58 .30883 Mdot
.58 .30884 Mdot
.58 .30887 Mdot
.58 .3089 Mdot
.58 .30892 Mdot
.58 .30892 Mdot
.58 .30895 Mdot
.58 .30901 Mdot
.58 .30901 Mdot
.58 .30902 Mdot
.58 .30906 Mdot
.58 .30907 Mdot
.58 .3091 Mdot
.58 .30912 Mdot
.58 .30913 Mdot
.58 .30913 Mdot
.58 .30914 Mdot
.58 .30915 Mdot
.58 .30919 Mdot
.58 .3092 Mdot
.58 .30921 Mdot
.58 .30922 Mdot
.58 .30922 Mdot
.58 .30923 Mdot
.58 .30926 Mdot
.58 .30926 Mdot
.58 .30929 Mdot
.58 .30931 Mdot
.58 .30935 Mdot
.58 .30937 Mdot
.58 .30937 Mdot
.58 .30939 Mdot
.58 .30941 Mdot
.58 .30941 Mdot
.58 .30943 Mdot
.58 .30944 Mdot
.58 .30946 Mdot
.58 .30947 Mdot
.58 .3095 Mdot
.58 .30951 Mdot
.58 .30954 Mdot
.58 .30959 Mdot
.58 .30962 Mdot
.58 .30964 Mdot
.58 .30965 Mdot
.58 .30966 Mdot
.58 .30967 Mdot
.58 .30974 Mdot
.58 .30976 Mdot
.58 .30979 Mdot
.58 .3098 Mdot
.58 .30982 Mdot
.58 .30982 Mdot
.58 .30983 Mdot
.58 .30984 Mdot
.58 .30985 Mdot
.58 .30986 Mdot
.58 .30987 Mdot
.58 .30991 Mdot
.58 .30993 Mdot
.58 .30993 Mdot
.58 .30998 Mdot
.58 .30999 Mdot
.58 .31003 Mdot
.58 .31004 Mdot
.58 .31006 Mdot
.58 .31008 Mdot
.58 .31008 Mdot
.58 .3101 Mdot
.58 .31011 Mdot
.58 .31013 Mdot
.58 .31015 Mdot
.58 .31018 Mdot
.58 .31019 Mdot
.58 .3102 Mdot
.58 .3102 Mdot
.58 .31021 Mdot
.58 .31024 Mdot
.58 .31024 Mdot
.58 .31028 Mdot
.58 .31032 Mdot
.58 .31032 Mdot
.58 .31036 Mdot
.58 .31037 Mdot
.58 .31039 Mdot
.58 .31041 Mdot
.58 .31041 Mdot
.58 .31041 Mdot
.58 .31043 Mdot
.58 .31045 Mdot
.58 .31046 Mdot
.58 .31046 Mdot
.58 .31047 Mdot
.58 .31049 Mdot
.58 .31051 Mdot
.58 .31053 Mdot
.58 .31054 Mdot
.58 .31058 Mdot
.58 .3106 Mdot
.58 .3106 Mdot
.58 .31061 Mdot
.58 .31064 Mdot
.58 .31065 Mdot
.58 .31067 Mdot
.58 .31068 Mdot
.58 .31071 Mdot
.58 .31072 Mdot
.58 .31074 Mdot
.58 .31074 Mdot
.58 .31076 Mdot
.58 .31077 Mdot
.58 .31079 Mdot
.58 .31081 Mdot
.58 .31084 Mdot
.58 .31085 Mdot
.58 .31086 Mdot
.58 .31087 Mdot
.58 .3109 Mdot
.58 .31091 Mdot
.58 .31091 Mdot
.58 .31093 Mdot
.58 .31093 Mdot
.58 .31094 Mdot
.58 .31095 Mdot
.58 .31097 Mdot
.58 .31101 Mdot
.58 .31101 Mdot
.58 .31102 Mdot
.58 .31105 Mdot
.58 .31106 Mdot
.58 .31107 Mdot
.58 .31108 Mdot
.58 .31108 Mdot
.58 .31111 Mdot
.58 .31115 Mdot
.58 .31116 Mdot
.58 .31117 Mdot
.58 .31118 Mdot
.58 .31122 Mdot
.58 .31124 Mdot
.58 .31127 Mdot
.58 .31128 Mdot
.58 .31128 Mdot
.58 .3113 Mdot
.58 .31132 Mdot
.58 .31132 Mdot
.58 .31133 Mdot
.58 .31138 Mdot
.58 .31138 Mdot
.58 .3114 Mdot
.58 .3114 Mdot
.58 .3114 Mdot
.58 .31141 Mdot
.58 .31142 Mdot
.58 .31144 Mdot
.58 .31145 Mdot
.58 .31145 Mdot
.58 .31145 Mdot
.58 .31149 Mdot
.58 .31151 Mdot
.58 .31151 Mdot
.58 .31152 Mdot
.58 .31155 Mdot
.58 .31156 Mdot
.58 .31157 Mdot
.58 .31161 Mdot
.58 .31161 Mdot
.58 .31161 Mdot
.58 .31165 Mdot
.58 .31169 Mdot
.58 .31169 Mdot
.58 .3117 Mdot
.58 .31171 Mdot
.58 .31172 Mdot
.58 .31174 Mdot
.58 .31177 Mdot
.58 .31178 Mdot
.58 .31178 Mdot
.58 .3118 Mdot
.58 .31183 Mdot
.58 .31185 Mdot
.58 .31188 Mdot
.58 .31189 Mdot
.58 .31189 Mdot
.58 .3119 Mdot
.58 .31191 Mdot
.58 .31194 Mdot
.58 .31197 Mdot
.58 .31199 Mdot
.58 .312 Mdot
.58 .31202 Mdot
.58 .31203 Mdot
.58 .31205 Mdot
.58 .31206 Mdot
.58 .31209 Mdot
.58 .31209 Mdot
.58 .31211 Mdot
.58 .31212 Mdot
.58 .31213 Mdot
.58 .31218 Mdot
.58 .31219 Mdot
.58 .3122 Mdot
.58 .31222 Mdot
.58 .31222 Mdot
.58 .31225 Mdot
.58 .31225 Mdot
.58 .34818 Mdot
.58 .34819 Mdot
.58 .34821 Mdot
.58 .34821 Mdot
.58 .34822 Mdot
.58 .34824 Mdot
.58 .34825 Mdot
.58 .34829 Mdot
.58 .3483 Mdot
.58 .34831 Mdot
.58 .34832 Mdot
.58 .34832 Mdot
.58 .34835 Mdot
.58 .34835 Mdot
.58 .34837 Mdot
.58 .34838 Mdot
.58 .3484 Mdot
.58 .3484 Mdot
.58 .34843 Mdot
.58 .34845 Mdot
.58 .34847 Mdot
.58 .34849 Mdot
.58 .34849 Mdot
.58 .3485 Mdot
.58 .3485 Mdot
.58 .34853 Mdot
.58 .34854 Mdot
.58 .34857 Mdot
.58 .34859 Mdot
.58 .34859 Mdot
.58 .3486 Mdot
.58 .34862 Mdot
.58 .34864 Mdot
.58 .34865 Mdot
.58 .34865 Mdot
.58 .34866 Mdot
.58 .34867 Mdot
.58 .3487 Mdot
.58 .34873 Mdot
.58 .34873 Mdot
.58 .34874 Mdot
.58 .34877 Mdot
.58 .34877 Mdot
.58 .34879 Mdot
.58 .34881 Mdot
.58 .34882 Mdot
.58 .34882 Mdot
.58 .34884 Mdot
.58 .34887 Mdot
.58 .34887 Mdot
.58 .34888 Mdot
.58 .34888 Mdot
.58 .3489 Mdot
.58 .34891 Mdot
.58 .34891 Mdot
.58 .34892 Mdot
.58 .34892 Mdot
.58 .34893 Mdot
.58 .34893 Mdot
.58 .34898 Mdot
.58 .34898 Mdot
.58 .34899 Mdot
.58 .349 Mdot
.58 .34902 Mdot
.58 .34902 Mdot
.58 .34903 Mdot
.58 .34905 Mdot
.58 .34907 Mdot
.58 .34911 Mdot
.58 .34911 Mdot
.58 .34912 Mdot
.58 .34913 Mdot
.58 .34916 Mdot
.58 .34919 Mdot
.58 .34919 Mdot
.58 .3492 Mdot
.58 .34921 Mdot
.58 .34922 Mdot
.58 .34924 Mdot
.58 .34925 Mdot
.58 .34925 Mdot
.58 .34928 Mdot
.58 .3493 Mdot
.58 .34931 Mdot
.58 .34932 Mdot
.58 .34932 Mdot
.58 .34934 Mdot
.58 .34934 Mdot
.58 .34935 Mdot
.58 .34937 Mdot
.58 .34938 Mdot
.58 .34938 Mdot
.58 .3494 Mdot
.58 .34942 Mdot
.58 .34944 Mdot
.58 .34945 Mdot
.58 .34946 Mdot
.58 .34948 Mdot
.58 .34948 Mdot
.58 .3495 Mdot
.58 .34951 Mdot
.58 .34954 Mdot
.58 .34954 Mdot
.58 .34956 Mdot
.58 .34957 Mdot
.58 .3496 Mdot
.58 .3496 Mdot
.58 .34961 Mdot
.58 .34962 Mdot
.58 .34965 Mdot
.58 .34966 Mdot
.58 .34968 Mdot
.58 .3497 Mdot
.58 .34972 Mdot
.58 .34973 Mdot
.58 .34973 Mdot
.58 .34973 Mdot
.58 .34975 Mdot
.58 .34977 Mdot
.58 .34977 Mdot
.58 .34977 Mdot
.58 .34978 Mdot
.58 .3498 Mdot
.58 .34981 Mdot
.58 .34984 Mdot
.58 .34985 Mdot
.58 .34988 Mdot
.58 .34991 Mdot
.58 .34992 Mdot
.58 .34994 Mdot
.58 .34995 Mdot
.58 .34995 Mdot
.58 .34996 Mdot
.58 .34997 Mdot
.58 .34999 Mdot
.58 .35001 Mdot
.58 .35002 Mdot
.58 .35003 Mdot
.58 .35005 Mdot
.58 .35005 Mdot
.58 .35007 Mdot
.58 .35009 Mdot
.58 .3501 Mdot
.58 .35013 Mdot
.58 .35014 Mdot
.58 .35018 Mdot
.58 .35019 Mdot
.58 .3502 Mdot
.58 .35024 Mdot
.58 .35024 Mdot
.58 .35025 Mdot
.58 .35026 Mdot
.58 .35027 Mdot
.58 .35028 Mdot
.58 .35028 Mdot
.58 .35029 Mdot
.58 .3503 Mdot
.58 .35033 Mdot
.58 .35034 Mdot
.58 .35041 Mdot
.58 .35041 Mdot
.58 .35042 Mdot
.58 .35043 Mdot
.58 .35045 Mdot
.58 .35048 Mdot
.58 .35052 Mdot
.58 .35054 Mdot
.58 .35056 Mdot
.58 .35058 Mdot
.58 .35059 Mdot
.58 .3506 Mdot
.58 .35061 Mdot
.58 .35063 Mdot
.58 .35063 Mdot
.58 .35065 Mdot
.58 .35066 Mdot
.58 .35067 Mdot
.58 .35068 Mdot
.58 .35072 Mdot
.58 .35074 Mdot
.58 .35076 Mdot
.58 .35076 Mdot
.58 .35079 Mdot
.58 .35079 Mdot
.58 .35079 Mdot
.58 .35081 Mdot
.58 .35081 Mdot
.58 .35082 Mdot
.58 .35085 Mdot
.58 .35086 Mdot
.58 .35087 Mdot
.58 .35087 Mdot
.58 .35088 Mdot
.58 .3509 Mdot
.58 .35093 Mdot
.58 .35093 Mdot
.58 .35097 Mdot
.58 .35097 Mdot
.58 .35098 Mdot
.58 .35103 Mdot
.58 .35105 Mdot
.58 .35105 Mdot
.58 .35107 Mdot
.58 .35109 Mdot
.58 .35112 Mdot
.58 .35113 Mdot
.58 .35113 Mdot
.58 .35114 Mdot
.58 .35118 Mdot
.58 .35119 Mdot
.58 .3512 Mdot
.58 .35124 Mdot
.58 .35125 Mdot
.58 .35126 Mdot
.58 .35127 Mdot
.58 .35128 Mdot
.58 .35129 Mdot
.58 .35129 Mdot
.58 .35133 Mdot
.58 .35137 Mdot
.58 .35139 Mdot
.58 .35139 Mdot
.58 .35141 Mdot
.58 .35146 Mdot
.58 .35149 Mdot
.58 .35154 Mdot
.58 .35155 Mdot
.58 .35156 Mdot
.58 .35157 Mdot
.58 .35159 Mdot
.58 .35164 Mdot
.58 .35168 Mdot
.58 .35172 Mdot
.58 .35173 Mdot
.58 .35176 Mdot
.58 .35177 Mdot
.58 .35181 Mdot
.58 .35182 Mdot
.58 .35186 Mdot
.58 .35186 Mdot
.58 .3519 Mdot
.58 .35191 Mdot
.58 .35193 Mdot
.58 .352 Mdot
.58 .35202 Mdot
.58 .35204 Mdot
.58 .35207 Mdot
.58 .35208 Mdot
.58 .35211 Mdot
.58 .35212 Mdot
.58 .35393 Mdot
.58 .35394 Mdot
.58 .35396 Mdot
.58 .35397 Mdot
.58 .35399 Mdot
.58 .35401 Mdot
.58 .35402 Mdot
.58 .35407 Mdot
.58 .35409 Mdot
.58 .3541 Mdot
.58 .35412 Mdot
.58 .35412 Mdot
.58 .35415 Mdot
.58 .35416 Mdot
.58 .35419 Mdot
.58 .3542 Mdot
.58 .35422 Mdot
.58 .35423 Mdot
.58 .35426 Mdot
.58 .35429 Mdot
.58 .35432 Mdot
.58 .35434 Mdot
.58 .35435 Mdot
.58 .35435 Mdot
.58 .35436 Mdot
.58 .3544 Mdot
.58 .35442 Mdot
.58 .35446 Mdot
.58 .35447 Mdot
.58 .35448 Mdot
.58 .35449 Mdot
.58 .35452 Mdot
.58 .35454 Mdot
.58 .35455 Mdot
.58 .35456 Mdot
.58 .35457 Mdot
.58 .35457 Mdot
.58 .35458 Mdot
.58 .35459 Mdot
.58 .35462 Mdot
.58 .35462 Mdot
.58 .35463 Mdot
.58 .35466 Mdot
.58 .35467 Mdot
.58 .35467 Mdot
.58 .35468 Mdot
.58 .35469 Mdot
.58 .35471 Mdot
.58 .35472 Mdot
.58 .35473 Mdot
.58 .35474 Mdot
.58 .35478 Mdot
.58 .35478 Mdot
.58 .35479 Mdot
.58 .35481 Mdot
.58 .35482 Mdot
.58 .35484 Mdot
.58 .35485 Mdot
.58 .35486 Mdot
.58 .35486 Mdot
.58 .35486 Mdot
.58 .35487 Mdot
.58 .35489 Mdot
.58 .3549 Mdot
.58 .3549 Mdot
.58 .35491 Mdot
.58 .35492 Mdot
.58 .35492 Mdot
.58 .35492 Mdot
.58 .35494 Mdot
.58 .35494 Mdot
.58 .35496 Mdot
.58 .35497 Mdot
.58 .355 Mdot
.58 .35501 Mdot
.58 .35501 Mdot
.58 .35502 Mdot
.58 .35504 Mdot
.58 .35504 Mdot
.58 .35505 Mdot
.58 .35506 Mdot
.58 .35507 Mdot
.58 .35508 Mdot
.58 .35509 Mdot
.58 .3551 Mdot
.58 .35512 Mdot
.58 .35515 Mdot
.58 .35518 Mdot
.58 .35518 Mdot
.58 .35519 Mdot
.58 .3552 Mdot
.58 .3552 Mdot
.58 .35525 Mdot
.58 .35526 Mdot
.58 .35528 Mdot
.58 .35529 Mdot
.58 .3553 Mdot
.58 .3553 Mdot
.58 .35531 Mdot
.58 .35531 Mdot
.58 .35532 Mdot
.58 .35533 Mdot
.58 .35533 Mdot
.58 .35536 Mdot
.58 .35537 Mdot
.58 .35537 Mdot
.58 .3554 Mdot
.58 .35541 Mdot
.58 .35543 Mdot
.58 .35544 Mdot
.58 .35545 Mdot
.58 .35547 Mdot
.58 .35547 Mdot
.58 .35548 Mdot
.58 .35549 Mdot
.58 .3555 Mdot
.58 .35551 Mdot
.58 .35553 Mdot
.58 .35554 Mdot
.58 .35554 Mdot
.58 .35554 Mdot
.58 .35555 Mdot
.58 .35557 Mdot
.58 .35557 Mdot
.58 .3556 Mdot
.58 .35562 Mdot
.58 .35562 Mdot
.58 .35564 Mdot
.58 .35566 Mdot
.58 .35567 Mdot
.58 .35568 Mdot
.58 .35568 Mdot
.58 .35568 Mdot
.58 .35569 Mdot
.58 .35571 Mdot
.58 .35571 Mdot
.58 .35571 Mdot
.58 .35571 Mdot
.58 .35573 Mdot
.58 .35574 Mdot
.58 .35576 Mdot
.58 .35576 Mdot
.58 .35579 Mdot
.58 .3558 Mdot
.58 .3558 Mdot
.58 .35581 Mdot
.58 .35583 Mdot
.58 .35583 Mdot
.58 .35585 Mdot
.58 .35585 Mdot
.58 .35587 Mdot
.58 .35588 Mdot
.58 .35589 Mdot
.58 .35589 Mdot
.58 .35591 Mdot
.58 .35591 Mdot
.58 .35592 Mdot
.58 .35594 Mdot
.58 .35595 Mdot
.58 .35596 Mdot
.58 .35597 Mdot
.58 .35598 Mdot
.58 .35599 Mdot
.58 .356 Mdot
.58 .356 Mdot
.58 .35601 Mdot
.58 .35601 Mdot
.58 .35602 Mdot
.58 .35603 Mdot
.58 .35604 Mdot
.58 .35606 Mdot
.58 .35606 Mdot
.58 .35607 Mdot
.58 .35609 Mdot
.58 .3561 Mdot
.58 .3561 Mdot
.58 .35611 Mdot
.58 .35611 Mdot
.58 .35613 Mdot
.58 .35616 Mdot
.58 .35616 Mdot
.58 .35617 Mdot
.58 .35617 Mdot
.58 .3562 Mdot
.58 .35621 Mdot
.58 .35623 Mdot
.58 .35623 Mdot
.58 .35624 Mdot
.58 .35625 Mdot
.58 .35626 Mdot
.58 .35626 Mdot
.58 .35627 Mdot
.58 .3563 Mdot
.58 .3563 Mdot
.58 .35631 Mdot
.58 .35631 Mdot
.58 .35631 Mdot
.58 .35632 Mdot
.58 .35633 Mdot
.58 .35634 Mdot
.58 .35634 Mdot
.58 .35635 Mdot
.58 .35635 Mdot
.58 .35637 Mdot
.58 .35638 Mdot
.58 .35639 Mdot
.58 .35639 Mdot
.58 .35641 Mdot
.58 .35642 Mdot
.58 .35642 Mdot
.58 .35645 Mdot
.58 .35645 Mdot
.58 .35645 Mdot
.58 .35647 Mdot
.58 .3565 Mdot
.58 .3565 Mdot
.58 .35651 Mdot
.58 .35651 Mdot
.58 .35652 Mdot
.58 .35653 Mdot
.58 .35655 Mdot
.58 .35656 Mdot
.58 .35656 Mdot
.58 .35657 Mdot
.58 .35659 Mdot
.58 .3566 Mdot
.58 .35662 Mdot
.58 .35662 Mdot
.58 .35663 Mdot
.58 .35663 Mdot
.58 .35664 Mdot
.58 .35666 Mdot
.58 .35668 Mdot
.58 .35669 Mdot
.58 .3567 Mdot
.58 .35671 Mdot
.58 .35672 Mdot
.58 .35673 Mdot
.58 .35673 Mdot
.58 .35675 Mdot
.58 .35675 Mdot
.58 .35677 Mdot
.58 .35677 Mdot
.58 .35678 Mdot
.58 .35681 Mdot
.58 .35682 Mdot
.58 .35683 Mdot
.58 .35684 Mdot
.58 .35684 Mdot
.58 .35685 Mdot
.58 .35686 Mdot
.582 .30179 Mdot
.582 .3018 Mdot
.582 .3018 Mdot
.582 .30182 Mdot
.582 .30183 Mdot
.582 .30184 Mdot
.582 .30187 Mdot
.582 .30187 Mdot
.582 .30187 Mdot
.582 .30189 Mdot
.582 .30189 Mdot
.582 .30189 Mdot
.582 .30189 Mdot
.582 .30192 Mdot
.582 .30192 Mdot
.582 .30194 Mdot
.582 .30194 Mdot
.582 .30195 Mdot
.582 .30195 Mdot
.582 .30197 Mdot
.582 .302 Mdot
.582 .302 Mdot
.582 .30201 Mdot
.582 .3021 Mdot
.582 .30213 Mdot
.582 .30217 Mdot
.582 .30218 Mdot
.582 .30219 Mdot
.582 .30221 Mdot
.582 .30224 Mdot
.582 .30226 Mdot
.582 .30227 Mdot
.582 .30228 Mdot
.582 .30229 Mdot
.582 .30229 Mdot
.582 .3023 Mdot
.582 .30231 Mdot
.582 .30232 Mdot
.582 .30232 Mdot
.582 .30234 Mdot
.582 .30238 Mdot
.582 .3024 Mdot
.582 .30243 Mdot
.582 .30244 Mdot
.582 .30247 Mdot
.582 .30251 Mdot
.582 .30252 Mdot
.582 .30255 Mdot
.582 .30257 Mdot
.582 .30259 Mdot
.582 .30265 Mdot
.582 .30266 Mdot
.582 .30267 Mdot
.582 .30268 Mdot
.582 .30268 Mdot
.582 .30269 Mdot
.582 .3027 Mdot
.582 .3027 Mdot
.582 .30272 Mdot
.582 .30273 Mdot
.582 .30274 Mdot
.582 .30275 Mdot
.582 .30275 Mdot
.582 .30275 Mdot
.582 .30275 Mdot
.582 .30276 Mdot
.582 .30276 Mdot
.582 .30276 Mdot
.582 .30278 Mdot
.582 .30278 Mdot
.582 .3028 Mdot
.582 .30281 Mdot
.582 .30282 Mdot
.582 .30284 Mdot
.582 .30286 Mdot
.582 .30287 Mdot
.582 .30288 Mdot
.582 .30291 Mdot
.582 .30295 Mdot
.582 .30298 Mdot
.582 .30299 Mdot
.582 .303 Mdot
.582 .303 Mdot
.582 .303 Mdot
.582 .303 Mdot
.582 .303 Mdot
.582 .30301 Mdot
.582 .30301 Mdot
.582 .30301 Mdot
.582 .30301 Mdot
.582 .30302 Mdot
.582 .30304 Mdot
.582 .30305 Mdot
.582 .30307 Mdot
.582 .30308 Mdot
.582 .30308 Mdot
.582 .30308 Mdot
.582 .30309 Mdot
.582 .3031 Mdot
.582 .3031 Mdot
.582 .3031 Mdot
.582 .30311 Mdot
.582 .30311 Mdot
.582 .30311 Mdot
.582 .30312 Mdot
.582 .30312 Mdot
.582 .30313 Mdot
.582 .30314 Mdot
.582 .30315 Mdot
.582 .30315 Mdot
.582 .30316 Mdot
.582 .30317 Mdot
.582 .30317 Mdot
.582 .30317 Mdot
.582 .30317 Mdot
.582 .30318 Mdot
.582 .30319 Mdot
.582 .30322 Mdot
.582 .30324 Mdot
.582 .30326 Mdot
.582 .30327 Mdot
.582 .30329 Mdot
.582 .30329 Mdot
.582 .3033 Mdot
.582 .3033 Mdot
.582 .3033 Mdot
.582 .3033 Mdot
.582 .3033 Mdot
.582 .3033 Mdot
.582 .3033 Mdot
.582 .30331 Mdot
.582 .30332 Mdot
.582 .30334 Mdot
.582 .30334 Mdot
.582 .30334 Mdot
.582 .30339 Mdot
.582 .30341 Mdot
.582 .30343 Mdot
.582 .30346 Mdot
.582 .30347 Mdot
.582 .30351 Mdot
.582 .30353 Mdot
.582 .30354 Mdot
.582 .30355 Mdot
.582 .30355 Mdot
.582 .30357 Mdot
.582 .30357 Mdot
.582 .3036 Mdot
.582 .30361 Mdot
.582 .30361 Mdot
.582 .30364 Mdot
.582 .30366 Mdot
.582 .30368 Mdot
.582 .30371 Mdot
.582 .30371 Mdot
.582 .30371 Mdot
.582 .30374 Mdot
.582 .30374 Mdot
.582 .30374 Mdot
.582 .30376 Mdot
.582 .30377 Mdot
.582 .30377 Mdot
.582 .30377 Mdot
.582 .30378 Mdot
.582 .30381 Mdot
.582 .30381 Mdot
.582 .30382 Mdot
.582 .30386 Mdot
.582 .30386 Mdot
.582 .30388 Mdot
.582 .3039 Mdot
.582 .3039 Mdot
.582 .30391 Mdot
.582 .30393 Mdot
.582 .30394 Mdot
.582 .30395 Mdot
.582 .30406 Mdot
.582 .3041 Mdot
.582 .30413 Mdot
.582 .30413 Mdot
.582 .30414 Mdot
.582 .30414 Mdot
.582 .30419 Mdot
.582 .3042 Mdot
.582 .30425 Mdot
.582 .30428 Mdot
.582 .30432 Mdot
.582 .30433 Mdot
.582 .30434 Mdot
.582 .30435 Mdot
.582 .30435 Mdot
.582 .30436 Mdot
.582 .3044 Mdot
.582 .30441 Mdot
.582 .30444 Mdot
.582 .30445 Mdot
.582 .30451 Mdot
.582 .30452 Mdot
.582 .30452 Mdot
.582 .30452 Mdot
.582 .30452 Mdot
.582 .30456 Mdot
.582 .30456 Mdot
.582 .30457 Mdot
.582 .30458 Mdot
.582 .30458 Mdot
.582 .30459 Mdot
.582 .3046 Mdot
.582 .30461 Mdot
.582 .30461 Mdot
.582 .30462 Mdot
.582 .30465 Mdot
.582 .30467 Mdot
.582 .3047 Mdot
.582 .3047 Mdot
.582 .30474 Mdot
.582 .30475 Mdot
.582 .30476 Mdot
.582 .30479 Mdot
.582 .30481 Mdot
.582 .30482 Mdot
.582 .30482 Mdot
.582 .30484 Mdot
.582 .30485 Mdot
.582 .3049 Mdot
.582 .30495 Mdot
.582 .30502 Mdot
.582 .30513 Mdot
.582 .30514 Mdot
.582 .30514 Mdot
.582 .3052 Mdot
.582 .30524 Mdot
.582 .30524 Mdot
.582 .30525 Mdot
.582 .30525 Mdot
.582 .30528 Mdot
.582 .3053 Mdot
.582 .30534 Mdot
.582 .30534 Mdot
.582 .30534 Mdot
.582 .30534 Mdot
.582 .30537 Mdot
.582 .30538 Mdot
.582 .30539 Mdot
.582 .30544 Mdot
.582 .30546 Mdot
.582 .30547 Mdot
.582 .3055 Mdot
.582 .30552 Mdot
.582 .30552 Mdot
.582 .30742 Mdot
.582 .30742 Mdot
.582 .30744 Mdot
.582 .30749 Mdot
.582 .3075 Mdot
.582 .30753 Mdot
.582 .3076 Mdot
.582 .30762 Mdot
.582 .30762 Mdot
.582 .30766 Mdot
.582 .30766 Mdot
.582 .30766 Mdot
.582 .30767 Mdot
.582 .30772 Mdot
.582 .30774 Mdot
.582 .30779 Mdot
.582 .30779 Mdot
.582 .3078 Mdot
.582 .30781 Mdot
.582 .30786 Mdot
.582 .30794 Mdot
.582 .30794 Mdot
.582 .30795 Mdot
.582 .3081 Mdot
.582 .30819 Mdot
.582 .30826 Mdot
.582 .30833 Mdot
.582 .30834 Mdot
.582 .30836 Mdot
.582 .30838 Mdot
.582 .30838 Mdot
.582 .30841 Mdot
.582 .30845 Mdot
.582 .30847 Mdot
.582 .30848 Mdot
.582 .30853 Mdot
.582 .30853 Mdot
.582 .30857 Mdot
.582 .30859 Mdot
.582 .30864 Mdot
.582 .30866 Mdot
.582 .30866 Mdot
.582 .30866 Mdot
.582 .30868 Mdot
.582 .30869 Mdot
.582 .3087 Mdot
.582 .3087 Mdot
.582 .30872 Mdot
.582 .30873 Mdot
.582 .30878 Mdot
.582 .30878 Mdot
.582 .30878 Mdot
.582 .30878 Mdot
.582 .30878 Mdot
.582 .30887 Mdot
.582 .30889 Mdot
.582 .30892 Mdot
.582 .30893 Mdot
.582 .30899 Mdot
.582 .30901 Mdot
.582 .30901 Mdot
.582 .30903 Mdot
.582 .30904 Mdot
.582 .30904 Mdot
.582 .3091 Mdot
.582 .30914 Mdot
.582 .30921 Mdot
.582 .30922 Mdot
.582 .30929 Mdot
.582 .30929 Mdot
.582 .30931 Mdot
.582 .30931 Mdot
.582 .30934 Mdot
.582 .30939 Mdot
.582 .30954 Mdot
.582 .30956 Mdot
.582 .30958 Mdot
.582 .3096 Mdot
.582 .30961 Mdot
.582 .30962 Mdot
.582 .30964 Mdot
.582 .30967 Mdot
.582 .30967 Mdot
.582 .30972 Mdot
.582 .30974 Mdot
.582 .30974 Mdot
.582 .30977 Mdot
.582 .30979 Mdot
.582 .30979 Mdot
.582 .30979 Mdot
.582 .30981 Mdot
.582 .30983 Mdot
.582 .30983 Mdot
.582 .30983 Mdot
.582 .30987 Mdot
.582 .30987 Mdot
.582 .30988 Mdot
.582 .30992 Mdot
.582 .30995 Mdot
.582 .30997 Mdot
.582 .31 Mdot
.582 .31001 Mdot
.582 .31002 Mdot
.582 .31006 Mdot
.582 .31007 Mdot
.582 .31009 Mdot
.582 .31009 Mdot
.582 .3101 Mdot
.582 .31012 Mdot
.582 .31015 Mdot
.582 .3102 Mdot
.582 .31022 Mdot
.582 .31025 Mdot
.582 .31028 Mdot
.582 .3103 Mdot
.582 .31037 Mdot
.582 .31037 Mdot
.582 .31038 Mdot
.582 .31041 Mdot
.582 .31042 Mdot
.582 .31042 Mdot
.582 .31042 Mdot
.582 .31042 Mdot
.582 .31043 Mdot
.582 .31043 Mdot
.582 .31043 Mdot
.582 .31044 Mdot
.582 .31045 Mdot
.582 .31045 Mdot
.582 .31048 Mdot
.582 .31049 Mdot
.582 .31051 Mdot
.582 .31054 Mdot
.582 .31058 Mdot
.582 .3106 Mdot
.582 .31061 Mdot
.582 .31061 Mdot
.582 .31061 Mdot
.582 .31061 Mdot
.582 .31062 Mdot
.582 .31063 Mdot
.582 .31064 Mdot
.582 .31065 Mdot
.582 .31066 Mdot
.582 .31067 Mdot
.582 .31067 Mdot
.582 .31068 Mdot
.582 .31068 Mdot
.582 .31069 Mdot
.582 .31069 Mdot
.582 .3107 Mdot
.582 .3107 Mdot
.582 .31072 Mdot
.582 .31072 Mdot
.582 .31073 Mdot
.582 .31073 Mdot
.582 .31074 Mdot
.582 .31077 Mdot
.582 .31079 Mdot
.582 .31081 Mdot
.582 .31082 Mdot
.582 .31083 Mdot
.582 .31083 Mdot
.582 .31083 Mdot
.582 .31083 Mdot
.582 .31083 Mdot
.582 .31083 Mdot
.582 .31083 Mdot
.582 .31084 Mdot
.582 .31084 Mdot
.582 .31086 Mdot
.582 .3109 Mdot
.582 .31096 Mdot
.582 .311 Mdot
.582 .31101 Mdot
.582 .31103 Mdot
.582 .31106 Mdot
.582 .31108 Mdot
.582 .31109 Mdot
.582 .31111 Mdot
.582 .31113 Mdot
.582 .31113 Mdot
.582 .31116 Mdot
.582 .31116 Mdot
.582 .31116 Mdot
.582 .31117 Mdot
.582 .31118 Mdot
.582 .31118 Mdot
.582 .31118 Mdot
.582 .31119 Mdot
.582 .31121 Mdot
.582 .31122 Mdot
.582 .31124 Mdot
.582 .31125 Mdot
.582 .31126 Mdot
.582 .31127 Mdot
.582 .31127 Mdot
.582 .31128 Mdot
.582 .3113 Mdot
.582 .31131 Mdot
.582 .3114 Mdot
.582 .31142 Mdot
.582 .31144 Mdot
.582 .31149 Mdot
.582 .3115 Mdot
.582 .31155 Mdot
.582 .31159 Mdot
.582 .31161 Mdot
.582 .31165 Mdot
.582 .31168 Mdot
.582 .31173 Mdot
.582 .31176 Mdot
.582 .31176 Mdot
.582 .31177 Mdot
.582 .31178 Mdot
.582 .31179 Mdot
.582 .3118 Mdot
.582 .31181 Mdot
.582 .31183 Mdot
.582 .31184 Mdot
.582 .31187 Mdot
.582 .31191 Mdot
.582 .31193 Mdot
.582 .31195 Mdot
.582 .31196 Mdot
.582 .31201 Mdot
.582 .31205 Mdot
.582 .31218 Mdot
.582 .31219 Mdot
.582 .31219 Mdot
.582 .31223 Mdot
.582 .31226 Mdot
.582 .31226 Mdot
.582 .31227 Mdot
.582 .31227 Mdot
.582 .3123 Mdot
.582 .31231 Mdot
.582 .31234 Mdot
.582 .31234 Mdot
.582 .31234 Mdot
.582 .31234 Mdot
.582 .31236 Mdot
.582 .31236 Mdot
.582 .31237 Mdot
.582 .31241 Mdot
.582 .31243 Mdot
.582 .31243 Mdot
.582 .31246 Mdot
.582 .31247 Mdot
.582 .31247 Mdot
.582 .34887 Mdot
.582 .34888 Mdot
.582 .34889 Mdot
.582 .34891 Mdot
.582 .34891 Mdot
.582 .34892 Mdot
.582 .34896 Mdot
.582 .34897 Mdot
.582 .34897 Mdot
.582 .34899 Mdot
.582 .34899 Mdot
.582 .34899 Mdot
.582 .34899 Mdot
.582 .34902 Mdot
.582 .34902 Mdot
.582 .34905 Mdot
.582 .34905 Mdot
.582 .34905 Mdot
.582 .34906 Mdot
.582 .34908 Mdot
.582 .34912 Mdot
.582 .34912 Mdot
.582 .34912 Mdot
.582 .34923 Mdot
.582 .34927 Mdot
.582 .34932 Mdot
.582 .34932 Mdot
.582 .34934 Mdot
.582 .34935 Mdot
.582 .34939 Mdot
.582 .34941 Mdot
.582 .34942 Mdot
.582 .34945 Mdot
.582 .34945 Mdot
.582 .34945 Mdot
.582 .34946 Mdot
.582 .34947 Mdot
.582 .34948 Mdot
.582 .34949 Mdot
.582 .34951 Mdot
.582 .34955 Mdot
.582 .34958 Mdot
.582 .34961 Mdot
.582 .34963 Mdot
.582 .34966 Mdot
.582 .34971 Mdot
.582 .34972 Mdot
.582 .34976 Mdot
.582 .34977 Mdot
.582 .3498 Mdot
.582 .34987 Mdot
.582 .34988 Mdot
.582 .34989 Mdot
.582 .3499 Mdot
.582 .3499 Mdot
.582 .34991 Mdot
.582 .34993 Mdot
.582 .34993 Mdot
.582 .34995 Mdot
.582 .34996 Mdot
.582 .34998 Mdot
.582 .34998 Mdot
.582 .34998 Mdot
.582 .34998 Mdot
.582 .34999 Mdot
.582 .35 Mdot
.582 .35 Mdot
.582 .35 Mdot
.582 .35002 Mdot
.582 .35002 Mdot
.582 .35004 Mdot
.582 .35006 Mdot
.582 .35007 Mdot
.582 .35009 Mdot
.582 .35011 Mdot
.582 .35013 Mdot
.582 .35014 Mdot
.582 .35017 Mdot
.582 .35022 Mdot
.582 .35026 Mdot
.582 .35027 Mdot
.582 .35028 Mdot
.582 .35028 Mdot
.582 .35028 Mdot
.582 .35028 Mdot
.582 .35028 Mdot
.582 .35028 Mdot
.582 .35029 Mdot
.582 .35029 Mdot
.582 .35029 Mdot
.582 .3503 Mdot
.582 .35032 Mdot
.582 .35034 Mdot
.582 .35036 Mdot
.582 .35037 Mdot
.582 .35037 Mdot
.582 .35037 Mdot
.582 .35038 Mdot
.582 .35039 Mdot
.582 .35039 Mdot
.582 .3504 Mdot
.582 .35041 Mdot
.582 .35041 Mdot
.582 .35041 Mdot
.582 .35042 Mdot
.582 .35042 Mdot
.582 .35043 Mdot
.582 .35044 Mdot
.582 .35045 Mdot
.582 .35046 Mdot
.582 .35047 Mdot
.582 .35047 Mdot
.582 .35047 Mdot
.582 .35047 Mdot
.582 .35048 Mdot
.582 .35048 Mdot
.582 .3505 Mdot
.582 .35053 Mdot
.582 .35056 Mdot
.582 .35058 Mdot
.582 .35059 Mdot
.582 .35061 Mdot
.582 .35061 Mdot
.582 .35062 Mdot
.582 .35062 Mdot
.582 .35062 Mdot
.582 .35063 Mdot
.582 .35063 Mdot
.582 .35063 Mdot
.582 .35063 Mdot
.582 .35064 Mdot
.582 .35065 Mdot
.582 .35067 Mdot
.582 .35068 Mdot
.582 .35068 Mdot
.582 .35073 Mdot
.582 .35076 Mdot
.582 .35078 Mdot
.582 .35081 Mdot
.582 .35083 Mdot
.582 .35087 Mdot
.582 .35089 Mdot
.582 .35091 Mdot
.582 .35092 Mdot
.582 .35092 Mdot
.582 .35094 Mdot
.582 .35094 Mdot
.582 .35098 Mdot
.582 .35099 Mdot
.582 .35099 Mdot
.582 .35102 Mdot
.582 .35104 Mdot
.582 .35107 Mdot
.582 .3511 Mdot
.582 .35111 Mdot
.582 .35111 Mdot
.582 .35114 Mdot
.582 .35114 Mdot
.582 .35114 Mdot
.582 .35116 Mdot
.582 .35118 Mdot
.582 .35118 Mdot
.582 .35118 Mdot
.582 .35119 Mdot
.582 .35122 Mdot
.582 .35122 Mdot
.582 .35124 Mdot
.582 .35128 Mdot
.582 .35128 Mdot
.582 .3513 Mdot
.582 .35133 Mdot
.582 .35133 Mdot
.582 .35134 Mdot
.582 .35136 Mdot
.582 .35137 Mdot
.582 .35139 Mdot
.582 .35152 Mdot
.582 .35156 Mdot
.582 .35159 Mdot
.582 .35159 Mdot
.582 .35161 Mdot
.582 .35161 Mdot
.582 .35166 Mdot
.582 .35168 Mdot
.582 .35173 Mdot
.582 .35177 Mdot
.582 .35182 Mdot
.582 .35182 Mdot
.582 .35183 Mdot
.582 .35185 Mdot
.582 .35185 Mdot
.582 .35186 Mdot
.582 .35191 Mdot
.582 .35192 Mdot
.582 .35195 Mdot
.582 .35197 Mdot
.582 .35204 Mdot
.582 .35204 Mdot
.582 .35205 Mdot
.582 .35205 Mdot
.582 .35205 Mdot
.582 .35209 Mdot
.582 .3521 Mdot
.582 .35211 Mdot
.582 .35211 Mdot
.582 .35212 Mdot
.582 .35213 Mdot
.582 .35214 Mdot
.582 .35215 Mdot
.582 .35215 Mdot
.582 .35216 Mdot
.582 .3522 Mdot
.582 .35222 Mdot
.582 .35226 Mdot
.582 .35226 Mdot
.582 .3523 Mdot
.582 .35231 Mdot
.582 .35233 Mdot
.582 .35236 Mdot
.582 .35239 Mdot
.582 .35239 Mdot
.582 .3524 Mdot
.582 .35242 Mdot
.582 .35243 Mdot
.582 .35249 Mdot
.582 .35255 Mdot
.582 .35263 Mdot
.582 .35276 Mdot
.582 .35277 Mdot
.582 .35277 Mdot
.582 .35283 Mdot
.582 .35288 Mdot
.582 .35289 Mdot
.582 .3529 Mdot
.582 .3529 Mdot
.582 .35294 Mdot
.582 .35295 Mdot
.582 .353 Mdot
.582 .353 Mdot
.582 .353 Mdot
.582 .353 Mdot
.582 .35304 Mdot
.582 .35304 Mdot
.582 .35306 Mdot
.582 .35312 Mdot
.582 .35314 Mdot
.582 .35315 Mdot
.582 .35319 Mdot
.582 .35321 Mdot
.582 .35321 Mdot
.582 .35484 Mdot
.582 .35485 Mdot
.582 .35486 Mdot
.582 .35489 Mdot
.582 .3549 Mdot
.582 .35491 Mdot
.582 .35496 Mdot
.582 .35497 Mdot
.582 .35497 Mdot
.582 .355 Mdot
.582 .355 Mdot
.582 .355 Mdot
.582 .355 Mdot
.582 .35504 Mdot
.582 .35505 Mdot
.582 .35508 Mdot
.582 .35508 Mdot
.582 .35508 Mdot
.582 .35509 Mdot
.582 .35512 Mdot
.582 .35517 Mdot
.582 .35517 Mdot
.582 .35518 Mdot
.582 .35527 Mdot
.582 .35533 Mdot
.582 .35538 Mdot
.582 .35542 Mdot
.582 .35543 Mdot
.582 .35544 Mdot
.582 .35545 Mdot
.582 .35545 Mdot
.582 .35547 Mdot
.582 .3555 Mdot
.582 .35551 Mdot
.582 .35552 Mdot
.582 .35555 Mdot
.582 .35555 Mdot
.582 .35558 Mdot
.582 .35559 Mdot
.582 .35562 Mdot
.582 .35563 Mdot
.582 .35563 Mdot
.582 .35563 Mdot
.582 .35564 Mdot
.582 .35565 Mdot
.582 .35566 Mdot
.582 .35566 Mdot
.582 .35567 Mdot
.582 .35567 Mdot
.582 .35571 Mdot
.582 .35571 Mdot
.582 .35571 Mdot
.582 .35571 Mdot
.582 .35571 Mdot
.582 .35576 Mdot
.582 .35578 Mdot
.582 .3558 Mdot
.582 .3558 Mdot
.582 .35584 Mdot
.582 .35585 Mdot
.582 .35585 Mdot
.582 .35586 Mdot
.582 .35587 Mdot
.582 .35587 Mdot
.582 .35591 Mdot
.582 .35594 Mdot
.582 .35598 Mdot
.582 .35599 Mdot
.582 .35603 Mdot
.582 .35603 Mdot
.582 .35604 Mdot
.582 .35604 Mdot
.582 .35606 Mdot
.582 .3561 Mdot
.582 .35619 Mdot
.582 .3562 Mdot
.582 .35621 Mdot
.582 .35623 Mdot
.582 .35624 Mdot
.582 .35624 Mdot
.582 .35625 Mdot
.582 .35627 Mdot
.582 .35627 Mdot
.582 .3563 Mdot
.582 .35632 Mdot
.582 .35632 Mdot
.582 .35634 Mdot
.582 .35635 Mdot
.582 .35635 Mdot
.582 .35635 Mdot
.582 .35636 Mdot
.582 .35637 Mdot
.582 .35637 Mdot
.582 .35638 Mdot
.582 .3564 Mdot
.582 .3564 Mdot
.582 .3564 Mdot
.582 .35643 Mdot
.582 .35645 Mdot
.582 .35646 Mdot
.582 .35648 Mdot
.582 .35649 Mdot
.582 .3565 Mdot
.582 .35652 Mdot
.582 .35652 Mdot
.582 .35654 Mdot
.582 .35654 Mdot
.582 .35654 Mdot
.582 .35656 Mdot
.582 .35658 Mdot
.582 .35661 Mdot
.582 .35662 Mdot
.582 .35664 Mdot
.582 .35666 Mdot
.582 .35667 Mdot
.582 .35672 Mdot
.582 .35672 Mdot
.582 .35672 Mdot
.582 .35674 Mdot
.582 .35675 Mdot
.582 .35675 Mdot
.582 .35675 Mdot
.582 .35675 Mdot
.582 .35675 Mdot
.582 .35676 Mdot
.582 .35676 Mdot
.582 .35676 Mdot
.582 .35676 Mdot
.582 .35676 Mdot
.582 .35678 Mdot
.582 .35679 Mdot
.582 .35681 Mdot
.582 .35683 Mdot
.582 .35685 Mdot
.582 .35686 Mdot
.582 .35686 Mdot
.582 .35687 Mdot
.582 .35687 Mdot
.582 .35687 Mdot
.582 .35687 Mdot
.582 .35688 Mdot
.582 .35688 Mdot
.582 .35689 Mdot
.582 .3569 Mdot
.582 .3569 Mdot
.582 .35691 Mdot
.582 .35691 Mdot
.582 .35691 Mdot
.582 .35692 Mdot
.582 .35692 Mdot
.582 .35693 Mdot
.582 .35693 Mdot
.582 .35694 Mdot
.582 .35694 Mdot
.582 .35694 Mdot
.582 .35694 Mdot
.582 .35695 Mdot
.582 .35697 Mdot
.582 .35698 Mdot
.582 .35699 Mdot
.582 .357 Mdot
.582 .35701 Mdot
.582 .35701 Mdot
.582 .35701 Mdot
.582 .35701 Mdot
.582 .35701 Mdot
.582 .35701 Mdot
.582 .35701 Mdot
.582 .35701 Mdot
.582 .35701 Mdot
.582 .35702 Mdot
.582 .35705 Mdot
.582 .35709 Mdot
.582 .35711 Mdot
.582 .35712 Mdot
.582 .35713 Mdot
.582 .35715 Mdot
.582 .35717 Mdot
.582 .35717 Mdot
.582 .35718 Mdot
.582 .3572 Mdot
.582 .3572 Mdot
.582 .35721 Mdot
.582 .35721 Mdot
.582 .35722 Mdot
.582 .35722 Mdot
.582 .35723 Mdot
.582 .35723 Mdot
.582 .35723 Mdot
.582 .35723 Mdot
.582 .35725 Mdot
.582 .35725 Mdot
.582 .35727 Mdot
.582 .35727 Mdot
.582 .35728 Mdot
.582 .35729 Mdot
.582 .35729 Mdot
.582 .35729 Mdot
.582 .35731 Mdot
.582 .35731 Mdot
.582 .35737 Mdot
.582 .35738 Mdot
.582 .3574 Mdot
.582 .35742 Mdot
.582 .35743 Mdot
.582 .35747 Mdot
.582 .35749 Mdot
.582 .3575 Mdot
.582 .35752 Mdot
.582 .35755 Mdot
.582 .35758 Mdot
.582 .3576 Mdot
.582 .3576 Mdot
.582 .3576 Mdot
.582 .35761 Mdot
.582 .35762 Mdot
.582 .35762 Mdot
.582 .35763 Mdot
.582 .35764 Mdot
.582 .35765 Mdot
.582 .35766 Mdot
.582 .35769 Mdot
.582 .35771 Mdot
.582 .35771 Mdot
.582 .35772 Mdot
.582 .35776 Mdot
.582 .35778 Mdot
.582 .35782 Mdot
.582 .35786 Mdot
.582 .35787 Mdot
.582 .35787 Mdot
.582 .35789 Mdot
.582 .35791 Mdot
.582 .35792 Mdot
.582 .35792 Mdot
.582 .35792 Mdot
.582 .35794 Mdot
.582 .35794 Mdot
.582 .35796 Mdot
.582 .35796 Mdot
.582 .35796 Mdot
.582 .35796 Mdot
.582 .35798 Mdot
.582 .35798 Mdot
.582 .35798 Mdot
.582 .35801 Mdot
.582 .35802 Mdot
.582 .35802 Mdot
.582 .35804 Mdot
.582 .35805 Mdot
.582 .35805 Mdot
.584 .30139 Mdot
.584 .30142 Mdot
.584 .30145 Mdot
.584 .30145 Mdot
.584 .30147 Mdot
.584 .30148 Mdot
.584 .30148 Mdot
.584 .30149 Mdot
.584 .3015 Mdot
.584 .3015 Mdot
.584 .30151 Mdot
.584 .30152 Mdot
.584 .30155 Mdot
.584 .30156 Mdot
.584 .30158 Mdot
.584 .30159 Mdot
.584 .30159 Mdot
.584 .3016 Mdot
.584 .30161 Mdot
.584 .30162 Mdot
.584 .30165 Mdot
.584 .30165 Mdot
.584 .30169 Mdot
.584 .30169 Mdot
.584 .30171 Mdot
.584 .30172 Mdot
.584 .30175 Mdot
.584 .30178 Mdot
.584 .30178 Mdot
.584 .30178 Mdot
.584 .30179 Mdot
.584 .30179 Mdot
.584 .3018 Mdot
.584 .30181 Mdot
.584 .30182 Mdot
.584 .30183 Mdot
.584 .30183 Mdot
.584 .30183 Mdot
.584 .30185 Mdot
.584 .30187 Mdot
.584 .30187 Mdot
.584 .30189 Mdot
.584 .30189 Mdot
.584 .30189 Mdot
.584 .30191 Mdot
.584 .30197 Mdot
.584 .30203 Mdot
.584 .30204 Mdot
.584 .30206 Mdot
.584 .30207 Mdot
.584 .30207 Mdot
.584 .30207 Mdot
.584 .3021 Mdot
.584 .3021 Mdot
.584 .30212 Mdot
.584 .30212 Mdot
.584 .30214 Mdot
.584 .30215 Mdot
.584 .30216 Mdot
.584 .30217 Mdot
.584 .30217 Mdot
.584 .3022 Mdot
.584 .30221 Mdot
.584 .30224 Mdot
.584 .30225 Mdot
.584 .30225 Mdot
.584 .30227 Mdot
.584 .30228 Mdot
.584 .30228 Mdot
.584 .30228 Mdot
.584 .30231 Mdot
.584 .30234 Mdot
.584 .30234 Mdot
.584 .30236 Mdot
.584 .30237 Mdot
.584 .30238 Mdot
.584 .30241 Mdot
.584 .30242 Mdot
.584 .30243 Mdot
.584 .30243 Mdot
.584 .30244 Mdot
.584 .30245 Mdot
.584 .30248 Mdot
.584 .30249 Mdot
.584 .3025 Mdot
.584 .30252 Mdot
.584 .30252 Mdot
.584 .30254 Mdot
.584 .30255 Mdot
.584 .30261 Mdot
.584 .30261 Mdot
.584 .30262 Mdot
.584 .30262 Mdot
.584 .30266 Mdot
.584 .30269 Mdot
.584 .30274 Mdot
.584 .30286 Mdot
.584 .30292 Mdot
.584 .30296 Mdot
.584 .303 Mdot
.584 .30301 Mdot
.584 .30302 Mdot
.584 .30305 Mdot
.584 .30306 Mdot
.584 .30311 Mdot
.584 .30311 Mdot
.584 .30312 Mdot
.584 .30313 Mdot
.584 .30315 Mdot
.584 .30317 Mdot
.584 .30318 Mdot
.584 .30318 Mdot
.584 .30319 Mdot
.584 .30319 Mdot
.584 .3032 Mdot
.584 .3032 Mdot
.584 .30322 Mdot
.584 .30322 Mdot
.584 .30327 Mdot
.584 .30332 Mdot
.584 .30332 Mdot
.584 .30333 Mdot
.584 .30334 Mdot
.584 .30335 Mdot
.584 .30335 Mdot
.584 .30335 Mdot
.584 .30337 Mdot
.584 .30338 Mdot
.584 .30339 Mdot
.584 .30341 Mdot
.584 .30341 Mdot
.584 .30342 Mdot
.584 .30344 Mdot
.584 .30346 Mdot
.584 .30348 Mdot
.584 .30349 Mdot
.584 .3035 Mdot
.584 .30352 Mdot
.584 .30352 Mdot
.584 .30352 Mdot
.584 .30353 Mdot
.584 .30354 Mdot
.584 .30354 Mdot
.584 .30355 Mdot
.584 .30357 Mdot
.584 .30358 Mdot
.584 .30362 Mdot
.584 .30364 Mdot
.584 .30365 Mdot
.584 .30366 Mdot
.584 .30371 Mdot
.584 .30371 Mdot
.584 .30372 Mdot
.584 .30372 Mdot
.584 .30375 Mdot
.584 .30376 Mdot
.584 .30381 Mdot
.584 .30382 Mdot
.584 .30382 Mdot
.584 .30382 Mdot
.584 .30383 Mdot
.584 .30384 Mdot
.584 .30387 Mdot
.584 .30387 Mdot
.584 .30389 Mdot
.584 .30395 Mdot
.584 .30395 Mdot
.584 .30396 Mdot
.584 .30397 Mdot
.584 .30402 Mdot
.584 .30402 Mdot
.584 .30404 Mdot
.584 .30407 Mdot
.584 .30408 Mdot
.584 .30408 Mdot
.584 .3041 Mdot
.584 .30411 Mdot
.584 .30411 Mdot
.584 .30413 Mdot
.584 .30415 Mdot
.584 .30416 Mdot
.584 .30416 Mdot
.584 .30416 Mdot
.584 .3042 Mdot
.584 .3042 Mdot
.584 .30421 Mdot
.584 .30421 Mdot
.584 .30422 Mdot
.584 .30426 Mdot
.584 .30426 Mdot
.584 .30429 Mdot
.584 .3043 Mdot
.584 .30439 Mdot
.584 .30443 Mdot
.584 .30447 Mdot
.584 .30448 Mdot
.584 .30448 Mdot
.584 .3045 Mdot
.584 .30453 Mdot
.584 .30453 Mdot
.584 .30454 Mdot
.584 .30455 Mdot
.584 .30456 Mdot
.584 .30457 Mdot
.584 .30457 Mdot
.584 .30459 Mdot
.584 .30459 Mdot
.584 .30462 Mdot
.584 .30465 Mdot
.584 .30465 Mdot
.584 .30465 Mdot
.584 .30466 Mdot
.584 .30466 Mdot
.584 .30468 Mdot
.584 .30469 Mdot
.584 .30472 Mdot
.584 .30473 Mdot
.584 .30473 Mdot
.584 .30475 Mdot
.584 .30475 Mdot
.584 .30475 Mdot
.584 .30478 Mdot
.584 .3048 Mdot
.584 .30486 Mdot
.584 .30486 Mdot
.584 .30487 Mdot
.584 .30491 Mdot
.584 .30492 Mdot
.584 .30498 Mdot
.584 .30499 Mdot
.584 .30505 Mdot
.584 .30506 Mdot
.584 .30507 Mdot
.584 .30509 Mdot
.584 .30509 Mdot
.584 .30511 Mdot
.584 .30515 Mdot
.584 .30517 Mdot
.584 .30524 Mdot
.584 .30526 Mdot
.584 .30526 Mdot
.584 .30526 Mdot
.584 .30529 Mdot
.584 .30531 Mdot
.584 .30531 Mdot
.584 .30532 Mdot
.584 .30535 Mdot
.584 .30536 Mdot
.584 .30542 Mdot
.584 .30547 Mdot
.584 .30714 Mdot
.584 .3072 Mdot
.584 .30729 Mdot
.584 .3073 Mdot
.584 .30734 Mdot
.584 .30735 Mdot
.584 .30736 Mdot
.584 .30738 Mdot
.584 .30742 Mdot
.584 .30742 Mdot
.584 .30743 Mdot
.584 .30746 Mdot
.584 .30755 Mdot
.584 .30758 Mdot
.584 .30763 Mdot
.584 .30765 Mdot
.584 .30765 Mdot
.584 .30768 Mdot
.584 .3077 Mdot
.584 .30771 Mdot
.584 .30779 Mdot
.584 .3078 Mdot
.584 .30789 Mdot
.584 .3079 Mdot
.584 .30796 Mdot
.584 .30797 Mdot
.584 .30798 Mdot
.584 .30805 Mdot
.584 .30808 Mdot
.584 .30811 Mdot
.584 .30812 Mdot
.584 .30812 Mdot
.584 .30814 Mdot
.584 .30815 Mdot
.584 .30816 Mdot
.584 .3082 Mdot
.584 .30822 Mdot
.584 .30824 Mdot
.584 .30825 Mdot
.584 .30825 Mdot
.584 .30826 Mdot
.584 .30826 Mdot
.584 .3083 Mdot
.584 .30834 Mdot
.584 .30834 Mdot
.584 .30836 Mdot
.584 .30837 Mdot
.584 .30838 Mdot
.584 .30839 Mdot
.584 .30841 Mdot
.584 .30841 Mdot
.584 .30842 Mdot
.584 .30846 Mdot
.584 .30849 Mdot
.584 .30849 Mdot
.584 .3085 Mdot
.584 .30856 Mdot
.584 .30861 Mdot
.584 .30873 Mdot
.584 .30875 Mdot
.584 .30878 Mdot
.584 .30879 Mdot
.584 .30884 Mdot
.584 .30886 Mdot
.584 .30886 Mdot
.584 .30887 Mdot
.584 .30887 Mdot
.584 .30892 Mdot
.584 .30892 Mdot
.584 .30893 Mdot
.584 .30894 Mdot
.584 .30897 Mdot
.584 .30899 Mdot
.584 .30899 Mdot
.584 .30901 Mdot
.584 .30903 Mdot
.584 .30903 Mdot
.584 .30905 Mdot
.584 .30908 Mdot
.584 .30911 Mdot
.584 .30912 Mdot
.584 .30919 Mdot
.584 .30919 Mdot
.584 .3092 Mdot
.584 .30922 Mdot
.584 .3093 Mdot
.584 .30931 Mdot
.584 .30931 Mdot
.584 .30936 Mdot
.584 .30937 Mdot
.584 .30939 Mdot
.584 .30939 Mdot
.584 .30939 Mdot
.584 .3094 Mdot
.584 .30946 Mdot
.584 .30949 Mdot
.584 .30952 Mdot
.584 .30953 Mdot
.584 .30953 Mdot
.584 .30953 Mdot
.584 .3096 Mdot
.584 .30962 Mdot
.584 .30964 Mdot
.584 .30966 Mdot
.584 .30971 Mdot
.584 .30976 Mdot
.584 .30977 Mdot
.584 .30978 Mdot
.584 .30978 Mdot
.584 .30979 Mdot
.584 .30979 Mdot
.584 .3098 Mdot
.584 .30983 Mdot
.584 .30984 Mdot
.584 .30985 Mdot
.584 .30988 Mdot
.584 .3099 Mdot
.584 .30993 Mdot
.584 .30995 Mdot
.584 .30995 Mdot
.584 .30997 Mdot
.584 .30999 Mdot
.584 .30999 Mdot
.584 .31002 Mdot
.584 .31003 Mdot
.584 .31003 Mdot
.584 .31005 Mdot
.584 .31006 Mdot
.584 .31007 Mdot
.584 .31007 Mdot
.584 .31014 Mdot
.584 .31021 Mdot
.584 .31021 Mdot
.584 .31023 Mdot
.584 .31023 Mdot
.584 .31025 Mdot
.584 .31025 Mdot
.584 .31026 Mdot
.584 .31026 Mdot
.584 .31028 Mdot
.584 .3103 Mdot
.584 .31034 Mdot
.584 .31034 Mdot
.584 .31035 Mdot
.584 .31036 Mdot
.584 .31043 Mdot
.584 .31043 Mdot
.584 .31048 Mdot
.584 .31049 Mdot
.584 .31051 Mdot
.584 .31056 Mdot
.584 .3106 Mdot
.584 .31061 Mdot
.584 .3107 Mdot
.584 .31086 Mdot
.584 .31093 Mdot
.584 .31097 Mdot
.584 .31102 Mdot
.584 .31103 Mdot
.584 .31104 Mdot
.584 .31104 Mdot
.584 .31112 Mdot
.584 .31113 Mdot
.584 .31117 Mdot
.584 .31117 Mdot
.584 .31119 Mdot
.584 .3112 Mdot
.584 .31122 Mdot
.584 .31125 Mdot
.584 .31127 Mdot
.584 .31128 Mdot
.584 .31129 Mdot
.584 .31129 Mdot
.584 .31132 Mdot
.584 .31136 Mdot
.584 .31137 Mdot
.584 .31138 Mdot
.584 .31141 Mdot
.584 .31141 Mdot
.584 .31145 Mdot
.584 .31149 Mdot
.584 .31149 Mdot
.584 .31149 Mdot
.584 .31151 Mdot
.584 .31153 Mdot
.584 .31153 Mdot
.584 .31154 Mdot
.584 .31158 Mdot
.584 .3116 Mdot
.584 .31164 Mdot
.584 .31164 Mdot
.584 .31166 Mdot
.584 .31167 Mdot
.584 .31168 Mdot
.584 .31171 Mdot
.584 .31171 Mdot
.584 .31173 Mdot
.584 .31174 Mdot
.584 .31177 Mdot
.584 .31178 Mdot
.584 .31178 Mdot
.584 .31179 Mdot
.584 .31181 Mdot
.584 .31183 Mdot
.584 .31191 Mdot
.584 .31199 Mdot
.584 .31202 Mdot
.584 .31202 Mdot
.584 .31203 Mdot
.584 .31204 Mdot
.584 .31205 Mdot
.584 .31207 Mdot
.584 .3121 Mdot
.584 .3121 Mdot
.584 .31211 Mdot
.584 .31212 Mdot
.584 .31213 Mdot
.584 .31215 Mdot
.584 .31216 Mdot
.584 .31216 Mdot
.584 .31217 Mdot
.584 .31217 Mdot
.584 .31218 Mdot
.584 .31221 Mdot
.584 .31225 Mdot
.584 .31226 Mdot
.584 .31229 Mdot
.584 .31229 Mdot
.584 .31234 Mdot
.584 .31235 Mdot
.584 .31239 Mdot
.584 .3124 Mdot
.584 .31241 Mdot
.584 .31243 Mdot
.584 .31243 Mdot
.584 .31244 Mdot
.584 .31246 Mdot
.584 .31248 Mdot
.584 .31253 Mdot
.584 .31255 Mdot
.584 .31255 Mdot
.584 .31255 Mdot
.584 .31257 Mdot
.584 .31258 Mdot
.584 .31258 Mdot
.584 .31259 Mdot
.584 .31262 Mdot
.584 .31262 Mdot
.584 .31267 Mdot
.584 .3127 Mdot
.584 .34956 Mdot
.584 .34958 Mdot
.584 .34962 Mdot
.584 .34963 Mdot
.584 .34965 Mdot
.584 .34965 Mdot
.584 .34966 Mdot
.584 .34967 Mdot
.584 .34968 Mdot
.584 .34968 Mdot
.584 .34969 Mdot
.584 .3497 Mdot
.584 .34974 Mdot
.584 .34976 Mdot
.584 .34978 Mdot
.584 .34979 Mdot
.584 .34979 Mdot
.584 .3498 Mdot
.584 .34981 Mdot
.584 .34982 Mdot
.584 .34985 Mdot
.584 .34986 Mdot
.584 .3499 Mdot
.584 .3499 Mdot
.584 .34993 Mdot
.584 .34994 Mdot
.584 .34997 Mdot
.584 .35 Mdot
.584 .35 Mdot
.584 .35001 Mdot
.584 .35002 Mdot
.584 .35002 Mdot
.584 .35003 Mdot
.584 .35004 Mdot
.584 .35005 Mdot
.584 .35006 Mdot
.584 .35006 Mdot
.584 .35007 Mdot
.584 .35009 Mdot
.584 .35011 Mdot
.584 .35012 Mdot
.584 .35013 Mdot
.584 .35014 Mdot
.584 .35014 Mdot
.584 .35016 Mdot
.584 .35023 Mdot
.584 .3503 Mdot
.584 .35031 Mdot
.584 .35033 Mdot
.584 .35034 Mdot
.584 .35034 Mdot
.584 .35035 Mdot
.584 .35038 Mdot
.584 .35038 Mdot
.584 .35041 Mdot
.584 .35041 Mdot
.584 .35042 Mdot
.584 .35043 Mdot
.584 .35045 Mdot
.584 .35046 Mdot
.584 .35047 Mdot
.584 .3505 Mdot
.584 .35051 Mdot
.584 .35055 Mdot
.584 .35055 Mdot
.584 .35055 Mdot
.584 .35058 Mdot
.584 .35059 Mdot
.584 .35059 Mdot
.584 .35059 Mdot
.584 .35062 Mdot
.584 .35066 Mdot
.584 .35066 Mdot
.584 .35069 Mdot
.584 .35069 Mdot
.584 .3507 Mdot
.584 .35074 Mdot
.584 .35076 Mdot
.584 .35076 Mdot
.584 .35077 Mdot
.584 .35078 Mdot
.584 .35079 Mdot
.584 .35082 Mdot
.584 .35084 Mdot
.584 .35085 Mdot
.584 .35087 Mdot
.584 .35087 Mdot
.584 .3509 Mdot
.584 .3509 Mdot
.584 .35097 Mdot
.584 .35098 Mdot
.584 .35098 Mdot
.584 .35099 Mdot
.584 .35104 Mdot
.584 .35107 Mdot
.584 .35113 Mdot
.584 .35127 Mdot
.584 .35134 Mdot
.584 .35135 Mdot
.584 .35139 Mdot
.584 .35143 Mdot
.584 .35145 Mdot
.584 .35145 Mdot
.584 .35149 Mdot
.584 .3515 Mdot
.584 .35156 Mdot
.584 .35156 Mdot
.584 .35157 Mdot
.584 .35158 Mdot
.584 .3516 Mdot
.584 .35163 Mdot
.584 .35164 Mdot
.584 .35164 Mdot
.584 .35165 Mdot
.584 .35165 Mdot
.584 .35167 Mdot
.584 .35167 Mdot
.584 .35168 Mdot
.584 .35169 Mdot
.584 .35175 Mdot
.584 .3518 Mdot
.584 .35181 Mdot
.584 .35181 Mdot
.584 .35182 Mdot
.584 .35184 Mdot
.584 .35184 Mdot
.584 .35185 Mdot
.584 .35187 Mdot
.584 .35187 Mdot
.584 .35189 Mdot
.584 .35191 Mdot
.584 .35191 Mdot
.584 .35192 Mdot
.584 .35195 Mdot
.584 .35197 Mdot
.584 .35199 Mdot
.584 .352 Mdot
.584 .35201 Mdot
.584 .35203 Mdot
.584 .35204 Mdot
.584 .35204 Mdot
.584 .35205 Mdot
.584 .35206 Mdot
.584 .35206 Mdot
.584 .35208 Mdot
.584 .3521 Mdot
.584 .35211 Mdot
.584 .35215 Mdot
.584 .35218 Mdot
.584 .35219 Mdot
.584 .35221 Mdot
.584 .35226 Mdot
.584 .35227 Mdot
.584 .35227 Mdot
.584 .35228 Mdot
.584 .3523 Mdot
.584 .35233 Mdot
.584 .35238 Mdot
.584 .35239 Mdot
.584 .35239 Mdot
.584 .35239 Mdot
.584 .3524 Mdot
.584 .35241 Mdot
.584 .35245 Mdot
.584 .35245 Mdot
.584 .35247 Mdot
.584 .35254 Mdot
.584 .35255 Mdot
.584 .35256 Mdot
.584 .35256 Mdot
.584 .35262 Mdot
.584 .35263 Mdot
.584 .35265 Mdot
.584 .35268 Mdot
.584 .3527 Mdot
.584 .3527 Mdot
.584 .35271 Mdot
.584 .35273 Mdot
.584 .35273 Mdot
.584 .35275 Mdot
.584 .35277 Mdot
.584 .35279 Mdot
.584 .35279 Mdot
.584 .35279 Mdot
.584 .35283 Mdot
.584 .35283 Mdot
.584 .35284 Mdot
.584 .35284 Mdot
.584 .35286 Mdot
.584 .3529 Mdot
.584 .35291 Mdot
.584 .35294 Mdot
.584 .35295 Mdot
.584 .35306 Mdot
.584 .3531 Mdot
.584 .35315 Mdot
.584 .35316 Mdot
.584 .35316 Mdot
.584 .35318 Mdot
.584 .35322 Mdot
.584 .35322 Mdot
.584 .35323 Mdot
.584 .35324 Mdot
.584 .35325 Mdot
.584 .35326 Mdot
.584 .35327 Mdot
.584 .35328 Mdot
.584 .35328 Mdot
.584 .35332 Mdot
.584 .35335 Mdot
.584 .35336 Mdot
.584 .35336 Mdot
.584 .35337 Mdot
.584 .35337 Mdot
.584 .35339 Mdot
.584 .3534 Mdot
.584 .35344 Mdot
.584 .35345 Mdot
.584 .35345 Mdot
.584 .35347 Mdot
.584 .35348 Mdot
.584 .35348 Mdot
.584 .35351 Mdot
.584 .35354 Mdot
.584 .3536 Mdot
.584 .3536 Mdot
.584 .35362 Mdot
.584 .35366 Mdot
.584 .35367 Mdot
.584 .35375 Mdot
.584 .35376 Mdot
.584 .35383 Mdot
.584 .35384 Mdot
.584 .35385 Mdot
.584 .35388 Mdot
.584 .35388 Mdot
.584 .3539 Mdot
.584 .35394 Mdot
.584 .35396 Mdot
.584 .35404 Mdot
.584 .35407 Mdot
.584 .35407 Mdot
.584 .35408 Mdot
.584 .35411 Mdot
.584 .35413 Mdot
.584 .35413 Mdot
.584 .35414 Mdot
.584 .35418 Mdot
.584 .35419 Mdot
.584 .35426 Mdot
.584 .35431 Mdot
.584 .35575 Mdot
.584 .35578 Mdot
.584 .35584 Mdot
.584 .35584 Mdot
.584 .35587 Mdot
.584 .35588 Mdot
.584 .35588 Mdot
.584 .3559 Mdot
.584 .35592 Mdot
.584 .35592 Mdot
.584 .35593 Mdot
.584 .35594 Mdot
.584 .356 Mdot
.584 .35602 Mdot
.584 .35605 Mdot
.584 .35607 Mdot
.584 .35607 Mdot
.584 .35608 Mdot
.584 .3561 Mdot
.584 .3561 Mdot
.584 .35616 Mdot
.584 .35616 Mdot
.584 .35622 Mdot
.584 .35622 Mdot
.584 .35626 Mdot
.584 .35627 Mdot
.584 .35627 Mdot
.584 .35632 Mdot
.584 .35634 Mdot
.584 .35636 Mdot
.584 .35636 Mdot
.584 .35636 Mdot
.584 .35638 Mdot
.584 .35638 Mdot
.584 .35639 Mdot
.584 .35641 Mdot
.584 .35642 Mdot
.584 .35644 Mdot
.584 .35644 Mdot
.584 .35644 Mdot
.584 .35645 Mdot
.584 .35645 Mdot
.584 .35648 Mdot
.584 .3565 Mdot
.584 .3565 Mdot
.584 .35651 Mdot
.584 .35652 Mdot
.584 .35652 Mdot
.584 .35653 Mdot
.584 .35654 Mdot
.584 .35654 Mdot
.584 .35655 Mdot
.584 .35658 Mdot
.584 .35659 Mdot
.584 .35659 Mdot
.584 .3566 Mdot
.584 .35664 Mdot
.584 .35667 Mdot
.584 .35674 Mdot
.584 .35676 Mdot
.584 .35678 Mdot
.584 .35678 Mdot
.584 .35681 Mdot
.584 .35682 Mdot
.584 .35682 Mdot
.584 .35683 Mdot
.584 .35683 Mdot
.584 .35686 Mdot
.584 .35686 Mdot
.584 .35687 Mdot
.584 .35687 Mdot
.584 .35689 Mdot
.584 .35691 Mdot
.584 .35691 Mdot
.584 .35692 Mdot
.584 .35693 Mdot
.584 .35693 Mdot
.584 .35695 Mdot
.584 .35696 Mdot
.584 .35698 Mdot
.584 .35699 Mdot
.584 .35703 Mdot
.584 .35703 Mdot
.584 .35704 Mdot
.584 .35705 Mdot
.584 .3571 Mdot
.584 .35711 Mdot
.584 .35711 Mdot
.584 .35714 Mdot
.584 .35715 Mdot
.584 .35715 Mdot
.584 .35716 Mdot
.584 .35716 Mdot
.584 .35716 Mdot
.584 .3572 Mdot
.584 .35722 Mdot
.584 .35724 Mdot
.584 .35724 Mdot
.584 .35725 Mdot
.584 .35725 Mdot
.584 .35729 Mdot
.584 .3573 Mdot
.584 .35731 Mdot
.584 .35733 Mdot
.584 .35736 Mdot
.584 .35737 Mdot
.584 .35739 Mdot
.584 .3574 Mdot
.584 .3574 Mdot
.584 .3574 Mdot
.584 .35741 Mdot
.584 .35741 Mdot
.584 .35742 Mdot
.584 .35743 Mdot
.584 .35744 Mdot
.584 .35745 Mdot
.584 .35746 Mdot
.584 .35748 Mdot
.584 .3575 Mdot
.584 .35751 Mdot
.584 .35751 Mdot
.584 .35752 Mdot
.584 .35754 Mdot
.584 .35754 Mdot
.584 .35756 Mdot
.584 .35756 Mdot
.584 .35756 Mdot
.584 .35757 Mdot
.584 .35758 Mdot
.584 .35758 Mdot
.584 .35759 Mdot
.584 .35763 Mdot
.584 .35767 Mdot
.584 .35767 Mdot
.584 .35768 Mdot
.584 .35769 Mdot
.584 .3577 Mdot
.584 .3577 Mdot
.584 .3577 Mdot
.584 .35771 Mdot
.584 .35772 Mdot
.584 .35773 Mdot
.584 .35775 Mdot
.584 .35775 Mdot
.584 .35776 Mdot
.584 .35777 Mdot
.584 .35781 Mdot
.584 .35781 Mdot
.584 .35784 Mdot
.584 .35785 Mdot
.584 .35786 Mdot
.584 .35789 Mdot
.584 .35793 Mdot
.584 .35798 Mdot
.584 .35808 Mdot
.584 .35813 Mdot
.584 .35815 Mdot
.584 .35818 Mdot
.584 .35819 Mdot
.584 .35819 Mdot
.584 .35819 Mdot
.584 .35825 Mdot
.584 .35825 Mdot
.584 .35827 Mdot
.584 .35827 Mdot
.584 .35829 Mdot
.584 .35829 Mdot
.584 .3583 Mdot
.584 .35833 Mdot
.584 .35834 Mdot
.584 .35835 Mdot
.584 .35835 Mdot
.584 .35835 Mdot
.584 .35837 Mdot
.584 .35839 Mdot
.584 .3584 Mdot
.584 .35841 Mdot
.584 .35843 Mdot
.584 .35843 Mdot
.584 .35845 Mdot
.584 .35847 Mdot
.584 .35848 Mdot
.584 .35848 Mdot
.584 .35849 Mdot
.584 .3585 Mdot
.584 .3585 Mdot
.584 .35851 Mdot
.584 .35853 Mdot
.584 .35854 Mdot
.584 .35857 Mdot
.584 .35857 Mdot
.584 .35858 Mdot
.584 .35859 Mdot
.584 .3586 Mdot
.584 .35861 Mdot
.584 .35861 Mdot
.584 .35863 Mdot
.584 .35863 Mdot
.584 .35865 Mdot
.584 .35866 Mdot
.584 .35866 Mdot
.584 .35866 Mdot
.584 .35868 Mdot
.584 .35869 Mdot
.584 .35874 Mdot
.584 .35879 Mdot
.584 .35881 Mdot
.584 .35881 Mdot
.584 .35881 Mdot
.584 .35882 Mdot
.584 .35883 Mdot
.584 .35884 Mdot
.584 .35886 Mdot
.584 .35886 Mdot
.584 .35886 Mdot
.584 .35887 Mdot
.584 .35888 Mdot
.584 .35889 Mdot
.584 .35889 Mdot
.584 .3589 Mdot
.584 .3589 Mdot
.584 .3589 Mdot
.584 .35891 Mdot
.584 .35893 Mdot
.584 .35895 Mdot
.584 .35896 Mdot
.584 .35898 Mdot
.584 .35898 Mdot
.584 .35901 Mdot
.584 .35901 Mdot
.584 .35904 Mdot
.584 .35905 Mdot
.584 .35905 Mdot
.584 .35906 Mdot
.584 .35906 Mdot
.584 .35907 Mdot
.584 .35909 Mdot
.584 .3591 Mdot
.584 .35913 Mdot
.584 .35914 Mdot
.584 .35914 Mdot
.584 .35914 Mdot
.584 .35915 Mdot
.584 .35916 Mdot
.584 .35916 Mdot
.584 .35917 Mdot
.584 .35918 Mdot
.584 .35918 Mdot
.584 .35921 Mdot
.584 .35923 Mdot
.586 .30099 Mdot
.586 .30099 Mdot
.586 .301 Mdot
.586 .30101 Mdot
.586 .30102 Mdot
.586 .30106 Mdot
.586 .30107 Mdot
.586 .30107 Mdot
.586 .30108 Mdot
.586 .30109 Mdot
.586 .30111 Mdot
.586 .30115 Mdot
.586 .30116 Mdot
.586 .30116 Mdot
.586 .30117 Mdot
.586 .30121 Mdot
.586 .30122 Mdot
.586 .30128 Mdot
.586 .30133 Mdot
.586 .30133 Mdot
.586 .30135 Mdot
.586 .30136 Mdot
.586 .30136 Mdot
.586 .30136 Mdot
.586 .30136 Mdot
.586 .30137 Mdot
.586 .30138 Mdot
.586 .3014 Mdot
.586 .30146 Mdot
.586 .30147 Mdot
.586 .3015 Mdot
.586 .3015 Mdot
.586 .3015 Mdot
.586 .30152 Mdot
.586 .30152 Mdot
.586 .30153 Mdot
.586 .30155 Mdot
.586 .30156 Mdot
.586 .30158 Mdot
.586 .30159 Mdot
.586 .30163 Mdot
.586 .30163 Mdot
.586 .30165 Mdot
.586 .30166 Mdot
.586 .30167 Mdot
.586 .30168 Mdot
.586 .30169 Mdot
.586 .30171 Mdot
.586 .30172 Mdot
.586 .30175 Mdot
.586 .30176 Mdot
.586 .30177 Mdot
.586 .3018 Mdot
.586 .3018 Mdot
.586 .30181 Mdot
.586 .30185 Mdot
.586 .30186 Mdot
.586 .30187 Mdot
.586 .30188 Mdot
.586 .30189 Mdot
.586 .30193 Mdot
.586 .30194 Mdot
.586 .30197 Mdot
.586 .30197 Mdot
.586 .30198 Mdot
.586 .30203 Mdot
.586 .30203 Mdot
.586 .30205 Mdot
.586 .30206 Mdot
.586 .30208 Mdot
.586 .30208 Mdot
.586 .30208 Mdot
.586 .3021 Mdot
.586 .30212 Mdot
.586 .30214 Mdot
.586 .30217 Mdot
.586 .30221 Mdot
.586 .30223 Mdot
.586 .30224 Mdot
.586 .30227 Mdot
.586 .30229 Mdot
.586 .3023 Mdot
.586 .30231 Mdot
.586 .30232 Mdot
.586 .30234 Mdot
.586 .30237 Mdot
.586 .30238 Mdot
.586 .30239 Mdot
.586 .30239 Mdot
.586 .3024 Mdot
.586 .30241 Mdot
.586 .30246 Mdot
.586 .30246 Mdot
.586 .30248 Mdot
.586 .30248 Mdot
.586 .30251 Mdot
.586 .30253 Mdot
.586 .30254 Mdot
.586 .30258 Mdot
.586 .30259 Mdot
.586 .30259 Mdot
.586 .3026 Mdot
.586 .30264 Mdot
.586 .30264 Mdot
.586 .30267 Mdot
.586 .30267 Mdot
.586 .30269 Mdot
.586 .30273 Mdot
.586 .30275 Mdot
.586 .30276 Mdot
.586 .30276 Mdot
.586 .30277 Mdot
.586 .30277 Mdot
.586 .30278 Mdot
.586 .30278 Mdot
.586 .30281 Mdot
.586 .30283 Mdot
.586 .30286 Mdot
.586 .30288 Mdot
.586 .3029 Mdot
.586 .30292 Mdot
.586 .30295 Mdot
.586 .30295 Mdot
.586 .30296 Mdot
.586 .30297 Mdot
.586 .30299 Mdot
.586 .303 Mdot
.586 .30304 Mdot
.586 .30305 Mdot
.586 .30305 Mdot
.586 .30306 Mdot
.586 .30306 Mdot
.586 .30306 Mdot
.586 .30311 Mdot
.586 .30315 Mdot
.586 .30318 Mdot
.586 .3032 Mdot
.586 .30321 Mdot
.586 .30324 Mdot
.586 .30325 Mdot
.586 .30327 Mdot
.586 .30328 Mdot
.586 .30329 Mdot
.586 .30332 Mdot
.586 .30336 Mdot
.586 .30336 Mdot
.586 .30336 Mdot
.586 .30337 Mdot
.586 .3034 Mdot
.586 .3034 Mdot
.586 .3034 Mdot
.586 .30345 Mdot
.586 .30345 Mdot
.586 .30347 Mdot
.586 .30353 Mdot
.586 .30354 Mdot
.586 .30355 Mdot
.586 .30355 Mdot
.586 .30355 Mdot
.586 .30355 Mdot
.586 .30355 Mdot
.586 .30356 Mdot
.586 .3036 Mdot
.586 .30361 Mdot
.586 .30364 Mdot
.586 .30366 Mdot
.586 .30366 Mdot
.586 .30367 Mdot
.586 .3037 Mdot
.586 .30371 Mdot
.586 .30372 Mdot
.586 .30376 Mdot
.586 .30376 Mdot
.586 .30378 Mdot
.586 .30379 Mdot
.586 .30382 Mdot
.586 .30382 Mdot
.586 .30383 Mdot
.586 .30386 Mdot
.586 .30387 Mdot
.586 .30388 Mdot
.586 .30393 Mdot
.586 .30396 Mdot
.586 .30398 Mdot
.586 .30403 Mdot
.586 .30405 Mdot
.586 .30406 Mdot
.586 .30407 Mdot
.586 .3041 Mdot
.586 .3041 Mdot
.586 .30413 Mdot
.586 .30414 Mdot
.586 .30417 Mdot
.586 .3042 Mdot
.586 .30421 Mdot
.586 .30424 Mdot
.586 .30425 Mdot
.586 .30425 Mdot
.586 .30428 Mdot
.586 .30429 Mdot
.586 .3043 Mdot
.586 .30433 Mdot
.586 .30435 Mdot
.586 .3044 Mdot
.586 .30441 Mdot
.586 .30442 Mdot
.586 .30444 Mdot
.586 .30445 Mdot
.586 .30445 Mdot
.586 .30445 Mdot
.586 .3045 Mdot
.586 .30453 Mdot
.586 .30453 Mdot
.586 .30455 Mdot
.586 .30457 Mdot
.586 .30458 Mdot
.586 .30461 Mdot
.586 .30463 Mdot
.586 .30467 Mdot
.586 .3047 Mdot
.586 .30471 Mdot
.586 .30471 Mdot
.586 .30471 Mdot
.586 .30471 Mdot
.586 .30474 Mdot
.586 .30477 Mdot
.586 .30477 Mdot
.586 .30477 Mdot
.586 .3048 Mdot
.586 .30484 Mdot
.586 .30485 Mdot
.586 .30485 Mdot
.586 .30486 Mdot
.586 .30498 Mdot
.586 .30499 Mdot
.586 .30508 Mdot
.586 .30508 Mdot
.586 .30508 Mdot
.586 .3051 Mdot
.586 .30519 Mdot
.586 .30523 Mdot
.586 .30524 Mdot
.586 .30525 Mdot
.586 .30525 Mdot
.586 .30527 Mdot
.586 .30536 Mdot
.586 .30537 Mdot
.586 .30539 Mdot
.586 .3054 Mdot
.586 .3054 Mdot
.586 .30687 Mdot
.586 .30687 Mdot
.586 .30688 Mdot
.586 .30691 Mdot
.586 .30693 Mdot
.586 .30704 Mdot
.586 .30707 Mdot
.586 .30708 Mdot
.586 .30709 Mdot
.586 .30711 Mdot
.586 .30716 Mdot
.586 .30728 Mdot
.586 .30731 Mdot
.586 .30731 Mdot
.586 .30731 Mdot
.586 .30744 Mdot
.586 .30745 Mdot
.586 .30761 Mdot
.586 .30762 Mdot
.586 .30762 Mdot
.586 .30765 Mdot
.586 .3077 Mdot
.586 .30773 Mdot
.586 .30773 Mdot
.586 .30774 Mdot
.586 .30778 Mdot
.586 .30782 Mdot
.586 .30782 Mdot
.586 .30782 Mdot
.586 .30782 Mdot
.586 .30783 Mdot
.586 .30787 Mdot
.586 .30793 Mdot
.586 .30795 Mdot
.586 .308 Mdot
.586 .30801 Mdot
.586 .30804 Mdot
.586 .30806 Mdot
.586 .30807 Mdot
.586 .30811 Mdot
.586 .30817 Mdot
.586 .30817 Mdot
.586 .30818 Mdot
.586 .30819 Mdot
.586 .30822 Mdot
.586 .30824 Mdot
.586 .30824 Mdot
.586 .30831 Mdot
.586 .30834 Mdot
.586 .30838 Mdot
.586 .3084 Mdot
.586 .3084 Mdot
.586 .30845 Mdot
.586 .30846 Mdot
.586 .30846 Mdot
.586 .30851 Mdot
.586 .30852 Mdot
.586 .30856 Mdot
.586 .3086 Mdot
.586 .30861 Mdot
.586 .30866 Mdot
.586 .30866 Mdot
.586 .3087 Mdot
.586 .30871 Mdot
.586 .30872 Mdot
.586 .30875 Mdot
.586 .30882 Mdot
.586 .30884 Mdot
.586 .30889 Mdot
.586 .30896 Mdot
.586 .30897 Mdot
.586 .30899 Mdot
.586 .30902 Mdot
.586 .30904 Mdot
.586 .30905 Mdot
.586 .30908 Mdot
.586 .30909 Mdot
.586 .30912 Mdot
.586 .30913 Mdot
.586 .30918 Mdot
.586 .30919 Mdot
.586 .3092 Mdot
.586 .30925 Mdot
.586 .30925 Mdot
.586 .30927 Mdot
.586 .30929 Mdot
.586 .30933 Mdot
.586 .30934 Mdot
.586 .3094 Mdot
.586 .30941 Mdot
.586 .30941 Mdot
.586 .30941 Mdot
.586 .30941 Mdot
.586 .30941 Mdot
.586 .30942 Mdot
.586 .30944 Mdot
.586 .30952 Mdot
.586 .30955 Mdot
.586 .30955 Mdot
.586 .30962 Mdot
.586 .30962 Mdot
.586 .30962 Mdot
.586 .30966 Mdot
.586 .30967 Mdot
.586 .30968 Mdot
.586 .30968 Mdot
.586 .30973 Mdot
.586 .30976 Mdot
.586 .30978 Mdot
.586 .3098 Mdot
.586 .30983 Mdot
.586 .30984 Mdot
.586 .30988 Mdot
.586 .30992 Mdot
.586 .30996 Mdot
.586 .31001 Mdot
.586 .31008 Mdot
.586 .31008 Mdot
.586 .31009 Mdot
.586 .31009 Mdot
.586 .3101 Mdot
.586 .31012 Mdot
.586 .31017 Mdot
.586 .31018 Mdot
.586 .3102 Mdot
.586 .31022 Mdot
.586 .31023 Mdot
.586 .31024 Mdot
.586 .31028 Mdot
.586 .3103 Mdot
.586 .31034 Mdot
.586 .31036 Mdot
.586 .3104 Mdot
.586 .31043 Mdot
.586 .31047 Mdot
.586 .31047 Mdot
.586 .31049 Mdot
.586 .31049 Mdot
.586 .3105 Mdot
.586 .3105 Mdot
.586 .31052 Mdot
.586 .31054 Mdot
.586 .3106 Mdot
.586 .31062 Mdot
.586 .31062 Mdot
.586 .31066 Mdot
.586 .31066 Mdot
.586 .31071 Mdot
.586 .31073 Mdot
.586 .31073 Mdot
.586 .31074 Mdot
.586 .31078 Mdot
.586 .3108 Mdot
.586 .31082 Mdot
.586 .31084 Mdot
.586 .31088 Mdot
.586 .31088 Mdot
.586 .31091 Mdot
.586 .31091 Mdot
.586 .31098 Mdot
.586 .311 Mdot
.586 .31101 Mdot
.586 .31101 Mdot
.586 .31102 Mdot
.586 .31104 Mdot
.586 .31107 Mdot
.586 .3111 Mdot
.586 .31111 Mdot
.586 .31114 Mdot
.586 .31114 Mdot
.586 .31117 Mdot
.586 .31121 Mdot
.586 .31122 Mdot
.586 .31126 Mdot
.586 .3113 Mdot
.586 .31135 Mdot
.586 .31137 Mdot
.586 .31141 Mdot
.586 .31143 Mdot
.586 .31143 Mdot
.586 .31144 Mdot
.586 .31146 Mdot
.586 .31147 Mdot
.586 .3115 Mdot
.586 .3115 Mdot
.586 .31158 Mdot
.586 .31158 Mdot
.586 .31158 Mdot
.586 .31162 Mdot
.586 .31164 Mdot
.586 .31169 Mdot
.586 .3117 Mdot
.586 .31172 Mdot
.586 .31173 Mdot
.586 .31175 Mdot
.586 .3118 Mdot
.586 .31181 Mdot
.586 .31181 Mdot
.586 .31185 Mdot
.586 .31188 Mdot
.586 .31189 Mdot
.586 .31193 Mdot
.586 .31195 Mdot
.586 .31197 Mdot
.586 .31197 Mdot
.586 .312 Mdot
.586 .31201 Mdot
.586 .31203 Mdot
.586 .31205 Mdot
.586 .31205 Mdot
.586 .31211 Mdot
.586 .31212 Mdot
.586 .31214 Mdot
.586 .31216 Mdot
.586 .31219 Mdot
.586 .3122 Mdot
.586 .31221 Mdot
.586 .31222 Mdot
.586 .31223 Mdot
.586 .31223 Mdot
.586 .31227 Mdot
.586 .31229 Mdot
.586 .31236 Mdot
.586 .31239 Mdot
.586 .31241 Mdot
.586 .31242 Mdot
.586 .31242 Mdot
.586 .31242 Mdot
.586 .31242 Mdot
.586 .31244 Mdot
.586 .31246 Mdot
.586 .31246 Mdot
.586 .31253 Mdot
.586 .31261 Mdot
.586 .31262 Mdot
.586 .31269 Mdot
.586 .31269 Mdot
.586 .31269 Mdot
.586 .31271 Mdot
.586 .31277 Mdot
.586 .3128 Mdot
.586 .31281 Mdot
.586 .31281 Mdot
.586 .31282 Mdot
.586 .31283 Mdot
.586 .31289 Mdot
.586 .3129 Mdot
.586 .31292 Mdot
.586 .31292 Mdot
.586 .31292 Mdot
.586 .35023 Mdot
.586 .35023 Mdot
.586 .35024 Mdot
.586 .35025 Mdot
.586 .35026 Mdot
.586 .35031 Mdot
.586 .35033 Mdot
.586 .35033 Mdot
.586 .35033 Mdot
.586 .35034 Mdot
.586 .35037 Mdot
.586 .35042 Mdot
.586 .35043 Mdot
.586 .35043 Mdot
.586 .35043 Mdot
.586 .35049 Mdot
.586 .3505 Mdot
.586 .35057 Mdot
.586 .35063 Mdot
.586 .35063 Mdot
.586 .35065 Mdot
.586 .35066 Mdot
.586 .35066 Mdot
.586 .35066 Mdot
.586 .35067 Mdot
.586 .35067 Mdot
.586 .35069 Mdot
.586 .35071 Mdot
.586 .35077 Mdot
.586 .35079 Mdot
.586 .35082 Mdot
.586 .35083 Mdot
.586 .35083 Mdot
.586 .35085 Mdot
.586 .35085 Mdot
.586 .35086 Mdot
.586 .35088 Mdot
.586 .3509 Mdot
.586 .35092 Mdot
.586 .35093 Mdot
.586 .35098 Mdot
.586 .35098 Mdot
.586 .351 Mdot
.586 .35101 Mdot
.586 .35102 Mdot
.586 .35104 Mdot
.586 .35105 Mdot
.586 .35107 Mdot
.586 .35108 Mdot
.586 .35112 Mdot
.586 .35113 Mdot
.586 .35115 Mdot
.586 .35118 Mdot
.586 .35118 Mdot
.586 .35119 Mdot
.586 .35124 Mdot
.586 .35125 Mdot
.586 .35126 Mdot
.586 .35128 Mdot
.586 .35129 Mdot
.586 .35133 Mdot
.586 .35135 Mdot
.586 .35138 Mdot
.586 .35138 Mdot
.586 .35138 Mdot
.586 .35145 Mdot
.586 .35145 Mdot
.586 .35148 Mdot
.586 .35148 Mdot
.586 .3515 Mdot
.586 .3515 Mdot
.586 .3515 Mdot
.586 .35153 Mdot
.586 .35156 Mdot
.586 .35158 Mdot
.586 .35162 Mdot
.586 .35166 Mdot
.586 .35169 Mdot
.586 .35169 Mdot
.586 .35173 Mdot
.586 .35176 Mdot
.586 .35176 Mdot
.586 .35178 Mdot
.586 .35179 Mdot
.586 .35181 Mdot
.586 .35184 Mdot
.586 .35186 Mdot
.586 .35187 Mdot
.586 .35187 Mdot
.586 .35188 Mdot
.586 .35189 Mdot
.586 .35195 Mdot
.586 .35195 Mdot
.586 .35198 Mdot
.586 .35198 Mdot
.586 .35201 Mdot
.586 .35203 Mdot
.586 .35205 Mdot
.586 .35206 Mdot
.586 .35209 Mdot
.586 .3521 Mdot
.586 .35211 Mdot
.586 .35212 Mdot
.586 .35216 Mdot
.586 .35217 Mdot
.586 .3522 Mdot
.586 .3522 Mdot
.586 .35222 Mdot
.586 .35227 Mdot
.586 .35229 Mdot
.586 .3523 Mdot
.586 .3523 Mdot
.586 .35231 Mdot
.586 .35231 Mdot
.586 .35233 Mdot
.586 .35233 Mdot
.586 .35236 Mdot
.586 .35239 Mdot
.586 .35242 Mdot
.586 .35244 Mdot
.586 .35247 Mdot
.586 .35249 Mdot
.586 .35252 Mdot
.586 .35253 Mdot
.586 .35254 Mdot
.586 .35255 Mdot
.586 .35258 Mdot
.586 .35258 Mdot
.586 .35263 Mdot
.586 .35264 Mdot
.586 .35265 Mdot
.586 .35265 Mdot
.586 .35266 Mdot
.586 .35266 Mdot
.586 .35272 Mdot
.586 .35276 Mdot
.586 .35279 Mdot
.586 .35282 Mdot
.586 .35283 Mdot
.586 .35287 Mdot
.586 .35287 Mdot
.586 .3529 Mdot
.586 .35291 Mdot
.586 .35293 Mdot
.586 .35296 Mdot
.586 .353 Mdot
.586 .353 Mdot
.586 .35301 Mdot
.586 .35302 Mdot
.586 .35305 Mdot
.586 .35305 Mdot
.586 .35306 Mdot
.586 .35311 Mdot
.586 .35311 Mdot
.586 .35314 Mdot
.586 .35321 Mdot
.586 .35322 Mdot
.586 .35323 Mdot
.586 .35323 Mdot
.586 .35323 Mdot
.586 .35323 Mdot
.586 .35323 Mdot
.586 .35324 Mdot
.586 .35329 Mdot
.586 .3533 Mdot
.586 .35333 Mdot
.586 .35335 Mdot
.586 .35336 Mdot
.586 .35337 Mdot
.586 .35341 Mdot
.586 .35342 Mdot
.586 .35343 Mdot
.586 .35347 Mdot
.586 .35348 Mdot
.586 .3535 Mdot
.586 .35351 Mdot
.586 .35354 Mdot
.586 .35354 Mdot
.586 .35356 Mdot
.586 .35359 Mdot
.586 .35361 Mdot
.586 .35361 Mdot
.586 .35368 Mdot
.586 .35371 Mdot
.586 .35373 Mdot
.586 .3538 Mdot
.586 .35382 Mdot
.586 .35383 Mdot
.586 .35384 Mdot
.586 .35387 Mdot
.586 .35387 Mdot
.586 .35391 Mdot
.586 .35393 Mdot
.586 .35395 Mdot
.586 .35399 Mdot
.586 .354 Mdot
.586 .35404 Mdot
.586 .35405 Mdot
.586 .35405 Mdot
.586 .35409 Mdot
.586 .3541 Mdot
.586 .35411 Mdot
.586 .35415 Mdot
.586 .35417 Mdot
.586 .35423 Mdot
.586 .35423 Mdot
.586 .35425 Mdot
.586 .35427 Mdot
.586 .35428 Mdot
.586 .35429 Mdot
.586 .35429 Mdot
.586 .35434 Mdot
.586 .35437 Mdot
.586 .35438 Mdot
.586 .3544 Mdot
.586 .35442 Mdot
.586 .35443 Mdot
.586 .35448 Mdot
.586 .3545 Mdot
.586 .35454 Mdot
.586 .35458 Mdot
.586 .35459 Mdot
.586 .35459 Mdot
.586 .35459 Mdot
.586 .35459 Mdot
.586 .35462 Mdot
.586 .35466 Mdot
.586 .35466 Mdot
.586 .35466 Mdot
.586 .35469 Mdot
.586 .35474 Mdot
.586 .35476 Mdot
.586 .35476 Mdot
.586 .35477 Mdot
.586 .3549 Mdot
.586 .35491 Mdot
.586 .35502 Mdot
.586 .35502 Mdot
.586 .35503 Mdot
.586 .35505 Mdot
.586 .35515 Mdot
.586 .3552 Mdot
.586 .35521 Mdot
.586 .35522 Mdot
.586 .35523 Mdot
.586 .35525 Mdot
.586 .35535 Mdot
.586 .35536 Mdot
.586 .35539 Mdot
.586 .3554 Mdot
.586 .3554 Mdot
.586 .35665 Mdot
.586 .35665 Mdot
.586 .35666 Mdot
.586 .35668 Mdot
.586 .35669 Mdot
.586 .35676 Mdot
.586 .35678 Mdot
.586 .35678 Mdot
.586 .35679 Mdot
.586 .3568 Mdot
.586 .35683 Mdot
.586 .35691 Mdot
.586 .35692 Mdot
.586 .35693 Mdot
.586 .35693 Mdot
.586 .35701 Mdot
.586 .35701 Mdot
.586 .35711 Mdot
.586 .35712 Mdot
.586 .35712 Mdot
.586 .35714 Mdot
.586 .35717 Mdot
.586 .35719 Mdot
.586 .35719 Mdot
.586 .35719 Mdot
.586 .35722 Mdot
.586 .35724 Mdot
.586 .35724 Mdot
.586 .35724 Mdot
.586 .35724 Mdot
.586 .35725 Mdot
.586 .35728 Mdot
.586 .35731 Mdot
.586 .35732 Mdot
.586 .35736 Mdot
.586 .35736 Mdot
.586 .35738 Mdot
.586 .35739 Mdot
.586 .3574 Mdot
.586 .35742 Mdot
.586 .35746 Mdot
.586 .35746 Mdot
.586 .35747 Mdot
.586 .35747 Mdot
.586 .35749 Mdot
.586 .3575 Mdot
.586 .35751 Mdot
.586 .35755 Mdot
.586 .35756 Mdot
.586 .35759 Mdot
.586 .3576 Mdot
.586 .3576 Mdot
.586 .35763 Mdot
.586 .35764 Mdot
.586 .35764 Mdot
.586 .35767 Mdot
.586 .35768 Mdot
.586 .3577 Mdot
.586 .35772 Mdot
.586 .35774 Mdot
.586 .35776 Mdot
.586 .35777 Mdot
.586 .35779 Mdot
.586 .3578 Mdot
.586 .3578 Mdot
.586 .35782 Mdot
.586 .35786 Mdot
.586 .35788 Mdot
.586 .35791 Mdot
.586 .35795 Mdot
.586 .35796 Mdot
.586 .35797 Mdot
.586 .35799 Mdot
.586 .358 Mdot
.586 .358 Mdot
.586 .35803 Mdot
.586 .35803 Mdot
.586 .35805 Mdot
.586 .35806 Mdot
.586 .35808 Mdot
.586 .3581 Mdot
.586 .3581 Mdot
.586 .35813 Mdot
.586 .35813 Mdot
.586 .35814 Mdot
.586 .35816 Mdot
.586 .35818 Mdot
.586 .35819 Mdot
.586 .35822 Mdot
.586 .35823 Mdot
.586 .35823 Mdot
.586 .35823 Mdot
.586 .35823 Mdot
.586 .35823 Mdot
.586 .35824 Mdot
.586 .35825 Mdot
.586 .3583 Mdot
.586 .35832 Mdot
.586 .35832 Mdot
.586 .35836 Mdot
.586 .35836 Mdot
.586 .35836 Mdot
.586 .35839 Mdot
.586 .35839 Mdot
.586 .3584 Mdot
.586 .3584 Mdot
.586 .35843 Mdot
.586 .35845 Mdot
.586 .35846 Mdot
.586 .35847 Mdot
.586 .35849 Mdot
.586 .3585 Mdot
.586 .35852 Mdot
.586 .35853 Mdot
.586 .35855 Mdot
.586 .35857 Mdot
.586 .3586 Mdot
.586 .35865 Mdot
.586 .35865 Mdot
.586 .35865 Mdot
.586 .35866 Mdot
.586 .35866 Mdot
.586 .35867 Mdot
.586 .35871 Mdot
.586 .35871 Mdot
.586 .35872 Mdot
.586 .35873 Mdot
.586 .35874 Mdot
.586 .35875 Mdot
.586 .35877 Mdot
.586 .35879 Mdot
.586 .35881 Mdot
.586 .35882 Mdot
.586 .35884 Mdot
.586 .35886 Mdot
.586 .35889 Mdot
.586 .35889 Mdot
.586 .3589 Mdot
.586 .3589 Mdot
.586 .35891 Mdot
.586 .35891 Mdot
.586 .35892 Mdot
.586 .35893 Mdot
.586 .35897 Mdot
.586 .35898 Mdot
.586 .35898 Mdot
.586 .35901 Mdot
.586 .35901 Mdot
.586 .35904 Mdot
.586 .35905 Mdot
.586 .35905 Mdot
.586 .35906 Mdot
.586 .35909 Mdot
.586 .3591 Mdot
.586 .35912 Mdot
.586 .35914 Mdot
.586 .35914 Mdot
.586 .35916 Mdot
.586 .35916 Mdot
.586 .3592 Mdot
.586 .35922 Mdot
.586 .35922 Mdot
.586 .35922 Mdot
.586 .35923 Mdot
.586 .35924 Mdot
.586 .35926 Mdot
.586 .35928 Mdot
.586 .35929 Mdot
.586 .3593 Mdot
.586 .3593 Mdot
.586 .35932 Mdot
.586 .35935 Mdot
.586 .35935 Mdot
.586 .35938 Mdot
.586 .35941 Mdot
.586 .35944 Mdot
.586 .35945 Mdot
.586 .35947 Mdot
.586 .35949 Mdot
.586 .35949 Mdot
.586 .35949 Mdot
.586 .35951 Mdot
.586 .35951 Mdot
.586 .35953 Mdot
.586 .35953 Mdot
.586 .35958 Mdot
.586 .35958 Mdot
.586 .35958 Mdot
.586 .3596 Mdot
.586 .35961 Mdot
.586 .35964 Mdot
.586 .35965 Mdot
.586 .35967 Mdot
.586 .35967 Mdot
.586 .35968 Mdot
.586 .35971 Mdot
.586 .35972 Mdot
.586 .35972 Mdot
.586 .35975 Mdot
.586 .35976 Mdot
.586 .35977 Mdot
.586 .35979 Mdot
.586 .35981 Mdot
.586 .35982 Mdot
.586 .35982 Mdot
.586 .35984 Mdot
.586 .35984 Mdot
.586 .35985 Mdot
.586 .35987 Mdot
.586 .35987 Mdot
.586 .35991 Mdot
.586 .35992 Mdot
.586 .35993 Mdot
.586 .35994 Mdot
.586 .35996 Mdot
.586 .35996 Mdot
.586 .35997 Mdot
.586 .35998 Mdot
.586 .35998 Mdot
.586 .35998 Mdot
.586 .36 Mdot
.586 .36002 Mdot
.586 .36006 Mdot
.586 .36008 Mdot
.586 .3601 Mdot
.586 .3601 Mdot
.586 .3601 Mdot
.586 .3601 Mdot
.586 .3601 Mdot
.586 .36011 Mdot
.586 .36013 Mdot
.586 .36013 Mdot
.586 .36017 Mdot
.586 .36022 Mdot
.586 .36022 Mdot
.586 .36027 Mdot
.586 .36027 Mdot
.586 .36027 Mdot
.586 .36028 Mdot
.586 .36032 Mdot
.586 .36033 Mdot
.586 .36034 Mdot
.586 .36034 Mdot
.586 .36035 Mdot
.586 .36036 Mdot
.586 .36039 Mdot
.586 .3604 Mdot
.586 .36041 Mdot
.586 .36041 Mdot
.586 .36041 Mdot
.588 .30059 Mdot
.588 .30061 Mdot
.588 .30064 Mdot
.588 .30064 Mdot
.588 .30064 Mdot
.588 .30067 Mdot
.588 .30068 Mdot
.588 .3007 Mdot
.588 .30073 Mdot
.588 .30073 Mdot
.588 .30074 Mdot
.588 .30077 Mdot
.588 .30079 Mdot
.588 .3008 Mdot
.588 .30083 Mdot
.588 .30085 Mdot
.588 .30087 Mdot
.588 .30089 Mdot
.588 .30091 Mdot
.588 .30095 Mdot
.588 .301 Mdot
.588 .30101 Mdot
.588 .30103 Mdot
.588 .30105 Mdot
.588 .30106 Mdot
.588 .3011 Mdot
.588 .30116 Mdot
.588 .30117 Mdot
.588 .30119 Mdot
.588 .30121 Mdot
.588 .30122 Mdot
.588 .30122 Mdot
.588 .30124 Mdot
.588 .30125 Mdot
.588 .30128 Mdot
.588 .30128 Mdot
.588 .3013 Mdot
.588 .30132 Mdot
.588 .30135 Mdot
.588 .30135 Mdot
.588 .30136 Mdot
.588 .30137 Mdot
.588 .30137 Mdot
.588 .30138 Mdot
.588 .30138 Mdot
.588 .30138 Mdot
.588 .30139 Mdot
.588 .3014 Mdot
.588 .30141 Mdot
.588 .30145 Mdot
.588 .30147 Mdot
.588 .30148 Mdot
.588 .3015 Mdot
.588 .30151 Mdot
.588 .30152 Mdot
.588 .30154 Mdot
.588 .30154 Mdot
.588 .30155 Mdot
.588 .30158 Mdot
.588 .30159 Mdot
.588 .3016 Mdot
.588 .30164 Mdot
.588 .30167 Mdot
.588 .30169 Mdot
.588 .3017 Mdot
.588 .30173 Mdot
.588 .30174 Mdot
.588 .30174 Mdot
.588 .30175 Mdot
.588 .30177 Mdot
.588 .3018 Mdot
.588 .3018 Mdot
.588 .30183 Mdot
.588 .30187 Mdot
.588 .3019 Mdot
.588 .30191 Mdot
.588 .30195 Mdot
.588 .30195 Mdot
.588 .30196 Mdot
.588 .30196 Mdot
.588 .30197 Mdot
.588 .30197 Mdot
.588 .30199 Mdot
.588 .30199 Mdot
.588 .30199 Mdot
.588 .30199 Mdot
.588 .302 Mdot
.588 .30202 Mdot
.588 .30203 Mdot
.588 .30207 Mdot
.588 .30208 Mdot
.588 .30209 Mdot
.588 .3021 Mdot
.588 .30211 Mdot
.588 .30215 Mdot
.588 .30216 Mdot
.588 .30219 Mdot
.588 .3022 Mdot
.588 .30223 Mdot
.588 .30226 Mdot
.588 .30228 Mdot
.588 .30228 Mdot
.588 .30229 Mdot
.588 .30234 Mdot
.588 .30234 Mdot
.588 .30235 Mdot
.588 .30236 Mdot
.588 .30244 Mdot
.588 .30244 Mdot
.588 .30245 Mdot
.588 .30247 Mdot
.588 .30247 Mdot
.588 .30249 Mdot
.588 .3025 Mdot
.588 .30251 Mdot
.588 .30255 Mdot
.588 .30256 Mdot
.588 .30258 Mdot
.588 .30258 Mdot
.588 .3026 Mdot
.588 .30261 Mdot
.588 .30265 Mdot
.588 .30266 Mdot
.588 .30266 Mdot
.588 .30266 Mdot
.588 .30267 Mdot
.588 .30267 Mdot
.588 .30268 Mdot
.588 .30269 Mdot
.588 .3027 Mdot
.588 .30271 Mdot
.588 .30271 Mdot
.588 .30273 Mdot
.588 .30274 Mdot
.588 .30275 Mdot
.588 .30276 Mdot
.588 .30281 Mdot
.588 .30283 Mdot
.588 .30288 Mdot
.588 .30291 Mdot
.588 .30294 Mdot
.588 .30298 Mdot
.588 .303 Mdot
.588 .303 Mdot
.588 .30302 Mdot
.588 .30303 Mdot
.588 .30307 Mdot
.588 .30312 Mdot
.588 .30313 Mdot
.588 .30313 Mdot
.588 .30313 Mdot
.588 .30315 Mdot
.588 .30318 Mdot
.588 .30321 Mdot
.588 .30321 Mdot
.588 .30323 Mdot
.588 .30325 Mdot
.588 .30326 Mdot
.588 .30332 Mdot
.588 .30332 Mdot
.588 .30334 Mdot
.588 .30335 Mdot
.588 .30341 Mdot
.588 .30341 Mdot
.588 .30343 Mdot
.588 .30345 Mdot
.588 .3035 Mdot
.588 .30352 Mdot
.588 .30352 Mdot
.588 .30353 Mdot
.588 .30355 Mdot
.588 .30357 Mdot
.588 .30358 Mdot
.588 .30359 Mdot
.588 .3036 Mdot
.588 .30361 Mdot
.588 .30363 Mdot
.588 .30366 Mdot
.588 .3037 Mdot
.588 .30371 Mdot
.588 .30375 Mdot
.588 .30378 Mdot
.588 .30379 Mdot
.588 .3038 Mdot
.588 .30381 Mdot
.588 .30382 Mdot
.588 .30382 Mdot
.588 .30383 Mdot
.588 .30384 Mdot
.588 .30384 Mdot
.588 .30384 Mdot
.588 .30385 Mdot
.588 .30386 Mdot
.588 .30388 Mdot
.588 .30388 Mdot
.588 .30393 Mdot
.588 .30394 Mdot
.588 .30396 Mdot
.588 .30399 Mdot
.588 .30399 Mdot
.588 .30402 Mdot
.588 .30403 Mdot
.588 .30408 Mdot
.588 .30409 Mdot
.588 .3041 Mdot
.588 .30413 Mdot
.588 .30413 Mdot
.588 .30414 Mdot
.588 .30416 Mdot
.588 .30419 Mdot
.588 .3042 Mdot
.588 .30423 Mdot
.588 .30424 Mdot
.588 .30432 Mdot
.588 .30433 Mdot
.588 .30436 Mdot
.588 .30437 Mdot
.588 .30443 Mdot
.588 .30446 Mdot
.588 .30448 Mdot
.588 .3045 Mdot
.588 .30453 Mdot
.588 .30454 Mdot
.588 .30455 Mdot
.588 .30458 Mdot
.588 .30464 Mdot
.588 .30467 Mdot
.588 .30467 Mdot
.588 .30468 Mdot
.588 .30474 Mdot
.588 .30476 Mdot
.588 .30478 Mdot
.588 .3048 Mdot
.588 .30485 Mdot
.588 .30487 Mdot
.588 .30488 Mdot
.588 .30494 Mdot
.588 .30496 Mdot
.588 .30499 Mdot
.588 .30505 Mdot
.588 .30506 Mdot
.588 .30508 Mdot
.588 .30514 Mdot
.588 .30517 Mdot
.588 .30519 Mdot
.588 .30524 Mdot
.588 .30524 Mdot
.588 .30524 Mdot
.588 .3053 Mdot
.588 .30534 Mdot
.588 .30658 Mdot
.588 .30664 Mdot
.588 .30672 Mdot
.588 .30672 Mdot
.588 .30673 Mdot
.588 .30679 Mdot
.588 .30682 Mdot
.588 .30686 Mdot
.588 .30694 Mdot
.588 .30697 Mdot
.588 .30698 Mdot
.588 .30707 Mdot
.588 .30711 Mdot
.588 .30713 Mdot
.588 .30721 Mdot
.588 .30724 Mdot
.588 .30726 Mdot
.588 .30734 Mdot
.588 .30735 Mdot
.588 .30739 Mdot
.588 .30742 Mdot
.588 .30749 Mdot
.588 .30751 Mdot
.588 .30751 Mdot
.588 .30755 Mdot
.588 .30764 Mdot
.588 .30768 Mdot
.588 .30769 Mdot
.588 .3077 Mdot
.588 .30775 Mdot
.588 .30778 Mdot
.588 .3078 Mdot
.588 .30784 Mdot
.588 .30793 Mdot
.588 .30793 Mdot
.588 .30798 Mdot
.588 .308 Mdot
.588 .3081 Mdot
.588 .30812 Mdot
.588 .30817 Mdot
.588 .30817 Mdot
.588 .30822 Mdot
.588 .30824 Mdot
.588 .30825 Mdot
.588 .30826 Mdot
.588 .3083 Mdot
.588 .30831 Mdot
.588 .30833 Mdot
.588 .3084 Mdot
.588 .30841 Mdot
.588 .30845 Mdot
.588 .30845 Mdot
.588 .30849 Mdot
.588 .30852 Mdot
.588 .30854 Mdot
.588 .3086 Mdot
.588 .3086 Mdot
.588 .30863 Mdot
.588 .30864 Mdot
.588 .30866 Mdot
.588 .30866 Mdot
.588 .30866 Mdot
.588 .30868 Mdot
.588 .30868 Mdot
.588 .30869 Mdot
.588 .30869 Mdot
.588 .30872 Mdot
.588 .30872 Mdot
.588 .30875 Mdot
.588 .30878 Mdot
.588 .30884 Mdot
.588 .30885 Mdot
.588 .30891 Mdot
.588 .30894 Mdot
.588 .30898 Mdot
.588 .30898 Mdot
.588 .30901 Mdot
.588 .30902 Mdot
.588 .30903 Mdot
.588 .30906 Mdot
.588 .30909 Mdot
.588 .3091 Mdot
.588 .30911 Mdot
.588 .30912 Mdot
.588 .3092 Mdot
.588 .30923 Mdot
.588 .30926 Mdot
.588 .30926 Mdot
.588 .30934 Mdot
.588 .30936 Mdot
.588 .30937 Mdot
.588 .30937 Mdot
.588 .30945 Mdot
.588 .30947 Mdot
.588 .3095 Mdot
.588 .30952 Mdot
.588 .30953 Mdot
.588 .30957 Mdot
.588 .30961 Mdot
.588 .30964 Mdot
.588 .30964 Mdot
.588 .30964 Mdot
.588 .30966 Mdot
.588 .30972 Mdot
.588 .30977 Mdot
.588 .3098 Mdot
.588 .30982 Mdot
.588 .30982 Mdot
.588 .30985 Mdot
.588 .3099 Mdot
.588 .30995 Mdot
.588 .30998 Mdot
.588 .31006 Mdot
.588 .31009 Mdot
.588 .31015 Mdot
.588 .31017 Mdot
.588 .31018 Mdot
.588 .31019 Mdot
.588 .31021 Mdot
.588 .31022 Mdot
.588 .31023 Mdot
.588 .31025 Mdot
.588 .31027 Mdot
.588 .31028 Mdot
.588 .31028 Mdot
.588 .31029 Mdot
.588 .31029 Mdot
.588 .3103 Mdot
.588 .31031 Mdot
.588 .31036 Mdot
.588 .31037 Mdot
.588 .31039 Mdot
.588 .31041 Mdot
.588 .31043 Mdot
.588 .31044 Mdot
.588 .3105 Mdot
.588 .31052 Mdot
.588 .31052 Mdot
.588 .31055 Mdot
.588 .31056 Mdot
.588 .31058 Mdot
.588 .31059 Mdot
.588 .3106 Mdot
.588 .31071 Mdot
.588 .31072 Mdot
.588 .31073 Mdot
.588 .31074 Mdot
.588 .31081 Mdot
.588 .31081 Mdot
.588 .31082 Mdot
.588 .31085 Mdot
.588 .31088 Mdot
.588 .31092 Mdot
.588 .31094 Mdot
.588 .31099 Mdot
.588 .31099 Mdot
.588 .31106 Mdot
.588 .31106 Mdot
.588 .31108 Mdot
.588 .31109 Mdot
.588 .3111 Mdot
.588 .31116 Mdot
.588 .31118 Mdot
.588 .31121 Mdot
.588 .31121 Mdot
.588 .31122 Mdot
.588 .31122 Mdot
.588 .31122 Mdot
.588 .31124 Mdot
.588 .31125 Mdot
.588 .31125 Mdot
.588 .31126 Mdot
.588 .31127 Mdot
.588 .31128 Mdot
.588 .31132 Mdot
.588 .31134 Mdot
.588 .31138 Mdot
.588 .31144 Mdot
.588 .31147 Mdot
.588 .31149 Mdot
.588 .31152 Mdot
.588 .31155 Mdot
.588 .31156 Mdot
.588 .31156 Mdot
.588 .31157 Mdot
.588 .31162 Mdot
.588 .31163 Mdot
.588 .31165 Mdot
.588 .3117 Mdot
.588 .31176 Mdot
.588 .31177 Mdot
.588 .31179 Mdot
.588 .31183 Mdot
.588 .31183 Mdot
.588 .31184 Mdot
.588 .31186 Mdot
.588 .31187 Mdot
.588 .3119 Mdot
.588 .31192 Mdot
.588 .31194 Mdot
.588 .31197 Mdot
.588 .31202 Mdot
.588 .31203 Mdot
.588 .31205 Mdot
.588 .31205 Mdot
.588 .31206 Mdot
.588 .31207 Mdot
.588 .31207 Mdot
.588 .31208 Mdot
.588 .31208 Mdot
.588 .3121 Mdot
.588 .3121 Mdot
.588 .31214 Mdot
.588 .31218 Mdot
.588 .3122 Mdot
.588 .31221 Mdot
.588 .31224 Mdot
.588 .31225 Mdot
.588 .31228 Mdot
.588 .31229 Mdot
.588 .3123 Mdot
.588 .31233 Mdot
.588 .31235 Mdot
.588 .31236 Mdot
.588 .31245 Mdot
.588 .3125 Mdot
.588 .31252 Mdot
.588 .31254 Mdot
.588 .31258 Mdot
.588 .31258 Mdot
.588 .31265 Mdot
.588 .31272 Mdot
.588 .31273 Mdot
.588 .31276 Mdot
.588 .3128 Mdot
.588 .31282 Mdot
.588 .31287 Mdot
.588 .31288 Mdot
.588 .3129 Mdot
.588 .31295 Mdot
.588 .31295 Mdot
.588 .31296 Mdot
.588 .31301 Mdot
.588 .31303 Mdot
.588 .31305 Mdot
.588 .31308 Mdot
.588 .31308 Mdot
.588 .31308 Mdot
.588 .31312 Mdot
.588 .31316 Mdot
.588 .3509 Mdot
.588 .35093 Mdot
.588 .35096 Mdot
.588 .35096 Mdot
.588 .35097 Mdot
.588 .351 Mdot
.588 .35101 Mdot
.588 .35103 Mdot
.588 .35106 Mdot
.588 .35107 Mdot
.588 .35108 Mdot
.588 .35112 Mdot
.588 .35114 Mdot
.588 .35115 Mdot
.588 .35118 Mdot
.588 .35121 Mdot
.588 .35124 Mdot
.588 .35126 Mdot
.588 .35127 Mdot
.588 .35133 Mdot
.588 .35139 Mdot
.588 .35139 Mdot
.588 .35142 Mdot
.588 .35144 Mdot
.588 .35146 Mdot
.588 .3515 Mdot
.588 .35158 Mdot
.588 .35159 Mdot
.588 .35161 Mdot
.588 .35163 Mdot
.588 .35164 Mdot
.588 .35165 Mdot
.588 .35167 Mdot
.588 .35168 Mdot
.588 .35171 Mdot
.588 .35172 Mdot
.588 .35173 Mdot
.588 .35176 Mdot
.588 .3518 Mdot
.588 .3518 Mdot
.588 .35181 Mdot
.588 .35182 Mdot
.588 .35183 Mdot
.588 .35183 Mdot
.588 .35183 Mdot
.588 .35184 Mdot
.588 .35184 Mdot
.588 .35186 Mdot
.588 .35186 Mdot
.588 .35191 Mdot
.588 .35194 Mdot
.588 .35195 Mdot
.588 .35197 Mdot
.588 .35199 Mdot
.588 .352 Mdot
.588 .35202 Mdot
.588 .35202 Mdot
.588 .35203 Mdot
.588 .35207 Mdot
.588 .35208 Mdot
.588 .35209 Mdot
.588 .35214 Mdot
.588 .35218 Mdot
.588 .3522 Mdot
.588 .35221 Mdot
.588 .35225 Mdot
.588 .35226 Mdot
.588 .35226 Mdot
.588 .35227 Mdot
.588 .3523 Mdot
.588 .35232 Mdot
.588 .35233 Mdot
.588 .35236 Mdot
.588 .35241 Mdot
.588 .35245 Mdot
.588 .35246 Mdot
.588 .3525 Mdot
.588 .35251 Mdot
.588 .35252 Mdot
.588 .35252 Mdot
.588 .35252 Mdot
.588 .35253 Mdot
.588 .35255 Mdot
.588 .35255 Mdot
.588 .35255 Mdot
.588 .35255 Mdot
.588 .35256 Mdot
.588 .35258 Mdot
.588 .3526 Mdot
.588 .35265 Mdot
.588 .35265 Mdot
.588 .35267 Mdot
.588 .35269 Mdot
.588 .35269 Mdot
.588 .35274 Mdot
.588 .35275 Mdot
.588 .35278 Mdot
.588 .3528 Mdot
.588 .35283 Mdot
.588 .35286 Mdot
.588 .35289 Mdot
.588 .35289 Mdot
.588 .3529 Mdot
.588 .35296 Mdot
.588 .35296 Mdot
.588 .35297 Mdot
.588 .35298 Mdot
.588 .35308 Mdot
.588 .35308 Mdot
.588 .3531 Mdot
.588 .35311 Mdot
.588 .35312 Mdot
.588 .35314 Mdot
.588 .35315 Mdot
.588 .35316 Mdot
.588 .35321 Mdot
.588 .35322 Mdot
.588 .35324 Mdot
.588 .35325 Mdot
.588 .35327 Mdot
.588 .35328 Mdot
.588 .35332 Mdot
.588 .35333 Mdot
.588 .35334 Mdot
.588 .35334 Mdot
.588 .35335 Mdot
.588 .35335 Mdot
.588 .35336 Mdot
.588 .35337 Mdot
.588 .35339 Mdot
.588 .3534 Mdot
.588 .3534 Mdot
.588 .35342 Mdot
.588 .35344 Mdot
.588 .35344 Mdot
.588 .35346 Mdot
.588 .35351 Mdot
.588 .35353 Mdot
.588 .3536 Mdot
.588 .35363 Mdot
.588 .35367 Mdot
.588 .35371 Mdot
.588 .35374 Mdot
.588 .35374 Mdot
.588 .35376 Mdot
.588 .35378 Mdot
.588 .35383 Mdot
.588 .35388 Mdot
.588 .35389 Mdot
.588 .35389 Mdot
.588 .35389 Mdot
.588 .35392 Mdot
.588 .35395 Mdot
.588 .35398 Mdot
.588 .35399 Mdot
.588 .35401 Mdot
.588 .35404 Mdot
.588 .35405 Mdot
.588 .35412 Mdot
.588 .35412 Mdot
.588 .35413 Mdot
.588 .35414 Mdot
.588 .35422 Mdot
.588 .35422 Mdot
.588 .35424 Mdot
.588 .35426 Mdot
.588 .35433 Mdot
.588 .35435 Mdot
.588 .35435 Mdot
.588 .35436 Mdot
.588 .35439 Mdot
.588 .35441 Mdot
.588 .35442 Mdot
.588 .35443 Mdot
.588 .35445 Mdot
.588 .35445 Mdot
.588 .35448 Mdot
.588 .35451 Mdot
.588 .35457 Mdot
.588 .35457 Mdot
.588 .35462 Mdot
.588 .35465 Mdot
.588 .35467 Mdot
.588 .35468 Mdot
.588 .3547 Mdot
.588 .3547 Mdot
.588 .35471 Mdot
.588 .35471 Mdot
.588 .35472 Mdot
.588 .35472 Mdot
.588 .35472 Mdot
.588 .35474 Mdot
.588 .35475 Mdot
.588 .35477 Mdot
.588 .35478 Mdot
.588 .35483 Mdot
.588 .35485 Mdot
.588 .35487 Mdot
.588 .3549 Mdot
.588 .35491 Mdot
.588 .35494 Mdot
.588 .35495 Mdot
.588 .35501 Mdot
.588 .35502 Mdot
.588 .35503 Mdot
.588 .35507 Mdot
.588 .35507 Mdot
.588 .35508 Mdot
.588 .3551 Mdot
.588 .35514 Mdot
.588 .35514 Mdot
.588 .35519 Mdot
.588 .3552 Mdot
.588 .35529 Mdot
.588 .35531 Mdot
.588 .35534 Mdot
.588 .35535 Mdot
.588 .35542 Mdot
.588 .35546 Mdot
.588 .35547 Mdot
.588 .3555 Mdot
.588 .35554 Mdot
.588 .35555 Mdot
.588 .35556 Mdot
.588 .3556 Mdot
.588 .35567 Mdot
.588 .3557 Mdot
.588 .35571 Mdot
.588 .35572 Mdot
.588 .35578 Mdot
.588 .35581 Mdot
.588 .35583 Mdot
.588 .35585 Mdot
.588 .35591 Mdot
.588 .35594 Mdot
.588 .35595 Mdot
.588 .35602 Mdot
.588 .35604 Mdot
.588 .35608 Mdot
.588 .35615 Mdot
.588 .35616 Mdot
.588 .35618 Mdot
.588 .35625 Mdot
.588 .35629 Mdot
.588 .35632 Mdot
.588 .35637 Mdot
.588 .35637 Mdot
.588 .35638 Mdot
.588 .35644 Mdot
.588 .35649 Mdot
.588 .35755 Mdot
.588 .35758 Mdot
.588 .35763 Mdot
.588 .35763 Mdot
.588 .35763 Mdot
.588 .35767 Mdot
.588 .35769 Mdot
.588 .35772 Mdot
.588 .35777 Mdot
.588 .35778 Mdot
.588 .35779 Mdot
.588 .35785 Mdot
.588 .35787 Mdot
.588 .35789 Mdot
.588 .35793 Mdot
.588 .35795 Mdot
.588 .35797 Mdot
.588 .35801 Mdot
.588 .35802 Mdot
.588 .35804 Mdot
.588 .35806 Mdot
.588 .35811 Mdot
.588 .35811 Mdot
.588 .35812 Mdot
.588 .35814 Mdot
.588 .35819 Mdot
.588 .35822 Mdot
.588 .35823 Mdot
.588 .35823 Mdot
.588 .35826 Mdot
.588 .35828 Mdot
.588 .35829 Mdot
.588 .35832 Mdot
.588 .35838 Mdot
.588 .35838 Mdot
.588 .3584 Mdot
.588 .35842 Mdot
.588 .35848 Mdot
.588 .35849 Mdot
.588 .35852 Mdot
.588 .35852 Mdot
.588 .35855 Mdot
.588 .35856 Mdot
.588 .35857 Mdot
.588 .35858 Mdot
.588 .3586 Mdot
.588 .35861 Mdot
.588 .35862 Mdot
.588 .35866 Mdot
.588 .35867 Mdot
.588 .35869 Mdot
.588 .3587 Mdot
.588 .35872 Mdot
.588 .35874 Mdot
.588 .35875 Mdot
.588 .35879 Mdot
.588 .35879 Mdot
.588 .35881 Mdot
.588 .35881 Mdot
.588 .35882 Mdot
.588 .35882 Mdot
.588 .35883 Mdot
.588 .35884 Mdot
.588 .35884 Mdot
.588 .35884 Mdot
.588 .35885 Mdot
.588 .35886 Mdot
.588 .35886 Mdot
.588 .35888 Mdot
.588 .3589 Mdot
.588 .35893 Mdot
.588 .35894 Mdot
.588 .35898 Mdot
.588 .359 Mdot
.588 .35902 Mdot
.588 .35902 Mdot
.588 .35904 Mdot
.588 .35905 Mdot
.588 .35905 Mdot
.588 .35907 Mdot
.588 .35909 Mdot
.588 .35909 Mdot
.588 .3591 Mdot
.588 .35911 Mdot
.588 .35916 Mdot
.588 .35917 Mdot
.588 .35919 Mdot
.588 .35919 Mdot
.588 .35924 Mdot
.588 .35925 Mdot
.588 .35926 Mdot
.588 .35926 Mdot
.588 .35931 Mdot
.588 .35932 Mdot
.588 .35934 Mdot
.588 .35936 Mdot
.588 .35936 Mdot
.588 .35938 Mdot
.588 .35941 Mdot
.588 .35942 Mdot
.588 .35942 Mdot
.588 .35943 Mdot
.588 .35944 Mdot
.588 .35947 Mdot
.588 .35951 Mdot
.588 .35952 Mdot
.588 .35954 Mdot
.588 .35954 Mdot
.588 .35956 Mdot
.588 .35959 Mdot
.588 .35962 Mdot
.588 .35964 Mdot
.588 .35969 Mdot
.588 .3597 Mdot
.588 .35974 Mdot
.588 .35975 Mdot
.588 .35976 Mdot
.588 .35977 Mdot
.588 .35978 Mdot
.588 .35978 Mdot
.588 .35979 Mdot
.588 .3598 Mdot
.588 .35981 Mdot
.588 .35982 Mdot
.588 .35982 Mdot
.588 .35982 Mdot
.588 .35983 Mdot
.588 .35983 Mdot
.588 .35984 Mdot
.588 .35987 Mdot
.588 .35988 Mdot
.588 .35989 Mdot
.588 .3599 Mdot
.588 .35992 Mdot
.588 .35992 Mdot
.588 .35996 Mdot
.588 .35997 Mdot
.588 .35997 Mdot
.588 .35999 Mdot
.588 .35999 Mdot
.588 .36 Mdot
.588 .36001 Mdot
.588 .36001 Mdot
.588 .36009 Mdot
.588 .36009 Mdot
.588 .3601 Mdot
.588 .3601 Mdot
.588 .36014 Mdot
.588 .36015 Mdot
.588 .36015 Mdot
.588 .36017 Mdot
.588 .36019 Mdot
.588 .36022 Mdot
.588 .36023 Mdot
.588 .36025 Mdot
.588 .36026 Mdot
.588 .3603 Mdot
.588 .3603 Mdot
.588 .36031 Mdot
.588 .36032 Mdot
.588 .36033 Mdot
.588 .36036 Mdot
.588 .36037 Mdot
.588 .36039 Mdot
.588 .36039 Mdot
.588 .3604 Mdot
.588 .3604 Mdot
.588 .3604 Mdot
.588 .36041 Mdot
.588 .36042 Mdot
.588 .36042 Mdot
.588 .36042 Mdot
.588 .36043 Mdot
.588 .36043 Mdot
.588 .36046 Mdot
.588 .36047 Mdot
.588 .36049 Mdot
.588 .36054 Mdot
.588 .36055 Mdot
.588 .36056 Mdot
.588 .36058 Mdot
.588 .3606 Mdot
.588 .36061 Mdot
.588 .36061 Mdot
.588 .36061 Mdot
.588 .36064 Mdot
.588 .36065 Mdot
.588 .36066 Mdot
.588 .36069 Mdot
.588 .36073 Mdot
.588 .36074 Mdot
.588 .36075 Mdot
.588 .36077 Mdot
.588 .36078 Mdot
.588 .36078 Mdot
.588 .36079 Mdot
.588 .3608 Mdot
.588 .36082 Mdot
.588 .36082 Mdot
.588 .36083 Mdot
.588 .36084 Mdot
.588 .36086 Mdot
.588 .36089 Mdot
.588 .3609 Mdot
.588 .36091 Mdot
.588 .36091 Mdot
.588 .36091 Mdot
.588 .36092 Mdot
.588 .36092 Mdot
.588 .36093 Mdot
.588 .36093 Mdot
.588 .36094 Mdot
.588 .36094 Mdot
.588 .36097 Mdot
.588 .36099 Mdot
.588 .361 Mdot
.588 .361 Mdot
.588 .36103 Mdot
.588 .36103 Mdot
.588 .36105 Mdot
.588 .36106 Mdot
.588 .36106 Mdot
.588 .36108 Mdot
.588 .36109 Mdot
.588 .3611 Mdot
.588 .36115 Mdot
.588 .36118 Mdot
.588 .3612 Mdot
.588 .36121 Mdot
.588 .36123 Mdot
.588 .36123 Mdot
.588 .36128 Mdot
.588 .36132 Mdot
.588 .36133 Mdot
.588 .36135 Mdot
.588 .36137 Mdot
.588 .36138 Mdot
.588 .36141 Mdot
.588 .36142 Mdot
.588 .36143 Mdot
.588 .36146 Mdot
.588 .36146 Mdot
.588 .36147 Mdot
.588 .3615 Mdot
.588 .36151 Mdot
.588 .36152 Mdot
.588 .36154 Mdot
.588 .36154 Mdot
.588 .36154 Mdot
.588 .36157 Mdot
.588 .36159 Mdot
.59 .30015 Mdot
.59 .30015 Mdot
.59 .30015 Mdot
.59 .30016 Mdot
.59 .30016 Mdot
.59 .30017 Mdot
.59 .30017 Mdot
.59 .30019 Mdot
.59 .3002 Mdot
.59 .30022 Mdot
.59 .30024 Mdot
.59 .30024 Mdot
.59 .30025 Mdot
.59 .30027 Mdot
.59 .30031 Mdot
.59 .30032 Mdot
.59 .30033 Mdot
.59 .30034 Mdot
.59 .30037 Mdot
.59 .30039 Mdot
.59 .30041 Mdot
.59 .30045 Mdot
.59 .30045 Mdot
.59 .30048 Mdot
.59 .3005 Mdot
.59 .30055 Mdot
.59 .30055 Mdot
.59 .30056 Mdot
.59 .30059 Mdot
.59 .30061 Mdot
.59 .30063 Mdot
.59 .30065 Mdot
.59 .30067 Mdot
.59 .30068 Mdot
.59 .30072 Mdot
.59 .30072 Mdot
.59 .30073 Mdot
.59 .30073 Mdot
.59 .30077 Mdot
.59 .30078 Mdot
.59 .30085 Mdot
.59 .30086 Mdot
.59 .30087 Mdot
.59 .30087 Mdot
.59 .30092 Mdot
.59 .30097 Mdot
.59 .30101 Mdot
.59 .30102 Mdot
.59 .30106 Mdot
.59 .30109 Mdot
.59 .30111 Mdot
.59 .30112 Mdot
.59 .30114 Mdot
.59 .30115 Mdot
.59 .30118 Mdot
.59 .30125 Mdot
.59 .30127 Mdot
.59 .30129 Mdot
.59 .30132 Mdot
.59 .30132 Mdot
.59 .30136 Mdot
.59 .30137 Mdot
.59 .30138 Mdot
.59 .30139 Mdot
.59 .30141 Mdot
.59 .30142 Mdot
.59 .30143 Mdot
.59 .30143 Mdot
.59 .30144 Mdot
.59 .30145 Mdot
.59 .30147 Mdot
.59 .30149 Mdot
.59 .30158 Mdot
.59 .3016 Mdot
.59 .30168 Mdot
.59 .30169 Mdot
.59 .30175 Mdot
.59 .30176 Mdot
.59 .30176 Mdot
.59 .30178 Mdot
.59 .30179 Mdot
.59 .30179 Mdot
.59 .30186 Mdot
.59 .30188 Mdot
.59 .3019 Mdot
.59 .30192 Mdot
.59 .30193 Mdot
.59 .30195 Mdot
.59 .30198 Mdot
.59 .30203 Mdot
.59 .30209 Mdot
.59 .30214 Mdot
.59 .30216 Mdot
.59 .30216 Mdot
.59 .30217 Mdot
.59 .30217 Mdot
.59 .30222 Mdot
.59 .30222 Mdot
.59 .30225 Mdot
.59 .30229 Mdot
.59 .30231 Mdot
.59 .30232 Mdot
.59 .30236 Mdot
.59 .30238 Mdot
.59 .30238 Mdot
.59 .30243 Mdot
.59 .30246 Mdot
.59 .30247 Mdot
.59 .30253 Mdot
.59 .30257 Mdot
.59 .30258 Mdot
.59 .30262 Mdot
.59 .30266 Mdot
.59 .30271 Mdot
.59 .30274 Mdot
.59 .30274 Mdot
.59 .30278 Mdot
.59 .30282 Mdot
.59 .30283 Mdot
.59 .30283 Mdot
.59 .30284 Mdot
.59 .30284 Mdot
.59 .30285 Mdot
.59 .30285 Mdot
.59 .30286 Mdot
.59 .30286 Mdot
.59 .30288 Mdot
.59 .30289 Mdot
.59 .30289 Mdot
.59 .3029 Mdot
.59 .30293 Mdot
.59 .30294 Mdot
.59 .30296 Mdot
.59 .30297 Mdot
.59 .30299 Mdot
.59 .30299 Mdot
.59 .30302 Mdot
.59 .30305 Mdot
.59 .30305 Mdot
.59 .30307 Mdot
.59 .30308 Mdot
.59 .30311 Mdot
.59 .30311 Mdot
.59 .30313 Mdot
.59 .30314 Mdot
.59 .30314 Mdot
.59 .30316 Mdot
.59 .30316 Mdot
.59 .30321 Mdot
.59 .30321 Mdot
.59 .30326 Mdot
.59 .30332 Mdot
.59 .30333 Mdot
.59 .30334 Mdot
.59 .3034 Mdot
.59 .30342 Mdot
.59 .30346 Mdot
.59 .30347 Mdot
.59 .30347 Mdot
.59 .30348 Mdot
.59 .30349 Mdot
.59 .30351 Mdot
.59 .30352 Mdot
.59 .30358 Mdot
.59 .30363 Mdot
.59 .30366 Mdot
.59 .30367 Mdot
.59 .30367 Mdot
.59 .30368 Mdot
.59 .30368 Mdot
.59 .30375 Mdot
.59 .30376 Mdot
.59 .30384 Mdot
.59 .30386 Mdot
.59 .30388 Mdot
.59 .30394 Mdot
.59 .30395 Mdot
.59 .30396 Mdot
.59 .30399 Mdot
.59 .30401 Mdot
.59 .30403 Mdot
.59 .30403 Mdot
.59 .30409 Mdot
.59 .30411 Mdot
.59 .30413 Mdot
.59 .30416 Mdot
.59 .30418 Mdot
.59 .30422 Mdot
.59 .30422 Mdot
.59 .30422 Mdot
.59 .30423 Mdot
.59 .30424 Mdot
.59 .30424 Mdot
.59 .30425 Mdot
.59 .30427 Mdot
.59 .3043 Mdot
.59 .30432 Mdot
.59 .30433 Mdot
.59 .30433 Mdot
.59 .30436 Mdot
.59 .30437 Mdot
.59 .30438 Mdot
.59 .30438 Mdot
.59 .30439 Mdot
.59 .30441 Mdot
.59 .30444 Mdot
.59 .30447 Mdot
.59 .30448 Mdot
.59 .30455 Mdot
.59 .30455 Mdot
.59 .30456 Mdot
.59 .30457 Mdot
.59 .30463 Mdot
.59 .30465 Mdot
.59 .30466 Mdot
.59 .30466 Mdot
.59 .3047 Mdot
.59 .30472 Mdot
.59 .30475 Mdot
.59 .30476 Mdot
.59 .30483 Mdot
.59 .30484 Mdot
.59 .30484 Mdot
.59 .30487 Mdot
.59 .30491 Mdot
.59 .30491 Mdot
.59 .30494 Mdot
.59 .30495 Mdot
.59 .30495 Mdot
.59 .30496 Mdot
.59 .30499 Mdot
.59 .305 Mdot
.59 .30501 Mdot
.59 .30501 Mdot
.59 .30502 Mdot
.59 .30503 Mdot
.59 .30511 Mdot
.59 .30515 Mdot
.59 .30516 Mdot
.59 .30516 Mdot
.59 .30519 Mdot
.59 .30525 Mdot
.59 .30526 Mdot
.59 .30529 Mdot
.59 .30531 Mdot
.59 .30531 Mdot
.59 .30532 Mdot
.59 .30534 Mdot
.59 .30535 Mdot
.59 .30535 Mdot
.59 .3062 Mdot
.59 .3062 Mdot
.59 .30621 Mdot
.59 .30624 Mdot
.59 .30624 Mdot
.59 .30625 Mdot
.59 .30627 Mdot
.59 .30632 Mdot
.59 .30633 Mdot
.59 .30641 Mdot
.59 .30645 Mdot
.59 .30646 Mdot
.59 .30647 Mdot
.59 .30653 Mdot
.59 .30664 Mdot
.59 .30665 Mdot
.59 .30666 Mdot
.59 .30666 Mdot
.59 .30668 Mdot
.59 .3067 Mdot
.59 .30673 Mdot
.59 .30674 Mdot
.59 .30675 Mdot
.59 .30677 Mdot
.59 .3068 Mdot
.59 .30681 Mdot
.59 .30686 Mdot
.59 .3069 Mdot
.59 .3069 Mdot
.59 .30691 Mdot
.59 .30701 Mdot
.59 .30702 Mdot
.59 .30707 Mdot
.59 .3071 Mdot
.59 .30715 Mdot
.59 .30715 Mdot
.59 .30716 Mdot
.59 .30719 Mdot
.59 .30728 Mdot
.59 .30729 Mdot
.59 .3073 Mdot
.59 .30731 Mdot
.59 .3074 Mdot
.59 .30741 Mdot
.59 .30745 Mdot
.59 .30749 Mdot
.59 .30752 Mdot
.59 .30754 Mdot
.59 .30755 Mdot
.59 .30756 Mdot
.59 .30757 Mdot
.59 .30761 Mdot
.59 .30761 Mdot
.59 .30763 Mdot
.59 .30765 Mdot
.59 .30769 Mdot
.59 .30772 Mdot
.59 .30773 Mdot
.59 .30774 Mdot
.59 .30775 Mdot
.59 .30776 Mdot
.59 .30777 Mdot
.59 .30777 Mdot
.59 .30783 Mdot
.59 .30785 Mdot
.59 .30789 Mdot
.59 .30791 Mdot
.59 .30794 Mdot
.59 .30802 Mdot
.59 .30803 Mdot
.59 .30805 Mdot
.59 .30809 Mdot
.59 .30813 Mdot
.59 .30814 Mdot
.59 .30815 Mdot
.59 .30824 Mdot
.59 .30826 Mdot
.59 .3083 Mdot
.59 .30841 Mdot
.59 .30841 Mdot
.59 .30851 Mdot
.59 .30852 Mdot
.59 .30853 Mdot
.59 .30853 Mdot
.59 .30854 Mdot
.59 .30859 Mdot
.59 .30865 Mdot
.59 .30874 Mdot
.59 .30876 Mdot
.59 .30878 Mdot
.59 .3088 Mdot
.59 .30881 Mdot
.59 .30881 Mdot
.59 .30882 Mdot
.59 .30887 Mdot
.59 .3089 Mdot
.59 .30899 Mdot
.59 .309 Mdot
.59 .30901 Mdot
.59 .3091 Mdot
.59 .30917 Mdot
.59 .30917 Mdot
.59 .30923 Mdot
.59 .30924 Mdot
.59 .30927 Mdot
.59 .30928 Mdot
.59 .30928 Mdot
.59 .3093 Mdot
.59 .30932 Mdot
.59 .30936 Mdot
.59 .30937 Mdot
.59 .3094 Mdot
.59 .3094 Mdot
.59 .30944 Mdot
.59 .30947 Mdot
.59 .30947 Mdot
.59 .3095 Mdot
.59 .30952 Mdot
.59 .30955 Mdot
.59 .30956 Mdot
.59 .3096 Mdot
.59 .30962 Mdot
.59 .30962 Mdot
.59 .30963 Mdot
.59 .30966 Mdot
.59 .30966 Mdot
.59 .30967 Mdot
.59 .30968 Mdot
.59 .30968 Mdot
.59 .30969 Mdot
.59 .3097 Mdot
.59 .30971 Mdot
.59 .30971 Mdot
.59 .30977 Mdot
.59 .30982 Mdot
.59 .30982 Mdot
.59 .30986 Mdot
.59 .30994 Mdot
.59 .30999 Mdot
.59 .31005 Mdot
.59 .31006 Mdot
.59 .31011 Mdot
.59 .3102 Mdot
.59 .31022 Mdot
.59 .31026 Mdot
.59 .31032 Mdot
.59 .31033 Mdot
.59 .31035 Mdot
.59 .31041 Mdot
.59 .31042 Mdot
.59 .31045 Mdot
.59 .31051 Mdot
.59 .31054 Mdot
.59 .31055 Mdot
.59 .31061 Mdot
.59 .31062 Mdot
.59 .31063 Mdot
.59 .31063 Mdot
.59 .31067 Mdot
.59 .31073 Mdot
.59 .31081 Mdot
.59 .31088 Mdot
.59 .31093 Mdot
.59 .31095 Mdot
.59 .31096 Mdot
.59 .311 Mdot
.59 .31102 Mdot
.59 .31106 Mdot
.59 .31115 Mdot
.59 .31115 Mdot
.59 .31116 Mdot
.59 .31119 Mdot
.59 .31119 Mdot
.59 .31121 Mdot
.59 .31129 Mdot
.59 .31131 Mdot
.59 .31142 Mdot
.59 .31144 Mdot
.59 .31157 Mdot
.59 .31159 Mdot
.59 .31163 Mdot
.59 .31164 Mdot
.59 .31164 Mdot
.59 .31165 Mdot
.59 .31167 Mdot
.59 .31168 Mdot
.59 .31171 Mdot
.59 .31172 Mdot
.59 .31173 Mdot
.59 .31175 Mdot
.59 .3118 Mdot
.59 .31181 Mdot
.59 .31185 Mdot
.59 .31187 Mdot
.59 .3119 Mdot
.59 .31199 Mdot
.59 .31204 Mdot
.59 .31206 Mdot
.59 .31208 Mdot
.59 .31209 Mdot
.59 .31212 Mdot
.59 .31217 Mdot
.59 .31223 Mdot
.59 .31223 Mdot
.59 .31229 Mdot
.59 .31235 Mdot
.59 .31243 Mdot
.59 .31244 Mdot
.59 .31244 Mdot
.59 .31246 Mdot
.59 .31255 Mdot
.59 .31256 Mdot
.59 .31263 Mdot
.59 .31263 Mdot
.59 .31263 Mdot
.59 .31264 Mdot
.59 .31269 Mdot
.59 .31271 Mdot
.59 .31274 Mdot
.59 .31277 Mdot
.59 .31279 Mdot
.59 .31281 Mdot
.59 .31286 Mdot
.59 .31287 Mdot
.59 .31288 Mdot
.59 .31294 Mdot
.59 .31297 Mdot
.59 .31301 Mdot
.59 .31302 Mdot
.59 .31307 Mdot
.59 .3131 Mdot
.59 .31313 Mdot
.59 .31316 Mdot
.59 .31318 Mdot
.59 .3132 Mdot
.59 .31321 Mdot
.59 .31326 Mdot
.59 .31329 Mdot
.59 .3133 Mdot
.59 .31331 Mdot
.59 .31333 Mdot
.59 .31337 Mdot
.59 .31337 Mdot
.59 .3134 Mdot
.59 .31341 Mdot
.59 .31341 Mdot
.59 .31341 Mdot
.59 .31343 Mdot
.59 .31344 Mdot
.59 .31344 Mdot
.59 .35152 Mdot
.59 .35152 Mdot
.59 .35153 Mdot
.59 .35154 Mdot
.59 .35154 Mdot
.59 .35155 Mdot
.59 .35156 Mdot
.59 .35158 Mdot
.59 .35158 Mdot
.59 .35162 Mdot
.59 .35164 Mdot
.59 .35164 Mdot
.59 .35164 Mdot
.59 .35167 Mdot
.59 .35172 Mdot
.59 .35172 Mdot
.59 .35174 Mdot
.59 .35176 Mdot
.59 .35179 Mdot
.59 .35181 Mdot
.59 .35183 Mdot
.59 .35188 Mdot
.59 .35189 Mdot
.59 .35192 Mdot
.59 .35194 Mdot
.59 .352 Mdot
.59 .352 Mdot
.59 .35201 Mdot
.59 .35205 Mdot
.59 .35207 Mdot
.59 .35209 Mdot
.59 .35211 Mdot
.59 .35214 Mdot
.59 .35216 Mdot
.59 .3522 Mdot
.59 .3522 Mdot
.59 .35221 Mdot
.59 .35221 Mdot
.59 .35226 Mdot
.59 .35227 Mdot
.59 .35235 Mdot
.59 .35237 Mdot
.59 .35237 Mdot
.59 .35238 Mdot
.59 .35244 Mdot
.59 .35249 Mdot
.59 .35255 Mdot
.59 .35255 Mdot
.59 .3526 Mdot
.59 .35264 Mdot
.59 .35266 Mdot
.59 .35267 Mdot
.59 .35269 Mdot
.59 .35271 Mdot
.59 .35275 Mdot
.59 .35282 Mdot
.59 .35286 Mdot
.59 .35287 Mdot
.59 .35291 Mdot
.59 .35291 Mdot
.59 .35296 Mdot
.59 .35297 Mdot
.59 .35298 Mdot
.59 .35299 Mdot
.59 .35301 Mdot
.59 .35302 Mdot
.59 .35304 Mdot
.59 .35304 Mdot
.59 .35305 Mdot
.59 .35306 Mdot
.59 .35309 Mdot
.59 .35311 Mdot
.59 .35321 Mdot
.59 .35324 Mdot
.59 .35333 Mdot
.59 .35334 Mdot
.59 .35341 Mdot
.59 .35342 Mdot
.59 .35343 Mdot
.59 .35346 Mdot
.59 .35346 Mdot
.59 .35346 Mdot
.59 .35354 Mdot
.59 .35357 Mdot
.59 .35359 Mdot
.59 .35362 Mdot
.59 .35363 Mdot
.59 .35365 Mdot
.59 .35369 Mdot
.59 .35375 Mdot
.59 .35382 Mdot
.59 .35387 Mdot
.59 .3539 Mdot
.59 .35391 Mdot
.59 .35391 Mdot
.59 .35392 Mdot
.59 .35397 Mdot
.59 .35398 Mdot
.59 .354 Mdot
.59 .35406 Mdot
.59 .35408 Mdot
.59 .35409 Mdot
.59 .35414 Mdot
.59 .35416 Mdot
.59 .35416 Mdot
.59 .35422 Mdot
.59 .35425 Mdot
.59 .35426 Mdot
.59 .35434 Mdot
.59 .35438 Mdot
.59 .3544 Mdot
.59 .35445 Mdot
.59 .35449 Mdot
.59 .35455 Mdot
.59 .35459 Mdot
.59 .35459 Mdot
.59 .35463 Mdot
.59 .35468 Mdot
.59 .35469 Mdot
.59 .35469 Mdot
.59 .3547 Mdot
.59 .35471 Mdot
.59 .35471 Mdot
.59 .35472 Mdot
.59 .35473 Mdot
.59 .35473 Mdot
.59 .35475 Mdot
.59 .35476 Mdot
.59 .35476 Mdot
.59 .35477 Mdot
.59 .35481 Mdot
.59 .35482 Mdot
.59 .35485 Mdot
.59 .35486 Mdot
.59 .35488 Mdot
.59 .35488 Mdot
.59 .35491 Mdot
.59 .35495 Mdot
.59 .35495 Mdot
.59 .35497 Mdot
.59 .35498 Mdot
.59 .35502 Mdot
.59 .35503 Mdot
.59 .35505 Mdot
.59 .35505 Mdot
.59 .35505 Mdot
.59 .35508 Mdot
.59 .35509 Mdot
.59 .35514 Mdot
.59 .35514 Mdot
.59 .3552 Mdot
.59 .35527 Mdot
.59 .35529 Mdot
.59 .35529 Mdot
.59 .35537 Mdot
.59 .35539 Mdot
.59 .35544 Mdot
.59 .35544 Mdot
.59 .35545 Mdot
.59 .35545 Mdot
.59 .35547 Mdot
.59 .35549 Mdot
.59 .3555 Mdot
.59 .35558 Mdot
.59 .35563 Mdot
.59 .35567 Mdot
.59 .35568 Mdot
.59 .35568 Mdot
.59 .35569 Mdot
.59 .3557 Mdot
.59 .35578 Mdot
.59 .35579 Mdot
.59 .35588 Mdot
.59 .35591 Mdot
.59 .35593 Mdot
.59 .35601 Mdot
.59 .35602 Mdot
.59 .35602 Mdot
.59 .35606 Mdot
.59 .35609 Mdot
.59 .35611 Mdot
.59 .35611 Mdot
.59 .35618 Mdot
.59 .3562 Mdot
.59 .35623 Mdot
.59 .35626 Mdot
.59 .35628 Mdot
.59 .35633 Mdot
.59 .35633 Mdot
.59 .35634 Mdot
.59 .35634 Mdot
.59 .35635 Mdot
.59 .35636 Mdot
.59 .35637 Mdot
.59 .35639 Mdot
.59 .35643 Mdot
.59 .35645 Mdot
.59 .35646 Mdot
.59 .35646 Mdot
.59 .3565 Mdot
.59 .3565 Mdot
.59 .35652 Mdot
.59 .35652 Mdot
.59 .35653 Mdot
.59 .35656 Mdot
.59 .35659 Mdot
.59 .35663 Mdot
.59 .35664 Mdot
.59 .35672 Mdot
.59 .35672 Mdot
.59 .35673 Mdot
.59 .35674 Mdot
.59 .35682 Mdot
.59 .35684 Mdot
.59 .35685 Mdot
.59 .35685 Mdot
.59 .3569 Mdot
.59 .35692 Mdot
.59 .35696 Mdot
.59 .35697 Mdot
.59 .35705 Mdot
.59 .35706 Mdot
.59 .35706 Mdot
.59 .3571 Mdot
.59 .35714 Mdot
.59 .35715 Mdot
.59 .35717 Mdot
.59 .35719 Mdot
.59 .3572 Mdot
.59 .35721 Mdot
.59 .35724 Mdot
.59 .35725 Mdot
.59 .35726 Mdot
.59 .35727 Mdot
.59 .35727 Mdot
.59 .35728 Mdot
.59 .35738 Mdot
.59 .35743 Mdot
.59 .35744 Mdot
.59 .35744 Mdot
.59 .35748 Mdot
.59 .35755 Mdot
.59 .35755 Mdot
.59 .3576 Mdot
.59 .35761 Mdot
.59 .35762 Mdot
.59 .35762 Mdot
.59 .35765 Mdot
.59 .35766 Mdot
.59 .35766 Mdot
.59 .35838 Mdot
.59 .35838 Mdot
.59 .35839 Mdot
.59 .35841 Mdot
.59 .35841 Mdot
.59 .35841 Mdot
.59 .35843 Mdot
.59 .35846 Mdot
.59 .35846 Mdot
.59 .35851 Mdot
.59 .35853 Mdot
.59 .35854 Mdot
.59 .35855 Mdot
.59 .35858 Mdot
.59 .35865 Mdot
.59 .35866 Mdot
.59 .35866 Mdot
.59 .35866 Mdot
.59 .35868 Mdot
.59 .35868 Mdot
.59 .3587 Mdot
.59 .35871 Mdot
.59 .35872 Mdot
.59 .35873 Mdot
.59 .35875 Mdot
.59 .35875 Mdot
.59 .35878 Mdot
.59 .35881 Mdot
.59 .35881 Mdot
.59 .35882 Mdot
.59 .35888 Mdot
.59 .35888 Mdot
.59 .35891 Mdot
.59 .35893 Mdot
.59 .35896 Mdot
.59 .35896 Mdot
.59 .35897 Mdot
.59 .35899 Mdot
.59 .35904 Mdot
.59 .35905 Mdot
.59 .35905 Mdot
.59 .35906 Mdot
.59 .35911 Mdot
.59 .35912 Mdot
.59 .35915 Mdot
.59 .35917 Mdot
.59 .35919 Mdot
.59 .3592 Mdot
.59 .3592 Mdot
.59 .35921 Mdot
.59 .35921 Mdot
.59 .35924 Mdot
.59 .35924 Mdot
.59 .35925 Mdot
.59 .35926 Mdot
.59 .35929 Mdot
.59 .35931 Mdot
.59 .35931 Mdot
.59 .35932 Mdot
.59 .35933 Mdot
.59 .35933 Mdot
.59 .35934 Mdot
.59 .35934 Mdot
.59 .35937 Mdot
.59 .35939 Mdot
.59 .35941 Mdot
.59 .35943 Mdot
.59 .35944 Mdot
.59 .35949 Mdot
.59 .3595 Mdot
.59 .35951 Mdot
.59 .35953 Mdot
.59 .35956 Mdot
.59 .35956 Mdot
.59 .35957 Mdot
.59 .35963 Mdot
.59 .35964 Mdot
.59 .35966 Mdot
.59 .35969 Mdot
.59 .35973 Mdot
.59 .35973 Mdot
.59 .35979 Mdot
.59 .35979 Mdot
.59 .3598 Mdot
.59 .3598 Mdot
.59 .35981 Mdot
.59 .35984 Mdot
.59 .35987 Mdot
.59 .35993 Mdot
.59 .35994 Mdot
.59 .35996 Mdot
.59 .35996 Mdot
.59 .35997 Mdot
.59 .35997 Mdot
.59 .35998 Mdot
.59 .36001 Mdot
.59 .36003 Mdot
.59 .36008 Mdot
.59 .36009 Mdot
.59 .3601 Mdot
.59 .36015 Mdot
.59 .36019 Mdot
.59 .36019 Mdot
.59 .36023 Mdot
.59 .36023 Mdot
.59 .36025 Mdot
.59 .36025 Mdot
.59 .36026 Mdot
.59 .36027 Mdot
.59 .36028 Mdot
.59 .3603 Mdot
.59 .36031 Mdot
.59 .36033 Mdot
.59 .36033 Mdot
.59 .36035 Mdot
.59 .36037 Mdot
.59 .36038 Mdot
.59 .36039 Mdot
.59 .3604 Mdot
.59 .36042 Mdot
.59 .36043 Mdot
.59 .36045 Mdot
.59 .36046 Mdot
.59 .36047 Mdot
.59 .36047 Mdot
.59 .36049 Mdot
.59 .36049 Mdot
.59 .36049 Mdot
.59 .3605 Mdot
.59 .3605 Mdot
.59 .36051 Mdot
.59 .36051 Mdot
.59 .36052 Mdot
.59 .36052 Mdot
.59 .36055 Mdot
.59 .36059 Mdot
.59 .36059 Mdot
.59 .36061 Mdot
.59 .36066 Mdot
.59 .36069 Mdot
.59 .36072 Mdot
.59 .36073 Mdot
.59 .36076 Mdot
.59 .36082 Mdot
.59 .36083 Mdot
.59 .36085 Mdot
.59 .36089 Mdot
.59 .36089 Mdot
.59 .36091 Mdot
.59 .36095 Mdot
.59 .36095 Mdot
.59 .36097 Mdot
.59 .36101 Mdot
.59 .36103 Mdot
.59 .36103 Mdot
.59 .36107 Mdot
.59 .36107 Mdot
.59 .36108 Mdot
.59 .36108 Mdot
.59 .3611 Mdot
.59 .36114 Mdot
.59 .36119 Mdot
.59 .36123 Mdot
.59 .36126 Mdot
.59 .36127 Mdot
.59 .36128 Mdot
.59 .3613 Mdot
.59 .36132 Mdot
.59 .36134 Mdot
.59 .3614 Mdot
.59 .3614 Mdot
.59 .3614 Mdot
.59 .36142 Mdot
.59 .36142 Mdot
.59 .36143 Mdot
.59 .36148 Mdot
.59 .36149 Mdot
.59 .36156 Mdot
.59 .36157 Mdot
.59 .36165 Mdot
.59 .36166 Mdot
.59 .36169 Mdot
.59 .36169 Mdot
.59 .3617 Mdot
.59 .3617 Mdot
.59 .36171 Mdot
.59 .36172 Mdot
.59 .36173 Mdot
.59 .36174 Mdot
.59 .36175 Mdot
.59 .36176 Mdot
.59 .36179 Mdot
.59 .36179 Mdot
.59 .36182 Mdot
.59 .36183 Mdot
.59 .36185 Mdot
.59 .36191 Mdot
.59 .36194 Mdot
.59 .36195 Mdot
.59 .36196 Mdot
.59 .36197 Mdot
.59 .36199 Mdot
.59 .36202 Mdot
.59 .36205 Mdot
.59 .36205 Mdot
.59 .36209 Mdot
.59 .36213 Mdot
.59 .36217 Mdot
.59 .36218 Mdot
.59 .36218 Mdot
.59 .36219 Mdot
.59 .36225 Mdot
.59 .36226 Mdot
.59 .36229 Mdot
.59 .3623 Mdot
.59 .3623 Mdot
.59 .3623 Mdot
.59 .36233 Mdot
.59 .36234 Mdot
.59 .36236 Mdot
.59 .36238 Mdot
.59 .36239 Mdot
.59 .36241 Mdot
.59 .36244 Mdot
.59 .36244 Mdot
.59 .36245 Mdot
.59 .36249 Mdot
.59 .3625 Mdot
.59 .36253 Mdot
.59 .36253 Mdot
.59 .36257 Mdot
.59 .36258 Mdot
.59 .3626 Mdot
.59 .36262 Mdot
.59 .36263 Mdot
.59 .36264 Mdot
.59 .36265 Mdot
.59 .36268 Mdot
.59 .3627 Mdot
.59 .36271 Mdot
.59 .36271 Mdot
.59 .36272 Mdot
.59 .36275 Mdot
.59 .36275 Mdot
.59 .36276 Mdot
.59 .36277 Mdot
.59 .36277 Mdot
.59 .36277 Mdot
.59 .36278 Mdot
.59 .36279 Mdot
.59 .36279 Mdot
.592 .29972 Mdot
.592 .29973 Mdot
.592 .29977 Mdot
.592 .29982 Mdot
.592 .29982 Mdot
.592 .29984 Mdot
.592 .29984 Mdot
.592 .29985 Mdot
.592 .29987 Mdot
.592 .29991 Mdot
.592 .30003 Mdot
.592 .30004 Mdot
.592 .30009 Mdot
.592 .30009 Mdot
.592 .3001 Mdot
.592 .30013 Mdot
.592 .30015 Mdot
.592 .30015 Mdot
.592 .30016 Mdot
.592 .30016 Mdot
.592 .3002 Mdot
.592 .30021 Mdot
.592 .30024 Mdot
.592 .30025 Mdot
.592 .30027 Mdot
.592 .3003 Mdot
.592 .30032 Mdot
.592 .30035 Mdot
.592 .30037 Mdot
.592 .30039 Mdot
.592 .30044 Mdot
.592 .30047 Mdot
.592 .30048 Mdot
.592 .30051 Mdot
.592 .30052 Mdot
.592 .30052 Mdot
.592 .30062 Mdot
.592 .30062 Mdot
.592 .30063 Mdot
.592 .30064 Mdot
.592 .30065 Mdot
.592 .30069 Mdot
.592 .3007 Mdot
.592 .30073 Mdot
.592 .30074 Mdot
.592 .30075 Mdot
.592 .30078 Mdot
.592 .30079 Mdot
.592 .30079 Mdot
.592 .3008 Mdot
.592 .30084 Mdot
.592 .30091 Mdot
.592 .30093 Mdot
.592 .30094 Mdot
.592 .30095 Mdot
.592 .30096 Mdot
.592 .30098 Mdot
.592 .30099 Mdot
.592 .301 Mdot
.592 .30101 Mdot
.592 .30101 Mdot
.592 .30102 Mdot
.592 .30107 Mdot
.592 .30108 Mdot
.592 .30109 Mdot
.592 .30112 Mdot
.592 .30113 Mdot
.592 .30115 Mdot
.592 .30115 Mdot
.592 .3012 Mdot
.592 .3012 Mdot
.592 .30125 Mdot
.592 .30131 Mdot
.592 .30132 Mdot
.592 .30135 Mdot
.592 .30135 Mdot
.592 .30136 Mdot
.592 .30137 Mdot
.592 .30138 Mdot
.592 .3014 Mdot
.592 .30143 Mdot
.592 .30144 Mdot
.592 .30145 Mdot
.592 .30145 Mdot
.592 .30148 Mdot
.592 .3015 Mdot
.592 .30153 Mdot
.592 .30155 Mdot
.592 .30155 Mdot
.592 .30157 Mdot
.592 .30157 Mdot
.592 .30157 Mdot
.592 .30159 Mdot
.592 .3016 Mdot
.592 .30161 Mdot
.592 .30163 Mdot
.592 .30163 Mdot
.592 .30164 Mdot
.592 .30167 Mdot
.592 .30169 Mdot
.592 .30169 Mdot
.592 .30169 Mdot
.592 .30172 Mdot
.592 .30173 Mdot
.592 .30175 Mdot
.592 .30179 Mdot
.592 .30182 Mdot
.592 .30184 Mdot
.592 .30185 Mdot
.592 .30187 Mdot
.592 .30188 Mdot
.592 .30191 Mdot
.592 .30191 Mdot
.592 .30192 Mdot
.592 .30194 Mdot
.592 .30196 Mdot
.592 .30202 Mdot
.592 .30202 Mdot
.592 .30203 Mdot
.592 .30204 Mdot
.592 .30205 Mdot
.592 .30205 Mdot
.592 .30207 Mdot
.592 .30209 Mdot
.592 .3021 Mdot
.592 .30211 Mdot
.592 .30211 Mdot
.592 .30216 Mdot
.592 .30217 Mdot
.592 .30219 Mdot
.592 .30224 Mdot
.592 .30226 Mdot
.592 .3023 Mdot
.592 .30232 Mdot
.592 .30234 Mdot
.592 .30235 Mdot
.592 .30238 Mdot
.592 .3024 Mdot
.592 .30241 Mdot
.592 .30251 Mdot
.592 .30251 Mdot
.592 .30252 Mdot
.592 .30254 Mdot
.592 .30257 Mdot
.592 .30258 Mdot
.592 .30263 Mdot
.592 .30264 Mdot
.592 .30266 Mdot
.592 .30267 Mdot
.592 .30277 Mdot
.592 .30277 Mdot
.592 .30278 Mdot
.592 .3028 Mdot
.592 .3028 Mdot
.592 .30282 Mdot
.592 .30285 Mdot
.592 .30286 Mdot
.592 .30287 Mdot
.592 .3029 Mdot
.592 .30292 Mdot
.592 .30295 Mdot
.592 .30296 Mdot
.592 .30298 Mdot
.592 .30305 Mdot
.592 .30308 Mdot
.592 .30312 Mdot
.592 .30315 Mdot
.592 .30319 Mdot
.592 .3032 Mdot
.592 .30321 Mdot
.592 .30322 Mdot
.592 .30323 Mdot
.592 .30324 Mdot
.592 .30327 Mdot
.592 .30329 Mdot
.592 .30331 Mdot
.592 .30333 Mdot
.592 .30339 Mdot
.592 .30341 Mdot
.592 .30341 Mdot
.592 .30341 Mdot
.592 .30343 Mdot
.592 .30345 Mdot
.592 .30348 Mdot
.592 .3035 Mdot
.592 .30351 Mdot
.592 .30352 Mdot
.592 .30353 Mdot
.592 .30354 Mdot
.592 .30355 Mdot
.592 .30363 Mdot
.592 .30366 Mdot
.592 .30367 Mdot
.592 .30368 Mdot
.592 .30369 Mdot
.592 .30375 Mdot
.592 .30375 Mdot
.592 .30376 Mdot
.592 .30377 Mdot
.592 .30379 Mdot
.592 .30382 Mdot
.592 .30386 Mdot
.592 .30387 Mdot
.592 .30389 Mdot
.592 .30391 Mdot
.592 .30391 Mdot
.592 .30393 Mdot
.592 .304 Mdot
.592 .30403 Mdot
.592 .30408 Mdot
.592 .30414 Mdot
.592 .30418 Mdot
.592 .30423 Mdot
.592 .30427 Mdot
.592 .30429 Mdot
.592 .30432 Mdot
.592 .30435 Mdot
.592 .30436 Mdot
.592 .30438 Mdot
.592 .30445 Mdot
.592 .30446 Mdot
.592 .30447 Mdot
.592 .30447 Mdot
.592 .3045 Mdot
.592 .30452 Mdot
.592 .30457 Mdot
.592 .30458 Mdot
.592 .30459 Mdot
.592 .30459 Mdot
.592 .3046 Mdot
.592 .30463 Mdot
.592 .30465 Mdot
.592 .30468 Mdot
.592 .30469 Mdot
.592 .30471 Mdot
.592 .30471 Mdot
.592 .30472 Mdot
.592 .30492 Mdot
.592 .30495 Mdot
.592 .30501 Mdot
.592 .30506 Mdot
.592 .30506 Mdot
.592 .30508 Mdot
.592 .30509 Mdot
.592 .30511 Mdot
.592 .30512 Mdot
.592 .30512 Mdot
.592 .30522 Mdot
.592 .30529 Mdot
.592 .30532 Mdot
.592 .30585 Mdot
.592 .30588 Mdot
.592 .30598 Mdot
.592 .30612 Mdot
.592 .30613 Mdot
.592 .30614 Mdot
.592 .30617 Mdot
.592 .30618 Mdot
.592 .30621 Mdot
.592 .30621 Mdot
.592 .30628 Mdot
.592 .30636 Mdot
.592 .30641 Mdot
.592 .30669 Mdot
.592 .3067 Mdot
.592 .3067 Mdot
.592 .30673 Mdot
.592 .30674 Mdot
.592 .30678 Mdot
.592 .30681 Mdot
.592 .30686 Mdot
.592 .30687 Mdot
.592 .30687 Mdot
.592 .30688 Mdot
.592 .3069 Mdot
.592 .30697 Mdot
.592 .30699 Mdot
.592 .30703 Mdot
.592 .30704 Mdot
.592 .30706 Mdot
.592 .30706 Mdot
.592 .30716 Mdot
.592 .30719 Mdot
.592 .30721 Mdot
.592 .30725 Mdot
.592 .30729 Mdot
.592 .30732 Mdot
.592 .30737 Mdot
.592 .30745 Mdot
.592 .3075 Mdot
.592 .30758 Mdot
.592 .30765 Mdot
.592 .30769 Mdot
.592 .30779 Mdot
.592 .30781 Mdot
.592 .30782 Mdot
.592 .30785 Mdot
.592 .30787 Mdot
.592 .30789 Mdot
.592 .30794 Mdot
.592 .30798 Mdot
.592 .30802 Mdot
.592 .30803 Mdot
.592 .30804 Mdot
.592 .30805 Mdot
.592 .30813 Mdot
.592 .30815 Mdot
.592 .30815 Mdot
.592 .30818 Mdot
.592 .30821 Mdot
.592 .30828 Mdot
.592 .30833 Mdot
.592 .30834 Mdot
.592 .30835 Mdot
.592 .30837 Mdot
.592 .30838 Mdot
.592 .3084 Mdot
.592 .30842 Mdot
.592 .30847 Mdot
.592 .30849 Mdot
.592 .30852 Mdot
.592 .30852 Mdot
.592 .30852 Mdot
.592 .30855 Mdot
.592 .30863 Mdot
.592 .30867 Mdot
.592 .30869 Mdot
.592 .30872 Mdot
.592 .30877 Mdot
.592 .30878 Mdot
.592 .30879 Mdot
.592 .3088 Mdot
.592 .30882 Mdot
.592 .30883 Mdot
.592 .30889 Mdot
.592 .30893 Mdot
.592 .30899 Mdot
.592 .30903 Mdot
.592 .30912 Mdot
.592 .30915 Mdot
.592 .30917 Mdot
.592 .30921 Mdot
.592 .30924 Mdot
.592 .30928 Mdot
.592 .30929 Mdot
.592 .30931 Mdot
.592 .30934 Mdot
.592 .30938 Mdot
.592 .30938 Mdot
.592 .3094 Mdot
.592 .30942 Mdot
.592 .30943 Mdot
.592 .30956 Mdot
.592 .30958 Mdot
.592 .3096 Mdot
.592 .30962 Mdot
.592 .30968 Mdot
.592 .3097 Mdot
.592 .30974 Mdot
.592 .30977 Mdot
.592 .30979 Mdot
.592 .30979 Mdot
.592 .30992 Mdot
.592 .30993 Mdot
.592 .30997 Mdot
.592 .31001 Mdot
.592 .31002 Mdot
.592 .31006 Mdot
.592 .31008 Mdot
.592 .31013 Mdot
.592 .31017 Mdot
.592 .31024 Mdot
.592 .31027 Mdot
.592 .31027 Mdot
.592 .31035 Mdot
.592 .31035 Mdot
.592 .31035 Mdot
.592 .31037 Mdot
.592 .31039 Mdot
.592 .31042 Mdot
.592 .31043 Mdot
.592 .31044 Mdot
.592 .31046 Mdot
.592 .31047 Mdot
.592 .31047 Mdot
.592 .31055 Mdot
.592 .31058 Mdot
.592 .31061 Mdot
.592 .31062 Mdot
.592 .31063 Mdot
.592 .31067 Mdot
.592 .31068 Mdot
.592 .31071 Mdot
.592 .31072 Mdot
.592 .31076 Mdot
.592 .31079 Mdot
.592 .31085 Mdot
.592 .31088 Mdot
.592 .31089 Mdot
.592 .31093 Mdot
.592 .31094 Mdot
.592 .31094 Mdot
.592 .31096 Mdot
.592 .31101 Mdot
.592 .31102 Mdot
.592 .31102 Mdot
.592 .31104 Mdot
.592 .31106 Mdot
.592 .31107 Mdot
.592 .31109 Mdot
.592 .31111 Mdot
.592 .31111 Mdot
.592 .31113 Mdot
.592 .31114 Mdot
.592 .31115 Mdot
.592 .3112 Mdot
.592 .31122 Mdot
.592 .31127 Mdot
.592 .31127 Mdot
.592 .31129 Mdot
.592 .3113 Mdot
.592 .31135 Mdot
.592 .31136 Mdot
.592 .31138 Mdot
.592 .3114 Mdot
.592 .3114 Mdot
.592 .31141 Mdot
.592 .31145 Mdot
.592 .31146 Mdot
.592 .31156 Mdot
.592 .31162 Mdot
.592 .31162 Mdot
.592 .31169 Mdot
.592 .31169 Mdot
.592 .31172 Mdot
.592 .31174 Mdot
.592 .31178 Mdot
.592 .31179 Mdot
.592 .3118 Mdot
.592 .31188 Mdot
.592 .31188 Mdot
.592 .31189 Mdot
.592 .3119 Mdot
.592 .31192 Mdot
.592 .31194 Mdot
.592 .31195 Mdot
.592 .31197 Mdot
.592 .31199 Mdot
.592 .31201 Mdot
.592 .31203 Mdot
.592 .31213 Mdot
.592 .31218 Mdot
.592 .31219 Mdot
.592 .3122 Mdot
.592 .31221 Mdot
.592 .31225 Mdot
.592 .31226 Mdot
.592 .31228 Mdot
.592 .31232 Mdot
.592 .31234 Mdot
.592 .31239 Mdot
.592 .31241 Mdot
.592 .31242 Mdot
.592 .31243 Mdot
.592 .31244 Mdot
.592 .31258 Mdot
.592 .31258 Mdot
.592 .31259 Mdot
.592 .31263 Mdot
.592 .31268 Mdot
.592 .31276 Mdot
.592 .31278 Mdot
.592 .31281 Mdot
.592 .31286 Mdot
.592 .31288 Mdot
.592 .31292 Mdot
.592 .31295 Mdot
.592 .31296 Mdot
.592 .31301 Mdot
.592 .31302 Mdot
.592 .31308 Mdot
.592 .31308 Mdot
.592 .31309 Mdot
.592 .31309 Mdot
.592 .31313 Mdot
.592 .31316 Mdot
.592 .31317 Mdot
.592 .31318 Mdot
.592 .31324 Mdot
.592 .31326 Mdot
.592 .31344 Mdot
.592 .31348 Mdot
.592 .31351 Mdot
.592 .31353 Mdot
.592 .31353 Mdot
.592 .31355 Mdot
.592 .31356 Mdot
.592 .31363 Mdot
.592 .31368 Mdot
.592 .3137 Mdot
.592 .35216 Mdot
.592 .35217 Mdot
.592 .35222 Mdot
.592 .35228 Mdot
.592 .35228 Mdot
.592 .3523 Mdot
.592 .3523 Mdot
.592 .35232 Mdot
.592 .35234 Mdot
.592 .35238 Mdot
.592 .35252 Mdot
.592 .35254 Mdot
.592 .3526 Mdot
.592 .3526 Mdot
.592 .35261 Mdot
.592 .35264 Mdot
.592 .35267 Mdot
.592 .35267 Mdot
.592 .35268 Mdot
.592 .35268 Mdot
.592 .35273 Mdot
.592 .35274 Mdot
.592 .35278 Mdot
.592 .35279 Mdot
.592 .35282 Mdot
.592 .35285 Mdot
.592 .35287 Mdot
.592 .35291 Mdot
.592 .35293 Mdot
.592 .35295 Mdot
.592 .35302 Mdot
.592 .35305 Mdot
.592 .35306 Mdot
.592 .35309 Mdot
.592 .3531 Mdot
.592 .35311 Mdot
.592 .35323 Mdot
.592 .35323 Mdot
.592 .35324 Mdot
.592 .35325 Mdot
.592 .35326 Mdot
.592 .35331 Mdot
.592 .35332 Mdot
.592 .35336 Mdot
.592 .35337 Mdot
.592 .35338 Mdot
.592 .35341 Mdot
.592 .35343 Mdot
.592 .35343 Mdot
.592 .35344 Mdot
.592 .35348 Mdot
.592 .35357 Mdot
.592 .35359 Mdot
.592 .35361 Mdot
.592 .35362 Mdot
.592 .35363 Mdot
.592 .35365 Mdot
.592 .35366 Mdot
.592 .35368 Mdot
.592 .35369 Mdot
.592 .35369 Mdot
.592 .3537 Mdot
.592 .35376 Mdot
.592 .35377 Mdot
.592 .35378 Mdot
.592 .35382 Mdot
.592 .35383 Mdot
.592 .35385 Mdot
.592 .35385 Mdot
.592 .35391 Mdot
.592 .35392 Mdot
.592 .35397 Mdot
.592 .35405 Mdot
.592 .35406 Mdot
.592 .35409 Mdot
.592 .3541 Mdot
.592 .3541 Mdot
.592 .35411 Mdot
.592 .35413 Mdot
.592 .35414 Mdot
.592 .35418 Mdot
.592 .35419 Mdot
.592 .35421 Mdot
.592 .35421 Mdot
.592 .35425 Mdot
.592 .35427 Mdot
.592 .35431 Mdot
.592 .35432 Mdot
.592 .35433 Mdot
.592 .35435 Mdot
.592 .35435 Mdot
.592 .35436 Mdot
.592 .35438 Mdot
.592 .35438 Mdot
.592 .3544 Mdot
.592 .35442 Mdot
.592 .35442 Mdot
.592 .35443 Mdot
.592 .35447 Mdot
.592 .35449 Mdot
.592 .35449 Mdot
.592 .3545 Mdot
.592 .35453 Mdot
.592 .35454 Mdot
.592 .35457 Mdot
.592 .35461 Mdot
.592 .35464 Mdot
.592 .35467 Mdot
.592 .35468 Mdot
.592 .35471 Mdot
.592 .35472 Mdot
.592 .35475 Mdot
.592 .35476 Mdot
.592 .35477 Mdot
.592 .35479 Mdot
.592 .35482 Mdot
.592 .35488 Mdot
.592 .35489 Mdot
.592 .35489 Mdot
.592 .35491 Mdot
.592 .35492 Mdot
.592 .35492 Mdot
.592 .35495 Mdot
.592 .35497 Mdot
.592 .35498 Mdot
.592 .35499 Mdot
.592 .35499 Mdot
.592 .35505 Mdot
.592 .35506 Mdot
.592 .35508 Mdot
.592 .35514 Mdot
.592 .35517 Mdot
.592 .35522 Mdot
.592 .35524 Mdot
.592 .35527 Mdot
.592 .35527 Mdot
.592 .35531 Mdot
.592 .35534 Mdot
.592 .35535 Mdot
.592 .35546 Mdot
.592 .35546 Mdot
.592 .35547 Mdot
.592 .3555 Mdot
.592 .35553 Mdot
.592 .35555 Mdot
.592 .3556 Mdot
.592 .35562 Mdot
.592 .35564 Mdot
.592 .35566 Mdot
.592 .35577 Mdot
.592 .35577 Mdot
.592 .35579 Mdot
.592 .3558 Mdot
.592 .35581 Mdot
.592 .35584 Mdot
.592 .35586 Mdot
.592 .35588 Mdot
.592 .35589 Mdot
.592 .35592 Mdot
.592 .35595 Mdot
.592 .35598 Mdot
.592 .356 Mdot
.592 .35603 Mdot
.592 .3561 Mdot
.592 .35614 Mdot
.592 .35619 Mdot
.592 .35622 Mdot
.592 .35627 Mdot
.592 .35628 Mdot
.592 .35629 Mdot
.592 .3563 Mdot
.592 .35632 Mdot
.592 .35632 Mdot
.592 .35636 Mdot
.592 .35639 Mdot
.592 .35641 Mdot
.592 .35644 Mdot
.592 .3565 Mdot
.592 .35653 Mdot
.592 .35653 Mdot
.592 .35653 Mdot
.592 .35655 Mdot
.592 .35657 Mdot
.592 .35662 Mdot
.592 .35664 Mdot
.592 .35665 Mdot
.592 .35666 Mdot
.592 .35667 Mdot
.592 .35668 Mdot
.592 .35669 Mdot
.592 .35673 Mdot
.592 .35679 Mdot
.592 .35682 Mdot
.592 .35684 Mdot
.592 .35685 Mdot
.592 .35686 Mdot
.592 .35693 Mdot
.592 .35694 Mdot
.592 .35694 Mdot
.592 .35695 Mdot
.592 .35698 Mdot
.592 .35702 Mdot
.592 .35706 Mdot
.592 .35708 Mdot
.592 .3571 Mdot
.592 .35713 Mdot
.592 .35713 Mdot
.592 .35715 Mdot
.592 .35723 Mdot
.592 .35727 Mdot
.592 .35732 Mdot
.592 .3574 Mdot
.592 .35744 Mdot
.592 .3575 Mdot
.592 .35755 Mdot
.592 .35757 Mdot
.592 .35761 Mdot
.592 .35764 Mdot
.592 .35766 Mdot
.592 .35768 Mdot
.592 .35777 Mdot
.592 .35777 Mdot
.592 .35778 Mdot
.592 .35779 Mdot
.592 .35782 Mdot
.592 .35784 Mdot
.592 .3579 Mdot
.592 .35792 Mdot
.592 .35793 Mdot
.592 .35793 Mdot
.592 .35794 Mdot
.592 .35798 Mdot
.592 .358 Mdot
.592 .35804 Mdot
.592 .35805 Mdot
.592 .35807 Mdot
.592 .35807 Mdot
.592 .35808 Mdot
.592 .35832 Mdot
.592 .35835 Mdot
.592 .35843 Mdot
.592 .35848 Mdot
.592 .35848 Mdot
.592 .3585 Mdot
.592 .35852 Mdot
.592 .35854 Mdot
.592 .35855 Mdot
.592 .35856 Mdot
.592 .35868 Mdot
.592 .35876 Mdot
.592 .35879 Mdot
.592 .35924 Mdot
.592 .35926 Mdot
.592 .35932 Mdot
.592 .3594 Mdot
.592 .35941 Mdot
.592 .35941 Mdot
.592 .35943 Mdot
.592 .35944 Mdot
.592 .35945 Mdot
.592 .35946 Mdot
.592 .3595 Mdot
.592 .35955 Mdot
.592 .35957 Mdot
.592 .35974 Mdot
.592 .35975 Mdot
.592 .35975 Mdot
.592 .35977 Mdot
.592 .35977 Mdot
.592 .3598 Mdot
.592 .35981 Mdot
.592 .35984 Mdot
.592 .35985 Mdot
.592 .35985 Mdot
.592 .35986 Mdot
.592 .35987 Mdot
.592 .35991 Mdot
.592 .35993 Mdot
.592 .35995 Mdot
.592 .35996 Mdot
.592 .35996 Mdot
.592 .35997 Mdot
.592 .36003 Mdot
.592 .36004 Mdot
.592 .36006 Mdot
.592 .36008 Mdot
.592 .36011 Mdot
.592 .36012 Mdot
.592 .36016 Mdot
.592 .3602 Mdot
.592 .36023 Mdot
.592 .36028 Mdot
.592 .36032 Mdot
.592 .36035 Mdot
.592 .36041 Mdot
.592 .36042 Mdot
.592 .36042 Mdot
.592 .36044 Mdot
.592 .36046 Mdot
.592 .36047 Mdot
.592 .3605 Mdot
.592 .36052 Mdot
.592 .36055 Mdot
.592 .36055 Mdot
.592 .36056 Mdot
.592 .36056 Mdot
.592 .36061 Mdot
.592 .36062 Mdot
.592 .36063 Mdot
.592 .36064 Mdot
.592 .36066 Mdot
.592 .36073 Mdot
.592 .36074 Mdot
.592 .36075 Mdot
.592 .36075 Mdot
.592 .36076 Mdot
.592 .36077 Mdot
.592 .36079 Mdot
.592 .36082 Mdot
.592 .36083 Mdot
.592 .36085 Mdot
.592 .36085 Mdot
.592 .36085 Mdot
.592 .36087 Mdot
.592 .36091 Mdot
.592 .36094 Mdot
.592 .36095 Mdot
.592 .36097 Mdot
.592 .36099 Mdot
.592 .361 Mdot
.592 .36101 Mdot
.592 .36102 Mdot
.592 .36103 Mdot
.592 .36103 Mdot
.592 .36107 Mdot
.592 .36109 Mdot
.592 .36113 Mdot
.592 .36116 Mdot
.592 .36121 Mdot
.592 .36122 Mdot
.592 .36124 Mdot
.592 .36126 Mdot
.592 .36128 Mdot
.592 .3613 Mdot
.592 .36131 Mdot
.592 .36132 Mdot
.592 .36134 Mdot
.592 .36136 Mdot
.592 .36137 Mdot
.592 .36138 Mdot
.592 .36139 Mdot
.592 .36139 Mdot
.592 .36147 Mdot
.592 .36148 Mdot
.592 .36149 Mdot
.592 .36151 Mdot
.592 .36155 Mdot
.592 .36156 Mdot
.592 .36158 Mdot
.592 .3616 Mdot
.592 .36161 Mdot
.592 .36161 Mdot
.592 .36169 Mdot
.592 .3617 Mdot
.592 .36172 Mdot
.592 .36175 Mdot
.592 .36175 Mdot
.592 .36177 Mdot
.592 .36178 Mdot
.592 .36182 Mdot
.592 .36184 Mdot
.592 .36188 Mdot
.592 .3619 Mdot
.592 .3619 Mdot
.592 .36195 Mdot
.592 .36195 Mdot
.592 .36195 Mdot
.592 .36196 Mdot
.592 .36198 Mdot
.592 .36199 Mdot
.592 .362 Mdot
.592 .362 Mdot
.592 .36201 Mdot
.592 .36202 Mdot
.592 .36202 Mdot
.592 .36207 Mdot
.592 .36209 Mdot
.592 .3621 Mdot
.592 .36211 Mdot
.592 .36212 Mdot
.592 .36214 Mdot
.592 .36215 Mdot
.592 .36217 Mdot
.592 .36217 Mdot
.592 .36219 Mdot
.592 .36222 Mdot
.592 .36225 Mdot
.592 .36227 Mdot
.592 .36227 Mdot
.592 .3623 Mdot
.592 .3623 Mdot
.592 .3623 Mdot
.592 .36232 Mdot
.592 .36234 Mdot
.592 .36235 Mdot
.592 .36235 Mdot
.592 .36237 Mdot
.592 .36238 Mdot
.592 .36238 Mdot
.592 .3624 Mdot
.592 .3624 Mdot
.592 .36241 Mdot
.592 .36242 Mdot
.592 .36242 Mdot
.592 .36243 Mdot
.592 .36246 Mdot
.592 .36247 Mdot
.592 .3625 Mdot
.592 .36251 Mdot
.592 .36251 Mdot
.592 .36252 Mdot
.592 .36255 Mdot
.592 .36256 Mdot
.592 .36257 Mdot
.592 .36258 Mdot
.592 .36258 Mdot
.592 .36259 Mdot
.592 .36261 Mdot
.592 .36262 Mdot
.592 .36268 Mdot
.592 .36271 Mdot
.592 .36272 Mdot
.592 .36276 Mdot
.592 .36276 Mdot
.592 .36277 Mdot
.592 .36278 Mdot
.592 .36281 Mdot
.592 .36282 Mdot
.592 .36282 Mdot
.592 .36287 Mdot
.592 .36287 Mdot
.592 .36288 Mdot
.592 .36288 Mdot
.592 .36289 Mdot
.592 .3629 Mdot
.592 .36291 Mdot
.592 .36293 Mdot
.592 .36293 Mdot
.592 .36295 Mdot
.592 .36296 Mdot
.592 .36302 Mdot
.592 .36305 Mdot
.592 .36306 Mdot
.592 .36306 Mdot
.592 .36307 Mdot
.592 .36309 Mdot
.592 .3631 Mdot
.592 .36311 Mdot
.592 .36314 Mdot
.592 .36315 Mdot
.592 .36318 Mdot
.592 .36319 Mdot
.592 .36319 Mdot
.592 .3632 Mdot
.592 .36321 Mdot
.592 .36329 Mdot
.592 .36329 Mdot
.592 .3633 Mdot
.592 .36332 Mdot
.592 .36333 Mdot
.592 .36335 Mdot
.592 .3634 Mdot
.592 .36341 Mdot
.592 .36343 Mdot
.592 .36346 Mdot
.592 .36347 Mdot
.592 .3635 Mdot
.592 .36352 Mdot
.592 .36352 Mdot
.592 .36355 Mdot
.592 .36356 Mdot
.592 .36359 Mdot
.592 .36359 Mdot
.592 .3636 Mdot
.592 .3636 Mdot
.592 .36362 Mdot
.592 .36364 Mdot
.592 .36365 Mdot
.592 .36365 Mdot
.592 .36369 Mdot
.592 .36371 Mdot
.592 .36381 Mdot
.592 .36383 Mdot
.592 .36385 Mdot
.592 .36386 Mdot
.592 .36387 Mdot
.592 .36388 Mdot
.592 .36388 Mdot
.592 .36392 Mdot
.592 .36396 Mdot
.592 .36397 Mdot
.594 .29931 Mdot
.594 .29933 Mdot
.594 .29934 Mdot
.594 .29936 Mdot
.594 .29938 Mdot
.594 .29939 Mdot
.594 .2994 Mdot
.594 .29945 Mdot
.594 .29948 Mdot
.594 .2995 Mdot
.594 .29953 Mdot
.594 .29954 Mdot
.594 .2996 Mdot
.594 .29962 Mdot
.594 .29963 Mdot
.594 .2997 Mdot
.594 .2997 Mdot
.594 .29972 Mdot
.594 .29972 Mdot
.594 .29972 Mdot
.594 .29975 Mdot
.594 .2998 Mdot
.594 .29981 Mdot
.594 .29982 Mdot
.594 .29982 Mdot
.594 .29986 Mdot
.594 .29987 Mdot
.594 .29989 Mdot
.594 .29989 Mdot
.594 .2999 Mdot
.594 .29993 Mdot
.594 .29995 Mdot
.594 .29997 Mdot
.594 .29999 Mdot
.594 .30008 Mdot
.594 .30018 Mdot
.594 .30019 Mdot
.594 .30025 Mdot
.594 .30026 Mdot
.594 .30027 Mdot
.594 .30028 Mdot
.594 .30028 Mdot
.594 .30031 Mdot
.594 .30039 Mdot
.594 .3004 Mdot
.594 .30043 Mdot
.594 .30043 Mdot
.594 .30049 Mdot
.594 .30053 Mdot
.594 .30055 Mdot
.594 .30058 Mdot
.594 .30062 Mdot
.594 .30063 Mdot
.594 .30063 Mdot
.594 .30063 Mdot
.594 .30063 Mdot
.594 .30065 Mdot
.594 .30067 Mdot
.594 .30067 Mdot
.594 .30068 Mdot
.594 .30072 Mdot
.594 .30074 Mdot
.594 .30076 Mdot
.594 .30077 Mdot
.594 .30077 Mdot
.594 .30081 Mdot
.594 .30081 Mdot
.594 .30085 Mdot
.594 .30087 Mdot
.594 .30089 Mdot
.594 .3009 Mdot
.594 .30092 Mdot
.594 .30095 Mdot
.594 .30096 Mdot
.594 .30103 Mdot
.594 .30104 Mdot
.594 .30108 Mdot
.594 .30112 Mdot
.594 .30114 Mdot
.594 .30115 Mdot
.594 .30115 Mdot
.594 .30119 Mdot
.594 .30119 Mdot
.594 .30121 Mdot
.594 .30126 Mdot
.594 .30126 Mdot
.594 .30127 Mdot
.594 .30129 Mdot
.594 .3013 Mdot
.594 .30131 Mdot
.594 .30134 Mdot
.594 .30134 Mdot
.594 .30135 Mdot
.594 .30136 Mdot
.594 .30137 Mdot
.594 .30138 Mdot
.594 .30142 Mdot
.594 .30146 Mdot
.594 .30149 Mdot
.594 .3015 Mdot
.594 .30156 Mdot
.594 .30157 Mdot
.594 .30158 Mdot
.594 .30161 Mdot
.594 .30162 Mdot
.594 .30162 Mdot
.594 .30163 Mdot
.594 .30163 Mdot
.594 .30163 Mdot
.594 .30163 Mdot
.594 .30167 Mdot
.594 .30168 Mdot
.594 .30173 Mdot
.594 .30174 Mdot
.594 .3018 Mdot
.594 .30181 Mdot
.594 .30182 Mdot
.594 .30196 Mdot
.594 .30198 Mdot
.594 .30204 Mdot
.594 .30207 Mdot
.594 .30208 Mdot
.594 .30209 Mdot
.594 .30213 Mdot
.594 .30214 Mdot
.594 .30217 Mdot
.594 .30225 Mdot
.594 .30225 Mdot
.594 .30228 Mdot
.594 .30233 Mdot
.594 .30235 Mdot
.594 .30236 Mdot
.594 .30237 Mdot
.594 .3024 Mdot
.594 .30242 Mdot
.594 .30243 Mdot
.594 .30244 Mdot
.594 .30248 Mdot
.594 .30252 Mdot
.594 .30253 Mdot
.594 .30254 Mdot
.594 .30257 Mdot
.594 .30258 Mdot
.594 .30259 Mdot
.594 .30261 Mdot
.594 .30261 Mdot
.594 .30262 Mdot
.594 .30262 Mdot
.594 .30263 Mdot
.594 .30265 Mdot
.594 .30267 Mdot
.594 .30271 Mdot
.594 .30276 Mdot
.594 .30277 Mdot
.594 .30281 Mdot
.594 .30281 Mdot
.594 .30283 Mdot
.594 .30288 Mdot
.594 .30289 Mdot
.594 .30292 Mdot
.594 .30297 Mdot
.594 .30301 Mdot
.594 .30302 Mdot
.594 .30306 Mdot
.594 .30306 Mdot
.594 .30308 Mdot
.594 .30308 Mdot
.594 .3031 Mdot
.594 .30313 Mdot
.594 .30314 Mdot
.594 .30315 Mdot
.594 .30319 Mdot
.594 .30322 Mdot
.594 .30325 Mdot
.594 .30331 Mdot
.594 .30332 Mdot
.594 .30333 Mdot
.594 .30335 Mdot
.594 .30335 Mdot
.594 .30337 Mdot
.594 .30339 Mdot
.594 .30346 Mdot
.594 .30349 Mdot
.594 .30349 Mdot
.594 .30349 Mdot
.594 .30349 Mdot
.594 .30349 Mdot
.594 .30351 Mdot
.594 .30352 Mdot
.594 .30355 Mdot
.594 .30359 Mdot
.594 .30372 Mdot
.594 .30375 Mdot
.594 .30382 Mdot
.594 .30387 Mdot
.594 .30389 Mdot
.594 .30389 Mdot
.594 .30392 Mdot
.594 .30397 Mdot
.594 .30397 Mdot
.594 .30401 Mdot
.594 .30402 Mdot
.594 .30406 Mdot
.594 .30409 Mdot
.594 .3041 Mdot
.594 .30412 Mdot
.594 .30414 Mdot
.594 .30416 Mdot
.594 .30421 Mdot
.594 .30422 Mdot
.594 .30423 Mdot
.594 .30424 Mdot
.594 .30425 Mdot
.594 .30426 Mdot
.594 .30428 Mdot
.594 .30429 Mdot
.594 .30436 Mdot
.594 .30438 Mdot
.594 .30441 Mdot
.594 .30443 Mdot
.594 .30443 Mdot
.594 .30443 Mdot
.594 .30443 Mdot
.594 .30444 Mdot
.594 .30446 Mdot
.594 .30448 Mdot
.594 .30456 Mdot
.594 .30459 Mdot
.594 .30462 Mdot
.594 .30463 Mdot
.594 .30467 Mdot
.594 .30477 Mdot
.594 .30479 Mdot
.594 .30481 Mdot
.594 .30481 Mdot
.594 .30483 Mdot
.594 .30486 Mdot
.594 .30489 Mdot
.594 .3049 Mdot
.594 .3049 Mdot
.594 .30496 Mdot
.594 .30498 Mdot
.594 .30507 Mdot
.594 .30509 Mdot
.594 .3051 Mdot
.594 .30513 Mdot
.594 .30514 Mdot
.594 .30518 Mdot
.594 .3052 Mdot
.594 .30525 Mdot
.594 .30554 Mdot
.594 .30561 Mdot
.594 .30565 Mdot
.594 .30571 Mdot
.594 .30571 Mdot
.594 .30576 Mdot
.594 .30577 Mdot
.594 .3058 Mdot
.594 .30593 Mdot
.594 .30595 Mdot
.594 .30603 Mdot
.594 .30604 Mdot
.594 .30605 Mdot
.594 .30609 Mdot
.594 .30614 Mdot
.594 .30617 Mdot
.594 .30617 Mdot
.594 .3062 Mdot
.594 .30623 Mdot
.594 .30636 Mdot
.594 .30642 Mdot
.594 .30644 Mdot
.594 .30647 Mdot
.594 .30652 Mdot
.594 .30664 Mdot
.594 .30666 Mdot
.594 .30669 Mdot
.594 .3067 Mdot
.594 .30671 Mdot
.594 .30671 Mdot
.594 .30671 Mdot
.594 .30673 Mdot
.594 .30678 Mdot
.594 .30681 Mdot
.594 .3069 Mdot
.594 .30692 Mdot
.594 .30695 Mdot
.594 .30696 Mdot
.594 .30696 Mdot
.594 .30698 Mdot
.594 .307 Mdot
.594 .30701 Mdot
.594 .30708 Mdot
.594 .30711 Mdot
.594 .30714 Mdot
.594 .30717 Mdot
.594 .30719 Mdot
.594 .30722 Mdot
.594 .30729 Mdot
.594 .3073 Mdot
.594 .30735 Mdot
.594 .30736 Mdot
.594 .30742 Mdot
.594 .30746 Mdot
.594 .30747 Mdot
.594 .3075 Mdot
.594 .30756 Mdot
.594 .30766 Mdot
.594 .30771 Mdot
.594 .3079 Mdot
.594 .30794 Mdot
.594 .30799 Mdot
.594 .308 Mdot
.594 .30803 Mdot
.594 .30803 Mdot
.594 .30803 Mdot
.594 .30803 Mdot
.594 .30803 Mdot
.594 .30807 Mdot
.594 .30817 Mdot
.594 .3082 Mdot
.594 .30823 Mdot
.594 .30823 Mdot
.594 .30825 Mdot
.594 .30827 Mdot
.594 .30829 Mdot
.594 .30837 Mdot
.594 .30842 Mdot
.594 .30845 Mdot
.594 .30851 Mdot
.594 .30853 Mdot
.594 .30854 Mdot
.594 .30858 Mdot
.594 .3086 Mdot
.594 .3086 Mdot
.594 .30863 Mdot
.594 .30864 Mdot
.594 .3087 Mdot
.594 .3087 Mdot
.594 .30877 Mdot
.594 .30883 Mdot
.594 .30888 Mdot
.594 .30889 Mdot
.594 .30896 Mdot
.594 .30898 Mdot
.594 .30899 Mdot
.594 .30904 Mdot
.594 .30905 Mdot
.594 .30912 Mdot
.594 .30919 Mdot
.594 .30921 Mdot
.594 .30925 Mdot
.594 .30926 Mdot
.594 .30926 Mdot
.594 .30927 Mdot
.594 .30928 Mdot
.594 .30931 Mdot
.594 .30931 Mdot
.594 .30932 Mdot
.594 .30938 Mdot
.594 .30938 Mdot
.594 .30939 Mdot
.594 .30945 Mdot
.594 .30951 Mdot
.594 .30953 Mdot
.594 .30955 Mdot
.594 .30957 Mdot
.594 .30961 Mdot
.594 .30963 Mdot
.594 .30964 Mdot
.594 .30967 Mdot
.594 .30974 Mdot
.594 .30978 Mdot
.594 .30978 Mdot
.594 .30989 Mdot
.594 .30993 Mdot
.594 .30995 Mdot
.594 .31 Mdot
.594 .31001 Mdot
.594 .31003 Mdot
.594 .31008 Mdot
.594 .31016 Mdot
.594 .31019 Mdot
.594 .31039 Mdot
.594 .3104 Mdot
.594 .31041 Mdot
.594 .31049 Mdot
.594 .31052 Mdot
.594 .31059 Mdot
.594 .3106 Mdot
.594 .31066 Mdot
.594 .31066 Mdot
.594 .31066 Mdot
.594 .31066 Mdot
.594 .31066 Mdot
.594 .31067 Mdot
.594 .31069 Mdot
.594 .31072 Mdot
.594 .31074 Mdot
.594 .31075 Mdot
.594 .31083 Mdot
.594 .31085 Mdot
.594 .31089 Mdot
.594 .31095 Mdot
.594 .31101 Mdot
.594 .31103 Mdot
.594 .31103 Mdot
.594 .31105 Mdot
.594 .31106 Mdot
.594 .31107 Mdot
.594 .3111 Mdot
.594 .31111 Mdot
.594 .31114 Mdot
.594 .31116 Mdot
.594 .31118 Mdot
.594 .31118 Mdot
.594 .31125 Mdot
.594 .31127 Mdot
.594 .31128 Mdot
.594 .31133 Mdot
.594 .31133 Mdot
.594 .31135 Mdot
.594 .31137 Mdot
.594 .31144 Mdot
.594 .31149 Mdot
.594 .3115 Mdot
.594 .3116 Mdot
.594 .31162 Mdot
.594 .31166 Mdot
.594 .31169 Mdot
.594 .3117 Mdot
.594 .31172 Mdot
.594 .31175 Mdot
.594 .31181 Mdot
.594 .31181 Mdot
.594 .31186 Mdot
.594 .31188 Mdot
.594 .31188 Mdot
.594 .31191 Mdot
.594 .31194 Mdot
.594 .312 Mdot
.594 .31201 Mdot
.594 .31201 Mdot
.594 .31204 Mdot
.594 .31206 Mdot
.594 .31206 Mdot
.594 .31207 Mdot
.594 .31207 Mdot
.594 .31207 Mdot
.594 .31214 Mdot
.594 .31218 Mdot
.594 .31221 Mdot
.594 .31226 Mdot
.594 .31235 Mdot
.594 .31235 Mdot
.594 .31238 Mdot
.594 .3124 Mdot
.594 .31251 Mdot
.594 .31256 Mdot
.594 .31257 Mdot
.594 .31258 Mdot
.594 .31259 Mdot
.594 .3126 Mdot
.594 .31269 Mdot
.594 .31271 Mdot
.594 .31285 Mdot
.594 .31297 Mdot
.594 .31299 Mdot
.594 .31302 Mdot
.594 .31306 Mdot
.594 .31309 Mdot
.594 .31311 Mdot
.594 .31312 Mdot
.594 .31313 Mdot
.594 .31315 Mdot
.594 .31321 Mdot
.594 .31321 Mdot
.594 .31323 Mdot
.594 .31324 Mdot
.594 .31331 Mdot
.594 .31335 Mdot
.594 .31335 Mdot
.594 .31335 Mdot
.594 .31337 Mdot
.594 .31338 Mdot
.594 .31348 Mdot
.594 .31349 Mdot
.594 .31352 Mdot
.594 .31361 Mdot
.594 .31362 Mdot
.594 .31366 Mdot
.594 .31368 Mdot
.594 .31373 Mdot
.594 .3138 Mdot
.594 .31382 Mdot
.594 .31383 Mdot
.594 .31385 Mdot
.594 .31388 Mdot
.594 .3139 Mdot
.594 .31393 Mdot
.594 .35281 Mdot
.594 .35284 Mdot
.594 .35285 Mdot
.594 .35288 Mdot
.594 .3529 Mdot
.594 .35291 Mdot
.594 .35292 Mdot
.594 .35298 Mdot
.594 .35302 Mdot
.594 .35304 Mdot
.594 .35307 Mdot
.594 .35309 Mdot
.594 .35316 Mdot
.594 .35318 Mdot
.594 .35319 Mdot
.594 .35327 Mdot
.594 .35328 Mdot
.594 .3533 Mdot
.594 .3533 Mdot
.594 .3533 Mdot
.594 .35333 Mdot
.594 .35339 Mdot
.594 .3534 Mdot
.594 .35342 Mdot
.594 .35342 Mdot
.594 .35347 Mdot
.594 .35348 Mdot
.594 .3535 Mdot
.594 .3535 Mdot
.594 .35352 Mdot
.594 .35355 Mdot
.594 .35358 Mdot
.594 .3536 Mdot
.594 .35362 Mdot
.594 .35373 Mdot
.594 .35384 Mdot
.594 .35386 Mdot
.594 .35393 Mdot
.594 .35394 Mdot
.594 .35395 Mdot
.594 .35396 Mdot
.594 .35397 Mdot
.594 .35401 Mdot
.594 .3541 Mdot
.594 .35411 Mdot
.594 .35414 Mdot
.594 .35415 Mdot
.594 .35422 Mdot
.594 .35426 Mdot
.594 .35429 Mdot
.594 .35432 Mdot
.594 .35438 Mdot
.594 .35438 Mdot
.594 .35438 Mdot
.594 .35438 Mdot
.594 .35439 Mdot
.594 .3544 Mdot
.594 .35443 Mdot
.594 .35443 Mdot
.594 .35444 Mdot
.594 .35449 Mdot
.594 .35451 Mdot
.594 .35454 Mdot
.594 .35454 Mdot
.594 .35455 Mdot
.594 .3546 Mdot
.594 .3546 Mdot
.594 .35464 Mdot
.594 .35467 Mdot
.594 .35469 Mdot
.594 .3547 Mdot
.594 .35472 Mdot
.594 .35476 Mdot
.594 .35478 Mdot
.594 .35486 Mdot
.594 .35487 Mdot
.594 .35491 Mdot
.594 .35497 Mdot
.594 .35498 Mdot
.594 .355 Mdot
.594 .355 Mdot
.594 .35504 Mdot
.594 .35505 Mdot
.594 .35507 Mdot
.594 .35513 Mdot
.594 .35513 Mdot
.594 .35515 Mdot
.594 .35516 Mdot
.594 .35518 Mdot
.594 .35519 Mdot
.594 .35522 Mdot
.594 .35523 Mdot
.594 .35523 Mdot
.594 .35525 Mdot
.594 .35526 Mdot
.594 .35527 Mdot
.594 .35532 Mdot
.594 .35537 Mdot
.594 .35541 Mdot
.594 .35542 Mdot
.594 .35549 Mdot
.594 .3555 Mdot
.594 .35551 Mdot
.594 .35554 Mdot
.594 .35556 Mdot
.594 .35556 Mdot
.594 .35557 Mdot
.594 .35557 Mdot
.594 .35557 Mdot
.594 .35557 Mdot
.594 .35561 Mdot
.594 .35563 Mdot
.594 .35568 Mdot
.594 .35571 Mdot
.594 .35577 Mdot
.594 .35579 Mdot
.594 .35579 Mdot
.594 .35596 Mdot
.594 .35599 Mdot
.594 .35606 Mdot
.594 .35609 Mdot
.594 .35611 Mdot
.594 .35612 Mdot
.594 .35617 Mdot
.594 .35618 Mdot
.594 .35622 Mdot
.594 .35631 Mdot
.594 .35631 Mdot
.594 .35634 Mdot
.594 .3564 Mdot
.594 .35642 Mdot
.594 .35643 Mdot
.594 .35645 Mdot
.594 .35648 Mdot
.594 .3565 Mdot
.594 .35651 Mdot
.594 .35653 Mdot
.594 .35658 Mdot
.594 .35663 Mdot
.594 .35664 Mdot
.594 .35665 Mdot
.594 .35669 Mdot
.594 .3567 Mdot
.594 .35671 Mdot
.594 .35673 Mdot
.594 .35674 Mdot
.594 .35674 Mdot
.594 .35675 Mdot
.594 .35675 Mdot
.594 .35678 Mdot
.594 .35681 Mdot
.594 .35686 Mdot
.594 .35692 Mdot
.594 .35693 Mdot
.594 .35697 Mdot
.594 .35698 Mdot
.594 .357 Mdot
.594 .35705 Mdot
.594 .35707 Mdot
.594 .35711 Mdot
.594 .35716 Mdot
.594 .35721 Mdot
.594 .35722 Mdot
.594 .35727 Mdot
.594 .35727 Mdot
.594 .3573 Mdot
.594 .3573 Mdot
.594 .35732 Mdot
.594 .35735 Mdot
.594 .35736 Mdot
.594 .35738 Mdot
.594 .35743 Mdot
.594 .35745 Mdot
.594 .35749 Mdot
.594 .35756 Mdot
.594 .35758 Mdot
.594 .35759 Mdot
.594 .35761 Mdot
.594 .35762 Mdot
.594 .35763 Mdot
.594 .35766 Mdot
.594 .35774 Mdot
.594 .35778 Mdot
.594 .35778 Mdot
.594 .35778 Mdot
.594 .35778 Mdot
.594 .35778 Mdot
.594 .35781 Mdot
.594 .35781 Mdot
.594 .35785 Mdot
.594 .35789 Mdot
.594 .35805 Mdot
.594 .35809 Mdot
.594 .35817 Mdot
.594 .35823 Mdot
.594 .35825 Mdot
.594 .35826 Mdot
.594 .35829 Mdot
.594 .35835 Mdot
.594 .35835 Mdot
.594 .35839 Mdot
.594 .3584 Mdot
.594 .35846 Mdot
.594 .35849 Mdot
.594 .3585 Mdot
.594 .35853 Mdot
.594 .35855 Mdot
.594 .35858 Mdot
.594 .35864 Mdot
.594 .35865 Mdot
.594 .35866 Mdot
.594 .35868 Mdot
.594 .35868 Mdot
.594 .35869 Mdot
.594 .35872 Mdot
.594 .35873 Mdot
.594 .35881 Mdot
.594 .35883 Mdot
.594 .35888 Mdot
.594 .35889 Mdot
.594 .35889 Mdot
.594 .3589 Mdot
.594 .3589 Mdot
.594 .35891 Mdot
.594 .35893 Mdot
.594 .35895 Mdot
.594 .35905 Mdot
.594 .35909 Mdot
.594 .35912 Mdot
.594 .35913 Mdot
.594 .35918 Mdot
.594 .3593 Mdot
.594 .35932 Mdot
.594 .35934 Mdot
.594 .35935 Mdot
.594 .35937 Mdot
.594 .35941 Mdot
.594 .35944 Mdot
.594 .35945 Mdot
.594 .35946 Mdot
.594 .35953 Mdot
.594 .35955 Mdot
.594 .35965 Mdot
.594 .35968 Mdot
.594 .35969 Mdot
.594 .35973 Mdot
.594 .35974 Mdot
.594 .35978 Mdot
.594 .35981 Mdot
.594 .35987 Mdot
.594 .36012 Mdot
.594 .36016 Mdot
.594 .36018 Mdot
.594 .36021 Mdot
.594 .36022 Mdot
.594 .36025 Mdot
.594 .36026 Mdot
.594 .36027 Mdot
.594 .3603 Mdot
.594 .36035 Mdot
.594 .36036 Mdot
.594 .36041 Mdot
.594 .36042 Mdot
.594 .36042 Mdot
.594 .36045 Mdot
.594 .36047 Mdot
.594 .36049 Mdot
.594 .36049 Mdot
.594 .36051 Mdot
.594 .36053 Mdot
.594 .36061 Mdot
.594 .36064 Mdot
.594 .36065 Mdot
.594 .36067 Mdot
.594 .3607 Mdot
.594 .36077 Mdot
.594 .36079 Mdot
.594 .3608 Mdot
.594 .36081 Mdot
.594 .36081 Mdot
.594 .36081 Mdot
.594 .36081 Mdot
.594 .36083 Mdot
.594 .36085 Mdot
.594 .36087 Mdot
.594 .36093 Mdot
.594 .36094 Mdot
.594 .36095 Mdot
.594 .36096 Mdot
.594 .36097 Mdot
.594 .36098 Mdot
.594 .36098 Mdot
.594 .36099 Mdot
.594 .36103 Mdot
.594 .36105 Mdot
.594 .36107 Mdot
.594 .36109 Mdot
.594 .3611 Mdot
.594 .36112 Mdot
.594 .36116 Mdot
.594 .36117 Mdot
.594 .36119 Mdot
.594 .3612 Mdot
.594 .36124 Mdot
.594 .36126 Mdot
.594 .36127 Mdot
.594 .36128 Mdot
.594 .36132 Mdot
.594 .36138 Mdot
.594 .36141 Mdot
.594 .36152 Mdot
.594 .36155 Mdot
.594 .36158 Mdot
.594 .36158 Mdot
.594 .3616 Mdot
.594 .3616 Mdot
.594 .3616 Mdot
.594 .3616 Mdot
.594 .3616 Mdot
.594 .36163 Mdot
.594 .36169 Mdot
.594 .3617 Mdot
.594 .36172 Mdot
.594 .36172 Mdot
.594 .36173 Mdot
.594 .36174 Mdot
.594 .36176 Mdot
.594 .36181 Mdot
.594 .36183 Mdot
.594 .36185 Mdot
.594 .36189 Mdot
.594 .3619 Mdot
.594 .36191 Mdot
.594 .36193 Mdot
.594 .36194 Mdot
.594 .36194 Mdot
.594 .36196 Mdot
.594 .36196 Mdot
.594 .362 Mdot
.594 .362 Mdot
.594 .36204 Mdot
.594 .36208 Mdot
.594 .36211 Mdot
.594 .36212 Mdot
.594 .36215 Mdot
.594 .36217 Mdot
.594 .36217 Mdot
.594 .36221 Mdot
.594 .36221 Mdot
.594 .36225 Mdot
.594 .36229 Mdot
.594 .36231 Mdot
.594 .36233 Mdot
.594 .36233 Mdot
.594 .36234 Mdot
.594 .36234 Mdot
.594 .36234 Mdot
.594 .36236 Mdot
.594 .36236 Mdot
.594 .36237 Mdot
.594 .3624 Mdot
.594 .36241 Mdot
.594 .36242 Mdot
.594 .36245 Mdot
.594 .36249 Mdot
.594 .3625 Mdot
.594 .36251 Mdot
.594 .36252 Mdot
.594 .36254 Mdot
.594 .36256 Mdot
.594 .36256 Mdot
.594 .36258 Mdot
.594 .36262 Mdot
.594 .36264 Mdot
.594 .36264 Mdot
.594 .36271 Mdot
.594 .36273 Mdot
.594 .36275 Mdot
.594 .36278 Mdot
.594 .36278 Mdot
.594 .3628 Mdot
.594 .36282 Mdot
.594 .36287 Mdot
.594 .36289 Mdot
.594 .36301 Mdot
.594 .36301 Mdot
.594 .36302 Mdot
.594 .36307 Mdot
.594 .36309 Mdot
.594 .36313 Mdot
.594 .36314 Mdot
.594 .36317 Mdot
.594 .36317 Mdot
.594 .36317 Mdot
.594 .36317 Mdot
.594 .36317 Mdot
.594 .36318 Mdot
.594 .36319 Mdot
.594 .36321 Mdot
.594 .36322 Mdot
.594 .36322 Mdot
.594 .36327 Mdot
.594 .36328 Mdot
.594 .36331 Mdot
.594 .36334 Mdot
.594 .36338 Mdot
.594 .36339 Mdot
.594 .36339 Mdot
.594 .36341 Mdot
.594 .36341 Mdot
.594 .36341 Mdot
.594 .36343 Mdot
.594 .36344 Mdot
.594 .36345 Mdot
.594 .36347 Mdot
.594 .36348 Mdot
.594 .36348 Mdot
.594 .36352 Mdot
.594 .36354 Mdot
.594 .36354 Mdot
.594 .36357 Mdot
.594 .36357 Mdot
.594 .36358 Mdot
.594 .36359 Mdot
.594 .36363 Mdot
.594 .36366 Mdot
.594 .36367 Mdot
.594 .36373 Mdot
.594 .36374 Mdot
.594 .36377 Mdot
.594 .36378 Mdot
.594 .36379 Mdot
.594 .3638 Mdot
.594 .36382 Mdot
.594 .36385 Mdot
.594 .36386 Mdot
.594 .36389 Mdot
.594 .36389 Mdot
.594 .3639 Mdot
.594 .36392 Mdot
.594 .36393 Mdot
.594 .36397 Mdot
.594 .36397 Mdot
.594 .36397 Mdot
.594 .364 Mdot
.594 .36401 Mdot
.594 .36401 Mdot
.594 .36401 Mdot
.594 .36401 Mdot
.594 .36401 Mdot
.594 .36405 Mdot
.594 .36407 Mdot
.594 .36409 Mdot
.594 .36413 Mdot
.594 .36418 Mdot
.594 .36418 Mdot
.594 .3642 Mdot
.594 .36421 Mdot
.594 .36428 Mdot
.594 .3643 Mdot
.594 .36431 Mdot
.594 .36431 Mdot
.594 .36432 Mdot
.594 .36433 Mdot
.594 .36438 Mdot
.594 .36439 Mdot
.594 .36447 Mdot
.594 .36455 Mdot
.594 .36456 Mdot
.594 .36458 Mdot
.594 .3646 Mdot
.594 .36462 Mdot
.594 .36463 Mdot
.594 .36463 Mdot
.594 .36464 Mdot
.594 .36465 Mdot
.594 .36469 Mdot
.594 .36469 Mdot
.594 .3647 Mdot
.594 .36471 Mdot
.594 .36475 Mdot
.594 .36477 Mdot
.594 .36477 Mdot
.594 .36478 Mdot
.594 .36479 Mdot
.594 .36479 Mdot
.594 .36485 Mdot
.594 .36486 Mdot
.594 .36488 Mdot
.594 .36493 Mdot
.594 .36494 Mdot
.594 .36496 Mdot
.594 .36497 Mdot
.594 .365 Mdot
.594 .36505 Mdot
.594 .36505 Mdot
.594 .36506 Mdot
.594 .36507 Mdot
.594 .36509 Mdot
.594 .3651 Mdot
.594 .36512 Mdot
.596 .29886 Mdot
.596 .29886 Mdot
.596 .29888 Mdot
.596 .2989 Mdot
.596 .29894 Mdot
.596 .29895 Mdot
.596 .29897 Mdot
.596 .299 Mdot
.596 .299 Mdot
.596 .29903 Mdot
.596 .29909 Mdot
.596 .29911 Mdot
.596 .29913 Mdot
.596 .29926 Mdot
.596 .29926 Mdot
.596 .29926 Mdot
.596 .29927 Mdot
.596 .29928 Mdot
.596 .29929 Mdot
.596 .29929 Mdot
.596 .29929 Mdot
.596 .2993 Mdot
.596 .29933 Mdot
.596 .29941 Mdot
.596 .29941 Mdot
.596 .29945 Mdot
.596 .2995 Mdot
.596 .29952 Mdot
.596 .29958 Mdot
.596 .2996 Mdot
.596 .2996 Mdot
.596 .29968 Mdot
.596 .29969 Mdot
.596 .29975 Mdot
.596 .29982 Mdot
.596 .29993 Mdot
.596 .29993 Mdot
.596 .29996 Mdot
.596 .29997 Mdot
.596 .30002 Mdot
.596 .30007 Mdot
.596 .30008 Mdot
.596 .3001 Mdot
.596 .30011 Mdot
.596 .30012 Mdot
.596 .30013 Mdot
.596 .30013 Mdot
.596 .30013 Mdot
.596 .30013 Mdot
.596 .30014 Mdot
.596 .30015 Mdot
.596 .3002 Mdot
.596 .30022 Mdot
.596 .30029 Mdot
.596 .30034 Mdot
.596 .30038 Mdot
.596 .30043 Mdot
.596 .30046 Mdot
.596 .30048 Mdot
.596 .30048 Mdot
.596 .30051 Mdot
.596 .30052 Mdot
.596 .30056 Mdot
.596 .30057 Mdot
.596 .30062 Mdot
.596 .30064 Mdot
.596 .30066 Mdot
.596 .30066 Mdot
.596 .30072 Mdot
.596 .30075 Mdot
.596 .30077 Mdot
.596 .30081 Mdot
.596 .30085 Mdot
.596 .30085 Mdot
.596 .30089 Mdot
.596 .3009 Mdot
.596 .30092 Mdot
.596 .30095 Mdot
.596 .30104 Mdot
.596 .30108 Mdot
.596 .3011 Mdot
.596 .30113 Mdot
.596 .30113 Mdot
.596 .30114 Mdot
.596 .30115 Mdot
.596 .30118 Mdot
.596 .30121 Mdot
.596 .30122 Mdot
.596 .30123 Mdot
.596 .30125 Mdot
.596 .30131 Mdot
.596 .30139 Mdot
.596 .3014 Mdot
.596 .30143 Mdot
.596 .30148 Mdot
.596 .30149 Mdot
.596 .3015 Mdot
.596 .30161 Mdot
.596 .30162 Mdot
.596 .30166 Mdot
.596 .30167 Mdot
.596 .3017 Mdot
.596 .30175 Mdot
.596 .30175 Mdot
.596 .30181 Mdot
.596 .30181 Mdot
.596 .30181 Mdot
.596 .30181 Mdot
.596 .30182 Mdot
.596 .30183 Mdot
.596 .30189 Mdot
.596 .30191 Mdot
.596 .30194 Mdot
.596 .30195 Mdot
.596 .30198 Mdot
.596 .30198 Mdot
.596 .30201 Mdot
.596 .30202 Mdot
.596 .30206 Mdot
.596 .30208 Mdot
.596 .30212 Mdot
.596 .30213 Mdot
.596 .30218 Mdot
.596 .30226 Mdot
.596 .30226 Mdot
.596 .30226 Mdot
.596 .3023 Mdot
.596 .30235 Mdot
.596 .30238 Mdot
.596 .30243 Mdot
.596 .3025 Mdot
.596 .30254 Mdot
.596 .30261 Mdot
.596 .30264 Mdot
.596 .30266 Mdot
.596 .30268 Mdot
.596 .30268 Mdot
.596 .30269 Mdot
.596 .30269 Mdot
.596 .30269 Mdot
.596 .3027 Mdot
.596 .3027 Mdot
.596 .30273 Mdot
.596 .30274 Mdot
.596 .30279 Mdot
.596 .30281 Mdot
.596 .30286 Mdot
.596 .30289 Mdot
.596 .30291 Mdot
.596 .303 Mdot
.596 .30303 Mdot
.596 .30305 Mdot
.596 .30307 Mdot
.596 .30307 Mdot
.596 .30308 Mdot
.596 .3031 Mdot
.596 .30317 Mdot
.596 .30319 Mdot
.596 .30319 Mdot
.596 .30321 Mdot
.596 .30322 Mdot
.596 .30324 Mdot
.596 .30332 Mdot
.596 .30336 Mdot
.596 .30337 Mdot
.596 .30345 Mdot
.596 .3035 Mdot
.596 .3035 Mdot
.596 .30352 Mdot
.596 .30352 Mdot
.596 .30353 Mdot
.596 .30357 Mdot
.596 .30359 Mdot
.596 .30359 Mdot
.596 .30362 Mdot
.596 .30365 Mdot
.596 .30367 Mdot
.596 .30368 Mdot
.596 .30375 Mdot
.596 .30375 Mdot
.596 .30376 Mdot
.596 .3038 Mdot
.596 .30383 Mdot
.596 .30392 Mdot
.596 .30396 Mdot
.596 .30396 Mdot
.596 .30404 Mdot
.596 .30406 Mdot
.596 .30414 Mdot
.596 .30415 Mdot
.596 .30415 Mdot
.596 .3042 Mdot
.596 .30421 Mdot
.596 .30421 Mdot
.596 .30422 Mdot
.596 .30422 Mdot
.596 .30423 Mdot
.596 .30429 Mdot
.596 .30429 Mdot
.596 .30436 Mdot
.596 .30436 Mdot
.596 .30437 Mdot
.596 .30437 Mdot
.596 .30438 Mdot
.596 .3044 Mdot
.596 .30442 Mdot
.596 .30443 Mdot
.596 .30445 Mdot
.596 .30445 Mdot
.596 .30448 Mdot
.596 .30452 Mdot
.596 .30459 Mdot
.596 .30463 Mdot
.596 .30468 Mdot
.596 .30471 Mdot
.596 .30471 Mdot
.596 .30471 Mdot
.596 .30472 Mdot
.596 .30472 Mdot
.596 .30472 Mdot
.596 .30475 Mdot
.596 .30479 Mdot
.596 .30485 Mdot
.596 .30487 Mdot
.596 .3049 Mdot
.596 .30492 Mdot
.596 .30494 Mdot
.596 .30496 Mdot
.596 .30496 Mdot
.596 .30496 Mdot
.596 .30496 Mdot
.596 .30497 Mdot
.596 .30503 Mdot
.596 .30504 Mdot
.596 .30506 Mdot
.596 .30507 Mdot
.596 .30508 Mdot
.596 .30508 Mdot
.596 .30509 Mdot
.596 .30512 Mdot
.596 .30513 Mdot
.596 .30514 Mdot
.596 .30515 Mdot
.596 .30516 Mdot
.596 .30517 Mdot
.596 .30518 Mdot
.596 .30519 Mdot
.596 .3052 Mdot
.596 .3052 Mdot
.596 .30521 Mdot
.596 .30521 Mdot
.596 .30522 Mdot
.596 .30523 Mdot
.596 .30525 Mdot
.596 .30525 Mdot
.596 .30525 Mdot
.596 .30526 Mdot
.596 .30529 Mdot
.596 .30529 Mdot
.596 .3053 Mdot
.596 .30532 Mdot
.596 .30537 Mdot
.596 .30537 Mdot
.596 .30538 Mdot
.596 .30539 Mdot
.596 .3054 Mdot
.596 .30544 Mdot
.596 .30546 Mdot
.596 .30554 Mdot
.596 .30555 Mdot
.596 .30555 Mdot
.596 .30555 Mdot
.596 .30556 Mdot
.596 .30558 Mdot
.596 .30561 Mdot
.596 .30564 Mdot
.596 .30568 Mdot
.596 .30571 Mdot
.596 .3058 Mdot
.596 .30584 Mdot
.596 .30589 Mdot
.596 .3059 Mdot
.596 .3059 Mdot
.596 .30591 Mdot
.596 .30591 Mdot
.596 .30591 Mdot
.596 .30596 Mdot
.596 .30602 Mdot
.596 .30608 Mdot
.596 .30617 Mdot
.596 .30623 Mdot
.596 .30628 Mdot
.596 .30628 Mdot
.596 .3063 Mdot
.596 .30632 Mdot
.596 .30634 Mdot
.596 .30638 Mdot
.596 .30639 Mdot
.596 .30639 Mdot
.596 .30641 Mdot
.596 .30641 Mdot
.596 .3065 Mdot
.596 .3065 Mdot
.596 .30658 Mdot
.596 .3066 Mdot
.596 .30661 Mdot
.596 .30662 Mdot
.596 .30662 Mdot
.596 .30663 Mdot
.596 .30671 Mdot
.596 .30671 Mdot
.596 .30672 Mdot
.596 .30684 Mdot
.596 .30685 Mdot
.596 .30697 Mdot
.596 .30697 Mdot
.596 .30703 Mdot
.596 .30716 Mdot
.596 .30719 Mdot
.596 .30725 Mdot
.596 .30728 Mdot
.596 .30728 Mdot
.596 .30737 Mdot
.596 .30738 Mdot
.596 .30742 Mdot
.596 .30745 Mdot
.596 .30749 Mdot
.596 .3075 Mdot
.596 .30753 Mdot
.596 .30758 Mdot
.596 .30759 Mdot
.596 .30759 Mdot
.596 .30763 Mdot
.596 .30763 Mdot
.596 .30769 Mdot
.596 .30781 Mdot
.596 .30783 Mdot
.596 .30789 Mdot
.596 .30799 Mdot
.596 .30802 Mdot
.596 .30804 Mdot
.596 .30806 Mdot
.596 .30807 Mdot
.596 .30809 Mdot
.596 .3082 Mdot
.596 .30822 Mdot
.596 .30823 Mdot
.596 .30824 Mdot
.596 .30827 Mdot
.596 .3083 Mdot
.596 .30834 Mdot
.596 .30847 Mdot
.596 .3085 Mdot
.596 .30853 Mdot
.596 .3086 Mdot
.596 .30863 Mdot
.596 .30871 Mdot
.596 .30872 Mdot
.596 .30876 Mdot
.596 .30877 Mdot
.596 .30877 Mdot
.596 .30878 Mdot
.596 .30878 Mdot
.596 .30879 Mdot
.596 .30879 Mdot
.596 .30881 Mdot
.596 .30885 Mdot
.596 .30889 Mdot
.596 .309 Mdot
.596 .30904 Mdot
.596 .30915 Mdot
.596 .30922 Mdot
.596 .30925 Mdot
.596 .30934 Mdot
.596 .30938 Mdot
.596 .30939 Mdot
.596 .30939 Mdot
.596 .3095 Mdot
.596 .30957 Mdot
.596 .30959 Mdot
.596 .30964 Mdot
.596 .30967 Mdot
.596 .30972 Mdot
.596 .30974 Mdot
.596 .30978 Mdot
.596 .30978 Mdot
.596 .30982 Mdot
.596 .30984 Mdot
.596 .30988 Mdot
.596 .30991 Mdot
.596 .31 Mdot
.596 .31002 Mdot
.596 .31003 Mdot
.596 .31003 Mdot
.596 .31003 Mdot
.596 .31003 Mdot
.596 .31011 Mdot
.596 .31011 Mdot
.596 .31019 Mdot
.596 .31023 Mdot
.596 .31025 Mdot
.596 .3103 Mdot
.596 .31031 Mdot
.596 .31047 Mdot
.596 .31048 Mdot
.596 .3105 Mdot
.596 .31057 Mdot
.596 .31061 Mdot
.596 .31062 Mdot
.596 .31073 Mdot
.596 .31083 Mdot
.596 .31085 Mdot
.596 .31086 Mdot
.596 .31089 Mdot
.596 .31092 Mdot
.596 .31096 Mdot
.596 .31098 Mdot
.596 .31099 Mdot
.596 .31099 Mdot
.596 .31103 Mdot
.596 .31106 Mdot
.596 .31113 Mdot
.596 .31126 Mdot
.596 .31129 Mdot
.596 .31132 Mdot
.596 .31134 Mdot
.596 .31139 Mdot
.596 .31139 Mdot
.596 .31145 Mdot
.596 .31151 Mdot
.596 .31153 Mdot
.596 .31158 Mdot
.596 .31166 Mdot
.596 .31166 Mdot
.596 .31169 Mdot
.596 .31172 Mdot
.596 .3118 Mdot
.596 .3118 Mdot
.596 .31186 Mdot
.596 .31187 Mdot
.596 .31192 Mdot
.596 .31192 Mdot
.596 .31195 Mdot
.596 .31199 Mdot
.596 .31206 Mdot
.596 .31212 Mdot
.596 .31218 Mdot
.596 .31229 Mdot
.596 .31231 Mdot
.596 .31238 Mdot
.596 .3124 Mdot
.596 .31241 Mdot
.596 .31241 Mdot
.596 .31242 Mdot
.596 .31242 Mdot
.596 .31243 Mdot
.596 .31244 Mdot
.596 .31245 Mdot
.596 .31249 Mdot
.596 .31251 Mdot
.596 .31257 Mdot
.596 .31264 Mdot
.596 .31266 Mdot
.596 .3127 Mdot
.596 .3127 Mdot
.596 .31286 Mdot
.596 .31296 Mdot
.596 .31304 Mdot
.596 .31305 Mdot
.596 .31316 Mdot
.596 .31317 Mdot
.596 .3132 Mdot
.596 .31329 Mdot
.596 .31331 Mdot
.596 .31338 Mdot
.596 .31344 Mdot
.596 .31344 Mdot
.596 .31355 Mdot
.596 .31359 Mdot
.596 .3136 Mdot
.596 .3136 Mdot
.596 .31361 Mdot
.596 .31362 Mdot
.596 .31364 Mdot
.596 .31365 Mdot
.596 .31366 Mdot
.596 .31366 Mdot
.596 .31384 Mdot
.596 .31387 Mdot
.596 .31389 Mdot
.596 .31397 Mdot
.596 .31401 Mdot
.596 .31402 Mdot
.596 .31406 Mdot
.596 .3141 Mdot
.596 .3141 Mdot
.596 .31417 Mdot
.596 .31419 Mdot
.596 .31422 Mdot
.596 .31422 Mdot
.596 .35341 Mdot
.596 .35342 Mdot
.596 .35344 Mdot
.596 .35346 Mdot
.596 .35351 Mdot
.596 .35352 Mdot
.596 .35355 Mdot
.596 .35358 Mdot
.596 .35359 Mdot
.596 .35362 Mdot
.596 .35369 Mdot
.596 .35371 Mdot
.596 .35373 Mdot
.596 .35389 Mdot
.596 .35389 Mdot
.596 .3539 Mdot
.596 .3539 Mdot
.596 .35391 Mdot
.596 .35393 Mdot
.596 .35393 Mdot
.596 .35393 Mdot
.596 .35394 Mdot
.596 .35398 Mdot
.596 .35407 Mdot
.596 .35407 Mdot
.596 .35412 Mdot
.596 .35418 Mdot
.596 .3542 Mdot
.596 .35427 Mdot
.596 .35429 Mdot
.596 .3543 Mdot
.596 .35439 Mdot
.596 .35441 Mdot
.596 .35448 Mdot
.596 .35456 Mdot
.596 .35469 Mdot
.596 .35469 Mdot
.596 .35473 Mdot
.596 .35474 Mdot
.596 .3548 Mdot
.596 .35485 Mdot
.596 .35487 Mdot
.596 .3549 Mdot
.596 .3549 Mdot
.596 .35492 Mdot
.596 .35493 Mdot
.596 .35493 Mdot
.596 .35493 Mdot
.596 .35493 Mdot
.596 .35494 Mdot
.596 .35496 Mdot
.596 .35502 Mdot
.596 .35504 Mdot
.596 .35512 Mdot
.596 .35518 Mdot
.596 .35523 Mdot
.596 .35529 Mdot
.596 .35532 Mdot
.596 .35534 Mdot
.596 .35534 Mdot
.596 .35539 Mdot
.596 .3554 Mdot
.596 .35544 Mdot
.596 .35545 Mdot
.596 .35551 Mdot
.596 .35554 Mdot
.596 .35556 Mdot
.596 .35556 Mdot
.596 .35563 Mdot
.596 .35567 Mdot
.596 .35569 Mdot
.596 .35574 Mdot
.596 .35579 Mdot
.596 .35579 Mdot
.596 .35583 Mdot
.596 .35585 Mdot
.596 .35588 Mdot
.596 .3559 Mdot
.596 .35601 Mdot
.596 .35606 Mdot
.596 .35609 Mdot
.596 .35612 Mdot
.596 .35613 Mdot
.596 .35614 Mdot
.596 .35615 Mdot
.596 .35618 Mdot
.596 .35621 Mdot
.596 .35623 Mdot
.596 .35624 Mdot
.596 .35626 Mdot
.596 .35634 Mdot
.596 .35644 Mdot
.596 .35644 Mdot
.596 .35648 Mdot
.596 .35654 Mdot
.596 .35656 Mdot
.596 .35656 Mdot
.596 .3567 Mdot
.596 .3567 Mdot
.596 .35675 Mdot
.596 .35677 Mdot
.596 .3568 Mdot
.596 .35687 Mdot
.596 .35687 Mdot
.596 .35693 Mdot
.596 .35693 Mdot
.596 .35693 Mdot
.596 .35693 Mdot
.596 .35694 Mdot
.596 .35695 Mdot
.596 .35703 Mdot
.596 .35705 Mdot
.596 .35709 Mdot
.596 .3571 Mdot
.596 .35714 Mdot
.596 .35714 Mdot
.596 .35717 Mdot
.596 .35719 Mdot
.596 .35723 Mdot
.596 .35725 Mdot
.596 .3573 Mdot
.596 .35732 Mdot
.596 .35738 Mdot
.596 .35747 Mdot
.596 .35747 Mdot
.596 .35747 Mdot
.596 .35751 Mdot
.596 .35758 Mdot
.596 .35761 Mdot
.596 .35767 Mdot
.596 .35776 Mdot
.596 .3578 Mdot
.596 .35789 Mdot
.596 .35792 Mdot
.596 .35795 Mdot
.596 .35797 Mdot
.596 .35797 Mdot
.596 .35798 Mdot
.596 .35798 Mdot
.596 .35798 Mdot
.596 .35799 Mdot
.596 .358 Mdot
.596 .35803 Mdot
.596 .35804 Mdot
.596 .35811 Mdot
.596 .35813 Mdot
.596 .35819 Mdot
.596 .35821 Mdot
.596 .35824 Mdot
.596 .35835 Mdot
.596 .35838 Mdot
.596 .35841 Mdot
.596 .35843 Mdot
.596 .35844 Mdot
.596 .35845 Mdot
.596 .35846 Mdot
.596 .35856 Mdot
.596 .35858 Mdot
.596 .35858 Mdot
.596 .3586 Mdot
.596 .35862 Mdot
.596 .35864 Mdot
.596 .35873 Mdot
.596 .35878 Mdot
.596 .35879 Mdot
.596 .35889 Mdot
.596 .35894 Mdot
.596 .35894 Mdot
.596 .35897 Mdot
.596 .35897 Mdot
.596 .35899 Mdot
.596 .35903 Mdot
.596 .35905 Mdot
.596 .35906 Mdot
.596 .35909 Mdot
.596 .35912 Mdot
.596 .35916 Mdot
.596 .35916 Mdot
.596 .35924 Mdot
.596 .35924 Mdot
.596 .35926 Mdot
.596 .35931 Mdot
.596 .35934 Mdot
.596 .35945 Mdot
.596 .35949 Mdot
.596 .3595 Mdot
.596 .3596 Mdot
.596 .35961 Mdot
.596 .3597 Mdot
.596 .35972 Mdot
.596 .35972 Mdot
.596 .35978 Mdot
.596 .35979 Mdot
.596 .35979 Mdot
.596 .3598 Mdot
.596 .35981 Mdot
.596 .35982 Mdot
.596 .35989 Mdot
.596 .35989 Mdot
.596 .35997 Mdot
.596 .35997 Mdot
.596 .35999 Mdot
.596 .35999 Mdot
.596 .35999 Mdot
.596 .36002 Mdot
.596 .36005 Mdot
.596 .36006 Mdot
.596 .36008 Mdot
.596 .36008 Mdot
.596 .36012 Mdot
.596 .36017 Mdot
.596 .36024 Mdot
.596 .36029 Mdot
.596 .36035 Mdot
.596 .36038 Mdot
.596 .36039 Mdot
.596 .36039 Mdot
.596 .3604 Mdot
.596 .3604 Mdot
.596 .36041 Mdot
.596 .36044 Mdot
.596 .36048 Mdot
.596 .36055 Mdot
.596 .36058 Mdot
.596 .36061 Mdot
.596 .36064 Mdot
.596 .36067 Mdot
.596 .36068 Mdot
.596 .36069 Mdot
.596 .36069 Mdot
.596 .36069 Mdot
.596 .36069 Mdot
.596 .36077 Mdot
.596 .36078 Mdot
.596 .36081 Mdot
.596 .36082 Mdot
.596 .36083 Mdot
.596 .36084 Mdot
.596 .36084 Mdot
.596 .36088 Mdot
.596 .3609 Mdot
.596 .36091 Mdot
.596 .36091 Mdot
.596 .36093 Mdot
.596 .36094 Mdot
.596 .36094 Mdot
.596 .36094 Mdot
.596 .36095 Mdot
.596 .36097 Mdot
.596 .36097 Mdot
.596 .36098 Mdot
.596 .36098 Mdot
.596 .36098 Mdot
.596 .36099 Mdot
.596 .361 Mdot
.596 .361 Mdot
.596 .36101 Mdot
.596 .36103 Mdot
.596 .36103 Mdot
.596 .36104 Mdot
.596 .36105 Mdot
.596 .36108 Mdot
.596 .36108 Mdot
.596 .36108 Mdot
.596 .36109 Mdot
.596 .3611 Mdot
.596 .36112 Mdot
.596 .36113 Mdot
.596 .36118 Mdot
.596 .36118 Mdot
.596 .36118 Mdot
.596 .36118 Mdot
.596 .36119 Mdot
.596 .3612 Mdot
.596 .36122 Mdot
.596 .36123 Mdot
.596 .36126 Mdot
.596 .36128 Mdot
.596 .36133 Mdot
.596 .36136 Mdot
.596 .36138 Mdot
.596 .36139 Mdot
.596 .36139 Mdot
.596 .36139 Mdot
.596 .36139 Mdot
.596 .3614 Mdot
.596 .36142 Mdot
.596 .36146 Mdot
.596 .3615 Mdot
.596 .36155 Mdot
.596 .36158 Mdot
.596 .36161 Mdot
.596 .36161 Mdot
.596 .36163 Mdot
.596 .36164 Mdot
.596 .36165 Mdot
.596 .36167 Mdot
.596 .36168 Mdot
.596 .36168 Mdot
.596 .36169 Mdot
.596 .36169 Mdot
.596 .36174 Mdot
.596 .36175 Mdot
.596 .36179 Mdot
.596 .3618 Mdot
.596 .36181 Mdot
.596 .36181 Mdot
.596 .36182 Mdot
.596 .36182 Mdot
.596 .36186 Mdot
.596 .36187 Mdot
.596 .36188 Mdot
.596 .36194 Mdot
.596 .36195 Mdot
.596 .36202 Mdot
.596 .36202 Mdot
.596 .36206 Mdot
.596 .36213 Mdot
.596 .36215 Mdot
.596 .36219 Mdot
.596 .3622 Mdot
.596 .3622 Mdot
.596 .36226 Mdot
.596 .36226 Mdot
.596 .36228 Mdot
.596 .3623 Mdot
.596 .36233 Mdot
.596 .36234 Mdot
.596 .36235 Mdot
.596 .36238 Mdot
.596 .36239 Mdot
.596 .36239 Mdot
.596 .36241 Mdot
.596 .36241 Mdot
.596 .36245 Mdot
.596 .36252 Mdot
.596 .36253 Mdot
.596 .36256 Mdot
.596 .36262 Mdot
.596 .36264 Mdot
.596 .36265 Mdot
.596 .36267 Mdot
.596 .36267 Mdot
.596 .36268 Mdot
.596 .36275 Mdot
.596 .36276 Mdot
.596 .36277 Mdot
.596 .36277 Mdot
.596 .36279 Mdot
.596 .36281 Mdot
.596 .36283 Mdot
.596 .36291 Mdot
.596 .36292 Mdot
.596 .36294 Mdot
.596 .36298 Mdot
.596 .363 Mdot
.596 .36305 Mdot
.596 .36306 Mdot
.596 .36308 Mdot
.596 .36308 Mdot
.596 .36309 Mdot
.596 .36309 Mdot
.596 .36309 Mdot
.596 .3631 Mdot
.596 .3631 Mdot
.596 .36311 Mdot
.596 .36313 Mdot
.596 .36315 Mdot
.596 .36322 Mdot
.596 .36325 Mdot
.596 .36331 Mdot
.596 .36335 Mdot
.596 .36337 Mdot
.596 .36342 Mdot
.596 .36344 Mdot
.596 .36345 Mdot
.596 .36345 Mdot
.596 .36351 Mdot
.596 .36356 Mdot
.596 .36357 Mdot
.596 .3636 Mdot
.596 .36362 Mdot
.596 .36365 Mdot
.596 .36366 Mdot
.596 .36368 Mdot
.596 .36368 Mdot
.596 .36371 Mdot
.596 .36372 Mdot
.596 .36374 Mdot
.596 .36375 Mdot
.596 .36376 Mdot
.596 .36381 Mdot
.596 .36382 Mdot
.596 .36383 Mdot
.596 .36383 Mdot
.596 .36383 Mdot
.596 .36383 Mdot
.596 .36387 Mdot
.596 .36387 Mdot
.596 .36392 Mdot
.596 .36394 Mdot
.596 .36396 Mdot
.596 .36399 Mdot
.596 .36399 Mdot
.596 .36409 Mdot
.596 .36409 Mdot
.596 .3641 Mdot
.596 .36415 Mdot
.596 .36417 Mdot
.596 .36418 Mdot
.596 .36424 Mdot
.596 .3643 Mdot
.596 .36431 Mdot
.596 .36432 Mdot
.596 .36433 Mdot
.596 .36435 Mdot
.596 .36438 Mdot
.596 .36439 Mdot
.596 .36439 Mdot
.596 .3644 Mdot
.596 .36442 Mdot
.596 .36444 Mdot
.596 .36447 Mdot
.596 .36455 Mdot
.596 .36457 Mdot
.596 .36459 Mdot
.596 .3646 Mdot
.596 .36463 Mdot
.596 .36463 Mdot
.596 .36467 Mdot
.596 .3647 Mdot
.596 .36471 Mdot
.596 .36474 Mdot
.596 .36479 Mdot
.596 .36479 Mdot
.596 .36481 Mdot
.596 .36483 Mdot
.596 .36487 Mdot
.596 .36488 Mdot
.596 .36491 Mdot
.596 .36491 Mdot
.596 .36494 Mdot
.596 .36494 Mdot
.596 .36496 Mdot
.596 .36498 Mdot
.596 .36503 Mdot
.596 .36506 Mdot
.596 .3651 Mdot
.596 .36516 Mdot
.596 .36517 Mdot
.596 .36522 Mdot
.596 .36523 Mdot
.596 .36523 Mdot
.596 .36523 Mdot
.596 .36524 Mdot
.596 .36524 Mdot
.596 .36524 Mdot
.596 .36525 Mdot
.596 .36526 Mdot
.596 .36528 Mdot
.596 .36529 Mdot
.596 .36533 Mdot
.596 .36537 Mdot
.596 .36538 Mdot
.596 .3654 Mdot
.596 .36541 Mdot
.596 .3655 Mdot
.596 .36556 Mdot
.596 .3656 Mdot
.596 .36561 Mdot
.596 .36568 Mdot
.596 .36568 Mdot
.596 .3657 Mdot
.596 .36575 Mdot
.596 .36577 Mdot
.596 .36581 Mdot
.596 .36584 Mdot
.596 .36584 Mdot
.596 .3659 Mdot
.596 .36593 Mdot
.596 .36594 Mdot
.596 .36594 Mdot
.596 .36594 Mdot
.596 .36595 Mdot
.596 .36596 Mdot
.596 .36596 Mdot
.596 .36597 Mdot
.596 .36597 Mdot
.596 .36608 Mdot
.596 .3661 Mdot
.596 .36611 Mdot
.596 .36616 Mdot
.596 .36618 Mdot
.596 .36618 Mdot
.596 .36621 Mdot
.596 .36623 Mdot
.596 .36623 Mdot
.596 .36627 Mdot
.596 .36628 Mdot
.596 .3663 Mdot
.596 .3663 Mdot
.598 .29838 Mdot
.598 .2984 Mdot
.598 .29843 Mdot
.598 .29845 Mdot
.598 .29851 Mdot
.598 .29852 Mdot
.598 .29853 Mdot
.598 .29854 Mdot
.598 .29857 Mdot
.598 .29862 Mdot
.598 .29867 Mdot
.598 .29874 Mdot
.598 .29877 Mdot
.598 .29878 Mdot
.598 .2989 Mdot
.598 .29892 Mdot
.598 .29894 Mdot
.598 .29896 Mdot
.598 .29899 Mdot
.598 .29906 Mdot
.598 .29909 Mdot
.598 .29912 Mdot
.598 .29912 Mdot
.598 .29912 Mdot
.598 .29913 Mdot
.598 .29918 Mdot
.598 .29918 Mdot
.598 .29922 Mdot
.598 .29927 Mdot
.598 .29929 Mdot
.598 .29932 Mdot
.598 .29936 Mdot
.598 .29938 Mdot
.598 .29942 Mdot
.598 .29943 Mdot
.598 .29943 Mdot
.598 .29944 Mdot
.598 .29944 Mdot
.598 .29946 Mdot
.598 .2995 Mdot
.598 .2995 Mdot
.598 .29956 Mdot
.598 .29957 Mdot
.598 .29964 Mdot
.598 .29965 Mdot
.598 .29968 Mdot
.598 .29971 Mdot
.598 .29972 Mdot
.598 .29979 Mdot
.598 .29979 Mdot
.598 .29982 Mdot
.598 .29985 Mdot
.598 .29989 Mdot
.598 .29991 Mdot
.598 .29994 Mdot
.598 .29997 Mdot
.598 .29998 Mdot
.598 .30003 Mdot
.598 .3001 Mdot
.598 .3001 Mdot
.598 .30014 Mdot
.598 .30015 Mdot
.598 .30017 Mdot
.598 .30021 Mdot
.598 .30028 Mdot
.598 .30029 Mdot
.598 .3003 Mdot
.598 .30031 Mdot
.598 .30033 Mdot
.598 .30036 Mdot
.598 .30038 Mdot
.598 .30048 Mdot
.598 .30057 Mdot
.598 .30057 Mdot
.598 .30059 Mdot
.598 .30061 Mdot
.598 .30063 Mdot
.598 .30064 Mdot
.598 .30069 Mdot
.598 .3007 Mdot
.598 .30074 Mdot
.598 .30079 Mdot
.598 .30083 Mdot
.598 .30084 Mdot
.598 .30087 Mdot
.598 .30089 Mdot
.598 .30092 Mdot
.598 .30093 Mdot
.598 .301 Mdot
.598 .30102 Mdot
.598 .30108 Mdot
.598 .30108 Mdot
.598 .30115 Mdot
.598 .30115 Mdot
.598 .30119 Mdot
.598 .30122 Mdot
.598 .30122 Mdot
.598 .30124 Mdot
.598 .30125 Mdot
.598 .30126 Mdot
.598 .30126 Mdot
.598 .30132 Mdot
.598 .30136 Mdot
.598 .30137 Mdot
.598 .3014 Mdot
.598 .3014 Mdot
.598 .30141 Mdot
.598 .30141 Mdot
.598 .30142 Mdot
.598 .3015 Mdot
.598 .30157 Mdot
.598 .30159 Mdot
.598 .30165 Mdot
.598 .30167 Mdot
.598 .30169 Mdot
.598 .3017 Mdot
.598 .3017 Mdot
.598 .30173 Mdot
.598 .30178 Mdot
.598 .30179 Mdot
.598 .30181 Mdot
.598 .30186 Mdot
.598 .30192 Mdot
.598 .30197 Mdot
.598 .30204 Mdot
.598 .30205 Mdot
.598 .30206 Mdot
.598 .30208 Mdot
.598 .30211 Mdot
.598 .30217 Mdot
.598 .30222 Mdot
.598 .30224 Mdot
.598 .30226 Mdot
.598 .30227 Mdot
.598 .3023 Mdot
.598 .3023 Mdot
.598 .30236 Mdot
.598 .30242 Mdot
.598 .30243 Mdot
.598 .30244 Mdot
.598 .30249 Mdot
.598 .3025 Mdot
.598 .30252 Mdot
.598 .30256 Mdot
.598 .30259 Mdot
.598 .30264 Mdot
.598 .30265 Mdot
.598 .30271 Mdot
.598 .30273 Mdot
.598 .30273 Mdot
.598 .30275 Mdot
.598 .30285 Mdot
.598 .30287 Mdot
.598 .30288 Mdot
.598 .30289 Mdot
.598 .303 Mdot
.598 .30301 Mdot
.598 .30303 Mdot
.598 .30303 Mdot
.598 .30307 Mdot
.598 .3031 Mdot
.598 .3031 Mdot
.598 .30313 Mdot
.598 .30314 Mdot
.598 .30315 Mdot
.598 .30317 Mdot
.598 .30318 Mdot
.598 .30318 Mdot
.598 .30319 Mdot
.598 .3032 Mdot
.598 .30326 Mdot
.598 .30326 Mdot
.598 .30326 Mdot
.598 .30331 Mdot
.598 .30335 Mdot
.598 .30339 Mdot
.598 .3034 Mdot
.598 .30342 Mdot
.598 .30346 Mdot
.598 .30348 Mdot
.598 .30354 Mdot
.598 .30358 Mdot
.598 .30359 Mdot
.598 .30367 Mdot
.598 .30368 Mdot
.598 .30368 Mdot
.598 .3037 Mdot
.598 .30377 Mdot
.598 .30379 Mdot
.598 .3038 Mdot
.598 .30381 Mdot
.598 .30387 Mdot
.598 .30391 Mdot
.598 .30392 Mdot
.598 .30397 Mdot
.598 .30398 Mdot
.598 .30404 Mdot
.598 .30405 Mdot
.598 .30407 Mdot
.598 .30409 Mdot
.598 .30413 Mdot
.598 .30413 Mdot
.598 .30414 Mdot
.598 .30417 Mdot
.598 .30417 Mdot
.598 .30421 Mdot
.598 .30424 Mdot
.598 .30424 Mdot
.598 .3043 Mdot
.598 .30432 Mdot
.598 .30437 Mdot
.598 .30438 Mdot
.598 .30448 Mdot
.598 .30451 Mdot
.598 .30452 Mdot
.598 .30455 Mdot
.598 .30456 Mdot
.598 .30457 Mdot
.598 .30459 Mdot
.598 .3046 Mdot
.598 .30461 Mdot
.598 .30465 Mdot
.598 .30468 Mdot
.598 .30469 Mdot
.598 .30471 Mdot
.598 .30471 Mdot
.598 .30478 Mdot
.598 .3048 Mdot
.598 .3048 Mdot
.598 .30482 Mdot
.598 .30482 Mdot
.598 .30483 Mdot
.598 .30486 Mdot
.598 .30488 Mdot
.598 .30492 Mdot
.598 .30492 Mdot
.598 .30493 Mdot
.598 .30493 Mdot
.598 .30496 Mdot
.598 .30498 Mdot
.598 .30498 Mdot
.598 .30498 Mdot
.598 .305 Mdot
.598 .30501 Mdot
.598 .30501 Mdot
.598 .30502 Mdot
.598 .30503 Mdot
.598 .30504 Mdot
.598 .30505 Mdot
.598 .30505 Mdot
.598 .30507 Mdot
.598 .30507 Mdot
.598 .30509 Mdot
.598 .3051 Mdot
.598 .30511 Mdot
.598 .30511 Mdot
.598 .30514 Mdot
.598 .30516 Mdot
.598 .30518 Mdot
.598 .30518 Mdot
.598 .30519 Mdot
.598 .3052 Mdot
.598 .30521 Mdot
.598 .30526 Mdot
.598 .30528 Mdot
.598 .30528 Mdot
.598 .3053 Mdot
.598 .30533 Mdot
.598 .30534 Mdot
.598 .30534 Mdot
.598 .30536 Mdot
.598 .30537 Mdot
.598 .30539 Mdot
.598 .30549 Mdot
.598 .3055 Mdot
.598 .30553 Mdot
.598 .30555 Mdot
.598 .30559 Mdot
.598 .30564 Mdot
.598 .30566 Mdot
.598 .30566 Mdot
.598 .30569 Mdot
.598 .3057 Mdot
.598 .30573 Mdot
.598 .30577 Mdot
.598 .30578 Mdot
.598 .30582 Mdot
.598 .30597 Mdot
.598 .30598 Mdot
.598 .30605 Mdot
.598 .30608 Mdot
.598 .30616 Mdot
.598 .30617 Mdot
.598 .30621 Mdot
.598 .30627 Mdot
.598 .30628 Mdot
.598 .30632 Mdot
.598 .30632 Mdot
.598 .30633 Mdot
.598 .30639 Mdot
.598 .30641 Mdot
.598 .30644 Mdot
.598 .30646 Mdot
.598 .30654 Mdot
.598 .30656 Mdot
.598 .30663 Mdot
.598 .30665 Mdot
.598 .3067 Mdot
.598 .30679 Mdot
.598 .3068 Mdot
.598 .30682 Mdot
.598 .30685 Mdot
.598 .30694 Mdot
.598 .30697 Mdot
.598 .30697 Mdot
.598 .30699 Mdot
.598 .3071 Mdot
.598 .30711 Mdot
.598 .30717 Mdot
.598 .30725 Mdot
.598 .30729 Mdot
.598 .30734 Mdot
.598 .30736 Mdot
.598 .30738 Mdot
.598 .30744 Mdot
.598 .3075 Mdot
.598 .30757 Mdot
.598 .30757 Mdot
.598 .30758 Mdot
.598 .30766 Mdot
.598 .30767 Mdot
.598 .30768 Mdot
.598 .30769 Mdot
.598 .3077 Mdot
.598 .30772 Mdot
.598 .30775 Mdot
.598 .30775 Mdot
.598 .3078 Mdot
.598 .3078 Mdot
.598 .30784 Mdot
.598 .30791 Mdot
.598 .30791 Mdot
.598 .30793 Mdot
.598 .30794 Mdot
.598 .30811 Mdot
.598 .30811 Mdot
.598 .30812 Mdot
.598 .30815 Mdot
.598 .3083 Mdot
.598 .30832 Mdot
.598 .30833 Mdot
.598 .30835 Mdot
.598 .30845 Mdot
.598 .30845 Mdot
.598 .30853 Mdot
.598 .30857 Mdot
.598 .30857 Mdot
.598 .30863 Mdot
.598 .30866 Mdot
.598 .30868 Mdot
.598 .30875 Mdot
.598 .30876 Mdot
.598 .30877 Mdot
.598 .30886 Mdot
.598 .30894 Mdot
.598 .30895 Mdot
.598 .30899 Mdot
.598 .309 Mdot
.598 .30903 Mdot
.598 .30906 Mdot
.598 .30913 Mdot
.598 .30921 Mdot
.598 .30926 Mdot
.598 .30928 Mdot
.598 .3093 Mdot
.598 .30932 Mdot
.598 .30941 Mdot
.598 .30948 Mdot
.598 .30957 Mdot
.598 .30965 Mdot
.598 .30967 Mdot
.598 .30968 Mdot
.598 .30976 Mdot
.598 .3098 Mdot
.598 .3098 Mdot
.598 .30981 Mdot
.598 .30984 Mdot
.598 .30988 Mdot
.598 .30996 Mdot
.598 .30999 Mdot
.598 .31008 Mdot
.598 .3102 Mdot
.598 .31022 Mdot
.598 .31022 Mdot
.598 .31023 Mdot
.598 .31023 Mdot
.598 .31027 Mdot
.598 .31029 Mdot
.598 .31034 Mdot
.598 .31043 Mdot
.598 .31044 Mdot
.598 .31045 Mdot
.598 .31046 Mdot
.598 .31049 Mdot
.598 .31049 Mdot
.598 .31054 Mdot
.598 .31059 Mdot
.598 .31059 Mdot
.598 .31069 Mdot
.598 .31069 Mdot
.598 .31078 Mdot
.598 .3108 Mdot
.598 .31091 Mdot
.598 .31091 Mdot
.598 .31096 Mdot
.598 .31099 Mdot
.598 .31104 Mdot
.598 .31105 Mdot
.598 .31111 Mdot
.598 .31118 Mdot
.598 .31124 Mdot
.598 .31125 Mdot
.598 .31132 Mdot
.598 .31133 Mdot
.598 .31136 Mdot
.598 .31139 Mdot
.598 .31142 Mdot
.598 .31143 Mdot
.598 .31154 Mdot
.598 .31169 Mdot
.598 .31172 Mdot
.598 .31177 Mdot
.598 .31179 Mdot
.598 .3118 Mdot
.598 .31182 Mdot
.598 .31183 Mdot
.598 .31194 Mdot
.598 .31199 Mdot
.598 .31202 Mdot
.598 .31203 Mdot
.598 .31209 Mdot
.598 .31209 Mdot
.598 .31219 Mdot
.598 .31226 Mdot
.598 .31228 Mdot
.598 .31232 Mdot
.598 .31236 Mdot
.598 .31239 Mdot
.598 .31245 Mdot
.598 .31249 Mdot
.598 .31253 Mdot
.598 .31254 Mdot
.598 .31263 Mdot
.598 .31265 Mdot
.598 .31269 Mdot
.598 .31274 Mdot
.598 .31275 Mdot
.598 .31286 Mdot
.598 .31286 Mdot
.598 .31294 Mdot
.598 .31295 Mdot
.598 .31301 Mdot
.598 .31303 Mdot
.598 .31303 Mdot
.598 .31304 Mdot
.598 .31306 Mdot
.598 .31307 Mdot
.598 .31312 Mdot
.598 .31315 Mdot
.598 .31321 Mdot
.598 .31326 Mdot
.598 .31328 Mdot
.598 .31335 Mdot
.598 .3134 Mdot
.598 .31341 Mdot
.598 .31347 Mdot
.598 .31349 Mdot
.598 .31349 Mdot
.598 .3135 Mdot
.598 .31354 Mdot
.598 .31358 Mdot
.598 .31367 Mdot
.598 .31373 Mdot
.598 .31375 Mdot
.598 .31378 Mdot
.598 .3138 Mdot
.598 .31397 Mdot
.598 .31399 Mdot
.598 .31404 Mdot
.598 .31413 Mdot
.598 .31421 Mdot
.598 .31428 Mdot
.598 .31432 Mdot
.598 .31433 Mdot
.598 .31435 Mdot
.598 .31437 Mdot
.598 .31444 Mdot
.598 .31448 Mdot
.598 .31453 Mdot
.598 .31455 Mdot
.598 .35398 Mdot
.598 .354 Mdot
.598 .35404 Mdot
.598 .35407 Mdot
.598 .35413 Mdot
.598 .35414 Mdot
.598 .35416 Mdot
.598 .35417 Mdot
.598 .3542 Mdot
.598 .35427 Mdot
.598 .35433 Mdot
.598 .35441 Mdot
.598 .35444 Mdot
.598 .35446 Mdot
.598 .3546 Mdot
.598 .35462 Mdot
.598 .35465 Mdot
.598 .35467 Mdot
.598 .35471 Mdot
.598 .35479 Mdot
.598 .35482 Mdot
.598 .35486 Mdot
.598 .35486 Mdot
.598 .35487 Mdot
.598 .35488 Mdot
.598 .35493 Mdot
.598 .35494 Mdot
.598 .35498 Mdot
.598 .35505 Mdot
.598 .35506 Mdot
.598 .3551 Mdot
.598 .35515 Mdot
.598 .35518 Mdot
.598 .35522 Mdot
.598 .35523 Mdot
.598 .35524 Mdot
.598 .35525 Mdot
.598 .35525 Mdot
.598 .35527 Mdot
.598 .35531 Mdot
.598 .35532 Mdot
.598 .35539 Mdot
.598 .3554 Mdot
.598 .35548 Mdot
.598 .3555 Mdot
.598 .35554 Mdot
.598 .35557 Mdot
.598 .35558 Mdot
.598 .35566 Mdot
.598 .35567 Mdot
.598 .3557 Mdot
.598 .35574 Mdot
.598 .35579 Mdot
.598 .35581 Mdot
.598 .35585 Mdot
.598 .35588 Mdot
.598 .35589 Mdot
.598 .35596 Mdot
.598 .35604 Mdot
.598 .35604 Mdot
.598 .35609 Mdot
.598 .35609 Mdot
.598 .35612 Mdot
.598 .35616 Mdot
.598 .35625 Mdot
.598 .35626 Mdot
.598 .35628 Mdot
.598 .35629 Mdot
.598 .35631 Mdot
.598 .35635 Mdot
.598 .35637 Mdot
.598 .3565 Mdot
.598 .35659 Mdot
.598 .3566 Mdot
.598 .35662 Mdot
.598 .35665 Mdot
.598 .35667 Mdot
.598 .35668 Mdot
.598 .35674 Mdot
.598 .35675 Mdot
.598 .3568 Mdot
.598 .35686 Mdot
.598 .3569 Mdot
.598 .35692 Mdot
.598 .35696 Mdot
.598 .35698 Mdot
.598 .35702 Mdot
.598 .35702 Mdot
.598 .35712 Mdot
.598 .35713 Mdot
.598 .3572 Mdot
.598 .35721 Mdot
.598 .35729 Mdot
.598 .35729 Mdot
.598 .35734 Mdot
.598 .35737 Mdot
.598 .35738 Mdot
.598 .3574 Mdot
.598 .35741 Mdot
.598 .35742 Mdot
.598 .35742 Mdot
.598 .3575 Mdot
.598 .35754 Mdot
.598 .35756 Mdot
.598 .35759 Mdot
.598 .35759 Mdot
.598 .3576 Mdot
.598 .3576 Mdot
.598 .35762 Mdot
.598 .35772 Mdot
.598 .35779 Mdot
.598 .35782 Mdot
.598 .35789 Mdot
.598 .35792 Mdot
.598 .35794 Mdot
.598 .35795 Mdot
.598 .35795 Mdot
.598 .35798 Mdot
.598 .35805 Mdot
.598 .35806 Mdot
.598 .35808 Mdot
.598 .35814 Mdot
.598 .35822 Mdot
.598 .35827 Mdot
.598 .35835 Mdot
.598 .35837 Mdot
.598 .35838 Mdot
.598 .35841 Mdot
.598 .35844 Mdot
.598 .35851 Mdot
.598 .35857 Mdot
.598 .35859 Mdot
.598 .35862 Mdot
.598 .35863 Mdot
.598 .35866 Mdot
.598 .35867 Mdot
.598 .35874 Mdot
.598 .35881 Mdot
.598 .35882 Mdot
.598 .35883 Mdot
.598 .35889 Mdot
.598 .35891 Mdot
.598 .35893 Mdot
.598 .35898 Mdot
.598 .35898 Mdot
.598 .35901 Mdot
.598 .35908 Mdot
.598 .35908 Mdot
.598 .35916 Mdot
.598 .35918 Mdot
.598 .35919 Mdot
.598 .35921 Mdot
.598 .35933 Mdot
.598 .35935 Mdot
.598 .35936 Mdot
.598 .35937 Mdot
.598 .3595 Mdot
.598 .35952 Mdot
.598 .35953 Mdot
.598 .35954 Mdot
.598 .35959 Mdot
.598 .35962 Mdot
.598 .35962 Mdot
.598 .35966 Mdot
.598 .35967 Mdot
.598 .35969 Mdot
.598 .35971 Mdot
.598 .35972 Mdot
.598 .35972 Mdot
.598 .35973 Mdot
.598 .35974 Mdot
.598 .35981 Mdot
.598 .35981 Mdot
.598 .35982 Mdot
.598 .35987 Mdot
.598 .35992 Mdot
.598 .35997 Mdot
.598 .35999 Mdot
.598 .36001 Mdot
.598 .36005 Mdot
.598 .36008 Mdot
.598 .36015 Mdot
.598 .3602 Mdot
.598 .36021 Mdot
.598 .3603 Mdot
.598 .36031 Mdot
.598 .36032 Mdot
.598 .36034 Mdot
.598 .36042 Mdot
.598 .36045 Mdot
.598 .36046 Mdot
.598 .36047 Mdot
.598 .36054 Mdot
.598 .36059 Mdot
.598 .3606 Mdot
.598 .36066 Mdot
.598 .36067 Mdot
.598 .36075 Mdot
.598 .36076 Mdot
.598 .36079 Mdot
.598 .36081 Mdot
.598 .36085 Mdot
.598 .36086 Mdot
.598 .36086 Mdot
.598 .3609 Mdot
.598 .3609 Mdot
.598 .36095 Mdot
.598 .36098 Mdot
.598 .36099 Mdot
.598 .36106 Mdot
.598 .36109 Mdot
.598 .36115 Mdot
.598 .36116 Mdot
.598 .36128 Mdot
.598 .36131 Mdot
.598 .36132 Mdot
.598 .36136 Mdot
.598 .36138 Mdot
.598 .36138 Mdot
.598 .36141 Mdot
.598 .36141 Mdot
.598 .36143 Mdot
.598 .36148 Mdot
.598 .36151 Mdot
.598 .36152 Mdot
.598 .36155 Mdot
.598 .36155 Mdot
.598 .36163 Mdot
.598 .36165 Mdot
.598 .36166 Mdot
.598 .36168 Mdot
.598 .36168 Mdot
.598 .36169 Mdot
.598 .36171 Mdot
.598 .36173 Mdot
.598 .36173 Mdot
.598 .36175 Mdot
.598 .36179 Mdot
.598 .3618 Mdot
.598 .3618 Mdot
.598 .36181 Mdot
.598 .36182 Mdot
.598 .36183 Mdot
.598 .36185 Mdot
.598 .36187 Mdot
.598 .36188 Mdot
.598 .36188 Mdot
.598 .36189 Mdot
.598 .36191 Mdot
.598 .36191 Mdot
.598 .36192 Mdot
.598 .36192 Mdot
.598 .36193 Mdot
.598 .36194 Mdot
.598 .36195 Mdot
.598 .36196 Mdot
.598 .36196 Mdot
.598 .36197 Mdot
.598 .36198 Mdot
.598 .36198 Mdot
.598 .36198 Mdot
.598 .362 Mdot
.598 .36202 Mdot
.598 .36202 Mdot
.598 .36203 Mdot
.598 .36203 Mdot
.598 .36207 Mdot
.598 .36208 Mdot
.598 .36211 Mdot
.598 .36212 Mdot
.598 .36212 Mdot
.598 .36213 Mdot
.598 .36213 Mdot
.598 .36215 Mdot
.598 .3622 Mdot
.598 .36221 Mdot
.598 .36223 Mdot
.598 .36224 Mdot
.598 .36226 Mdot
.598 .36229 Mdot
.598 .3623 Mdot
.598 .3623 Mdot
.598 .36232 Mdot
.598 .36233 Mdot
.598 .36234 Mdot
.598 .36237 Mdot
.598 .36237 Mdot
.598 .3624 Mdot
.598 .36248 Mdot
.598 .36249 Mdot
.598 .36253 Mdot
.598 .36255 Mdot
.598 .3626 Mdot
.598 .3626 Mdot
.598 .36262 Mdot
.598 .36266 Mdot
.598 .36266 Mdot
.598 .36269 Mdot
.598 .36269 Mdot
.598 .36269 Mdot
.598 .36273 Mdot
.598 .36274 Mdot
.598 .36276 Mdot
.598 .36277 Mdot
.598 .36282 Mdot
.598 .36283 Mdot
.598 .36287 Mdot
.598 .36288 Mdot
.598 .36291 Mdot
.598 .36296 Mdot
.598 .36297 Mdot
.598 .36298 Mdot
.598 .363 Mdot
.598 .36305 Mdot
.598 .36307 Mdot
.598 .36307 Mdot
.598 .36308 Mdot
.598 .36314 Mdot
.598 .36315 Mdot
.598 .36319 Mdot
.598 .36323 Mdot
.598 .36326 Mdot
.598 .36329 Mdot
.598 .3633 Mdot
.598 .36331 Mdot
.598 .36334 Mdot
.598 .36338 Mdot
.598 .36342 Mdot
.598 .36342 Mdot
.598 .36342 Mdot
.598 .36347 Mdot
.598 .36348 Mdot
.598 .36348 Mdot
.598 .36349 Mdot
.598 .36349 Mdot
.598 .36351 Mdot
.598 .36352 Mdot
.598 .36352 Mdot
.598 .36355 Mdot
.598 .36355 Mdot
.598 .36358 Mdot
.598 .36362 Mdot
.598 .36362 Mdot
.598 .36363 Mdot
.598 .36364 Mdot
.598 .36373 Mdot
.598 .36373 Mdot
.598 .36374 Mdot
.598 .36376 Mdot
.598 .36385 Mdot
.598 .36386 Mdot
.598 .36387 Mdot
.598 .36388 Mdot
.598 .36393 Mdot
.598 .36394 Mdot
.598 .36398 Mdot
.598 .364 Mdot
.598 .36404 Mdot
.598 .36405 Mdot
.598 .36407 Mdot
.598 .36411 Mdot
.598 .36411 Mdot
.598 .36412 Mdot
.598 .36417 Mdot
.598 .36422 Mdot
.598 .36422 Mdot
.598 .36425 Mdot
.598 .36426 Mdot
.598 .36427 Mdot
.598 .36429 Mdot
.598 .36433 Mdot
.598 .36438 Mdot
.598 .3644 Mdot
.598 .36442 Mdot
.598 .36443 Mdot
.598 .36444 Mdot
.598 .3645 Mdot
.598 .36454 Mdot
.598 .36459 Mdot
.598 .36464 Mdot
.598 .36465 Mdot
.598 .36465 Mdot
.598 .3647 Mdot
.598 .36472 Mdot
.598 .36472 Mdot
.598 .36473 Mdot
.598 .36475 Mdot
.598 .36477 Mdot
.598 .36482 Mdot
.598 .36483 Mdot
.598 .36489 Mdot
.598 .36496 Mdot
.598 .36497 Mdot
.598 .36497 Mdot
.598 .36497 Mdot
.598 .36498 Mdot
.598 .365 Mdot
.598 .36501 Mdot
.598 .36504 Mdot
.598 .36508 Mdot
.598 .36509 Mdot
.598 .3651 Mdot
.598 .3651 Mdot
.598 .36511 Mdot
.598 .36512 Mdot
.598 .36513 Mdot
.598 .36515 Mdot
.598 .36518 Mdot
.598 .36519 Mdot
.598 .36524 Mdot
.598 .36525 Mdot
.598 .36529 Mdot
.598 .36531 Mdot
.598 .36537 Mdot
.598 .36537 Mdot
.598 .3654 Mdot
.598 .36542 Mdot
.598 .36544 Mdot
.598 .36545 Mdot
.598 .36549 Mdot
.598 .36553 Mdot
.598 .36556 Mdot
.598 .36557 Mdot
.598 .36561 Mdot
.598 .36562 Mdot
.598 .36563 Mdot
.598 .36565 Mdot
.598 .36567 Mdot
.598 .36567 Mdot
.598 .36574 Mdot
.598 .36583 Mdot
.598 .36584 Mdot
.598 .36587 Mdot
.598 .36588 Mdot
.598 .36589 Mdot
.598 .36591 Mdot
.598 .36591 Mdot
.598 .36597 Mdot
.598 .366 Mdot
.598 .36602 Mdot
.598 .36603 Mdot
.598 .36606 Mdot
.598 .36606 Mdot
.598 .36612 Mdot
.598 .36616 Mdot
.598 .36617 Mdot
.598 .36619 Mdot
.598 .36622 Mdot
.598 .36624 Mdot
.598 .36627 Mdot
.598 .3663 Mdot
.598 .36632 Mdot
.598 .36632 Mdot
.598 .36638 Mdot
.598 .36639 Mdot
.598 .36641 Mdot
.598 .36644 Mdot
.598 .36645 Mdot
.598 .36651 Mdot
.598 .36651 Mdot
.598 .36656 Mdot
.598 .36657 Mdot
.598 .3666 Mdot
.598 .36661 Mdot
.598 .36661 Mdot
.598 .36662 Mdot
.598 .36663 Mdot
.598 .36663 Mdot
.598 .36666 Mdot
.598 .36668 Mdot
.598 .36672 Mdot
.598 .36674 Mdot
.598 .36675 Mdot
.598 .3668 Mdot
.598 .36683 Mdot
.598 .36683 Mdot
.598 .36687 Mdot
.598 .36688 Mdot
.598 .36688 Mdot
.598 .36689 Mdot
.598 .36691 Mdot
.598 .36693 Mdot
.598 .36699 Mdot
.598 .36702 Mdot
.598 .36703 Mdot
.598 .36705 Mdot
.598 .36706 Mdot
.598 .36716 Mdot
.598 .36717 Mdot
.598 .3672 Mdot
.598 .36726 Mdot
.598 .3673 Mdot
.598 .36734 Mdot
.598 .36736 Mdot
.598 .36737 Mdot
.598 .36738 Mdot
.598 .36739 Mdot
.598 .36744 Mdot
.598 .36746 Mdot
.598 .36749 Mdot
.598 .3675 Mdot
.6 .29796 Mdot
.6 .29797 Mdot
.6 .29805 Mdot
.6 .29807 Mdot
.6 .29809 Mdot
.6 .29815 Mdot
.6 .29815 Mdot
.6 .2982 Mdot
.6 .29825 Mdot
.6 .29826 Mdot
.6 .29828 Mdot
.6 .29829 Mdot
.6 .29829 Mdot
.6 .29832 Mdot
.6 .29834 Mdot
.6 .29842 Mdot
.6 .29849 Mdot
.6 .2985 Mdot
.6 .29854 Mdot
.6 .29857 Mdot
.6 .29857 Mdot
.6 .29865 Mdot
.6 .29867 Mdot
.6 .29875 Mdot
.6 .29877 Mdot
.6 .29877 Mdot
.6 .29877 Mdot
.6 .2988 Mdot
.6 .2989 Mdot
.6 .29893 Mdot
.6 .29894 Mdot
.6 .29895 Mdot
.6 .29897 Mdot
.6 .29899 Mdot
.6 .29899 Mdot
.6 .29901 Mdot
.6 .29911 Mdot
.6 .29911 Mdot
.6 .29914 Mdot
.6 .29916 Mdot
.6 .29918 Mdot
.6 .29921 Mdot
.6 .29928 Mdot
.6 .29929 Mdot
.6 .29931 Mdot
.6 .29931 Mdot
.6 .29936 Mdot
.6 .29938 Mdot
.6 .29939 Mdot
.6 .29944 Mdot
.6 .29952 Mdot
.6 .29955 Mdot
.6 .29956 Mdot
.6 .29956 Mdot
.6 .29961 Mdot
.6 .29964 Mdot
.6 .29967 Mdot
.6 .29978 Mdot
.6 .29983 Mdot
.6 .29986 Mdot
.6 .29987 Mdot
.6 .29992 Mdot
.6 .29994 Mdot
.6 .3 Mdot
.6 .3 Mdot
.6 .30001 Mdot
.6 .30002 Mdot
.6 .30004 Mdot
.6 .30006 Mdot
.6 .30006 Mdot
.6 .30015 Mdot
.6 .30016 Mdot
.6 .30025 Mdot
.6 .30026 Mdot
.6 .30026 Mdot
.6 .30027 Mdot
.6 .30031 Mdot
.6 .30032 Mdot
.6 .30033 Mdot
.6 .30033 Mdot
.6 .30033 Mdot
.6 .30033 Mdot
.6 .30034 Mdot
.6 .30036 Mdot
.6 .30037 Mdot
.6 .30041 Mdot
.6 .30046 Mdot
.6 .30047 Mdot
.6 .30048 Mdot
.6 .30048 Mdot
.6 .30049 Mdot
.6 .30059 Mdot
.6 .30068 Mdot
.6 .3007 Mdot
.6 .3007 Mdot
.6 .30079 Mdot
.6 .30087 Mdot
.6 .30088 Mdot
.6 .30089 Mdot
.6 .30092 Mdot
.6 .30096 Mdot
.6 .30099 Mdot
.6 .301 Mdot
.6 .301 Mdot
.6 .30102 Mdot
.6 .30108 Mdot
.6 .30109 Mdot
.6 .30113 Mdot
.6 .30114 Mdot
.6 .30118 Mdot
.6 .30121 Mdot
.6 .30122 Mdot
.6 .30129 Mdot
.6 .3013 Mdot
.6 .30132 Mdot
.6 .30133 Mdot
.6 .30133 Mdot
.6 .30136 Mdot
.6 .30138 Mdot
.6 .30143 Mdot
.6 .30147 Mdot
.6 .30147 Mdot
.6 .30159 Mdot
.6 .3016 Mdot
.6 .30162 Mdot
.6 .30169 Mdot
.6 .30169 Mdot
.6 .30175 Mdot
.6 .30181 Mdot
.6 .30183 Mdot
.6 .30192 Mdot
.6 .30192 Mdot
.6 .30194 Mdot
.6 .30201 Mdot
.6 .30203 Mdot
.6 .30203 Mdot
.6 .30209 Mdot
.6 .30217 Mdot
.6 .30217 Mdot
.6 .30218 Mdot
.6 .30218 Mdot
.6 .30221 Mdot
.6 .30222 Mdot
.6 .30224 Mdot
.6 .30228 Mdot
.6 .3023 Mdot
.6 .30234 Mdot
.6 .30236 Mdot
.6 .30244 Mdot
.6 .30245 Mdot
.6 .30245 Mdot
.6 .30248 Mdot
.6 .30249 Mdot
.6 .30252 Mdot
.6 .30254 Mdot
.6 .30259 Mdot
.6 .30264 Mdot
.6 .30264 Mdot
.6 .30267 Mdot
.6 .30268 Mdot
.6 .30271 Mdot
.6 .30275 Mdot
.6 .3028 Mdot
.6 .30286 Mdot
.6 .3029 Mdot
.6 .30294 Mdot
.6 .303 Mdot
.6 .30304 Mdot
.6 .30304 Mdot
.6 .30306 Mdot
.6 .3031 Mdot
.6 .3031 Mdot
.6 .30315 Mdot
.6 .30316 Mdot
.6 .30316 Mdot
.6 .30318 Mdot
.6 .3032 Mdot
.6 .30322 Mdot
.6 .30328 Mdot
.6 .30329 Mdot
.6 .3033 Mdot
.6 .30333 Mdot
.6 .30339 Mdot
.6 .3035 Mdot
.6 .3035 Mdot
.6 .30352 Mdot
.6 .30356 Mdot
.6 .30356 Mdot
.6 .30357 Mdot
.6 .30358 Mdot
.6 .30359 Mdot
.6 .3036 Mdot
.6 .30365 Mdot
.6 .30369 Mdot
.6 .30371 Mdot
.6 .30374 Mdot
.6 .30377 Mdot
.6 .30379 Mdot
.6 .3038 Mdot
.6 .30381 Mdot
.6 .30391 Mdot
.6 .30393 Mdot
.6 .30396 Mdot
.6 .30398 Mdot
.6 .30398 Mdot
.6 .30404 Mdot
.6 .30404 Mdot
.6 .3041 Mdot
.6 .30411 Mdot
.6 .30412 Mdot
.6 .30415 Mdot
.6 .3042 Mdot
.6 .30422 Mdot
.6 .30424 Mdot
.6 .30425 Mdot
.6 .30428 Mdot
.6 .3043 Mdot
.6 .30431 Mdot
.6 .30432 Mdot
.6 .30434 Mdot
.6 .30435 Mdot
.6 .3044 Mdot
.6 .30441 Mdot
.6 .30443 Mdot
.6 .30446 Mdot
.6 .30449 Mdot
.6 .3045 Mdot
.6 .30454 Mdot
.6 .30455 Mdot
.6 .30456 Mdot
.6 .30456 Mdot
.6 .30458 Mdot
.6 .30459 Mdot
.6 .30461 Mdot
.6 .30464 Mdot
.6 .30464 Mdot
.6 .30465 Mdot
.6 .30468 Mdot
.6 .30471 Mdot
.6 .30471 Mdot
.6 .30475 Mdot
.6 .30478 Mdot
.6 .30479 Mdot
.6 .30482 Mdot
.6 .30483 Mdot
.6 .30484 Mdot
.6 .30484 Mdot
.6 .30485 Mdot
.6 .30487 Mdot
.6 .30489 Mdot
.6 .30489 Mdot
.6 .30491 Mdot
.6 .30492 Mdot
.6 .30496 Mdot
.6 .30497 Mdot
.6 .30498 Mdot
.6 .30501 Mdot
.6 .30501 Mdot
.6 .30505 Mdot
.6 .30508 Mdot
.6 .30508 Mdot
.6 .30512 Mdot
.6 .30516 Mdot
.6 .30517 Mdot
.6 .30518 Mdot
.6 .30521 Mdot
.6 .30522 Mdot
.6 .30523 Mdot
.6 .30525 Mdot
.6 .30526 Mdot
.6 .30529 Mdot
.6 .30529 Mdot
.6 .30531 Mdot
.6 .30532 Mdot
.6 .30538 Mdot
.6 .30539 Mdot
.6 .30543 Mdot
.6 .30548 Mdot
.6 .30551 Mdot
.6 .30552 Mdot
.6 .30559 Mdot
.6 .3056 Mdot
.6 .30564 Mdot
.6 .30566 Mdot
.6 .30567 Mdot
.6 .3057 Mdot
.6 .30574 Mdot
.6 .30575 Mdot
.6 .30579 Mdot
.6 .30581 Mdot
.6 .30588 Mdot
.6 .30592 Mdot
.6 .30594 Mdot
.6 .30596 Mdot
.6 .30604 Mdot
.6 .30604 Mdot
.6 .30612 Mdot
.6 .30613 Mdot
.6 .30615 Mdot
.6 .3062 Mdot
.6 .30622 Mdot
.6 .30638 Mdot
.6 .30638 Mdot
.6 .3064 Mdot
.6 .30644 Mdot
.6 .30647 Mdot
.6 .30652 Mdot
.6 .30654 Mdot
.6 .3066 Mdot
.6 .30668 Mdot
.6 .30669 Mdot
.6 .3067 Mdot
.6 .30672 Mdot
.6 .30673 Mdot
.6 .30673 Mdot
.6 .30679 Mdot
.6 .30683 Mdot
.6 .30683 Mdot
.6 .30698 Mdot
.6 .30706 Mdot
.6 .30711 Mdot
.6 .30713 Mdot
.6 .30713 Mdot
.6 .30722 Mdot
.6 .30725 Mdot
.6 .30728 Mdot
.6 .30731 Mdot
.6 .30732 Mdot
.6 .30732 Mdot
.6 .30739 Mdot
.6 .30739 Mdot
.6 .30745 Mdot
.6 .30748 Mdot
.6 .30749 Mdot
.6 .30754 Mdot
.6 .30763 Mdot
.6 .30769 Mdot
.6 .30775 Mdot
.6 .30782 Mdot
.6 .3079 Mdot
.6 .30795 Mdot
.6 .30801 Mdot
.6 .30802 Mdot
.6 .30805 Mdot
.6 .30806 Mdot
.6 .30813 Mdot
.6 .3082 Mdot
.6 .30824 Mdot
.6 .30828 Mdot
.6 .30829 Mdot
.6 .30833 Mdot
.6 .30833 Mdot
.6 .30835 Mdot
.6 .30846 Mdot
.6 .30848 Mdot
.6 .30854 Mdot
.6 .30857 Mdot
.6 .30863 Mdot
.6 .30866 Mdot
.6 .30868 Mdot
.6 .30872 Mdot
.6 .30872 Mdot
.6 .30873 Mdot
.6 .30874 Mdot
.6 .30885 Mdot
.6 .30894 Mdot
.6 .30894 Mdot
.6 .30896 Mdot
.6 .30907 Mdot
.6 .30909 Mdot
.6 .30909 Mdot
.6 .30923 Mdot
.6 .30925 Mdot
.6 .30934 Mdot
.6 .30943 Mdot
.6 .30943 Mdot
.6 .30952 Mdot
.6 .30956 Mdot
.6 .30957 Mdot
.6 .30974 Mdot
.6 .30975 Mdot
.6 .30981 Mdot
.6 .30987 Mdot
.6 .3099 Mdot
.6 .30994 Mdot
.6 .30995 Mdot
.6 .30996 Mdot
.6 .30999 Mdot
.6 .31 Mdot
.6 .31011 Mdot
.6 .31011 Mdot
.6 .31016 Mdot
.6 .31022 Mdot
.6 .31023 Mdot
.6 .31029 Mdot
.6 .3103 Mdot
.6 .3104 Mdot
.6 .31042 Mdot
.6 .31042 Mdot
.6 .31044 Mdot
.6 .31047 Mdot
.6 .31054 Mdot
.6 .31056 Mdot
.6 .31058 Mdot
.6 .31059 Mdot
.6 .31061 Mdot
.6 .31072 Mdot
.6 .31085 Mdot
.6 .31085 Mdot
.6 .31088 Mdot
.6 .311 Mdot
.6 .31116 Mdot
.6 .31117 Mdot
.6 .31117 Mdot
.6 .31119 Mdot
.6 .3112 Mdot
.6 .31127 Mdot
.6 .31133 Mdot
.6 .31134 Mdot
.6 .31138 Mdot
.6 .31138 Mdot
.6 .31139 Mdot
.6 .31139 Mdot
.6 .31139 Mdot
.6 .31141 Mdot
.6 .31141 Mdot
.6 .31148 Mdot
.6 .31148 Mdot
.6 .31149 Mdot
.6 .31149 Mdot
.6 .31163 Mdot
.6 .31164 Mdot
.6 .31177 Mdot
.6 .31178 Mdot
.6 .3118 Mdot
.6 .31183 Mdot
.6 .31184 Mdot
.6 .31185 Mdot
.6 .31186 Mdot
.6 .31195 Mdot
.6 .31198 Mdot
.6 .31205 Mdot
.6 .31206 Mdot
.6 .3121 Mdot
.6 .31218 Mdot
.6 .31233 Mdot
.6 .31237 Mdot
.6 .31242 Mdot
.6 .31249 Mdot
.6 .31249 Mdot
.6 .3125 Mdot
.6 .31255 Mdot
.6 .31267 Mdot
.6 .31274 Mdot
.6 .31276 Mdot
.6 .31278 Mdot
.6 .31286 Mdot
.6 .31286 Mdot
.6 .31288 Mdot
.6 .3129 Mdot
.6 .31299 Mdot
.6 .31304 Mdot
.6 .31306 Mdot
.6 .3131 Mdot
.6 .31314 Mdot
.6 .31328 Mdot
.6 .31331 Mdot
.6 .31331 Mdot
.6 .31335 Mdot
.6 .31337 Mdot
.6 .31338 Mdot
.6 .3134 Mdot
.6 .31344 Mdot
.6 .31358 Mdot
.6 .31363 Mdot
.6 .31363 Mdot
.6 .31364 Mdot
.6 .31366 Mdot
.6 .31377 Mdot
.6 .3138 Mdot
.6 .31392 Mdot
.6 .31392 Mdot
.6 .31396 Mdot
.6 .31402 Mdot
.6 .31404 Mdot
.6 .31414 Mdot
.6 .31426 Mdot
.6 .31428 Mdot
.6 .31433 Mdot
.6 .31433 Mdot
.6 .31434 Mdot
.6 .31436 Mdot
.6 .31438 Mdot
.6 .31446 Mdot
.6 .31452 Mdot
.6 .31453 Mdot
.6 .3146 Mdot
.6 .31463 Mdot
.6 .31466 Mdot
.6 .31478 Mdot
.6 .31479 Mdot
.6 .35461 Mdot
.6 .35463 Mdot
.6 .35472 Mdot
.6 .35475 Mdot
.6 .35477 Mdot
.6 .35483 Mdot
.6 .35484 Mdot
.6 .35489 Mdot
.6 .35496 Mdot
.6 .35497 Mdot
.6 .35499 Mdot
.6 .355 Mdot
.6 .355 Mdot
.6 .35504 Mdot
.6 .35506 Mdot
.6 .35516 Mdot
.6 .35524 Mdot
.6 .35526 Mdot
.6 .3553 Mdot
.6 .35534 Mdot
.6 .35534 Mdot
.6 .35544 Mdot
.6 .35546 Mdot
.6 .35556 Mdot
.6 .35558 Mdot
.6 .35558 Mdot
.6 .35558 Mdot
.6 .35562 Mdot
.6 .35574 Mdot
.6 .35578 Mdot
.6 .35579 Mdot
.6 .3558 Mdot
.6 .35582 Mdot
.6 .35585 Mdot
.6 .35585 Mdot
.6 .35587 Mdot
.6 .35599 Mdot
.6 .35602 Mdot
.6 .35605 Mdot
.6 .35607 Mdot
.6 .35611 Mdot
.6 .35619 Mdot
.6 .3562 Mdot
.6 .35622 Mdot
.6 .35623 Mdot
.6 .35629 Mdot
.6 .35631 Mdot
.6 .35632 Mdot
.6 .35638 Mdot
.6 .35648 Mdot
.6 .35652 Mdot
.6 .35653 Mdot
.6 .35653 Mdot
.6 .35659 Mdot
.6 .35663 Mdot
.6 .35666 Mdot
.6 .35679 Mdot
.6 .35686 Mdot
.6 .35689 Mdot
.6 .3569 Mdot
.6 .35696 Mdot
.6 .35698 Mdot
.6 .35705 Mdot
.6 .35706 Mdot
.6 .35707 Mdot
.6 .35708 Mdot
.6 .35711 Mdot
.6 .35713 Mdot
.6 .35713 Mdot
.6 .35724 Mdot
.6 .35725 Mdot
.6 .35736 Mdot
.6 .35736 Mdot
.6 .35737 Mdot
.6 .35738 Mdot
.6 .35743 Mdot
.6 .35744 Mdot
.6 .35745 Mdot
.6 .35745 Mdot
.6 .35745 Mdot
.6 .35745 Mdot
.6 .35746 Mdot
.6 .35749 Mdot
.6 .3575 Mdot
.6 .35755 Mdot
.6 .35761 Mdot
.6 .35762 Mdot
.6 .35763 Mdot
.6 .35764 Mdot
.6 .35764 Mdot
.6 .35777 Mdot
.6 .35787 Mdot
.6 .3579 Mdot
.6 .3579 Mdot
.6 .358 Mdot
.6 .3581 Mdot
.6 .35812 Mdot
.6 .35813 Mdot
.6 .35816 Mdot
.6 .35821 Mdot
.6 .35824 Mdot
.6 .35825 Mdot
.6 .35826 Mdot
.6 .35828 Mdot
.6 .35835 Mdot
.6 .35836 Mdot
.6 .35841 Mdot
.6 .35842 Mdot
.6 .35847 Mdot
.6 .35851 Mdot
.6 .35852 Mdot
.6 .35861 Mdot
.6 .35862 Mdot
.6 .35864 Mdot
.6 .35865 Mdot
.6 .35866 Mdot
.6 .35869 Mdot
.6 .35871 Mdot
.6 .35877 Mdot
.6 .35882 Mdot
.6 .35882 Mdot
.6 .35896 Mdot
.6 .35897 Mdot
.6 .35901 Mdot
.6 .35909 Mdot
.6 .35909 Mdot
.6 .35916 Mdot
.6 .35923 Mdot
.6 .35925 Mdot
.6 .35936 Mdot
.6 .35936 Mdot
.6 .35938 Mdot
.6 .35947 Mdot
.6 .35949 Mdot
.6 .35949 Mdot
.6 .35956 Mdot
.6 .35966 Mdot
.6 .35967 Mdot
.6 .35968 Mdot
.6 .35968 Mdot
.6 .35971 Mdot
.6 .35972 Mdot
.6 .35975 Mdot
.6 .3598 Mdot
.6 .35982 Mdot
.6 .35987 Mdot
.6 .35989 Mdot
.6 .35998 Mdot
.6 .36 Mdot
.6 .36 Mdot
.6 .36003 Mdot
.6 .36004 Mdot
.6 .36008 Mdot
.6 .36011 Mdot
.6 .36016 Mdot
.6 .36022 Mdot
.6 .36023 Mdot
.6 .36026 Mdot
.6 .36027 Mdot
.6 .36031 Mdot
.6 .36035 Mdot
.6 .36042 Mdot
.6 .36048 Mdot
.6 .36053 Mdot
.6 .36058 Mdot
.6 .36065 Mdot
.6 .3607 Mdot
.6 .36071 Mdot
.6 .36073 Mdot
.6 .36078 Mdot
.6 .36078 Mdot
.6 .36084 Mdot
.6 .36084 Mdot
.6 .36085 Mdot
.6 .36087 Mdot
.6 .3609 Mdot
.6 .36092 Mdot
.6 .361 Mdot
.6 .361 Mdot
.6 .36102 Mdot
.6 .36106 Mdot
.6 .36113 Mdot
.6 .36125 Mdot
.6 .36125 Mdot
.6 .36129 Mdot
.6 .36133 Mdot
.6 .36133 Mdot
.6 .36134 Mdot
.6 .36135 Mdot
.6 .36136 Mdot
.6 .36138 Mdot
.6 .36144 Mdot
.6 .36149 Mdot
.6 .36151 Mdot
.6 .36155 Mdot
.6 .36158 Mdot
.6 .3616 Mdot
.6 .36162 Mdot
.6 .36163 Mdot
.6 .36175 Mdot
.6 .36178 Mdot
.6 .36181 Mdot
.6 .36184 Mdot
.6 .36184 Mdot
.6 .3619 Mdot
.6 .36191 Mdot
.6 .36198 Mdot
.6 .36199 Mdot
.6 .36201 Mdot
.6 .36204 Mdot
.6 .3621 Mdot
.6 .36212 Mdot
.6 .36215 Mdot
.6 .36215 Mdot
.6 .36219 Mdot
.6 .36221 Mdot
.6 .36222 Mdot
.6 .36224 Mdot
.6 .36227 Mdot
.6 .36228 Mdot
.6 .36234 Mdot
.6 .36235 Mdot
.6 .36237 Mdot
.6 .36241 Mdot
.6 .36245 Mdot
.6 .36245 Mdot
.6 .36251 Mdot
.6 .36252 Mdot
.6 .36253 Mdot
.6 .36253 Mdot
.6 .36255 Mdot
.6 .36257 Mdot
.6 .36258 Mdot
.6 .36259 Mdot
.6 .3626 Mdot
.6 .36263 Mdot
.6 .36263 Mdot
.6 .36264 Mdot
.6 .36268 Mdot
.6 .36271 Mdot
.6 .36271 Mdot
.6 .36274 Mdot
.6 .36276 Mdot
.6 .36277 Mdot
.6 .36279 Mdot
.6 .3628 Mdot
.6 .3628 Mdot
.6 .36284 Mdot
.6 .36285 Mdot
.6 .36287 Mdot
.6 .36287 Mdot
.6 .36288 Mdot
.6 .3629 Mdot
.6 .3629 Mdot
.6 .36291 Mdot
.6 .36292 Mdot
.6 .36292 Mdot
.6 .36295 Mdot
.6 .36296 Mdot
.6 .36298 Mdot
.6 .36301 Mdot
.6 .36302 Mdot
.6 .36304 Mdot
.6 .36306 Mdot
.6 .36307 Mdot
.6 .36307 Mdot
.6 .3631 Mdot
.6 .36311 Mdot
.6 .36312 Mdot
.6 .36314 Mdot
.6 .36314 Mdot
.6 .36315 Mdot
.6 .36315 Mdot
.6 .36319 Mdot
.6 .3632 Mdot
.6 .36322 Mdot
.6 .36325 Mdot
.6 .36326 Mdot
.6 .36327 Mdot
.6 .36331 Mdot
.6 .36332 Mdot
.6 .36334 Mdot
.6 .36335 Mdot
.6 .36336 Mdot
.6 .36337 Mdot
.6 .3634 Mdot
.6 .3634 Mdot
.6 .36343 Mdot
.6 .36344 Mdot
.6 .36348 Mdot
.6 .3635 Mdot
.6 .36352 Mdot
.6 .36352 Mdot
.6 .36357 Mdot
.6 .36357 Mdot
.6 .36362 Mdot
.6 .36362 Mdot
.6 .36364 Mdot
.6 .36366 Mdot
.6 .36368 Mdot
.6 .36377 Mdot
.6 .36377 Mdot
.6 .36378 Mdot
.6 .3638 Mdot
.6 .36382 Mdot
.6 .36385 Mdot
.6 .36386 Mdot
.6 .3639 Mdot
.6 .36394 Mdot
.6 .36395 Mdot
.6 .36396 Mdot
.6 .36397 Mdot
.6 .36397 Mdot
.6 .36397 Mdot
.6 .364 Mdot
.6 .36403 Mdot
.6 .36403 Mdot
.6 .36411 Mdot
.6 .36416 Mdot
.6 .36419 Mdot
.6 .3642 Mdot
.6 .36421 Mdot
.6 .36425 Mdot
.6 .36427 Mdot
.6 .36429 Mdot
.6 .36431 Mdot
.6 .36431 Mdot
.6 .36431 Mdot
.6 .36435 Mdot
.6 .36436 Mdot
.6 .36439 Mdot
.6 .36441 Mdot
.6 .36441 Mdot
.6 .36444 Mdot
.6 .36449 Mdot
.6 .36453 Mdot
.6 .36456 Mdot
.6 .3646 Mdot
.6 .36465 Mdot
.6 .36468 Mdot
.6 .36471 Mdot
.6 .36472 Mdot
.6 .36474 Mdot
.6 .36474 Mdot
.6 .36478 Mdot
.6 .36482 Mdot
.6 .36484 Mdot
.6 .36487 Mdot
.6 .36488 Mdot
.6 .3649 Mdot
.6 .3649 Mdot
.6 .36491 Mdot
.6 .36497 Mdot
.6 .36499 Mdot
.6 .36502 Mdot
.6 .36504 Mdot
.6 .36507 Mdot
.6 .36509 Mdot
.6 .3651 Mdot
.6 .36512 Mdot
.6 .36512 Mdot
.6 .36513 Mdot
.6 .36513 Mdot
.6 .3652 Mdot
.6 .36525 Mdot
.6 .36525 Mdot
.6 .36526 Mdot
.6 .36532 Mdot
.6 .36534 Mdot
.6 .36534 Mdot
.6 .36542 Mdot
.6 .36543 Mdot
.6 .36548 Mdot
.6 .36553 Mdot
.6 .36553 Mdot
.6 .36559 Mdot
.6 .36561 Mdot
.6 .36562 Mdot
.6 .36572 Mdot
.6 .36572 Mdot
.6 .36575 Mdot
.6 .36579 Mdot
.6 .36581 Mdot
.6 .36583 Mdot
.6 .36584 Mdot
.6 .36584 Mdot
.6 .36586 Mdot
.6 .36586 Mdot
.6 .36592 Mdot
.6 .36593 Mdot
.6 .36596 Mdot
.6 .36599 Mdot
.6 .366 Mdot
.6 .36603 Mdot
.6 .36604 Mdot
.6 .36609 Mdot
.6 .3661 Mdot
.6 .36611 Mdot
.6 .36612 Mdot
.6 .36614 Mdot
.6 .36617 Mdot
.6 .3662 Mdot
.6 .3662 Mdot
.6 .36622 Mdot
.6 .36628 Mdot
.6 .36635 Mdot
.6 .36636 Mdot
.6 .36638 Mdot
.6 .36644 Mdot
.6 .36654 Mdot
.6 .36654 Mdot
.6 .36654 Mdot
.6 .36655 Mdot
.6 .36656 Mdot
.6 .3666 Mdot
.6 .36664 Mdot
.6 .36664 Mdot
.6 .36666 Mdot
.6 .36666 Mdot
.6 .36667 Mdot
.6 .36667 Mdot
.6 .36667 Mdot
.6 .36668 Mdot
.6 .36668 Mdot
.6 .36672 Mdot
.6 .36672 Mdot
.6 .36673 Mdot
.6 .36673 Mdot
.6 .36681 Mdot
.6 .36681 Mdot
.6 .36689 Mdot
.6 .36689 Mdot
.6 .3669 Mdot
.6 .36692 Mdot
.6 .36693 Mdot
.6 .36694 Mdot
.6 .36694 Mdot
.6 .36699 Mdot
.6 .36701 Mdot
.6 .36705 Mdot
.6 .36706 Mdot
.6 .36708 Mdot
.6 .36712 Mdot
.6 .36721 Mdot
.6 .36724 Mdot
.6 .36727 Mdot
.6 .36731 Mdot
.6 .36731 Mdot
.6 .36731 Mdot
.6 .36734 Mdot
.6 .36741 Mdot
.6 .36745 Mdot
.6 .36746 Mdot
.6 .36748 Mdot
.6 .36752 Mdot
.6 .36752 Mdot
.6 .36753 Mdot
.6 .36754 Mdot
.6 .3676 Mdot
.6 .36762 Mdot
.6 .36764 Mdot
.6 .36766 Mdot
.6 .36768 Mdot
.6 .36769 Mdot
.6 .36776 Mdot
.6 .36778 Mdot
.6 .36778 Mdot
.6 .3678 Mdot
.6 .36781 Mdot
.6 .36782 Mdot
.6 .36783 Mdot
.6 .36785 Mdot
.6 .36794 Mdot
.6 .36796 Mdot
.6 .36797 Mdot
.6 .36797 Mdot
.6 .36798 Mdot
.6 .36805 Mdot
.6 .36806 Mdot
.6 .36813 Mdot
.6 .36813 Mdot
.6 .36816 Mdot
.6 .36819 Mdot
.6 .3682 Mdot
.6 .36826 Mdot
.6 .36833 Mdot
.6 .36834 Mdot
.6 .36837 Mdot
.6 .36837 Mdot
.6 .36837 Mdot
.6 .36839 Mdot
.6 .3684 Mdot
.6 .36844 Mdot
.6 .36848 Mdot
.6 .36848 Mdot
.6 .36853 Mdot
.6 .36855 Mdot
.6 .36856 Mdot
.6 .36863 Mdot
.6 .36864 Mdot
.602 .29743 Mdot
.602 .29746 Mdot
.602 .2975 Mdot
.602 .29752 Mdot
.602 .29768 Mdot
.602 .29773 Mdot
.602 .29775 Mdot
.602 .29776 Mdot
.602 .29782 Mdot
.602 .29783 Mdot
.602 .29785 Mdot
.602 .29785 Mdot
.602 .29787 Mdot
.602 .29793 Mdot
.602 .29793 Mdot
.602 .29795 Mdot
.602 .29796 Mdot
.602 .29797 Mdot
.602 .29797 Mdot
.602 .298 Mdot
.602 .29806 Mdot
.602 .29809 Mdot
.602 .29811 Mdot
.602 .29811 Mdot
.602 .29812 Mdot
.602 .29813 Mdot
.602 .29816 Mdot
.602 .29818 Mdot
.602 .29827 Mdot
.602 .29831 Mdot
.602 .29835 Mdot
.602 .29836 Mdot
.602 .29837 Mdot
.602 .29848 Mdot
.602 .29851 Mdot
.602 .29858 Mdot
.602 .2986 Mdot
.602 .29864 Mdot
.602 .29868 Mdot
.602 .29868 Mdot
.602 .29872 Mdot
.602 .29874 Mdot
.602 .29875 Mdot
.602 .29877 Mdot
.602 .2988 Mdot
.602 .29889 Mdot
.602 .29893 Mdot
.602 .29899 Mdot
.602 .2991 Mdot
.602 .29912 Mdot
.602 .29912 Mdot
.602 .29921 Mdot
.602 .29921 Mdot
.602 .29926 Mdot
.602 .29929 Mdot
.602 .2993 Mdot
.602 .29931 Mdot
.602 .29939 Mdot
.602 .29943 Mdot
.602 .29951 Mdot
.602 .29957 Mdot
.602 .29957 Mdot
.602 .29963 Mdot
.602 .29968 Mdot
.602 .2997 Mdot
.602 .29972 Mdot
.602 .29975 Mdot
.602 .29984 Mdot
.602 .29987 Mdot
.602 .29989 Mdot
.602 .29997 Mdot
.602 .30001 Mdot
.602 .30005 Mdot
.602 .30006 Mdot
.602 .30008 Mdot
.602 .30014 Mdot
.602 .30018 Mdot
.602 .30023 Mdot
.602 .30027 Mdot
.602 .30029 Mdot
.602 .30034 Mdot
.602 .30038 Mdot
.602 .30042 Mdot
.602 .30042 Mdot
.602 .30051 Mdot
.602 .30053 Mdot
.602 .30054 Mdot
.602 .30059 Mdot
.602 .3006 Mdot
.602 .30063 Mdot
.602 .30063 Mdot
.602 .30065 Mdot
.602 .30067 Mdot
.602 .30068 Mdot
.602 .30071 Mdot
.602 .30078 Mdot
.602 .30078 Mdot
.602 .30087 Mdot
.602 .3009 Mdot
.602 .3009 Mdot
.602 .30091 Mdot
.602 .30098 Mdot
.602 .30102 Mdot
.602 .30103 Mdot
.602 .30106 Mdot
.602 .30107 Mdot
.602 .3011 Mdot
.602 .30119 Mdot
.602 .30123 Mdot
.602 .30125 Mdot
.602 .30127 Mdot
.602 .30137 Mdot
.602 .30142 Mdot
.602 .30143 Mdot
.602 .30144 Mdot
.602 .30147 Mdot
.602 .30148 Mdot
.602 .30149 Mdot
.602 .30149 Mdot
.602 .30149 Mdot
.602 .3015 Mdot
.602 .30153 Mdot
.602 .30155 Mdot
.602 .30156 Mdot
.602 .30158 Mdot
.602 .30163 Mdot
.602 .30165 Mdot
.602 .30167 Mdot
.602 .30173 Mdot
.602 .30184 Mdot
.602 .30185 Mdot
.602 .30188 Mdot
.602 .30198 Mdot
.602 .30203 Mdot
.602 .30208 Mdot
.602 .3021 Mdot
.602 .30212 Mdot
.602 .30213 Mdot
.602 .30225 Mdot
.602 .30225 Mdot
.602 .3023 Mdot
.602 .30232 Mdot
.602 .30233 Mdot
.602 .30246 Mdot
.602 .30248 Mdot
.602 .30249 Mdot
.602 .30252 Mdot
.602 .30254 Mdot
.602 .30259 Mdot
.602 .30264 Mdot
.602 .30265 Mdot
.602 .30266 Mdot
.602 .3027 Mdot
.602 .30271 Mdot
.602 .30274 Mdot
.602 .30275 Mdot
.602 .30276 Mdot
.602 .30277 Mdot
.602 .30279 Mdot
.602 .30282 Mdot
.602 .30287 Mdot
.602 .30288 Mdot
.602 .30292 Mdot
.602 .30295 Mdot
.602 .30296 Mdot
.602 .30297 Mdot
.602 .30298 Mdot
.602 .30304 Mdot
.602 .30305 Mdot
.602 .30311 Mdot
.602 .30313 Mdot
.602 .30314 Mdot
.602 .30316 Mdot
.602 .30316 Mdot
.602 .30317 Mdot
.602 .30317 Mdot
.602 .30319 Mdot
.602 .3032 Mdot
.602 .30321 Mdot
.602 .30323 Mdot
.602 .30328 Mdot
.602 .3034 Mdot
.602 .30342 Mdot
.602 .30345 Mdot
.602 .30346 Mdot
.602 .30347 Mdot
.602 .30353 Mdot
.602 .30355 Mdot
.602 .30356 Mdot
.602 .30363 Mdot
.602 .30364 Mdot
.602 .30364 Mdot
.602 .30366 Mdot
.602 .30374 Mdot
.602 .30376 Mdot
.602 .30377 Mdot
.602 .30378 Mdot
.602 .3038 Mdot
.602 .30383 Mdot
.602 .30385 Mdot
.602 .30387 Mdot
.602 .30387 Mdot
.602 .3039 Mdot
.602 .30391 Mdot
.602 .30394 Mdot
.602 .30395 Mdot
.602 .30396 Mdot
.602 .30396 Mdot
.602 .30396 Mdot
.602 .30396 Mdot
.602 .30397 Mdot
.602 .30398 Mdot
.602 .30399 Mdot
.602 .30402 Mdot
.602 .30407 Mdot
.602 .3041 Mdot
.602 .30413 Mdot
.602 .30415 Mdot
.602 .30419 Mdot
.602 .3042 Mdot
.602 .30424 Mdot
.602 .30425 Mdot
.602 .30426 Mdot
.602 .30426 Mdot
.602 .30429 Mdot
.602 .30431 Mdot
.602 .30433 Mdot
.602 .30434 Mdot
.602 .30434 Mdot
.602 .30434 Mdot
.602 .30436 Mdot
.602 .3044 Mdot
.602 .30442 Mdot
.602 .30443 Mdot
.602 .30445 Mdot
.602 .30448 Mdot
.602 .30448 Mdot
.602 .30452 Mdot
.602 .30452 Mdot
.602 .30453 Mdot
.602 .30455 Mdot
.602 .30456 Mdot
.602 .30457 Mdot
.602 .30459 Mdot
.602 .30461 Mdot
.602 .30464 Mdot
.602 .30466 Mdot
.602 .3047 Mdot
.602 .30472 Mdot
.602 .30474 Mdot
.602 .30475 Mdot
.602 .30478 Mdot
.602 .3048 Mdot
.602 .30483 Mdot
.602 .30485 Mdot
.602 .30486 Mdot
.602 .30487 Mdot
.602 .30488 Mdot
.602 .30491 Mdot
.602 .30492 Mdot
.602 .30493 Mdot
.602 .30499 Mdot
.602 .30499 Mdot
.602 .30503 Mdot
.602 .30505 Mdot
.602 .30507 Mdot
.602 .30509 Mdot
.602 .30516 Mdot
.602 .30518 Mdot
.602 .30518 Mdot
.602 .30519 Mdot
.602 .30519 Mdot
.602 .30522 Mdot
.602 .30522 Mdot
.602 .30525 Mdot
.602 .30526 Mdot
.602 .3053 Mdot
.602 .30531 Mdot
.602 .30532 Mdot
.602 .30532 Mdot
.602 .30533 Mdot
.602 .30539 Mdot
.602 .30541 Mdot
.602 .30541 Mdot
.602 .30546 Mdot
.602 .30548 Mdot
.602 .30554 Mdot
.602 .30557 Mdot
.602 .30565 Mdot
.602 .30569 Mdot
.602 .3057 Mdot
.602 .30572 Mdot
.602 .30573 Mdot
.602 .30573 Mdot
.602 .30573 Mdot
.602 .30574 Mdot
.602 .30575 Mdot
.602 .30577 Mdot
.602 .30581 Mdot
.602 .30582 Mdot
.602 .30587 Mdot
.602 .30587 Mdot
.602 .3059 Mdot
.602 .30593 Mdot
.602 .30597 Mdot
.602 .30599 Mdot
.602 .30602 Mdot
.602 .30603 Mdot
.602 .30605 Mdot
.602 .30616 Mdot
.602 .3062 Mdot
.602 .30621 Mdot
.602 .30622 Mdot
.602 .30631 Mdot
.602 .30633 Mdot
.602 .30636 Mdot
.602 .30645 Mdot
.602 .30647 Mdot
.602 .30648 Mdot
.602 .30652 Mdot
.602 .30655 Mdot
.602 .30672 Mdot
.602 .30679 Mdot
.602 .30683 Mdot
.602 .30684 Mdot
.602 .30686 Mdot
.602 .30688 Mdot
.602 .30689 Mdot
.602 .30689 Mdot
.602 .3069 Mdot
.602 .30693 Mdot
.602 .30694 Mdot
.602 .30697 Mdot
.602 .30706 Mdot
.602 .30707 Mdot
.602 .30716 Mdot
.602 .30718 Mdot
.602 .30718 Mdot
.602 .3072 Mdot
.602 .30724 Mdot
.602 .3073 Mdot
.602 .30732 Mdot
.602 .30738 Mdot
.602 .30743 Mdot
.602 .30746 Mdot
.602 .30747 Mdot
.602 .30748 Mdot
.602 .30751 Mdot
.602 .30755 Mdot
.602 .30757 Mdot
.602 .30763 Mdot
.602 .30763 Mdot
.602 .30766 Mdot
.602 .30772 Mdot
.602 .30779 Mdot
.602 .30782 Mdot
.602 .30786 Mdot
.602 .30788 Mdot
.602 .30791 Mdot
.602 .30809 Mdot
.602 .30811 Mdot
.602 .30814 Mdot
.602 .30821 Mdot
.602 .30822 Mdot
.602 .30839 Mdot
.602 .3084 Mdot
.602 .30843 Mdot
.602 .30846 Mdot
.602 .30854 Mdot
.602 .30861 Mdot
.602 .30875 Mdot
.602 .30879 Mdot
.602 .3088 Mdot
.602 .30897 Mdot
.602 .30906 Mdot
.602 .30908 Mdot
.602 .30911 Mdot
.602 .30919 Mdot
.602 .30921 Mdot
.602 .30922 Mdot
.602 .30925 Mdot
.602 .3093 Mdot
.602 .30931 Mdot
.602 .30932 Mdot
.602 .30932 Mdot
.602 .30933 Mdot
.602 .30934 Mdot
.602 .30939 Mdot
.602 .3094 Mdot
.602 .30942 Mdot
.602 .30948 Mdot
.602 .30963 Mdot
.602 .30967 Mdot
.602 .30969 Mdot
.602 .30975 Mdot
.602 .30988 Mdot
.602 .30992 Mdot
.602 .30993 Mdot
.602 .30998 Mdot
.602 .30999 Mdot
.602 .31005 Mdot
.602 .31016 Mdot
.602 .31017 Mdot
.602 .31018 Mdot
.602 .31022 Mdot
.602 .31034 Mdot
.602 .31035 Mdot
.602 .31045 Mdot
.602 .3105 Mdot
.602 .31051 Mdot
.602 .31053 Mdot
.602 .31057 Mdot
.602 .31057 Mdot
.602 .31061 Mdot
.602 .31063 Mdot
.602 .31071 Mdot
.602 .31074 Mdot
.602 .31087 Mdot
.602 .31087 Mdot
.602 .31093 Mdot
.602 .31099 Mdot
.602 .31106 Mdot
.602 .31109 Mdot
.602 .31114 Mdot
.602 .31122 Mdot
.602 .31127 Mdot
.602 .31137 Mdot
.602 .31139 Mdot
.602 .3114 Mdot
.602 .31146 Mdot
.602 .31152 Mdot
.602 .31164 Mdot
.602 .31166 Mdot
.602 .31171 Mdot
.602 .31185 Mdot
.602 .31188 Mdot
.602 .31191 Mdot
.602 .31194 Mdot
.602 .31202 Mdot
.602 .31209 Mdot
.602 .3121 Mdot
.602 .31218 Mdot
.602 .3123 Mdot
.602 .31235 Mdot
.602 .31247 Mdot
.602 .31249 Mdot
.602 .3125 Mdot
.602 .31256 Mdot
.602 .31262 Mdot
.602 .31263 Mdot
.602 .31275 Mdot
.602 .31276 Mdot
.602 .31278 Mdot
.602 .31294 Mdot
.602 .31303 Mdot
.602 .31309 Mdot
.602 .31322 Mdot
.602 .31326 Mdot
.602 .31329 Mdot
.602 .31331 Mdot
.602 .31334 Mdot
.602 .31338 Mdot
.602 .31339 Mdot
.602 .31345 Mdot
.602 .31351 Mdot
.602 .31353 Mdot
.602 .31364 Mdot
.602 .31368 Mdot
.602 .31384 Mdot
.602 .31386 Mdot
.602 .31387 Mdot
.602 .31393 Mdot
.602 .31398 Mdot
.602 .31412 Mdot
.602 .31414 Mdot
.602 .31419 Mdot
.602 .31421 Mdot
.602 .31422 Mdot
.602 .31422 Mdot
.602 .31425 Mdot
.602 .31428 Mdot
.602 .31437 Mdot
.602 .31441 Mdot
.602 .31442 Mdot
.602 .31443 Mdot
.602 .31445 Mdot
.602 .31447 Mdot
.602 .31447 Mdot
.602 .31456 Mdot
.602 .31459 Mdot
.602 .3146 Mdot
.602 .31462 Mdot
.602 .31463 Mdot
.602 .31472 Mdot
.602 .31475 Mdot
.602 .31477 Mdot
.602 .31483 Mdot
.602 .31508 Mdot
.602 .3151 Mdot
.602 .31516 Mdot
.602 .3152 Mdot
.602 .3551 Mdot
.602 .35514 Mdot
.602 .35519 Mdot
.602 .35521 Mdot
.602 .35541 Mdot
.602 .35546 Mdot
.602 .35548 Mdot
.602 .35551 Mdot
.602 .35558 Mdot
.602 .35558 Mdot
.602 .3556 Mdot
.602 .35561 Mdot
.602 .35563 Mdot
.602 .35571 Mdot
.602 .35571 Mdot
.602 .35573 Mdot
.602 .35574 Mdot
.602 .35576 Mdot
.602 .35576 Mdot
.602 .35579 Mdot
.602 .35587 Mdot
.602 .3559 Mdot
.602 .35592 Mdot
.602 .35592 Mdot
.602 .35593 Mdot
.602 .35594 Mdot
.602 .35598 Mdot
.602 .35601 Mdot
.602 .35612 Mdot
.602 .35616 Mdot
.602 .35621 Mdot
.602 .35622 Mdot
.602 .35624 Mdot
.602 .35637 Mdot
.602 .3564 Mdot
.602 .35649 Mdot
.602 .35651 Mdot
.602 .35656 Mdot
.602 .35661 Mdot
.602 .35661 Mdot
.602 .35665 Mdot
.602 .35668 Mdot
.602 .35669 Mdot
.602 .35671 Mdot
.602 .35675 Mdot
.602 .35686 Mdot
.602 .35691 Mdot
.602 .35698 Mdot
.602 .35712 Mdot
.602 .35714 Mdot
.602 .35714 Mdot
.602 .35724 Mdot
.602 .35725 Mdot
.602 .3573 Mdot
.602 .35735 Mdot
.602 .35735 Mdot
.602 .35737 Mdot
.602 .35747 Mdot
.602 .35752 Mdot
.602 .35761 Mdot
.602 .35768 Mdot
.602 .35768 Mdot
.602 .35775 Mdot
.602 .35781 Mdot
.602 .35784 Mdot
.602 .35786 Mdot
.602 .35789 Mdot
.602 .35801 Mdot
.602 .35804 Mdot
.602 .35807 Mdot
.602 .35816 Mdot
.602 .35822 Mdot
.602 .35826 Mdot
.602 .35827 Mdot
.602 .35829 Mdot
.602 .35837 Mdot
.602 .35841 Mdot
.602 .35848 Mdot
.602 .35852 Mdot
.602 .35855 Mdot
.602 .3586 Mdot
.602 .35865 Mdot
.602 .3587 Mdot
.602 .3587 Mdot
.602 .35881 Mdot
.602 .35883 Mdot
.602 .35891 Mdot
.602 .35892 Mdot
.602 .35895 Mdot
.602 .35895 Mdot
.602 .35898 Mdot
.602 .359 Mdot
.602 .35901 Mdot
.602 .35905 Mdot
.602 .35913 Mdot
.602 .35914 Mdot
.602 .35924 Mdot
.602 .35928 Mdot
.602 .35928 Mdot
.602 .35929 Mdot
.602 .35938 Mdot
.602 .35943 Mdot
.602 .35944 Mdot
.602 .35948 Mdot
.602 .35949 Mdot
.602 .35953 Mdot
.602 .35963 Mdot
.602 .35968 Mdot
.602 .3597 Mdot
.602 .35973 Mdot
.602 .35985 Mdot
.602 .35991 Mdot
.602 .35992 Mdot
.602 .35993 Mdot
.602 .35997 Mdot
.602 .35998 Mdot
.602 .35999 Mdot
.602 .35999 Mdot
.602 .35999 Mdot
.602 .36001 Mdot
.602 .36004 Mdot
.602 .36007 Mdot
.602 .36008 Mdot
.602 .3601 Mdot
.602 .36017 Mdot
.602 .36019 Mdot
.602 .36021 Mdot
.602 .36028 Mdot
.602 .36042 Mdot
.602 .36043 Mdot
.602 .36047 Mdot
.602 .36058 Mdot
.602 .36064 Mdot
.602 .3607 Mdot
.602 .36073 Mdot
.602 .36075 Mdot
.602 .36076 Mdot
.602 .36091 Mdot
.602 .36091 Mdot
.602 .36097 Mdot
.602 .36099 Mdot
.602 .36101 Mdot
.602 .36116 Mdot
.602 .36118 Mdot
.602 .3612 Mdot
.602 .36124 Mdot
.602 .36126 Mdot
.602 .36132 Mdot
.602 .36137 Mdot
.602 .36139 Mdot
.602 .3614 Mdot
.602 .36145 Mdot
.602 .36146 Mdot
.602 .3615 Mdot
.602 .36151 Mdot
.602 .36153 Mdot
.602 .36154 Mdot
.602 .36156 Mdot
.602 .3616 Mdot
.602 .36165 Mdot
.602 .36167 Mdot
.602 .36172 Mdot
.602 .36175 Mdot
.602 .36176 Mdot
.602 .36177 Mdot
.602 .36179 Mdot
.602 .36186 Mdot
.602 .36187 Mdot
.602 .36194 Mdot
.602 .36197 Mdot
.602 .36197 Mdot
.602 .362 Mdot
.602 .36201 Mdot
.602 .36201 Mdot
.602 .36202 Mdot
.602 .36203 Mdot
.602 .36205 Mdot
.602 .36206 Mdot
.602 .36209 Mdot
.602 .36215 Mdot
.602 .36229 Mdot
.602 .36232 Mdot
.602 .36235 Mdot
.602 .36236 Mdot
.602 .36237 Mdot
.602 .36245 Mdot
.602 .36247 Mdot
.602 .36249 Mdot
.602 .36257 Mdot
.602 .36258 Mdot
.602 .36258 Mdot
.602 .36261 Mdot
.602 .36271 Mdot
.602 .36272 Mdot
.602 .36273 Mdot
.602 .36275 Mdot
.602 .36277 Mdot
.602 .36281 Mdot
.602 .36283 Mdot
.602 .36285 Mdot
.602 .36285 Mdot
.602 .3629 Mdot
.602 .3629 Mdot
.602 .36294 Mdot
.602 .36295 Mdot
.602 .36296 Mdot
.602 .36297 Mdot
.602 .36297 Mdot
.602 .36297 Mdot
.602 .36298 Mdot
.602 .36299 Mdot
.602 .36301 Mdot
.602 .36303 Mdot
.602 .3631 Mdot
.602 .36313 Mdot
.602 .36318 Mdot
.602 .36319 Mdot
.602 .36324 Mdot
.602 .36324 Mdot
.602 .36325 Mdot
.602 .3633 Mdot
.602 .36331 Mdot
.602 .36331 Mdot
.602 .36332 Mdot
.602 .36333 Mdot
.602 .36336 Mdot
.602 .36337 Mdot
.602 .36339 Mdot
.602 .36339 Mdot
.602 .36342 Mdot
.602 .36342 Mdot
.602 .36342 Mdot
.602 .36343 Mdot
.602 .36344 Mdot
.602 .3635 Mdot
.602 .36352 Mdot
.602 .36353 Mdot
.602 .36355 Mdot
.602 .36359 Mdot
.602 .36359 Mdot
.602 .36364 Mdot
.602 .36364 Mdot
.602 .36365 Mdot
.602 .36368 Mdot
.602 .36369 Mdot
.602 .36369 Mdot
.602 .3637 Mdot
.602 .36372 Mdot
.602 .36374 Mdot
.602 .36376 Mdot
.602 .36378 Mdot
.602 .36379 Mdot
.602 .36381 Mdot
.602 .36383 Mdot
.602 .36386 Mdot
.602 .36388 Mdot
.602 .3639 Mdot
.602 .36392 Mdot
.602 .36393 Mdot
.602 .36394 Mdot
.602 .36395 Mdot
.602 .36397 Mdot
.602 .36398 Mdot
.602 .36398 Mdot
.602 .36401 Mdot
.602 .36401 Mdot
.602 .36404 Mdot
.602 .36405 Mdot
.602 .36406 Mdot
.602 .36407 Mdot
.602 .36411 Mdot
.602 .36412 Mdot
.602 .36412 Mdot
.602 .36413 Mdot
.602 .36413 Mdot
.602 .36415 Mdot
.602 .36417 Mdot
.602 .36419 Mdot
.602 .36419 Mdot
.602 .3642 Mdot
.602 .3642 Mdot
.602 .36424 Mdot
.602 .36425 Mdot
.602 .36428 Mdot
.602 .3643 Mdot
.602 .36433 Mdot
.602 .36435 Mdot
.602 .36439 Mdot
.602 .36441 Mdot
.602 .36442 Mdot
.602 .36443 Mdot
.602 .36444 Mdot
.602 .36444 Mdot
.602 .36444 Mdot
.602 .36444 Mdot
.602 .36445 Mdot
.602 .36446 Mdot
.602 .36449 Mdot
.602 .36449 Mdot
.602 .36452 Mdot
.602 .36452 Mdot
.602 .36454 Mdot
.602 .36455 Mdot
.602 .36457 Mdot
.602 .36459 Mdot
.602 .3646 Mdot
.602 .36461 Mdot
.602 .36462 Mdot
.602 .36469 Mdot
.602 .36471 Mdot
.602 .36471 Mdot
.602 .36472 Mdot
.602 .36477 Mdot
.602 .36478 Mdot
.602 .3648 Mdot
.602 .36485 Mdot
.602 .36486 Mdot
.602 .36487 Mdot
.602 .36489 Mdot
.602 .36491 Mdot
.602 .36501 Mdot
.602 .36504 Mdot
.602 .36507 Mdot
.602 .36508 Mdot
.602 .36508 Mdot
.602 .3651 Mdot
.602 .3651 Mdot
.602 .3651 Mdot
.602 .36511 Mdot
.602 .36513 Mdot
.602 .36513 Mdot
.602 .36515 Mdot
.602 .3652 Mdot
.602 .3652 Mdot
.602 .36526 Mdot
.602 .36527 Mdot
.602 .36527 Mdot
.602 .36528 Mdot
.602 .3653 Mdot
.602 .36534 Mdot
.602 .36535 Mdot
.602 .36538 Mdot
.602 .36541 Mdot
.602 .36543 Mdot
.602 .36543 Mdot
.602 .36544 Mdot
.602 .36545 Mdot
.602 .36548 Mdot
.602 .36549 Mdot
.602 .36553 Mdot
.602 .36554 Mdot
.602 .36558 Mdot
.602 .36562 Mdot
.602 .36563 Mdot
.602 .36566 Mdot
.602 .36567 Mdot
.602 .36569 Mdot
.602 .36579 Mdot
.602 .3658 Mdot
.602 .36582 Mdot
.602 .36586 Mdot
.602 .36586 Mdot
.602 .36596 Mdot
.602 .36597 Mdot
.602 .36598 Mdot
.602 .366 Mdot
.602 .36604 Mdot
.602 .36609 Mdot
.602 .36617 Mdot
.602 .36619 Mdot
.602 .3662 Mdot
.602 .36629 Mdot
.602 .36634 Mdot
.602 .36636 Mdot
.602 .36637 Mdot
.602 .36642 Mdot
.602 .36643 Mdot
.602 .36644 Mdot
.602 .36646 Mdot
.602 .36648 Mdot
.602 .36649 Mdot
.602 .36649 Mdot
.602 .3665 Mdot
.602 .3665 Mdot
.602 .36651 Mdot
.602 .36653 Mdot
.602 .36654 Mdot
.602 .36655 Mdot
.602 .36659 Mdot
.602 .36667 Mdot
.602 .36669 Mdot
.602 .36671 Mdot
.602 .36674 Mdot
.602 .36681 Mdot
.602 .36684 Mdot
.602 .36685 Mdot
.602 .36687 Mdot
.602 .36688 Mdot
.602 .36691 Mdot
.602 .36697 Mdot
.602 .36698 Mdot
.602 .36698 Mdot
.602 .36701 Mdot
.602 .36708 Mdot
.602 .36709 Mdot
.602 .36714 Mdot
.602 .36717 Mdot
.602 .36718 Mdot
.602 .36719 Mdot
.602 .36721 Mdot
.602 .36721 Mdot
.602 .36723 Mdot
.602 .36724 Mdot
.602 .36729 Mdot
.602 .36729 Mdot
.602 .36731 Mdot
.602 .36738 Mdot
.602 .36738 Mdot
.602 .36742 Mdot
.602 .36745 Mdot
.602 .36749 Mdot
.602 .36751 Mdot
.602 .36754 Mdot
.602 .36758 Mdot
.602 .36761 Mdot
.602 .36767 Mdot
.602 .36768 Mdot
.602 .36769 Mdot
.602 .36772 Mdot
.602 .36775 Mdot
.602 .36782 Mdot
.602 .36784 Mdot
.602 .36786 Mdot
.602 .36794 Mdot
.602 .36796 Mdot
.602 .36798 Mdot
.602 .368 Mdot
.602 .36804 Mdot
.602 .36808 Mdot
.602 .36809 Mdot
.602 .36813 Mdot
.602 .3682 Mdot
.602 .36823 Mdot
.602 .3683 Mdot
.602 .36831 Mdot
.602 .36832 Mdot
.602 .36835 Mdot
.602 .36838 Mdot
.602 .36839 Mdot
.602 .36846 Mdot
.602 .36846 Mdot
.602 .36847 Mdot
.602 .36857 Mdot
.602 .36862 Mdot
.602 .36865 Mdot
.602 .36873 Mdot
.602 .36875 Mdot
.602 .36877 Mdot
.602 .36878 Mdot
.602 .3688 Mdot
.602 .36882 Mdot
.602 .36883 Mdot
.602 .36886 Mdot
.602 .36889 Mdot
.602 .36891 Mdot
.602 .36897 Mdot
.602 .36899 Mdot
.602 .36908 Mdot
.602 .3691 Mdot
.602 .3691 Mdot
.602 .36913 Mdot
.602 .36916 Mdot
.602 .36924 Mdot
.602 .36926 Mdot
.602 .36929 Mdot
.602 .3693 Mdot
.602 .3693 Mdot
.602 .3693 Mdot
.602 .36932 Mdot
.602 .36934 Mdot
.602 .36939 Mdot
.602 .36941 Mdot
.602 .36941 Mdot
.602 .36942 Mdot
.602 .36943 Mdot
.602 .36945 Mdot
.602 .36945 Mdot
.602 .3695 Mdot
.602 .36952 Mdot
.602 .36952 Mdot
.602 .36953 Mdot
.602 .36954 Mdot
.602 .36959 Mdot
.602 .3696 Mdot
.602 .36962 Mdot
.602 .36965 Mdot
.602 .36979 Mdot
.602 .3698 Mdot
.602 .36984 Mdot
.602 .36987 Mdot
.604 .29694 Mdot
.604 .29697 Mdot
.604 .29703 Mdot
.604 .29706 Mdot
.604 .29709 Mdot
.604 .29713 Mdot
.604 .29714 Mdot
.604 .29719 Mdot
.604 .2972 Mdot
.604 .29722 Mdot
.604 .29723 Mdot
.604 .2973 Mdot
.604 .29731 Mdot
.604 .29737 Mdot
.604 .29738 Mdot
.604 .29739 Mdot
.604 .29752 Mdot
.604 .29762 Mdot
.604 .29768 Mdot
.604 .29768 Mdot
.604 .29773 Mdot
.604 .29781 Mdot
.604 .29784 Mdot
.604 .29787 Mdot
.604 .29787 Mdot
.604 .29796 Mdot
.604 .29796 Mdot
.604 .298 Mdot
.604 .29801 Mdot
.604 .29813 Mdot
.604 .29839 Mdot
.604 .2984 Mdot
.604 .29843 Mdot
.604 .29844 Mdot
.604 .29845 Mdot
.604 .29845 Mdot
.604 .29846 Mdot
.604 .29851 Mdot
.604 .29855 Mdot
.604 .29856 Mdot
.604 .29856 Mdot
.604 .2986 Mdot
.604 .29861 Mdot
.604 .29861 Mdot
.604 .29863 Mdot
.604 .29865 Mdot
.604 .29869 Mdot
.604 .29871 Mdot
.604 .29872 Mdot
.604 .29873 Mdot
.604 .29883 Mdot
.604 .29884 Mdot
.604 .29886 Mdot
.604 .2989 Mdot
.604 .29898 Mdot
.604 .29898 Mdot
.604 .299 Mdot
.604 .29902 Mdot
.604 .29902 Mdot
.604 .29903 Mdot
.604 .29904 Mdot
.604 .29907 Mdot
.604 .29909 Mdot
.604 .29912 Mdot
.604 .29913 Mdot
.604 .29916 Mdot
.604 .29916 Mdot
.604 .29921 Mdot
.604 .29923 Mdot
.604 .29924 Mdot
.604 .29926 Mdot
.604 .29926 Mdot
.604 .2993 Mdot
.604 .29938 Mdot
.604 .2994 Mdot
.604 .29943 Mdot
.604 .29944 Mdot
.604 .29946 Mdot
.604 .29949 Mdot
.604 .29952 Mdot
.604 .29953 Mdot
.604 .29957 Mdot
.604 .29961 Mdot
.604 .2997 Mdot
.604 .29971 Mdot
.604 .29973 Mdot
.604 .29977 Mdot
.604 .29979 Mdot
.604 .2998 Mdot
.604 .29986 Mdot
.604 .29987 Mdot
.604 .29992 Mdot
.604 .29992 Mdot
.604 .29995 Mdot
.604 .29997 Mdot
.604 .29997 Mdot
.604 .29998 Mdot
.604 .30005 Mdot
.604 .30011 Mdot
.604 .30015 Mdot
.604 .30016 Mdot
.604 .30024 Mdot
.604 .30024 Mdot
.604 .30025 Mdot
.604 .30027 Mdot
.604 .30045 Mdot
.604 .30051 Mdot
.604 .30053 Mdot
.604 .30054 Mdot
.604 .30058 Mdot
.604 .3006 Mdot
.604 .30063 Mdot
.604 .30074 Mdot
.604 .30074 Mdot
.604 .30081 Mdot
.604 .30083 Mdot
.604 .30083 Mdot
.604 .30089 Mdot
.604 .30093 Mdot
.604 .30095 Mdot
.604 .30099 Mdot
.604 .30102 Mdot
.604 .30104 Mdot
.604 .30105 Mdot
.604 .30108 Mdot
.604 .30112 Mdot
.604 .30113 Mdot
.604 .30116 Mdot
.604 .30122 Mdot
.604 .3013 Mdot
.604 .30139 Mdot
.604 .30143 Mdot
.604 .30143 Mdot
.604 .30146 Mdot
.604 .30151 Mdot
.604 .30164 Mdot
.604 .30166 Mdot
.604 .30167 Mdot
.604 .30169 Mdot
.604 .30171 Mdot
.604 .30171 Mdot
.604 .30172 Mdot
.604 .30173 Mdot
.604 .30174 Mdot
.604 .30175 Mdot
.604 .30178 Mdot
.604 .30178 Mdot
.604 .3018 Mdot
.604 .30184 Mdot
.604 .30184 Mdot
.604 .30187 Mdot
.604 .30191 Mdot
.604 .30191 Mdot
.604 .30193 Mdot
.604 .30194 Mdot
.604 .30196 Mdot
.604 .302 Mdot
.604 .302 Mdot
.604 .30202 Mdot
.604 .30203 Mdot
.604 .30204 Mdot
.604 .30206 Mdot
.604 .30213 Mdot
.604 .30214 Mdot
.604 .30215 Mdot
.604 .30217 Mdot
.604 .30225 Mdot
.604 .30226 Mdot
.604 .30227 Mdot
.604 .30228 Mdot
.604 .30229 Mdot
.604 .30232 Mdot
.604 .30235 Mdot
.604 .30235 Mdot
.604 .30237 Mdot
.604 .30238 Mdot
.604 .3024 Mdot
.604 .3025 Mdot
.604 .30251 Mdot
.604 .30263 Mdot
.604 .30278 Mdot
.604 .30283 Mdot
.604 .30293 Mdot
.604 .30297 Mdot
.604 .30306 Mdot
.604 .3031 Mdot
.604 .30316 Mdot
.604 .30317 Mdot
.604 .3032 Mdot
.604 .3032 Mdot
.604 .3032 Mdot
.604 .30321 Mdot
.604 .30323 Mdot
.604 .30323 Mdot
.604 .30323 Mdot
.604 .30326 Mdot
.604 .3033 Mdot
.604 .30331 Mdot
.604 .30333 Mdot
.604 .30333 Mdot
.604 .30336 Mdot
.604 .30339 Mdot
.604 .3034 Mdot
.604 .30341 Mdot
.604 .30348 Mdot
.604 .3035 Mdot
.604 .3035 Mdot
.604 .30351 Mdot
.604 .30357 Mdot
.604 .30357 Mdot
.604 .30363 Mdot
.604 .3037 Mdot
.604 .30372 Mdot
.604 .30378 Mdot
.604 .30383 Mdot
.604 .30387 Mdot
.604 .30388 Mdot
.604 .3039 Mdot
.604 .3039 Mdot
.604 .30391 Mdot
.604 .30391 Mdot
.604 .30392 Mdot
.604 .30395 Mdot
.604 .30395 Mdot
.604 .30398 Mdot
.604 .30399 Mdot
.604 .30399 Mdot
.604 .30404 Mdot
.604 .30419 Mdot
.604 .30421 Mdot
.604 .30422 Mdot
.604 .30423 Mdot
.604 .30425 Mdot
.604 .30426 Mdot
.604 .30426 Mdot
.604 .30436 Mdot
.604 .30439 Mdot
.604 .30439 Mdot
.604 .30444 Mdot
.604 .30445 Mdot
.604 .30445 Mdot
.604 .30448 Mdot
.604 .30452 Mdot
.604 .30454 Mdot
.604 .30454 Mdot
.604 .30456 Mdot
.604 .30459 Mdot
.604 .30459 Mdot
.604 .30461 Mdot
.604 .30467 Mdot
.604 .30467 Mdot
.604 .3047 Mdot
.604 .3047 Mdot
.604 .30473 Mdot
.604 .30486 Mdot
.604 .30486 Mdot
.604 .30487 Mdot
.604 .30489 Mdot
.604 .30489 Mdot
.604 .30491 Mdot
.604 .30492 Mdot
.604 .30493 Mdot
.604 .30494 Mdot
.604 .30494 Mdot
.604 .30497 Mdot
.604 .30505 Mdot
.604 .30506 Mdot
.604 .30515 Mdot
.604 .30519 Mdot
.604 .30521 Mdot
.604 .30526 Mdot
.604 .30527 Mdot
.604 .30527 Mdot
.604 .30529 Mdot
.604 .30531 Mdot
.604 .30531 Mdot
.604 .30536 Mdot
.604 .30538 Mdot
.604 .30538 Mdot
.604 .3054 Mdot
.604 .3054 Mdot
.604 .30541 Mdot
.604 .30542 Mdot
.604 .30543 Mdot
.604 .30547 Mdot
.604 .3055 Mdot
.604 .30556 Mdot
.604 .30566 Mdot
.604 .30569 Mdot
.604 .30579 Mdot
.604 .30588 Mdot
.604 .30588 Mdot
.604 .30597 Mdot
.604 .30598 Mdot
.604 .30598 Mdot
.604 .306 Mdot
.604 .30611 Mdot
.604 .30612 Mdot
.604 .30613 Mdot
.604 .30618 Mdot
.604 .30623 Mdot
.604 .30623 Mdot
.604 .30625 Mdot
.604 .30627 Mdot
.604 .30633 Mdot
.604 .30637 Mdot
.604 .30637 Mdot
.604 .30638 Mdot
.604 .3064 Mdot
.604 .30641 Mdot
.604 .30642 Mdot
.604 .30642 Mdot
.604 .30645 Mdot
.604 .30647 Mdot
.604 .30656 Mdot
.604 .30662 Mdot
.604 .30676 Mdot
.604 .3068 Mdot
.604 .30696 Mdot
.604 .30703 Mdot
.604 .30725 Mdot
.604 .30743 Mdot
.604 .30743 Mdot
.604 .30759 Mdot
.604 .30762 Mdot
.604 .30763 Mdot
.604 .30765 Mdot
.604 .30765 Mdot
.604 .30769 Mdot
.604 .30774 Mdot
.604 .30775 Mdot
.604 .30778 Mdot
.604 .30779 Mdot
.604 .3078 Mdot
.604 .30792 Mdot
.604 .30795 Mdot
.604 .30797 Mdot
.604 .30798 Mdot
.604 .30808 Mdot
.604 .3081 Mdot
.604 .30812 Mdot
.604 .30813 Mdot
.604 .30817 Mdot
.604 .30817 Mdot
.604 .30822 Mdot
.604 .30825 Mdot
.604 .30827 Mdot
.604 .30829 Mdot
.604 .30829 Mdot
.604 .30835 Mdot
.604 .30839 Mdot
.604 .3084 Mdot
.604 .30846 Mdot
.604 .30848 Mdot
.604 .30849 Mdot
.604 .30853 Mdot
.604 .30855 Mdot
.604 .30856 Mdot
.604 .30858 Mdot
.604 .30858 Mdot
.604 .30859 Mdot
.604 .30861 Mdot
.604 .30865 Mdot
.604 .30867 Mdot
.604 .30869 Mdot
.604 .30887 Mdot
.604 .30896 Mdot
.604 .30899 Mdot
.604 .309 Mdot
.604 .30906 Mdot
.604 .30919 Mdot
.604 .3093 Mdot
.604 .3094 Mdot
.604 .30944 Mdot
.604 .30944 Mdot
.604 .3095 Mdot
.604 .30955 Mdot
.604 .30956 Mdot
.604 .30959 Mdot
.604 .30963 Mdot
.604 .3097 Mdot
.604 .30972 Mdot
.604 .30979 Mdot
.604 .30987 Mdot
.604 .30988 Mdot
.604 .3099 Mdot
.604 .31 Mdot
.604 .31001 Mdot
.604 .31016 Mdot
.604 .3102 Mdot
.604 .31024 Mdot
.604 .3103 Mdot
.604 .31031 Mdot
.604 .31034 Mdot
.604 .31042 Mdot
.604 .31069 Mdot
.604 .31072 Mdot
.604 .31073 Mdot
.604 .31074 Mdot
.604 .31085 Mdot
.604 .31087 Mdot
.604 .31092 Mdot
.604 .31102 Mdot
.604 .31111 Mdot
.604 .31113 Mdot
.604 .31113 Mdot
.604 .31116 Mdot
.604 .3112 Mdot
.604 .3112 Mdot
.604 .31128 Mdot
.604 .31129 Mdot
.604 .31138 Mdot
.604 .31138 Mdot
.604 .31142 Mdot
.604 .31147 Mdot
.604 .3115 Mdot
.604 .31153 Mdot
.604 .31166 Mdot
.604 .31171 Mdot
.604 .31177 Mdot
.604 .31178 Mdot
.604 .31183 Mdot
.604 .31188 Mdot
.604 .3119 Mdot
.604 .31191 Mdot
.604 .31196 Mdot
.604 .31198 Mdot
.604 .31211 Mdot
.604 .31216 Mdot
.604 .31217 Mdot
.604 .31219 Mdot
.604 .31221 Mdot
.604 .31223 Mdot
.604 .3123 Mdot
.604 .31231 Mdot
.604 .31235 Mdot
.604 .31237 Mdot
.604 .31241 Mdot
.604 .31245 Mdot
.604 .31248 Mdot
.604 .3125 Mdot
.604 .31251 Mdot
.604 .31252 Mdot
.604 .31254 Mdot
.604 .31257 Mdot
.604 .31257 Mdot
.604 .31269 Mdot
.604 .31275 Mdot
.604 .31278 Mdot
.604 .3128 Mdot
.604 .31293 Mdot
.604 .31296 Mdot
.604 .31297 Mdot
.604 .31299 Mdot
.604 .31306 Mdot
.604 .31308 Mdot
.604 .31311 Mdot
.604 .31311 Mdot
.604 .31313 Mdot
.604 .31318 Mdot
.604 .31319 Mdot
.604 .3132 Mdot
.604 .31325 Mdot
.604 .31334 Mdot
.604 .31334 Mdot
.604 .31335 Mdot
.604 .31336 Mdot
.604 .31337 Mdot
.604 .31342 Mdot
.604 .31344 Mdot
.604 .31381 Mdot
.604 .31399 Mdot
.604 .31401 Mdot
.604 .31406 Mdot
.604 .31407 Mdot
.604 .31419 Mdot
.604 .31419 Mdot
.604 .31424 Mdot
.604 .31428 Mdot
.604 .31439 Mdot
.604 .31447 Mdot
.604 .31448 Mdot
.604 .31456 Mdot
.604 .31468 Mdot
.604 .31471 Mdot
.604 .3149 Mdot
.604 .31491 Mdot
.604 .31492 Mdot
.604 .31502 Mdot
.604 .31502 Mdot
.604 .31513 Mdot
.604 .31515 Mdot
.604 .31517 Mdot
.604 .31518 Mdot
.604 .31526 Mdot
.604 .31527 Mdot
.604 .31533 Mdot
.604 .31537 Mdot
.604 .31543 Mdot
.604 .3155 Mdot
.604 .31555 Mdot
.604 .35565 Mdot
.604 .35568 Mdot
.604 .35575 Mdot
.604 .35579 Mdot
.604 .35583 Mdot
.604 .35588 Mdot
.604 .35589 Mdot
.604 .35595 Mdot
.604 .35596 Mdot
.604 .35598 Mdot
.604 .35599 Mdot
.604 .35608 Mdot
.604 .35608 Mdot
.604 .35616 Mdot
.604 .35617 Mdot
.604 .35618 Mdot
.604 .35634 Mdot
.604 .35646 Mdot
.604 .35653 Mdot
.604 .35653 Mdot
.604 .3566 Mdot
.604 .35669 Mdot
.604 .35673 Mdot
.604 .35677 Mdot
.604 .35677 Mdot
.604 .35687 Mdot
.604 .35688 Mdot
.604 .35692 Mdot
.604 .35694 Mdot
.604 .35708 Mdot
.604 .35739 Mdot
.604 .35741 Mdot
.604 .35745 Mdot
.604 .35745 Mdot
.604 .35746 Mdot
.604 .35747 Mdot
.604 .35747 Mdot
.604 .35754 Mdot
.604 .35759 Mdot
.604 .3576 Mdot
.604 .3576 Mdot
.604 .35765 Mdot
.604 .35766 Mdot
.604 .35766 Mdot
.604 .35769 Mdot
.604 .35771 Mdot
.604 .35776 Mdot
.604 .35778 Mdot
.604 .35779 Mdot
.604 .35781 Mdot
.604 .35792 Mdot
.604 .35794 Mdot
.604 .35796 Mdot
.604 .35801 Mdot
.604 .35811 Mdot
.604 .35811 Mdot
.604 .35813 Mdot
.604 .35815 Mdot
.604 .35816 Mdot
.604 .35817 Mdot
.604 .35819 Mdot
.604 .35821 Mdot
.604 .35824 Mdot
.604 .35828 Mdot
.604 .35829 Mdot
.604 .35833 Mdot
.604 .35833 Mdot
.604 .35839 Mdot
.604 .35841 Mdot
.604 .35842 Mdot
.604 .35844 Mdot
.604 .35845 Mdot
.604 .35849 Mdot
.604 .3586 Mdot
.604 .35861 Mdot
.604 .35866 Mdot
.604 .35867 Mdot
.604 .35868 Mdot
.604 .35872 Mdot
.604 .35876 Mdot
.604 .35877 Mdot
.604 .35882 Mdot
.604 .35886 Mdot
.604 .35897 Mdot
.604 .35899 Mdot
.604 .35902 Mdot
.604 .35907 Mdot
.604 .35909 Mdot
.604 .3591 Mdot
.604 .35917 Mdot
.604 .35918 Mdot
.604 .35924 Mdot
.604 .35925 Mdot
.604 .35928 Mdot
.604 .3593 Mdot
.604 .3593 Mdot
.604 .35931 Mdot
.604 .3594 Mdot
.604 .35948 Mdot
.604 .35952 Mdot
.604 .35954 Mdot
.604 .35963 Mdot
.604 .35963 Mdot
.604 .35964 Mdot
.604 .35966 Mdot
.604 .35989 Mdot
.604 .35996 Mdot
.604 .35998 Mdot
.604 .35999 Mdot
.604 .36003 Mdot
.604 .36007 Mdot
.604 .3601 Mdot
.604 .36023 Mdot
.604 .36024 Mdot
.604 .36032 Mdot
.604 .36034 Mdot
.604 .36034 Mdot
.604 .36041 Mdot
.604 .36047 Mdot
.604 .36048 Mdot
.604 .36054 Mdot
.604 .36058 Mdot
.604 .3606 Mdot
.604 .36061 Mdot
.604 .36065 Mdot
.604 .3607 Mdot
.604 .3607 Mdot
.604 .36074 Mdot
.604 .36082 Mdot
.604 .36091 Mdot
.604 .36102 Mdot
.604 .36107 Mdot
.604 .36107 Mdot
.604 .3611 Mdot
.604 .36117 Mdot
.604 .36132 Mdot
.604 .36134 Mdot
.604 .36135 Mdot
.604 .36138 Mdot
.604 .36141 Mdot
.604 .36141 Mdot
.604 .36141 Mdot
.604 .36143 Mdot
.604 .36144 Mdot
.604 .36145 Mdot
.604 .36149 Mdot
.604 .36149 Mdot
.604 .36151 Mdot
.604 .36156 Mdot
.604 .36157 Mdot
.604 .3616 Mdot
.604 .36165 Mdot
.604 .36165 Mdot
.604 .36167 Mdot
.604 .36169 Mdot
.604 .36171 Mdot
.604 .36175 Mdot
.604 .36175 Mdot
.604 .36178 Mdot
.604 .36179 Mdot
.604 .36181 Mdot
.604 .36183 Mdot
.604 .36191 Mdot
.604 .36192 Mdot
.604 .36194 Mdot
.604 .36196 Mdot
.604 .36205 Mdot
.604 .36206 Mdot
.604 .36208 Mdot
.604 .3621 Mdot
.604 .36211 Mdot
.604 .36215 Mdot
.604 .36218 Mdot
.604 .36218 Mdot
.604 .3622 Mdot
.604 .36221 Mdot
.604 .36223 Mdot
.604 .36236 Mdot
.604 .36237 Mdot
.604 .36252 Mdot
.604 .3627 Mdot
.604 .36276 Mdot
.604 .36288 Mdot
.604 .36292 Mdot
.604 .36304 Mdot
.604 .36309 Mdot
.604 .36316 Mdot
.604 .36317 Mdot
.604 .3632 Mdot
.604 .3632 Mdot
.604 .36321 Mdot
.604 .36322 Mdot
.604 .36324 Mdot
.604 .36324 Mdot
.604 .36325 Mdot
.604 .36327 Mdot
.604 .36332 Mdot
.604 .36334 Mdot
.604 .36336 Mdot
.604 .36336 Mdot
.604 .3634 Mdot
.604 .36344 Mdot
.604 .36345 Mdot
.604 .36346 Mdot
.604 .36355 Mdot
.604 .36356 Mdot
.604 .36356 Mdot
.604 .36358 Mdot
.604 .36365 Mdot
.604 .36365 Mdot
.604 .36372 Mdot
.604 .3638 Mdot
.604 .36383 Mdot
.604 .36391 Mdot
.604 .36396 Mdot
.604 .36399 Mdot
.604 .36402 Mdot
.604 .36403 Mdot
.604 .36404 Mdot
.604 .36404 Mdot
.604 .36405 Mdot
.604 .36406 Mdot
.604 .36406 Mdot
.604 .36407 Mdot
.604 .36412 Mdot
.604 .36412 Mdot
.604 .36413 Mdot
.604 .36415 Mdot
.604 .36416 Mdot
.604 .36416 Mdot
.604 .3642 Mdot
.604 .36422 Mdot
.604 .36425 Mdot
.604 .36432 Mdot
.604 .36434 Mdot
.604 .3644 Mdot
.604 .36442 Mdot
.604 .36443 Mdot
.604 .36444 Mdot
.604 .36444 Mdot
.604 .36445 Mdot
.604 .36447 Mdot
.604 .36447 Mdot
.604 .36449 Mdot
.604 .36449 Mdot
.604 .36449 Mdot
.604 .3646 Mdot
.604 .36462 Mdot
.604 .36463 Mdot
.604 .36465 Mdot
.604 .36465 Mdot
.604 .3647 Mdot
.604 .36472 Mdot
.604 .36472 Mdot
.604 .36474 Mdot
.604 .36475 Mdot
.604 .36475 Mdot
.604 .36477 Mdot
.604 .3648 Mdot
.604 .36483 Mdot
.604 .36483 Mdot
.604 .36484 Mdot
.604 .36488 Mdot
.604 .36488 Mdot
.604 .36491 Mdot
.604 .36498 Mdot
.604 .36499 Mdot
.604 .365 Mdot
.604 .36501 Mdot
.604 .36502 Mdot
.604 .36503 Mdot
.604 .36505 Mdot
.604 .36517 Mdot
.604 .36521 Mdot
.604 .36521 Mdot
.604 .36522 Mdot
.604 .36524 Mdot
.604 .36524 Mdot
.604 .36527 Mdot
.604 .36528 Mdot
.604 .36528 Mdot
.604 .36529 Mdot
.604 .36529 Mdot
.604 .3653 Mdot
.604 .36531 Mdot
.604 .36535 Mdot
.604 .36538 Mdot
.604 .36544 Mdot
.604 .36546 Mdot
.604 .36551 Mdot
.604 .36556 Mdot
.604 .36556 Mdot
.604 .36561 Mdot
.604 .36562 Mdot
.604 .36562 Mdot
.604 .36563 Mdot
.604 .36569 Mdot
.604 .3657 Mdot
.604 .36571 Mdot
.604 .36573 Mdot
.604 .36576 Mdot
.604 .36576 Mdot
.604 .36577 Mdot
.604 .36579 Mdot
.604 .36582 Mdot
.604 .36584 Mdot
.604 .36584 Mdot
.604 .36584 Mdot
.604 .36586 Mdot
.604 .36586 Mdot
.604 .36587 Mdot
.604 .36587 Mdot
.604 .36589 Mdot
.604 .3659 Mdot
.604 .36595 Mdot
.604 .36598 Mdot
.604 .36606 Mdot
.604 .36609 Mdot
.604 .36617 Mdot
.604 .36621 Mdot
.604 .36634 Mdot
.604 .36644 Mdot
.604 .36644 Mdot
.604 .36653 Mdot
.604 .36655 Mdot
.604 .36656 Mdot
.604 .36657 Mdot
.604 .36657 Mdot
.604 .36659 Mdot
.604 .36662 Mdot
.604 .36662 Mdot
.604 .36664 Mdot
.604 .36665 Mdot
.604 .36665 Mdot
.604 .36672 Mdot
.604 .36673 Mdot
.604 .36675 Mdot
.604 .36676 Mdot
.604 .36681 Mdot
.604 .36682 Mdot
.604 .36684 Mdot
.604 .36684 Mdot
.604 .36686 Mdot
.604 .36686 Mdot
.604 .36689 Mdot
.604 .36691 Mdot
.604 .36692 Mdot
.604 .36693 Mdot
.604 .36693 Mdot
.604 .36696 Mdot
.604 .36699 Mdot
.604 .36699 Mdot
.604 .36703 Mdot
.604 .36704 Mdot
.604 .36704 Mdot
.604 .36707 Mdot
.604 .36708 Mdot
.604 .36708 Mdot
.604 .36709 Mdot
.604 .3671 Mdot
.604 .3671 Mdot
.604 .36711 Mdot
.604 .36714 Mdot
.604 .36714 Mdot
.604 .36716 Mdot
.604 .36726 Mdot
.604 .36731 Mdot
.604 .36733 Mdot
.604 .36733 Mdot
.604 .36736 Mdot
.604 .36744 Mdot
.604 .3675 Mdot
.604 .36756 Mdot
.604 .36758 Mdot
.604 .36758 Mdot
.604 .36762 Mdot
.604 .36765 Mdot
.604 .36765 Mdot
.604 .36767 Mdot
.604 .36769 Mdot
.604 .36773 Mdot
.604 .36774 Mdot
.604 .36778 Mdot
.604 .36783 Mdot
.604 .36783 Mdot
.604 .36784 Mdot
.604 .3679 Mdot
.604 .3679 Mdot
.604 .36799 Mdot
.604 .36802 Mdot
.604 .36804 Mdot
.604 .36807 Mdot
.604 .36808 Mdot
.604 .36809 Mdot
.604 .36814 Mdot
.604 .36829 Mdot
.604 .36831 Mdot
.604 .36832 Mdot
.604 .36832 Mdot
.604 .36838 Mdot
.604 .36839 Mdot
.604 .36842 Mdot
.604 .36848 Mdot
.604 .36853 Mdot
.604 .36854 Mdot
.604 .36854 Mdot
.604 .36856 Mdot
.604 .36858 Mdot
.604 .36858 Mdot
.604 .36862 Mdot
.604 .36863 Mdot
.604 .36868 Mdot
.604 .36869 Mdot
.604 .3687 Mdot
.604 .36874 Mdot
.604 .36875 Mdot
.604 .36877 Mdot
.604 .36884 Mdot
.604 .36887 Mdot
.604 .36891 Mdot
.604 .36891 Mdot
.604 .36894 Mdot
.604 .36896 Mdot
.604 .36898 Mdot
.604 .36898 Mdot
.604 .36901 Mdot
.604 .36902 Mdot
.604 .3691 Mdot
.604 .36912 Mdot
.604 .36913 Mdot
.604 .36914 Mdot
.604 .36915 Mdot
.604 .36916 Mdot
.604 .36921 Mdot
.604 .36921 Mdot
.604 .36924 Mdot
.604 .36924 Mdot
.604 .36927 Mdot
.604 .36929 Mdot
.604 .36931 Mdot
.604 .36932 Mdot
.604 .36933 Mdot
.604 .36933 Mdot
.604 .36934 Mdot
.604 .36936 Mdot
.604 .36936 Mdot
.604 .36942 Mdot
.604 .36946 Mdot
.604 .36948 Mdot
.604 .36949 Mdot
.604 .36956 Mdot
.604 .36958 Mdot
.604 .36958 Mdot
.604 .3696 Mdot
.604 .36963 Mdot
.604 .36965 Mdot
.604 .36966 Mdot
.604 .36966 Mdot
.604 .36967 Mdot
.604 .36971 Mdot
.604 .36971 Mdot
.604 .36971 Mdot
.604 .36975 Mdot
.604 .36979 Mdot
.604 .3698 Mdot
.604 .3698 Mdot
.604 .36981 Mdot
.604 .36981 Mdot
.604 .36984 Mdot
.604 .36985 Mdot
.604 .37006 Mdot
.604 .37016 Mdot
.604 .37017 Mdot
.604 .3702 Mdot
.604 .37021 Mdot
.604 .37028 Mdot
.604 .37028 Mdot
.604 .37031 Mdot
.604 .37033 Mdot
.604 .37039 Mdot
.604 .37044 Mdot
.604 .37044 Mdot
.604 .37049 Mdot
.604 .37057 Mdot
.604 .37068 Mdot
.604 .37069 Mdot
.604 .37069 Mdot
.604 .37074 Mdot
.604 .37075 Mdot
.604 .37081 Mdot
.604 .37082 Mdot
.604 .37083 Mdot
.604 .37084 Mdot
.604 .37088 Mdot
.604 .37089 Mdot
.604 .37092 Mdot
.604 .37094 Mdot
.604 .37098 Mdot
.604 .37102 Mdot
.604 .37105 Mdot
.606 .29646 Mdot
.606 .29648 Mdot
.606 .29651 Mdot
.606 .29651 Mdot
.606 .29661 Mdot
.606 .29668 Mdot
.606 .2967 Mdot
.606 .29675 Mdot
.606 .29677 Mdot
.606 .29677 Mdot
.606 .29681 Mdot
.606 .29681 Mdot
.606 .29688 Mdot
.606 .29695 Mdot
.606 .29701 Mdot
.606 .29704 Mdot
.606 .29711 Mdot
.606 .29715 Mdot
.606 .29716 Mdot
.606 .29725 Mdot
.606 .29725 Mdot
.606 .29728 Mdot
.606 .29728 Mdot
.606 .29736 Mdot
.606 .29739 Mdot
.606 .29742 Mdot
.606 .29742 Mdot
.606 .29742 Mdot
.606 .29743 Mdot
.606 .29746 Mdot
.606 .29747 Mdot
.606 .29752 Mdot
.606 .29758 Mdot
.606 .29762 Mdot
.606 .29763 Mdot
.606 .29766 Mdot
.606 .29768 Mdot
.606 .2977 Mdot
.606 .29774 Mdot
.606 .29787 Mdot
.606 .29788 Mdot
.606 .2979 Mdot
.606 .29803 Mdot
.606 .29805 Mdot
.606 .29811 Mdot
.606 .29813 Mdot
.606 .29825 Mdot
.606 .29827 Mdot
.606 .29829 Mdot
.606 .2984 Mdot
.606 .29843 Mdot
.606 .29849 Mdot
.606 .2985 Mdot
.606 .29851 Mdot
.606 .29853 Mdot
.606 .29856 Mdot
.606 .29857 Mdot
.606 .2986 Mdot
.606 .29862 Mdot
.606 .29866 Mdot
.606 .29871 Mdot
.606 .29875 Mdot
.606 .29878 Mdot
.606 .29891 Mdot
.606 .29892 Mdot
.606 .29896 Mdot
.606 .29898 Mdot
.606 .29907 Mdot
.606 .29914 Mdot
.606 .29916 Mdot
.606 .29917 Mdot
.606 .29921 Mdot
.606 .29921 Mdot
.606 .29924 Mdot
.606 .29925 Mdot
.606 .2993 Mdot
.606 .29931 Mdot
.606 .29933 Mdot
.606 .29933 Mdot
.606 .29934 Mdot
.606 .29937 Mdot
.606 .2994 Mdot
.606 .29949 Mdot
.606 .2995 Mdot
.606 .29952 Mdot
.606 .29959 Mdot
.606 .2996 Mdot
.606 .29962 Mdot
.606 .29966 Mdot
.606 .29967 Mdot
.606 .2997 Mdot
.606 .29971 Mdot
.606 .29972 Mdot
.606 .29975 Mdot
.606 .29982 Mdot
.606 .2999 Mdot
.606 .29992 Mdot
.606 .29999 Mdot
.606 .30009 Mdot
.606 .30012 Mdot
.606 .30017 Mdot
.606 .30021 Mdot
.606 .30022 Mdot
.606 .30022 Mdot
.606 .30023 Mdot
.606 .30028 Mdot
.606 .30029 Mdot
.606 .3003 Mdot
.606 .30034 Mdot
.606 .30041 Mdot
.606 .30052 Mdot
.606 .30053 Mdot
.606 .30055 Mdot
.606 .30059 Mdot
.606 .30064 Mdot
.606 .30064 Mdot
.606 .30066 Mdot
.606 .30069 Mdot
.606 .30078 Mdot
.606 .30082 Mdot
.606 .30084 Mdot
.606 .30084 Mdot
.606 .30087 Mdot
.606 .30091 Mdot
.606 .30095 Mdot
.606 .30098 Mdot
.606 .301 Mdot
.606 .30106 Mdot
.606 .3011 Mdot
.606 .30113 Mdot
.606 .30115 Mdot
.606 .30115 Mdot
.606 .3012 Mdot
.606 .30122 Mdot
.606 .30124 Mdot
.606 .30125 Mdot
.606 .30127 Mdot
.606 .30134 Mdot
.606 .30134 Mdot
.606 .30141 Mdot
.606 .30145 Mdot
.606 .30151 Mdot
.606 .30153 Mdot
.606 .30158 Mdot
.606 .30163 Mdot
.606 .30165 Mdot
.606 .30166 Mdot
.606 .3017 Mdot
.606 .30182 Mdot
.606 .30189 Mdot
.606 .30192 Mdot
.606 .30193 Mdot
.606 .30195 Mdot
.606 .30196 Mdot
.606 .30197 Mdot
.606 .302 Mdot
.606 .30201 Mdot
.606 .30209 Mdot
.606 .30214 Mdot
.606 .30217 Mdot
.606 .30219 Mdot
.606 .30219 Mdot
.606 .30224 Mdot
.606 .30229 Mdot
.606 .30232 Mdot
.606 .3024 Mdot
.606 .30242 Mdot
.606 .30242 Mdot
.606 .30245 Mdot
.606 .30246 Mdot
.606 .30246 Mdot
.606 .30248 Mdot
.606 .30251 Mdot
.606 .30257 Mdot
.606 .30258 Mdot
.606 .30262 Mdot
.606 .30262 Mdot
.606 .30264 Mdot
.606 .3027 Mdot
.606 .30271 Mdot
.606 .30271 Mdot
.606 .30276 Mdot
.606 .30285 Mdot
.606 .30288 Mdot
.606 .30289 Mdot
.606 .30289 Mdot
.606 .3029 Mdot
.606 .30294 Mdot
.606 .30297 Mdot
.606 .30299 Mdot
.606 .30302 Mdot
.606 .30303 Mdot
.606 .30309 Mdot
.606 .30311 Mdot
.606 .30317 Mdot
.606 .3032 Mdot
.606 .30321 Mdot
.606 .30323 Mdot
.606 .30323 Mdot
.606 .30325 Mdot
.606 .30325 Mdot
.606 .30332 Mdot
.606 .30334 Mdot
.606 .30334 Mdot
.606 .30336 Mdot
.606 .30338 Mdot
.606 .3034 Mdot
.606 .30343 Mdot
.606 .30344 Mdot
.606 .30346 Mdot
.606 .30346 Mdot
.606 .30348 Mdot
.606 .30352 Mdot
.606 .30353 Mdot
.606 .30355 Mdot
.606 .30357 Mdot
.606 .30366 Mdot
.606 .30366 Mdot
.606 .30367 Mdot
.606 .3037 Mdot
.606 .30375 Mdot
.606 .30376 Mdot
.606 .30379 Mdot
.606 .3038 Mdot
.606 .30381 Mdot
.606 .30382 Mdot
.606 .30383 Mdot
.606 .30387 Mdot
.606 .30389 Mdot
.606 .3039 Mdot
.606 .30402 Mdot
.606 .30404 Mdot
.606 .30408 Mdot
.606 .30408 Mdot
.606 .30409 Mdot
.606 .30411 Mdot
.606 .30413 Mdot
.606 .30421 Mdot
.606 .30422 Mdot
.606 .30427 Mdot
.606 .30428 Mdot
.606 .3043 Mdot
.606 .30434 Mdot
.606 .30436 Mdot
.606 .3044 Mdot
.606 .30441 Mdot
.606 .30447 Mdot
.606 .30449 Mdot
.606 .30449 Mdot
.606 .3045 Mdot
.606 .30462 Mdot
.606 .30463 Mdot
.606 .30464 Mdot
.606 .30467 Mdot
.606 .30468 Mdot
.606 .30469 Mdot
.606 .30475 Mdot
.606 .30478 Mdot
.606 .30478 Mdot
.606 .30478 Mdot
.606 .30486 Mdot
.606 .30487 Mdot
.606 .3049 Mdot
.606 .30496 Mdot
.606 .30497 Mdot
.606 .305 Mdot
.606 .30501 Mdot
.606 .30506 Mdot
.606 .30506 Mdot
.606 .30508 Mdot
.606 .30509 Mdot
.606 .3051 Mdot
.606 .30512 Mdot
.606 .30516 Mdot
.606 .30517 Mdot
.606 .30521 Mdot
.606 .30525 Mdot
.606 .3053 Mdot
.606 .3053 Mdot
.606 .30531 Mdot
.606 .30543 Mdot
.606 .30543 Mdot
.606 .30543 Mdot
.606 .30547 Mdot
.606 .30549 Mdot
.606 .30549 Mdot
.606 .30552 Mdot
.606 .30553 Mdot
.606 .30556 Mdot
.606 .3056 Mdot
.606 .3056 Mdot
.606 .30562 Mdot
.606 .30564 Mdot
.606 .30569 Mdot
.606 .30572 Mdot
.606 .30575 Mdot
.606 .30578 Mdot
.606 .30578 Mdot
.606 .3058 Mdot
.606 .3059 Mdot
.606 .30591 Mdot
.606 .30594 Mdot
.606 .30594 Mdot
.606 .30596 Mdot
.606 .30599 Mdot
.606 .30603 Mdot
.606 .30611 Mdot
.606 .30615 Mdot
.606 .30623 Mdot
.606 .30624 Mdot
.606 .30628 Mdot
.606 .30631 Mdot
.606 .30636 Mdot
.606 .30642 Mdot
.606 .30643 Mdot
.606 .30644 Mdot
.606 .30645 Mdot
.606 .30649 Mdot
.606 .30663 Mdot
.606 .3067 Mdot
.606 .3067 Mdot
.606 .30671 Mdot
.606 .3068 Mdot
.606 .30684 Mdot
.606 .30684 Mdot
.606 .3069 Mdot
.606 .30691 Mdot
.606 .30699 Mdot
.606 .30704 Mdot
.606 .30707 Mdot
.606 .30707 Mdot
.606 .30708 Mdot
.606 .30712 Mdot
.606 .30712 Mdot
.606 .30716 Mdot
.606 .30728 Mdot
.606 .30732 Mdot
.606 .30739 Mdot
.606 .30746 Mdot
.606 .30747 Mdot
.606 .3075 Mdot
.606 .30753 Mdot
.606 .30762 Mdot
.606 .30773 Mdot
.606 .30775 Mdot
.606 .30778 Mdot
.606 .30781 Mdot
.606 .30781 Mdot
.606 .30784 Mdot
.606 .30786 Mdot
.606 .30791 Mdot
.606 .30801 Mdot
.606 .30819 Mdot
.606 .30825 Mdot
.606 .30825 Mdot
.606 .30829 Mdot
.606 .30836 Mdot
.606 .30844 Mdot
.606 .30846 Mdot
.606 .30855 Mdot
.606 .30862 Mdot
.606 .30871 Mdot
.606 .30872 Mdot
.606 .30881 Mdot
.606 .30885 Mdot
.606 .30887 Mdot
.606 .30888 Mdot
.606 .30892 Mdot
.606 .30899 Mdot
.606 .309 Mdot
.606 .30903 Mdot
.606 .30907 Mdot
.606 .30912 Mdot
.606 .30921 Mdot
.606 .30924 Mdot
.606 .30929 Mdot
.606 .30935 Mdot
.606 .3094 Mdot
.606 .30945 Mdot
.606 .30945 Mdot
.606 .30947 Mdot
.606 .30953 Mdot
.606 .30967 Mdot
.606 .30971 Mdot
.606 .30974 Mdot
.606 .30974 Mdot
.606 .30981 Mdot
.606 .30987 Mdot
.606 .30991 Mdot
.606 .30992 Mdot
.606 .31008 Mdot
.606 .31019 Mdot
.606 .31025 Mdot
.606 .31025 Mdot
.606 .31027 Mdot
.606 .31035 Mdot
.606 .31036 Mdot
.606 .31036 Mdot
.606 .31037 Mdot
.606 .31044 Mdot
.606 .3105 Mdot
.606 .31055 Mdot
.606 .31069 Mdot
.606 .3108 Mdot
.606 .31083 Mdot
.606 .31094 Mdot
.606 .31105 Mdot
.606 .31109 Mdot
.606 .31111 Mdot
.606 .31112 Mdot
.606 .31117 Mdot
.606 .31118 Mdot
.606 .31125 Mdot
.606 .31127 Mdot
.606 .31129 Mdot
.606 .31138 Mdot
.606 .31142 Mdot
.606 .31143 Mdot
.606 .31156 Mdot
.606 .3116 Mdot
.606 .31165 Mdot
.606 .31166 Mdot
.606 .31167 Mdot
.606 .31169 Mdot
.606 .31171 Mdot
.606 .31178 Mdot
.606 .3118 Mdot
.606 .31184 Mdot
.606 .31185 Mdot
.606 .3119 Mdot
.606 .31192 Mdot
.606 .31195 Mdot
.606 .31205 Mdot
.606 .31218 Mdot
.606 .3122 Mdot
.606 .31227 Mdot
.606 .31228 Mdot
.606 .31247 Mdot
.606 .31252 Mdot
.606 .31257 Mdot
.606 .31265 Mdot
.606 .31272 Mdot
.606 .31274 Mdot
.606 .31279 Mdot
.606 .3128 Mdot
.606 .31284 Mdot
.606 .31287 Mdot
.606 .31289 Mdot
.606 .3129 Mdot
.606 .31299 Mdot
.606 .31303 Mdot
.606 .3132 Mdot
.606 .31323 Mdot
.606 .31325 Mdot
.606 .31344 Mdot
.606 .31347 Mdot
.606 .31354 Mdot
.606 .31358 Mdot
.606 .31377 Mdot
.606 .31379 Mdot
.606 .31381 Mdot
.606 .314 Mdot
.606 .31406 Mdot
.606 .31409 Mdot
.606 .31412 Mdot
.606 .31416 Mdot
.606 .31418 Mdot
.606 .31423 Mdot
.606 .31432 Mdot
.606 .31439 Mdot
.606 .31441 Mdot
.606 .31446 Mdot
.606 .31447 Mdot
.606 .31448 Mdot
.606 .31448 Mdot
.606 .31451 Mdot
.606 .31455 Mdot
.606 .31468 Mdot
.606 .31468 Mdot
.606 .31471 Mdot
.606 .31473 Mdot
.606 .31485 Mdot
.606 .31487 Mdot
.606 .31493 Mdot
.606 .31503 Mdot
.606 .31508 Mdot
.606 .31516 Mdot
.606 .31518 Mdot
.606 .31527 Mdot
.606 .31537 Mdot
.606 .31537 Mdot
.606 .31543 Mdot
.606 .31543 Mdot
.606 .31546 Mdot
.606 .31553 Mdot
.606 .31556 Mdot
.606 .31567 Mdot
.606 .31581 Mdot
.606 .31581 Mdot
.606 .31586 Mdot
.606 .31588 Mdot
.606 .35619 Mdot
.606 .35621 Mdot
.606 .35625 Mdot
.606 .35625 Mdot
.606 .35637 Mdot
.606 .35645 Mdot
.606 .35648 Mdot
.606 .35654 Mdot
.606 .35656 Mdot
.606 .35656 Mdot
.606 .35661 Mdot
.606 .35661 Mdot
.606 .3567 Mdot
.606 .35678 Mdot
.606 .35685 Mdot
.606 .35689 Mdot
.606 .35698 Mdot
.606 .35703 Mdot
.606 .35704 Mdot
.606 .35714 Mdot
.606 .35715 Mdot
.606 .35718 Mdot
.606 .35719 Mdot
.606 .35729 Mdot
.606 .35732 Mdot
.606 .35735 Mdot
.606 .35735 Mdot
.606 .35736 Mdot
.606 .35737 Mdot
.606 .35741 Mdot
.606 .35742 Mdot
.606 .35748 Mdot
.606 .35755 Mdot
.606 .3576 Mdot
.606 .35761 Mdot
.606 .35764 Mdot
.606 .35767 Mdot
.606 .35769 Mdot
.606 .35774 Mdot
.606 .3579 Mdot
.606 .35792 Mdot
.606 .35793 Mdot
.606 .35809 Mdot
.606 .35812 Mdot
.606 .35818 Mdot
.606 .35821 Mdot
.606 .35836 Mdot
.606 .35838 Mdot
.606 .35841 Mdot
.606 .35854 Mdot
.606 .35858 Mdot
.606 .35865 Mdot
.606 .35866 Mdot
.606 .35868 Mdot
.606 .3587 Mdot
.606 .35873 Mdot
.606 .35874 Mdot
.606 .35878 Mdot
.606 .3588 Mdot
.606 .35885 Mdot
.606 .35892 Mdot
.606 .35896 Mdot
.606 .359 Mdot
.606 .35916 Mdot
.606 .35917 Mdot
.606 .35922 Mdot
.606 .35924 Mdot
.606 .35935 Mdot
.606 .35943 Mdot
.606 .35946 Mdot
.606 .35948 Mdot
.606 .35952 Mdot
.606 .35953 Mdot
.606 .35956 Mdot
.606 .35957 Mdot
.606 .35963 Mdot
.606 .35965 Mdot
.606 .35966 Mdot
.606 .35967 Mdot
.606 .35968 Mdot
.606 .35972 Mdot
.606 .35976 Mdot
.606 .35987 Mdot
.606 .35988 Mdot
.606 .3599 Mdot
.606 .35998 Mdot
.606 .36 Mdot
.606 .36002 Mdot
.606 .36007 Mdot
.606 .36008 Mdot
.606 .36012 Mdot
.606 .36013 Mdot
.606 .36014 Mdot
.606 .36018 Mdot
.606 .36027 Mdot
.606 .36036 Mdot
.606 .36039 Mdot
.606 .36047 Mdot
.606 .36059 Mdot
.606 .36063 Mdot
.606 .36068 Mdot
.606 .36074 Mdot
.606 .36074 Mdot
.606 .36074 Mdot
.606 .36076 Mdot
.606 .36082 Mdot
.606 .36084 Mdot
.606 .36084 Mdot
.606 .36089 Mdot
.606 .36097 Mdot
.606 .36111 Mdot
.606 .36112 Mdot
.606 .36115 Mdot
.606 .3612 Mdot
.606 .36126 Mdot
.606 .36126 Mdot
.606 .36128 Mdot
.606 .36132 Mdot
.606 .36143 Mdot
.606 .36148 Mdot
.606 .3615 Mdot
.606 .3615 Mdot
.606 .36154 Mdot
.606 .36158 Mdot
.606 .36163 Mdot
.606 .36167 Mdot
.606 .36169 Mdot
.606 .36177 Mdot
.606 .36181 Mdot
.606 .36185 Mdot
.606 .36187 Mdot
.606 .36188 Mdot
.606 .36194 Mdot
.606 .36196 Mdot
.606 .36198 Mdot
.606 .36199 Mdot
.606 .36203 Mdot
.606 .3621 Mdot
.606 .36211 Mdot
.606 .36219 Mdot
.606 .36224 Mdot
.606 .36231 Mdot
.606 .36233 Mdot
.606 .3624 Mdot
.606 .36245 Mdot
.606 .36248 Mdot
.606 .36249 Mdot
.606 .36254 Mdot
.606 .36269 Mdot
.606 .36277 Mdot
.606 .36281 Mdot
.606 .36282 Mdot
.606 .36285 Mdot
.606 .36285 Mdot
.606 .36287 Mdot
.606 .3629 Mdot
.606 .36292 Mdot
.606 .36301 Mdot
.606 .36308 Mdot
.606 .3631 Mdot
.606 .36313 Mdot
.606 .36314 Mdot
.606 .3632 Mdot
.606 .36325 Mdot
.606 .36329 Mdot
.606 .36339 Mdot
.606 .36342 Mdot
.606 .36342 Mdot
.606 .36345 Mdot
.606 .36346 Mdot
.606 .36346 Mdot
.606 .36348 Mdot
.606 .36352 Mdot
.606 .36359 Mdot
.606 .3636 Mdot
.606 .36365 Mdot
.606 .36365 Mdot
.606 .36368 Mdot
.606 .36376 Mdot
.606 .36377 Mdot
.606 .36377 Mdot
.606 .36383 Mdot
.606 .36394 Mdot
.606 .36397 Mdot
.606 .36398 Mdot
.606 .36399 Mdot
.606 .36399 Mdot
.606 .36405 Mdot
.606 .36408 Mdot
.606 .36411 Mdot
.606 .36414 Mdot
.606 .36415 Mdot
.606 .36422 Mdot
.606 .36425 Mdot
.606 .36432 Mdot
.606 .36436 Mdot
.606 .36437 Mdot
.606 .36439 Mdot
.606 .36439 Mdot
.606 .36442 Mdot
.606 .36442 Mdot
.606 .36451 Mdot
.606 .36452 Mdot
.606 .36453 Mdot
.606 .36455 Mdot
.606 .36458 Mdot
.606 .3646 Mdot
.606 .36464 Mdot
.606 .36465 Mdot
.606 .36467 Mdot
.606 .36468 Mdot
.606 .3647 Mdot
.606 .36474 Mdot
.606 .36474 Mdot
.606 .36476 Mdot
.606 .36476 Mdot
.606 .36478 Mdot
.606 .36481 Mdot
.606 .36482 Mdot
.606 .36482 Mdot
.606 .36491 Mdot
.606 .36492 Mdot
.606 .36492 Mdot
.606 .36496 Mdot
.606 .365 Mdot
.606 .36503 Mdot
.606 .36504 Mdot
.606 .36507 Mdot
.606 .36509 Mdot
.606 .3651 Mdot
.606 .36511 Mdot
.606 .36512 Mdot
.606 .36512 Mdot
.606 .36516 Mdot
.606 .36517 Mdot
.606 .36519 Mdot
.606 .3652 Mdot
.606 .36525 Mdot
.606 .36528 Mdot
.606 .36529 Mdot
.606 .36535 Mdot
.606 .36535 Mdot
.606 .36535 Mdot
.606 .36537 Mdot
.606 .36542 Mdot
.606 .36543 Mdot
.606 .36544 Mdot
.606 .36547 Mdot
.606 .36548 Mdot
.606 .36548 Mdot
.606 .36558 Mdot
.606 .36559 Mdot
.606 .36559 Mdot
.606 .3656 Mdot
.606 .36566 Mdot
.606 .36566 Mdot
.606 .36569 Mdot
.606 .36571 Mdot
.606 .36574 Mdot
.606 .36577 Mdot
.606 .36577 Mdot
.606 .36581 Mdot
.606 .36582 Mdot
.606 .36589 Mdot
.606 .3659 Mdot
.606 .36592 Mdot
.606 .36592 Mdot
.606 .36593 Mdot
.606 .36596 Mdot
.606 .36598 Mdot
.606 .36608 Mdot
.606 .36609 Mdot
.606 .3661 Mdot
.606 .36614 Mdot
.606 .36614 Mdot
.606 .36615 Mdot
.606 .36616 Mdot
.606 .36617 Mdot
.606 .36619 Mdot
.606 .3662 Mdot
.606 .36624 Mdot
.606 .36627 Mdot
.606 .36627 Mdot
.606 .36628 Mdot
.606 .36635 Mdot
.606 .36637 Mdot
.606 .36638 Mdot
.606 .36639 Mdot
.606 .36642 Mdot
.606 .36644 Mdot
.606 .36644 Mdot
.606 .36645 Mdot
.606 .36646 Mdot
.606 .36649 Mdot
.606 .3665 Mdot
.606 .36652 Mdot
.606 .36654 Mdot
.606 .36654 Mdot
.606 .36655 Mdot
.606 .36661 Mdot
.606 .36662 Mdot
.606 .36663 Mdot
.606 .36663 Mdot
.606 .36664 Mdot
.606 .36666 Mdot
.606 .36668 Mdot
.606 .36673 Mdot
.606 .36675 Mdot
.606 .36679 Mdot
.606 .3668 Mdot
.606 .36682 Mdot
.606 .36684 Mdot
.606 .36687 Mdot
.606 .3669 Mdot
.606 .36691 Mdot
.606 .36691 Mdot
.606 .36692 Mdot
.606 .36694 Mdot
.606 .36702 Mdot
.606 .36706 Mdot
.606 .36706 Mdot
.606 .36706 Mdot
.606 .36712 Mdot
.606 .36713 Mdot
.606 .36713 Mdot
.606 .36717 Mdot
.606 .36718 Mdot
.606 .36722 Mdot
.606 .36725 Mdot
.606 .36727 Mdot
.606 .36727 Mdot
.606 .36727 Mdot
.606 .3673 Mdot
.606 .3673 Mdot
.606 .36731 Mdot
.606 .36738 Mdot
.606 .36741 Mdot
.606 .36745 Mdot
.606 .36749 Mdot
.606 .36749 Mdot
.606 .36751 Mdot
.606 .36753 Mdot
.606 .36757 Mdot
.606 .36763 Mdot
.606 .36765 Mdot
.606 .36766 Mdot
.606 .36768 Mdot
.606 .36768 Mdot
.606 .3677 Mdot
.606 .36771 Mdot
.606 .36774 Mdot
.606 .36779 Mdot
.606 .36789 Mdot
.606 .36793 Mdot
.606 .36793 Mdot
.606 .36795 Mdot
.606 .36799 Mdot
.606 .36803 Mdot
.606 .36805 Mdot
.606 .3681 Mdot
.606 .36813 Mdot
.606 .36819 Mdot
.606 .36819 Mdot
.606 .36824 Mdot
.606 .36827 Mdot
.606 .36827 Mdot
.606 .36828 Mdot
.606 .3683 Mdot
.606 .36834 Mdot
.606 .36835 Mdot
.606 .36836 Mdot
.606 .36839 Mdot
.606 .36842 Mdot
.606 .36847 Mdot
.606 .36848 Mdot
.606 .36851 Mdot
.606 .36855 Mdot
.606 .36857 Mdot
.606 .3686 Mdot
.606 .3686 Mdot
.606 .36862 Mdot
.606 .36865 Mdot
.606 .36873 Mdot
.606 .36875 Mdot
.606 .36877 Mdot
.606 .36877 Mdot
.606 .3688 Mdot
.606 .36884 Mdot
.606 .36886 Mdot
.606 .36887 Mdot
.606 .36896 Mdot
.606 .36902 Mdot
.606 .36905 Mdot
.606 .36905 Mdot
.606 .36906 Mdot
.606 .3691 Mdot
.606 .36911 Mdot
.606 .36911 Mdot
.606 .36912 Mdot
.606 .36916 Mdot
.606 .36919 Mdot
.606 .36922 Mdot
.606 .3693 Mdot
.606 .36936 Mdot
.606 .36938 Mdot
.606 .36944 Mdot
.606 .3695 Mdot
.606 .36952 Mdot
.606 .36953 Mdot
.606 .36954 Mdot
.606 .36957 Mdot
.606 .36957 Mdot
.606 .36961 Mdot
.606 .36962 Mdot
.606 .36964 Mdot
.606 .36969 Mdot
.606 .36971 Mdot
.606 .36971 Mdot
.606 .36979 Mdot
.606 .36981 Mdot
.606 .36984 Mdot
.606 .36984 Mdot
.606 .36985 Mdot
.606 .36986 Mdot
.606 .36987 Mdot
.606 .36991 Mdot
.606 .36992 Mdot
.606 .36994 Mdot
.606 .36995 Mdot
.606 .36998 Mdot
.606 .36999 Mdot
.606 .37001 Mdot
.606 .37006 Mdot
.606 .37014 Mdot
.606 .37015 Mdot
.606 .37018 Mdot
.606 .37019 Mdot
.606 .3703 Mdot
.606 .37033 Mdot
.606 .37036 Mdot
.606 .3704 Mdot
.606 .37044 Mdot
.606 .37045 Mdot
.606 .37048 Mdot
.606 .37048 Mdot
.606 .37051 Mdot
.606 .37052 Mdot
.606 .37053 Mdot
.606 .37054 Mdot
.606 .37059 Mdot
.606 .37061 Mdot
.606 .37071 Mdot
.606 .37072 Mdot
.606 .37074 Mdot
.606 .37084 Mdot
.606 .37086 Mdot
.606 .3709 Mdot
.606 .37092 Mdot
.606 .37103 Mdot
.606 .37104 Mdot
.606 .37105 Mdot
.606 .37116 Mdot
.606 .37119 Mdot
.606 .37121 Mdot
.606 .37123 Mdot
.606 .37125 Mdot
.606 .37126 Mdot
.606 .37129 Mdot
.606 .37134 Mdot
.606 .37138 Mdot
.606 .37139 Mdot
.606 .37142 Mdot
.606 .37142 Mdot
.606 .37143 Mdot
.606 .37143 Mdot
.606 .37145 Mdot
.606 .37147 Mdot
.606 .37154 Mdot
.606 .37154 Mdot
.606 .37156 Mdot
.606 .37157 Mdot
.606 .37164 Mdot
.606 .37165 Mdot
.606 .37168 Mdot
.606 .37174 Mdot
.606 .37176 Mdot
.606 .37181 Mdot
.606 .37187 Mdot
.606 .37193 Mdot
.606 .37193 Mdot
.606 .37196 Mdot
.606 .37196 Mdot
.606 .37198 Mdot
.606 .37202 Mdot
.606 .37204 Mdot
.606 .37209 Mdot
.606 .37218 Mdot
.606 .37218 Mdot
.606 .3722 Mdot
.606 .37221 Mdot
.608 .29595 Mdot
.608 .29598 Mdot
.608 .29602 Mdot
.608 .29606 Mdot
.608 .29607 Mdot
.608 .29611 Mdot
.608 .29618 Mdot
.608 .29632 Mdot
.608 .29635 Mdot
.608 .29636 Mdot
.608 .29638 Mdot
.608 .29641 Mdot
.608 .29646 Mdot
.608 .29647 Mdot
.608 .2965 Mdot
.608 .29651 Mdot
.608 .29651 Mdot
.608 .29651 Mdot
.608 .29653 Mdot
.608 .29653 Mdot
.608 .29659 Mdot
.608 .29666 Mdot
.608 .29666 Mdot
.608 .29671 Mdot
.608 .29672 Mdot
.608 .29682 Mdot
.608 .29682 Mdot
.608 .29691 Mdot
.608 .297 Mdot
.608 .29701 Mdot
.608 .29707 Mdot
.608 .2971 Mdot
.608 .29713 Mdot
.608 .29717 Mdot
.608 .29719 Mdot
.608 .29721 Mdot
.608 .29724 Mdot
.608 .29729 Mdot
.608 .29729 Mdot
.608 .29733 Mdot
.608 .29734 Mdot
.608 .29743 Mdot
.608 .29746 Mdot
.608 .29754 Mdot
.608 .29762 Mdot
.608 .2977 Mdot
.608 .29772 Mdot
.608 .29777 Mdot
.608 .2978 Mdot
.608 .29782 Mdot
.608 .29783 Mdot
.608 .29787 Mdot
.608 .29798 Mdot
.608 .29809 Mdot
.608 .29811 Mdot
.608 .29823 Mdot
.608 .29823 Mdot
.608 .29824 Mdot
.608 .29824 Mdot
.608 .29832 Mdot
.608 .29834 Mdot
.608 .29836 Mdot
.608 .29844 Mdot
.608 .29849 Mdot
.608 .29852 Mdot
.608 .29857 Mdot
.608 .29865 Mdot
.608 .29867 Mdot
.608 .29872 Mdot
.608 .29873 Mdot
.608 .29883 Mdot
.608 .29889 Mdot
.608 .29892 Mdot
.608 .29897 Mdot
.608 .29904 Mdot
.608 .29906 Mdot
.608 .29915 Mdot
.608 .29921 Mdot
.608 .29928 Mdot
.608 .29929 Mdot
.608 .29933 Mdot
.608 .29933 Mdot
.608 .29945 Mdot
.608 .29952 Mdot
.608 .29955 Mdot
.608 .29957 Mdot
.608 .29962 Mdot
.608 .29965 Mdot
.608 .29969 Mdot
.608 .29971 Mdot
.608 .29974 Mdot
.608 .29977 Mdot
.608 .29979 Mdot
.608 .2998 Mdot
.608 .29984 Mdot
.608 .29986 Mdot
.608 .2999 Mdot
.608 .2999 Mdot
.608 .29994 Mdot
.608 .29998 Mdot
.608 .30003 Mdot
.608 .30006 Mdot
.608 .30006 Mdot
.608 .30009 Mdot
.608 .30012 Mdot
.608 .30013 Mdot
.608 .30013 Mdot
.608 .30017 Mdot
.608 .30019 Mdot
.608 .3002 Mdot
.608 .3002 Mdot
.608 .30031 Mdot
.608 .30035 Mdot
.608 .30038 Mdot
.608 .30041 Mdot
.608 .30045 Mdot
.608 .30045 Mdot
.608 .3005 Mdot
.608 .30057 Mdot
.608 .30063 Mdot
.608 .30063 Mdot
.608 .30065 Mdot
.608 .30065 Mdot
.608 .30066 Mdot
.608 .30075 Mdot
.608 .30079 Mdot
.608 .30091 Mdot
.608 .30095 Mdot
.608 .30096 Mdot
.608 .30101 Mdot
.608 .30103 Mdot
.608 .3012 Mdot
.608 .30124 Mdot
.608 .30125 Mdot
.608 .30128 Mdot
.608 .30138 Mdot
.608 .30139 Mdot
.608 .30144 Mdot
.608 .30144 Mdot
.608 .30148 Mdot
.608 .30153 Mdot
.608 .30156 Mdot
.608 .30157 Mdot
.608 .3016 Mdot
.608 .30164 Mdot
.608 .30167 Mdot
.608 .30167 Mdot
.608 .30175 Mdot
.608 .30178 Mdot
.608 .30182 Mdot
.608 .30192 Mdot
.608 .30192 Mdot
.608 .30194 Mdot
.608 .302 Mdot
.608 .30203 Mdot
.608 .30207 Mdot
.608 .30209 Mdot
.608 .30211 Mdot
.608 .30214 Mdot
.608 .30215 Mdot
.608 .30216 Mdot
.608 .30218 Mdot
.608 .30218 Mdot
.608 .3022 Mdot
.608 .30222 Mdot
.608 .30224 Mdot
.608 .30228 Mdot
.608 .3023 Mdot
.608 .30231 Mdot
.608 .30231 Mdot
.608 .30233 Mdot
.608 .30233 Mdot
.608 .30234 Mdot
.608 .30239 Mdot
.608 .30241 Mdot
.608 .30245 Mdot
.608 .30248 Mdot
.608 .30251 Mdot
.608 .30255 Mdot
.608 .30259 Mdot
.608 .30261 Mdot
.608 .30269 Mdot
.608 .30271 Mdot
.608 .30272 Mdot
.608 .30282 Mdot
.608 .30282 Mdot
.608 .30283 Mdot
.608 .30288 Mdot
.608 .30288 Mdot
.608 .30291 Mdot
.608 .30293 Mdot
.608 .30297 Mdot
.608 .303 Mdot
.608 .30301 Mdot
.608 .30305 Mdot
.608 .30313 Mdot
.608 .30313 Mdot
.608 .3032 Mdot
.608 .3032 Mdot
.608 .30322 Mdot
.608 .30323 Mdot
.608 .30324 Mdot
.608 .30325 Mdot
.608 .30326 Mdot
.608 .30327 Mdot
.608 .30327 Mdot
.608 .30329 Mdot
.608 .3033 Mdot
.608 .30331 Mdot
.608 .30332 Mdot
.608 .30334 Mdot
.608 .30338 Mdot
.608 .3034 Mdot
.608 .30341 Mdot
.608 .30354 Mdot
.608 .30354 Mdot
.608 .30357 Mdot
.608 .30358 Mdot
.608 .30362 Mdot
.608 .30363 Mdot
.608 .30371 Mdot
.608 .30372 Mdot
.608 .30373 Mdot
.608 .30374 Mdot
.608 .30374 Mdot
.608 .30375 Mdot
.608 .30375 Mdot
.608 .30376 Mdot
.608 .3038 Mdot
.608 .3038 Mdot
.608 .30387 Mdot
.608 .30388 Mdot
.608 .30391 Mdot
.608 .30395 Mdot
.608 .30397 Mdot
.608 .30402 Mdot
.608 .30402 Mdot
.608 .30404 Mdot
.608 .30409 Mdot
.608 .30409 Mdot
.608 .30422 Mdot
.608 .30423 Mdot
.608 .30423 Mdot
.608 .3043 Mdot
.608 .30432 Mdot
.608 .30433 Mdot
.608 .30438 Mdot
.608 .30438 Mdot
.608 .3044 Mdot
.608 .30441 Mdot
.608 .30442 Mdot
.608 .30442 Mdot
.608 .30443 Mdot
.608 .30443 Mdot
.608 .30449 Mdot
.608 .3045 Mdot
.608 .30453 Mdot
.608 .30453 Mdot
.608 .30455 Mdot
.608 .30464 Mdot
.608 .30465 Mdot
.608 .30466 Mdot
.608 .30471 Mdot
.608 .30471 Mdot
.608 .30472 Mdot
.608 .30473 Mdot
.608 .30474 Mdot
.608 .30475 Mdot
.608 .30475 Mdot
.608 .30475 Mdot
.608 .30476 Mdot
.608 .30477 Mdot
.608 .30478 Mdot
.608 .30483 Mdot
.608 .30491 Mdot
.608 .30492 Mdot
.608 .30498 Mdot
.608 .305 Mdot
.608 .30503 Mdot
.608 .30504 Mdot
.608 .30513 Mdot
.608 .30522 Mdot
.608 .30525 Mdot
.608 .30527 Mdot
.608 .30529 Mdot
.608 .30533 Mdot
.608 .30537 Mdot
.608 .30537 Mdot
.608 .30539 Mdot
.608 .30539 Mdot
.608 .30539 Mdot
.608 .30541 Mdot
.608 .30543 Mdot
.608 .30544 Mdot
.608 .30546 Mdot
.608 .30547 Mdot
.608 .30548 Mdot
.608 .30549 Mdot
.608 .3055 Mdot
.608 .30552 Mdot
.608 .30553 Mdot
.608 .30554 Mdot
.608 .30557 Mdot
.608 .30563 Mdot
.608 .30565 Mdot
.608 .30565 Mdot
.608 .30576 Mdot
.608 .30582 Mdot
.608 .30584 Mdot
.608 .30588 Mdot
.608 .30594 Mdot
.608 .30597 Mdot
.608 .30601 Mdot
.608 .30602 Mdot
.608 .30608 Mdot
.608 .3061 Mdot
.608 .30611 Mdot
.608 .30625 Mdot
.608 .30627 Mdot
.608 .30629 Mdot
.608 .30641 Mdot
.608 .30644 Mdot
.608 .3065 Mdot
.608 .30656 Mdot
.608 .30661 Mdot
.608 .30664 Mdot
.608 .30671 Mdot
.608 .30674 Mdot
.608 .30681 Mdot
.608 .30682 Mdot
.608 .30683 Mdot
.608 .30686 Mdot
.608 .30686 Mdot
.608 .30687 Mdot
.608 .30691 Mdot
.608 .30696 Mdot
.608 .30699 Mdot
.608 .30702 Mdot
.608 .30704 Mdot
.608 .30705 Mdot
.608 .30708 Mdot
.608 .30709 Mdot
.608 .3071 Mdot
.608 .30715 Mdot
.608 .30718 Mdot
.608 .3072 Mdot
.608 .30727 Mdot
.608 .30732 Mdot
.608 .3074 Mdot
.608 .30743 Mdot
.608 .30743 Mdot
.608 .30758 Mdot
.608 .30764 Mdot
.608 .30768 Mdot
.608 .3078 Mdot
.608 .30781 Mdot
.608 .30785 Mdot
.608 .30791 Mdot
.608 .30794 Mdot
.608 .30797 Mdot
.608 .308 Mdot
.608 .30808 Mdot
.608 .30814 Mdot
.608 .30815 Mdot
.608 .30822 Mdot
.608 .30824 Mdot
.608 .30839 Mdot
.608 .30842 Mdot
.608 .30844 Mdot
.608 .3085 Mdot
.608 .30875 Mdot
.608 .30878 Mdot
.608 .30885 Mdot
.608 .30886 Mdot
.608 .30893 Mdot
.608 .3091 Mdot
.608 .30917 Mdot
.608 .3093 Mdot
.608 .3093 Mdot
.608 .30931 Mdot
.608 .30933 Mdot
.608 .30934 Mdot
.608 .30944 Mdot
.608 .30953 Mdot
.608 .30961 Mdot
.608 .30961 Mdot
.608 .30967 Mdot
.608 .30971 Mdot
.608 .30975 Mdot
.608 .30982 Mdot
.608 .30998 Mdot
.608 .30998 Mdot
.608 .31 Mdot
.608 .31002 Mdot
.608 .31008 Mdot
.608 .31009 Mdot
.608 .3101 Mdot
.608 .31014 Mdot
.608 .31019 Mdot
.608 .31019 Mdot
.608 .31023 Mdot
.608 .3103 Mdot
.608 .31036 Mdot
.608 .31042 Mdot
.608 .31043 Mdot
.608 .31048 Mdot
.608 .31051 Mdot
.608 .31056 Mdot
.608 .31058 Mdot
.608 .31061 Mdot
.608 .31065 Mdot
.608 .31071 Mdot
.608 .31073 Mdot
.608 .31079 Mdot
.608 .31083 Mdot
.608 .3109 Mdot
.608 .31094 Mdot
.608 .31098 Mdot
.608 .31108 Mdot
.608 .31126 Mdot
.608 .31126 Mdot
.608 .31132 Mdot
.608 .31133 Mdot
.608 .31144 Mdot
.608 .31153 Mdot
.608 .31166 Mdot
.608 .3117 Mdot
.608 .31179 Mdot
.608 .31187 Mdot
.608 .31191 Mdot
.608 .312 Mdot
.608 .31214 Mdot
.608 .31216 Mdot
.608 .31224 Mdot
.608 .31227 Mdot
.608 .31238 Mdot
.608 .31247 Mdot
.608 .3125 Mdot
.608 .31258 Mdot
.608 .3127 Mdot
.608 .31272 Mdot
.608 .31275 Mdot
.608 .31287 Mdot
.608 .31288 Mdot
.608 .31289 Mdot
.608 .31289 Mdot
.608 .31306 Mdot
.608 .31309 Mdot
.608 .31325 Mdot
.608 .31342 Mdot
.608 .31348 Mdot
.608 .3135 Mdot
.608 .31353 Mdot
.608 .31357 Mdot
.608 .31365 Mdot
.608 .31368 Mdot
.608 .3138 Mdot
.608 .3139 Mdot
.608 .31403 Mdot
.608 .31408 Mdot
.608 .3142 Mdot
.608 .31421 Mdot
.608 .31428 Mdot
.608 .31429 Mdot
.608 .31435 Mdot
.608 .31439 Mdot
.608 .31443 Mdot
.608 .31445 Mdot
.608 .31451 Mdot
.608 .31456 Mdot
.608 .31461 Mdot
.608 .31469 Mdot
.608 .31471 Mdot
.608 .31484 Mdot
.608 .31497 Mdot
.608 .31498 Mdot
.608 .31512 Mdot
.608 .31513 Mdot
.608 .31521 Mdot
.608 .31522 Mdot
.608 .31531 Mdot
.608 .31541 Mdot
.608 .31541 Mdot
.608 .31543 Mdot
.608 .31543 Mdot
.608 .31544 Mdot
.608 .31544 Mdot
.608 .31549 Mdot
.608 .31551 Mdot
.608 .31558 Mdot
.608 .31563 Mdot
.608 .31566 Mdot
.608 .31567 Mdot
.608 .31571 Mdot
.608 .31591 Mdot
.608 .31602 Mdot
.608 .31609 Mdot
.608 .31609 Mdot
.608 .31616 Mdot
.608 .31622 Mdot
.608 .31625 Mdot
.608 .3567 Mdot
.608 .35673 Mdot
.608 .35678 Mdot
.608 .35684 Mdot
.608 .35684 Mdot
.608 .35689 Mdot
.608 .35698 Mdot
.608 .35715 Mdot
.608 .35718 Mdot
.608 .35719 Mdot
.608 .35722 Mdot
.608 .35725 Mdot
.608 .35732 Mdot
.608 .35733 Mdot
.608 .35737 Mdot
.608 .35737 Mdot
.608 .35738 Mdot
.608 .35738 Mdot
.608 .3574 Mdot
.608 .3574 Mdot
.608 .35748 Mdot
.608 .35756 Mdot
.608 .35756 Mdot
.608 .35763 Mdot
.608 .35764 Mdot
.608 .35775 Mdot
.608 .35775 Mdot
.608 .35786 Mdot
.608 .35797 Mdot
.608 .35799 Mdot
.608 .35805 Mdot
.608 .35809 Mdot
.608 .35814 Mdot
.608 .35818 Mdot
.608 .35821 Mdot
.608 .35823 Mdot
.608 .35827 Mdot
.608 .35832 Mdot
.608 .35833 Mdot
.608 .35838 Mdot
.608 .35839 Mdot
.608 .35849 Mdot
.608 .35853 Mdot
.608 .35864 Mdot
.608 .35872 Mdot
.608 .35882 Mdot
.608 .35884 Mdot
.608 .35891 Mdot
.608 .35894 Mdot
.608 .35897 Mdot
.608 .35898 Mdot
.608 .35903 Mdot
.608 .35917 Mdot
.608 .3593 Mdot
.608 .35933 Mdot
.608 .35947 Mdot
.608 .35947 Mdot
.608 .35948 Mdot
.608 .35948 Mdot
.608 .35958 Mdot
.608 .3596 Mdot
.608 .35962 Mdot
.608 .35972 Mdot
.608 .35978 Mdot
.608 .35982 Mdot
.608 .35989 Mdot
.608 .35998 Mdot
.608 .36 Mdot
.608 .36007 Mdot
.608 .36008 Mdot
.608 .3602 Mdot
.608 .36027 Mdot
.608 .36031 Mdot
.608 .36037 Mdot
.608 .36045 Mdot
.608 .36048 Mdot
.608 .36059 Mdot
.608 .36066 Mdot
.608 .36075 Mdot
.608 .36076 Mdot
.608 .36081 Mdot
.608 .36081 Mdot
.608 .36096 Mdot
.608 .36104 Mdot
.608 .36107 Mdot
.608 .3611 Mdot
.608 .36116 Mdot
.608 .3612 Mdot
.608 .36125 Mdot
.608 .36126 Mdot
.608 .36131 Mdot
.608 .36134 Mdot
.608 .36137 Mdot
.608 .36138 Mdot
.608 .36143 Mdot
.608 .36145 Mdot
.608 .36149 Mdot
.608 .3615 Mdot
.608 .36155 Mdot
.608 .3616 Mdot
.608 .36166 Mdot
.608 .36169 Mdot
.608 .36169 Mdot
.608 .36173 Mdot
.608 .36176 Mdot
.608 .36177 Mdot
.608 .36178 Mdot
.608 .36183 Mdot
.608 .36185 Mdot
.608 .36186 Mdot
.608 .36186 Mdot
.608 .362 Mdot
.608 .36205 Mdot
.608 .36208 Mdot
.608 .36212 Mdot
.608 .36217 Mdot
.608 .36217 Mdot
.608 .36223 Mdot
.608 .36231 Mdot
.608 .36239 Mdot
.608 .36239 Mdot
.608 .36241 Mdot
.608 .36242 Mdot
.608 .36242 Mdot
.608 .36253 Mdot
.608 .36259 Mdot
.608 .36272 Mdot
.608 .36278 Mdot
.608 .36279 Mdot
.608 .36285 Mdot
.608 .36287 Mdot
.608 .36307 Mdot
.608 .36313 Mdot
.608 .36314 Mdot
.608 .36317 Mdot
.608 .36329 Mdot
.608 .36331 Mdot
.608 .36337 Mdot
.608 .36337 Mdot
.608 .36342 Mdot
.608 .36349 Mdot
.608 .36352 Mdot
.608 .36354 Mdot
.608 .36356 Mdot
.608 .36362 Mdot
.608 .36365 Mdot
.608 .36365 Mdot
.608 .36375 Mdot
.608 .36378 Mdot
.608 .36383 Mdot
.608 .36396 Mdot
.608 .36396 Mdot
.608 .36399 Mdot
.608 .36405 Mdot
.608 .36409 Mdot
.608 .36414 Mdot
.608 .36416 Mdot
.608 .36419 Mdot
.608 .36423 Mdot
.608 .36424 Mdot
.608 .36425 Mdot
.608 .36427 Mdot
.608 .36428 Mdot
.608 .3643 Mdot
.608 .36432 Mdot
.608 .36435 Mdot
.608 .36439 Mdot
.608 .36442 Mdot
.608 .36443 Mdot
.608 .36443 Mdot
.608 .36445 Mdot
.608 .36446 Mdot
.608 .36446 Mdot
.608 .36453 Mdot
.608 .36455 Mdot
.608 .36461 Mdot
.608 .36464 Mdot
.608 .36467 Mdot
.608 .36472 Mdot
.608 .36477 Mdot
.608 .3648 Mdot
.608 .36489 Mdot
.608 .36492 Mdot
.608 .36493 Mdot
.608 .36505 Mdot
.608 .36505 Mdot
.608 .36507 Mdot
.608 .36512 Mdot
.608 .36513 Mdot
.608 .36516 Mdot
.608 .36518 Mdot
.608 .36523 Mdot
.608 .36527 Mdot
.608 .36528 Mdot
.608 .36533 Mdot
.608 .36542 Mdot
.608 .36543 Mdot
.608 .36544 Mdot
.608 .36549 Mdot
.608 .36551 Mdot
.608 .36552 Mdot
.608 .36553 Mdot
.608 .36555 Mdot
.608 .36556 Mdot
.608 .36557 Mdot
.608 .36557 Mdot
.608 .36558 Mdot
.608 .36559 Mdot
.608 .3656 Mdot
.608 .36562 Mdot
.608 .36564 Mdot
.608 .36564 Mdot
.608 .36564 Mdot
.608 .36565 Mdot
.608 .36565 Mdot
.608 .36568 Mdot
.608 .36572 Mdot
.608 .36573 Mdot
.608 .36575 Mdot
.608 .36577 Mdot
.608 .36585 Mdot
.608 .36592 Mdot
.608 .36593 Mdot
.608 .36596 Mdot
.608 .36597 Mdot
.608 .36602 Mdot
.608 .36603 Mdot
.608 .3661 Mdot
.608 .36614 Mdot
.608 .36614 Mdot
.608 .36615 Mdot
.608 .36616 Mdot
.608 .36616 Mdot
.608 .36617 Mdot
.608 .36617 Mdot
.608 .36618 Mdot
.608 .36619 Mdot
.608 .36619 Mdot
.608 .3662 Mdot
.608 .36624 Mdot
.608 .36624 Mdot
.608 .36625 Mdot
.608 .36633 Mdot
.608 .36634 Mdot
.608 .36635 Mdot
.608 .36637 Mdot
.608 .36637 Mdot
.608 .36642 Mdot
.608 .36642 Mdot
.608 .36643 Mdot
.608 .36644 Mdot
.608 .36644 Mdot
.608 .36645 Mdot
.608 .36647 Mdot
.608 .36647 Mdot
.608 .36651 Mdot
.608 .36651 Mdot
.608 .36653 Mdot
.608 .36659 Mdot
.608 .36659 Mdot
.608 .3666 Mdot
.608 .3667 Mdot
.608 .36671 Mdot
.608 .36675 Mdot
.608 .36676 Mdot
.608 .36676 Mdot
.608 .36681 Mdot
.608 .36682 Mdot
.608 .36686 Mdot
.608 .36688 Mdot
.608 .36689 Mdot
.608 .36694 Mdot
.608 .36695 Mdot
.608 .36698 Mdot
.608 .36698 Mdot
.608 .36699 Mdot
.608 .36699 Mdot
.608 .36699 Mdot
.608 .367 Mdot
.608 .36701 Mdot
.608 .36701 Mdot
.608 .36709 Mdot
.608 .36709 Mdot
.608 .36713 Mdot
.608 .36714 Mdot
.608 .36715 Mdot
.608 .36716 Mdot
.608 .36726 Mdot
.608 .36728 Mdot
.608 .36729 Mdot
.608 .36732 Mdot
.608 .36734 Mdot
.608 .36734 Mdot
.608 .36735 Mdot
.608 .36736 Mdot
.608 .36738 Mdot
.608 .36738 Mdot
.608 .36739 Mdot
.608 .3674 Mdot
.608 .3674 Mdot
.608 .36741 Mdot
.608 .36742 Mdot
.608 .36743 Mdot
.608 .36744 Mdot
.608 .3675 Mdot
.608 .3675 Mdot
.608 .36756 Mdot
.608 .36759 Mdot
.608 .3676 Mdot
.608 .36763 Mdot
.608 .36766 Mdot
.608 .36768 Mdot
.608 .3677 Mdot
.608 .3677 Mdot
.608 .36774 Mdot
.608 .36775 Mdot
.608 .36775 Mdot
.608 .36783 Mdot
.608 .36784 Mdot
.608 .36786 Mdot
.608 .36792 Mdot
.608 .36794 Mdot
.608 .36797 Mdot
.608 .36801 Mdot
.608 .36803 Mdot
.608 .36805 Mdot
.608 .36809 Mdot
.608 .3681 Mdot
.608 .36815 Mdot
.608 .36815 Mdot
.608 .36815 Mdot
.608 .36817 Mdot
.608 .36817 Mdot
.608 .36818 Mdot
.608 .3682 Mdot
.608 .36823 Mdot
.608 .36824 Mdot
.608 .36826 Mdot
.608 .36827 Mdot
.608 .36828 Mdot
.608 .36829 Mdot
.608 .3683 Mdot
.608 .36831 Mdot
.608 .36833 Mdot
.608 .36835 Mdot
.608 .36836 Mdot
.608 .3684 Mdot
.608 .36843 Mdot
.608 .36847 Mdot
.608 .36849 Mdot
.608 .36849 Mdot
.608 .36857 Mdot
.608 .36861 Mdot
.608 .36863 Mdot
.608 .3687 Mdot
.608 .3687 Mdot
.608 .36872 Mdot
.608 .36876 Mdot
.608 .36877 Mdot
.608 .36879 Mdot
.608 .36881 Mdot
.608 .36885 Mdot
.608 .36888 Mdot
.608 .36889 Mdot
.608 .36893 Mdot
.608 .36894 Mdot
.608 .36902 Mdot
.608 .36904 Mdot
.608 .36905 Mdot
.608 .36909 Mdot
.608 .36922 Mdot
.608 .36924 Mdot
.608 .36928 Mdot
.608 .36928 Mdot
.608 .36932 Mdot
.608 .36942 Mdot
.608 .36946 Mdot
.608 .36953 Mdot
.608 .36953 Mdot
.608 .36953 Mdot
.608 .36955 Mdot
.608 .36955 Mdot
.608 .3696 Mdot
.608 .36965 Mdot
.608 .3697 Mdot
.608 .3697 Mdot
.608 .36973 Mdot
.608 .36976 Mdot
.608 .36978 Mdot
.608 .36982 Mdot
.608 .36991 Mdot
.608 .36991 Mdot
.608 .36992 Mdot
.608 .36993 Mdot
.608 .36996 Mdot
.608 .36997 Mdot
.608 .36997 Mdot
.608 .37 Mdot
.608 .37002 Mdot
.608 .37005 Mdot
.608 .37008 Mdot
.608 .37012 Mdot
.608 .37015 Mdot
.608 .37015 Mdot
.608 .37019 Mdot
.608 .3702 Mdot
.608 .37023 Mdot
.608 .37024 Mdot
.608 .37026 Mdot
.608 .37028 Mdot
.608 .37031 Mdot
.608 .37032 Mdot
.608 .37035 Mdot
.608 .37038 Mdot
.608 .37042 Mdot
.608 .37044 Mdot
.608 .37046 Mdot
.608 .37052 Mdot
.608 .37062 Mdot
.608 .37062 Mdot
.608 .37065 Mdot
.608 .37066 Mdot
.608 .37072 Mdot
.608 .37077 Mdot
.608 .37084 Mdot
.608 .37086 Mdot
.608 .37092 Mdot
.608 .37096 Mdot
.608 .37098 Mdot
.608 .37103 Mdot
.608 .37111 Mdot
.608 .37112 Mdot
.608 .37116 Mdot
.608 .37118 Mdot
.608 .37124 Mdot
.608 .37129 Mdot
.608 .37131 Mdot
.608 .37135 Mdot
.608 .37142 Mdot
.608 .37143 Mdot
.608 .37145 Mdot
.608 .37151 Mdot
.608 .37152 Mdot
.608 .37152 Mdot
.608 .37153 Mdot
.608 .37162 Mdot
.608 .37164 Mdot
.608 .37173 Mdot
.608 .37182 Mdot
.608 .37186 Mdot
.608 .37186 Mdot
.608 .37188 Mdot
.608 .3719 Mdot
.608 .37195 Mdot
.608 .37196 Mdot
.608 .37203 Mdot
.608 .37209 Mdot
.608 .37216 Mdot
.608 .37218 Mdot
.608 .37225 Mdot
.608 .37226 Mdot
.608 .3723 Mdot
.608 .3723 Mdot
.608 .37234 Mdot
.608 .37236 Mdot
.608 .37238 Mdot
.608 .37239 Mdot
.608 .37243 Mdot
.608 .37245 Mdot
.608 .37248 Mdot
.608 .37253 Mdot
.608 .37253 Mdot
.608 .37261 Mdot
.608 .37268 Mdot
.608 .37269 Mdot
.608 .37276 Mdot
.608 .37277 Mdot
.608 .37282 Mdot
.608 .37282 Mdot
.608 .37287 Mdot
.608 .37292 Mdot
.608 .37293 Mdot
.608 .37294 Mdot
.608 .37294 Mdot
.608 .37294 Mdot
.608 .37294 Mdot
.608 .37297 Mdot
.608 .37298 Mdot
.608 .37302 Mdot
.608 .37305 Mdot
.608 .37307 Mdot
.608 .37307 Mdot
.608 .3731 Mdot
.608 .37321 Mdot
.608 .37327 Mdot
.608 .3733 Mdot
.608 .37331 Mdot
.608 .37334 Mdot
.608 .37337 Mdot
.608 .3734 Mdot
.61 .29551 Mdot
.61 .29552 Mdot
.61 .29553 Mdot
.61 .29555 Mdot
.61 .2956 Mdot
.61 .29564 Mdot
.61 .29565 Mdot
.61 .29567 Mdot
.61 .29578 Mdot
.61 .29587 Mdot
.61 .29588 Mdot
.61 .29595 Mdot
.61 .29602 Mdot
.61 .29603 Mdot
.61 .29603 Mdot
.61 .29605 Mdot
.61 .29611 Mdot
.61 .29612 Mdot
.61 .29614 Mdot
.61 .29622 Mdot
.61 .29622 Mdot
.61 .29623 Mdot
.61 .29623 Mdot
.61 .29631 Mdot
.61 .29644 Mdot
.61 .29646 Mdot
.61 .2965 Mdot
.61 .29658 Mdot
.61 .29661 Mdot
.61 .29665 Mdot
.61 .29665 Mdot
.61 .29669 Mdot
.61 .29672 Mdot
.61 .2968 Mdot
.61 .29682 Mdot
.61 .29684 Mdot
.61 .29691 Mdot
.61 .29699 Mdot
.61 .29704 Mdot
.61 .29709 Mdot
.61 .29726 Mdot
.61 .2973 Mdot
.61 .29739 Mdot
.61 .29743 Mdot
.61 .29746 Mdot
.61 .29751 Mdot
.61 .29753 Mdot
.61 .29755 Mdot
.61 .29755 Mdot
.61 .29755 Mdot
.61 .29756 Mdot
.61 .29761 Mdot
.61 .29767 Mdot
.61 .29775 Mdot
.61 .29777 Mdot
.61 .29783 Mdot
.61 .29785 Mdot
.61 .29785 Mdot
.61 .29794 Mdot
.61 .29797 Mdot
.61 .29801 Mdot
.61 .29802 Mdot
.61 .29803 Mdot
.61 .29803 Mdot
.61 .29806 Mdot
.61 .29812 Mdot
.61 .29815 Mdot
.61 .2982 Mdot
.61 .29825 Mdot
.61 .29825 Mdot
.61 .29828 Mdot
.61 .29836 Mdot
.61 .29841 Mdot
.61 .29852 Mdot
.61 .29853 Mdot
.61 .2986 Mdot
.61 .2987 Mdot
.61 .29876 Mdot
.61 .29881 Mdot
.61 .29882 Mdot
.61 .29883 Mdot
.61 .29889 Mdot
.61 .29891 Mdot
.61 .29892 Mdot
.61 .29893 Mdot
.61 .29902 Mdot
.61 .29912 Mdot
.61 .29914 Mdot
.61 .29918 Mdot
.61 .2992 Mdot
.61 .29921 Mdot
.61 .29927 Mdot
.61 .29937 Mdot
.61 .29946 Mdot
.61 .29947 Mdot
.61 .29952 Mdot
.61 .29953 Mdot
.61 .29955 Mdot
.61 .29955 Mdot
.61 .29956 Mdot
.61 .29963 Mdot
.61 .29964 Mdot
.61 .29974 Mdot
.61 .29974 Mdot
.61 .29974 Mdot
.61 .29982 Mdot
.61 .29983 Mdot
.61 .29986 Mdot
.61 .29994 Mdot
.61 .29999 Mdot
.61 .30001 Mdot
.61 .30002 Mdot
.61 .30005 Mdot
.61 .30005 Mdot
.61 .30006 Mdot
.61 .30014 Mdot
.61 .30021 Mdot
.61 .30031 Mdot
.61 .30031 Mdot
.61 .30038 Mdot
.61 .30038 Mdot
.61 .30042 Mdot
.61 .30042 Mdot
.61 .30043 Mdot
.61 .30046 Mdot
.61 .30051 Mdot
.61 .30059 Mdot
.61 .30063 Mdot
.61 .30073 Mdot
.61 .30078 Mdot
.61 .30081 Mdot
.61 .30086 Mdot
.61 .30095 Mdot
.61 .30103 Mdot
.61 .30105 Mdot
.61 .30106 Mdot
.61 .30107 Mdot
.61 .30107 Mdot
.61 .30107 Mdot
.61 .30112 Mdot
.61 .30116 Mdot
.61 .30116 Mdot
.61 .3012 Mdot
.61 .3012 Mdot
.61 .30124 Mdot
.61 .30126 Mdot
.61 .30128 Mdot
.61 .30128 Mdot
.61 .30134 Mdot
.61 .30136 Mdot
.61 .30143 Mdot
.61 .3015 Mdot
.61 .30154 Mdot
.61 .30159 Mdot
.61 .30164 Mdot
.61 .30164 Mdot
.61 .30164 Mdot
.61 .30167 Mdot
.61 .30169 Mdot
.61 .30173 Mdot
.61 .30177 Mdot
.61 .30178 Mdot
.61 .30181 Mdot
.61 .30182 Mdot
.61 .30189 Mdot
.61 .30193 Mdot
.61 .30197 Mdot
.61 .30197 Mdot
.61 .30198 Mdot
.61 .30201 Mdot
.61 .30205 Mdot
.61 .30205 Mdot
.61 .30209 Mdot
.61 .30211 Mdot
.61 .30217 Mdot
.61 .3022 Mdot
.61 .30231 Mdot
.61 .30231 Mdot
.61 .30234 Mdot
.61 .30234 Mdot
.61 .30236 Mdot
.61 .3024 Mdot
.61 .3025 Mdot
.61 .30252 Mdot
.61 .30256 Mdot
.61 .30264 Mdot
.61 .30265 Mdot
.61 .30269 Mdot
.61 .30271 Mdot
.61 .30271 Mdot
.61 .30273 Mdot
.61 .30274 Mdot
.61 .30275 Mdot
.61 .30278 Mdot
.61 .30291 Mdot
.61 .30293 Mdot
.61 .30294 Mdot
.61 .30297 Mdot
.61 .30298 Mdot
.61 .30299 Mdot
.61 .30302 Mdot
.61 .30306 Mdot
.61 .30306 Mdot
.61 .30308 Mdot
.61 .3031 Mdot
.61 .30312 Mdot
.61 .30315 Mdot
.61 .30322 Mdot
.61 .30323 Mdot
.61 .30323 Mdot
.61 .30324 Mdot
.61 .30331 Mdot
.61 .30333 Mdot
.61 .30336 Mdot
.61 .3034 Mdot
.61 .30341 Mdot
.61 .30343 Mdot
.61 .30349 Mdot
.61 .3035 Mdot
.61 .30352 Mdot
.61 .30354 Mdot
.61 .30355 Mdot
.61 .30357 Mdot
.61 .30358 Mdot
.61 .30367 Mdot
.61 .30369 Mdot
.61 .30371 Mdot
.61 .30372 Mdot
.61 .30378 Mdot
.61 .30378 Mdot
.61 .30383 Mdot
.61 .30384 Mdot
.61 .30385 Mdot
.61 .30385 Mdot
.61 .30388 Mdot
.61 .30388 Mdot
.61 .3039 Mdot
.61 .30391 Mdot
.61 .30392 Mdot
.61 .30399 Mdot
.61 .304 Mdot
.61 .30401 Mdot
.61 .30401 Mdot
.61 .30403 Mdot
.61 .30403 Mdot
.61 .30404 Mdot
.61 .30408 Mdot
.61 .30408 Mdot
.61 .30412 Mdot
.61 .30412 Mdot
.61 .30414 Mdot
.61 .30415 Mdot
.61 .30421 Mdot
.61 .30422 Mdot
.61 .30423 Mdot
.61 .30425 Mdot
.61 .30427 Mdot
.61 .30432 Mdot
.61 .30433 Mdot
.61 .30436 Mdot
.61 .30438 Mdot
.61 .30439 Mdot
.61 .30444 Mdot
.61 .30445 Mdot
.61 .30446 Mdot
.61 .30452 Mdot
.61 .30454 Mdot
.61 .30456 Mdot
.61 .30459 Mdot
.61 .30461 Mdot
.61 .30462 Mdot
.61 .30465 Mdot
.61 .30466 Mdot
.61 .30475 Mdot
.61 .30477 Mdot
.61 .30478 Mdot
.61 .3048 Mdot
.61 .3048 Mdot
.61 .30485 Mdot
.61 .3049 Mdot
.61 .30492 Mdot
.61 .30501 Mdot
.61 .30503 Mdot
.61 .30504 Mdot
.61 .30505 Mdot
.61 .30507 Mdot
.61 .30516 Mdot
.61 .3052 Mdot
.61 .30524 Mdot
.61 .30524 Mdot
.61 .30527 Mdot
.61 .30529 Mdot
.61 .3053 Mdot
.61 .3053 Mdot
.61 .30532 Mdot
.61 .30535 Mdot
.61 .3054 Mdot
.61 .3054 Mdot
.61 .30542 Mdot
.61 .30543 Mdot
.61 .30548 Mdot
.61 .3055 Mdot
.61 .30552 Mdot
.61 .30552 Mdot
.61 .30555 Mdot
.61 .30558 Mdot
.61 .30561 Mdot
.61 .30571 Mdot
.61 .30576 Mdot
.61 .30577 Mdot
.61 .30578 Mdot
.61 .30581 Mdot
.61 .30581 Mdot
.61 .30584 Mdot
.61 .30591 Mdot
.61 .30593 Mdot
.61 .30604 Mdot
.61 .3061 Mdot
.61 .30613 Mdot
.61 .30628 Mdot
.61 .30633 Mdot
.61 .30636 Mdot
.61 .30637 Mdot
.61 .30641 Mdot
.61 .30641 Mdot
.61 .30658 Mdot
.61 .30663 Mdot
.61 .30671 Mdot
.61 .30673 Mdot
.61 .3068 Mdot
.61 .3068 Mdot
.61 .30687 Mdot
.61 .30691 Mdot
.61 .30692 Mdot
.61 .30692 Mdot
.61 .30697 Mdot
.61 .30704 Mdot
.61 .30715 Mdot
.61 .30716 Mdot
.61 .3072 Mdot
.61 .30721 Mdot
.61 .30728 Mdot
.61 .30734 Mdot
.61 .30737 Mdot
.61 .30741 Mdot
.61 .30741 Mdot
.61 .30742 Mdot
.61 .30749 Mdot
.61 .30756 Mdot
.61 .30761 Mdot
.61 .30772 Mdot
.61 .30783 Mdot
.61 .30786 Mdot
.61 .30794 Mdot
.61 .30795 Mdot
.61 .30798 Mdot
.61 .308 Mdot
.61 .30806 Mdot
.61 .30807 Mdot
.61 .30812 Mdot
.61 .30813 Mdot
.61 .30819 Mdot
.61 .30826 Mdot
.61 .30826 Mdot
.61 .30826 Mdot
.61 .30828 Mdot
.61 .30829 Mdot
.61 .30831 Mdot
.61 .30843 Mdot
.61 .30857 Mdot
.61 .30864 Mdot
.61 .3087 Mdot
.61 .30877 Mdot
.61 .30892 Mdot
.61 .30897 Mdot
.61 .3091 Mdot
.61 .30916 Mdot
.61 .30922 Mdot
.61 .30923 Mdot
.61 .30923 Mdot
.61 .30929 Mdot
.61 .30929 Mdot
.61 .30939 Mdot
.61 .30939 Mdot
.61 .30954 Mdot
.61 .30964 Mdot
.61 .30976 Mdot
.61 .30977 Mdot
.61 .30978 Mdot
.61 .30982 Mdot
.61 .30984 Mdot
.61 .30987 Mdot
.61 .30994 Mdot
.61 .31005 Mdot
.61 .31011 Mdot
.61 .31012 Mdot
.61 .31024 Mdot
.61 .31024 Mdot
.61 .31024 Mdot
.61 .31038 Mdot
.61 .3104 Mdot
.61 .3105 Mdot
.61 .31052 Mdot
.61 .31053 Mdot
.61 .31055 Mdot
.61 .31057 Mdot
.61 .31064 Mdot
.61 .31065 Mdot
.61 .31079 Mdot
.61 .31093 Mdot
.61 .31102 Mdot
.61 .31105 Mdot
.61 .31107 Mdot
.61 .31113 Mdot
.61 .31117 Mdot
.61 .31131 Mdot
.61 .31144 Mdot
.61 .31145 Mdot
.61 .31147 Mdot
.61 .31151 Mdot
.61 .3116 Mdot
.61 .3116 Mdot
.61 .31162 Mdot
.61 .3117 Mdot
.61 .31179 Mdot
.61 .31194 Mdot
.61 .31204 Mdot
.61 .31205 Mdot
.61 .31222 Mdot
.61 .31229 Mdot
.61 .31241 Mdot
.61 .31245 Mdot
.61 .31246 Mdot
.61 .31253 Mdot
.61 .3126 Mdot
.61 .31265 Mdot
.61 .31274 Mdot
.61 .31278 Mdot
.61 .31279 Mdot
.61 .31281 Mdot
.61 .31281 Mdot
.61 .31287 Mdot
.61 .31291 Mdot
.61 .31305 Mdot
.61 .31306 Mdot
.61 .31309 Mdot
.61 .31317 Mdot
.61 .3132 Mdot
.61 .31332 Mdot
.61 .31341 Mdot
.61 .31348 Mdot
.61 .31349 Mdot
.61 .31349 Mdot
.61 .31349 Mdot
.61 .31353 Mdot
.61 .31356 Mdot
.61 .31363 Mdot
.61 .31367 Mdot
.61 .31374 Mdot
.61 .31387 Mdot
.61 .31394 Mdot
.61 .31418 Mdot
.61 .31425 Mdot
.61 .31433 Mdot
.61 .31445 Mdot
.61 .31455 Mdot
.61 .31458 Mdot
.61 .31461 Mdot
.61 .31474 Mdot
.61 .31477 Mdot
.61 .31483 Mdot
.61 .31484 Mdot
.61 .31489 Mdot
.61 .31494 Mdot
.61 .31506 Mdot
.61 .31512 Mdot
.61 .31515 Mdot
.61 .31535 Mdot
.61 .31546 Mdot
.61 .31546 Mdot
.61 .31547 Mdot
.61 .31548 Mdot
.61 .3156 Mdot
.61 .31563 Mdot
.61 .31564 Mdot
.61 .31573 Mdot
.61 .31576 Mdot
.61 .31576 Mdot
.61 .31577 Mdot
.61 .31588 Mdot
.61 .31598 Mdot
.61 .316 Mdot
.61 .31614 Mdot
.61 .31629 Mdot
.61 .31633 Mdot
.61 .31635 Mdot
.61 .3164 Mdot
.61 .31648 Mdot
.61 .31651 Mdot
.61 .31653 Mdot
.61 .31654 Mdot
.61 .35728 Mdot
.61 .35729 Mdot
.61 .35731 Mdot
.61 .35733 Mdot
.61 .35739 Mdot
.61 .35744 Mdot
.61 .35745 Mdot
.61 .35748 Mdot
.61 .35761 Mdot
.61 .35773 Mdot
.61 .35774 Mdot
.61 .35782 Mdot
.61 .35791 Mdot
.61 .35792 Mdot
.61 .35792 Mdot
.61 .35795 Mdot
.61 .35802 Mdot
.61 .35802 Mdot
.61 .35805 Mdot
.61 .35815 Mdot
.61 .35816 Mdot
.61 .35817 Mdot
.61 .35817 Mdot
.61 .35826 Mdot
.61 .35842 Mdot
.61 .35845 Mdot
.61 .3585 Mdot
.61 .35859 Mdot
.61 .35863 Mdot
.61 .35867 Mdot
.61 .35868 Mdot
.61 .35873 Mdot
.61 .35876 Mdot
.61 .35886 Mdot
.61 .35888 Mdot
.61 .35891 Mdot
.61 .35899 Mdot
.61 .35909 Mdot
.61 .35916 Mdot
.61 .35921 Mdot
.61 .35942 Mdot
.61 .35947 Mdot
.61 .35958 Mdot
.61 .35963 Mdot
.61 .35966 Mdot
.61 .35973 Mdot
.61 .35975 Mdot
.61 .35978 Mdot
.61 .35978 Mdot
.61 .35978 Mdot
.61 .35979 Mdot
.61 .35984 Mdot
.61 .35992 Mdot
.61 .36002 Mdot
.61 .36004 Mdot
.61 .36011 Mdot
.61 .36014 Mdot
.61 .36014 Mdot
.61 .36025 Mdot
.61 .36029 Mdot
.61 .36034 Mdot
.61 .36034 Mdot
.61 .36035 Mdot
.61 .36036 Mdot
.61 .3604 Mdot
.61 .36047 Mdot
.61 .36051 Mdot
.61 .36056 Mdot
.61 .36063 Mdot
.61 .36063 Mdot
.61 .36066 Mdot
.61 .36077 Mdot
.61 .36082 Mdot
.61 .36096 Mdot
.61 .36097 Mdot
.61 .36105 Mdot
.61 .36118 Mdot
.61 .36125 Mdot
.61 .36131 Mdot
.61 .36133 Mdot
.61 .36133 Mdot
.61 .3614 Mdot
.61 .36143 Mdot
.61 .36145 Mdot
.61 .36146 Mdot
.61 .36156 Mdot
.61 .36169 Mdot
.61 .36171 Mdot
.61 .36177 Mdot
.61 .36178 Mdot
.61 .3618 Mdot
.61 .36188 Mdot
.61 .362 Mdot
.61 .36211 Mdot
.61 .36212 Mdot
.61 .36218 Mdot
.61 .36219 Mdot
.61 .36221 Mdot
.61 .36221 Mdot
.61 .36223 Mdot
.61 .36232 Mdot
.61 .36233 Mdot
.61 .36244 Mdot
.61 .36244 Mdot
.61 .36245 Mdot
.61 .36254 Mdot
.61 .36255 Mdot
.61 .3626 Mdot
.61 .36269 Mdot
.61 .36275 Mdot
.61 .36277 Mdot
.61 .36279 Mdot
.61 .36282 Mdot
.61 .36283 Mdot
.61 .36284 Mdot
.61 .36294 Mdot
.61 .36301 Mdot
.61 .36314 Mdot
.61 .36314 Mdot
.61 .36322 Mdot
.61 .36323 Mdot
.61 .36327 Mdot
.61 .36327 Mdot
.61 .36328 Mdot
.61 .36333 Mdot
.61 .36338 Mdot
.61 .36349 Mdot
.61 .36353 Mdot
.61 .36365 Mdot
.61 .36371 Mdot
.61 .36376 Mdot
.61 .36381 Mdot
.61 .36392 Mdot
.61 .36402 Mdot
.61 .36404 Mdot
.61 .36405 Mdot
.61 .36406 Mdot
.61 .36407 Mdot
.61 .36407 Mdot
.61 .36413 Mdot
.61 .36418 Mdot
.61 .36418 Mdot
.61 .36423 Mdot
.61 .36423 Mdot
.61 .36428 Mdot
.61 .3643 Mdot
.61 .36432 Mdot
.61 .36433 Mdot
.61 .3644 Mdot
.61 .36442 Mdot
.61 .36451 Mdot
.61 .3646 Mdot
.61 .36464 Mdot
.61 .3647 Mdot
.61 .36476 Mdot
.61 .36477 Mdot
.61 .36477 Mdot
.61 .3648 Mdot
.61 .36483 Mdot
.61 .36487 Mdot
.61 .36493 Mdot
.61 .36494 Mdot
.61 .36497 Mdot
.61 .36498 Mdot
.61 .36507 Mdot
.61 .36512 Mdot
.61 .36516 Mdot
.61 .36516 Mdot
.61 .36517 Mdot
.61 .36521 Mdot
.61 .36527 Mdot
.61 .36527 Mdot
.61 .36532 Mdot
.61 .36534 Mdot
.61 .36541 Mdot
.61 .36545 Mdot
.61 .36558 Mdot
.61 .36558 Mdot
.61 .36562 Mdot
.61 .36562 Mdot
.61 .36565 Mdot
.61 .36569 Mdot
.61 .36581 Mdot
.61 .36584 Mdot
.61 .36589 Mdot
.61 .36598 Mdot
.61 .36599 Mdot
.61 .36605 Mdot
.61 .36607 Mdot
.61 .36607 Mdot
.61 .3661 Mdot
.61 .3661 Mdot
.61 .36612 Mdot
.61 .36616 Mdot
.61 .36624 Mdot
.61 .36626 Mdot
.61 .36629 Mdot
.61 .36632 Mdot
.61 .36632 Mdot
.61 .36633 Mdot
.61 .36634 Mdot
.61 .36639 Mdot
.61 .36639 Mdot
.61 .36641 Mdot
.61 .36641 Mdot
.61 .36645 Mdot
.61 .36648 Mdot
.61 .3665 Mdot
.61 .3665 Mdot
.61 .3665 Mdot
.61 .36652 Mdot
.61 .36654 Mdot
.61 .36654 Mdot
.61 .36657 Mdot
.61 .36661 Mdot
.61 .36669 Mdot
.61 .3667 Mdot
.61 .3667 Mdot
.61 .36671 Mdot
.61 .36673 Mdot
.61 .3668 Mdot
.61 .36682 Mdot
.61 .36687 Mdot
.61 .36691 Mdot
.61 .36691 Mdot
.61 .36692 Mdot
.61 .36693 Mdot
.61 .36695 Mdot
.61 .36702 Mdot
.61 .36703 Mdot
.61 .36705 Mdot
.61 .36706 Mdot
.61 .36708 Mdot
.61 .3671 Mdot
.61 .36712 Mdot
.61 .36713 Mdot
.61 .36718 Mdot
.61 .36719 Mdot
.61 .3672 Mdot
.61 .36724 Mdot
.61 .36724 Mdot
.61 .36726 Mdot
.61 .36729 Mdot
.61 .3673 Mdot
.61 .36734 Mdot
.61 .36735 Mdot
.61 .36737 Mdot
.61 .36738 Mdot
.61 .36739 Mdot
.61 .36744 Mdot
.61 .36744 Mdot
.61 .36746 Mdot
.61 .36746 Mdot
.61 .36749 Mdot
.61 .3675 Mdot
.61 .36753 Mdot
.61 .36753 Mdot
.61 .36753 Mdot
.61 .36755 Mdot
.61 .36755 Mdot
.61 .36756 Mdot
.61 .36756 Mdot
.61 .36763 Mdot
.61 .36764 Mdot
.61 .36766 Mdot
.61 .36766 Mdot
.61 .36768 Mdot
.61 .36768 Mdot
.61 .36769 Mdot
.61 .3677 Mdot
.61 .36774 Mdot
.61 .36774 Mdot
.61 .36779 Mdot
.61 .36779 Mdot
.61 .36781 Mdot
.61 .36783 Mdot
.61 .3679 Mdot
.61 .36791 Mdot
.61 .36793 Mdot
.61 .36794 Mdot
.61 .36795 Mdot
.61 .36797 Mdot
.61 .36798 Mdot
.61 .36803 Mdot
.61 .36804 Mdot
.61 .36805 Mdot
.61 .36808 Mdot
.61 .36811 Mdot
.61 .36812 Mdot
.61 .36818 Mdot
.61 .36819 Mdot
.61 .36819 Mdot
.61 .3682 Mdot
.61 .36826 Mdot
.61 .36828 Mdot
.61 .3683 Mdot
.61 .36832 Mdot
.61 .36833 Mdot
.61 .36833 Mdot
.61 .36836 Mdot
.61 .36839 Mdot
.61 .3684 Mdot
.61 .3684 Mdot
.61 .36843 Mdot
.61 .36844 Mdot
.61 .36845 Mdot
.61 .36855 Mdot
.61 .36858 Mdot
.61 .36859 Mdot
.61 .3686 Mdot
.61 .36861 Mdot
.61 .36861 Mdot
.61 .36863 Mdot
.61 .36867 Mdot
.61 .36868 Mdot
.61 .36874 Mdot
.61 .36877 Mdot
.61 .36879 Mdot
.61 .36887 Mdot
.61 .3689 Mdot
.61 .36892 Mdot
.61 .36892 Mdot
.61 .36894 Mdot
.61 .36894 Mdot
.61 .36903 Mdot
.61 .36906 Mdot
.61 .36911 Mdot
.61 .36912 Mdot
.61 .36915 Mdot
.61 .36916 Mdot
.61 .36919 Mdot
.61 .36922 Mdot
.61 .36922 Mdot
.61 .36923 Mdot
.61 .36925 Mdot
.61 .36929 Mdot
.61 .36935 Mdot
.61 .36936 Mdot
.61 .36938 Mdot
.61 .36938 Mdot
.61 .36942 Mdot
.61 .36945 Mdot
.61 .36947 Mdot
.61 .36949 Mdot
.61 .36949 Mdot
.61 .3695 Mdot
.61 .36954 Mdot
.61 .36958 Mdot
.61 .3696 Mdot
.61 .36966 Mdot
.61 .36972 Mdot
.61 .36974 Mdot
.61 .36979 Mdot
.61 .36979 Mdot
.61 .36981 Mdot
.61 .36982 Mdot
.61 .36985 Mdot
.61 .36985 Mdot
.61 .36988 Mdot
.61 .36989 Mdot
.61 .36992 Mdot
.61 .36996 Mdot
.61 .36996 Mdot
.61 .36996 Mdot
.61 .36997 Mdot
.61 .36998 Mdot
.61 .36999 Mdot
.61 .37006 Mdot
.61 .37013 Mdot
.61 .37017 Mdot
.61 .3702 Mdot
.61 .37024 Mdot
.61 .37032 Mdot
.61 .37035 Mdot
.61 .37042 Mdot
.61 .37046 Mdot
.61 .37049 Mdot
.61 .37049 Mdot
.61 .3705 Mdot
.61 .37053 Mdot
.61 .37053 Mdot
.61 .37058 Mdot
.61 .37058 Mdot
.61 .37067 Mdot
.61 .37072 Mdot
.61 .37079 Mdot
.61 .37079 Mdot
.61 .3708 Mdot
.61 .37082 Mdot
.61 .37083 Mdot
.61 .37085 Mdot
.61 .37088 Mdot
.61 .37095 Mdot
.61 .37098 Mdot
.61 .37099 Mdot
.61 .37105 Mdot
.61 .37105 Mdot
.61 .37105 Mdot
.61 .37113 Mdot
.61 .37114 Mdot
.61 .37119 Mdot
.61 .37121 Mdot
.61 .37121 Mdot
.61 .37122 Mdot
.61 .37123 Mdot
.61 .37127 Mdot
.61 .37128 Mdot
.61 .37135 Mdot
.61 .37143 Mdot
.61 .37148 Mdot
.61 .3715 Mdot
.61 .37151 Mdot
.61 .37154 Mdot
.61 .37156 Mdot
.61 .37164 Mdot
.61 .37171 Mdot
.61 .37172 Mdot
.61 .37173 Mdot
.61 .37175 Mdot
.61 .3718 Mdot
.61 .3718 Mdot
.61 .37181 Mdot
.61 .37186 Mdot
.61 .3719 Mdot
.61 .37199 Mdot
.61 .37204 Mdot
.61 .37205 Mdot
.61 .37214 Mdot
.61 .37218 Mdot
.61 .37225 Mdot
.61 .37227 Mdot
.61 .37227 Mdot
.61 .37232 Mdot
.61 .37235 Mdot
.61 .37238 Mdot
.61 .37243 Mdot
.61 .37245 Mdot
.61 .37246 Mdot
.61 .37246 Mdot
.61 .37247 Mdot
.61 .3725 Mdot
.61 .37252 Mdot
.61 .3726 Mdot
.61 .3726 Mdot
.61 .37262 Mdot
.61 .37267 Mdot
.61 .37268 Mdot
.61 .37275 Mdot
.61 .3728 Mdot
.61 .37283 Mdot
.61 .37284 Mdot
.61 .37284 Mdot
.61 .37284 Mdot
.61 .37286 Mdot
.61 .37288 Mdot
.61 .37292 Mdot
.61 .37294 Mdot
.61 .37298 Mdot
.61 .37305 Mdot
.61 .37309 Mdot
.61 .37322 Mdot
.61 .37326 Mdot
.61 .3733 Mdot
.61 .37337 Mdot
.61 .37343 Mdot
.61 .37344 Mdot
.61 .37346 Mdot
.61 .37353 Mdot
.61 .37355 Mdot
.61 .37358 Mdot
.61 .37359 Mdot
.61 .37361 Mdot
.61 .37364 Mdot
.61 .3737 Mdot
.61 .37374 Mdot
.61 .37376 Mdot
.61 .37386 Mdot
.61 .37392 Mdot
.61 .37393 Mdot
.61 .37393 Mdot
.61 .37394 Mdot
.61 .37401 Mdot
.61 .37402 Mdot
.61 .37403 Mdot
.61 .37407 Mdot
.61 .37409 Mdot
.61 .37409 Mdot
.61 .3741 Mdot
.61 .37416 Mdot
.61 .37422 Mdot
.61 .37422 Mdot
.61 .3743 Mdot
.61 .37439 Mdot
.61 .37441 Mdot
.61 .37442 Mdot
.61 .37444 Mdot
.61 .37449 Mdot
.61 .3745 Mdot
.61 .37451 Mdot
.61 .37452 Mdot
.612 .29492 Mdot
.612 .29496 Mdot
.612 .29497 Mdot
.612 .29502 Mdot
.612 .29509 Mdot
.612 .2951 Mdot
.612 .29511 Mdot
.612 .29519 Mdot
.612 .2952 Mdot
.612 .29521 Mdot
.612 .29521 Mdot
.612 .29527 Mdot
.612 .29549 Mdot
.612 .29553 Mdot
.612 .2956 Mdot
.612 .29572 Mdot
.612 .29573 Mdot
.612 .29575 Mdot
.612 .29584 Mdot
.612 .29591 Mdot
.612 .296 Mdot
.612 .29601 Mdot
.612 .29604 Mdot
.612 .29605 Mdot
.612 .29615 Mdot
.612 .29615 Mdot
.612 .29618 Mdot
.612 .2963 Mdot
.612 .2964 Mdot
.612 .29644 Mdot
.612 .29644 Mdot
.612 .29644 Mdot
.612 .29647 Mdot
.612 .29647 Mdot
.612 .29657 Mdot
.612 .29657 Mdot
.612 .29664 Mdot
.612 .29664 Mdot
.612 .29665 Mdot
.612 .29667 Mdot
.612 .29675 Mdot
.612 .2968 Mdot
.612 .2968 Mdot
.612 .29692 Mdot
.612 .29693 Mdot
.612 .29695 Mdot
.612 .29697 Mdot
.612 .297 Mdot
.612 .297 Mdot
.612 .29701 Mdot
.612 .29705 Mdot
.612 .29707 Mdot
.612 .29707 Mdot
.612 .29709 Mdot
.612 .29713 Mdot
.612 .29719 Mdot
.612 .2972 Mdot
.612 .29725 Mdot
.612 .29726 Mdot
.612 .29729 Mdot
.612 .29731 Mdot
.612 .29735 Mdot
.612 .29737 Mdot
.612 .29737 Mdot
.612 .29742 Mdot
.612 .29745 Mdot
.612 .29756 Mdot
.612 .29757 Mdot
.612 .29765 Mdot
.612 .29766 Mdot
.612 .29767 Mdot
.612 .29767 Mdot
.612 .29769 Mdot
.612 .29781 Mdot
.612 .29793 Mdot
.612 .29793 Mdot
.612 .29796 Mdot
.612 .29797 Mdot
.612 .29804 Mdot
.612 .29804 Mdot
.612 .29806 Mdot
.612 .2981 Mdot
.612 .29811 Mdot
.612 .29815 Mdot
.612 .29817 Mdot
.612 .29821 Mdot
.612 .29823 Mdot
.612 .29827 Mdot
.612 .29831 Mdot
.612 .29837 Mdot
.612 .29839 Mdot
.612 .29845 Mdot
.612 .29846 Mdot
.612 .29851 Mdot
.612 .29858 Mdot
.612 .29863 Mdot
.612 .29872 Mdot
.612 .29873 Mdot
.612 .29874 Mdot
.612 .29877 Mdot
.612 .29879 Mdot
.612 .29882 Mdot
.612 .29884 Mdot
.612 .29887 Mdot
.612 .29888 Mdot
.612 .29888 Mdot
.612 .29889 Mdot
.612 .29902 Mdot
.612 .29904 Mdot
.612 .29904 Mdot
.612 .29907 Mdot
.612 .29913 Mdot
.612 .29913 Mdot
.612 .29913 Mdot
.612 .29926 Mdot
.612 .2993 Mdot
.612 .29932 Mdot
.612 .29933 Mdot
.612 .2994 Mdot
.612 .29953 Mdot
.612 .29965 Mdot
.612 .29968 Mdot
.612 .29968 Mdot
.612 .29972 Mdot
.612 .29972 Mdot
.612 .29973 Mdot
.612 .29976 Mdot
.612 .29983 Mdot
.612 .29984 Mdot
.612 .29985 Mdot
.612 .29995 Mdot
.612 .29995 Mdot
.612 .30008 Mdot
.612 .30013 Mdot
.612 .30018 Mdot
.612 .30019 Mdot
.612 .3002 Mdot
.612 .30027 Mdot
.612 .30033 Mdot
.612 .30038 Mdot
.612 .30039 Mdot
.612 .30044 Mdot
.612 .30049 Mdot
.612 .30052 Mdot
.612 .30052 Mdot
.612 .30057 Mdot
.612 .30059 Mdot
.612 .30064 Mdot
.612 .30067 Mdot
.612 .30067 Mdot
.612 .30072 Mdot
.612 .30072 Mdot
.612 .30073 Mdot
.612 .30077 Mdot
.612 .30079 Mdot
.612 .30079 Mdot
.612 .30084 Mdot
.612 .30087 Mdot
.612 .30088 Mdot
.612 .30092 Mdot
.612 .30094 Mdot
.612 .30096 Mdot
.612 .30101 Mdot
.612 .30104 Mdot
.612 .30105 Mdot
.612 .30105 Mdot
.612 .30106 Mdot
.612 .30112 Mdot
.612 .30117 Mdot
.612 .30119 Mdot
.612 .30122 Mdot
.612 .30122 Mdot
.612 .30123 Mdot
.612 .30125 Mdot
.612 .30128 Mdot
.612 .30129 Mdot
.612 .3013 Mdot
.612 .30134 Mdot
.612 .30137 Mdot
.612 .30141 Mdot
.612 .30152 Mdot
.612 .30154 Mdot
.612 .30155 Mdot
.612 .30157 Mdot
.612 .30159 Mdot
.612 .30159 Mdot
.612 .30166 Mdot
.612 .30166 Mdot
.612 .3017 Mdot
.612 .30176 Mdot
.612 .30178 Mdot
.612 .30179 Mdot
.612 .30179 Mdot
.612 .30188 Mdot
.612 .30193 Mdot
.612 .30195 Mdot
.612 .30201 Mdot
.612 .30202 Mdot
.612 .30203 Mdot
.612 .30213 Mdot
.612 .30215 Mdot
.612 .30217 Mdot
.612 .30218 Mdot
.612 .30224 Mdot
.612 .30231 Mdot
.612 .30232 Mdot
.612 .30241 Mdot
.612 .30242 Mdot
.612 .30247 Mdot
.612 .30248 Mdot
.612 .30249 Mdot
.612 .30252 Mdot
.612 .30256 Mdot
.612 .30256 Mdot
.612 .30266 Mdot
.612 .30267 Mdot
.612 .30278 Mdot
.612 .3028 Mdot
.612 .30285 Mdot
.612 .30288 Mdot
.612 .30289 Mdot
.612 .30293 Mdot
.612 .30295 Mdot
.612 .30304 Mdot
.612 .30305 Mdot
.612 .30309 Mdot
.612 .30312 Mdot
.612 .30313 Mdot
.612 .30323 Mdot
.612 .30328 Mdot
.612 .30333 Mdot
.612 .30336 Mdot
.612 .30337 Mdot
.612 .3034 Mdot
.612 .30341 Mdot
.612 .30345 Mdot
.612 .30347 Mdot
.612 .30353 Mdot
.612 .30361 Mdot
.612 .30366 Mdot
.612 .3037 Mdot
.612 .30382 Mdot
.612 .30388 Mdot
.612 .30393 Mdot
.612 .30402 Mdot
.612 .30402 Mdot
.612 .30407 Mdot
.612 .3041 Mdot
.612 .30413 Mdot
.612 .30423 Mdot
.612 .30426 Mdot
.612 .30432 Mdot
.612 .30433 Mdot
.612 .30436 Mdot
.612 .30437 Mdot
.612 .30439 Mdot
.612 .30443 Mdot
.612 .30451 Mdot
.612 .30451 Mdot
.612 .30458 Mdot
.612 .30461 Mdot
.612 .30474 Mdot
.612 .30475 Mdot
.612 .3048 Mdot
.612 .30485 Mdot
.612 .30487 Mdot
.612 .305 Mdot
.612 .30503 Mdot
.612 .30509 Mdot
.612 .3051 Mdot
.612 .30511 Mdot
.612 .30515 Mdot
.612 .30523 Mdot
.612 .30523 Mdot
.612 .30524 Mdot
.612 .30525 Mdot
.612 .30526 Mdot
.612 .30528 Mdot
.612 .30542 Mdot
.612 .30544 Mdot
.612 .30546 Mdot
.612 .30548 Mdot
.612 .30551 Mdot
.612 .30559 Mdot
.612 .30559 Mdot
.612 .30565 Mdot
.612 .30566 Mdot
.612 .3057 Mdot
.612 .30571 Mdot
.612 .30573 Mdot
.612 .30576 Mdot
.612 .3058 Mdot
.612 .30581 Mdot
.612 .30581 Mdot
.612 .30589 Mdot
.612 .30594 Mdot
.612 .30596 Mdot
.612 .30607 Mdot
.612 .30616 Mdot
.612 .30617 Mdot
.612 .3062 Mdot
.612 .30623 Mdot
.612 .30639 Mdot
.612 .30639 Mdot
.612 .3064 Mdot
.612 .3065 Mdot
.612 .30652 Mdot
.612 .3066 Mdot
.612 .30674 Mdot
.612 .30674 Mdot
.612 .30675 Mdot
.612 .30678 Mdot
.612 .30687 Mdot
.612 .30693 Mdot
.612 .30694 Mdot
.612 .30704 Mdot
.612 .30704 Mdot
.612 .30708 Mdot
.612 .30709 Mdot
.612 .30711 Mdot
.612 .30715 Mdot
.612 .30731 Mdot
.612 .30737 Mdot
.612 .30742 Mdot
.612 .30747 Mdot
.612 .30749 Mdot
.612 .30751 Mdot
.612 .30755 Mdot
.612 .30758 Mdot
.612 .3076 Mdot
.612 .3076 Mdot
.612 .30764 Mdot
.612 .30767 Mdot
.612 .30775 Mdot
.612 .30783 Mdot
.612 .30785 Mdot
.612 .30785 Mdot
.612 .30786 Mdot
.612 .30791 Mdot
.612 .30799 Mdot
.612 .30801 Mdot
.612 .30804 Mdot
.612 .3081 Mdot
.612 .30812 Mdot
.612 .30816 Mdot
.612 .30824 Mdot
.612 .30824 Mdot
.612 .30826 Mdot
.612 .30833 Mdot
.612 .30834 Mdot
.612 .30835 Mdot
.612 .30842 Mdot
.612 .30842 Mdot
.612 .30846 Mdot
.612 .30853 Mdot
.612 .30858 Mdot
.612 .30865 Mdot
.612 .30865 Mdot
.612 .30869 Mdot
.612 .30876 Mdot
.612 .30884 Mdot
.612 .30886 Mdot
.612 .30893 Mdot
.612 .30902 Mdot
.612 .30913 Mdot
.612 .30914 Mdot
.612 .30915 Mdot
.612 .30923 Mdot
.612 .3093 Mdot
.612 .30949 Mdot
.612 .3095 Mdot
.612 .30964 Mdot
.612 .30966 Mdot
.612 .30968 Mdot
.612 .30978 Mdot
.612 .30983 Mdot
.612 .30983 Mdot
.612 .30984 Mdot
.612 .3099 Mdot
.612 .30991 Mdot
.612 .30995 Mdot
.612 .31012 Mdot
.612 .31033 Mdot
.612 .31043 Mdot
.612 .31044 Mdot
.612 .31046 Mdot
.612 .31053 Mdot
.612 .31072 Mdot
.612 .31073 Mdot
.612 .31073 Mdot
.612 .31082 Mdot
.612 .31086 Mdot
.612 .31086 Mdot
.612 .31088 Mdot
.612 .31108 Mdot
.612 .3111 Mdot
.612 .3111 Mdot
.612 .31111 Mdot
.612 .31116 Mdot
.612 .31119 Mdot
.612 .31123 Mdot
.612 .31126 Mdot
.612 .31131 Mdot
.612 .31133 Mdot
.612 .31135 Mdot
.612 .31148 Mdot
.612 .31154 Mdot
.612 .31165 Mdot
.612 .31172 Mdot
.612 .31174 Mdot
.612 .31184 Mdot
.612 .31187 Mdot
.612 .31195 Mdot
.612 .31201 Mdot
.612 .31207 Mdot
.612 .31211 Mdot
.612 .31216 Mdot
.612 .31219 Mdot
.612 .31225 Mdot
.612 .31226 Mdot
.612 .31233 Mdot
.612 .31236 Mdot
.612 .31237 Mdot
.612 .31246 Mdot
.612 .31248 Mdot
.612 .31252 Mdot
.612 .31252 Mdot
.612 .3127 Mdot
.612 .31289 Mdot
.612 .31292 Mdot
.612 .31292 Mdot
.612 .31292 Mdot
.612 .31294 Mdot
.612 .31307 Mdot
.612 .31307 Mdot
.612 .31324 Mdot
.612 .31328 Mdot
.612 .31336 Mdot
.612 .31336 Mdot
.612 .3134 Mdot
.612 .31345 Mdot
.612 .31348 Mdot
.612 .31353 Mdot
.612 .31355 Mdot
.612 .31362 Mdot
.612 .31363 Mdot
.612 .31372 Mdot
.612 .31378 Mdot
.612 .31381 Mdot
.612 .31381 Mdot
.612 .31385 Mdot
.612 .3139 Mdot
.612 .31392 Mdot
.612 .31392 Mdot
.612 .31397 Mdot
.612 .314 Mdot
.612 .31402 Mdot
.612 .31404 Mdot
.612 .31421 Mdot
.612 .31421 Mdot
.612 .3143 Mdot
.612 .3144 Mdot
.612 .31445 Mdot
.612 .31445 Mdot
.612 .31446 Mdot
.612 .31455 Mdot
.612 .31456 Mdot
.612 .31471 Mdot
.612 .31472 Mdot
.612 .31475 Mdot
.612 .31476 Mdot
.612 .31476 Mdot
.612 .31481 Mdot
.612 .31497 Mdot
.612 .31514 Mdot
.612 .31519 Mdot
.612 .31519 Mdot
.612 .31535 Mdot
.612 .31535 Mdot
.612 .3154 Mdot
.612 .31542 Mdot
.612 .31555 Mdot
.612 .31565 Mdot
.612 .31579 Mdot
.612 .31582 Mdot
.612 .31584 Mdot
.612 .31602 Mdot
.612 .31612 Mdot
.612 .31618 Mdot
.612 .3165 Mdot
.612 .31659 Mdot
.612 .3166 Mdot
.612 .31661 Mdot
.612 .31662 Mdot
.612 .31674 Mdot
.612 .31676 Mdot
.612 .31678 Mdot
.612 .31688 Mdot
.612 .31695 Mdot
.612 .31698 Mdot
.612 .31704 Mdot
.612 .35768 Mdot
.612 .35773 Mdot
.612 .35775 Mdot
.612 .35781 Mdot
.612 .35789 Mdot
.612 .35791 Mdot
.612 .35792 Mdot
.612 .35802 Mdot
.612 .35803 Mdot
.612 .35804 Mdot
.612 .35805 Mdot
.612 .35812 Mdot
.612 .35838 Mdot
.612 .35844 Mdot
.612 .35852 Mdot
.612 .35866 Mdot
.612 .35868 Mdot
.612 .3587 Mdot
.612 .35881 Mdot
.612 .3589 Mdot
.612 .35901 Mdot
.612 .35902 Mdot
.612 .35906 Mdot
.612 .35906 Mdot
.612 .35919 Mdot
.612 .35919 Mdot
.612 .35923 Mdot
.612 .35937 Mdot
.612 .3595 Mdot
.612 .35954 Mdot
.612 .35954 Mdot
.612 .35955 Mdot
.612 .35958 Mdot
.612 .35958 Mdot
.612 .35971 Mdot
.612 .35971 Mdot
.612 .35979 Mdot
.612 .35979 Mdot
.612 .3598 Mdot
.612 .35983 Mdot
.612 .35992 Mdot
.612 .35999 Mdot
.612 .35999 Mdot
.612 .36013 Mdot
.612 .36015 Mdot
.612 .36017 Mdot
.612 .36019 Mdot
.612 .36023 Mdot
.612 .36023 Mdot
.612 .36025 Mdot
.612 .36029 Mdot
.612 .36032 Mdot
.612 .36032 Mdot
.612 .36035 Mdot
.612 .36039 Mdot
.612 .36047 Mdot
.612 .36047 Mdot
.612 .36053 Mdot
.612 .36055 Mdot
.612 .36059 Mdot
.612 .36061 Mdot
.612 .36066 Mdot
.612 .36068 Mdot
.612 .36069 Mdot
.612 .36075 Mdot
.612 .36079 Mdot
.612 .36092 Mdot
.612 .36092 Mdot
.612 .36103 Mdot
.612 .36104 Mdot
.612 .36105 Mdot
.612 .36105 Mdot
.612 .36107 Mdot
.612 .36123 Mdot
.612 .36137 Mdot
.612 .36137 Mdot
.612 .3614 Mdot
.612 .36142 Mdot
.612 .3615 Mdot
.612 .36151 Mdot
.612 .36153 Mdot
.612 .36158 Mdot
.612 .36159 Mdot
.612 .36164 Mdot
.612 .36167 Mdot
.612 .36171 Mdot
.612 .36174 Mdot
.612 .36179 Mdot
.612 .36184 Mdot
.612 .3619 Mdot
.612 .36193 Mdot
.612 .36201 Mdot
.612 .36202 Mdot
.612 .36208 Mdot
.612 .36217 Mdot
.612 .36223 Mdot
.612 .36233 Mdot
.612 .36234 Mdot
.612 .36236 Mdot
.612 .3624 Mdot
.612 .36243 Mdot
.612 .36246 Mdot
.612 .36248 Mdot
.612 .36252 Mdot
.612 .36253 Mdot
.612 .36253 Mdot
.612 .36255 Mdot
.612 .36271 Mdot
.612 .36273 Mdot
.612 .36273 Mdot
.612 .36276 Mdot
.612 .36284 Mdot
.612 .36284 Mdot
.612 .36284 Mdot
.612 .363 Mdot
.612 .36305 Mdot
.612 .36307 Mdot
.612 .36308 Mdot
.612 .36316 Mdot
.612 .36333 Mdot
.612 .36347 Mdot
.612 .36351 Mdot
.612 .36351 Mdot
.612 .36356 Mdot
.612 .36357 Mdot
.612 .36357 Mdot
.612 .36361 Mdot
.612 .36369 Mdot
.612 .36371 Mdot
.612 .36372 Mdot
.612 .36384 Mdot
.612 .36385 Mdot
.612 .364 Mdot
.612 .36406 Mdot
.612 .36413 Mdot
.612 .36414 Mdot
.612 .36415 Mdot
.612 .36423 Mdot
.612 .3643 Mdot
.612 .36437 Mdot
.612 .36438 Mdot
.612 .36444 Mdot
.612 .3645 Mdot
.612 .36454 Mdot
.612 .36454 Mdot
.612 .3646 Mdot
.612 .36463 Mdot
.612 .36469 Mdot
.612 .36472 Mdot
.612 .36472 Mdot
.612 .36478 Mdot
.612 .36479 Mdot
.612 .3648 Mdot
.612 .36485 Mdot
.612 .36487 Mdot
.612 .36487 Mdot
.612 .36494 Mdot
.612 .36497 Mdot
.612 .36499 Mdot
.612 .36503 Mdot
.612 .36506 Mdot
.612 .36508 Mdot
.612 .36514 Mdot
.612 .36518 Mdot
.612 .36519 Mdot
.612 .36519 Mdot
.612 .3652 Mdot
.612 .36527 Mdot
.612 .36533 Mdot
.612 .36536 Mdot
.612 .36539 Mdot
.612 .3654 Mdot
.612 .36541 Mdot
.612 .36543 Mdot
.612 .36547 Mdot
.612 .36548 Mdot
.612 .3655 Mdot
.612 .36554 Mdot
.612 .36558 Mdot
.612 .36563 Mdot
.612 .36576 Mdot
.612 .36579 Mdot
.612 .36581 Mdot
.612 .36582 Mdot
.612 .36585 Mdot
.612 .36585 Mdot
.612 .36593 Mdot
.612 .36594 Mdot
.612 .36599 Mdot
.612 .36606 Mdot
.612 .36608 Mdot
.612 .36609 Mdot
.612 .3661 Mdot
.612 .36621 Mdot
.612 .36627 Mdot
.612 .36629 Mdot
.612 .36637 Mdot
.612 .36638 Mdot
.612 .36638 Mdot
.612 .36651 Mdot
.612 .36653 Mdot
.612 .36656 Mdot
.612 .36657 Mdot
.612 .36664 Mdot
.612 .36673 Mdot
.612 .36675 Mdot
.612 .36679 Mdot
.612 .36685 Mdot
.612 .36686 Mdot
.612 .36686 Mdot
.612 .36689 Mdot
.612 .36692 Mdot
.612 .36694 Mdot
.612 .36695 Mdot
.612 .36698 Mdot
.612 .36699 Mdot
.612 .36703 Mdot
.612 .36704 Mdot
.612 .3671 Mdot
.612 .36713 Mdot
.612 .36715 Mdot
.612 .36716 Mdot
.612 .36717 Mdot
.612 .36729 Mdot
.612 .36731 Mdot
.612 .36731 Mdot
.612 .36732 Mdot
.612 .36733 Mdot
.612 .36733 Mdot
.612 .36739 Mdot
.612 .36742 Mdot
.612 .36744 Mdot
.612 .36744 Mdot
.612 .36749 Mdot
.612 .36752 Mdot
.612 .36762 Mdot
.612 .36764 Mdot
.612 .36768 Mdot
.612 .36772 Mdot
.612 .36773 Mdot
.612 .36784 Mdot
.612 .36786 Mdot
.612 .36791 Mdot
.612 .36792 Mdot
.612 .36798 Mdot
.612 .36802 Mdot
.612 .36803 Mdot
.612 .36804 Mdot
.612 .36806 Mdot
.612 .36807 Mdot
.612 .36812 Mdot
.612 .36815 Mdot
.612 .36823 Mdot
.612 .36825 Mdot
.612 .36828 Mdot
.612 .36832 Mdot
.612 .36832 Mdot
.612 .36839 Mdot
.612 .36843 Mdot
.612 .36848 Mdot
.612 .36858 Mdot
.612 .36861 Mdot
.612 .36865 Mdot
.612 .36872 Mdot
.612 .36877 Mdot
.612 .36879 Mdot
.612 .36882 Mdot
.612 .36883 Mdot
.612 .36885 Mdot
.612 .36886 Mdot
.612 .36888 Mdot
.612 .36892 Mdot
.612 .36896 Mdot
.612 .36905 Mdot
.612 .36905 Mdot
.612 .36908 Mdot
.612 .36911 Mdot
.612 .36912 Mdot
.612 .36919 Mdot
.612 .36921 Mdot
.612 .36924 Mdot
.612 .36925 Mdot
.612 .36927 Mdot
.612 .36931 Mdot
.612 .36933 Mdot
.612 .36942 Mdot
.612 .36943 Mdot
.612 .36951 Mdot
.612 .36951 Mdot
.612 .36954 Mdot
.612 .36957 Mdot
.612 .36958 Mdot
.612 .36959 Mdot
.612 .36963 Mdot
.612 .36963 Mdot
.612 .36971 Mdot
.612 .36972 Mdot
.612 .36977 Mdot
.612 .36982 Mdot
.612 .36983 Mdot
.612 .36985 Mdot
.612 .36986 Mdot
.612 .36995 Mdot
.612 .36995 Mdot
.612 .36996 Mdot
.612 .37001 Mdot
.612 .37002 Mdot
.612 .37006 Mdot
.612 .37014 Mdot
.612 .37014 Mdot
.612 .37015 Mdot
.612 .37016 Mdot
.612 .37021 Mdot
.612 .37024 Mdot
.612 .37025 Mdot
.612 .3703 Mdot
.612 .3703 Mdot
.612 .37032 Mdot
.612 .37033 Mdot
.612 .37034 Mdot
.612 .37036 Mdot
.612 .37045 Mdot
.612 .37048 Mdot
.612 .37051 Mdot
.612 .37054 Mdot
.612 .37055 Mdot
.612 .37056 Mdot
.612 .37058 Mdot
.612 .3706 Mdot
.612 .37061 Mdot
.612 .37061 Mdot
.612 .37063 Mdot
.612 .37065 Mdot
.612 .37069 Mdot
.612 .37074 Mdot
.612 .37074 Mdot
.612 .37074 Mdot
.612 .37075 Mdot
.612 .37078 Mdot
.612 .37082 Mdot
.612 .37083 Mdot
.612 .37085 Mdot
.612 .37088 Mdot
.612 .37089 Mdot
.612 .37091 Mdot
.612 .37096 Mdot
.612 .37096 Mdot
.612 .37097 Mdot
.612 .371 Mdot
.612 .37101 Mdot
.612 .37102 Mdot
.612 .37106 Mdot
.612 .37108 Mdot
.612 .37112 Mdot
.612 .37114 Mdot
.612 .37118 Mdot
.612 .37118 Mdot
.612 .3712 Mdot
.612 .37124 Mdot
.612 .37128 Mdot
.612 .37129 Mdot
.612 .37133 Mdot
.612 .37138 Mdot
.612 .37144 Mdot
.612 .37145 Mdot
.612 .37145 Mdot
.612 .3715 Mdot
.612 .37154 Mdot
.612 .37164 Mdot
.612 .37164 Mdot
.612 .37172 Mdot
.612 .37173 Mdot
.612 .37174 Mdot
.612 .3718 Mdot
.612 .37182 Mdot
.612 .37183 Mdot
.612 .37183 Mdot
.612 .37186 Mdot
.612 .37187 Mdot
.612 .37189 Mdot
.612 .37198 Mdot
.612 .3721 Mdot
.612 .37215 Mdot
.612 .37216 Mdot
.612 .37217 Mdot
.612 .37221 Mdot
.612 .37231 Mdot
.612 .37231 Mdot
.612 .37231 Mdot
.612 .37236 Mdot
.612 .37239 Mdot
.612 .37239 Mdot
.612 .3724 Mdot
.612 .37251 Mdot
.612 .37252 Mdot
.612 .37252 Mdot
.612 .37252 Mdot
.612 .37255 Mdot
.612 .37257 Mdot
.612 .37259 Mdot
.612 .37261 Mdot
.612 .37263 Mdot
.612 .37264 Mdot
.612 .37265 Mdot
.612 .37272 Mdot
.612 .37276 Mdot
.612 .37282 Mdot
.612 .37286 Mdot
.612 .37287 Mdot
.612 .37292 Mdot
.612 .37294 Mdot
.612 .37298 Mdot
.612 .37301 Mdot
.612 .37305 Mdot
.612 .37307 Mdot
.612 .37309 Mdot
.612 .37311 Mdot
.612 .37315 Mdot
.612 .37315 Mdot
.612 .37319 Mdot
.612 .3732 Mdot
.612 .37321 Mdot
.612 .37326 Mdot
.612 .37327 Mdot
.612 .37329 Mdot
.612 .37329 Mdot
.612 .37339 Mdot
.612 .37349 Mdot
.612 .37351 Mdot
.612 .37351 Mdot
.612 .37351 Mdot
.612 .37352 Mdot
.612 .37359 Mdot
.612 .37359 Mdot
.612 .37368 Mdot
.612 .37371 Mdot
.612 .37375 Mdot
.612 .37375 Mdot
.612 .37377 Mdot
.612 .3738 Mdot
.612 .37382 Mdot
.612 .37384 Mdot
.612 .37385 Mdot
.612 .37389 Mdot
.612 .3739 Mdot
.612 .37394 Mdot
.612 .37398 Mdot
.612 .37399 Mdot
.612 .374 Mdot
.612 .37402 Mdot
.612 .37404 Mdot
.612 .37405 Mdot
.612 .37406 Mdot
.612 .37408 Mdot
.612 .3741 Mdot
.612 .37411 Mdot
.612 .37412 Mdot
.612 .37421 Mdot
.612 .37421 Mdot
.612 .37426 Mdot
.612 .37432 Mdot
.612 .37434 Mdot
.612 .37435 Mdot
.612 .37435 Mdot
.612 .3744 Mdot
.612 .3744 Mdot
.612 .37449 Mdot
.612 .37449 Mdot
.612 .37451 Mdot
.612 .37451 Mdot
.612 .37451 Mdot
.612 .37454 Mdot
.612 .37463 Mdot
.612 .37472 Mdot
.612 .37475 Mdot
.612 .37475 Mdot
.612 .37483 Mdot
.612 .37484 Mdot
.612 .37486 Mdot
.612 .37487 Mdot
.612 .37494 Mdot
.612 .375 Mdot
.612 .37507 Mdot
.612 .37509 Mdot
.612 .3751 Mdot
.612 .3752 Mdot
.612 .37525 Mdot
.612 .37529 Mdot
.612 .37546 Mdot
.612 .37551 Mdot
.612 .37552 Mdot
.612 .37552 Mdot
.612 .37553 Mdot
.612 .37559 Mdot
.612 .3756 Mdot
.612 .37561 Mdot
.612 .37567 Mdot
.612 .37571 Mdot
.612 .37572 Mdot
.612 .37575 Mdot
.614 .29437 Mdot
.614 .2945 Mdot
.614 .29454 Mdot
.614 .29458 Mdot
.614 .29464 Mdot
.614 .29469 Mdot
.614 .29472 Mdot
.614 .29473 Mdot
.614 .2948 Mdot
.614 .29491 Mdot
.614 .295 Mdot
.614 .29502 Mdot
.614 .29505 Mdot
.614 .29512 Mdot
.614 .29513 Mdot
.614 .29514 Mdot
.614 .29521 Mdot
.614 .29523 Mdot
.614 .29527 Mdot
.614 .29528 Mdot
.614 .29533 Mdot
.614 .29536 Mdot
.614 .29536 Mdot
.614 .29538 Mdot
.614 .29544 Mdot
.614 .29552 Mdot
.614 .29553 Mdot
.614 .29557 Mdot
.614 .29561 Mdot
.614 .29561 Mdot
.614 .29563 Mdot
.614 .29564 Mdot
.614 .29568 Mdot
.614 .29569 Mdot
.614 .2957 Mdot
.614 .29593 Mdot
.614 .29594 Mdot
.614 .29603 Mdot
.614 .29605 Mdot
.614 .29609 Mdot
.614 .29612 Mdot
.614 .29628 Mdot
.614 .2963 Mdot
.614 .29649 Mdot
.614 .29649 Mdot
.614 .29658 Mdot
.614 .29659 Mdot
.614 .29674 Mdot
.614 .29676 Mdot
.614 .29678 Mdot
.614 .2968 Mdot
.614 .29685 Mdot
.614 .29692 Mdot
.614 .29693 Mdot
.614 .29701 Mdot
.614 .29702 Mdot
.614 .29706 Mdot
.614 .29708 Mdot
.614 .29709 Mdot
.614 .29712 Mdot
.614 .29719 Mdot
.614 .29722 Mdot
.614 .29723 Mdot
.614 .29726 Mdot
.614 .29732 Mdot
.614 .29744 Mdot
.614 .29745 Mdot
.614 .29748 Mdot
.614 .29749 Mdot
.614 .2975 Mdot
.614 .29751 Mdot
.614 .29751 Mdot
.614 .29768 Mdot
.614 .29772 Mdot
.614 .29773 Mdot
.614 .29775 Mdot
.614 .2978 Mdot
.614 .29781 Mdot
.614 .29783 Mdot
.614 .29786 Mdot
.614 .29786 Mdot
.614 .29805 Mdot
.614 .29815 Mdot
.614 .29815 Mdot
.614 .29817 Mdot
.614 .29823 Mdot
.614 .29827 Mdot
.614 .29827 Mdot
.614 .29829 Mdot
.614 .29831 Mdot
.614 .29833 Mdot
.614 .29834 Mdot
.614 .2984 Mdot
.614 .29846 Mdot
.614 .29847 Mdot
.614 .29855 Mdot
.614 .29895 Mdot
.614 .29895 Mdot
.614 .29897 Mdot
.614 .29898 Mdot
.614 .299 Mdot
.614 .29902 Mdot
.614 .29905 Mdot
.614 .29909 Mdot
.614 .2991 Mdot
.614 .29919 Mdot
.614 .2992 Mdot
.614 .29924 Mdot
.614 .29929 Mdot
.614 .29934 Mdot
.614 .29937 Mdot
.614 .29938 Mdot
.614 .29943 Mdot
.614 .29952 Mdot
.614 .29959 Mdot
.614 .2996 Mdot
.614 .29965 Mdot
.614 .29969 Mdot
.614 .29981 Mdot
.614 .29983 Mdot
.614 .29986 Mdot
.614 .2999 Mdot
.614 .29991 Mdot
.614 .29993 Mdot
.614 .29993 Mdot
.614 .29997 Mdot
.614 .29997 Mdot
.614 .30004 Mdot
.614 .30008 Mdot
.614 .30009 Mdot
.614 .30012 Mdot
.614 .30022 Mdot
.614 .30022 Mdot
.614 .30026 Mdot
.614 .30027 Mdot
.614 .30029 Mdot
.614 .3003 Mdot
.614 .30037 Mdot
.614 .30038 Mdot
.614 .30046 Mdot
.614 .30046 Mdot
.614 .30051 Mdot
.614 .30058 Mdot
.614 .30059 Mdot
.614 .30062 Mdot
.614 .30065 Mdot
.614 .30069 Mdot
.614 .30069 Mdot
.614 .30073 Mdot
.614 .3008 Mdot
.614 .30089 Mdot
.614 .3009 Mdot
.614 .30091 Mdot
.614 .30091 Mdot
.614 .30091 Mdot
.614 .30099 Mdot
.614 .301 Mdot
.614 .30102 Mdot
.614 .30104 Mdot
.614 .30104 Mdot
.614 .30105 Mdot
.614 .30107 Mdot
.614 .30107 Mdot
.614 .30115 Mdot
.614 .3012 Mdot
.614 .30124 Mdot
.614 .30127 Mdot
.614 .30127 Mdot
.614 .30128 Mdot
.614 .30155 Mdot
.614 .30159 Mdot
.614 .30165 Mdot
.614 .30165 Mdot
.614 .30167 Mdot
.614 .30169 Mdot
.614 .30172 Mdot
.614 .30173 Mdot
.614 .30176 Mdot
.614 .30185 Mdot
.614 .30195 Mdot
.614 .30196 Mdot
.614 .30198 Mdot
.614 .30199 Mdot
.614 .30202 Mdot
.614 .30206 Mdot
.614 .3021 Mdot
.614 .30211 Mdot
.614 .30214 Mdot
.614 .30217 Mdot
.614 .30221 Mdot
.614 .30227 Mdot
.614 .30231 Mdot
.614 .30236 Mdot
.614 .3024 Mdot
.614 .30241 Mdot
.614 .30241 Mdot
.614 .30241 Mdot
.614 .30244 Mdot
.614 .30245 Mdot
.614 .30247 Mdot
.614 .30248 Mdot
.614 .30251 Mdot
.614 .30254 Mdot
.614 .30255 Mdot
.614 .30269 Mdot
.614 .30271 Mdot
.614 .30273 Mdot
.614 .30274 Mdot
.614 .30276 Mdot
.614 .30277 Mdot
.614 .30282 Mdot
.614 .30287 Mdot
.614 .30288 Mdot
.614 .30288 Mdot
.614 .30291 Mdot
.614 .30293 Mdot
.614 .30298 Mdot
.614 .30306 Mdot
.614 .30307 Mdot
.614 .30307 Mdot
.614 .30309 Mdot
.614 .3031 Mdot
.614 .30312 Mdot
.614 .3032 Mdot
.614 .30321 Mdot
.614 .30321 Mdot
.614 .30322 Mdot
.614 .30325 Mdot
.614 .30327 Mdot
.614 .30327 Mdot
.614 .3033 Mdot
.614 .30332 Mdot
.614 .30335 Mdot
.614 .30336 Mdot
.614 .30346 Mdot
.614 .30347 Mdot
.614 .30348 Mdot
.614 .30366 Mdot
.614 .30373 Mdot
.614 .30376 Mdot
.614 .30377 Mdot
.614 .3038 Mdot
.614 .30383 Mdot
.614 .30384 Mdot
.614 .30391 Mdot
.614 .30392 Mdot
.614 .30393 Mdot
.614 .30398 Mdot
.614 .30401 Mdot
.614 .30403 Mdot
.614 .30405 Mdot
.614 .30405 Mdot
.614 .30405 Mdot
.614 .30409 Mdot
.614 .30412 Mdot
.614 .30413 Mdot
.614 .30414 Mdot
.614 .30414 Mdot
.614 .30416 Mdot
.614 .30417 Mdot
.614 .30428 Mdot
.614 .30432 Mdot
.614 .30432 Mdot
.614 .30433 Mdot
.614 .30434 Mdot
.614 .30436 Mdot
.614 .30436 Mdot
.614 .30436 Mdot
.614 .30437 Mdot
.614 .30439 Mdot
.614 .30449 Mdot
.614 .30454 Mdot
.614 .30456 Mdot
.614 .30459 Mdot
.614 .30462 Mdot
.614 .30464 Mdot
.614 .30465 Mdot
.614 .30466 Mdot
.614 .30467 Mdot
.614 .30473 Mdot
.614 .30481 Mdot
.614 .30482 Mdot
.614 .30485 Mdot
.614 .30486 Mdot
.614 .30486 Mdot
.614 .3049 Mdot
.614 .30493 Mdot
.614 .30512 Mdot
.614 .30513 Mdot
.614 .30516 Mdot
.614 .3052 Mdot
.614 .30525 Mdot
.614 .30527 Mdot
.614 .30527 Mdot
.614 .30528 Mdot
.614 .30529 Mdot
.614 .3053 Mdot
.614 .30535 Mdot
.614 .30535 Mdot
.614 .30536 Mdot
.614 .30536 Mdot
.614 .30537 Mdot
.614 .30543 Mdot
.614 .30548 Mdot
.614 .3055 Mdot
.614 .30557 Mdot
.614 .30562 Mdot
.614 .30565 Mdot
.614 .3057 Mdot
.614 .30571 Mdot
.614 .30576 Mdot
.614 .30578 Mdot
.614 .30581 Mdot
.614 .30582 Mdot
.614 .30588 Mdot
.614 .30593 Mdot
.614 .30598 Mdot
.614 .306 Mdot
.614 .30602 Mdot
.614 .30605 Mdot
.614 .30609 Mdot
.614 .30619 Mdot
.614 .30633 Mdot
.614 .30638 Mdot
.614 .3064 Mdot
.614 .30643 Mdot
.614 .30646 Mdot
.614 .30649 Mdot
.614 .3065 Mdot
.614 .30659 Mdot
.614 .30664 Mdot
.614 .30706 Mdot
.614 .30706 Mdot
.614 .30708 Mdot
.614 .30711 Mdot
.614 .30717 Mdot
.614 .30725 Mdot
.614 .30738 Mdot
.614 .30738 Mdot
.614 .3074 Mdot
.614 .30741 Mdot
.614 .30742 Mdot
.614 .30745 Mdot
.614 .30747 Mdot
.614 .30749 Mdot
.614 .30761 Mdot
.614 .30761 Mdot
.614 .30762 Mdot
.614 .30763 Mdot
.614 .30765 Mdot
.614 .30778 Mdot
.614 .30789 Mdot
.614 .30794 Mdot
.614 .30794 Mdot
.614 .308 Mdot
.614 .30805 Mdot
.614 .3081 Mdot
.614 .30812 Mdot
.614 .30822 Mdot
.614 .30829 Mdot
.614 .30829 Mdot
.614 .30841 Mdot
.614 .30843 Mdot
.614 .30853 Mdot
.614 .30855 Mdot
.614 .30858 Mdot
.614 .30859 Mdot
.614 .30865 Mdot
.614 .30866 Mdot
.614 .30881 Mdot
.614 .30886 Mdot
.614 .30887 Mdot
.614 .30892 Mdot
.614 .30902 Mdot
.614 .30903 Mdot
.614 .30909 Mdot
.614 .3091 Mdot
.614 .30912 Mdot
.614 .30913 Mdot
.614 .30919 Mdot
.614 .30924 Mdot
.614 .30928 Mdot
.614 .30946 Mdot
.614 .30951 Mdot
.614 .30958 Mdot
.614 .3096 Mdot
.614 .3097 Mdot
.614 .30984 Mdot
.614 .30991 Mdot
.614 .30994 Mdot
.614 .30999 Mdot
.614 .31006 Mdot
.614 .31013 Mdot
.614 .3102 Mdot
.614 .31021 Mdot
.614 .31034 Mdot
.614 .31036 Mdot
.614 .31041 Mdot
.614 .31046 Mdot
.614 .3105 Mdot
.614 .31052 Mdot
.614 .31054 Mdot
.614 .31057 Mdot
.614 .31058 Mdot
.614 .31117 Mdot
.614 .31129 Mdot
.614 .31131 Mdot
.614 .3114 Mdot
.614 .31149 Mdot
.614 .3115 Mdot
.614 .31153 Mdot
.614 .31157 Mdot
.614 .31159 Mdot
.614 .3116 Mdot
.614 .31166 Mdot
.614 .31174 Mdot
.614 .31177 Mdot
.614 .31178 Mdot
.614 .31193 Mdot
.614 .31221 Mdot
.614 .31221 Mdot
.614 .31226 Mdot
.614 .31229 Mdot
.614 .3123 Mdot
.614 .31237 Mdot
.614 .31241 Mdot
.614 .31242 Mdot
.614 .31248 Mdot
.614 .31274 Mdot
.614 .31274 Mdot
.614 .31276 Mdot
.614 .31277 Mdot
.614 .31279 Mdot
.614 .31283 Mdot
.614 .31284 Mdot
.614 .31303 Mdot
.614 .31312 Mdot
.614 .31316 Mdot
.614 .31317 Mdot
.614 .31323 Mdot
.614 .31332 Mdot
.614 .31338 Mdot
.614 .31339 Mdot
.614 .31342 Mdot
.614 .31349 Mdot
.614 .31349 Mdot
.614 .31361 Mdot
.614 .31363 Mdot
.614 .31374 Mdot
.614 .31382 Mdot
.614 .31385 Mdot
.614 .31387 Mdot
.614 .31389 Mdot
.614 .31413 Mdot
.614 .31414 Mdot
.614 .31428 Mdot
.614 .31428 Mdot
.614 .31456 Mdot
.614 .3146 Mdot
.614 .31483 Mdot
.614 .31488 Mdot
.614 .31494 Mdot
.614 .31497 Mdot
.614 .3151 Mdot
.614 .31513 Mdot
.614 .31547 Mdot
.614 .31549 Mdot
.614 .31551 Mdot
.614 .31557 Mdot
.614 .31557 Mdot
.614 .3156 Mdot
.614 .31561 Mdot
.614 .31566 Mdot
.614 .31573 Mdot
.614 .31574 Mdot
.614 .31586 Mdot
.614 .31596 Mdot
.614 .31597 Mdot
.614 .31598 Mdot
.614 .31603 Mdot
.614 .31611 Mdot
.614 .31612 Mdot
.614 .31617 Mdot
.614 .3162 Mdot
.614 .3163 Mdot
.614 .31631 Mdot
.614 .31633 Mdot
.614 .31635 Mdot
.614 .31644 Mdot
.614 .3165 Mdot
.614 .31653 Mdot
.614 .31666 Mdot
.614 .31683 Mdot
.614 .31693 Mdot
.614 .31694 Mdot
.614 .31699 Mdot
.614 .31707 Mdot
.614 .31716 Mdot
.614 .31722 Mdot
.614 .31727 Mdot
.614 .31747 Mdot
.614 .35813 Mdot
.614 .3583 Mdot
.614 .35834 Mdot
.614 .35838 Mdot
.614 .35846 Mdot
.614 .35852 Mdot
.614 .35856 Mdot
.614 .35858 Mdot
.614 .35866 Mdot
.614 .35879 Mdot
.614 .3589 Mdot
.614 .35893 Mdot
.614 .35897 Mdot
.614 .35905 Mdot
.614 .35906 Mdot
.614 .35908 Mdot
.614 .35917 Mdot
.614 .35919 Mdot
.614 .35923 Mdot
.614 .35925 Mdot
.614 .35931 Mdot
.614 .35935 Mdot
.614 .35935 Mdot
.614 .35937 Mdot
.614 .35944 Mdot
.614 .35954 Mdot
.614 .35955 Mdot
.614 .35961 Mdot
.614 .35965 Mdot
.614 .35965 Mdot
.614 .35968 Mdot
.614 .35969 Mdot
.614 .35973 Mdot
.614 .35975 Mdot
.614 .35976 Mdot
.614 .36004 Mdot
.614 .36006 Mdot
.614 .36017 Mdot
.614 .3602 Mdot
.614 .36025 Mdot
.614 .36028 Mdot
.614 .36047 Mdot
.614 .36051 Mdot
.614 .36073 Mdot
.614 .36073 Mdot
.614 .36084 Mdot
.614 .36085 Mdot
.614 .36105 Mdot
.614 .36107 Mdot
.614 .36109 Mdot
.614 .36111 Mdot
.614 .36117 Mdot
.614 .36126 Mdot
.614 .36127 Mdot
.614 .36137 Mdot
.614 .36138 Mdot
.614 .36143 Mdot
.614 .36146 Mdot
.614 .36147 Mdot
.614 .36151 Mdot
.614 .36159 Mdot
.614 .36163 Mdot
.614 .36164 Mdot
.614 .36168 Mdot
.614 .36175 Mdot
.614 .3619 Mdot
.614 .36191 Mdot
.614 .36195 Mdot
.614 .36196 Mdot
.614 .36197 Mdot
.614 .36199 Mdot
.614 .36199 Mdot
.614 .3622 Mdot
.614 .36225 Mdot
.614 .36225 Mdot
.614 .36229 Mdot
.614 .36235 Mdot
.614 .36235 Mdot
.614 .36238 Mdot
.614 .36242 Mdot
.614 .36242 Mdot
.614 .36265 Mdot
.614 .36277 Mdot
.614 .36278 Mdot
.614 .3628 Mdot
.614 .36287 Mdot
.614 .36292 Mdot
.614 .36292 Mdot
.614 .36294 Mdot
.614 .36297 Mdot
.614 .363 Mdot
.614 .36301 Mdot
.614 .36308 Mdot
.614 .36315 Mdot
.614 .36317 Mdot
.614 .36327 Mdot
.614 .36375 Mdot
.614 .36376 Mdot
.614 .36378 Mdot
.614 .36379 Mdot
.614 .36381 Mdot
.614 .36384 Mdot
.614 .36388 Mdot
.614 .36393 Mdot
.614 .36394 Mdot
.614 .36404 Mdot
.614 .36406 Mdot
.614 .36411 Mdot
.614 .36417 Mdot
.614 .36423 Mdot
.614 .36427 Mdot
.614 .36429 Mdot
.614 .36435 Mdot
.614 .36446 Mdot
.614 .36454 Mdot
.614 .36456 Mdot
.614 .36462 Mdot
.614 .36466 Mdot
.614 .36481 Mdot
.614 .36484 Mdot
.614 .36488 Mdot
.614 .36492 Mdot
.614 .36494 Mdot
.614 .36495 Mdot
.614 .36496 Mdot
.614 .36501 Mdot
.614 .36501 Mdot
.614 .36509 Mdot
.614 .36514 Mdot
.614 .36515 Mdot
.614 .36519 Mdot
.614 .36531 Mdot
.614 .36532 Mdot
.614 .36537 Mdot
.614 .36538 Mdot
.614 .3654 Mdot
.614 .36542 Mdot
.614 .3655 Mdot
.614 .36551 Mdot
.614 .36561 Mdot
.614 .36561 Mdot
.614 .36567 Mdot
.614 .36575 Mdot
.614 .36577 Mdot
.614 .36581 Mdot
.614 .36585 Mdot
.614 .3659 Mdot
.614 .3659 Mdot
.614 .36594 Mdot
.614 .36603 Mdot
.614 .36613 Mdot
.614 .36615 Mdot
.614 .36616 Mdot
.614 .36616 Mdot
.614 .36617 Mdot
.614 .36626 Mdot
.614 .36628 Mdot
.614 .3663 Mdot
.614 .36632 Mdot
.614 .36633 Mdot
.614 .36634 Mdot
.614 .36635 Mdot
.614 .36636 Mdot
.614 .36646 Mdot
.614 .36652 Mdot
.614 .36657 Mdot
.614 .3666 Mdot
.614 .36661 Mdot
.614 .36661 Mdot
.614 .36695 Mdot
.614 .367 Mdot
.614 .36707 Mdot
.614 .36708 Mdot
.614 .3671 Mdot
.614 .36712 Mdot
.614 .36715 Mdot
.614 .36717 Mdot
.614 .3672 Mdot
.614 .36732 Mdot
.614 .36741 Mdot
.614 .36744 Mdot
.614 .36746 Mdot
.614 .36747 Mdot
.614 .36749 Mdot
.614 .36753 Mdot
.614 .36757 Mdot
.614 .36763 Mdot
.614 .36763 Mdot
.614 .36765 Mdot
.614 .36767 Mdot
.614 .36771 Mdot
.614 .36772 Mdot
.614 .36776 Mdot
.614 .36778 Mdot
.614 .36783 Mdot
.614 .36788 Mdot
.614 .3679 Mdot
.614 .36794 Mdot
.614 .36799 Mdot
.614 .36799 Mdot
.614 .368 Mdot
.614 .368 Mdot
.614 .368 Mdot
.614 .36804 Mdot
.614 .36805 Mdot
.614 .36806 Mdot
.614 .36807 Mdot
.614 .36807 Mdot
.614 .36809 Mdot
.614 .36813 Mdot
.614 .36816 Mdot
.614 .36818 Mdot
.614 .36819 Mdot
.614 .36835 Mdot
.614 .36837 Mdot
.614 .3684 Mdot
.614 .3684 Mdot
.614 .36841 Mdot
.614 .36844 Mdot
.614 .36844 Mdot
.614 .36851 Mdot
.614 .36856 Mdot
.614 .36857 Mdot
.614 .36858 Mdot
.614 .36859 Mdot
.614 .3686 Mdot
.614 .36862 Mdot
.614 .36864 Mdot
.614 .36866 Mdot
.614 .3687 Mdot
.614 .36878 Mdot
.614 .3688 Mdot
.614 .36881 Mdot
.614 .36881 Mdot
.614 .36881 Mdot
.614 .36883 Mdot
.614 .36884 Mdot
.614 .36884 Mdot
.614 .36885 Mdot
.614 .36888 Mdot
.614 .36896 Mdot
.614 .36897 Mdot
.614 .36899 Mdot
.614 .36899 Mdot
.614 .369 Mdot
.614 .369 Mdot
.614 .36903 Mdot
.614 .36906 Mdot
.614 .36906 Mdot
.614 .36907 Mdot
.614 .36908 Mdot
.614 .36909 Mdot
.614 .36912 Mdot
.614 .36916 Mdot
.614 .36917 Mdot
.614 .36918 Mdot
.614 .36924 Mdot
.614 .36924 Mdot
.614 .36926 Mdot
.614 .36929 Mdot
.614 .3693 Mdot
.614 .36932 Mdot
.614 .36938 Mdot
.614 .36953 Mdot
.614 .36954 Mdot
.614 .36955 Mdot
.614 .36963 Mdot
.614 .36963 Mdot
.614 .36966 Mdot
.614 .36968 Mdot
.614 .36969 Mdot
.614 .3697 Mdot
.614 .36972 Mdot
.614 .36974 Mdot
.614 .36974 Mdot
.614 .36975 Mdot
.614 .36976 Mdot
.614 .36982 Mdot
.614 .36984 Mdot
.614 .36985 Mdot
.614 .36986 Mdot
.614 .36986 Mdot
.614 .36987 Mdot
.614 .36994 Mdot
.614 .36997 Mdot
.614 .36999 Mdot
.614 .37001 Mdot
.614 .37002 Mdot
.614 .37002 Mdot
.614 .37006 Mdot
.614 .37011 Mdot
.614 .37011 Mdot
.614 .37013 Mdot
.614 .37013 Mdot
.614 .37016 Mdot
.614 .37017 Mdot
.614 .37028 Mdot
.614 .3703 Mdot
.614 .37032 Mdot
.614 .37034 Mdot
.614 .37035 Mdot
.614 .37036 Mdot
.614 .37037 Mdot
.614 .3704 Mdot
.614 .3704 Mdot
.614 .3704 Mdot
.614 .37041 Mdot
.614 .37044 Mdot
.614 .37048 Mdot
.614 .37052 Mdot
.614 .37056 Mdot
.614 .37059 Mdot
.614 .37062 Mdot
.614 .37065 Mdot
.614 .37065 Mdot
.614 .37069 Mdot
.614 .37071 Mdot
.614 .37074 Mdot
.614 .37075 Mdot
.614 .37076 Mdot
.614 .37078 Mdot
.614 .37085 Mdot
.614 .37093 Mdot
.614 .37095 Mdot
.614 .37096 Mdot
.614 .37098 Mdot
.614 .371 Mdot
.614 .37101 Mdot
.614 .37102 Mdot
.614 .37107 Mdot
.614 .3711 Mdot
.614 .37132 Mdot
.614 .37132 Mdot
.614 .37133 Mdot
.614 .37135 Mdot
.614 .37138 Mdot
.614 .37143 Mdot
.614 .37149 Mdot
.614 .37149 Mdot
.614 .3715 Mdot
.614 .37151 Mdot
.614 .37151 Mdot
.614 .37153 Mdot
.614 .37154 Mdot
.614 .37156 Mdot
.614 .37162 Mdot
.614 .37162 Mdot
.614 .37162 Mdot
.614 .37163 Mdot
.614 .37164 Mdot
.614 .37171 Mdot
.614 .37177 Mdot
.614 .3718 Mdot
.614 .3718 Mdot
.614 .37183 Mdot
.614 .37186 Mdot
.614 .37188 Mdot
.614 .37189 Mdot
.614 .37195 Mdot
.614 .37198 Mdot
.614 .37198 Mdot
.614 .37205 Mdot
.614 .37206 Mdot
.614 .37212 Mdot
.614 .37213 Mdot
.614 .37214 Mdot
.614 .37215 Mdot
.614 .37218 Mdot
.614 .37219 Mdot
.614 .37227 Mdot
.614 .37229 Mdot
.614 .3723 Mdot
.614 .37233 Mdot
.614 .37238 Mdot
.614 .37239 Mdot
.614 .37242 Mdot
.614 .37242 Mdot
.614 .37243 Mdot
.614 .37244 Mdot
.614 .37247 Mdot
.614 .3725 Mdot
.614 .37252 Mdot
.614 .37262 Mdot
.614 .37265 Mdot
.614 .37268 Mdot
.614 .37269 Mdot
.614 .37275 Mdot
.614 .37282 Mdot
.614 .37286 Mdot
.614 .37288 Mdot
.614 .3729 Mdot
.614 .37294 Mdot
.614 .37298 Mdot
.614 .37302 Mdot
.614 .37302 Mdot
.614 .37309 Mdot
.614 .3731 Mdot
.614 .37313 Mdot
.614 .37316 Mdot
.614 .37318 Mdot
.614 .37319 Mdot
.614 .3732 Mdot
.614 .37322 Mdot
.614 .37322 Mdot
.614 .37354 Mdot
.614 .3736 Mdot
.614 .37362 Mdot
.614 .37367 Mdot
.614 .37371 Mdot
.614 .37372 Mdot
.614 .37373 Mdot
.614 .37376 Mdot
.614 .37377 Mdot
.614 .37377 Mdot
.614 .3738 Mdot
.614 .37385 Mdot
.614 .37387 Mdot
.614 .37387 Mdot
.614 .37395 Mdot
.614 .3741 Mdot
.614 .3741 Mdot
.614 .37413 Mdot
.614 .37415 Mdot
.614 .37415 Mdot
.614 .37419 Mdot
.614 .37421 Mdot
.614 .37422 Mdot
.614 .37425 Mdot
.614 .37439 Mdot
.614 .37439 Mdot
.614 .3744 Mdot
.614 .3744 Mdot
.614 .37441 Mdot
.614 .37444 Mdot
.614 .37444 Mdot
.614 .37454 Mdot
.614 .37459 Mdot
.614 .37462 Mdot
.614 .37462 Mdot
.614 .37465 Mdot
.614 .3747 Mdot
.614 .37473 Mdot
.614 .37474 Mdot
.614 .37476 Mdot
.614 .37479 Mdot
.614 .3748 Mdot
.614 .37486 Mdot
.614 .37487 Mdot
.614 .37493 Mdot
.614 .37497 Mdot
.614 .37499 Mdot
.614 .375 Mdot
.614 .37501 Mdot
.614 .37514 Mdot
.614 .37515 Mdot
.614 .37522 Mdot
.614 .37522 Mdot
.614 .37537 Mdot
.614 .37539 Mdot
.614 .37552 Mdot
.614 .37554 Mdot
.614 .37558 Mdot
.614 .37559 Mdot
.614 .37566 Mdot
.614 .37568 Mdot
.614 .37586 Mdot
.614 .37587 Mdot
.614 .37588 Mdot
.614 .37592 Mdot
.614 .37592 Mdot
.614 .37594 Mdot
.614 .37594 Mdot
.614 .37597 Mdot
.614 .376 Mdot
.614 .37601 Mdot
.614 .37608 Mdot
.614 .37613 Mdot
.614 .37614 Mdot
.614 .37614 Mdot
.614 .37617 Mdot
.614 .37621 Mdot
.614 .37622 Mdot
.614 .37624 Mdot
.614 .37626 Mdot
.614 .37632 Mdot
.614 .37633 Mdot
.614 .37634 Mdot
.614 .37639 Mdot
.614 .37642 Mdot
.614 .37644 Mdot
.614 .37651 Mdot
.614 .3766 Mdot
.614 .37665 Mdot
.614 .37666 Mdot
.614 .37668 Mdot
.614 .37673 Mdot
.614 .37678 Mdot
.614 .37681 Mdot
.614 .37684 Mdot
.614 .37694 Mdot
.616 .29386 Mdot
.616 .29389 Mdot
.616 .29394 Mdot
.616 .29396 Mdot
.616 .29397 Mdot
.616 .29399 Mdot
.616 .29409 Mdot
.616 .2941 Mdot
.616 .29412 Mdot
.616 .29414 Mdot
.616 .29416 Mdot
.616 .29416 Mdot
.616 .29418 Mdot
.616 .29433 Mdot
.616 .29441 Mdot
.616 .29444 Mdot
.616 .29447 Mdot
.616 .29451 Mdot
.616 .29453 Mdot
.616 .29457 Mdot
.616 .29465 Mdot
.616 .29466 Mdot
.616 .29468 Mdot
.616 .29468 Mdot
.616 .29472 Mdot
.616 .29485 Mdot
.616 .29491 Mdot
.616 .29492 Mdot
.616 .29508 Mdot
.616 .2952 Mdot
.616 .29536 Mdot
.616 .29542 Mdot
.616 .29543 Mdot
.616 .29544 Mdot
.616 .29552 Mdot
.616 .29557 Mdot
.616 .29563 Mdot
.616 .29563 Mdot
.616 .29565 Mdot
.616 .29565 Mdot
.616 .29568 Mdot
.616 .29568 Mdot
.616 .29583 Mdot
.616 .29589 Mdot
.616 .29593 Mdot
.616 .29595 Mdot
.616 .29595 Mdot
.616 .29599 Mdot
.616 .296 Mdot
.616 .29601 Mdot
.616 .29605 Mdot
.616 .29607 Mdot
.616 .29608 Mdot
.616 .29609 Mdot
.616 .29611 Mdot
.616 .29612 Mdot
.616 .29613 Mdot
.616 .29615 Mdot
.616 .29622 Mdot
.616 .29624 Mdot
.616 .29628 Mdot
.616 .29632 Mdot
.616 .29634 Mdot
.616 .29638 Mdot
.616 .29639 Mdot
.616 .2964 Mdot
.616 .29642 Mdot
.616 .29646 Mdot
.616 .29646 Mdot
.616 .29647 Mdot
.616 .29649 Mdot
.616 .2965 Mdot
.616 .29662 Mdot
.616 .29671 Mdot
.616 .29672 Mdot
.616 .29672 Mdot
.616 .29673 Mdot
.616 .29675 Mdot
.616 .29682 Mdot
.616 .29686 Mdot
.616 .29692 Mdot
.616 .29694 Mdot
.616 .29701 Mdot
.616 .29723 Mdot
.616 .29732 Mdot
.616 .29734 Mdot
.616 .29736 Mdot
.616 .29737 Mdot
.616 .2977 Mdot
.616 .29788 Mdot
.616 .29789 Mdot
.616 .29792 Mdot
.616 .29796 Mdot
.616 .29802 Mdot
.616 .29808 Mdot
.616 .29809 Mdot
.616 .29811 Mdot
.616 .29814 Mdot
.616 .29815 Mdot
.616 .29818 Mdot
.616 .29822 Mdot
.616 .29825 Mdot
.616 .29826 Mdot
.616 .29843 Mdot
.616 .29844 Mdot
.616 .29845 Mdot
.616 .29854 Mdot
.616 .29857 Mdot
.616 .29876 Mdot
.616 .29876 Mdot
.616 .29879 Mdot
.616 .29887 Mdot
.616 .29894 Mdot
.616 .29896 Mdot
.616 .29896 Mdot
.616 .29909 Mdot
.616 .29911 Mdot
.616 .29911 Mdot
.616 .29912 Mdot
.616 .29916 Mdot
.616 .29917 Mdot
.616 .29922 Mdot
.616 .29927 Mdot
.616 .29929 Mdot
.616 .2993 Mdot
.616 .29938 Mdot
.616 .29938 Mdot
.616 .29939 Mdot
.616 .29946 Mdot
.616 .29949 Mdot
.616 .29954 Mdot
.616 .29956 Mdot
.616 .2996 Mdot
.616 .29961 Mdot
.616 .29961 Mdot
.616 .29963 Mdot
.616 .29978 Mdot
.616 .29984 Mdot
.616 .29993 Mdot
.616 .29994 Mdot
.616 .29997 Mdot
.616 .3 Mdot
.616 .30002 Mdot
.616 .30003 Mdot
.616 .30004 Mdot
.616 .30011 Mdot
.616 .30013 Mdot
.616 .30015 Mdot
.616 .30016 Mdot
.616 .30016 Mdot
.616 .30018 Mdot
.616 .30018 Mdot
.616 .30019 Mdot
.616 .3002 Mdot
.616 .30022 Mdot
.616 .30023 Mdot
.616 .30023 Mdot
.616 .30024 Mdot
.616 .30028 Mdot
.616 .30031 Mdot
.616 .30035 Mdot
.616 .30035 Mdot
.616 .30036 Mdot
.616 .30038 Mdot
.616 .30039 Mdot
.616 .3004 Mdot
.616 .30049 Mdot
.616 .3005 Mdot
.616 .3005 Mdot
.616 .3005 Mdot
.616 .30054 Mdot
.616 .30062 Mdot
.616 .30072 Mdot
.616 .30076 Mdot
.616 .30076 Mdot
.616 .30078 Mdot
.616 .30092 Mdot
.616 .30098 Mdot
.616 .301 Mdot
.616 .301 Mdot
.616 .30101 Mdot
.616 .30103 Mdot
.616 .30106 Mdot
.616 .30109 Mdot
.616 .30109 Mdot
.616 .30112 Mdot
.616 .30116 Mdot
.616 .30116 Mdot
.616 .30124 Mdot
.616 .30125 Mdot
.616 .30129 Mdot
.616 .3013 Mdot
.616 .30138 Mdot
.616 .30138 Mdot
.616 .30139 Mdot
.616 .30143 Mdot
.616 .30146 Mdot
.616 .30147 Mdot
.616 .30152 Mdot
.616 .30153 Mdot
.616 .30156 Mdot
.616 .3016 Mdot
.616 .30161 Mdot
.616 .30165 Mdot
.616 .30189 Mdot
.616 .30192 Mdot
.616 .30193 Mdot
.616 .30194 Mdot
.616 .30199 Mdot
.616 .302 Mdot
.616 .30202 Mdot
.616 .30202 Mdot
.616 .30204 Mdot
.616 .30207 Mdot
.616 .30207 Mdot
.616 .30209 Mdot
.616 .30213 Mdot
.616 .30213 Mdot
.616 .30214 Mdot
.616 .30226 Mdot
.616 .30235 Mdot
.616 .30239 Mdot
.616 .30256 Mdot
.616 .30258 Mdot
.616 .3026 Mdot
.616 .30261 Mdot
.616 .30275 Mdot
.616 .30276 Mdot
.616 .3028 Mdot
.616 .30283 Mdot
.616 .30294 Mdot
.616 .30312 Mdot
.616 .3032 Mdot
.616 .30331 Mdot
.616 .30335 Mdot
.616 .30337 Mdot
.616 .3034 Mdot
.616 .30341 Mdot
.616 .30345 Mdot
.616 .30352 Mdot
.616 .30369 Mdot
.616 .30376 Mdot
.616 .30378 Mdot
.616 .30381 Mdot
.616 .30392 Mdot
.616 .30407 Mdot
.616 .30422 Mdot
.616 .30425 Mdot
.616 .30428 Mdot
.616 .30431 Mdot
.616 .30431 Mdot
.616 .30435 Mdot
.616 .30435 Mdot
.616 .30436 Mdot
.616 .30438 Mdot
.616 .30456 Mdot
.616 .30457 Mdot
.616 .3046 Mdot
.616 .30462 Mdot
.616 .30466 Mdot
.616 .30466 Mdot
.616 .30471 Mdot
.616 .30481 Mdot
.616 .30486 Mdot
.616 .30491 Mdot
.616 .30494 Mdot
.616 .30496 Mdot
.616 .30511 Mdot
.616 .30512 Mdot
.616 .3053 Mdot
.616 .3053 Mdot
.616 .3053 Mdot
.616 .30536 Mdot
.616 .30539 Mdot
.616 .30539 Mdot
.616 .30544 Mdot
.616 .30547 Mdot
.616 .30547 Mdot
.616 .30547 Mdot
.616 .30551 Mdot
.616 .30551 Mdot
.616 .30552 Mdot
.616 .30552 Mdot
.616 .30555 Mdot
.616 .3056 Mdot
.616 .3056 Mdot
.616 .30561 Mdot
.616 .30563 Mdot
.616 .30564 Mdot
.616 .30566 Mdot
.616 .30567 Mdot
.616 .30591 Mdot
.616 .30596 Mdot
.616 .30598 Mdot
.616 .30602 Mdot
.616 .30603 Mdot
.616 .30609 Mdot
.616 .30611 Mdot
.616 .30614 Mdot
.616 .30617 Mdot
.616 .30621 Mdot
.616 .30621 Mdot
.616 .30623 Mdot
.616 .30631 Mdot
.616 .30632 Mdot
.616 .30637 Mdot
.616 .30642 Mdot
.616 .30644 Mdot
.616 .30644 Mdot
.616 .30657 Mdot
.616 .30659 Mdot
.616 .30664 Mdot
.616 .30666 Mdot
.616 .30677 Mdot
.616 .30677 Mdot
.616 .30684 Mdot
.616 .30688 Mdot
.616 .30689 Mdot
.616 .30693 Mdot
.616 .30697 Mdot
.616 .307 Mdot
.616 .30701 Mdot
.616 .30702 Mdot
.616 .30704 Mdot
.616 .30714 Mdot
.616 .30735 Mdot
.616 .30738 Mdot
.616 .30739 Mdot
.616 .30745 Mdot
.616 .3076 Mdot
.616 .30772 Mdot
.616 .30778 Mdot
.616 .30778 Mdot
.616 .30778 Mdot
.616 .30779 Mdot
.616 .30793 Mdot
.616 .30794 Mdot
.616 .30796 Mdot
.616 .30799 Mdot
.616 .308 Mdot
.616 .30801 Mdot
.616 .30807 Mdot
.616 .30811 Mdot
.616 .30818 Mdot
.616 .30818 Mdot
.616 .30819 Mdot
.616 .3082 Mdot
.616 .30823 Mdot
.616 .30825 Mdot
.616 .30826 Mdot
.616 .30827 Mdot
.616 .30829 Mdot
.616 .30829 Mdot
.616 .3083 Mdot
.616 .30833 Mdot
.616 .30837 Mdot
.616 .30847 Mdot
.616 .30849 Mdot
.616 .30851 Mdot
.616 .30854 Mdot
.616 .30858 Mdot
.616 .30863 Mdot
.616 .30864 Mdot
.616 .30879 Mdot
.616 .30887 Mdot
.616 .3091 Mdot
.616 .30913 Mdot
.616 .30913 Mdot
.616 .30915 Mdot
.616 .3092 Mdot
.616 .30923 Mdot
.616 .30931 Mdot
.616 .30936 Mdot
.616 .30946 Mdot
.616 .30947 Mdot
.616 .30948 Mdot
.616 .30961 Mdot
.616 .30962 Mdot
.616 .30965 Mdot
.616 .30972 Mdot
.616 .30979 Mdot
.616 .30981 Mdot
.616 .30988 Mdot
.616 .30988 Mdot
.616 .3099 Mdot
.616 .30992 Mdot
.616 .31011 Mdot
.616 .31012 Mdot
.616 .31015 Mdot
.616 .31025 Mdot
.616 .31038 Mdot
.616 .31042 Mdot
.616 .31042 Mdot
.616 .31071 Mdot
.616 .31075 Mdot
.616 .31089 Mdot
.616 .3109 Mdot
.616 .31092 Mdot
.616 .31118 Mdot
.616 .31119 Mdot
.616 .31123 Mdot
.616 .31129 Mdot
.616 .31134 Mdot
.616 .31136 Mdot
.616 .31141 Mdot
.616 .31144 Mdot
.616 .31144 Mdot
.616 .31154 Mdot
.616 .31163 Mdot
.616 .3117 Mdot
.616 .31174 Mdot
.616 .31175 Mdot
.616 .31203 Mdot
.616 .31252 Mdot
.616 .31254 Mdot
.616 .31257 Mdot
.616 .3126 Mdot
.616 .31274 Mdot
.616 .31308 Mdot
.616 .31319 Mdot
.616 .31322 Mdot
.616 .3133 Mdot
.616 .31336 Mdot
.616 .31347 Mdot
.616 .3135 Mdot
.616 .31351 Mdot
.616 .31351 Mdot
.616 .31352 Mdot
.616 .31366 Mdot
.616 .31386 Mdot
.616 .31387 Mdot
.616 .31389 Mdot
.616 .3139 Mdot
.616 .31392 Mdot
.616 .31397 Mdot
.616 .314 Mdot
.616 .31402 Mdot
.616 .31403 Mdot
.616 .3141 Mdot
.616 .31412 Mdot
.616 .31418 Mdot
.616 .31424 Mdot
.616 .31427 Mdot
.616 .31437 Mdot
.616 .31442 Mdot
.616 .31443 Mdot
.616 .31444 Mdot
.616 .31447 Mdot
.616 .31448 Mdot
.616 .3145 Mdot
.616 .31453 Mdot
.616 .31459 Mdot
.616 .31462 Mdot
.616 .31462 Mdot
.616 .31468 Mdot
.616 .31469 Mdot
.616 .31471 Mdot
.616 .31478 Mdot
.616 .31486 Mdot
.616 .3151 Mdot
.616 .3151 Mdot
.616 .31513 Mdot
.616 .31513 Mdot
.616 .31517 Mdot
.616 .31517 Mdot
.616 .31526 Mdot
.616 .31534 Mdot
.616 .31545 Mdot
.616 .31548 Mdot
.616 .31549 Mdot
.616 .31558 Mdot
.616 .31582 Mdot
.616 .31601 Mdot
.616 .31625 Mdot
.616 .31626 Mdot
.616 .31635 Mdot
.616 .31655 Mdot
.616 .31661 Mdot
.616 .31661 Mdot
.616 .31664 Mdot
.616 .31665 Mdot
.616 .31678 Mdot
.616 .31684 Mdot
.616 .31687 Mdot
.616 .31694 Mdot
.616 .31697 Mdot
.616 .31702 Mdot
.616 .31714 Mdot
.616 .31737 Mdot
.616 .3174 Mdot
.616 .3174 Mdot
.616 .31743 Mdot
.616 .31746 Mdot
.616 .31749 Mdot
.616 .3175 Mdot
.616 .31766 Mdot
.616 .31769 Mdot
.616 .31771 Mdot
.616 .31774 Mdot
.616 .31781 Mdot
.616 .31786 Mdot
.616 .35862 Mdot
.616 .35866 Mdot
.616 .35871 Mdot
.616 .35874 Mdot
.616 .35875 Mdot
.616 .35878 Mdot
.616 .35891 Mdot
.616 .35892 Mdot
.616 .35894 Mdot
.616 .35897 Mdot
.616 .35899 Mdot
.616 .359 Mdot
.616 .35901 Mdot
.616 .3592 Mdot
.616 .3593 Mdot
.616 .35934 Mdot
.616 .35937 Mdot
.616 .35942 Mdot
.616 .35945 Mdot
.616 .3595 Mdot
.616 .3596 Mdot
.616 .35961 Mdot
.616 .35963 Mdot
.616 .35964 Mdot
.616 .35968 Mdot
.616 .35984 Mdot
.616 .35992 Mdot
.616 .35993 Mdot
.616 .36012 Mdot
.616 .36027 Mdot
.616 .36047 Mdot
.616 .36054 Mdot
.616 .36055 Mdot
.616 .36057 Mdot
.616 .36066 Mdot
.616 .36073 Mdot
.616 .3608 Mdot
.616 .3608 Mdot
.616 .36083 Mdot
.616 .36083 Mdot
.616 .36086 Mdot
.616 .36086 Mdot
.616 .36105 Mdot
.616 .36112 Mdot
.616 .36118 Mdot
.616 .36119 Mdot
.616 .3612 Mdot
.616 .36125 Mdot
.616 .36125 Mdot
.616 .36127 Mdot
.616 .36132 Mdot
.616 .36134 Mdot
.616 .36136 Mdot
.616 .36137 Mdot
.616 .3614 Mdot
.616 .3614 Mdot
.616 .36141 Mdot
.616 .36145 Mdot
.616 .36153 Mdot
.616 .36156 Mdot
.616 .36161 Mdot
.616 .36165 Mdot
.616 .36167 Mdot
.616 .36173 Mdot
.616 .36174 Mdot
.616 .36175 Mdot
.616 .36178 Mdot
.616 .36182 Mdot
.616 .36183 Mdot
.616 .36184 Mdot
.616 .36186 Mdot
.616 .36187 Mdot
.616 .36203 Mdot
.616 .36214 Mdot
.616 .36215 Mdot
.616 .36215 Mdot
.616 .36215 Mdot
.616 .36218 Mdot
.616 .36227 Mdot
.616 .36232 Mdot
.616 .36239 Mdot
.616 .36241 Mdot
.616 .3625 Mdot
.616 .36277 Mdot
.616 .36289 Mdot
.616 .36291 Mdot
.616 .36293 Mdot
.616 .36295 Mdot
.616 .36335 Mdot
.616 .36358 Mdot
.616 .36359 Mdot
.616 .36362 Mdot
.616 .36368 Mdot
.616 .36374 Mdot
.616 .36383 Mdot
.616 .36383 Mdot
.616 .36385 Mdot
.616 .3639 Mdot
.616 .36391 Mdot
.616 .36395 Mdot
.616 .364 Mdot
.616 .36404 Mdot
.616 .36404 Mdot
.616 .36425 Mdot
.616 .36426 Mdot
.616 .36428 Mdot
.616 .36439 Mdot
.616 .36442 Mdot
.616 .36466 Mdot
.616 .36466 Mdot
.616 .36469 Mdot
.616 .36479 Mdot
.616 .36488 Mdot
.616 .3649 Mdot
.616 .36491 Mdot
.616 .36506 Mdot
.616 .36508 Mdot
.616 .36509 Mdot
.616 .3651 Mdot
.616 .36516 Mdot
.616 .36517 Mdot
.616 .36523 Mdot
.616 .36528 Mdot
.616 .36531 Mdot
.616 .36532 Mdot
.616 .36542 Mdot
.616 .36543 Mdot
.616 .36544 Mdot
.616 .36552 Mdot
.616 .36556 Mdot
.616 .36562 Mdot
.616 .36565 Mdot
.616 .36569 Mdot
.616 .36571 Mdot
.616 .36571 Mdot
.616 .36573 Mdot
.616 .36592 Mdot
.616 .36598 Mdot
.616 .3661 Mdot
.616 .36611 Mdot
.616 .36615 Mdot
.616 .36618 Mdot
.616 .36621 Mdot
.616 .36623 Mdot
.616 .36624 Mdot
.616 .36632 Mdot
.616 .36635 Mdot
.616 .36638 Mdot
.616 .36638 Mdot
.616 .36639 Mdot
.616 .36641 Mdot
.616 .36641 Mdot
.616 .36642 Mdot
.616 .36644 Mdot
.616 .36646 Mdot
.616 .36647 Mdot
.616 .36647 Mdot
.616 .36648 Mdot
.616 .36653 Mdot
.616 .36656 Mdot
.616 .36662 Mdot
.616 .36662 Mdot
.616 .36663 Mdot
.616 .36666 Mdot
.616 .36667 Mdot
.616 .36668 Mdot
.616 .36679 Mdot
.616 .3668 Mdot
.616 .3668 Mdot
.616 .3668 Mdot
.616 .36685 Mdot
.616 .36695 Mdot
.616 .36707 Mdot
.616 .36712 Mdot
.616 .36713 Mdot
.616 .36715 Mdot
.616 .36732 Mdot
.616 .3674 Mdot
.616 .36742 Mdot
.616 .36742 Mdot
.616 .36744 Mdot
.616 .36746 Mdot
.616 .36749 Mdot
.616 .36753 Mdot
.616 .36753 Mdot
.616 .36756 Mdot
.616 .36762 Mdot
.616 .36762 Mdot
.616 .36771 Mdot
.616 .36772 Mdot
.616 .36777 Mdot
.616 .36778 Mdot
.616 .36789 Mdot
.616 .36789 Mdot
.616 .3679 Mdot
.616 .36795 Mdot
.616 .36798 Mdot
.616 .368 Mdot
.616 .36806 Mdot
.616 .36807 Mdot
.616 .36808 Mdot
.616 .36811 Mdot
.616 .36813 Mdot
.616 .36816 Mdot
.616 .36817 Mdot
.616 .36822 Mdot
.616 .36822 Mdot
.616 .36826 Mdot
.616 .36828 Mdot
.616 .36832 Mdot
.616 .36851 Mdot
.616 .36852 Mdot
.616 .36854 Mdot
.616 .36855 Mdot
.616 .36856 Mdot
.616 .36857 Mdot
.616 .36857 Mdot
.616 .36861 Mdot
.616 .36864 Mdot
.616 .36864 Mdot
.616 .36865 Mdot
.616 .36865 Mdot
.616 .36867 Mdot
.616 .36868 Mdot
.616 .36868 Mdot
.616 .3687 Mdot
.616 .36874 Mdot
.616 .36874 Mdot
.616 .36876 Mdot
.616 .36881 Mdot
.616 .36882 Mdot
.616 .36882 Mdot
.616 .36896 Mdot
.616 .36897 Mdot
.616 .36909 Mdot
.616 .3691 Mdot
.616 .36913 Mdot
.616 .36917 Mdot
.616 .36921 Mdot
.616 .36929 Mdot
.616 .36933 Mdot
.616 .36934 Mdot
.616 .36936 Mdot
.616 .36938 Mdot
.616 .36941 Mdot
.616 .36941 Mdot
.616 .36956 Mdot
.616 .36958 Mdot
.616 .36958 Mdot
.616 .36959 Mdot
.616 .36961 Mdot
.616 .36962 Mdot
.616 .36964 Mdot
.616 .36967 Mdot
.616 .36969 Mdot
.616 .36981 Mdot
.616 .36993 Mdot
.616 .37003 Mdot
.616 .37005 Mdot
.616 .37006 Mdot
.616 .37012 Mdot
.616 .37026 Mdot
.616 .37032 Mdot
.616 .37034 Mdot
.616 .37035 Mdot
.616 .37038 Mdot
.616 .37039 Mdot
.616 .37043 Mdot
.616 .37052 Mdot
.616 .37059 Mdot
.616 .37073 Mdot
.616 .37082 Mdot
.616 .37084 Mdot
.616 .37088 Mdot
.616 .37088 Mdot
.616 .37099 Mdot
.616 .37101 Mdot
.616 .37102 Mdot
.616 .37104 Mdot
.616 .37117 Mdot
.616 .3712 Mdot
.616 .37128 Mdot
.616 .37138 Mdot
.616 .37138 Mdot
.616 .37138 Mdot
.616 .37142 Mdot
.616 .37143 Mdot
.616 .37143 Mdot
.616 .37146 Mdot
.616 .37147 Mdot
.616 .37148 Mdot
.616 .3715 Mdot
.616 .3715 Mdot
.616 .37154 Mdot
.616 .37155 Mdot
.616 .37156 Mdot
.616 .37158 Mdot
.616 .37177 Mdot
.616 .37181 Mdot
.616 .37182 Mdot
.616 .37185 Mdot
.616 .37187 Mdot
.616 .37188 Mdot
.616 .37192 Mdot
.616 .37193 Mdot
.616 .37196 Mdot
.616 .37198 Mdot
.616 .37199 Mdot
.616 .372 Mdot
.616 .37206 Mdot
.616 .37207 Mdot
.616 .3721 Mdot
.616 .37211 Mdot
.616 .37217 Mdot
.616 .37217 Mdot
.616 .37221 Mdot
.616 .37223 Mdot
.616 .37223 Mdot
.616 .37226 Mdot
.616 .37228 Mdot
.616 .37229 Mdot
.616 .3723 Mdot
.616 .3723 Mdot
.616 .37232 Mdot
.616 .37237 Mdot
.616 .37248 Mdot
.616 .37249 Mdot
.616 .3725 Mdot
.616 .37253 Mdot
.616 .37261 Mdot
.616 .37268 Mdot
.616 .37271 Mdot
.616 .37271 Mdot
.616 .37271 Mdot
.616 .37272 Mdot
.616 .37279 Mdot
.616 .3728 Mdot
.616 .37281 Mdot
.616 .37283 Mdot
.616 .37283 Mdot
.616 .37283 Mdot
.616 .37287 Mdot
.616 .37289 Mdot
.616 .37292 Mdot
.616 .37293 Mdot
.616 .37293 Mdot
.616 .37293 Mdot
.616 .37295 Mdot
.616 .37296 Mdot
.616 .37297 Mdot
.616 .37297 Mdot
.616 .37298 Mdot
.616 .37299 Mdot
.616 .37299 Mdot
.616 .37301 Mdot
.616 .37303 Mdot
.616 .37308 Mdot
.616 .37309 Mdot
.616 .3731 Mdot
.616 .37312 Mdot
.616 .37314 Mdot
.616 .37316 Mdot
.616 .37317 Mdot
.616 .37325 Mdot
.616 .37342 Mdot
.616 .37343 Mdot
.616 .37343 Mdot
.616 .37344 Mdot
.616 .37347 Mdot
.616 .37349 Mdot
.616 .37353 Mdot
.616 .37356 Mdot
.616 .37361 Mdot
.616 .37362 Mdot
.616 .37362 Mdot
.616 .37369 Mdot
.616 .37369 Mdot
.616 .37371 Mdot
.616 .37375 Mdot
.616 .37379 Mdot
.616 .37379 Mdot
.616 .37383 Mdot
.616 .37384 Mdot
.616 .37384 Mdot
.616 .37386 Mdot
.616 .37396 Mdot
.616 .37396 Mdot
.616 .37398 Mdot
.616 .37403 Mdot
.616 .3741 Mdot
.616 .37412 Mdot
.616 .37412 Mdot
.616 .37428 Mdot
.616 .3743 Mdot
.616 .37437 Mdot
.616 .37438 Mdot
.616 .37439 Mdot
.616 .37453 Mdot
.616 .37453 Mdot
.616 .37456 Mdot
.616 .37459 Mdot
.616 .37462 Mdot
.616 .37462 Mdot
.616 .37465 Mdot
.616 .37467 Mdot
.616 .37467 Mdot
.616 .37472 Mdot
.616 .37477 Mdot
.616 .37481 Mdot
.616 .37483 Mdot
.616 .37483 Mdot
.616 .37498 Mdot
.616 .37525 Mdot
.616 .37526 Mdot
.616 .37527 Mdot
.616 .37529 Mdot
.616 .37536 Mdot
.616 .37555 Mdot
.616 .3756 Mdot
.616 .37562 Mdot
.616 .37566 Mdot
.616 .37569 Mdot
.616 .37575 Mdot
.616 .37577 Mdot
.616 .37578 Mdot
.616 .37578 Mdot
.616 .37578 Mdot
.616 .37586 Mdot
.616 .37596 Mdot
.616 .37597 Mdot
.616 .37598 Mdot
.616 .37598 Mdot
.616 .37599 Mdot
.616 .37602 Mdot
.616 .37604 Mdot
.616 .37605 Mdot
.616 .37605 Mdot
.616 .37609 Mdot
.616 .3761 Mdot
.616 .37613 Mdot
.616 .37617 Mdot
.616 .37618 Mdot
.616 .37624 Mdot
.616 .37626 Mdot
.616 .37627 Mdot
.616 .37627 Mdot
.616 .37629 Mdot
.616 .3763 Mdot
.616 .37631 Mdot
.616 .37632 Mdot
.616 .37635 Mdot
.616 .37637 Mdot
.616 .37637 Mdot
.616 .3764 Mdot
.616 .3764 Mdot
.616 .37642 Mdot
.616 .37645 Mdot
.616 .3765 Mdot
.616 .37662 Mdot
.616 .37663 Mdot
.616 .37664 Mdot
.616 .37664 Mdot
.616 .37666 Mdot
.616 .37667 Mdot
.616 .37671 Mdot
.616 .37676 Mdot
.616 .37681 Mdot
.616 .37683 Mdot
.616 .37683 Mdot
.616 .37688 Mdot
.616 .37701 Mdot
.616 .37711 Mdot
.616 .37724 Mdot
.616 .37724 Mdot
.616 .3773 Mdot
.616 .3774 Mdot
.616 .37743 Mdot
.616 .37743 Mdot
.616 .37745 Mdot
.616 .37746 Mdot
.616 .37752 Mdot
.616 .37756 Mdot
.616 .37757 Mdot
.616 .37761 Mdot
.616 .37763 Mdot
.616 .37765 Mdot
.616 .37772 Mdot
.616 .37784 Mdot
.616 .37785 Mdot
.616 .37786 Mdot
.616 .37787 Mdot
.616 .37789 Mdot
.616 .3779 Mdot
.616 .37791 Mdot
.616 .378 Mdot
.616 .37801 Mdot
.616 .37802 Mdot
.616 .37804 Mdot
.616 .37808 Mdot
.616 .3781 Mdot
.618 .2933 Mdot
.618 .29331 Mdot
.618 .29331 Mdot
.618 .29338 Mdot
.618 .29343 Mdot
.618 .2935 Mdot
.618 .29354 Mdot
.618 .29363 Mdot
.618 .29374 Mdot
.618 .29375 Mdot
.618 .2938 Mdot
.618 .29382 Mdot
.618 .29383 Mdot
.618 .29389 Mdot
.618 .29392 Mdot
.618 .29398 Mdot
.618 .294 Mdot
.618 .29409 Mdot
.618 .2942 Mdot
.618 .2942 Mdot
.618 .29424 Mdot
.618 .29434 Mdot
.618 .29436 Mdot
.618 .29436 Mdot
.618 .29443 Mdot
.618 .29448 Mdot
.618 .29451 Mdot
.618 .29452 Mdot
.618 .29454 Mdot
.618 .29463 Mdot
.618 .29469 Mdot
.618 .29477 Mdot
.618 .29479 Mdot
.618 .29479 Mdot
.618 .29486 Mdot
.618 .2949 Mdot
.618 .29491 Mdot
.618 .29495 Mdot
.618 .29498 Mdot
.618 .29512 Mdot
.618 .2952 Mdot
.618 .29521 Mdot
.618 .29525 Mdot
.618 .2953 Mdot
.618 .29537 Mdot
.618 .2954 Mdot
.618 .2954 Mdot
.618 .29541 Mdot
.618 .29542 Mdot
.618 .29543 Mdot
.618 .29546 Mdot
.618 .29555 Mdot
.618 .29558 Mdot
.618 .29559 Mdot
.618 .29584 Mdot
.618 .29587 Mdot
.618 .29592 Mdot
.618 .29597 Mdot
.618 .29601 Mdot
.618 .29601 Mdot
.618 .29602 Mdot
.618 .29603 Mdot
.618 .29608 Mdot
.618 .29609 Mdot
.618 .29609 Mdot
.618 .29617 Mdot
.618 .29623 Mdot
.618 .29631 Mdot
.618 .29646 Mdot
.618 .29647 Mdot
.618 .29649 Mdot
.618 .29651 Mdot
.618 .29652 Mdot
.618 .29665 Mdot
.618 .29669 Mdot
.618 .29673 Mdot
.618 .29676 Mdot
.618 .29682 Mdot
.618 .29682 Mdot
.618 .29687 Mdot
.618 .2969 Mdot
.618 .2969 Mdot
.618 .29703 Mdot
.618 .29703 Mdot
.618 .29733 Mdot
.618 .29748 Mdot
.618 .29764 Mdot
.618 .29773 Mdot
.618 .29774 Mdot
.618 .29802 Mdot
.618 .29803 Mdot
.618 .29804 Mdot
.618 .29811 Mdot
.618 .29811 Mdot
.618 .29821 Mdot
.618 .29822 Mdot
.618 .29824 Mdot
.618 .29824 Mdot
.618 .29826 Mdot
.618 .29829 Mdot
.618 .2983 Mdot
.618 .29833 Mdot
.618 .29836 Mdot
.618 .29842 Mdot
.618 .29848 Mdot
.618 .29853 Mdot
.618 .29854 Mdot
.618 .29863 Mdot
.618 .29866 Mdot
.618 .2987 Mdot
.618 .29892 Mdot
.618 .29895 Mdot
.618 .29896 Mdot
.618 .29899 Mdot
.618 .29901 Mdot
.618 .29904 Mdot
.618 .29906 Mdot
.618 .2991 Mdot
.618 .29914 Mdot
.618 .29915 Mdot
.618 .29917 Mdot
.618 .29918 Mdot
.618 .29921 Mdot
.618 .29925 Mdot
.618 .2993 Mdot
.618 .29934 Mdot
.618 .29941 Mdot
.618 .29941 Mdot
.618 .29944 Mdot
.618 .29948 Mdot
.618 .29948 Mdot
.618 .29949 Mdot
.618 .29959 Mdot
.618 .29974 Mdot
.618 .29979 Mdot
.618 .29981 Mdot
.618 .29986 Mdot
.618 .29986 Mdot
.618 .29987 Mdot
.618 .29988 Mdot
.618 .29992 Mdot
.618 .29993 Mdot
.618 .29994 Mdot
.618 .30005 Mdot
.618 .30006 Mdot
.618 .30008 Mdot
.618 .3001 Mdot
.618 .30012 Mdot
.618 .30012 Mdot
.618 .30012 Mdot
.618 .30013 Mdot
.618 .30015 Mdot
.618 .30019 Mdot
.618 .30021 Mdot
.618 .30031 Mdot
.618 .30031 Mdot
.618 .30032 Mdot
.618 .30033 Mdot
.618 .30034 Mdot
.618 .30039 Mdot
.618 .30043 Mdot
.618 .30044 Mdot
.618 .30046 Mdot
.618 .30047 Mdot
.618 .30048 Mdot
.618 .3005 Mdot
.618 .3005 Mdot
.618 .30055 Mdot
.618 .30068 Mdot
.618 .30075 Mdot
.618 .30082 Mdot
.618 .30098 Mdot
.618 .30102 Mdot
.618 .30107 Mdot
.618 .30108 Mdot
.618 .30111 Mdot
.618 .30118 Mdot
.618 .30125 Mdot
.618 .3014 Mdot
.618 .30146 Mdot
.618 .30146 Mdot
.618 .30147 Mdot
.618 .30148 Mdot
.618 .30149 Mdot
.618 .30151 Mdot
.618 .30153 Mdot
.618 .30155 Mdot
.618 .3016 Mdot
.618 .3016 Mdot
.618 .30161 Mdot
.618 .30174 Mdot
.618 .30177 Mdot
.618 .30177 Mdot
.618 .30178 Mdot
.618 .30188 Mdot
.618 .30189 Mdot
.618 .30191 Mdot
.618 .30196 Mdot
.618 .30197 Mdot
.618 .30197 Mdot
.618 .30199 Mdot
.618 .30201 Mdot
.618 .30203 Mdot
.618 .30203 Mdot
.618 .30204 Mdot
.618 .30206 Mdot
.618 .30215 Mdot
.618 .30218 Mdot
.618 .30225 Mdot
.618 .30226 Mdot
.618 .30236 Mdot
.618 .30246 Mdot
.618 .30252 Mdot
.618 .30257 Mdot
.618 .30259 Mdot
.618 .30259 Mdot
.618 .30264 Mdot
.618 .30264 Mdot
.618 .30267 Mdot
.618 .30269 Mdot
.618 .3027 Mdot
.618 .30271 Mdot
.618 .30275 Mdot
.618 .30279 Mdot
.618 .30284 Mdot
.618 .30296 Mdot
.618 .30296 Mdot
.618 .30298 Mdot
.618 .30301 Mdot
.618 .30304 Mdot
.618 .30313 Mdot
.618 .30317 Mdot
.618 .30318 Mdot
.618 .30319 Mdot
.618 .30319 Mdot
.618 .3032 Mdot
.618 .3032 Mdot
.618 .3032 Mdot
.618 .3032 Mdot
.618 .30322 Mdot
.618 .30324 Mdot
.618 .3033 Mdot
.618 .30334 Mdot
.618 .30343 Mdot
.618 .30349 Mdot
.618 .30352 Mdot
.618 .30353 Mdot
.618 .30356 Mdot
.618 .30356 Mdot
.618 .3036 Mdot
.618 .30361 Mdot
.618 .30368 Mdot
.618 .30374 Mdot
.618 .30381 Mdot
.618 .30382 Mdot
.618 .30388 Mdot
.618 .30394 Mdot
.618 .30395 Mdot
.618 .30396 Mdot
.618 .30396 Mdot
.618 .30397 Mdot
.618 .304 Mdot
.618 .30401 Mdot
.618 .30404 Mdot
.618 .30405 Mdot
.618 .30413 Mdot
.618 .30413 Mdot
.618 .30415 Mdot
.618 .30424 Mdot
.618 .30424 Mdot
.618 .30432 Mdot
.618 .30433 Mdot
.618 .30433 Mdot
.618 .30447 Mdot
.618 .30459 Mdot
.618 .30462 Mdot
.618 .30465 Mdot
.618 .30476 Mdot
.618 .3048 Mdot
.618 .30484 Mdot
.618 .30493 Mdot
.618 .30496 Mdot
.618 .30497 Mdot
.618 .30498 Mdot
.618 .30499 Mdot
.618 .30501 Mdot
.618 .30503 Mdot
.618 .30507 Mdot
.618 .30507 Mdot
.618 .30508 Mdot
.618 .30508 Mdot
.618 .30517 Mdot
.618 .30519 Mdot
.618 .30521 Mdot
.618 .30521 Mdot
.618 .30521 Mdot
.618 .30526 Mdot
.618 .30537 Mdot
.618 .30538 Mdot
.618 .30538 Mdot
.618 .30538 Mdot
.618 .30541 Mdot
.618 .30543 Mdot
.618 .30562 Mdot
.618 .30563 Mdot
.618 .30563 Mdot
.618 .30566 Mdot
.618 .30572 Mdot
.618 .30575 Mdot
.618 .30578 Mdot
.618 .30581 Mdot
.618 .30583 Mdot
.618 .30583 Mdot
.618 .30585 Mdot
.618 .30585 Mdot
.618 .30588 Mdot
.618 .30594 Mdot
.618 .30597 Mdot
.618 .30614 Mdot
.618 .30617 Mdot
.618 .30624 Mdot
.618 .30628 Mdot
.618 .30638 Mdot
.618 .3064 Mdot
.618 .30641 Mdot
.618 .30643 Mdot
.618 .30644 Mdot
.618 .30644 Mdot
.618 .30653 Mdot
.618 .30659 Mdot
.618 .30683 Mdot
.618 .30694 Mdot
.618 .30704 Mdot
.618 .30723 Mdot
.618 .30732 Mdot
.618 .30732 Mdot
.618 .30734 Mdot
.618 .30737 Mdot
.618 .30737 Mdot
.618 .30741 Mdot
.618 .30743 Mdot
.618 .30749 Mdot
.618 .30757 Mdot
.618 .30758 Mdot
.618 .30759 Mdot
.618 .3076 Mdot
.618 .30761 Mdot
.618 .30776 Mdot
.618 .3078 Mdot
.618 .30785 Mdot
.618 .30789 Mdot
.618 .30789 Mdot
.618 .3079 Mdot
.618 .3079 Mdot
.618 .30793 Mdot
.618 .30796 Mdot
.618 .30799 Mdot
.618 .30801 Mdot
.618 .30817 Mdot
.618 .30818 Mdot
.618 .3082 Mdot
.618 .30826 Mdot
.618 .30828 Mdot
.618 .30829 Mdot
.618 .3083 Mdot
.618 .30837 Mdot
.618 .3084 Mdot
.618 .30848 Mdot
.618 .3087 Mdot
.618 .30886 Mdot
.618 .30888 Mdot
.618 .30888 Mdot
.618 .30894 Mdot
.618 .30898 Mdot
.618 .30898 Mdot
.618 .30909 Mdot
.618 .30916 Mdot
.618 .30923 Mdot
.618 .30929 Mdot
.618 .30933 Mdot
.618 .30935 Mdot
.618 .30938 Mdot
.618 .30939 Mdot
.618 .30946 Mdot
.618 .30952 Mdot
.618 .30954 Mdot
.618 .30959 Mdot
.618 .30962 Mdot
.618 .30967 Mdot
.618 .30968 Mdot
.618 .30973 Mdot
.618 .31006 Mdot
.618 .31012 Mdot
.618 .31018 Mdot
.618 .31031 Mdot
.618 .31033 Mdot
.618 .3104 Mdot
.618 .31049 Mdot
.618 .31059 Mdot
.618 .31063 Mdot
.618 .31068 Mdot
.618 .31069 Mdot
.618 .31074 Mdot
.618 .31076 Mdot
.618 .31077 Mdot
.618 .3108 Mdot
.618 .31082 Mdot
.618 .31096 Mdot
.618 .31097 Mdot
.618 .31107 Mdot
.618 .31109 Mdot
.618 .31111 Mdot
.618 .31154 Mdot
.618 .31154 Mdot
.618 .31169 Mdot
.618 .31194 Mdot
.618 .31216 Mdot
.618 .31262 Mdot
.618 .31262 Mdot
.618 .31281 Mdot
.618 .31282 Mdot
.618 .31287 Mdot
.618 .31293 Mdot
.618 .31294 Mdot
.618 .31303 Mdot
.618 .31307 Mdot
.618 .31314 Mdot
.618 .31321 Mdot
.618 .3134 Mdot
.618 .31342 Mdot
.618 .31344 Mdot
.618 .31348 Mdot
.618 .31349 Mdot
.618 .31372 Mdot
.618 .31384 Mdot
.618 .31393 Mdot
.618 .31405 Mdot
.618 .31406 Mdot
.618 .31406 Mdot
.618 .31414 Mdot
.618 .31416 Mdot
.618 .31417 Mdot
.618 .31418 Mdot
.618 .31424 Mdot
.618 .31431 Mdot
.618 .31439 Mdot
.618 .31443 Mdot
.618 .31481 Mdot
.618 .31483 Mdot
.618 .31487 Mdot
.618 .31502 Mdot
.618 .31506 Mdot
.618 .31507 Mdot
.618 .31509 Mdot
.618 .3151 Mdot
.618 .31512 Mdot
.618 .31515 Mdot
.618 .31526 Mdot
.618 .31533 Mdot
.618 .31539 Mdot
.618 .31541 Mdot
.618 .31553 Mdot
.618 .31575 Mdot
.618 .3158 Mdot
.618 .31585 Mdot
.618 .31588 Mdot
.618 .31593 Mdot
.618 .31604 Mdot
.618 .31604 Mdot
.618 .31607 Mdot
.618 .3162 Mdot
.618 .31629 Mdot
.618 .31641 Mdot
.618 .31646 Mdot
.618 .31646 Mdot
.618 .31651 Mdot
.618 .3166 Mdot
.618 .31669 Mdot
.618 .3167 Mdot
.618 .31673 Mdot
.618 .31688 Mdot
.618 .31694 Mdot
.618 .31694 Mdot
.618 .31711 Mdot
.618 .31725 Mdot
.618 .31727 Mdot
.618 .31737 Mdot
.618 .31742 Mdot
.618 .31751 Mdot
.618 .31752 Mdot
.618 .31755 Mdot
.618 .31763 Mdot
.618 .31765 Mdot
.618 .31781 Mdot
.618 .31795 Mdot
.618 .31801 Mdot
.618 .31812 Mdot
.618 .31819 Mdot
.618 .31829 Mdot
.618 .3183 Mdot
.618 .31832 Mdot
.618 .35904 Mdot
.618 .35906 Mdot
.618 .35906 Mdot
.618 .35915 Mdot
.618 .3592 Mdot
.618 .35929 Mdot
.618 .35934 Mdot
.618 .35946 Mdot
.618 .35959 Mdot
.618 .3596 Mdot
.618 .35967 Mdot
.618 .35969 Mdot
.618 .3597 Mdot
.618 .35977 Mdot
.618 .35981 Mdot
.618 .35989 Mdot
.618 .35991 Mdot
.618 .36003 Mdot
.618 .36016 Mdot
.618 .36016 Mdot
.618 .36021 Mdot
.618 .36033 Mdot
.618 .36036 Mdot
.618 .36036 Mdot
.618 .36044 Mdot
.618 .36051 Mdot
.618 .36054 Mdot
.618 .36055 Mdot
.618 .36058 Mdot
.618 .36069 Mdot
.618 .36076 Mdot
.618 .36086 Mdot
.618 .36089 Mdot
.618 .36089 Mdot
.618 .36098 Mdot
.618 .36102 Mdot
.618 .36104 Mdot
.618 .36108 Mdot
.618 .36112 Mdot
.618 .3613 Mdot
.618 .3614 Mdot
.618 .36141 Mdot
.618 .36146 Mdot
.618 .36152 Mdot
.618 .36161 Mdot
.618 .36164 Mdot
.618 .36165 Mdot
.618 .36166 Mdot
.618 .36167 Mdot
.618 .36168 Mdot
.618 .36171 Mdot
.618 .36183 Mdot
.618 .36186 Mdot
.618 .36188 Mdot
.618 .36219 Mdot
.618 .36222 Mdot
.618 .36229 Mdot
.618 .36234 Mdot
.618 .36239 Mdot
.618 .3624 Mdot
.618 .36241 Mdot
.618 .36242 Mdot
.618 .36249 Mdot
.618 .36249 Mdot
.618 .3625 Mdot
.618 .36259 Mdot
.618 .36267 Mdot
.618 .36277 Mdot
.618 .36295 Mdot
.618 .36296 Mdot
.618 .36299 Mdot
.618 .36301 Mdot
.618 .36302 Mdot
.618 .36318 Mdot
.618 .36324 Mdot
.618 .36329 Mdot
.618 .36332 Mdot
.618 .3634 Mdot
.618 .3634 Mdot
.618 .36345 Mdot
.618 .36349 Mdot
.618 .3635 Mdot
.618 .36365 Mdot
.618 .36365 Mdot
.618 .36403 Mdot
.618 .36421 Mdot
.618 .36441 Mdot
.618 .36453 Mdot
.618 .36453 Mdot
.618 .36487 Mdot
.618 .36489 Mdot
.618 .36491 Mdot
.618 .36499 Mdot
.618 .36499 Mdot
.618 .36511 Mdot
.618 .36513 Mdot
.618 .36515 Mdot
.618 .36516 Mdot
.618 .36518 Mdot
.618 .36521 Mdot
.618 .36522 Mdot
.618 .36527 Mdot
.618 .3653 Mdot
.618 .36538 Mdot
.618 .36545 Mdot
.618 .3655 Mdot
.618 .36552 Mdot
.618 .36563 Mdot
.618 .36567 Mdot
.618 .36572 Mdot
.618 .366 Mdot
.618 .36604 Mdot
.618 .36604 Mdot
.618 .36608 Mdot
.618 .3661 Mdot
.618 .36614 Mdot
.618 .36616 Mdot
.618 .36621 Mdot
.618 .36627 Mdot
.618 .36628 Mdot
.618 .3663 Mdot
.618 .36631 Mdot
.618 .36635 Mdot
.618 .3664 Mdot
.618 .36646 Mdot
.618 .36651 Mdot
.618 .3666 Mdot
.618 .3666 Mdot
.618 .36663 Mdot
.618 .36668 Mdot
.618 .36668 Mdot
.618 .3667 Mdot
.618 .36683 Mdot
.618 .367 Mdot
.618 .36707 Mdot
.618 .3671 Mdot
.618 .36715 Mdot
.618 .36716 Mdot
.618 .36716 Mdot
.618 .36718 Mdot
.618 .36723 Mdot
.618 .36724 Mdot
.618 .36725 Mdot
.618 .36738 Mdot
.618 .3674 Mdot
.618 .36743 Mdot
.618 .36745 Mdot
.618 .36747 Mdot
.618 .36747 Mdot
.618 .36748 Mdot
.618 .36748 Mdot
.618 .36752 Mdot
.618 .36756 Mdot
.618 .36759 Mdot
.618 .36771 Mdot
.618 .36771 Mdot
.618 .36773 Mdot
.618 .36773 Mdot
.618 .36774 Mdot
.618 .36781 Mdot
.618 .36786 Mdot
.618 .36787 Mdot
.618 .3679 Mdot
.618 .3679 Mdot
.618 .36793 Mdot
.618 .36794 Mdot
.618 .36794 Mdot
.618 .36801 Mdot
.618 .36817 Mdot
.618 .36825 Mdot
.618 .36833 Mdot
.618 .36853 Mdot
.618 .36858 Mdot
.618 .36865 Mdot
.618 .36866 Mdot
.618 .36866 Mdot
.618 .36868 Mdot
.618 .36868 Mdot
.618 .3687 Mdot
.618 .36878 Mdot
.618 .36881 Mdot
.618 .36888 Mdot
.618 .3689 Mdot
.618 .36904 Mdot
.618 .36906 Mdot
.618 .36911 Mdot
.618 .36913 Mdot
.618 .36914 Mdot
.618 .36915 Mdot
.618 .36915 Mdot
.618 .36917 Mdot
.618 .36919 Mdot
.618 .36921 Mdot
.618 .36924 Mdot
.618 .36929 Mdot
.618 .36931 Mdot
.618 .36931 Mdot
.618 .36932 Mdot
.618 .36948 Mdot
.618 .36949 Mdot
.618 .36951 Mdot
.618 .36951 Mdot
.618 .36951 Mdot
.618 .36952 Mdot
.618 .36961 Mdot
.618 .36965 Mdot
.618 .36965 Mdot
.618 .36965 Mdot
.618 .36967 Mdot
.618 .36968 Mdot
.618 .36975 Mdot
.618 .36976 Mdot
.618 .36976 Mdot
.618 .36976 Mdot
.618 .36979 Mdot
.618 .36981 Mdot
.618 .36983 Mdot
.618 .36983 Mdot
.618 .36984 Mdot
.618 .36985 Mdot
.618 .36988 Mdot
.618 .36995 Mdot
.618 .36998 Mdot
.618 .37002 Mdot
.618 .3701 Mdot
.618 .37012 Mdot
.618 .37015 Mdot
.618 .37025 Mdot
.618 .37036 Mdot
.618 .37037 Mdot
.618 .37037 Mdot
.618 .37043 Mdot
.618 .37044 Mdot
.618 .37051 Mdot
.618 .37052 Mdot
.618 .37053 Mdot
.618 .37059 Mdot
.618 .3706 Mdot
.618 .37062 Mdot
.618 .37063 Mdot
.618 .37065 Mdot
.618 .37066 Mdot
.618 .37066 Mdot
.618 .37067 Mdot
.618 .37068 Mdot
.618 .37073 Mdot
.618 .37077 Mdot
.618 .37078 Mdot
.618 .37084 Mdot
.618 .37089 Mdot
.618 .37095 Mdot
.618 .37095 Mdot
.618 .37098 Mdot
.618 .37099 Mdot
.618 .37101 Mdot
.618 .37101 Mdot
.618 .37104 Mdot
.618 .37109 Mdot
.618 .37117 Mdot
.618 .3712 Mdot
.618 .37124 Mdot
.618 .37126 Mdot
.618 .37127 Mdot
.618 .37128 Mdot
.618 .37128 Mdot
.618 .37128 Mdot
.618 .37128 Mdot
.618 .37128 Mdot
.618 .37129 Mdot
.618 .3713 Mdot
.618 .37133 Mdot
.618 .3714 Mdot
.618 .37143 Mdot
.618 .37145 Mdot
.618 .37147 Mdot
.618 .37147 Mdot
.618 .37157 Mdot
.618 .37161 Mdot
.618 .37164 Mdot
.618 .37167 Mdot
.618 .37168 Mdot
.618 .37169 Mdot
.618 .37171 Mdot
.618 .37173 Mdot
.618 .37173 Mdot
.618 .37177 Mdot
.618 .37177 Mdot
.618 .37178 Mdot
.618 .37183 Mdot
.618 .37187 Mdot
.618 .37195 Mdot
.618 .37203 Mdot
.618 .37205 Mdot
.618 .3721 Mdot
.618 .37212 Mdot
.618 .37219 Mdot
.618 .37221 Mdot
.618 .37222 Mdot
.618 .37222 Mdot
.618 .37224 Mdot
.618 .37225 Mdot
.618 .37227 Mdot
.618 .37227 Mdot
.618 .37228 Mdot
.618 .37232 Mdot
.618 .37233 Mdot
.618 .37234 Mdot
.618 .37243 Mdot
.618 .37243 Mdot
.618 .37243 Mdot
.618 .37246 Mdot
.618 .37256 Mdot
.618 .37257 Mdot
.618 .37257 Mdot
.618 .37261 Mdot
.618 .37263 Mdot
.618 .37265 Mdot
.618 .37266 Mdot
.618 .37267 Mdot
.618 .37267 Mdot
.618 .37268 Mdot
.618 .37268 Mdot
.618 .37273 Mdot
.618 .37285 Mdot
.618 .37291 Mdot
.618 .37296 Mdot
.618 .37299 Mdot
.618 .373 Mdot
.618 .37304 Mdot
.618 .37307 Mdot
.618 .37321 Mdot
.618 .37326 Mdot
.618 .37331 Mdot
.618 .37342 Mdot
.618 .37346 Mdot
.618 .37346 Mdot
.618 .37347 Mdot
.618 .37349 Mdot
.618 .37349 Mdot
.618 .37351 Mdot
.618 .37352 Mdot
.618 .37355 Mdot
.618 .37359 Mdot
.618 .3736 Mdot
.618 .3736 Mdot
.618 .37361 Mdot
.618 .37361 Mdot
.618 .37369 Mdot
.618 .37371 Mdot
.618 .37374 Mdot
.618 .37376 Mdot
.618 .37377 Mdot
.618 .37377 Mdot
.618 .37377 Mdot
.618 .37378 Mdot
.618 .3738 Mdot
.618 .37382 Mdot
.618 .37383 Mdot
.618 .37391 Mdot
.618 .37392 Mdot
.618 .37393 Mdot
.618 .37396 Mdot
.618 .37397 Mdot
.618 .37398 Mdot
.618 .37398 Mdot
.618 .37402 Mdot
.618 .37403 Mdot
.618 .37408 Mdot
.618 .37419 Mdot
.618 .37428 Mdot
.618 .37429 Mdot
.618 .37429 Mdot
.618 .37432 Mdot
.618 .37434 Mdot
.618 .3744 Mdot
.618 .37443 Mdot
.618 .37447 Mdot
.618 .37451 Mdot
.618 .37453 Mdot
.618 .37453 Mdot
.618 .37455 Mdot
.618 .37456 Mdot
.618 .37459 Mdot
.618 .37463 Mdot
.618 .37464 Mdot
.618 .37467 Mdot
.618 .37468 Mdot
.618 .3747 Mdot
.618 .37471 Mdot
.618 .37474 Mdot
.618 .37491 Mdot
.618 .37495 Mdot
.618 .37497 Mdot
.618 .37505 Mdot
.618 .37506 Mdot
.618 .37509 Mdot
.618 .37514 Mdot
.618 .37519 Mdot
.618 .37521 Mdot
.618 .37524 Mdot
.618 .37525 Mdot
.618 .37527 Mdot
.618 .37529 Mdot
.618 .37529 Mdot
.618 .3753 Mdot
.618 .37531 Mdot
.618 .37539 Mdot
.618 .3754 Mdot
.618 .37545 Mdot
.618 .37546 Mdot
.618 .37547 Mdot
.618 .3757 Mdot
.618 .3757 Mdot
.618 .37578 Mdot
.618 .37591 Mdot
.618 .37602 Mdot
.618 .37627 Mdot
.618 .37627 Mdot
.618 .37637 Mdot
.618 .37638 Mdot
.618 .3764 Mdot
.618 .37643 Mdot
.618 .37644 Mdot
.618 .37649 Mdot
.618 .37651 Mdot
.618 .37654 Mdot
.618 .37658 Mdot
.618 .37668 Mdot
.618 .37669 Mdot
.618 .3767 Mdot
.618 .37672 Mdot
.618 .37673 Mdot
.618 .37685 Mdot
.618 .37691 Mdot
.618 .37696 Mdot
.618 .37703 Mdot
.618 .37703 Mdot
.618 .37703 Mdot
.618 .37707 Mdot
.618 .37708 Mdot
.618 .37709 Mdot
.618 .3771 Mdot
.618 .37713 Mdot
.618 .37716 Mdot
.618 .37721 Mdot
.618 .37723 Mdot
.618 .37743 Mdot
.618 .37744 Mdot
.618 .37746 Mdot
.618 .37754 Mdot
.618 .37756 Mdot
.618 .37757 Mdot
.618 .37758 Mdot
.618 .37758 Mdot
.618 .37759 Mdot
.618 .37761 Mdot
.618 .37767 Mdot
.618 .37771 Mdot
.618 .37774 Mdot
.618 .37775 Mdot
.618 .37781 Mdot
.618 .37793 Mdot
.618 .37795 Mdot
.618 .37798 Mdot
.618 .37799 Mdot
.618 .37802 Mdot
.618 .37808 Mdot
.618 .37808 Mdot
.618 .3781 Mdot
.618 .37816 Mdot
.618 .37821 Mdot
.618 .37828 Mdot
.618 .3783 Mdot
.618 .3783 Mdot
.618 .37833 Mdot
.618 .37837 Mdot
.618 .37843 Mdot
.618 .37843 Mdot
.618 .37844 Mdot
.618 .37852 Mdot
.618 .37855 Mdot
.618 .37856 Mdot
.618 .37864 Mdot
.618 .37872 Mdot
.618 .37873 Mdot
.618 .37878 Mdot
.618 .37881 Mdot
.618 .37886 Mdot
.618 .37886 Mdot
.618 .37888 Mdot
.618 .37892 Mdot
.618 .37893 Mdot
.618 .37902 Mdot
.618 .37909 Mdot
.618 .37912 Mdot
.618 .37918 Mdot
.618 .37922 Mdot
.618 .37927 Mdot
.618 .37928 Mdot
.618 .37929 Mdot
.62 .29272 Mdot
.62 .29272 Mdot
.62 .29278 Mdot
.62 .29289 Mdot
.62 .29297 Mdot
.62 .29307 Mdot
.62 .2931 Mdot
.62 .29314 Mdot
.62 .29326 Mdot
.62 .29327 Mdot
.62 .29343 Mdot
.62 .29345 Mdot
.62 .29346 Mdot
.62 .2935 Mdot
.62 .29353 Mdot
.62 .2937 Mdot
.62 .29371 Mdot
.62 .29374 Mdot
.62 .29388 Mdot
.62 .29392 Mdot
.62 .29395 Mdot
.62 .294 Mdot
.62 .294 Mdot
.62 .29403 Mdot
.62 .29409 Mdot
.62 .29413 Mdot
.62 .29416 Mdot
.62 .29418 Mdot
.62 .29418 Mdot
.62 .29423 Mdot
.62 .29424 Mdot
.62 .29427 Mdot
.62 .29428 Mdot
.62 .29441 Mdot
.62 .29444 Mdot
.62 .29447 Mdot
.62 .29454 Mdot
.62 .29458 Mdot
.62 .29459 Mdot
.62 .29462 Mdot
.62 .29466 Mdot
.62 .29493 Mdot
.62 .29493 Mdot
.62 .29493 Mdot
.62 .29498 Mdot
.62 .29507 Mdot
.62 .29516 Mdot
.62 .29524 Mdot
.62 .29524 Mdot
.62 .29526 Mdot
.62 .29535 Mdot
.62 .29536 Mdot
.62 .2954 Mdot
.62 .29542 Mdot
.62 .2955 Mdot
.62 .29553 Mdot
.62 .29557 Mdot
.62 .2956 Mdot
.62 .29562 Mdot
.62 .29563 Mdot
.62 .29568 Mdot
.62 .29571 Mdot
.62 .29574 Mdot
.62 .29585 Mdot
.62 .29586 Mdot
.62 .29588 Mdot
.62 .29596 Mdot
.62 .29599 Mdot
.62 .29606 Mdot
.62 .29606 Mdot
.62 .29618 Mdot
.62 .29623 Mdot
.62 .29627 Mdot
.62 .29637 Mdot
.62 .29638 Mdot
.62 .29641 Mdot
.62 .29644 Mdot
.62 .29648 Mdot
.62 .29663 Mdot
.62 .29667 Mdot
.62 .29679 Mdot
.62 .29679 Mdot
.62 .29698 Mdot
.62 .29705 Mdot
.62 .29708 Mdot
.62 .29709 Mdot
.62 .2971 Mdot
.62 .29714 Mdot
.62 .29723 Mdot
.62 .29727 Mdot
.62 .2973 Mdot
.62 .29739 Mdot
.62 .29741 Mdot
.62 .29746 Mdot
.62 .2975 Mdot
.62 .29751 Mdot
.62 .29756 Mdot
.62 .29757 Mdot
.62 .29768 Mdot
.62 .2977 Mdot
.62 .29771 Mdot
.62 .29784 Mdot
.62 .2979 Mdot
.62 .29791 Mdot
.62 .29792 Mdot
.62 .29798 Mdot
.62 .298 Mdot
.62 .29806 Mdot
.62 .29809 Mdot
.62 .2981 Mdot
.62 .29815 Mdot
.62 .29821 Mdot
.62 .29822 Mdot
.62 .29833 Mdot
.62 .29834 Mdot
.62 .29841 Mdot
.62 .29853 Mdot
.62 .29857 Mdot
.62 .29864 Mdot
.62 .29865 Mdot
.62 .29868 Mdot
.62 .2988 Mdot
.62 .29881 Mdot
.62 .29883 Mdot
.62 .29888 Mdot
.62 .29896 Mdot
.62 .29898 Mdot
.62 .29899 Mdot
.62 .29907 Mdot
.62 .29916 Mdot
.62 .29917 Mdot
.62 .29919 Mdot
.62 .29925 Mdot
.62 .29926 Mdot
.62 .29927 Mdot
.62 .29927 Mdot
.62 .29929 Mdot
.62 .29931 Mdot
.62 .29942 Mdot
.62 .29944 Mdot
.62 .29945 Mdot
.62 .29947 Mdot
.62 .29959 Mdot
.62 .29965 Mdot
.62 .29968 Mdot
.62 .29972 Mdot
.62 .29977 Mdot
.62 .29977 Mdot
.62 .29984 Mdot
.62 .29986 Mdot
.62 .29987 Mdot
.62 .29988 Mdot
.62 .29992 Mdot
.62 .29993 Mdot
.62 .29998 Mdot
.62 .29998 Mdot
.62 .30004 Mdot
.62 .30006 Mdot
.62 .30012 Mdot
.62 .30014 Mdot
.62 .30023 Mdot
.62 .30032 Mdot
.62 .30037 Mdot
.62 .30037 Mdot
.62 .30046 Mdot
.62 .30048 Mdot
.62 .3005 Mdot
.62 .30052 Mdot
.62 .30056 Mdot
.62 .30064 Mdot
.62 .30067 Mdot
.62 .3007 Mdot
.62 .30071 Mdot
.62 .30075 Mdot
.62 .30076 Mdot
.62 .30076 Mdot
.62 .30085 Mdot
.62 .30088 Mdot
.62 .30093 Mdot
.62 .30095 Mdot
.62 .30098 Mdot
.62 .30103 Mdot
.62 .30116 Mdot
.62 .30117 Mdot
.62 .30129 Mdot
.62 .30131 Mdot
.62 .30138 Mdot
.62 .30138 Mdot
.62 .30139 Mdot
.62 .30142 Mdot
.62 .30149 Mdot
.62 .30149 Mdot
.62 .3015 Mdot
.62 .30151 Mdot
.62 .3016 Mdot
.62 .30163 Mdot
.62 .30163 Mdot
.62 .30168 Mdot
.62 .30175 Mdot
.62 .30189 Mdot
.62 .30192 Mdot
.62 .30195 Mdot
.62 .30197 Mdot
.62 .302 Mdot
.62 .30201 Mdot
.62 .30202 Mdot
.62 .30203 Mdot
.62 .30205 Mdot
.62 .30212 Mdot
.62 .30217 Mdot
.62 .30223 Mdot
.62 .30228 Mdot
.62 .30228 Mdot
.62 .30232 Mdot
.62 .30232 Mdot
.62 .30233 Mdot
.62 .30241 Mdot
.62 .30242 Mdot
.62 .30244 Mdot
.62 .30253 Mdot
.62 .30256 Mdot
.62 .30258 Mdot
.62 .30258 Mdot
.62 .30258 Mdot
.62 .30259 Mdot
.62 .30265 Mdot
.62 .30271 Mdot
.62 .30272 Mdot
.62 .30276 Mdot
.62 .30282 Mdot
.62 .30282 Mdot
.62 .30288 Mdot
.62 .30293 Mdot
.62 .30295 Mdot
.62 .30303 Mdot
.62 .30305 Mdot
.62 .30308 Mdot
.62 .30312 Mdot
.62 .30312 Mdot
.62 .30315 Mdot
.62 .30319 Mdot
.62 .30327 Mdot
.62 .30327 Mdot
.62 .30328 Mdot
.62 .30328 Mdot
.62 .30331 Mdot
.62 .30337 Mdot
.62 .30338 Mdot
.62 .30344 Mdot
.62 .30344 Mdot
.62 .30347 Mdot
.62 .30354 Mdot
.62 .30362 Mdot
.62 .30363 Mdot
.62 .30364 Mdot
.62 .30365 Mdot
.62 .30365 Mdot
.62 .30367 Mdot
.62 .30368 Mdot
.62 .3037 Mdot
.62 .30372 Mdot
.62 .30382 Mdot
.62 .30386 Mdot
.62 .30389 Mdot
.62 .30389 Mdot
.62 .30391 Mdot
.62 .30397 Mdot
.62 .30403 Mdot
.62 .30405 Mdot
.62 .30405 Mdot
.62 .3041 Mdot
.62 .30411 Mdot
.62 .30419 Mdot
.62 .30428 Mdot
.62 .30432 Mdot
.62 .30435 Mdot
.62 .30438 Mdot
.62 .3044 Mdot
.62 .30446 Mdot
.62 .3045 Mdot
.62 .30452 Mdot
.62 .30453 Mdot
.62 .30454 Mdot
.62 .30459 Mdot
.62 .30461 Mdot
.62 .30466 Mdot
.62 .30471 Mdot
.62 .3048 Mdot
.62 .30488 Mdot
.62 .30493 Mdot
.62 .30497 Mdot
.62 .305 Mdot
.62 .30503 Mdot
.62 .30504 Mdot
.62 .3051 Mdot
.62 .30511 Mdot
.62 .30516 Mdot
.62 .30529 Mdot
.62 .30531 Mdot
.62 .30532 Mdot
.62 .30533 Mdot
.62 .30543 Mdot
.62 .30543 Mdot
.62 .30543 Mdot
.62 .30548 Mdot
.62 .30549 Mdot
.62 .3055 Mdot
.62 .30561 Mdot
.62 .30563 Mdot
.62 .30573 Mdot
.62 .30581 Mdot
.62 .30583 Mdot
.62 .30584 Mdot
.62 .30588 Mdot
.62 .30603 Mdot
.62 .30611 Mdot
.62 .30612 Mdot
.62 .30616 Mdot
.62 .30619 Mdot
.62 .30626 Mdot
.62 .3063 Mdot
.62 .30632 Mdot
.62 .30644 Mdot
.62 .30645 Mdot
.62 .30646 Mdot
.62 .30653 Mdot
.62 .30654 Mdot
.62 .30657 Mdot
.62 .30658 Mdot
.62 .30664 Mdot
.62 .30671 Mdot
.62 .30673 Mdot
.62 .30676 Mdot
.62 .30681 Mdot
.62 .30685 Mdot
.62 .30687 Mdot
.62 .30691 Mdot
.62 .30704 Mdot
.62 .30704 Mdot
.62 .30712 Mdot
.62 .30727 Mdot
.62 .3074 Mdot
.62 .30744 Mdot
.62 .30752 Mdot
.62 .30756 Mdot
.62 .30764 Mdot
.62 .30765 Mdot
.62 .30773 Mdot
.62 .30774 Mdot
.62 .3078 Mdot
.62 .30782 Mdot
.62 .30783 Mdot
.62 .30786 Mdot
.62 .30797 Mdot
.62 .30798 Mdot
.62 .30805 Mdot
.62 .3081 Mdot
.62 .30816 Mdot
.62 .30825 Mdot
.62 .30842 Mdot
.62 .30847 Mdot
.62 .30848 Mdot
.62 .3085 Mdot
.62 .30868 Mdot
.62 .30871 Mdot
.62 .30874 Mdot
.62 .30874 Mdot
.62 .30875 Mdot
.62 .30877 Mdot
.62 .30886 Mdot
.62 .30889 Mdot
.62 .30891 Mdot
.62 .30905 Mdot
.62 .30916 Mdot
.62 .30918 Mdot
.62 .30921 Mdot
.62 .30933 Mdot
.62 .30942 Mdot
.62 .30944 Mdot
.62 .30946 Mdot
.62 .30965 Mdot
.62 .30968 Mdot
.62 .3097 Mdot
.62 .30982 Mdot
.62 .30987 Mdot
.62 .31006 Mdot
.62 .31017 Mdot
.62 .31019 Mdot
.62 .31035 Mdot
.62 .31037 Mdot
.62 .31046 Mdot
.62 .31054 Mdot
.62 .31056 Mdot
.62 .3106 Mdot
.62 .31069 Mdot
.62 .31072 Mdot
.62 .31081 Mdot
.62 .31082 Mdot
.62 .31084 Mdot
.62 .31094 Mdot
.62 .31114 Mdot
.62 .31114 Mdot
.62 .31118 Mdot
.62 .31134 Mdot
.62 .31136 Mdot
.62 .31145 Mdot
.62 .31147 Mdot
.62 .31152 Mdot
.62 .3116 Mdot
.62 .31163 Mdot
.62 .31176 Mdot
.62 .31181 Mdot
.62 .31188 Mdot
.62 .31201 Mdot
.62 .31208 Mdot
.62 .31209 Mdot
.62 .31211 Mdot
.62 .31215 Mdot
.62 .31225 Mdot
.62 .31255 Mdot
.62 .31255 Mdot
.62 .31274 Mdot
.62 .31279 Mdot
.62 .31303 Mdot
.62 .31308 Mdot
.62 .31313 Mdot
.62 .31318 Mdot
.62 .3132 Mdot
.62 .31335 Mdot
.62 .31341 Mdot
.62 .31349 Mdot
.62 .31367 Mdot
.62 .31368 Mdot
.62 .31378 Mdot
.62 .31383 Mdot
.62 .31395 Mdot
.62 .31398 Mdot
.62 .31399 Mdot
.62 .31417 Mdot
.62 .31421 Mdot
.62 .31426 Mdot
.62 .31434 Mdot
.62 .31435 Mdot
.62 .31439 Mdot
.62 .31443 Mdot
.62 .31448 Mdot
.62 .31453 Mdot
.62 .31465 Mdot
.62 .31468 Mdot
.62 .31476 Mdot
.62 .31476 Mdot
.62 .3149 Mdot
.62 .31493 Mdot
.62 .31494 Mdot
.62 .31506 Mdot
.62 .31519 Mdot
.62 .31533 Mdot
.62 .31541 Mdot
.62 .31541 Mdot
.62 .31541 Mdot
.62 .31582 Mdot
.62 .31589 Mdot
.62 .31593 Mdot
.62 .31595 Mdot
.62 .31601 Mdot
.62 .31612 Mdot
.62 .31616 Mdot
.62 .31621 Mdot
.62 .31641 Mdot
.62 .31642 Mdot
.62 .31647 Mdot
.62 .31649 Mdot
.62 .31657 Mdot
.62 .31657 Mdot
.62 .31659 Mdot
.62 .31664 Mdot
.62 .3167 Mdot
.62 .31679 Mdot
.62 .31684 Mdot
.62 .31685 Mdot
.62 .31692 Mdot
.62 .31697 Mdot
.62 .31702 Mdot
.62 .31725 Mdot
.62 .31729 Mdot
.62 .3173 Mdot
.62 .31757 Mdot
.62 .31761 Mdot
.62 .31767 Mdot
.62 .31769 Mdot
.62 .31771 Mdot
.62 .31797 Mdot
.62 .31797 Mdot
.62 .31817 Mdot
.62 .31823 Mdot
.62 .31827 Mdot
.62 .31842 Mdot
.62 .31855 Mdot
.62 .31872 Mdot
.62 .3188 Mdot
.62 .31882 Mdot
.62 .35944 Mdot
.62 .35945 Mdot
.62 .35952 Mdot
.62 .35965 Mdot
.62 .35976 Mdot
.62 .35988 Mdot
.62 .35991 Mdot
.62 .35996 Mdot
.62 .36011 Mdot
.62 .36012 Mdot
.62 .36033 Mdot
.62 .36034 Mdot
.62 .36036 Mdot
.62 .36041 Mdot
.62 .36044 Mdot
.62 .36066 Mdot
.62 .36067 Mdot
.62 .3607 Mdot
.62 .36088 Mdot
.62 .36092 Mdot
.62 .36096 Mdot
.62 .36102 Mdot
.62 .36103 Mdot
.62 .36107 Mdot
.62 .36114 Mdot
.62 .36119 Mdot
.62 .36123 Mdot
.62 .36125 Mdot
.62 .36125 Mdot
.62 .36131 Mdot
.62 .36133 Mdot
.62 .36136 Mdot
.62 .36137 Mdot
.62 .36154 Mdot
.62 .36157 Mdot
.62 .36161 Mdot
.62 .3617 Mdot
.62 .36175 Mdot
.62 .36177 Mdot
.62 .3618 Mdot
.62 .36185 Mdot
.62 .36218 Mdot
.62 .36218 Mdot
.62 .36218 Mdot
.62 .36224 Mdot
.62 .36236 Mdot
.62 .36247 Mdot
.62 .36256 Mdot
.62 .36257 Mdot
.62 .36259 Mdot
.62 .3627 Mdot
.62 .36271 Mdot
.62 .36277 Mdot
.62 .3628 Mdot
.62 .36289 Mdot
.62 .36293 Mdot
.62 .36297 Mdot
.62 .36301 Mdot
.62 .36304 Mdot
.62 .36305 Mdot
.62 .36311 Mdot
.62 .36315 Mdot
.62 .36318 Mdot
.62 .36333 Mdot
.62 .36334 Mdot
.62 .36336 Mdot
.62 .36345 Mdot
.62 .3635 Mdot
.62 .36358 Mdot
.62 .36359 Mdot
.62 .36373 Mdot
.62 .3638 Mdot
.62 .36384 Mdot
.62 .36397 Mdot
.62 .36398 Mdot
.62 .36402 Mdot
.62 .36406 Mdot
.62 .3641 Mdot
.62 .36429 Mdot
.62 .36433 Mdot
.62 .36449 Mdot
.62 .36449 Mdot
.62 .36473 Mdot
.62 .36481 Mdot
.62 .36484 Mdot
.62 .36486 Mdot
.62 .36487 Mdot
.62 .36492 Mdot
.62 .36503 Mdot
.62 .36509 Mdot
.62 .36513 Mdot
.62 .36523 Mdot
.62 .36526 Mdot
.62 .36532 Mdot
.62 .36536 Mdot
.62 .36538 Mdot
.62 .36545 Mdot
.62 .36546 Mdot
.62 .3656 Mdot
.62 .36562 Mdot
.62 .36562 Mdot
.62 .36579 Mdot
.62 .36587 Mdot
.62 .36588 Mdot
.62 .3659 Mdot
.62 .36597 Mdot
.62 .36598 Mdot
.62 .36606 Mdot
.62 .36609 Mdot
.62 .36611 Mdot
.62 .36617 Mdot
.62 .36625 Mdot
.62 .36626 Mdot
.62 .36639 Mdot
.62 .36641 Mdot
.62 .3665 Mdot
.62 .36665 Mdot
.62 .36669 Mdot
.62 .36678 Mdot
.62 .3668 Mdot
.62 .36683 Mdot
.62 .36698 Mdot
.62 .36699 Mdot
.62 .36702 Mdot
.62 .36708 Mdot
.62 .36718 Mdot
.62 .36721 Mdot
.62 .36722 Mdot
.62 .36731 Mdot
.62 .36742 Mdot
.62 .36744 Mdot
.62 .36747 Mdot
.62 .36754 Mdot
.62 .36755 Mdot
.62 .36756 Mdot
.62 .36756 Mdot
.62 .36759 Mdot
.62 .36761 Mdot
.62 .36775 Mdot
.62 .36777 Mdot
.62 .36778 Mdot
.62 .36782 Mdot
.62 .36796 Mdot
.62 .36803 Mdot
.62 .36808 Mdot
.62 .36812 Mdot
.62 .36818 Mdot
.62 .36818 Mdot
.62 .36827 Mdot
.62 .36829 Mdot
.62 .36831 Mdot
.62 .36832 Mdot
.62 .36837 Mdot
.62 .36838 Mdot
.62 .36844 Mdot
.62 .36844 Mdot
.62 .36851 Mdot
.62 .36855 Mdot
.62 .36861 Mdot
.62 .36864 Mdot
.62 .36875 Mdot
.62 .36887 Mdot
.62 .36893 Mdot
.62 .36893 Mdot
.62 .36903 Mdot
.62 .36907 Mdot
.62 .36908 Mdot
.62 .36911 Mdot
.62 .36916 Mdot
.62 .36918 Mdot
.62 .3692 Mdot
.62 .36926 Mdot
.62 .3693 Mdot
.62 .36931 Mdot
.62 .36934 Mdot
.62 .36934 Mdot
.62 .3694 Mdot
.62 .36941 Mdot
.62 .36941 Mdot
.62 .36951 Mdot
.62 .36953 Mdot
.62 .36956 Mdot
.62 .36962 Mdot
.62 .36964 Mdot
.62 .36968 Mdot
.62 .36968 Mdot
.62 .36974 Mdot
.62 .36986 Mdot
.62 .3699 Mdot
.62 .36991 Mdot
.62 .36992 Mdot
.62 .36999 Mdot
.62 .37007 Mdot
.62 .37009 Mdot
.62 .37017 Mdot
.62 .37018 Mdot
.62 .37019 Mdot
.62 .37023 Mdot
.62 .37023 Mdot
.62 .37023 Mdot
.62 .37031 Mdot
.62 .37032 Mdot
.62 .37032 Mdot
.62 .37034 Mdot
.62 .37045 Mdot
.62 .37049 Mdot
.62 .37049 Mdot
.62 .37055 Mdot
.62 .37055 Mdot
.62 .37058 Mdot
.62 .3706 Mdot
.62 .37063 Mdot
.62 .37068 Mdot
.62 .37073 Mdot
.62 .37081 Mdot
.62 .37085 Mdot
.62 .37089 Mdot
.62 .37091 Mdot
.62 .37095 Mdot
.62 .37096 Mdot
.62 .37097 Mdot
.62 .37098 Mdot
.62 .37101 Mdot
.62 .37106 Mdot
.62 .37108 Mdot
.62 .3711 Mdot
.62 .37113 Mdot
.62 .37116 Mdot
.62 .37123 Mdot
.62 .37129 Mdot
.62 .3713 Mdot
.62 .37134 Mdot
.62 .37134 Mdot
.62 .37136 Mdot
.62 .37141 Mdot
.62 .37145 Mdot
.62 .37147 Mdot
.62 .37147 Mdot
.62 .37149 Mdot
.62 .37153 Mdot
.62 .37161 Mdot
.62 .37162 Mdot
.62 .37164 Mdot
.62 .37165 Mdot
.62 .37166 Mdot
.62 .37167 Mdot
.62 .37167 Mdot
.62 .37168 Mdot
.62 .37169 Mdot
.62 .37175 Mdot
.62 .37181 Mdot
.62 .37183 Mdot
.62 .37184 Mdot
.62 .37189 Mdot
.62 .3719 Mdot
.62 .37194 Mdot
.62 .37196 Mdot
.62 .37197 Mdot
.62 .37197 Mdot
.62 .37197 Mdot
.62 .37204 Mdot
.62 .37207 Mdot
.62 .37209 Mdot
.62 .3721 Mdot
.62 .37213 Mdot
.62 .37215 Mdot
.62 .37216 Mdot
.62 .37223 Mdot
.62 .37225 Mdot
.62 .37229 Mdot
.62 .37233 Mdot
.62 .37234 Mdot
.62 .37238 Mdot
.62 .37242 Mdot
.62 .37242 Mdot
.62 .37247 Mdot
.62 .37252 Mdot
.62 .37253 Mdot
.62 .37253 Mdot
.62 .37253 Mdot
.62 .37254 Mdot
.62 .37257 Mdot
.62 .37264 Mdot
.62 .37266 Mdot
.62 .37267 Mdot
.62 .37273 Mdot
.62 .37274 Mdot
.62 .37274 Mdot
.62 .37277 Mdot
.62 .37277 Mdot
.62 .37281 Mdot
.62 .37286 Mdot
.62 .3729 Mdot
.62 .37295 Mdot
.62 .37297 Mdot
.62 .37298 Mdot
.62 .37299 Mdot
.62 .373 Mdot
.62 .37302 Mdot
.62 .37304 Mdot
.62 .37306 Mdot
.62 .37309 Mdot
.62 .3732 Mdot
.62 .37326 Mdot
.62 .37329 Mdot
.62 .37329 Mdot
.62 .37332 Mdot
.62 .37339 Mdot
.62 .3734 Mdot
.62 .3734 Mdot
.62 .37341 Mdot
.62 .37346 Mdot
.62 .37349 Mdot
.62 .3735 Mdot
.62 .3735 Mdot
.62 .37356 Mdot
.62 .37357 Mdot
.62 .37366 Mdot
.62 .37368 Mdot
.62 .37378 Mdot
.62 .37382 Mdot
.62 .37384 Mdot
.62 .37386 Mdot
.62 .3739 Mdot
.62 .37392 Mdot
.62 .374 Mdot
.62 .374 Mdot
.62 .374 Mdot
.62 .37404 Mdot
.62 .37404 Mdot
.62 .37407 Mdot
.62 .3741 Mdot
.62 .37416 Mdot
.62 .37419 Mdot
.62 .37421 Mdot
.62 .37422 Mdot
.62 .37424 Mdot
.62 .37431 Mdot
.62 .37431 Mdot
.62 .37435 Mdot
.62 .37443 Mdot
.62 .3745 Mdot
.62 .37452 Mdot
.62 .37456 Mdot
.62 .37458 Mdot
.62 .37462 Mdot
.62 .37463 Mdot
.62 .37467 Mdot
.62 .37468 Mdot
.62 .37471 Mdot
.62 .37472 Mdot
.62 .37472 Mdot
.62 .37474 Mdot
.62 .3748 Mdot
.62 .3748 Mdot
.62 .37484 Mdot
.62 .37486 Mdot
.62 .37489 Mdot
.62 .37494 Mdot
.62 .37503 Mdot
.62 .37506 Mdot
.62 .37506 Mdot
.62 .37507 Mdot
.62 .37517 Mdot
.62 .37518 Mdot
.62 .3752 Mdot
.62 .3752 Mdot
.62 .3752 Mdot
.62 .37521 Mdot
.62 .37526 Mdot
.62 .37528 Mdot
.62 .37529 Mdot
.62 .37536 Mdot
.62 .37542 Mdot
.62 .37543 Mdot
.62 .37545 Mdot
.62 .37555 Mdot
.62 .37557 Mdot
.62 .37558 Mdot
.62 .37568 Mdot
.62 .37569 Mdot
.62 .3757 Mdot
.62 .37576 Mdot
.62 .37579 Mdot
.62 .37589 Mdot
.62 .37595 Mdot
.62 .37596 Mdot
.62 .37604 Mdot
.62 .37605 Mdot
.62 .3761 Mdot
.62 .37614 Mdot
.62 .37615 Mdot
.62 .37617 Mdot
.62 .37622 Mdot
.62 .37624 Mdot
.62 .37628 Mdot
.62 .37629 Mdot
.62 .3763 Mdot
.62 .37635 Mdot
.62 .37646 Mdot
.62 .37646 Mdot
.62 .37648 Mdot
.62 .37657 Mdot
.62 .37657 Mdot
.62 .37662 Mdot
.62 .37663 Mdot
.62 .37666 Mdot
.62 .3767 Mdot
.62 .37672 Mdot
.62 .37678 Mdot
.62 .37681 Mdot
.62 .37685 Mdot
.62 .37692 Mdot
.62 .37695 Mdot
.62 .37696 Mdot
.62 .37697 Mdot
.62 .37699 Mdot
.62 .37704 Mdot
.62 .3772 Mdot
.62 .3772 Mdot
.62 .3773 Mdot
.62 .37732 Mdot
.62 .37745 Mdot
.62 .37748 Mdot
.62 .3775 Mdot
.62 .37753 Mdot
.62 .37754 Mdot
.62 .37762 Mdot
.62 .37765 Mdot
.62 .37769 Mdot
.62 .37778 Mdot
.62 .37779 Mdot
.62 .37784 Mdot
.62 .37787 Mdot
.62 .37793 Mdot
.62 .37795 Mdot
.62 .37795 Mdot
.62 .37805 Mdot
.62 .37807 Mdot
.62 .37809 Mdot
.62 .37814 Mdot
.62 .37814 Mdot
.62 .37816 Mdot
.62 .37818 Mdot
.62 .37821 Mdot
.62 .37824 Mdot
.62 .3783 Mdot
.62 .37832 Mdot
.62 .37835 Mdot
.62 .37836 Mdot
.62 .37843 Mdot
.62 .37845 Mdot
.62 .37845 Mdot
.62 .37851 Mdot
.62 .37858 Mdot
.62 .37866 Mdot
.62 .3787 Mdot
.62 .3787 Mdot
.62 .3787 Mdot
.62 .37891 Mdot
.62 .37895 Mdot
.62 .37897 Mdot
.62 .37898 Mdot
.62 .37901 Mdot
.62 .37907 Mdot
.62 .37909 Mdot
.62 .37912 Mdot
.62 .37922 Mdot
.62 .37923 Mdot
.62 .37925 Mdot
.62 .37927 Mdot
.62 .3793 Mdot
.62 .37931 Mdot
.62 .37932 Mdot
.62 .37934 Mdot
.62 .37937 Mdot
.62 .37942 Mdot
.62 .37945 Mdot
.62 .37945 Mdot
.62 .37949 Mdot
.62 .37952 Mdot
.62 .37954 Mdot
.62 .37966 Mdot
.62 .37968 Mdot
.62 .37969 Mdot
.62 .37983 Mdot
.62 .37985 Mdot
.62 .37988 Mdot
.62 .37989 Mdot
.62 .37991 Mdot
.62 .38004 Mdot
.62 .38004 Mdot
.62 .38014 Mdot
.62 .38018 Mdot
.62 .3802 Mdot
.62 .38028 Mdot
.62 .38034 Mdot
.62 .38043 Mdot
.62 .38048 Mdot
.62 .38048 Mdot
.622 .29216 Mdot
.622 .29216 Mdot
.622 .29216 Mdot
.622 .29217 Mdot
.622 .29219 Mdot
.622 .29223 Mdot
.622 .29227 Mdot
.622 .29229 Mdot
.622 .29241 Mdot
.622 .29252 Mdot
.622 .29252 Mdot
.622 .29255 Mdot
.622 .29257 Mdot
.622 .29258 Mdot
.622 .29259 Mdot
.622 .29264 Mdot
.622 .29268 Mdot
.622 .29268 Mdot
.622 .29275 Mdot
.622 .29278 Mdot
.622 .29293 Mdot
.622 .29295 Mdot
.622 .29302 Mdot
.622 .29307 Mdot
.622 .29311 Mdot
.622 .29311 Mdot
.622 .29312 Mdot
.622 .29316 Mdot
.622 .29316 Mdot
.622 .2932 Mdot
.622 .29321 Mdot
.622 .29321 Mdot
.622 .29321 Mdot
.622 .29329 Mdot
.622 .29335 Mdot
.622 .29337 Mdot
.622 .29339 Mdot
.622 .29342 Mdot
.622 .29342 Mdot
.622 .29355 Mdot
.622 .29358 Mdot
.622 .29366 Mdot
.622 .29368 Mdot
.622 .29379 Mdot
.622 .29385 Mdot
.622 .29391 Mdot
.622 .29406 Mdot
.622 .2942 Mdot
.622 .29422 Mdot
.622 .29425 Mdot
.622 .29428 Mdot
.622 .2943 Mdot
.622 .29439 Mdot
.622 .29439 Mdot
.622 .29453 Mdot
.622 .29466 Mdot
.622 .29467 Mdot
.622 .29476 Mdot
.622 .29508 Mdot
.622 .2952 Mdot
.622 .29534 Mdot
.622 .29544 Mdot
.622 .2955 Mdot
.622 .29557 Mdot
.622 .29559 Mdot
.622 .29569 Mdot
.622 .29569 Mdot
.622 .29575 Mdot
.622 .29577 Mdot
.622 .29583 Mdot
.622 .29583 Mdot
.622 .29589 Mdot
.622 .29592 Mdot
.622 .29593 Mdot
.622 .29594 Mdot
.622 .29596 Mdot
.622 .29596 Mdot
.622 .29597 Mdot
.622 .29598 Mdot
.622 .296 Mdot
.622 .29604 Mdot
.622 .29605 Mdot
.622 .29615 Mdot
.622 .29619 Mdot
.622 .29629 Mdot
.622 .29633 Mdot
.622 .29635 Mdot
.622 .29637 Mdot
.622 .29638 Mdot
.622 .29639 Mdot
.622 .29642 Mdot
.622 .29642 Mdot
.622 .2965 Mdot
.622 .29656 Mdot
.622 .29659 Mdot
.622 .29665 Mdot
.622 .29667 Mdot
.622 .29671 Mdot
.622 .29675 Mdot
.622 .29675 Mdot
.622 .29675 Mdot
.622 .29677 Mdot
.622 .29678 Mdot
.622 .29683 Mdot
.622 .29684 Mdot
.622 .29686 Mdot
.622 .29686 Mdot
.622 .29691 Mdot
.622 .29697 Mdot
.622 .29707 Mdot
.622 .29729 Mdot
.622 .29729 Mdot
.622 .29741 Mdot
.622 .29744 Mdot
.622 .29745 Mdot
.622 .29748 Mdot
.622 .29749 Mdot
.622 .29763 Mdot
.622 .29766 Mdot
.622 .2977 Mdot
.622 .29771 Mdot
.622 .29776 Mdot
.622 .29781 Mdot
.622 .29781 Mdot
.622 .29782 Mdot
.622 .29783 Mdot
.622 .29784 Mdot
.622 .29787 Mdot
.622 .2979 Mdot
.622 .2979 Mdot
.622 .2979 Mdot
.622 .29792 Mdot
.622 .29792 Mdot
.622 .29794 Mdot
.622 .29794 Mdot
.622 .29794 Mdot
.622 .29798 Mdot
.622 .29802 Mdot
.622 .29808 Mdot
.622 .29816 Mdot
.622 .29816 Mdot
.622 .29817 Mdot
.622 .29817 Mdot
.622 .29823 Mdot
.622 .29829 Mdot
.622 .29831 Mdot
.622 .29832 Mdot
.622 .29834 Mdot
.622 .29836 Mdot
.622 .29836 Mdot
.622 .29836 Mdot
.622 .29841 Mdot
.622 .29851 Mdot
.622 .29851 Mdot
.622 .29856 Mdot
.622 .29857 Mdot
.622 .29858 Mdot
.622 .29861 Mdot
.622 .29869 Mdot
.622 .29874 Mdot
.622 .2988 Mdot
.622 .29895 Mdot
.622 .29909 Mdot
.622 .29915 Mdot
.622 .29923 Mdot
.622 .29929 Mdot
.622 .29935 Mdot
.622 .29945 Mdot
.622 .29958 Mdot
.622 .29968 Mdot
.622 .29975 Mdot
.622 .29979 Mdot
.622 .29989 Mdot
.622 .29989 Mdot
.622 .29993 Mdot
.622 .29994 Mdot
.622 .29995 Mdot
.622 .29996 Mdot
.622 .29998 Mdot
.622 .30008 Mdot
.622 .3001 Mdot
.622 .30024 Mdot
.622 .30026 Mdot
.622 .30027 Mdot
.622 .30028 Mdot
.622 .30045 Mdot
.622 .30056 Mdot
.622 .30057 Mdot
.622 .30058 Mdot
.622 .30058 Mdot
.622 .30072 Mdot
.622 .30075 Mdot
.622 .30077 Mdot
.622 .30077 Mdot
.622 .30083 Mdot
.622 .30086 Mdot
.622 .3009 Mdot
.622 .30094 Mdot
.622 .30095 Mdot
.622 .30095 Mdot
.622 .30097 Mdot
.622 .30103 Mdot
.622 .30104 Mdot
.622 .30105 Mdot
.622 .30128 Mdot
.622 .3014 Mdot
.622 .30155 Mdot
.622 .3016 Mdot
.622 .30162 Mdot
.622 .30162 Mdot
.622 .30182 Mdot
.622 .30187 Mdot
.622 .30187 Mdot
.622 .30188 Mdot
.622 .30195 Mdot
.622 .30196 Mdot
.622 .30198 Mdot
.622 .30201 Mdot
.622 .30202 Mdot
.622 .30207 Mdot
.622 .30222 Mdot
.622 .30242 Mdot
.622 .30242 Mdot
.622 .30246 Mdot
.622 .30256 Mdot
.622 .30266 Mdot
.622 .3027 Mdot
.622 .30276 Mdot
.622 .30287 Mdot
.622 .3029 Mdot
.622 .30296 Mdot
.622 .30303 Mdot
.622 .30305 Mdot
.622 .30318 Mdot
.622 .30332 Mdot
.622 .30334 Mdot
.622 .30336 Mdot
.622 .3034 Mdot
.622 .3034 Mdot
.622 .30356 Mdot
.622 .30362 Mdot
.622 .30371 Mdot
.622 .30394 Mdot
.622 .30394 Mdot
.622 .30395 Mdot
.622 .304 Mdot
.622 .30401 Mdot
.622 .30404 Mdot
.622 .30406 Mdot
.622 .30408 Mdot
.622 .30411 Mdot
.622 .30412 Mdot
.622 .30413 Mdot
.622 .30424 Mdot
.622 .30424 Mdot
.622 .30425 Mdot
.622 .30425 Mdot
.622 .30433 Mdot
.622 .30443 Mdot
.622 .30444 Mdot
.622 .30445 Mdot
.622 .30446 Mdot
.622 .30455 Mdot
.622 .30456 Mdot
.622 .30463 Mdot
.622 .30464 Mdot
.622 .30465 Mdot
.622 .30466 Mdot
.622 .30468 Mdot
.622 .30469 Mdot
.622 .30475 Mdot
.622 .30477 Mdot
.622 .30489 Mdot
.622 .30497 Mdot
.622 .30507 Mdot
.622 .30511 Mdot
.622 .30516 Mdot
.622 .30546 Mdot
.622 .30551 Mdot
.622 .30553 Mdot
.622 .30554 Mdot
.622 .30554 Mdot
.622 .30564 Mdot
.622 .30567 Mdot
.622 .30567 Mdot
.622 .30569 Mdot
.622 .3057 Mdot
.622 .30572 Mdot
.622 .30575 Mdot
.622 .3058 Mdot
.622 .3058 Mdot
.622 .30586 Mdot
.622 .30592 Mdot
.622 .30594 Mdot
.622 .30595 Mdot
.622 .30596 Mdot
.622 .30597 Mdot
.622 .30597 Mdot
.622 .30602 Mdot
.622 .30603 Mdot
.622 .30609 Mdot
.622 .3061 Mdot
.622 .30624 Mdot
.622 .30624 Mdot
.622 .30626 Mdot
.622 .30627 Mdot
.622 .30636 Mdot
.622 .30645 Mdot
.622 .30664 Mdot
.622 .3067 Mdot
.622 .3067 Mdot
.622 .30671 Mdot
.622 .30674 Mdot
.622 .30676 Mdot
.622 .30678 Mdot
.622 .30688 Mdot
.622 .30693 Mdot
.622 .30695 Mdot
.622 .30695 Mdot
.622 .30696 Mdot
.622 .30698 Mdot
.622 .30701 Mdot
.622 .30717 Mdot
.622 .3072 Mdot
.622 .30721 Mdot
.622 .30724 Mdot
.622 .30724 Mdot
.622 .30731 Mdot
.622 .30731 Mdot
.622 .30746 Mdot
.622 .30752 Mdot
.622 .30763 Mdot
.622 .30779 Mdot
.622 .308 Mdot
.622 .30815 Mdot
.622 .30824 Mdot
.622 .30833 Mdot
.622 .30846 Mdot
.622 .30855 Mdot
.622 .30877 Mdot
.622 .309 Mdot
.622 .30909 Mdot
.622 .30917 Mdot
.622 .3093 Mdot
.622 .30934 Mdot
.622 .30935 Mdot
.622 .30937 Mdot
.622 .30945 Mdot
.622 .30945 Mdot
.622 .3096 Mdot
.622 .30967 Mdot
.622 .30968 Mdot
.622 .30968 Mdot
.622 .30971 Mdot
.622 .30973 Mdot
.622 .30976 Mdot
.622 .30978 Mdot
.622 .30987 Mdot
.622 .30996 Mdot
.622 .30998 Mdot
.622 .30998 Mdot
.622 .30999 Mdot
.622 .31012 Mdot
.622 .31021 Mdot
.622 .31027 Mdot
.622 .31033 Mdot
.622 .31033 Mdot
.622 .31033 Mdot
.622 .31036 Mdot
.622 .31036 Mdot
.622 .31039 Mdot
.622 .31039 Mdot
.622 .31039 Mdot
.622 .31044 Mdot
.622 .31048 Mdot
.622 .31049 Mdot
.622 .31051 Mdot
.622 .31052 Mdot
.622 .31053 Mdot
.622 .31061 Mdot
.622 .31068 Mdot
.622 .31069 Mdot
.622 .31077 Mdot
.622 .31081 Mdot
.622 .31103 Mdot
.622 .31104 Mdot
.622 .31109 Mdot
.622 .3111 Mdot
.622 .31115 Mdot
.622 .31133 Mdot
.622 .31133 Mdot
.622 .31167 Mdot
.622 .31183 Mdot
.622 .31191 Mdot
.622 .31199 Mdot
.622 .31199 Mdot
.622 .31203 Mdot
.622 .31205 Mdot
.622 .31212 Mdot
.622 .31214 Mdot
.622 .31217 Mdot
.622 .31217 Mdot
.622 .31217 Mdot
.622 .31223 Mdot
.622 .31229 Mdot
.622 .31232 Mdot
.622 .31242 Mdot
.622 .31247 Mdot
.622 .31256 Mdot
.622 .31268 Mdot
.622 .31268 Mdot
.622 .31273 Mdot
.622 .31274 Mdot
.622 .31275 Mdot
.622 .31279 Mdot
.622 .31282 Mdot
.622 .31289 Mdot
.622 .31303 Mdot
.622 .3131 Mdot
.622 .31325 Mdot
.622 .31327 Mdot
.622 .31333 Mdot
.622 .31337 Mdot
.622 .31338 Mdot
.622 .31338 Mdot
.622 .3134 Mdot
.622 .31342 Mdot
.622 .31344 Mdot
.622 .31345 Mdot
.622 .3135 Mdot
.622 .31359 Mdot
.622 .3136 Mdot
.622 .31368 Mdot
.622 .31372 Mdot
.622 .31381 Mdot
.622 .31382 Mdot
.622 .31396 Mdot
.622 .314 Mdot
.622 .3141 Mdot
.622 .31419 Mdot
.622 .31436 Mdot
.622 .31458 Mdot
.622 .31475 Mdot
.622 .31524 Mdot
.622 .31539 Mdot
.622 .31541 Mdot
.622 .3156 Mdot
.622 .31582 Mdot
.622 .31582 Mdot
.622 .31595 Mdot
.622 .31599 Mdot
.622 .31604 Mdot
.622 .31609 Mdot
.622 .31611 Mdot
.622 .31634 Mdot
.622 .31656 Mdot
.622 .31665 Mdot
.622 .31675 Mdot
.622 .31692 Mdot
.622 .31695 Mdot
.622 .31708 Mdot
.622 .31712 Mdot
.622 .31732 Mdot
.622 .31733 Mdot
.622 .31736 Mdot
.622 .3174 Mdot
.622 .31744 Mdot
.622 .31752 Mdot
.622 .31764 Mdot
.622 .31765 Mdot
.622 .31765 Mdot
.622 .31766 Mdot
.622 .31772 Mdot
.622 .31773 Mdot
.622 .31779 Mdot
.622 .31781 Mdot
.622 .31781 Mdot
.622 .31786 Mdot
.622 .31794 Mdot
.622 .31806 Mdot
.622 .31808 Mdot
.622 .31831 Mdot
.622 .31836 Mdot
.622 .31846 Mdot
.622 .31847 Mdot
.622 .31853 Mdot
.622 .31861 Mdot
.622 .31863 Mdot
.622 .31864 Mdot
.622 .31867 Mdot
.622 .31872 Mdot
.622 .31872 Mdot
.622 .31889 Mdot
.622 .31907 Mdot
.622 .31911 Mdot
.622 .31916 Mdot
.622 .31922 Mdot
.622 .31925 Mdot
.622 .31927 Mdot
.622 .31927 Mdot
.622 .31928 Mdot
.622 .35985 Mdot
.622 .35986 Mdot
.622 .35986 Mdot
.622 .35987 Mdot
.622 .3599 Mdot
.622 .35995 Mdot
.622 .35999 Mdot
.622 .36002 Mdot
.622 .36016 Mdot
.622 .3603 Mdot
.622 .3603 Mdot
.622 .36034 Mdot
.622 .36037 Mdot
.622 .36037 Mdot
.622 .36039 Mdot
.622 .36046 Mdot
.622 .3605 Mdot
.622 .36051 Mdot
.622 .36059 Mdot
.622 .36063 Mdot
.622 .36081 Mdot
.622 .36083 Mdot
.622 .36093 Mdot
.622 .36099 Mdot
.622 .36104 Mdot
.622 .36104 Mdot
.622 .36105 Mdot
.622 .3611 Mdot
.622 .36111 Mdot
.622 .36115 Mdot
.622 .36116 Mdot
.622 .36116 Mdot
.622 .36117 Mdot
.622 .36126 Mdot
.622 .36133 Mdot
.622 .36136 Mdot
.622 .36139 Mdot
.622 .36142 Mdot
.622 .36142 Mdot
.622 .36159 Mdot
.622 .36162 Mdot
.622 .36173 Mdot
.622 .36175 Mdot
.622 .36188 Mdot
.622 .36196 Mdot
.622 .36204 Mdot
.622 .36221 Mdot
.622 .3624 Mdot
.622 .36242 Mdot
.622 .36245 Mdot
.622 .3625 Mdot
.622 .36252 Mdot
.622 .36263 Mdot
.622 .36264 Mdot
.622 .36281 Mdot
.622 .36296 Mdot
.622 .36298 Mdot
.622 .3631 Mdot
.622 .36349 Mdot
.622 .36363 Mdot
.622 .36381 Mdot
.622 .36394 Mdot
.622 .36401 Mdot
.622 .36409 Mdot
.622 .36412 Mdot
.622 .36424 Mdot
.622 .36424 Mdot
.622 .36432 Mdot
.622 .36435 Mdot
.622 .36442 Mdot
.622 .36442 Mdot
.622 .3645 Mdot
.622 .36454 Mdot
.622 .36455 Mdot
.622 .36456 Mdot
.622 .36458 Mdot
.622 .36459 Mdot
.622 .36459 Mdot
.622 .3646 Mdot
.622 .36463 Mdot
.622 .36469 Mdot
.622 .3647 Mdot
.622 .36482 Mdot
.622 .36487 Mdot
.622 .36499 Mdot
.622 .36504 Mdot
.622 .36507 Mdot
.622 .3651 Mdot
.622 .36511 Mdot
.622 .36512 Mdot
.622 .36516 Mdot
.622 .36516 Mdot
.622 .36526 Mdot
.622 .36533 Mdot
.622 .36536 Mdot
.622 .36545 Mdot
.622 .36547 Mdot
.622 .36552 Mdot
.622 .36556 Mdot
.622 .36556 Mdot
.622 .36557 Mdot
.622 .36559 Mdot
.622 .3656 Mdot
.622 .36567 Mdot
.622 .36568 Mdot
.622 .36571 Mdot
.622 .36571 Mdot
.622 .36577 Mdot
.622 .36584 Mdot
.622 .36596 Mdot
.622 .36624 Mdot
.622 .36624 Mdot
.622 .36638 Mdot
.622 .36643 Mdot
.622 .36644 Mdot
.622 .36647 Mdot
.622 .36648 Mdot
.622 .36666 Mdot
.622 .3667 Mdot
.622 .36675 Mdot
.622 .36676 Mdot
.622 .36682 Mdot
.622 .36689 Mdot
.622 .36689 Mdot
.622 .3669 Mdot
.622 .36691 Mdot
.622 .36693 Mdot
.622 .36695 Mdot
.622 .36699 Mdot
.622 .367 Mdot
.622 .367 Mdot
.622 .36702 Mdot
.622 .36702 Mdot
.622 .36704 Mdot
.622 .36705 Mdot
.622 .36705 Mdot
.622 .36709 Mdot
.622 .36714 Mdot
.622 .36722 Mdot
.622 .36732 Mdot
.622 .36733 Mdot
.622 .36733 Mdot
.622 .36734 Mdot
.622 .36741 Mdot
.622 .36749 Mdot
.622 .3675 Mdot
.622 .36752 Mdot
.622 .36754 Mdot
.622 .36757 Mdot
.622 .36757 Mdot
.622 .36757 Mdot
.622 .36764 Mdot
.622 .36775 Mdot
.622 .36775 Mdot
.622 .36782 Mdot
.622 .36784 Mdot
.622 .36784 Mdot
.622 .36788 Mdot
.622 .36798 Mdot
.622 .36804 Mdot
.622 .36811 Mdot
.622 .3683 Mdot
.622 .36848 Mdot
.622 .36855 Mdot
.622 .36865 Mdot
.622 .36873 Mdot
.622 .3688 Mdot
.622 .36892 Mdot
.622 .36909 Mdot
.622 .36922 Mdot
.622 .3693 Mdot
.622 .36935 Mdot
.622 .36947 Mdot
.622 .36947 Mdot
.622 .36953 Mdot
.622 .36953 Mdot
.622 .36955 Mdot
.622 .36956 Mdot
.622 .36958 Mdot
.622 .36971 Mdot
.622 .36973 Mdot
.622 .36976 Mdot
.622 .36976 Mdot
.622 .36976 Mdot
.622 .36978 Mdot
.622 .36982 Mdot
.622 .3699 Mdot
.622 .36991 Mdot
.622 .36993 Mdot
.622 .36995 Mdot
.622 .36996 Mdot
.622 .36997 Mdot
.622 .37001 Mdot
.622 .37016 Mdot
.622 .37023 Mdot
.622 .37031 Mdot
.622 .37032 Mdot
.622 .37033 Mdot
.622 .37033 Mdot
.622 .37045 Mdot
.622 .37045 Mdot
.622 .3705 Mdot
.622 .37051 Mdot
.622 .37055 Mdot
.622 .37055 Mdot
.622 .37056 Mdot
.622 .37057 Mdot
.622 .37057 Mdot
.622 .37059 Mdot
.622 .37064 Mdot
.622 .37068 Mdot
.622 .37069 Mdot
.622 .37072 Mdot
.622 .37075 Mdot
.622 .37077 Mdot
.622 .37078 Mdot
.622 .37079 Mdot
.622 .37079 Mdot
.622 .37082 Mdot
.622 .37089 Mdot
.622 .3709 Mdot
.622 .3709 Mdot
.622 .37092 Mdot
.622 .37096 Mdot
.622 .3712 Mdot
.622 .37124 Mdot
.622 .37127 Mdot
.622 .37135 Mdot
.622 .37142 Mdot
.622 .37151 Mdot
.622 .37153 Mdot
.622 .37158 Mdot
.622 .37158 Mdot
.622 .37161 Mdot
.622 .37161 Mdot
.622 .37162 Mdot
.622 .37163 Mdot
.622 .37168 Mdot
.622 .37169 Mdot
.622 .37177 Mdot
.622 .37177 Mdot
.622 .37178 Mdot
.622 .37179 Mdot
.622 .37187 Mdot
.622 .37193 Mdot
.622 .37194 Mdot
.622 .37194 Mdot
.622 .37194 Mdot
.622 .37203 Mdot
.622 .37204 Mdot
.622 .37204 Mdot
.622 .37207 Mdot
.622 .37209 Mdot
.622 .37211 Mdot
.622 .37213 Mdot
.622 .37213 Mdot
.622 .37218 Mdot
.622 .37218 Mdot
.622 .37219 Mdot
.622 .37237 Mdot
.622 .37244 Mdot
.622 .37248 Mdot
.622 .37261 Mdot
.622 .37261 Mdot
.622 .37265 Mdot
.622 .37267 Mdot
.622 .37268 Mdot
.622 .37279 Mdot
.622 .3729 Mdot
.622 .37292 Mdot
.622 .37297 Mdot
.622 .37302 Mdot
.622 .37304 Mdot
.622 .37313 Mdot
.622 .37318 Mdot
.622 .37321 Mdot
.622 .37329 Mdot
.622 .37337 Mdot
.622 .37341 Mdot
.622 .37341 Mdot
.622 .37357 Mdot
.622 .37369 Mdot
.622 .37372 Mdot
.622 .37374 Mdot
.622 .37376 Mdot
.622 .37378 Mdot
.622 .37378 Mdot
.622 .37384 Mdot
.622 .37384 Mdot
.622 .37385 Mdot
.622 .37389 Mdot
.622 .37404 Mdot
.622 .37405 Mdot
.622 .37406 Mdot
.622 .37411 Mdot
.622 .37422 Mdot
.622 .37432 Mdot
.622 .3745 Mdot
.622 .37451 Mdot
.622 .37452 Mdot
.622 .37457 Mdot
.622 .37459 Mdot
.622 .37459 Mdot
.622 .3746 Mdot
.622 .37463 Mdot
.622 .37466 Mdot
.622 .37468 Mdot
.622 .37473 Mdot
.622 .37473 Mdot
.622 .37474 Mdot
.622 .37477 Mdot
.622 .37488 Mdot
.622 .37488 Mdot
.622 .37489 Mdot
.622 .3749 Mdot
.622 .37499 Mdot
.622 .37512 Mdot
.622 .37513 Mdot
.622 .37514 Mdot
.622 .37515 Mdot
.622 .37527 Mdot
.622 .37528 Mdot
.622 .37537 Mdot
.622 .37538 Mdot
.622 .37539 Mdot
.622 .3754 Mdot
.622 .3754 Mdot
.622 .37544 Mdot
.622 .37544 Mdot
.622 .37552 Mdot
.622 .37555 Mdot
.622 .3756 Mdot
.622 .37569 Mdot
.622 .37579 Mdot
.622 .37587 Mdot
.622 .37592 Mdot
.622 .37597 Mdot
.622 .37603 Mdot
.622 .37608 Mdot
.622 .37619 Mdot
.622 .37632 Mdot
.622 .37636 Mdot
.622 .3764 Mdot
.622 .37647 Mdot
.622 .37649 Mdot
.622 .3765 Mdot
.622 .37651 Mdot
.622 .37655 Mdot
.622 .37655 Mdot
.622 .37662 Mdot
.622 .37666 Mdot
.622 .37667 Mdot
.622 .37667 Mdot
.622 .37669 Mdot
.622 .3767 Mdot
.622 .37671 Mdot
.622 .37672 Mdot
.622 .37677 Mdot
.622 .37682 Mdot
.622 .37682 Mdot
.622 .37683 Mdot
.622 .37683 Mdot
.622 .37689 Mdot
.622 .37694 Mdot
.622 .37698 Mdot
.622 .377 Mdot
.622 .377 Mdot
.622 .37701 Mdot
.622 .37702 Mdot
.622 .37702 Mdot
.622 .37704 Mdot
.622 .37704 Mdot
.622 .37704 Mdot
.622 .37707 Mdot
.622 .37708 Mdot
.622 .37709 Mdot
.622 .3771 Mdot
.622 .37711 Mdot
.622 .37711 Mdot
.622 .37715 Mdot
.622 .37719 Mdot
.622 .3772 Mdot
.622 .37723 Mdot
.622 .37725 Mdot
.622 .37737 Mdot
.622 .37738 Mdot
.622 .3774 Mdot
.622 .37741 Mdot
.622 .37743 Mdot
.622 .37752 Mdot
.622 .37753 Mdot
.622 .3777 Mdot
.622 .37779 Mdot
.622 .37783 Mdot
.622 .37787 Mdot
.622 .37787 Mdot
.622 .37789 Mdot
.622 .3779 Mdot
.622 .37794 Mdot
.622 .37795 Mdot
.622 .37796 Mdot
.622 .37796 Mdot
.622 .37796 Mdot
.622 .37799 Mdot
.622 .37802 Mdot
.622 .37804 Mdot
.622 .37812 Mdot
.622 .37816 Mdot
.622 .37823 Mdot
.622 .37823 Mdot
.622 .37825 Mdot
.622 .37826 Mdot
.622 .37826 Mdot
.622 .37828 Mdot
.622 .3783 Mdot
.622 .37833 Mdot
.622 .37841 Mdot
.622 .37845 Mdot
.622 .37852 Mdot
.622 .37853 Mdot
.622 .37856 Mdot
.622 .37858 Mdot
.622 .37859 Mdot
.622 .37859 Mdot
.622 .3786 Mdot
.622 .37861 Mdot
.622 .37862 Mdot
.622 .37863 Mdot
.622 .37865 Mdot
.622 .3787 Mdot
.622 .3787 Mdot
.622 .37875 Mdot
.622 .37877 Mdot
.622 .37882 Mdot
.622 .37882 Mdot
.622 .37889 Mdot
.622 .37891 Mdot
.622 .37896 Mdot
.622 .37901 Mdot
.622 .3791 Mdot
.622 .37921 Mdot
.622 .3793 Mdot
.622 .37956 Mdot
.622 .37964 Mdot
.622 .37964 Mdot
.622 .37975 Mdot
.622 .37986 Mdot
.622 .37986 Mdot
.622 .37993 Mdot
.622 .37994 Mdot
.622 .37997 Mdot
.622 .38 Mdot
.622 .38001 Mdot
.622 .38013 Mdot
.622 .38024 Mdot
.622 .38029 Mdot
.622 .38034 Mdot
.622 .38043 Mdot
.622 .38044 Mdot
.622 .38051 Mdot
.622 .38053 Mdot
.622 .38064 Mdot
.622 .38064 Mdot
.622 .38066 Mdot
.622 .38068 Mdot
.622 .3807 Mdot
.622 .38074 Mdot
.622 .3808 Mdot
.622 .38081 Mdot
.622 .38081 Mdot
.622 .38081 Mdot
.622 .38084 Mdot
.622 .38085 Mdot
.622 .38088 Mdot
.622 .38089 Mdot
.622 .38089 Mdot
.622 .38092 Mdot
.622 .38096 Mdot
.622 .38102 Mdot
.622 .38103 Mdot
.622 .38115 Mdot
.622 .38118 Mdot
.622 .38123 Mdot
.622 .38124 Mdot
.622 .38126 Mdot
.622 .3813 Mdot
.622 .38132 Mdot
.622 .38132 Mdot
.622 .38134 Mdot
.622 .38136 Mdot
.622 .38136 Mdot
.622 .38145 Mdot
.622 .38155 Mdot
.622 .38156 Mdot
.622 .38159 Mdot
.622 .38162 Mdot
.622 .38164 Mdot
.622 .38165 Mdot
.622 .38165 Mdot
.622 .38165 Mdot
.624 .2916 Mdot
.624 .2918 Mdot
.624 .29181 Mdot
.624 .29185 Mdot
.624 .2919 Mdot
.624 .29192 Mdot
.624 .29193 Mdot
.624 .29193 Mdot
.624 .29194 Mdot
.624 .29208 Mdot
.624 .29209 Mdot
.624 .29209 Mdot
.624 .29209 Mdot
.624 .29209 Mdot
.624 .2921 Mdot
.624 .29219 Mdot
.624 .29223 Mdot
.624 .29223 Mdot
.624 .29225 Mdot
.624 .29236 Mdot
.624 .29238 Mdot
.624 .29248 Mdot
.624 .29252 Mdot
.624 .29254 Mdot
.624 .29259 Mdot
.624 .29264 Mdot
.624 .29274 Mdot
.624 .29282 Mdot
.624 .29284 Mdot
.624 .29298 Mdot
.624 .29305 Mdot
.624 .29328 Mdot
.624 .29328 Mdot
.624 .29329 Mdot
.624 .29329 Mdot
.624 .29332 Mdot
.624 .29333 Mdot
.624 .29336 Mdot
.624 .29338 Mdot
.624 .29341 Mdot
.624 .29346 Mdot
.624 .29347 Mdot
.624 .29361 Mdot
.624 .29365 Mdot
.624 .29366 Mdot
.624 .29371 Mdot
.624 .29382 Mdot
.624 .29384 Mdot
.624 .29393 Mdot
.624 .29397 Mdot
.624 .29401 Mdot
.624 .29401 Mdot
.624 .29418 Mdot
.624 .29429 Mdot
.624 .29442 Mdot
.624 .29445 Mdot
.624 .29449 Mdot
.624 .29454 Mdot
.624 .29474 Mdot
.624 .29478 Mdot
.624 .29478 Mdot
.624 .29486 Mdot
.624 .29487 Mdot
.624 .29488 Mdot
.624 .29488 Mdot
.624 .29495 Mdot
.624 .29496 Mdot
.624 .29498 Mdot
.624 .29501 Mdot
.624 .29502 Mdot
.624 .29506 Mdot
.624 .29512 Mdot
.624 .2952 Mdot
.624 .29525 Mdot
.624 .29526 Mdot
.624 .29528 Mdot
.624 .29542 Mdot
.624 .29544 Mdot
.624 .29546 Mdot
.624 .29551 Mdot
.624 .29557 Mdot
.624 .29559 Mdot
.624 .29566 Mdot
.624 .29579 Mdot
.624 .29596 Mdot
.624 .29603 Mdot
.624 .2962 Mdot
.624 .29623 Mdot
.624 .29638 Mdot
.624 .29639 Mdot
.624 .29642 Mdot
.624 .29645 Mdot
.624 .29645 Mdot
.624 .29658 Mdot
.624 .29662 Mdot
.624 .29664 Mdot
.624 .29665 Mdot
.624 .29668 Mdot
.624 .29668 Mdot
.624 .29668 Mdot
.624 .29668 Mdot
.624 .29672 Mdot
.624 .29672 Mdot
.624 .29697 Mdot
.624 .29704 Mdot
.624 .29716 Mdot
.624 .29726 Mdot
.624 .29728 Mdot
.624 .29731 Mdot
.624 .29731 Mdot
.624 .29732 Mdot
.624 .29733 Mdot
.624 .29734 Mdot
.624 .29734 Mdot
.624 .29752 Mdot
.624 .29756 Mdot
.624 .29765 Mdot
.624 .29767 Mdot
.624 .29771 Mdot
.624 .29782 Mdot
.624 .29783 Mdot
.624 .29783 Mdot
.624 .29783 Mdot
.624 .29783 Mdot
.624 .29789 Mdot
.624 .29789 Mdot
.624 .29789 Mdot
.624 .29791 Mdot
.624 .29793 Mdot
.624 .29794 Mdot
.624 .29807 Mdot
.624 .29815 Mdot
.624 .2982 Mdot
.624 .29826 Mdot
.624 .29833 Mdot
.624 .29833 Mdot
.624 .29833 Mdot
.624 .29838 Mdot
.624 .29845 Mdot
.624 .29847 Mdot
.624 .29849 Mdot
.624 .29857 Mdot
.624 .29864 Mdot
.624 .29866 Mdot
.624 .29876 Mdot
.624 .2988 Mdot
.624 .29884 Mdot
.624 .29889 Mdot
.624 .29891 Mdot
.624 .29891 Mdot
.624 .29898 Mdot
.624 .29899 Mdot
.624 .29903 Mdot
.624 .29904 Mdot
.624 .29906 Mdot
.624 .29918 Mdot
.624 .29923 Mdot
.624 .29924 Mdot
.624 .29926 Mdot
.624 .29928 Mdot
.624 .29936 Mdot
.624 .29946 Mdot
.624 .29948 Mdot
.624 .29949 Mdot
.624 .29955 Mdot
.624 .29957 Mdot
.624 .29957 Mdot
.624 .29958 Mdot
.624 .29974 Mdot
.624 .29979 Mdot
.624 .30004 Mdot
.624 .30005 Mdot
.624 .30007 Mdot
.624 .30015 Mdot
.624 .30015 Mdot
.624 .30016 Mdot
.624 .30018 Mdot
.624 .30028 Mdot
.624 .30028 Mdot
.624 .30036 Mdot
.624 .30043 Mdot
.624 .30056 Mdot
.624 .30063 Mdot
.624 .30063 Mdot
.624 .30066 Mdot
.624 .30067 Mdot
.624 .30068 Mdot
.624 .30073 Mdot
.624 .30077 Mdot
.624 .30079 Mdot
.624 .3009 Mdot
.624 .30091 Mdot
.624 .30094 Mdot
.624 .30097 Mdot
.624 .30105 Mdot
.624 .30113 Mdot
.624 .30131 Mdot
.624 .30135 Mdot
.624 .30135 Mdot
.624 .30136 Mdot
.624 .30144 Mdot
.624 .30155 Mdot
.624 .30159 Mdot
.624 .3016 Mdot
.624 .30164 Mdot
.624 .30171 Mdot
.624 .30176 Mdot
.624 .30179 Mdot
.624 .30179 Mdot
.624 .30181 Mdot
.624 .30183 Mdot
.624 .30185 Mdot
.624 .30185 Mdot
.624 .3019 Mdot
.624 .30193 Mdot
.624 .30196 Mdot
.624 .30199 Mdot
.624 .30207 Mdot
.624 .30208 Mdot
.624 .30219 Mdot
.624 .30219 Mdot
.624 .30221 Mdot
.624 .30223 Mdot
.624 .30229 Mdot
.624 .30231 Mdot
.624 .30232 Mdot
.624 .30243 Mdot
.624 .30248 Mdot
.624 .30253 Mdot
.624 .30265 Mdot
.624 .30268 Mdot
.624 .30271 Mdot
.624 .30279 Mdot
.624 .3028 Mdot
.624 .30287 Mdot
.624 .30287 Mdot
.624 .30294 Mdot
.624 .30299 Mdot
.624 .30301 Mdot
.624 .30304 Mdot
.624 .30305 Mdot
.624 .30308 Mdot
.624 .30309 Mdot
.624 .3031 Mdot
.624 .30312 Mdot
.624 .30312 Mdot
.624 .30318 Mdot
.624 .30322 Mdot
.624 .30325 Mdot
.624 .30325 Mdot
.624 .30341 Mdot
.624 .30343 Mdot
.624 .30355 Mdot
.624 .3036 Mdot
.624 .30365 Mdot
.624 .30369 Mdot
.624 .3037 Mdot
.624 .30377 Mdot
.624 .30378 Mdot
.624 .3038 Mdot
.624 .30384 Mdot
.624 .30385 Mdot
.624 .30387 Mdot
.624 .30387 Mdot
.624 .30391 Mdot
.624 .304 Mdot
.624 .30409 Mdot
.624 .30417 Mdot
.624 .30418 Mdot
.624 .30418 Mdot
.624 .30423 Mdot
.624 .30425 Mdot
.624 .30441 Mdot
.624 .30444 Mdot
.624 .30454 Mdot
.624 .30455 Mdot
.624 .30456 Mdot
.624 .30462 Mdot
.624 .30468 Mdot
.624 .3048 Mdot
.624 .3049 Mdot
.624 .30493 Mdot
.624 .30497 Mdot
.624 .30502 Mdot
.624 .30507 Mdot
.624 .30515 Mdot
.624 .30519 Mdot
.624 .30524 Mdot
.624 .30525 Mdot
.624 .30531 Mdot
.624 .30535 Mdot
.624 .30543 Mdot
.624 .30546 Mdot
.624 .30551 Mdot
.624 .30559 Mdot
.624 .30562 Mdot
.624 .30563 Mdot
.624 .30563 Mdot
.624 .30567 Mdot
.624 .30567 Mdot
.624 .30567 Mdot
.624 .30567 Mdot
.624 .30577 Mdot
.624 .30578 Mdot
.624 .30598 Mdot
.624 .30599 Mdot
.624 .306 Mdot
.624 .306 Mdot
.624 .306 Mdot
.624 .30602 Mdot
.624 .30603 Mdot
.624 .3061 Mdot
.624 .30622 Mdot
.624 .30622 Mdot
.624 .30638 Mdot
.624 .30638 Mdot
.624 .3064 Mdot
.624 .3064 Mdot
.624 .30641 Mdot
.624 .30641 Mdot
.624 .30643 Mdot
.624 .30643 Mdot
.624 .30647 Mdot
.624 .30655 Mdot
.624 .30657 Mdot
.624 .30659 Mdot
.624 .3066 Mdot
.624 .30669 Mdot
.624 .30671 Mdot
.624 .30698 Mdot
.624 .30706 Mdot
.624 .30719 Mdot
.624 .3073 Mdot
.624 .30732 Mdot
.624 .30732 Mdot
.624 .30735 Mdot
.624 .30745 Mdot
.624 .30747 Mdot
.624 .3075 Mdot
.624 .30765 Mdot
.624 .30778 Mdot
.624 .30781 Mdot
.624 .30784 Mdot
.624 .30786 Mdot
.624 .30794 Mdot
.624 .30812 Mdot
.624 .30814 Mdot
.624 .30817 Mdot
.624 .30823 Mdot
.624 .30824 Mdot
.624 .30835 Mdot
.624 .30835 Mdot
.624 .30838 Mdot
.624 .30846 Mdot
.624 .30852 Mdot
.624 .30858 Mdot
.624 .30874 Mdot
.624 .30878 Mdot
.624 .30888 Mdot
.624 .309 Mdot
.624 .30903 Mdot
.624 .30907 Mdot
.624 .30918 Mdot
.624 .30925 Mdot
.624 .30926 Mdot
.624 .30926 Mdot
.624 .30929 Mdot
.624 .30936 Mdot
.624 .30946 Mdot
.624 .30954 Mdot
.624 .30966 Mdot
.624 .30986 Mdot
.624 .30988 Mdot
.624 .30992 Mdot
.624 .30993 Mdot
.624 .30994 Mdot
.624 .30994 Mdot
.624 .31004 Mdot
.624 .31004 Mdot
.624 .31004 Mdot
.624 .31004 Mdot
.624 .31005 Mdot
.624 .31022 Mdot
.624 .31029 Mdot
.624 .31031 Mdot
.624 .31046 Mdot
.624 .31052 Mdot
.624 .3108 Mdot
.624 .3108 Mdot
.624 .31081 Mdot
.624 .31083 Mdot
.624 .31084 Mdot
.624 .31085 Mdot
.624 .31089 Mdot
.624 .31092 Mdot
.624 .31108 Mdot
.624 .31127 Mdot
.624 .31138 Mdot
.624 .31176 Mdot
.624 .31177 Mdot
.624 .31182 Mdot
.624 .31183 Mdot
.624 .31183 Mdot
.624 .31183 Mdot
.624 .31188 Mdot
.624 .31188 Mdot
.624 .31192 Mdot
.624 .31198 Mdot
.624 .31218 Mdot
.624 .31219 Mdot
.624 .31224 Mdot
.624 .31228 Mdot
.624 .31229 Mdot
.624 .31252 Mdot
.624 .31257 Mdot
.624 .31284 Mdot
.624 .31295 Mdot
.624 .31322 Mdot
.624 .31341 Mdot
.624 .31352 Mdot
.624 .31355 Mdot
.624 .31365 Mdot
.624 .31372 Mdot
.624 .31376 Mdot
.624 .31379 Mdot
.624 .31401 Mdot
.624 .31404 Mdot
.624 .31405 Mdot
.624 .31413 Mdot
.624 .31426 Mdot
.624 .31435 Mdot
.624 .31441 Mdot
.624 .31442 Mdot
.624 .31447 Mdot
.624 .31451 Mdot
.624 .31452 Mdot
.624 .31462 Mdot
.624 .31463 Mdot
.624 .31464 Mdot
.624 .31466 Mdot
.624 .31478 Mdot
.624 .31479 Mdot
.624 .31485 Mdot
.624 .31515 Mdot
.624 .31523 Mdot
.624 .3153 Mdot
.624 .31535 Mdot
.624 .31555 Mdot
.624 .31572 Mdot
.624 .31599 Mdot
.624 .31599 Mdot
.624 .31605 Mdot
.624 .31611 Mdot
.624 .31625 Mdot
.624 .31628 Mdot
.624 .31645 Mdot
.624 .31654 Mdot
.624 .31655 Mdot
.624 .31661 Mdot
.624 .31682 Mdot
.624 .31684 Mdot
.624 .31692 Mdot
.624 .31696 Mdot
.624 .317 Mdot
.624 .31704 Mdot
.624 .31705 Mdot
.624 .3171 Mdot
.624 .31711 Mdot
.624 .31712 Mdot
.624 .31712 Mdot
.624 .31749 Mdot
.624 .31759 Mdot
.624 .3178 Mdot
.624 .31784 Mdot
.624 .31797 Mdot
.624 .31813 Mdot
.624 .3182 Mdot
.624 .31828 Mdot
.624 .31831 Mdot
.624 .31837 Mdot
.624 .31853 Mdot
.624 .31855 Mdot
.624 .31873 Mdot
.624 .31876 Mdot
.624 .31876 Mdot
.624 .31882 Mdot
.624 .31896 Mdot
.624 .31897 Mdot
.624 .31897 Mdot
.624 .31897 Mdot
.624 .31898 Mdot
.624 .31899 Mdot
.624 .31922 Mdot
.624 .31923 Mdot
.624 .31923 Mdot
.624 .31923 Mdot
.624 .31927 Mdot
.624 .31935 Mdot
.624 .31942 Mdot
.624 .31943 Mdot
.624 .31973 Mdot
.624 .36027 Mdot
.624 .36052 Mdot
.624 .36053 Mdot
.624 .36058 Mdot
.624 .36064 Mdot
.624 .36067 Mdot
.624 .36067 Mdot
.624 .36067 Mdot
.624 .36069 Mdot
.624 .36087 Mdot
.624 .36087 Mdot
.624 .36088 Mdot
.624 .36088 Mdot
.624 .36088 Mdot
.624 .36089 Mdot
.624 .361 Mdot
.624 .36105 Mdot
.624 .36105 Mdot
.624 .36108 Mdot
.624 .36122 Mdot
.624 .36124 Mdot
.624 .36136 Mdot
.624 .36141 Mdot
.624 .36143 Mdot
.624 .3615 Mdot
.624 .36156 Mdot
.624 .36169 Mdot
.624 .36179 Mdot
.624 .36182 Mdot
.624 .36199 Mdot
.624 .36207 Mdot
.624 .36236 Mdot
.624 .36236 Mdot
.624 .36238 Mdot
.624 .36238 Mdot
.624 .36242 Mdot
.624 .36243 Mdot
.624 .36246 Mdot
.624 .36249 Mdot
.624 .36253 Mdot
.624 .36259 Mdot
.624 .36261 Mdot
.624 .36277 Mdot
.624 .36282 Mdot
.624 .36283 Mdot
.624 .3629 Mdot
.624 .36304 Mdot
.624 .36306 Mdot
.624 .36317 Mdot
.624 .36323 Mdot
.624 .36327 Mdot
.624 .36327 Mdot
.624 .36349 Mdot
.624 .36363 Mdot
.624 .36379 Mdot
.624 .36383 Mdot
.624 .36388 Mdot
.624 .36394 Mdot
.624 .36419 Mdot
.624 .36423 Mdot
.624 .36424 Mdot
.624 .36434 Mdot
.624 .36435 Mdot
.624 .36436 Mdot
.624 .36437 Mdot
.624 .36445 Mdot
.624 .36446 Mdot
.624 .36449 Mdot
.624 .36453 Mdot
.624 .36454 Mdot
.624 .36459 Mdot
.624 .36466 Mdot
.624 .36477 Mdot
.624 .36483 Mdot
.624 .36483 Mdot
.624 .36486 Mdot
.624 .36504 Mdot
.624 .36505 Mdot
.624 .36509 Mdot
.624 .36515 Mdot
.624 .36522 Mdot
.624 .36525 Mdot
.624 .36534 Mdot
.624 .36549 Mdot
.624 .36571 Mdot
.624 .3658 Mdot
.624 .36601 Mdot
.624 .36605 Mdot
.624 .36624 Mdot
.624 .36625 Mdot
.624 .36628 Mdot
.624 .36632 Mdot
.624 .36633 Mdot
.624 .36648 Mdot
.624 .36653 Mdot
.624 .36656 Mdot
.624 .36657 Mdot
.624 .3666 Mdot
.624 .3666 Mdot
.624 .36661 Mdot
.624 .36661 Mdot
.624 .36665 Mdot
.624 .36666 Mdot
.624 .36696 Mdot
.624 .36705 Mdot
.624 .3672 Mdot
.624 .36733 Mdot
.624 .36736 Mdot
.624 .36739 Mdot
.624 .3674 Mdot
.624 .3674 Mdot
.624 .36742 Mdot
.624 .36743 Mdot
.624 .36743 Mdot
.624 .36765 Mdot
.624 .36771 Mdot
.624 .36782 Mdot
.624 .36784 Mdot
.624 .36789 Mdot
.624 .36803 Mdot
.624 .36804 Mdot
.624 .36804 Mdot
.624 .36804 Mdot
.624 .36804 Mdot
.624 .36812 Mdot
.624 .36812 Mdot
.624 .36812 Mdot
.624 .36814 Mdot
.624 .36816 Mdot
.624 .36818 Mdot
.624 .36834 Mdot
.624 .36844 Mdot
.624 .36851 Mdot
.624 .36859 Mdot
.624 .36866 Mdot
.624 .36866 Mdot
.624 .36867 Mdot
.624 .36873 Mdot
.624 .36882 Mdot
.624 .36885 Mdot
.624 .36887 Mdot
.624 .36897 Mdot
.624 .36905 Mdot
.624 .36908 Mdot
.624 .36921 Mdot
.624 .36926 Mdot
.624 .3693 Mdot
.624 .36937 Mdot
.624 .36939 Mdot
.624 .3694 Mdot
.624 .36948 Mdot
.624 .36949 Mdot
.624 .36954 Mdot
.624 .36956 Mdot
.624 .36958 Mdot
.624 .36972 Mdot
.624 .36979 Mdot
.624 .36981 Mdot
.624 .36983 Mdot
.624 .36985 Mdot
.624 .36995 Mdot
.624 .37008 Mdot
.624 .3701 Mdot
.624 .37012 Mdot
.624 .37019 Mdot
.624 .37022 Mdot
.624 .37022 Mdot
.624 .37023 Mdot
.624 .37033 Mdot
.624 .37043 Mdot
.624 .37049 Mdot
.624 .37071 Mdot
.624 .37072 Mdot
.624 .3708 Mdot
.624 .3708 Mdot
.624 .37082 Mdot
.624 .37084 Mdot
.624 .3709 Mdot
.624 .37093 Mdot
.624 .37093 Mdot
.624 .37095 Mdot
.624 .37095 Mdot
.624 .37095 Mdot
.624 .37095 Mdot
.624 .37097 Mdot
.624 .37097 Mdot
.624 .3711 Mdot
.624 .3711 Mdot
.624 .3712 Mdot
.624 .37125 Mdot
.624 .37126 Mdot
.624 .37127 Mdot
.624 .37128 Mdot
.624 .37128 Mdot
.624 .37129 Mdot
.624 .37129 Mdot
.624 .37145 Mdot
.624 .37146 Mdot
.624 .37154 Mdot
.624 .37154 Mdot
.624 .37154 Mdot
.624 .37154 Mdot
.624 .37158 Mdot
.624 .37158 Mdot
.624 .37158 Mdot
.624 .3716 Mdot
.624 .37167 Mdot
.624 .37171 Mdot
.624 .37173 Mdot
.624 .3718 Mdot
.624 .37183 Mdot
.624 .37187 Mdot
.624 .37188 Mdot
.624 .37192 Mdot
.624 .37196 Mdot
.624 .37202 Mdot
.624 .37206 Mdot
.624 .3721 Mdot
.624 .37214 Mdot
.624 .37216 Mdot
.624 .37224 Mdot
.624 .37233 Mdot
.624 .37238 Mdot
.624 .37243 Mdot
.624 .37244 Mdot
.624 .37245 Mdot
.624 .37253 Mdot
.624 .37255 Mdot
.624 .37268 Mdot
.624 .37269 Mdot
.624 .37273 Mdot
.624 .37274 Mdot
.624 .37274 Mdot
.624 .3728 Mdot
.624 .37288 Mdot
.624 .37295 Mdot
.624 .37299 Mdot
.624 .37299 Mdot
.624 .373 Mdot
.624 .37301 Mdot
.624 .37304 Mdot
.624 .37305 Mdot
.624 .37307 Mdot
.624 .37312 Mdot
.624 .37313 Mdot
.624 .37316 Mdot
.624 .3732 Mdot
.624 .37324 Mdot
.624 .37333 Mdot
.624 .37335 Mdot
.624 .37348 Mdot
.624 .37348 Mdot
.624 .37351 Mdot
.624 .37354 Mdot
.624 .37358 Mdot
.624 .37358 Mdot
.624 .3736 Mdot
.624 .37361 Mdot
.624 .37361 Mdot
.624 .37364 Mdot
.624 .37365 Mdot
.624 .37367 Mdot
.624 .37369 Mdot
.624 .37373 Mdot
.624 .37378 Mdot
.624 .37379 Mdot
.624 .37384 Mdot
.624 .37385 Mdot
.624 .37391 Mdot
.624 .37394 Mdot
.624 .37396 Mdot
.624 .37406 Mdot
.624 .37409 Mdot
.624 .37414 Mdot
.624 .37422 Mdot
.624 .37423 Mdot
.624 .37425 Mdot
.624 .37429 Mdot
.624 .37432 Mdot
.624 .37433 Mdot
.624 .37433 Mdot
.624 .37441 Mdot
.624 .37443 Mdot
.624 .37449 Mdot
.624 .37451 Mdot
.624 .37454 Mdot
.624 .37456 Mdot
.624 .3746 Mdot
.624 .37461 Mdot
.624 .37462 Mdot
.624 .37463 Mdot
.624 .37465 Mdot
.624 .37465 Mdot
.624 .37467 Mdot
.624 .37472 Mdot
.624 .37477 Mdot
.624 .3748 Mdot
.624 .37481 Mdot
.624 .37484 Mdot
.624 .37493 Mdot
.624 .375 Mdot
.624 .375 Mdot
.624 .37501 Mdot
.624 .37504 Mdot
.624 .37518 Mdot
.624 .37524 Mdot
.624 .37531 Mdot
.624 .37533 Mdot
.624 .37536 Mdot
.624 .37536 Mdot
.624 .37545 Mdot
.624 .37547 Mdot
.624 .3755 Mdot
.624 .37554 Mdot
.624 .37555 Mdot
.624 .37555 Mdot
.624 .37558 Mdot
.624 .37558 Mdot
.624 .37563 Mdot
.624 .37574 Mdot
.624 .3758 Mdot
.624 .37586 Mdot
.624 .37586 Mdot
.624 .37594 Mdot
.624 .37595 Mdot
.624 .37597 Mdot
.624 .37597 Mdot
.624 .37603 Mdot
.624 .37604 Mdot
.624 .37605 Mdot
.624 .37625 Mdot
.624 .37629 Mdot
.624 .37642 Mdot
.624 .37643 Mdot
.624 .37643 Mdot
.624 .37644 Mdot
.624 .37649 Mdot
.624 .3765 Mdot
.624 .37652 Mdot
.624 .3766 Mdot
.624 .37666 Mdot
.624 .37668 Mdot
.624 .37669 Mdot
.624 .3767 Mdot
.624 .37674 Mdot
.624 .37684 Mdot
.624 .37685 Mdot
.624 .37686 Mdot
.624 .37689 Mdot
.624 .3769 Mdot
.624 .37695 Mdot
.624 .37696 Mdot
.624 .37697 Mdot
.624 .37701 Mdot
.624 .37704 Mdot
.624 .37707 Mdot
.624 .37716 Mdot
.624 .37718 Mdot
.624 .37723 Mdot
.624 .37729 Mdot
.624 .37731 Mdot
.624 .37732 Mdot
.624 .37738 Mdot
.624 .37742 Mdot
.624 .37743 Mdot
.624 .37743 Mdot
.624 .37747 Mdot
.624 .37753 Mdot
.624 .37757 Mdot
.624 .37763 Mdot
.624 .37773 Mdot
.624 .37775 Mdot
.624 .37776 Mdot
.624 .37777 Mdot
.624 .37777 Mdot
.624 .37777 Mdot
.624 .37782 Mdot
.624 .37783 Mdot
.624 .37783 Mdot
.624 .37783 Mdot
.624 .37783 Mdot
.624 .37792 Mdot
.624 .37795 Mdot
.624 .37797 Mdot
.624 .37804 Mdot
.624 .37807 Mdot
.624 .37822 Mdot
.624 .37822 Mdot
.624 .37822 Mdot
.624 .37823 Mdot
.624 .37824 Mdot
.624 .37824 Mdot
.624 .37826 Mdot
.624 .37828 Mdot
.624 .37836 Mdot
.624 .37846 Mdot
.624 .37852 Mdot
.624 .37871 Mdot
.624 .37871 Mdot
.624 .37874 Mdot
.624 .37874 Mdot
.624 .37875 Mdot
.624 .37875 Mdot
.624 .37877 Mdot
.624 .37877 Mdot
.624 .37879 Mdot
.624 .37883 Mdot
.624 .37893 Mdot
.624 .37893 Mdot
.624 .37896 Mdot
.624 .37898 Mdot
.624 .37898 Mdot
.624 .3791 Mdot
.624 .37913 Mdot
.624 .37926 Mdot
.624 .37932 Mdot
.624 .37946 Mdot
.624 .37956 Mdot
.624 .37962 Mdot
.624 .37963 Mdot
.624 .37968 Mdot
.624 .37972 Mdot
.624 .37974 Mdot
.624 .37975 Mdot
.624 .37986 Mdot
.624 .37989 Mdot
.624 .37989 Mdot
.624 .37993 Mdot
.624 .38 Mdot
.624 .38004 Mdot
.624 .38007 Mdot
.624 .38008 Mdot
.624 .3801 Mdot
.624 .38012 Mdot
.624 .38013 Mdot
.624 .38018 Mdot
.624 .38019 Mdot
.624 .38019 Mdot
.624 .3802 Mdot
.624 .38027 Mdot
.624 .38027 Mdot
.624 .3803 Mdot
.624 .38046 Mdot
.624 .3805 Mdot
.624 .38053 Mdot
.624 .38056 Mdot
.624 .38066 Mdot
.624 .38075 Mdot
.624 .38089 Mdot
.624 .38089 Mdot
.624 .38092 Mdot
.624 .38095 Mdot
.624 .38102 Mdot
.624 .38104 Mdot
.624 .38112 Mdot
.624 .38117 Mdot
.624 .38118 Mdot
.624 .38121 Mdot
.624 .38131 Mdot
.624 .38132 Mdot
.624 .38136 Mdot
.624 .38139 Mdot
.624 .38141 Mdot
.624 .38143 Mdot
.624 .38143 Mdot
.624 .38146 Mdot
.624 .38146 Mdot
.624 .38147 Mdot
.624 .38147 Mdot
.624 .38166 Mdot
.624 .38171 Mdot
.624 .38182 Mdot
.624 .38184 Mdot
.624 .3819 Mdot
.624 .38198 Mdot
.624 .38202 Mdot
.624 .38207 Mdot
.624 .38208 Mdot
.624 .38211 Mdot
.624 .38219 Mdot
.624 .3822 Mdot
.624 .3823 Mdot
.624 .38231 Mdot
.624 .38231 Mdot
.624 .38234 Mdot
.624 .38241 Mdot
.624 .38242 Mdot
.624 .38242 Mdot
.624 .38242 Mdot
.624 .38243 Mdot
.624 .38243 Mdot
.624 .38255 Mdot
.624 .38255 Mdot
.624 .38255 Mdot
.624 .38255 Mdot
.624 .38258 Mdot
.624 .38262 Mdot
.624 .38265 Mdot
.624 .38266 Mdot
.624 .38281 Mdot
.626 .29105 Mdot
.626 .2911 Mdot
.626 .29111 Mdot
.626 .29113 Mdot
.626 .29114 Mdot
.626 .2912 Mdot
.626 .29134 Mdot
.626 .29136 Mdot
.626 .29139 Mdot
.626 .29148 Mdot
.626 .29159 Mdot
.626 .29167 Mdot
.626 .29167 Mdot
.626 .29175 Mdot
.626 .29177 Mdot
.626 .29182 Mdot
.626 .29207 Mdot
.626 .2922 Mdot
.626 .29221 Mdot
.626 .29223 Mdot
.626 .2923 Mdot
.626 .29237 Mdot
.626 .29239 Mdot
.626 .29242 Mdot
.626 .29264 Mdot
.626 .2927 Mdot
.626 .29276 Mdot
.626 .29277 Mdot
.626 .29284 Mdot
.626 .29297 Mdot
.626 .29298 Mdot
.626 .29309 Mdot
.626 .29318 Mdot
.626 .29327 Mdot
.626 .29333 Mdot
.626 .2934 Mdot
.626 .29346 Mdot
.626 .29352 Mdot
.626 .29354 Mdot
.626 .29355 Mdot
.626 .29356 Mdot
.626 .29359 Mdot
.626 .29362 Mdot
.626 .29366 Mdot
.626 .29368 Mdot
.626 .29374 Mdot
.626 .29377 Mdot
.626 .29385 Mdot
.626 .29387 Mdot
.626 .2939 Mdot
.626 .29398 Mdot
.626 .29402 Mdot
.626 .29403 Mdot
.626 .29405 Mdot
.626 .29407 Mdot
.626 .2941 Mdot
.626 .29427 Mdot
.626 .29428 Mdot
.626 .29438 Mdot
.626 .29442 Mdot
.626 .29448 Mdot
.626 .29454 Mdot
.626 .29456 Mdot
.626 .29456 Mdot
.626 .29462 Mdot
.626 .29471 Mdot
.626 .29474 Mdot
.626 .29475 Mdot
.626 .29478 Mdot
.626 .29486 Mdot
.626 .29487 Mdot
.626 .29492 Mdot
.626 .29492 Mdot
.626 .29496 Mdot
.626 .29501 Mdot
.626 .29502 Mdot
.626 .29506 Mdot
.626 .2951 Mdot
.626 .29512 Mdot
.626 .2952 Mdot
.626 .29521 Mdot
.626 .29527 Mdot
.626 .29539 Mdot
.626 .29541 Mdot
.626 .29541 Mdot
.626 .29543 Mdot
.626 .29547 Mdot
.626 .2955 Mdot
.626 .29556 Mdot
.626 .29558 Mdot
.626 .29565 Mdot
.626 .29567 Mdot
.626 .29572 Mdot
.626 .29572 Mdot
.626 .29572 Mdot
.626 .29574 Mdot
.626 .2958 Mdot
.626 .29581 Mdot
.626 .29583 Mdot
.626 .2959 Mdot
.626 .29593 Mdot
.626 .29594 Mdot
.626 .29594 Mdot
.626 .29602 Mdot
.626 .29606 Mdot
.626 .29608 Mdot
.626 .2961 Mdot
.626 .29612 Mdot
.626 .29621 Mdot
.626 .29628 Mdot
.626 .29632 Mdot
.626 .29634 Mdot
.626 .29647 Mdot
.626 .29649 Mdot
.626 .29655 Mdot
.626 .2966 Mdot
.626 .29662 Mdot
.626 .29665 Mdot
.626 .29666 Mdot
.626 .2967 Mdot
.626 .29671 Mdot
.626 .29673 Mdot
.626 .29675 Mdot
.626 .29681 Mdot
.626 .29688 Mdot
.626 .29692 Mdot
.626 .29693 Mdot
.626 .29701 Mdot
.626 .29704 Mdot
.626 .2972 Mdot
.626 .29723 Mdot
.626 .29724 Mdot
.626 .29729 Mdot
.626 .29742 Mdot
.626 .29746 Mdot
.626 .29749 Mdot
.626 .29753 Mdot
.626 .29757 Mdot
.626 .29765 Mdot
.626 .29769 Mdot
.626 .29769 Mdot
.626 .29778 Mdot
.626 .29781 Mdot
.626 .29782 Mdot
.626 .2979 Mdot
.626 .29791 Mdot
.626 .29803 Mdot
.626 .29807 Mdot
.626 .29809 Mdot
.626 .29825 Mdot
.626 .29832 Mdot
.626 .29833 Mdot
.626 .29834 Mdot
.626 .29843 Mdot
.626 .29848 Mdot
.626 .29851 Mdot
.626 .29865 Mdot
.626 .29871 Mdot
.626 .2988 Mdot
.626 .2988 Mdot
.626 .29881 Mdot
.626 .29885 Mdot
.626 .29892 Mdot
.626 .29893 Mdot
.626 .29898 Mdot
.626 .29899 Mdot
.626 .29899 Mdot
.626 .29901 Mdot
.626 .29909 Mdot
.626 .2991 Mdot
.626 .29914 Mdot
.626 .29921 Mdot
.626 .29923 Mdot
.626 .29927 Mdot
.626 .29936 Mdot
.626 .29936 Mdot
.626 .2994 Mdot
.626 .29947 Mdot
.626 .2995 Mdot
.626 .29956 Mdot
.626 .29958 Mdot
.626 .29962 Mdot
.626 .29962 Mdot
.626 .29968 Mdot
.626 .29972 Mdot
.626 .29972 Mdot
.626 .29981 Mdot
.626 .29983 Mdot
.626 .29984 Mdot
.626 .29992 Mdot
.626 .29999 Mdot
.626 .30005 Mdot
.626 .30006 Mdot
.626 .30009 Mdot
.626 .30012 Mdot
.626 .30015 Mdot
.626 .30021 Mdot
.626 .30042 Mdot
.626 .30048 Mdot
.626 .30052 Mdot
.626 .30053 Mdot
.626 .30065 Mdot
.626 .30074 Mdot
.626 .30082 Mdot
.626 .3009 Mdot
.626 .30094 Mdot
.626 .30098 Mdot
.626 .30099 Mdot
.626 .30101 Mdot
.626 .30106 Mdot
.626 .3011 Mdot
.626 .30113 Mdot
.626 .30116 Mdot
.626 .30118 Mdot
.626 .30124 Mdot
.626 .30125 Mdot
.626 .30127 Mdot
.626 .30129 Mdot
.626 .30131 Mdot
.626 .30134 Mdot
.626 .30136 Mdot
.626 .30145 Mdot
.626 .30149 Mdot
.626 .30164 Mdot
.626 .30182 Mdot
.626 .30183 Mdot
.626 .30185 Mdot
.626 .30193 Mdot
.626 .30195 Mdot
.626 .30198 Mdot
.626 .30217 Mdot
.626 .30218 Mdot
.626 .3023 Mdot
.626 .30236 Mdot
.626 .30238 Mdot
.626 .30241 Mdot
.626 .30243 Mdot
.626 .30246 Mdot
.626 .30255 Mdot
.626 .30267 Mdot
.626 .3027 Mdot
.626 .30275 Mdot
.626 .30277 Mdot
.626 .30301 Mdot
.626 .30307 Mdot
.626 .30311 Mdot
.626 .30313 Mdot
.626 .30319 Mdot
.626 .30321 Mdot
.626 .30326 Mdot
.626 .3033 Mdot
.626 .3033 Mdot
.626 .30336 Mdot
.626 .30352 Mdot
.626 .3036 Mdot
.626 .30383 Mdot
.626 .30389 Mdot
.626 .30404 Mdot
.626 .30404 Mdot
.626 .30406 Mdot
.626 .30411 Mdot
.626 .30411 Mdot
.626 .30414 Mdot
.626 .30417 Mdot
.626 .30418 Mdot
.626 .3042 Mdot
.626 .30421 Mdot
.626 .30432 Mdot
.626 .30434 Mdot
.626 .30434 Mdot
.626 .3044 Mdot
.626 .30444 Mdot
.626 .30451 Mdot
.626 .30451 Mdot
.626 .30456 Mdot
.626 .30458 Mdot
.626 .30459 Mdot
.626 .30461 Mdot
.626 .30462 Mdot
.626 .30469 Mdot
.626 .30476 Mdot
.626 .30488 Mdot
.626 .3049 Mdot
.626 .30501 Mdot
.626 .30515 Mdot
.626 .30533 Mdot
.626 .30535 Mdot
.626 .30541 Mdot
.626 .3055 Mdot
.626 .30553 Mdot
.626 .30566 Mdot
.626 .30569 Mdot
.626 .30584 Mdot
.626 .30589 Mdot
.626 .30589 Mdot
.626 .30592 Mdot
.626 .30597 Mdot
.626 .30602 Mdot
.626 .30607 Mdot
.626 .30609 Mdot
.626 .3061 Mdot
.626 .30618 Mdot
.626 .30628 Mdot
.626 .30635 Mdot
.626 .30642 Mdot
.626 .30643 Mdot
.626 .30647 Mdot
.626 .30659 Mdot
.626 .30661 Mdot
.626 .30661 Mdot
.626 .30666 Mdot
.626 .30666 Mdot
.626 .30671 Mdot
.626 .30675 Mdot
.626 .30677 Mdot
.626 .30682 Mdot
.626 .30686 Mdot
.626 .30695 Mdot
.626 .30699 Mdot
.626 .30706 Mdot
.626 .30711 Mdot
.626 .30717 Mdot
.626 .30717 Mdot
.626 .30721 Mdot
.626 .30721 Mdot
.626 .30726 Mdot
.626 .30728 Mdot
.626 .30731 Mdot
.626 .30737 Mdot
.626 .3074 Mdot
.626 .30742 Mdot
.626 .30752 Mdot
.626 .30758 Mdot
.626 .30759 Mdot
.626 .30771 Mdot
.626 .30774 Mdot
.626 .30775 Mdot
.626 .30777 Mdot
.626 .30784 Mdot
.626 .30785 Mdot
.626 .30796 Mdot
.626 .30802 Mdot
.626 .30804 Mdot
.626 .30805 Mdot
.626 .30819 Mdot
.626 .30828 Mdot
.626 .3085 Mdot
.626 .30855 Mdot
.626 .30863 Mdot
.626 .30877 Mdot
.626 .30878 Mdot
.626 .3088 Mdot
.626 .3089 Mdot
.626 .30915 Mdot
.626 .30919 Mdot
.626 .30925 Mdot
.626 .30944 Mdot
.626 .30946 Mdot
.626 .30959 Mdot
.626 .30959 Mdot
.626 .30964 Mdot
.626 .30979 Mdot
.626 .30979 Mdot
.626 .30984 Mdot
.626 .30997 Mdot
.626 .31003 Mdot
.626 .31009 Mdot
.626 .31015 Mdot
.626 .31021 Mdot
.626 .3104 Mdot
.626 .31049 Mdot
.626 .31051 Mdot
.626 .31055 Mdot
.626 .3108 Mdot
.626 .31085 Mdot
.626 .31098 Mdot
.626 .31098 Mdot
.626 .31105 Mdot
.626 .31117 Mdot
.626 .31125 Mdot
.626 .31129 Mdot
.626 .31133 Mdot
.626 .31134 Mdot
.626 .31139 Mdot
.626 .31141 Mdot
.626 .31146 Mdot
.626 .31149 Mdot
.626 .31157 Mdot
.626 .31166 Mdot
.626 .3117 Mdot
.626 .3119 Mdot
.626 .31194 Mdot
.626 .31199 Mdot
.626 .31211 Mdot
.626 .31224 Mdot
.626 .31228 Mdot
.626 .31231 Mdot
.626 .31235 Mdot
.626 .3124 Mdot
.626 .31252 Mdot
.626 .31253 Mdot
.626 .31254 Mdot
.626 .31259 Mdot
.626 .3127 Mdot
.626 .31273 Mdot
.626 .31274 Mdot
.626 .31285 Mdot
.626 .31286 Mdot
.626 .31287 Mdot
.626 .31287 Mdot
.626 .31294 Mdot
.626 .31299 Mdot
.626 .31309 Mdot
.626 .31313 Mdot
.626 .31322 Mdot
.626 .31326 Mdot
.626 .31333 Mdot
.626 .31336 Mdot
.626 .31336 Mdot
.626 .31339 Mdot
.626 .31357 Mdot
.626 .31368 Mdot
.626 .31369 Mdot
.626 .31381 Mdot
.626 .31384 Mdot
.626 .31391 Mdot
.626 .31396 Mdot
.626 .31398 Mdot
.626 .31407 Mdot
.626 .31412 Mdot
.626 .31413 Mdot
.626 .31421 Mdot
.626 .31423 Mdot
.626 .31435 Mdot
.626 .31439 Mdot
.626 .3144 Mdot
.626 .31446 Mdot
.626 .3146 Mdot
.626 .31469 Mdot
.626 .3147 Mdot
.626 .31473 Mdot
.626 .31482 Mdot
.626 .31491 Mdot
.626 .31497 Mdot
.626 .31512 Mdot
.626 .31514 Mdot
.626 .31541 Mdot
.626 .31545 Mdot
.626 .31549 Mdot
.626 .31552 Mdot
.626 .31554 Mdot
.626 .31559 Mdot
.626 .31573 Mdot
.626 .31577 Mdot
.626 .3158 Mdot
.626 .31593 Mdot
.626 .31598 Mdot
.626 .31611 Mdot
.626 .31616 Mdot
.626 .31621 Mdot
.626 .31625 Mdot
.626 .31627 Mdot
.626 .3163 Mdot
.626 .31632 Mdot
.626 .31641 Mdot
.626 .3165 Mdot
.626 .31663 Mdot
.626 .31671 Mdot
.626 .31685 Mdot
.626 .317 Mdot
.626 .31717 Mdot
.626 .31718 Mdot
.626 .31738 Mdot
.626 .3175 Mdot
.626 .31751 Mdot
.626 .3176 Mdot
.626 .31771 Mdot
.626 .31804 Mdot
.626 .31808 Mdot
.626 .31813 Mdot
.626 .31823 Mdot
.626 .31834 Mdot
.626 .31837 Mdot
.626 .31839 Mdot
.626 .31859 Mdot
.626 .31899 Mdot
.626 .31907 Mdot
.626 .31909 Mdot
.626 .31922 Mdot
.626 .31922 Mdot
.626 .31935 Mdot
.626 .31951 Mdot
.626 .31967 Mdot
.626 .31971 Mdot
.626 .31974 Mdot
.626 .31996 Mdot
.626 .32006 Mdot
.626 .32006 Mdot
.626 .32009 Mdot
.626 .32011 Mdot
.626 .32019 Mdot
.626 .36069 Mdot
.626 .36075 Mdot
.626 .36076 Mdot
.626 .36079 Mdot
.626 .36079 Mdot
.626 .36087 Mdot
.626 .36105 Mdot
.626 .36107 Mdot
.626 .36111 Mdot
.626 .36123 Mdot
.626 .36136 Mdot
.626 .36146 Mdot
.626 .36146 Mdot
.626 .36157 Mdot
.626 .36158 Mdot
.626 .36165 Mdot
.626 .36197 Mdot
.626 .36213 Mdot
.626 .36214 Mdot
.626 .36217 Mdot
.626 .36225 Mdot
.626 .36234 Mdot
.626 .36237 Mdot
.626 .36241 Mdot
.626 .36267 Mdot
.626 .36275 Mdot
.626 .36283 Mdot
.626 .36284 Mdot
.626 .36293 Mdot
.626 .36309 Mdot
.626 .3631 Mdot
.626 .36324 Mdot
.626 .36336 Mdot
.626 .36347 Mdot
.626 .36354 Mdot
.626 .36363 Mdot
.626 .36371 Mdot
.626 .36378 Mdot
.626 .3638 Mdot
.626 .36382 Mdot
.626 .36383 Mdot
.626 .36386 Mdot
.626 .3639 Mdot
.626 .36395 Mdot
.626 .36405 Mdot
.626 .36409 Mdot
.626 .36419 Mdot
.626 .36422 Mdot
.626 .36425 Mdot
.626 .36436 Mdot
.626 .3644 Mdot
.626 .36442 Mdot
.626 .36444 Mdot
.626 .36447 Mdot
.626 .3645 Mdot
.626 .36472 Mdot
.626 .36473 Mdot
.626 .36486 Mdot
.626 .36491 Mdot
.626 .36498 Mdot
.626 .36505 Mdot
.626 .36508 Mdot
.626 .36508 Mdot
.626 .36515 Mdot
.626 .36527 Mdot
.626 .36531 Mdot
.626 .36532 Mdot
.626 .36536 Mdot
.626 .36545 Mdot
.626 .36547 Mdot
.626 .36553 Mdot
.626 .36554 Mdot
.626 .36558 Mdot
.626 .36564 Mdot
.626 .36566 Mdot
.626 .3657 Mdot
.626 .36576 Mdot
.626 .36578 Mdot
.626 .36588 Mdot
.626 .36589 Mdot
.626 .36597 Mdot
.626 .36612 Mdot
.626 .36614 Mdot
.626 .36615 Mdot
.626 .36616 Mdot
.626 .36622 Mdot
.626 .36625 Mdot
.626 .36633 Mdot
.626 .36636 Mdot
.626 .36644 Mdot
.626 .36648 Mdot
.626 .36653 Mdot
.626 .36654 Mdot
.626 .36654 Mdot
.626 .36655 Mdot
.626 .36664 Mdot
.626 .36665 Mdot
.626 .36667 Mdot
.626 .36676 Mdot
.626 .3668 Mdot
.626 .3668 Mdot
.626 .36681 Mdot
.626 .36691 Mdot
.626 .36695 Mdot
.626 .36698 Mdot
.626 .36701 Mdot
.626 .36703 Mdot
.626 .36714 Mdot
.626 .36724 Mdot
.626 .36728 Mdot
.626 .36731 Mdot
.626 .36747 Mdot
.626 .3675 Mdot
.626 .36757 Mdot
.626 .36764 Mdot
.626 .36766 Mdot
.626 .3677 Mdot
.626 .36772 Mdot
.626 .36776 Mdot
.626 .36777 Mdot
.626 .3678 Mdot
.626 .36783 Mdot
.626 .36789 Mdot
.626 .36799 Mdot
.626 .36804 Mdot
.626 .36805 Mdot
.626 .36815 Mdot
.626 .36818 Mdot
.626 .36839 Mdot
.626 .36842 Mdot
.626 .36844 Mdot
.626 .3685 Mdot
.626 .36866 Mdot
.626 .36871 Mdot
.626 .36875 Mdot
.626 .36881 Mdot
.626 .36886 Mdot
.626 .36895 Mdot
.626 .36899 Mdot
.626 .369 Mdot
.626 .36911 Mdot
.626 .36916 Mdot
.626 .36916 Mdot
.626 .36926 Mdot
.626 .36927 Mdot
.626 .36943 Mdot
.626 .36947 Mdot
.626 .3695 Mdot
.626 .36971 Mdot
.626 .36979 Mdot
.626 .3698 Mdot
.626 .36981 Mdot
.626 .36992 Mdot
.626 .36999 Mdot
.626 .37003 Mdot
.626 .3702 Mdot
.626 .37027 Mdot
.626 .37039 Mdot
.626 .37039 Mdot
.626 .37041 Mdot
.626 .37045 Mdot
.626 .37054 Mdot
.626 .37055 Mdot
.626 .37061 Mdot
.626 .37063 Mdot
.626 .37063 Mdot
.626 .37065 Mdot
.626 .37076 Mdot
.626 .37076 Mdot
.626 .37081 Mdot
.626 .37089 Mdot
.626 .3709 Mdot
.626 .37093 Mdot
.626 .37098 Mdot
.626 .371 Mdot
.626 .37101 Mdot
.626 .37105 Mdot
.626 .37106 Mdot
.626 .37109 Mdot
.626 .37109 Mdot
.626 .37114 Mdot
.626 .37118 Mdot
.626 .37123 Mdot
.626 .37127 Mdot
.626 .37134 Mdot
.626 .37137 Mdot
.626 .37141 Mdot
.626 .37142 Mdot
.626 .37146 Mdot
.626 .37149 Mdot
.626 .3715 Mdot
.626 .37154 Mdot
.626 .37154 Mdot
.626 .37155 Mdot
.626 .37165 Mdot
.626 .37168 Mdot
.626 .37169 Mdot
.626 .37174 Mdot
.626 .3718 Mdot
.626 .37188 Mdot
.626 .37194 Mdot
.626 .37195 Mdot
.626 .37197 Mdot
.626 .37201 Mdot
.626 .37205 Mdot
.626 .37209 Mdot
.626 .37211 Mdot
.626 .37211 Mdot
.626 .37215 Mdot
.626 .37227 Mdot
.626 .3723 Mdot
.626 .3724 Mdot
.626 .37242 Mdot
.626 .3725 Mdot
.626 .37254 Mdot
.626 .37256 Mdot
.626 .3727 Mdot
.626 .37282 Mdot
.626 .3729 Mdot
.626 .37292 Mdot
.626 .37302 Mdot
.626 .37307 Mdot
.626 .37312 Mdot
.626 .37313 Mdot
.626 .37315 Mdot
.626 .37316 Mdot
.626 .37317 Mdot
.626 .37321 Mdot
.626 .37321 Mdot
.626 .37327 Mdot
.626 .3733 Mdot
.626 .37335 Mdot
.626 .37335 Mdot
.626 .37337 Mdot
.626 .37345 Mdot
.626 .37346 Mdot
.626 .37348 Mdot
.626 .37348 Mdot
.626 .37351 Mdot
.626 .37353 Mdot
.626 .37353 Mdot
.626 .37357 Mdot
.626 .37359 Mdot
.626 .37359 Mdot
.626 .3737 Mdot
.626 .37375 Mdot
.626 .37394 Mdot
.626 .374 Mdot
.626 .37413 Mdot
.626 .37418 Mdot
.626 .37418 Mdot
.626 .37421 Mdot
.626 .37425 Mdot
.626 .37427 Mdot
.626 .37431 Mdot
.626 .37433 Mdot
.626 .37437 Mdot
.626 .37441 Mdot
.626 .3746 Mdot
.626 .37462 Mdot
.626 .37466 Mdot
.626 .37468 Mdot
.626 .37478 Mdot
.626 .37485 Mdot
.626 .37488 Mdot
.626 .37489 Mdot
.626 .37491 Mdot
.626 .37493 Mdot
.626 .37497 Mdot
.626 .37508 Mdot
.626 .37508 Mdot
.626 .37524 Mdot
.626 .37526 Mdot
.626 .37527 Mdot
.626 .37533 Mdot
.626 .37536 Mdot
.626 .37536 Mdot
.626 .37551 Mdot
.626 .37563 Mdot
.626 .37566 Mdot
.626 .37573 Mdot
.626 .37574 Mdot
.626 .37577 Mdot
.626 .37578 Mdot
.626 .3758 Mdot
.626 .37581 Mdot
.626 .37582 Mdot
.626 .37587 Mdot
.626 .37589 Mdot
.626 .37591 Mdot
.626 .37593 Mdot
.626 .37597 Mdot
.626 .37601 Mdot
.626 .37603 Mdot
.626 .37603 Mdot
.626 .3761 Mdot
.626 .37616 Mdot
.626 .37622 Mdot
.626 .3763 Mdot
.626 .37639 Mdot
.626 .3764 Mdot
.626 .37643 Mdot
.626 .37648 Mdot
.626 .37665 Mdot
.626 .37669 Mdot
.626 .37672 Mdot
.626 .37674 Mdot
.626 .37677 Mdot
.626 .37678 Mdot
.626 .37683 Mdot
.626 .37688 Mdot
.626 .37695 Mdot
.626 .37695 Mdot
.626 .37697 Mdot
.626 .37704 Mdot
.626 .37704 Mdot
.626 .37707 Mdot
.626 .37711 Mdot
.626 .37712 Mdot
.626 .37715 Mdot
.626 .37717 Mdot
.626 .37721 Mdot
.626 .37724 Mdot
.626 .37729 Mdot
.626 .37733 Mdot
.626 .37733 Mdot
.626 .3774 Mdot
.626 .37743 Mdot
.626 .37745 Mdot
.626 .3775 Mdot
.626 .37754 Mdot
.626 .37754 Mdot
.626 .3776 Mdot
.626 .37762 Mdot
.626 .37762 Mdot
.626 .37763 Mdot
.626 .37767 Mdot
.626 .37768 Mdot
.626 .37773 Mdot
.626 .37776 Mdot
.626 .37777 Mdot
.626 .37777 Mdot
.626 .37785 Mdot
.626 .37789 Mdot
.626 .378 Mdot
.626 .37803 Mdot
.626 .37807 Mdot
.626 .37814 Mdot
.626 .37815 Mdot
.626 .37816 Mdot
.626 .37821 Mdot
.626 .37834 Mdot
.626 .37836 Mdot
.626 .37839 Mdot
.626 .37849 Mdot
.626 .37849 Mdot
.626 .37856 Mdot
.626 .37856 Mdot
.626 .37859 Mdot
.626 .37866 Mdot
.626 .37866 Mdot
.626 .37869 Mdot
.626 .37875 Mdot
.626 .37878 Mdot
.626 .37882 Mdot
.626 .37884 Mdot
.626 .37888 Mdot
.626 .37898 Mdot
.626 .37902 Mdot
.626 .37903 Mdot
.626 .37905 Mdot
.626 .37918 Mdot
.626 .3792 Mdot
.626 .37927 Mdot
.626 .37927 Mdot
.626 .37931 Mdot
.626 .37937 Mdot
.626 .37941 Mdot
.626 .37943 Mdot
.626 .37945 Mdot
.626 .37945 Mdot
.626 .37948 Mdot
.626 .37949 Mdot
.626 .37952 Mdot
.626 .37953 Mdot
.626 .37957 Mdot
.626 .37962 Mdot
.626 .37963 Mdot
.626 .37974 Mdot
.626 .37976 Mdot
.626 .37978 Mdot
.626 .37985 Mdot
.626 .37991 Mdot
.626 .37993 Mdot
.626 .37994 Mdot
.626 .37997 Mdot
.626 .37999 Mdot
.626 .38005 Mdot
.626 .38006 Mdot
.626 .38007 Mdot
.626 .38009 Mdot
.626 .38015 Mdot
.626 .38016 Mdot
.626 .38017 Mdot
.626 .38022 Mdot
.626 .38023 Mdot
.626 .38023 Mdot
.626 .38023 Mdot
.626 .38027 Mdot
.626 .38029 Mdot
.626 .38034 Mdot
.626 .38036 Mdot
.626 .38041 Mdot
.626 .38043 Mdot
.626 .38047 Mdot
.626 .38048 Mdot
.626 .38048 Mdot
.626 .3805 Mdot
.626 .38059 Mdot
.626 .38064 Mdot
.626 .38065 Mdot
.626 .38071 Mdot
.626 .38073 Mdot
.626 .38076 Mdot
.626 .38079 Mdot
.626 .3808 Mdot
.626 .38084 Mdot
.626 .38087 Mdot
.626 .38087 Mdot
.626 .38091 Mdot
.626 .38092 Mdot
.626 .38098 Mdot
.626 .38101 Mdot
.626 .38101 Mdot
.626 .38104 Mdot
.626 .38111 Mdot
.626 .38116 Mdot
.626 .38116 Mdot
.626 .38118 Mdot
.626 .38123 Mdot
.626 .38127 Mdot
.626 .3813 Mdot
.626 .38138 Mdot
.626 .38139 Mdot
.626 .38153 Mdot
.626 .38155 Mdot
.626 .38157 Mdot
.626 .38158 Mdot
.626 .38159 Mdot
.626 .38162 Mdot
.626 .38169 Mdot
.626 .38171 Mdot
.626 .38173 Mdot
.626 .38179 Mdot
.626 .38182 Mdot
.626 .38186 Mdot
.626 .38188 Mdot
.626 .38191 Mdot
.626 .38194 Mdot
.626 .38196 Mdot
.626 .38197 Mdot
.626 .38198 Mdot
.626 .38199 Mdot
.626 .38204 Mdot
.626 .38208 Mdot
.626 .38215 Mdot
.626 .38219 Mdot
.626 .38226 Mdot
.626 .38234 Mdot
.626 .38242 Mdot
.626 .38243 Mdot
.626 .38253 Mdot
.626 .38259 Mdot
.626 .3826 Mdot
.626 .38264 Mdot
.626 .3827 Mdot
.626 .38287 Mdot
.626 .38289 Mdot
.626 .38291 Mdot
.626 .38296 Mdot
.626 .38302 Mdot
.626 .38304 Mdot
.626 .38304 Mdot
.626 .38315 Mdot
.626 .38335 Mdot
.626 .38339 Mdot
.626 .3834 Mdot
.626 .38347 Mdot
.626 .38347 Mdot
.626 .38353 Mdot
.626 .38362 Mdot
.626 .3837 Mdot
.626 .38372 Mdot
.626 .38373 Mdot
.626 .38385 Mdot
.626 .38389 Mdot
.626 .3839 Mdot
.626 .38391 Mdot
.626 .38392 Mdot
.626 .38396 Mdot
.628 .29054 Mdot
.628 .29055 Mdot
.628 .29059 Mdot
.628 .29068 Mdot
.628 .29071 Mdot
.628 .29071 Mdot
.628 .29072 Mdot
.628 .29096 Mdot
.628 .291 Mdot
.628 .29103 Mdot
.628 .29103 Mdot
.628 .29104 Mdot
.628 .29109 Mdot
.628 .29109 Mdot
.628 .29118 Mdot
.628 .29123 Mdot
.628 .29129 Mdot
.628 .29132 Mdot
.628 .29133 Mdot
.628 .29134 Mdot
.628 .29134 Mdot
.628 .29137 Mdot
.628 .29138 Mdot
.628 .29141 Mdot
.628 .29149 Mdot
.628 .29159 Mdot
.628 .29161 Mdot
.628 .29168 Mdot
.628 .29169 Mdot
.628 .29171 Mdot
.628 .29176 Mdot
.628 .29178 Mdot
.628 .29181 Mdot
.628 .29186 Mdot
.628 .29186 Mdot
.628 .2919 Mdot
.628 .29206 Mdot
.628 .29211 Mdot
.628 .29219 Mdot
.628 .29224 Mdot
.628 .29237 Mdot
.628 .29242 Mdot
.628 .29247 Mdot
.628 .29247 Mdot
.628 .29248 Mdot
.628 .2925 Mdot
.628 .29262 Mdot
.628 .29266 Mdot
.628 .2927 Mdot
.628 .29275 Mdot
.628 .29279 Mdot
.628 .29286 Mdot
.628 .29296 Mdot
.628 .29306 Mdot
.628 .29317 Mdot
.628 .2932 Mdot
.628 .29329 Mdot
.628 .29333 Mdot
.628 .29337 Mdot
.628 .29343 Mdot
.628 .29352 Mdot
.628 .29361 Mdot
.628 .29372 Mdot
.628 .29377 Mdot
.628 .29381 Mdot
.628 .29397 Mdot
.628 .29409 Mdot
.628 .2941 Mdot
.628 .29411 Mdot
.628 .29414 Mdot
.628 .29423 Mdot
.628 .29426 Mdot
.628 .29432 Mdot
.628 .29432 Mdot
.628 .29437 Mdot
.628 .29444 Mdot
.628 .29444 Mdot
.628 .29444 Mdot
.628 .29445 Mdot
.628 .29448 Mdot
.628 .2945 Mdot
.628 .29454 Mdot
.628 .29455 Mdot
.628 .29463 Mdot
.628 .29469 Mdot
.628 .29472 Mdot
.628 .29473 Mdot
.628 .29494 Mdot
.628 .29503 Mdot
.628 .29523 Mdot
.628 .29525 Mdot
.628 .29527 Mdot
.628 .29538 Mdot
.628 .29541 Mdot
.628 .29543 Mdot
.628 .29548 Mdot
.628 .29549 Mdot
.628 .29557 Mdot
.628 .2956 Mdot
.628 .29569 Mdot
.628 .2957 Mdot
.628 .29573 Mdot
.628 .29576 Mdot
.628 .29578 Mdot
.628 .2958 Mdot
.628 .29583 Mdot
.628 .29588 Mdot
.628 .29592 Mdot
.628 .29594 Mdot
.628 .29609 Mdot
.628 .29627 Mdot
.628 .29636 Mdot
.628 .2964 Mdot
.628 .29647 Mdot
.628 .29648 Mdot
.628 .2965 Mdot
.628 .29659 Mdot
.628 .2966 Mdot
.628 .29671 Mdot
.628 .29682 Mdot
.628 .29684 Mdot
.628 .29687 Mdot
.628 .2969 Mdot
.628 .29691 Mdot
.628 .29695 Mdot
.628 .29702 Mdot
.628 .29705 Mdot
.628 .29706 Mdot
.628 .29712 Mdot
.628 .29715 Mdot
.628 .29717 Mdot
.628 .29717 Mdot
.628 .2972 Mdot
.628 .29735 Mdot
.628 .29737 Mdot
.628 .29751 Mdot
.628 .29757 Mdot
.628 .29758 Mdot
.628 .29758 Mdot
.628 .29759 Mdot
.628 .2977 Mdot
.628 .29771 Mdot
.628 .29774 Mdot
.628 .29779 Mdot
.628 .29781 Mdot
.628 .29783 Mdot
.628 .29783 Mdot
.628 .29785 Mdot
.628 .29785 Mdot
.628 .2979 Mdot
.628 .29794 Mdot
.628 .29798 Mdot
.628 .298 Mdot
.628 .29802 Mdot
.628 .29804 Mdot
.628 .29812 Mdot
.628 .29815 Mdot
.628 .29819 Mdot
.628 .29825 Mdot
.628 .29827 Mdot
.628 .29829 Mdot
.628 .2983 Mdot
.628 .29835 Mdot
.628 .29836 Mdot
.628 .29844 Mdot
.628 .29857 Mdot
.628 .29858 Mdot
.628 .29864 Mdot
.628 .29865 Mdot
.628 .29867 Mdot
.628 .29871 Mdot
.628 .29875 Mdot
.628 .29894 Mdot
.628 .29895 Mdot
.628 .29899 Mdot
.628 .29903 Mdot
.628 .29908 Mdot
.628 .29912 Mdot
.628 .2992 Mdot
.628 .29941 Mdot
.628 .2995 Mdot
.628 .29955 Mdot
.628 .29962 Mdot
.628 .29963 Mdot
.628 .29974 Mdot
.628 .29987 Mdot
.628 .2999 Mdot
.628 .29991 Mdot
.628 .29995 Mdot
.628 .30004 Mdot
.628 .30009 Mdot
.628 .30013 Mdot
.628 .30018 Mdot
.628 .30026 Mdot
.628 .30034 Mdot
.628 .30034 Mdot
.628 .30043 Mdot
.628 .30045 Mdot
.628 .30049 Mdot
.628 .30052 Mdot
.628 .30053 Mdot
.628 .30059 Mdot
.628 .30062 Mdot
.628 .30069 Mdot
.628 .30092 Mdot
.628 .30094 Mdot
.628 .30099 Mdot
.628 .30113 Mdot
.628 .30116 Mdot
.628 .30126 Mdot
.628 .30128 Mdot
.628 .30133 Mdot
.628 .30135 Mdot
.628 .30139 Mdot
.628 .30145 Mdot
.628 .30149 Mdot
.628 .30152 Mdot
.628 .30153 Mdot
.628 .30156 Mdot
.628 .30177 Mdot
.628 .30183 Mdot
.628 .30191 Mdot
.628 .30193 Mdot
.628 .30194 Mdot
.628 .30205 Mdot
.628 .30208 Mdot
.628 .30217 Mdot
.628 .30227 Mdot
.628 .30237 Mdot
.628 .30238 Mdot
.628 .30243 Mdot
.628 .3026 Mdot
.628 .30262 Mdot
.628 .30264 Mdot
.628 .30267 Mdot
.628 .30271 Mdot
.628 .30273 Mdot
.628 .30275 Mdot
.628 .30278 Mdot
.628 .30285 Mdot
.628 .30287 Mdot
.628 .30299 Mdot
.628 .3032 Mdot
.628 .30325 Mdot
.628 .30326 Mdot
.628 .3033 Mdot
.628 .30332 Mdot
.628 .30337 Mdot
.628 .30343 Mdot
.628 .30348 Mdot
.628 .30353 Mdot
.628 .30356 Mdot
.628 .30362 Mdot
.628 .30365 Mdot
.628 .30367 Mdot
.628 .30375 Mdot
.628 .30382 Mdot
.628 .30388 Mdot
.628 .3041 Mdot
.628 .30414 Mdot
.628 .30417 Mdot
.628 .3042 Mdot
.628 .30426 Mdot
.628 .30426 Mdot
.628 .30438 Mdot
.628 .30445 Mdot
.628 .30449 Mdot
.628 .30457 Mdot
.628 .30464 Mdot
.628 .30467 Mdot
.628 .30469 Mdot
.628 .3047 Mdot
.628 .30473 Mdot
.628 .30483 Mdot
.628 .30484 Mdot
.628 .30487 Mdot
.628 .30489 Mdot
.628 .30492 Mdot
.628 .30495 Mdot
.628 .30499 Mdot
.628 .30512 Mdot
.628 .30512 Mdot
.628 .30516 Mdot
.628 .30526 Mdot
.628 .30538 Mdot
.628 .30538 Mdot
.628 .30545 Mdot
.628 .30546 Mdot
.628 .30548 Mdot
.628 .30552 Mdot
.628 .30555 Mdot
.628 .30555 Mdot
.628 .30557 Mdot
.628 .30559 Mdot
.628 .3056 Mdot
.628 .30568 Mdot
.628 .30575 Mdot
.628 .3058 Mdot
.628 .30582 Mdot
.628 .30583 Mdot
.628 .30587 Mdot
.628 .30596 Mdot
.628 .30607 Mdot
.628 .30616 Mdot
.628 .30617 Mdot
.628 .30625 Mdot
.628 .30626 Mdot
.628 .3063 Mdot
.628 .30631 Mdot
.628 .30632 Mdot
.628 .30638 Mdot
.628 .3064 Mdot
.628 .30645 Mdot
.628 .3065 Mdot
.628 .30659 Mdot
.628 .30693 Mdot
.628 .30705 Mdot
.628 .30709 Mdot
.628 .30711 Mdot
.628 .30711 Mdot
.628 .30712 Mdot
.628 .30719 Mdot
.628 .30719 Mdot
.628 .30725 Mdot
.628 .30732 Mdot
.628 .30734 Mdot
.628 .30741 Mdot
.628 .30752 Mdot
.628 .30754 Mdot
.628 .30764 Mdot
.628 .3077 Mdot
.628 .30775 Mdot
.628 .30779 Mdot
.628 .30781 Mdot
.628 .3079 Mdot
.628 .30792 Mdot
.628 .30811 Mdot
.628 .30824 Mdot
.628 .30827 Mdot
.628 .30834 Mdot
.628 .30836 Mdot
.628 .30839 Mdot
.628 .30843 Mdot
.628 .30851 Mdot
.628 .30859 Mdot
.628 .30862 Mdot
.628 .30875 Mdot
.628 .30878 Mdot
.628 .30881 Mdot
.628 .30885 Mdot
.628 .30891 Mdot
.628 .30898 Mdot
.628 .30905 Mdot
.628 .30906 Mdot
.628 .30908 Mdot
.628 .30908 Mdot
.628 .30911 Mdot
.628 .30915 Mdot
.628 .30923 Mdot
.628 .30927 Mdot
.628 .30929 Mdot
.628 .30947 Mdot
.628 .30947 Mdot
.628 .30948 Mdot
.628 .30949 Mdot
.628 .30958 Mdot
.628 .30981 Mdot
.628 .30984 Mdot
.628 .31007 Mdot
.628 .31012 Mdot
.628 .31012 Mdot
.628 .31016 Mdot
.628 .31021 Mdot
.628 .3103 Mdot
.628 .31031 Mdot
.628 .31036 Mdot
.628 .31047 Mdot
.628 .31053 Mdot
.628 .31055 Mdot
.628 .31059 Mdot
.628 .31064 Mdot
.628 .31067 Mdot
.628 .31086 Mdot
.628 .31103 Mdot
.628 .31104 Mdot
.628 .31118 Mdot
.628 .31121 Mdot
.628 .31123 Mdot
.628 .31134 Mdot
.628 .31141 Mdot
.628 .31155 Mdot
.628 .31183 Mdot
.628 .31207 Mdot
.628 .31209 Mdot
.628 .31216 Mdot
.628 .31224 Mdot
.628 .31228 Mdot
.628 .31232 Mdot
.628 .31234 Mdot
.628 .3124 Mdot
.628 .31244 Mdot
.628 .31245 Mdot
.628 .3126 Mdot
.628 .31266 Mdot
.628 .31278 Mdot
.628 .31279 Mdot
.628 .31288 Mdot
.628 .3129 Mdot
.628 .31294 Mdot
.628 .31312 Mdot
.628 .31316 Mdot
.628 .31319 Mdot
.628 .3135 Mdot
.628 .31364 Mdot
.628 .31398 Mdot
.628 .314 Mdot
.628 .31403 Mdot
.628 .31412 Mdot
.628 .31426 Mdot
.628 .31427 Mdot
.628 .31434 Mdot
.628 .31437 Mdot
.628 .31442 Mdot
.628 .31443 Mdot
.628 .31443 Mdot
.628 .31444 Mdot
.628 .31454 Mdot
.628 .31462 Mdot
.628 .31463 Mdot
.628 .31472 Mdot
.628 .31477 Mdot
.628 .3149 Mdot
.628 .31495 Mdot
.628 .31496 Mdot
.628 .31499 Mdot
.628 .31517 Mdot
.628 .31543 Mdot
.628 .31549 Mdot
.628 .31556 Mdot
.628 .31574 Mdot
.628 .31589 Mdot
.628 .31602 Mdot
.628 .31611 Mdot
.628 .31618 Mdot
.628 .31624 Mdot
.628 .31639 Mdot
.628 .31643 Mdot
.628 .3166 Mdot
.628 .31677 Mdot
.628 .31693 Mdot
.628 .31704 Mdot
.628 .3171 Mdot
.628 .31718 Mdot
.628 .31724 Mdot
.628 .31731 Mdot
.628 .3175 Mdot
.628 .31752 Mdot
.628 .31754 Mdot
.628 .31755 Mdot
.628 .31761 Mdot
.628 .3177 Mdot
.628 .31791 Mdot
.628 .31798 Mdot
.628 .3181 Mdot
.628 .31818 Mdot
.628 .31843 Mdot
.628 .3185 Mdot
.628 .31851 Mdot
.628 .31858 Mdot
.628 .31863 Mdot
.628 .31865 Mdot
.628 .31874 Mdot
.628 .31876 Mdot
.628 .31878 Mdot
.628 .31889 Mdot
.628 .31892 Mdot
.628 .31908 Mdot
.628 .31922 Mdot
.628 .31926 Mdot
.628 .31928 Mdot
.628 .31932 Mdot
.628 .31932 Mdot
.628 .31934 Mdot
.628 .31935 Mdot
.628 .3194 Mdot
.628 .3195 Mdot
.628 .31958 Mdot
.628 .31971 Mdot
.628 .31972 Mdot
.628 .3198 Mdot
.628 .31981 Mdot
.628 .31981 Mdot
.628 .31986 Mdot
.628 .31992 Mdot
.628 .3203 Mdot
.628 .32031 Mdot
.628 .32032 Mdot
.628 .32036 Mdot
.628 .3205 Mdot
.628 .32057 Mdot
.628 .32058 Mdot
.628 .36115 Mdot
.628 .36116 Mdot
.628 .36122 Mdot
.628 .36133 Mdot
.628 .36137 Mdot
.628 .36137 Mdot
.628 .36138 Mdot
.628 .36168 Mdot
.628 .36173 Mdot
.628 .36177 Mdot
.628 .36177 Mdot
.628 .36178 Mdot
.628 .36184 Mdot
.628 .36185 Mdot
.628 .36195 Mdot
.628 .36202 Mdot
.628 .36209 Mdot
.628 .36214 Mdot
.628 .36215 Mdot
.628 .36215 Mdot
.628 .36216 Mdot
.628 .36219 Mdot
.628 .3622 Mdot
.628 .36224 Mdot
.628 .36235 Mdot
.628 .36247 Mdot
.628 .3625 Mdot
.628 .36259 Mdot
.628 .3626 Mdot
.628 .36262 Mdot
.628 .36269 Mdot
.628 .36271 Mdot
.628 .36274 Mdot
.628 .36281 Mdot
.628 .36281 Mdot
.628 .36287 Mdot
.628 .36306 Mdot
.628 .36313 Mdot
.628 .36323 Mdot
.628 .36328 Mdot
.628 .36345 Mdot
.628 .36352 Mdot
.628 .36357 Mdot
.628 .36358 Mdot
.628 .36359 Mdot
.628 .36361 Mdot
.628 .36376 Mdot
.628 .36381 Mdot
.628 .36386 Mdot
.628 .36392 Mdot
.628 .36398 Mdot
.628 .36406 Mdot
.628 .36419 Mdot
.628 .36432 Mdot
.628 .36446 Mdot
.628 .36449 Mdot
.628 .36461 Mdot
.628 .36466 Mdot
.628 .36471 Mdot
.628 .36478 Mdot
.628 .36489 Mdot
.628 .36501 Mdot
.628 .36515 Mdot
.628 .36521 Mdot
.628 .36525 Mdot
.628 .36546 Mdot
.628 .36561 Mdot
.628 .36563 Mdot
.628 .36564 Mdot
.628 .36567 Mdot
.628 .36578 Mdot
.628 .36582 Mdot
.628 .36589 Mdot
.628 .3659 Mdot
.628 .36596 Mdot
.628 .36604 Mdot
.628 .36605 Mdot
.628 .36605 Mdot
.628 .36606 Mdot
.628 .3661 Mdot
.628 .36612 Mdot
.628 .36618 Mdot
.628 .36618 Mdot
.628 .36629 Mdot
.628 .36637 Mdot
.628 .3664 Mdot
.628 .36641 Mdot
.628 .36668 Mdot
.628 .3668 Mdot
.628 .36704 Mdot
.628 .36706 Mdot
.628 .36709 Mdot
.628 .36723 Mdot
.628 .36727 Mdot
.628 .36729 Mdot
.628 .36736 Mdot
.628 .36737 Mdot
.628 .36746 Mdot
.628 .36751 Mdot
.628 .36762 Mdot
.628 .36763 Mdot
.628 .36766 Mdot
.628 .36771 Mdot
.628 .36774 Mdot
.628 .36776 Mdot
.628 .3678 Mdot
.628 .36785 Mdot
.628 .36791 Mdot
.628 .36793 Mdot
.628 .36812 Mdot
.628 .36834 Mdot
.628 .36846 Mdot
.628 .36851 Mdot
.628 .3686 Mdot
.628 .36862 Mdot
.628 .36864 Mdot
.628 .36875 Mdot
.628 .36876 Mdot
.628 .3689 Mdot
.628 .36904 Mdot
.628 .36907 Mdot
.628 .36911 Mdot
.628 .36914 Mdot
.628 .36916 Mdot
.628 .3692 Mdot
.628 .36929 Mdot
.628 .36933 Mdot
.628 .36934 Mdot
.628 .36941 Mdot
.628 .36945 Mdot
.628 .36948 Mdot
.628 .36948 Mdot
.628 .36952 Mdot
.628 .3697 Mdot
.628 .36973 Mdot
.628 .36991 Mdot
.628 .36998 Mdot
.628 .36999 Mdot
.628 .37 Mdot
.628 .37 Mdot
.628 .37014 Mdot
.628 .37016 Mdot
.628 .37019 Mdot
.628 .37026 Mdot
.628 .37029 Mdot
.628 .37031 Mdot
.628 .37031 Mdot
.628 .37033 Mdot
.628 .37033 Mdot
.628 .37039 Mdot
.628 .37045 Mdot
.628 .37049 Mdot
.628 .37053 Mdot
.628 .37055 Mdot
.628 .37057 Mdot
.628 .37068 Mdot
.628 .3707 Mdot
.628 .37076 Mdot
.628 .37083 Mdot
.628 .37086 Mdot
.628 .37088 Mdot
.628 .3709 Mdot
.628 .37096 Mdot
.628 .37098 Mdot
.628 .37108 Mdot
.628 .37124 Mdot
.628 .37125 Mdot
.628 .37132 Mdot
.628 .37134 Mdot
.628 .37137 Mdot
.628 .37141 Mdot
.628 .37146 Mdot
.628 .37154 Mdot
.628 .37156 Mdot
.628 .37164 Mdot
.628 .3717 Mdot
.628 .37171 Mdot
.628 .37177 Mdot
.628 .37181 Mdot
.628 .37182 Mdot
.628 .37187 Mdot
.628 .37188 Mdot
.628 .37188 Mdot
.628 .3719 Mdot
.628 .37193 Mdot
.628 .37202 Mdot
.628 .3723 Mdot
.628 .37237 Mdot
.628 .3724 Mdot
.628 .37245 Mdot
.628 .37246 Mdot
.628 .37251 Mdot
.628 .37251 Mdot
.628 .37253 Mdot
.628 .37255 Mdot
.628 .37257 Mdot
.628 .37263 Mdot
.628 .37263 Mdot
.628 .37271 Mdot
.628 .3728 Mdot
.628 .37287 Mdot
.628 .3729 Mdot
.628 .37291 Mdot
.628 .37292 Mdot
.628 .37296 Mdot
.628 .37302 Mdot
.628 .37308 Mdot
.628 .37309 Mdot
.628 .3731 Mdot
.628 .37312 Mdot
.628 .37312 Mdot
.628 .37314 Mdot
.628 .37318 Mdot
.628 .3732 Mdot
.628 .3732 Mdot
.628 .37326 Mdot
.628 .37326 Mdot
.628 .37335 Mdot
.628 .37343 Mdot
.628 .37346 Mdot
.628 .37346 Mdot
.628 .37357 Mdot
.628 .3736 Mdot
.628 .37362 Mdot
.628 .37365 Mdot
.628 .37366 Mdot
.628 .37368 Mdot
.628 .3737 Mdot
.628 .37377 Mdot
.628 .3738 Mdot
.628 .37381 Mdot
.628 .37382 Mdot
.628 .37385 Mdot
.628 .3739 Mdot
.628 .37396 Mdot
.628 .37399 Mdot
.628 .37405 Mdot
.628 .37415 Mdot
.628 .37415 Mdot
.628 .37419 Mdot
.628 .37422 Mdot
.628 .37424 Mdot
.628 .37428 Mdot
.628 .37445 Mdot
.628 .3745 Mdot
.628 .37455 Mdot
.628 .37462 Mdot
.628 .37464 Mdot
.628 .37466 Mdot
.628 .3747 Mdot
.628 .37473 Mdot
.628 .37477 Mdot
.628 .37481 Mdot
.628 .37486 Mdot
.628 .3749 Mdot
.628 .37491 Mdot
.628 .37494 Mdot
.628 .37495 Mdot
.628 .375 Mdot
.628 .37516 Mdot
.628 .37525 Mdot
.628 .37527 Mdot
.628 .37533 Mdot
.628 .37535 Mdot
.628 .37536 Mdot
.628 .37538 Mdot
.628 .37542 Mdot
.628 .37544 Mdot
.628 .37545 Mdot
.628 .37547 Mdot
.628 .37561 Mdot
.628 .37565 Mdot
.628 .37565 Mdot
.628 .37573 Mdot
.628 .37581 Mdot
.628 .37588 Mdot
.628 .37591 Mdot
.628 .37599 Mdot
.628 .37601 Mdot
.628 .37602 Mdot
.628 .37609 Mdot
.628 .37613 Mdot
.628 .3763 Mdot
.628 .37633 Mdot
.628 .37633 Mdot
.628 .37635 Mdot
.628 .37638 Mdot
.628 .37644 Mdot
.628 .37647 Mdot
.628 .37648 Mdot
.628 .37652 Mdot
.628 .37654 Mdot
.628 .37661 Mdot
.628 .37664 Mdot
.628 .37675 Mdot
.628 .37679 Mdot
.628 .3768 Mdot
.628 .37699 Mdot
.628 .37705 Mdot
.628 .37707 Mdot
.628 .37712 Mdot
.628 .37713 Mdot
.628 .37715 Mdot
.628 .37718 Mdot
.628 .3772 Mdot
.628 .37727 Mdot
.628 .37727 Mdot
.628 .37734 Mdot
.628 .3774 Mdot
.628 .37744 Mdot
.628 .37747 Mdot
.628 .37751 Mdot
.628 .37758 Mdot
.628 .37761 Mdot
.628 .37762 Mdot
.628 .37765 Mdot
.628 .37774 Mdot
.628 .37784 Mdot
.628 .37784 Mdot
.628 .3779 Mdot
.628 .37794 Mdot
.628 .37801 Mdot
.628 .37818 Mdot
.628 .37824 Mdot
.628 .37827 Mdot
.628 .37831 Mdot
.628 .37834 Mdot
.628 .37838 Mdot
.628 .37839 Mdot
.628 .37854 Mdot
.628 .37857 Mdot
.628 .3786 Mdot
.628 .37861 Mdot
.628 .37863 Mdot
.628 .37867 Mdot
.628 .37868 Mdot
.628 .37878 Mdot
.628 .37884 Mdot
.628 .37886 Mdot
.628 .37889 Mdot
.628 .3789 Mdot
.628 .37892 Mdot
.628 .37894 Mdot
.628 .37898 Mdot
.628 .37902 Mdot
.628 .37903 Mdot
.628 .3791 Mdot
.628 .37911 Mdot
.628 .37913 Mdot
.628 .37915 Mdot
.628 .37918 Mdot
.628 .37922 Mdot
.628 .37925 Mdot
.628 .37926 Mdot
.628 .37926 Mdot
.628 .37926 Mdot
.628 .37928 Mdot
.628 .3793 Mdot
.628 .37934 Mdot
.628 .37937 Mdot
.628 .37946 Mdot
.628 .37946 Mdot
.628 .37947 Mdot
.628 .37948 Mdot
.628 .37952 Mdot
.628 .37964 Mdot
.628 .37965 Mdot
.628 .37977 Mdot
.628 .37979 Mdot
.628 .37979 Mdot
.628 .37981 Mdot
.628 .37984 Mdot
.628 .37988 Mdot
.628 .37989 Mdot
.628 .37991 Mdot
.628 .37997 Mdot
.628 .38 Mdot
.628 .38001 Mdot
.628 .38003 Mdot
.628 .38005 Mdot
.628 .38007 Mdot
.628 .38016 Mdot
.628 .38025 Mdot
.628 .38025 Mdot
.628 .38032 Mdot
.628 .38034 Mdot
.628 .38035 Mdot
.628 .38041 Mdot
.628 .38044 Mdot
.628 .38051 Mdot
.628 .38065 Mdot
.628 .38077 Mdot
.628 .38078 Mdot
.628 .38082 Mdot
.628 .38086 Mdot
.628 .38088 Mdot
.628 .3809 Mdot
.628 .38091 Mdot
.628 .38094 Mdot
.628 .38096 Mdot
.628 .38097 Mdot
.628 .38104 Mdot
.628 .38107 Mdot
.628 .38113 Mdot
.628 .38114 Mdot
.628 .38118 Mdot
.628 .3812 Mdot
.628 .38122 Mdot
.628 .3813 Mdot
.628 .38133 Mdot
.628 .38134 Mdot
.628 .38149 Mdot
.628 .38157 Mdot
.628 .38174 Mdot
.628 .38175 Mdot
.628 .38176 Mdot
.628 .38181 Mdot
.628 .38188 Mdot
.628 .38189 Mdot
.628 .38192 Mdot
.628 .38193 Mdot
.628 .38196 Mdot
.628 .38197 Mdot
.628 .38197 Mdot
.628 .38197 Mdot
.628 .38202 Mdot
.628 .38206 Mdot
.628 .38207 Mdot
.628 .38211 Mdot
.628 .38214 Mdot
.628 .38221 Mdot
.628 .38223 Mdot
.628 .38224 Mdot
.628 .38225 Mdot
.628 .38234 Mdot
.628 .38247 Mdot
.628 .3825 Mdot
.628 .38254 Mdot
.628 .38263 Mdot
.628 .3827 Mdot
.628 .38277 Mdot
.628 .38282 Mdot
.628 .38285 Mdot
.628 .38288 Mdot
.628 .38295 Mdot
.628 .38298 Mdot
.628 .38306 Mdot
.628 .38315 Mdot
.628 .38323 Mdot
.628 .38328 Mdot
.628 .38331 Mdot
.628 .38335 Mdot
.628 .38339 Mdot
.628 .38342 Mdot
.628 .38351 Mdot
.628 .38353 Mdot
.628 .38353 Mdot
.628 .38354 Mdot
.628 .38357 Mdot
.628 .38362 Mdot
.628 .38372 Mdot
.628 .38376 Mdot
.628 .38382 Mdot
.628 .38386 Mdot
.628 .38399 Mdot
.628 .38402 Mdot
.628 .38402 Mdot
.628 .38406 Mdot
.628 .38408 Mdot
.628 .3841 Mdot
.628 .38414 Mdot
.628 .38415 Mdot
.628 .38416 Mdot
.628 .38422 Mdot
.628 .38423 Mdot
.628 .38431 Mdot
.628 .38438 Mdot
.628 .3844 Mdot
.628 .38441 Mdot
.628 .38443 Mdot
.628 .38444 Mdot
.628 .38444 Mdot
.628 .38445 Mdot
.628 .38448 Mdot
.628 .38452 Mdot
.628 .38456 Mdot
.628 .38463 Mdot
.628 .38463 Mdot
.628 .38467 Mdot
.628 .38468 Mdot
.628 .38468 Mdot
.628 .38471 Mdot
.628 .38474 Mdot
.628 .38493 Mdot
.628 .38493 Mdot
.628 .38494 Mdot
.628 .38496 Mdot
.628 .38503 Mdot
.628 .38506 Mdot
.628 .38507 Mdot
.63 .28979 Mdot
.63 .28994 Mdot
.63 .28994 Mdot
.63 .28998 Mdot
.63 .28998 Mdot
.63 .28999 Mdot
.63 .29 Mdot
.63 .29001 Mdot
.63 .29004 Mdot
.63 .29005 Mdot
.63 .29011 Mdot
.63 .29015 Mdot
.63 .29029 Mdot
.63 .2903 Mdot
.63 .29031 Mdot
.63 .29031 Mdot
.63 .29034 Mdot
.63 .29049 Mdot
.63 .29051 Mdot
.63 .29052 Mdot
.63 .29056 Mdot
.63 .29071 Mdot
.63 .29085 Mdot
.63 .29088 Mdot
.63 .29091 Mdot
.63 .29105 Mdot
.63 .29107 Mdot
.63 .29118 Mdot
.63 .29124 Mdot
.63 .29136 Mdot
.63 .29136 Mdot
.63 .29152 Mdot
.63 .29153 Mdot
.63 .29171 Mdot
.63 .29179 Mdot
.63 .29182 Mdot
.63 .29182 Mdot
.63 .29192 Mdot
.63 .29202 Mdot
.63 .29209 Mdot
.63 .29215 Mdot
.63 .29218 Mdot
.63 .29226 Mdot
.63 .29237 Mdot
.63 .29247 Mdot
.63 .29259 Mdot
.63 .2926 Mdot
.63 .29261 Mdot
.63 .29263 Mdot
.63 .29265 Mdot
.63 .29268 Mdot
.63 .2927 Mdot
.63 .29278 Mdot
.63 .29279 Mdot
.63 .29279 Mdot
.63 .29279 Mdot
.63 .29283 Mdot
.63 .29286 Mdot
.63 .29289 Mdot
.63 .2929 Mdot
.63 .29303 Mdot
.63 .29306 Mdot
.63 .29308 Mdot
.63 .29321 Mdot
.63 .29325 Mdot
.63 .29331 Mdot
.63 .29337 Mdot
.63 .29346 Mdot
.63 .29356 Mdot
.63 .29376 Mdot
.63 .29381 Mdot
.63 .29383 Mdot
.63 .29388 Mdot
.63 .29389 Mdot
.63 .29393 Mdot
.63 .29398 Mdot
.63 .294 Mdot
.63 .29403 Mdot
.63 .29406 Mdot
.63 .29409 Mdot
.63 .29412 Mdot
.63 .29415 Mdot
.63 .29415 Mdot
.63 .29417 Mdot
.63 .29417 Mdot
.63 .29424 Mdot
.63 .29433 Mdot
.63 .29433 Mdot
.63 .29433 Mdot
.63 .29441 Mdot
.63 .29444 Mdot
.63 .29453 Mdot
.63 .29465 Mdot
.63 .2947 Mdot
.63 .29481 Mdot
.63 .29486 Mdot
.63 .2949 Mdot
.63 .2949 Mdot
.63 .29493 Mdot
.63 .29509 Mdot
.63 .29511 Mdot
.63 .29517 Mdot
.63 .29532 Mdot
.63 .29532 Mdot
.63 .29538 Mdot
.63 .29539 Mdot
.63 .29539 Mdot
.63 .29545 Mdot
.63 .29548 Mdot
.63 .29555 Mdot
.63 .29563 Mdot
.63 .2957 Mdot
.63 .29582 Mdot
.63 .29589 Mdot
.63 .29601 Mdot
.63 .29606 Mdot
.63 .2961 Mdot
.63 .29619 Mdot
.63 .29628 Mdot
.63 .29632 Mdot
.63 .29636 Mdot
.63 .2965 Mdot
.63 .2965 Mdot
.63 .29655 Mdot
.63 .29662 Mdot
.63 .2967 Mdot
.63 .29682 Mdot
.63 .29683 Mdot
.63 .29684 Mdot
.63 .29691 Mdot
.63 .29692 Mdot
.63 .29702 Mdot
.63 .29702 Mdot
.63 .29704 Mdot
.63 .29704 Mdot
.63 .29705 Mdot
.63 .29706 Mdot
.63 .29715 Mdot
.63 .29721 Mdot
.63 .29723 Mdot
.63 .29723 Mdot
.63 .29728 Mdot
.63 .29729 Mdot
.63 .29735 Mdot
.63 .29736 Mdot
.63 .29737 Mdot
.63 .29743 Mdot
.63 .29752 Mdot
.63 .29758 Mdot
.63 .29759 Mdot
.63 .29766 Mdot
.63 .2977 Mdot
.63 .29784 Mdot
.63 .29784 Mdot
.63 .29794 Mdot
.63 .29796 Mdot
.63 .29806 Mdot
.63 .2981 Mdot
.63 .29813 Mdot
.63 .29827 Mdot
.63 .29829 Mdot
.63 .2983 Mdot
.63 .2983 Mdot
.63 .29834 Mdot
.63 .29834 Mdot
.63 .29851 Mdot
.63 .29852 Mdot
.63 .29875 Mdot
.63 .29875 Mdot
.63 .29877 Mdot
.63 .29878 Mdot
.63 .29881 Mdot
.63 .29895 Mdot
.63 .29898 Mdot
.63 .299 Mdot
.63 .29903 Mdot
.63 .29908 Mdot
.63 .29925 Mdot
.63 .29929 Mdot
.63 .29934 Mdot
.63 .29937 Mdot
.63 .2994 Mdot
.63 .29943 Mdot
.63 .29954 Mdot
.63 .29964 Mdot
.63 .29965 Mdot
.63 .29969 Mdot
.63 .29981 Mdot
.63 .29989 Mdot
.63 .29998 Mdot
.63 .29998 Mdot
.63 .30002 Mdot
.63 .30002 Mdot
.63 .30002 Mdot
.63 .30003 Mdot
.63 .30009 Mdot
.63 .30015 Mdot
.63 .30015 Mdot
.63 .30043 Mdot
.63 .30046 Mdot
.63 .30053 Mdot
.63 .30054 Mdot
.63 .30054 Mdot
.63 .30061 Mdot
.63 .30061 Mdot
.63 .3007 Mdot
.63 .30071 Mdot
.63 .30071 Mdot
.63 .30073 Mdot
.63 .3008 Mdot
.63 .30084 Mdot
.63 .30092 Mdot
.63 .30094 Mdot
.63 .30095 Mdot
.63 .30098 Mdot
.63 .30106 Mdot
.63 .30113 Mdot
.63 .30116 Mdot
.63 .30119 Mdot
.63 .30121 Mdot
.63 .30121 Mdot
.63 .30142 Mdot
.63 .30144 Mdot
.63 .30152 Mdot
.63 .30153 Mdot
.63 .30156 Mdot
.63 .30176 Mdot
.63 .30181 Mdot
.63 .30192 Mdot
.63 .30204 Mdot
.63 .3021 Mdot
.63 .30226 Mdot
.63 .30228 Mdot
.63 .30233 Mdot
.63 .30235 Mdot
.63 .30248 Mdot
.63 .30265 Mdot
.63 .30267 Mdot
.63 .30272 Mdot
.63 .30274 Mdot
.63 .30286 Mdot
.63 .3029 Mdot
.63 .3029 Mdot
.63 .30315 Mdot
.63 .30315 Mdot
.63 .30323 Mdot
.63 .30323 Mdot
.63 .30323 Mdot
.63 .30326 Mdot
.63 .30331 Mdot
.63 .30336 Mdot
.63 .30344 Mdot
.63 .30347 Mdot
.63 .3036 Mdot
.63 .30364 Mdot
.63 .30366 Mdot
.63 .30369 Mdot
.63 .30382 Mdot
.63 .30388 Mdot
.63 .30388 Mdot
.63 .3039 Mdot
.63 .30399 Mdot
.63 .30402 Mdot
.63 .30403 Mdot
.63 .30403 Mdot
.63 .30417 Mdot
.63 .30418 Mdot
.63 .30429 Mdot
.63 .30429 Mdot
.63 .30431 Mdot
.63 .30432 Mdot
.63 .30432 Mdot
.63 .30442 Mdot
.63 .30447 Mdot
.63 .30461 Mdot
.63 .30476 Mdot
.63 .30491 Mdot
.63 .30491 Mdot
.63 .305 Mdot
.63 .30504 Mdot
.63 .3051 Mdot
.63 .30511 Mdot
.63 .30511 Mdot
.63 .30512 Mdot
.63 .30512 Mdot
.63 .30518 Mdot
.63 .30519 Mdot
.63 .30532 Mdot
.63 .30545 Mdot
.63 .30545 Mdot
.63 .30554 Mdot
.63 .30559 Mdot
.63 .30564 Mdot
.63 .3057 Mdot
.63 .30573 Mdot
.63 .30588 Mdot
.63 .30595 Mdot
.63 .30605 Mdot
.63 .30611 Mdot
.63 .30615 Mdot
.63 .30619 Mdot
.63 .30628 Mdot
.63 .30632 Mdot
.63 .30633 Mdot
.63 .30644 Mdot
.63 .30646 Mdot
.63 .30652 Mdot
.63 .30661 Mdot
.63 .30669 Mdot
.63 .30674 Mdot
.63 .30676 Mdot
.63 .30681 Mdot
.63 .30687 Mdot
.63 .30695 Mdot
.63 .30696 Mdot
.63 .30699 Mdot
.63 .307 Mdot
.63 .30703 Mdot
.63 .30709 Mdot
.63 .3071 Mdot
.63 .30713 Mdot
.63 .30714 Mdot
.63 .30737 Mdot
.63 .30746 Mdot
.63 .30749 Mdot
.63 .30752 Mdot
.63 .30761 Mdot
.63 .30763 Mdot
.63 .30772 Mdot
.63 .30774 Mdot
.63 .30776 Mdot
.63 .30778 Mdot
.63 .30778 Mdot
.63 .30779 Mdot
.63 .30779 Mdot
.63 .30784 Mdot
.63 .30785 Mdot
.63 .30787 Mdot
.63 .30789 Mdot
.63 .3079 Mdot
.63 .30791 Mdot
.63 .30812 Mdot
.63 .30817 Mdot
.63 .30823 Mdot
.63 .30827 Mdot
.63 .30839 Mdot
.63 .30842 Mdot
.63 .30858 Mdot
.63 .30858 Mdot
.63 .3088 Mdot
.63 .30887 Mdot
.63 .30897 Mdot
.63 .30899 Mdot
.63 .30909 Mdot
.63 .30924 Mdot
.63 .30933 Mdot
.63 .30935 Mdot
.63 .30935 Mdot
.63 .30945 Mdot
.63 .30947 Mdot
.63 .30954 Mdot
.63 .30955 Mdot
.63 .30958 Mdot
.63 .30967 Mdot
.63 .30981 Mdot
.63 .30984 Mdot
.63 .30985 Mdot
.63 .30986 Mdot
.63 .30988 Mdot
.63 .30988 Mdot
.63 .31004 Mdot
.63 .31005 Mdot
.63 .31017 Mdot
.63 .31018 Mdot
.63 .3102 Mdot
.63 .31039 Mdot
.63 .31051 Mdot
.63 .31063 Mdot
.63 .3107 Mdot
.63 .31071 Mdot
.63 .31093 Mdot
.63 .311 Mdot
.63 .31106 Mdot
.63 .3112 Mdot
.63 .31134 Mdot
.63 .31141 Mdot
.63 .31148 Mdot
.63 .31168 Mdot
.63 .31179 Mdot
.63 .31197 Mdot
.63 .31209 Mdot
.63 .31222 Mdot
.63 .31232 Mdot
.63 .31237 Mdot
.63 .31247 Mdot
.63 .31248 Mdot
.63 .31248 Mdot
.63 .31258 Mdot
.63 .31258 Mdot
.63 .31281 Mdot
.63 .31291 Mdot
.63 .31294 Mdot
.63 .3132 Mdot
.63 .31324 Mdot
.63 .31325 Mdot
.63 .3133 Mdot
.63 .31339 Mdot
.63 .31356 Mdot
.63 .31364 Mdot
.63 .31383 Mdot
.63 .31397 Mdot
.63 .31402 Mdot
.63 .31414 Mdot
.63 .31415 Mdot
.63 .31416 Mdot
.63 .3143 Mdot
.63 .3144 Mdot
.63 .31441 Mdot
.63 .31443 Mdot
.63 .31444 Mdot
.63 .31449 Mdot
.63 .31453 Mdot
.63 .31458 Mdot
.63 .31463 Mdot
.63 .31467 Mdot
.63 .3147 Mdot
.63 .31479 Mdot
.63 .31485 Mdot
.63 .31486 Mdot
.63 .31495 Mdot
.63 .31497 Mdot
.63 .31506 Mdot
.63 .31538 Mdot
.63 .31554 Mdot
.63 .31568 Mdot
.63 .31577 Mdot
.63 .31586 Mdot
.63 .31593 Mdot
.63 .31613 Mdot
.63 .31616 Mdot
.63 .31621 Mdot
.63 .31642 Mdot
.63 .31644 Mdot
.63 .31648 Mdot
.63 .31653 Mdot
.63 .31659 Mdot
.63 .31659 Mdot
.63 .3166 Mdot
.63 .31661 Mdot
.63 .31674 Mdot
.63 .31676 Mdot
.63 .31681 Mdot
.63 .31686 Mdot
.63 .31688 Mdot
.63 .3169 Mdot
.63 .31691 Mdot
.63 .31711 Mdot
.63 .31726 Mdot
.63 .31743 Mdot
.63 .31757 Mdot
.63 .31762 Mdot
.63 .31771 Mdot
.63 .31782 Mdot
.63 .31798 Mdot
.63 .31813 Mdot
.63 .31813 Mdot
.63 .31818 Mdot
.63 .31832 Mdot
.63 .3186 Mdot
.63 .31861 Mdot
.63 .31887 Mdot
.63 .31887 Mdot
.63 .31905 Mdot
.63 .31915 Mdot
.63 .31932 Mdot
.63 .31936 Mdot
.63 .31958 Mdot
.63 .31964 Mdot
.63 .31967 Mdot
.63 .3199 Mdot
.63 .32013 Mdot
.63 .3202 Mdot
.63 .32022 Mdot
.63 .32025 Mdot
.63 .32048 Mdot
.63 .32053 Mdot
.63 .32054 Mdot
.63 .32055 Mdot
.63 .32056 Mdot
.63 .32079 Mdot
.63 .32085 Mdot
.63 .32094 Mdot
.63 .32096 Mdot
.63 .32101 Mdot
.63 .32102 Mdot
.63 .32104 Mdot
.63 .32105 Mdot
.63 .32105 Mdot
.63 .32112 Mdot
.63 .32113 Mdot
.63 .32136 Mdot
.63 .36131 Mdot
.63 .36149 Mdot
.63 .3615 Mdot
.63 .36155 Mdot
.63 .36155 Mdot
.63 .36157 Mdot
.63 .36158 Mdot
.63 .36158 Mdot
.63 .36163 Mdot
.63 .36164 Mdot
.63 .36172 Mdot
.63 .36176 Mdot
.63 .36194 Mdot
.63 .36195 Mdot
.63 .36196 Mdot
.63 .36197 Mdot
.63 .36201 Mdot
.63 .36219 Mdot
.63 .36222 Mdot
.63 .36223 Mdot
.63 .36228 Mdot
.63 .36247 Mdot
.63 .36265 Mdot
.63 .36268 Mdot
.63 .36272 Mdot
.63 .36289 Mdot
.63 .36293 Mdot
.63 .36307 Mdot
.63 .36314 Mdot
.63 .36328 Mdot
.63 .36329 Mdot
.63 .36349 Mdot
.63 .3635 Mdot
.63 .36372 Mdot
.63 .36383 Mdot
.63 .36387 Mdot
.63 .36387 Mdot
.63 .36399 Mdot
.63 .36412 Mdot
.63 .3642 Mdot
.63 .36428 Mdot
.63 .36432 Mdot
.63 .36443 Mdot
.63 .36456 Mdot
.63 .36469 Mdot
.63 .36484 Mdot
.63 .36485 Mdot
.63 .36487 Mdot
.63 .36488 Mdot
.63 .36492 Mdot
.63 .36496 Mdot
.63 .36497 Mdot
.63 .36508 Mdot
.63 .36509 Mdot
.63 .36509 Mdot
.63 .36509 Mdot
.63 .36514 Mdot
.63 .36518 Mdot
.63 .36522 Mdot
.63 .36523 Mdot
.63 .3654 Mdot
.63 .36543 Mdot
.63 .36546 Mdot
.63 .36562 Mdot
.63 .36567 Mdot
.63 .36575 Mdot
.63 .36582 Mdot
.63 .36593 Mdot
.63 .36606 Mdot
.63 .36631 Mdot
.63 .36638 Mdot
.63 .3664 Mdot
.63 .36647 Mdot
.63 .36647 Mdot
.63 .36652 Mdot
.63 .36659 Mdot
.63 .36661 Mdot
.63 .36665 Mdot
.63 .36669 Mdot
.63 .36673 Mdot
.63 .36676 Mdot
.63 .3668 Mdot
.63 .36681 Mdot
.63 .36683 Mdot
.63 .36683 Mdot
.63 .36691 Mdot
.63 .36703 Mdot
.63 .36703 Mdot
.63 .36704 Mdot
.63 .36713 Mdot
.63 .36717 Mdot
.63 .36729 Mdot
.63 .36744 Mdot
.63 .3675 Mdot
.63 .36763 Mdot
.63 .3677 Mdot
.63 .36775 Mdot
.63 .36775 Mdot
.63 .36778 Mdot
.63 .36799 Mdot
.63 .36801 Mdot
.63 .36809 Mdot
.63 .36828 Mdot
.63 .36828 Mdot
.63 .36836 Mdot
.63 .36836 Mdot
.63 .36837 Mdot
.63 .36844 Mdot
.63 .36848 Mdot
.63 .36856 Mdot
.63 .36866 Mdot
.63 .36876 Mdot
.63 .3689 Mdot
.63 .36899 Mdot
.63 .36915 Mdot
.63 .36921 Mdot
.63 .36926 Mdot
.63 .36937 Mdot
.63 .36948 Mdot
.63 .36953 Mdot
.63 .36959 Mdot
.63 .36976 Mdot
.63 .36977 Mdot
.63 .36982 Mdot
.63 .36992 Mdot
.63 .37002 Mdot
.63 .37016 Mdot
.63 .37018 Mdot
.63 .37019 Mdot
.63 .37029 Mdot
.63 .3703 Mdot
.63 .37042 Mdot
.63 .37042 Mdot
.63 .37044 Mdot
.63 .37045 Mdot
.63 .37045 Mdot
.63 .37047 Mdot
.63 .37058 Mdot
.63 .37066 Mdot
.63 .37068 Mdot
.63 .37069 Mdot
.63 .37074 Mdot
.63 .37076 Mdot
.63 .37084 Mdot
.63 .37084 Mdot
.63 .37086 Mdot
.63 .37093 Mdot
.63 .37104 Mdot
.63 .37113 Mdot
.63 .37114 Mdot
.63 .37122 Mdot
.63 .37128 Mdot
.63 .37145 Mdot
.63 .37145 Mdot
.63 .37158 Mdot
.63 .3716 Mdot
.63 .3717 Mdot
.63 .37173 Mdot
.63 .37178 Mdot
.63 .37182 Mdot
.63 .37199 Mdot
.63 .37199 Mdot
.63 .372 Mdot
.63 .37201 Mdot
.63 .37203 Mdot
.63 .37204 Mdot
.63 .37208 Mdot
.63 .37208 Mdot
.63 .37208 Mdot
.63 .37208 Mdot
.63 .3721 Mdot
.63 .37212 Mdot
.63 .37213 Mdot
.63 .3722 Mdot
.63 .37222 Mdot
.63 .37229 Mdot
.63 .37231 Mdot
.63 .37234 Mdot
.63 .37242 Mdot
.63 .37259 Mdot
.63 .3726 Mdot
.63 .37263 Mdot
.63 .37263 Mdot
.63 .37268 Mdot
.63 .3727 Mdot
.63 .37272 Mdot
.63 .37273 Mdot
.63 .37274 Mdot
.63 .37281 Mdot
.63 .37285 Mdot
.63 .37289 Mdot
.63 .37291 Mdot
.63 .37295 Mdot
.63 .37301 Mdot
.63 .37309 Mdot
.63 .37314 Mdot
.63 .37315 Mdot
.63 .37323 Mdot
.63 .37324 Mdot
.63 .37327 Mdot
.63 .37335 Mdot
.63 .37338 Mdot
.63 .37341 Mdot
.63 .37346 Mdot
.63 .37354 Mdot
.63 .3736 Mdot
.63 .37372 Mdot
.63 .37374 Mdot
.63 .37378 Mdot
.63 .37383 Mdot
.63 .37387 Mdot
.63 .37394 Mdot
.63 .37394 Mdot
.63 .37404 Mdot
.63 .37414 Mdot
.63 .37415 Mdot
.63 .3742 Mdot
.63 .3742 Mdot
.63 .37421 Mdot
.63 .37421 Mdot
.63 .37421 Mdot
.63 .37426 Mdot
.63 .37429 Mdot
.63 .37436 Mdot
.63 .37436 Mdot
.63 .37448 Mdot
.63 .37461 Mdot
.63 .37472 Mdot
.63 .37475 Mdot
.63 .37483 Mdot
.63 .37484 Mdot
.63 .37484 Mdot
.63 .37486 Mdot
.63 .37486 Mdot
.63 .37494 Mdot
.63 .37495 Mdot
.63 .37506 Mdot
.63 .37506 Mdot
.63 .37507 Mdot
.63 .37509 Mdot
.63 .37516 Mdot
.63 .37518 Mdot
.63 .37518 Mdot
.63 .37523 Mdot
.63 .37533 Mdot
.63 .37536 Mdot
.63 .37537 Mdot
.63 .3754 Mdot
.63 .37551 Mdot
.63 .37553 Mdot
.63 .37559 Mdot
.63 .37563 Mdot
.63 .37568 Mdot
.63 .3757 Mdot
.63 .3757 Mdot
.63 .3757 Mdot
.63 .37576 Mdot
.63 .37576 Mdot
.63 .37596 Mdot
.63 .37596 Mdot
.63 .37599 Mdot
.63 .37609 Mdot
.63 .3761 Mdot
.63 .37615 Mdot
.63 .37616 Mdot
.63 .37629 Mdot
.63 .37639 Mdot
.63 .37641 Mdot
.63 .37645 Mdot
.63 .37647 Mdot
.63 .37659 Mdot
.63 .37665 Mdot
.63 .37674 Mdot
.63 .37683 Mdot
.63 .37686 Mdot
.63 .37702 Mdot
.63 .37705 Mdot
.63 .37706 Mdot
.63 .37711 Mdot
.63 .37714 Mdot
.63 .3773 Mdot
.63 .3773 Mdot
.63 .37731 Mdot
.63 .37734 Mdot
.63 .37737 Mdot
.63 .37742 Mdot
.63 .37749 Mdot
.63 .37751 Mdot
.63 .37751 Mdot
.63 .37753 Mdot
.63 .3776 Mdot
.63 .37762 Mdot
.63 .37768 Mdot
.63 .37769 Mdot
.63 .3777 Mdot
.63 .3777 Mdot
.63 .37777 Mdot
.63 .37778 Mdot
.63 .37783 Mdot
.63 .37783 Mdot
.63 .37784 Mdot
.63 .3779 Mdot
.63 .37792 Mdot
.63 .37814 Mdot
.63 .37814 Mdot
.63 .37819 Mdot
.63 .37824 Mdot
.63 .37824 Mdot
.63 .37825 Mdot
.63 .37825 Mdot
.63 .37828 Mdot
.63 .37828 Mdot
.63 .37835 Mdot
.63 .37841 Mdot
.63 .37851 Mdot
.63 .37854 Mdot
.63 .37855 Mdot
.63 .37863 Mdot
.63 .37871 Mdot
.63 .37874 Mdot
.63 .37876 Mdot
.63 .37878 Mdot
.63 .37883 Mdot
.63 .37885 Mdot
.63 .37899 Mdot
.63 .37903 Mdot
.63 .37906 Mdot
.63 .37907 Mdot
.63 .37909 Mdot
.63 .3792 Mdot
.63 .37923 Mdot
.63 .37923 Mdot
.63 .37925 Mdot
.63 .37926 Mdot
.63 .37943 Mdot
.63 .37945 Mdot
.63 .37958 Mdot
.63 .37958 Mdot
.63 .37961 Mdot
.63 .37961 Mdot
.63 .37962 Mdot
.63 .37963 Mdot
.63 .37974 Mdot
.63 .37977 Mdot
.63 .3798 Mdot
.63 .37988 Mdot
.63 .37989 Mdot
.63 .37998 Mdot
.63 .37998 Mdot
.63 .38008 Mdot
.63 .38012 Mdot
.63 .38017 Mdot
.63 .38018 Mdot
.63 .38023 Mdot
.63 .3803 Mdot
.63 .38035 Mdot
.63 .38036 Mdot
.63 .38036 Mdot
.63 .38041 Mdot
.63 .38042 Mdot
.63 .38046 Mdot
.63 .38046 Mdot
.63 .38048 Mdot
.63 .38052 Mdot
.63 .38059 Mdot
.63 .38061 Mdot
.63 .38061 Mdot
.63 .38061 Mdot
.63 .38062 Mdot
.63 .38063 Mdot
.63 .3807 Mdot
.63 .38071 Mdot
.63 .38077 Mdot
.63 .38077 Mdot
.63 .38079 Mdot
.63 .38088 Mdot
.63 .38094 Mdot
.63 .381 Mdot
.63 .38104 Mdot
.63 .38104 Mdot
.63 .38115 Mdot
.63 .38118 Mdot
.63 .38122 Mdot
.63 .38129 Mdot
.63 .38136 Mdot
.63 .38139 Mdot
.63 .38143 Mdot
.63 .38152 Mdot
.63 .38158 Mdot
.63 .38167 Mdot
.63 .38173 Mdot
.63 .38179 Mdot
.63 .38185 Mdot
.63 .38187 Mdot
.63 .38192 Mdot
.63 .38192 Mdot
.63 .38192 Mdot
.63 .38197 Mdot
.63 .38197 Mdot
.63 .38209 Mdot
.63 .38214 Mdot
.63 .38215 Mdot
.63 .38229 Mdot
.63 .38231 Mdot
.63 .38231 Mdot
.63 .38234 Mdot
.63 .38238 Mdot
.63 .38247 Mdot
.63 .3825 Mdot
.63 .3826 Mdot
.63 .38267 Mdot
.63 .3827 Mdot
.63 .38276 Mdot
.63 .38276 Mdot
.63 .38276 Mdot
.63 .38283 Mdot
.63 .38289 Mdot
.63 .38289 Mdot
.63 .3829 Mdot
.63 .38293 Mdot
.63 .38295 Mdot
.63 .38298 Mdot
.63 .383 Mdot
.63 .38302 Mdot
.63 .38304 Mdot
.63 .38308 Mdot
.63 .38311 Mdot
.63 .38312 Mdot
.63 .38316 Mdot
.63 .38317 Mdot
.63 .38321 Mdot
.63 .38337 Mdot
.63 .38345 Mdot
.63 .38352 Mdot
.63 .38357 Mdot
.63 .38362 Mdot
.63 .38365 Mdot
.63 .38375 Mdot
.63 .38377 Mdot
.63 .38379 Mdot
.63 .3839 Mdot
.63 .3839 Mdot
.63 .38393 Mdot
.63 .38395 Mdot
.63 .38398 Mdot
.63 .38398 Mdot
.63 .38398 Mdot
.63 .38399 Mdot
.63 .38406 Mdot
.63 .38407 Mdot
.63 .38409 Mdot
.63 .38411 Mdot
.63 .38412 Mdot
.63 .38414 Mdot
.63 .38414 Mdot
.63 .38424 Mdot
.63 .38431 Mdot
.63 .3844 Mdot
.63 .38447 Mdot
.63 .38449 Mdot
.63 .38454 Mdot
.63 .38459 Mdot
.63 .38467 Mdot
.63 .38475 Mdot
.63 .38475 Mdot
.63 .38478 Mdot
.63 .38484 Mdot
.63 .38498 Mdot
.63 .38499 Mdot
.63 .38512 Mdot
.63 .38512 Mdot
.63 .38521 Mdot
.63 .38526 Mdot
.63 .38535 Mdot
.63 .38537 Mdot
.63 .38548 Mdot
.63 .3855 Mdot
.63 .38552 Mdot
.63 .38563 Mdot
.63 .38575 Mdot
.63 .38579 Mdot
.63 .38579 Mdot
.63 .38581 Mdot
.63 .38592 Mdot
.63 .38595 Mdot
.63 .38595 Mdot
.63 .38596 Mdot
.63 .38596 Mdot
.63 .38608 Mdot
.63 .38611 Mdot
.63 .38616 Mdot
.63 .38616 Mdot
.63 .38619 Mdot
.63 .3862 Mdot
.63 .3862 Mdot
.63 .38621 Mdot
.63 .38621 Mdot
.63 .38624 Mdot
.63 .38625 Mdot
.63 .38636 Mdot
.632 .28914 Mdot
.632 .28916 Mdot
.632 .2892 Mdot
.632 .28923 Mdot
.632 .28943 Mdot
.632 .28953 Mdot
.632 .28953 Mdot
.632 .28964 Mdot
.632 .28968 Mdot
.632 .28979 Mdot
.632 .28981 Mdot
.632 .2901 Mdot
.632 .29014 Mdot
.632 .29015 Mdot
.632 .29024 Mdot
.632 .29025 Mdot
.632 .29049 Mdot
.632 .29062 Mdot
.632 .29063 Mdot
.632 .29067 Mdot
.632 .29072 Mdot
.632 .2908 Mdot
.632 .29081 Mdot
.632 .29086 Mdot
.632 .2909 Mdot
.632 .2909 Mdot
.632 .29096 Mdot
.632 .29097 Mdot
.632 .29098 Mdot
.632 .29104 Mdot
.632 .29109 Mdot
.632 .29114 Mdot
.632 .29118 Mdot
.632 .29131 Mdot
.632 .29142 Mdot
.632 .29153 Mdot
.632 .29159 Mdot
.632 .2916 Mdot
.632 .29164 Mdot
.632 .29164 Mdot
.632 .29165 Mdot
.632 .29166 Mdot
.632 .29181 Mdot
.632 .29182 Mdot
.632 .29186 Mdot
.632 .29207 Mdot
.632 .29211 Mdot
.632 .2922 Mdot
.632 .29222 Mdot
.632 .29222 Mdot
.632 .29223 Mdot
.632 .29226 Mdot
.632 .29226 Mdot
.632 .29234 Mdot
.632 .29243 Mdot
.632 .29249 Mdot
.632 .29258 Mdot
.632 .2926 Mdot
.632 .29267 Mdot
.632 .2927 Mdot
.632 .29274 Mdot
.632 .29277 Mdot
.632 .29284 Mdot
.632 .29297 Mdot
.632 .29298 Mdot
.632 .29299 Mdot
.632 .2931 Mdot
.632 .29322 Mdot
.632 .29323 Mdot
.632 .29328 Mdot
.632 .29334 Mdot
.632 .29337 Mdot
.632 .2934 Mdot
.632 .29356 Mdot
.632 .29361 Mdot
.632 .2938 Mdot
.632 .29381 Mdot
.632 .29381 Mdot
.632 .29388 Mdot
.632 .29397 Mdot
.632 .29397 Mdot
.632 .2941 Mdot
.632 .29411 Mdot
.632 .29411 Mdot
.632 .29412 Mdot
.632 .29423 Mdot
.632 .29441 Mdot
.632 .29444 Mdot
.632 .29453 Mdot
.632 .29453 Mdot
.632 .29454 Mdot
.632 .29456 Mdot
.632 .29456 Mdot
.632 .29458 Mdot
.632 .2946 Mdot
.632 .29464 Mdot
.632 .29471 Mdot
.632 .29471 Mdot
.632 .29475 Mdot
.632 .29483 Mdot
.632 .29488 Mdot
.632 .29493 Mdot
.632 .29494 Mdot
.632 .29497 Mdot
.632 .295 Mdot
.632 .295 Mdot
.632 .2951 Mdot
.632 .29517 Mdot
.632 .29523 Mdot
.632 .29532 Mdot
.632 .2954 Mdot
.632 .29542 Mdot
.632 .29548 Mdot
.632 .29561 Mdot
.632 .29566 Mdot
.632 .29576 Mdot
.632 .29585 Mdot
.632 .29585 Mdot
.632 .29587 Mdot
.632 .29593 Mdot
.632 .29598 Mdot
.632 .29606 Mdot
.632 .29608 Mdot
.632 .29611 Mdot
.632 .29611 Mdot
.632 .29614 Mdot
.632 .29614 Mdot
.632 .29618 Mdot
.632 .29639 Mdot
.632 .2964 Mdot
.632 .29643 Mdot
.632 .29644 Mdot
.632 .29661 Mdot
.632 .29668 Mdot
.632 .29668 Mdot
.632 .29671 Mdot
.632 .29683 Mdot
.632 .29684 Mdot
.632 .29685 Mdot
.632 .29686 Mdot
.632 .29703 Mdot
.632 .29708 Mdot
.632 .29709 Mdot
.632 .29721 Mdot
.632 .29736 Mdot
.632 .29741 Mdot
.632 .29743 Mdot
.632 .29748 Mdot
.632 .29761 Mdot
.632 .29763 Mdot
.632 .29777 Mdot
.632 .29779 Mdot
.632 .29781 Mdot
.632 .29782 Mdot
.632 .29788 Mdot
.632 .29798 Mdot
.632 .29804 Mdot
.632 .29804 Mdot
.632 .29805 Mdot
.632 .29808 Mdot
.632 .29812 Mdot
.632 .29814 Mdot
.632 .29819 Mdot
.632 .29823 Mdot
.632 .29833 Mdot
.632 .29834 Mdot
.632 .29838 Mdot
.632 .29843 Mdot
.632 .2985 Mdot
.632 .29858 Mdot
.632 .29866 Mdot
.632 .29877 Mdot
.632 .29878 Mdot
.632 .29878 Mdot
.632 .29894 Mdot
.632 .29895 Mdot
.632 .29896 Mdot
.632 .29897 Mdot
.632 .29899 Mdot
.632 .29928 Mdot
.632 .29929 Mdot
.632 .29931 Mdot
.632 .29936 Mdot
.632 .29938 Mdot
.632 .29946 Mdot
.632 .29946 Mdot
.632 .29947 Mdot
.632 .29949 Mdot
.632 .29951 Mdot
.632 .29956 Mdot
.632 .29957 Mdot
.632 .29959 Mdot
.632 .29967 Mdot
.632 .29967 Mdot
.632 .29976 Mdot
.632 .29992 Mdot
.632 .29994 Mdot
.632 .29999 Mdot
.632 .30015 Mdot
.632 .30021 Mdot
.632 .30023 Mdot
.632 .30032 Mdot
.632 .30036 Mdot
.632 .30039 Mdot
.632 .30047 Mdot
.632 .3005 Mdot
.632 .3006 Mdot
.632 .3006 Mdot
.632 .30067 Mdot
.632 .3008 Mdot
.632 .30081 Mdot
.632 .30083 Mdot
.632 .30084 Mdot
.632 .30087 Mdot
.632 .30087 Mdot
.632 .30089 Mdot
.632 .30091 Mdot
.632 .30092 Mdot
.632 .30096 Mdot
.632 .30114 Mdot
.632 .30117 Mdot
.632 .30121 Mdot
.632 .30127 Mdot
.632 .30128 Mdot
.632 .30153 Mdot
.632 .30156 Mdot
.632 .30158 Mdot
.632 .3017 Mdot
.632 .30183 Mdot
.632 .30191 Mdot
.632 .30192 Mdot
.632 .30194 Mdot
.632 .3021 Mdot
.632 .30214 Mdot
.632 .30218 Mdot
.632 .30232 Mdot
.632 .30235 Mdot
.632 .30237 Mdot
.632 .30238 Mdot
.632 .30248 Mdot
.632 .30252 Mdot
.632 .30259 Mdot
.632 .3026 Mdot
.632 .30265 Mdot
.632 .3027 Mdot
.632 .30275 Mdot
.632 .3028 Mdot
.632 .30293 Mdot
.632 .3031 Mdot
.632 .30316 Mdot
.632 .30317 Mdot
.632 .30321 Mdot
.632 .30323 Mdot
.632 .30324 Mdot
.632 .30324 Mdot
.632 .30328 Mdot
.632 .3033 Mdot
.632 .30334 Mdot
.632 .30335 Mdot
.632 .30354 Mdot
.632 .30355 Mdot
.632 .30366 Mdot
.632 .30366 Mdot
.632 .30367 Mdot
.632 .30379 Mdot
.632 .30384 Mdot
.632 .30388 Mdot
.632 .30391 Mdot
.632 .30401 Mdot
.632 .30406 Mdot
.632 .30407 Mdot
.632 .3041 Mdot
.632 .30412 Mdot
.632 .30412 Mdot
.632 .30426 Mdot
.632 .30427 Mdot
.632 .30428 Mdot
.632 .3043 Mdot
.632 .30438 Mdot
.632 .30439 Mdot
.632 .30451 Mdot
.632 .30452 Mdot
.632 .30465 Mdot
.632 .30472 Mdot
.632 .30472 Mdot
.632 .30476 Mdot
.632 .30487 Mdot
.632 .30495 Mdot
.632 .30498 Mdot
.632 .30502 Mdot
.632 .30515 Mdot
.632 .30516 Mdot
.632 .30529 Mdot
.632 .30531 Mdot
.632 .30532 Mdot
.632 .30533 Mdot
.632 .30541 Mdot
.632 .30544 Mdot
.632 .30548 Mdot
.632 .3055 Mdot
.632 .3055 Mdot
.632 .30561 Mdot
.632 .30565 Mdot
.632 .30573 Mdot
.632 .30577 Mdot
.632 .30577 Mdot
.632 .30592 Mdot
.632 .30597 Mdot
.632 .30618 Mdot
.632 .30621 Mdot
.632 .30625 Mdot
.632 .30628 Mdot
.632 .30629 Mdot
.632 .3063 Mdot
.632 .3063 Mdot
.632 .30632 Mdot
.632 .30659 Mdot
.632 .30659 Mdot
.632 .30659 Mdot
.632 .30677 Mdot
.632 .3069 Mdot
.632 .30703 Mdot
.632 .30706 Mdot
.632 .3071 Mdot
.632 .30714 Mdot
.632 .30722 Mdot
.632 .30729 Mdot
.632 .3073 Mdot
.632 .30738 Mdot
.632 .30747 Mdot
.632 .30749 Mdot
.632 .30753 Mdot
.632 .3076 Mdot
.632 .30763 Mdot
.632 .30769 Mdot
.632 .30774 Mdot
.632 .30776 Mdot
.632 .30776 Mdot
.632 .30777 Mdot
.632 .30778 Mdot
.632 .30786 Mdot
.632 .30802 Mdot
.632 .30802 Mdot
.632 .30812 Mdot
.632 .30812 Mdot
.632 .30815 Mdot
.632 .3082 Mdot
.632 .30841 Mdot
.632 .30844 Mdot
.632 .30855 Mdot
.632 .30862 Mdot
.632 .30865 Mdot
.632 .3087 Mdot
.632 .30874 Mdot
.632 .30876 Mdot
.632 .30877 Mdot
.632 .30885 Mdot
.632 .30909 Mdot
.632 .30928 Mdot
.632 .30929 Mdot
.632 .30938 Mdot
.632 .30964 Mdot
.632 .30966 Mdot
.632 .30968 Mdot
.632 .30969 Mdot
.632 .30988 Mdot
.632 .30994 Mdot
.632 .30994 Mdot
.632 .31004 Mdot
.632 .31032 Mdot
.632 .31033 Mdot
.632 .31038 Mdot
.632 .3104 Mdot
.632 .31074 Mdot
.632 .3108 Mdot
.632 .3108 Mdot
.632 .31084 Mdot
.632 .31084 Mdot
.632 .31089 Mdot
.632 .31092 Mdot
.632 .31105 Mdot
.632 .31113 Mdot
.632 .31123 Mdot
.632 .31126 Mdot
.632 .31127 Mdot
.632 .3114 Mdot
.632 .31156 Mdot
.632 .31165 Mdot
.632 .31185 Mdot
.632 .31195 Mdot
.632 .31197 Mdot
.632 .3121 Mdot
.632 .31225 Mdot
.632 .31234 Mdot
.632 .31246 Mdot
.632 .31262 Mdot
.632 .31262 Mdot
.632 .31266 Mdot
.632 .31272 Mdot
.632 .31272 Mdot
.632 .31281 Mdot
.632 .31289 Mdot
.632 .31302 Mdot
.632 .31307 Mdot
.632 .31308 Mdot
.632 .31319 Mdot
.632 .31326 Mdot
.632 .31329 Mdot
.632 .31333 Mdot
.632 .31333 Mdot
.632 .31335 Mdot
.632 .31336 Mdot
.632 .31337 Mdot
.632 .31351 Mdot
.632 .31357 Mdot
.632 .31384 Mdot
.632 .31403 Mdot
.632 .31404 Mdot
.632 .31404 Mdot
.632 .31406 Mdot
.632 .31426 Mdot
.632 .31426 Mdot
.632 .31442 Mdot
.632 .31451 Mdot
.632 .31452 Mdot
.632 .31453 Mdot
.632 .31484 Mdot
.632 .31492 Mdot
.632 .31517 Mdot
.632 .31523 Mdot
.632 .31527 Mdot
.632 .31536 Mdot
.632 .31545 Mdot
.632 .31545 Mdot
.632 .31566 Mdot
.632 .31583 Mdot
.632 .31584 Mdot
.632 .31586 Mdot
.632 .31607 Mdot
.632 .31618 Mdot
.632 .31623 Mdot
.632 .31629 Mdot
.632 .31634 Mdot
.632 .31644 Mdot
.632 .31649 Mdot
.632 .31663 Mdot
.632 .31672 Mdot
.632 .31687 Mdot
.632 .317 Mdot
.632 .317 Mdot
.632 .31704 Mdot
.632 .31705 Mdot
.632 .31707 Mdot
.632 .31709 Mdot
.632 .31723 Mdot
.632 .3173 Mdot
.632 .31764 Mdot
.632 .3177 Mdot
.632 .31771 Mdot
.632 .31795 Mdot
.632 .31797 Mdot
.632 .31798 Mdot
.632 .31798 Mdot
.632 .31805 Mdot
.632 .31807 Mdot
.632 .31816 Mdot
.632 .31833 Mdot
.632 .31852 Mdot
.632 .31871 Mdot
.632 .31879 Mdot
.632 .31887 Mdot
.632 .31894 Mdot
.632 .31905 Mdot
.632 .31906 Mdot
.632 .31907 Mdot
.632 .31917 Mdot
.632 .31917 Mdot
.632 .31924 Mdot
.632 .31932 Mdot
.632 .31932 Mdot
.632 .31945 Mdot
.632 .31954 Mdot
.632 .3196 Mdot
.632 .31961 Mdot
.632 .31982 Mdot
.632 .3202 Mdot
.632 .32023 Mdot
.632 .32037 Mdot
.632 .32038 Mdot
.632 .32044 Mdot
.632 .32092 Mdot
.632 .32094 Mdot
.632 .32111 Mdot
.632 .32118 Mdot
.632 .32136 Mdot
.632 .32137 Mdot
.632 .32151 Mdot
.632 .32184 Mdot
.632 .32189 Mdot
.632 .32194 Mdot
.632 .32198 Mdot
.632 .36159 Mdot
.632 .36162 Mdot
.632 .36166 Mdot
.632 .3617 Mdot
.632 .36196 Mdot
.632 .36207 Mdot
.632 .36208 Mdot
.632 .36222 Mdot
.632 .36227 Mdot
.632 .36241 Mdot
.632 .36243 Mdot
.632 .36281 Mdot
.632 .36285 Mdot
.632 .36287 Mdot
.632 .36297 Mdot
.632 .363 Mdot
.632 .3633 Mdot
.632 .36346 Mdot
.632 .36347 Mdot
.632 .36352 Mdot
.632 .36359 Mdot
.632 .36369 Mdot
.632 .3637 Mdot
.632 .36376 Mdot
.632 .36381 Mdot
.632 .36382 Mdot
.632 .36389 Mdot
.632 .3639 Mdot
.632 .36391 Mdot
.632 .36399 Mdot
.632 .36405 Mdot
.632 .36411 Mdot
.632 .36417 Mdot
.632 .36433 Mdot
.632 .36448 Mdot
.632 .36461 Mdot
.632 .36468 Mdot
.632 .3647 Mdot
.632 .36475 Mdot
.632 .36475 Mdot
.632 .36476 Mdot
.632 .36478 Mdot
.632 .36497 Mdot
.632 .36498 Mdot
.632 .36502 Mdot
.632 .36529 Mdot
.632 .36535 Mdot
.632 .36545 Mdot
.632 .36548 Mdot
.632 .36549 Mdot
.632 .3655 Mdot
.632 .36553 Mdot
.632 .36553 Mdot
.632 .36563 Mdot
.632 .36575 Mdot
.632 .36582 Mdot
.632 .36593 Mdot
.632 .36597 Mdot
.632 .36605 Mdot
.632 .36609 Mdot
.632 .36614 Mdot
.632 .36618 Mdot
.632 .36627 Mdot
.632 .36643 Mdot
.632 .36644 Mdot
.632 .36645 Mdot
.632 .36659 Mdot
.632 .36675 Mdot
.632 .36675 Mdot
.632 .36683 Mdot
.632 .3669 Mdot
.632 .36693 Mdot
.632 .36698 Mdot
.632 .36717 Mdot
.632 .36724 Mdot
.632 .36748 Mdot
.632 .36749 Mdot
.632 .3675 Mdot
.632 .36757 Mdot
.632 .36769 Mdot
.632 .36769 Mdot
.632 .36785 Mdot
.632 .36787 Mdot
.632 .36787 Mdot
.632 .36788 Mdot
.632 .36803 Mdot
.632 .36824 Mdot
.632 .36829 Mdot
.632 .3684 Mdot
.632 .36841 Mdot
.632 .36842 Mdot
.632 .36844 Mdot
.632 .36844 Mdot
.632 .36846 Mdot
.632 .36849 Mdot
.632 .36854 Mdot
.632 .36863 Mdot
.632 .36863 Mdot
.632 .36868 Mdot
.632 .36878 Mdot
.632 .36884 Mdot
.632 .36891 Mdot
.632 .36891 Mdot
.632 .36896 Mdot
.632 .36899 Mdot
.632 .369 Mdot
.632 .36912 Mdot
.632 .36921 Mdot
.632 .36928 Mdot
.632 .3694 Mdot
.632 .36951 Mdot
.632 .36952 Mdot
.632 .3696 Mdot
.632 .36976 Mdot
.632 .36983 Mdot
.632 .36996 Mdot
.632 .37006 Mdot
.632 .37007 Mdot
.632 .37009 Mdot
.632 .37017 Mdot
.632 .37023 Mdot
.632 .37034 Mdot
.632 .37036 Mdot
.632 .3704 Mdot
.632 .3704 Mdot
.632 .37043 Mdot
.632 .37044 Mdot
.632 .37048 Mdot
.632 .37075 Mdot
.632 .37076 Mdot
.632 .3708 Mdot
.632 .37081 Mdot
.632 .37104 Mdot
.632 .37111 Mdot
.632 .37111 Mdot
.632 .37116 Mdot
.632 .37131 Mdot
.632 .37132 Mdot
.632 .37134 Mdot
.632 .37135 Mdot
.632 .37156 Mdot
.632 .37163 Mdot
.632 .37164 Mdot
.632 .37178 Mdot
.632 .37198 Mdot
.632 .37204 Mdot
.632 .37205 Mdot
.632 .37206 Mdot
.632 .37209 Mdot
.632 .37213 Mdot
.632 .37216 Mdot
.632 .37222 Mdot
.632 .3723 Mdot
.632 .37232 Mdot
.632 .37249 Mdot
.632 .37253 Mdot
.632 .37255 Mdot
.632 .37256 Mdot
.632 .37263 Mdot
.632 .37263 Mdot
.632 .37276 Mdot
.632 .37282 Mdot
.632 .37283 Mdot
.632 .37283 Mdot
.632 .37284 Mdot
.632 .37285 Mdot
.632 .37289 Mdot
.632 .37294 Mdot
.632 .37297 Mdot
.632 .37302 Mdot
.632 .37305 Mdot
.632 .37307 Mdot
.632 .37314 Mdot
.632 .3732 Mdot
.632 .37321 Mdot
.632 .37327 Mdot
.632 .37333 Mdot
.632 .37336 Mdot
.632 .37339 Mdot
.632 .37342 Mdot
.632 .37352 Mdot
.632 .37362 Mdot
.632 .37376 Mdot
.632 .37377 Mdot
.632 .37377 Mdot
.632 .37398 Mdot
.632 .37399 Mdot
.632 .37399 Mdot
.632 .374 Mdot
.632 .37401 Mdot
.632 .37403 Mdot
.632 .37407 Mdot
.632 .37409 Mdot
.632 .37426 Mdot
.632 .37429 Mdot
.632 .37441 Mdot
.632 .37442 Mdot
.632 .37445 Mdot
.632 .37451 Mdot
.632 .37454 Mdot
.632 .37463 Mdot
.632 .37463 Mdot
.632 .37464 Mdot
.632 .37467 Mdot
.632 .37469 Mdot
.632 .37476 Mdot
.632 .37477 Mdot
.632 .37477 Mdot
.632 .37479 Mdot
.632 .3749 Mdot
.632 .3749 Mdot
.632 .37501 Mdot
.632 .37504 Mdot
.632 .37506 Mdot
.632 .37513 Mdot
.632 .37521 Mdot
.632 .37524 Mdot
.632 .37524 Mdot
.632 .3753 Mdot
.632 .3754 Mdot
.632 .37541 Mdot
.632 .3755 Mdot
.632 .37551 Mdot
.632 .37558 Mdot
.632 .37559 Mdot
.632 .3756 Mdot
.632 .37561 Mdot
.632 .37572 Mdot
.632 .37572 Mdot
.632 .37574 Mdot
.632 .37575 Mdot
.632 .37577 Mdot
.632 .37581 Mdot
.632 .37588 Mdot
.632 .37591 Mdot
.632 .37594 Mdot
.632 .37598 Mdot
.632 .37608 Mdot
.632 .37608 Mdot
.632 .37608 Mdot
.632 .37617 Mdot
.632 .37617 Mdot
.632 .37633 Mdot
.632 .37633 Mdot
.632 .37637 Mdot
.632 .37638 Mdot
.632 .37642 Mdot
.632 .37642 Mdot
.632 .37642 Mdot
.632 .37644 Mdot
.632 .37647 Mdot
.632 .37648 Mdot
.632 .37652 Mdot
.632 .37666 Mdot
.632 .37676 Mdot
.632 .3768 Mdot
.632 .37684 Mdot
.632 .37688 Mdot
.632 .37692 Mdot
.632 .37693 Mdot
.632 .37698 Mdot
.632 .37702 Mdot
.632 .3771 Mdot
.632 .3771 Mdot
.632 .37712 Mdot
.632 .37714 Mdot
.632 .37725 Mdot
.632 .37728 Mdot
.632 .37731 Mdot
.632 .37744 Mdot
.632 .37746 Mdot
.632 .37747 Mdot
.632 .37753 Mdot
.632 .37763 Mdot
.632 .37773 Mdot
.632 .37775 Mdot
.632 .37777 Mdot
.632 .37797 Mdot
.632 .37797 Mdot
.632 .37802 Mdot
.632 .37805 Mdot
.632 .37807 Mdot
.632 .37822 Mdot
.632 .37825 Mdot
.632 .37826 Mdot
.632 .37827 Mdot
.632 .37829 Mdot
.632 .37829 Mdot
.632 .37831 Mdot
.632 .37832 Mdot
.632 .37834 Mdot
.632 .37834 Mdot
.632 .37845 Mdot
.632 .3785 Mdot
.632 .3785 Mdot
.632 .37858 Mdot
.632 .37861 Mdot
.632 .37867 Mdot
.632 .3787 Mdot
.632 .37873 Mdot
.632 .3788 Mdot
.632 .37881 Mdot
.632 .37886 Mdot
.632 .37899 Mdot
.632 .37902 Mdot
.632 .37904 Mdot
.632 .37917 Mdot
.632 .37924 Mdot
.632 .37924 Mdot
.632 .37931 Mdot
.632 .37932 Mdot
.632 .37933 Mdot
.632 .37937 Mdot
.632 .37938 Mdot
.632 .3794 Mdot
.632 .37941 Mdot
.632 .37941 Mdot
.632 .37946 Mdot
.632 .37948 Mdot
.632 .37952 Mdot
.632 .37954 Mdot
.632 .37954 Mdot
.632 .37978 Mdot
.632 .37979 Mdot
.632 .3798 Mdot
.632 .37981 Mdot
.632 .37982 Mdot
.632 .37995 Mdot
.632 .37995 Mdot
.632 .37995 Mdot
.632 .38004 Mdot
.632 .3801 Mdot
.632 .38016 Mdot
.632 .38022 Mdot
.632 .38026 Mdot
.632 .38029 Mdot
.632 .3803 Mdot
.632 .38038 Mdot
.632 .38041 Mdot
.632 .38045 Mdot
.632 .38047 Mdot
.632 .3805 Mdot
.632 .38052 Mdot
.632 .38053 Mdot
.632 .38053 Mdot
.632 .38058 Mdot
.632 .38066 Mdot
.632 .3807 Mdot
.632 .38071 Mdot
.632 .38072 Mdot
.632 .38074 Mdot
.632 .38085 Mdot
.632 .38087 Mdot
.632 .38097 Mdot
.632 .38101 Mdot
.632 .38103 Mdot
.632 .38107 Mdot
.632 .38119 Mdot
.632 .38128 Mdot
.632 .38128 Mdot
.632 .38133 Mdot
.632 .38146 Mdot
.632 .38147 Mdot
.632 .38148 Mdot
.632 .38149 Mdot
.632 .38158 Mdot
.632 .38161 Mdot
.632 .38161 Mdot
.632 .38166 Mdot
.632 .3818 Mdot
.632 .3818 Mdot
.632 .38183 Mdot
.632 .38183 Mdot
.632 .382 Mdot
.632 .38203 Mdot
.632 .38203 Mdot
.632 .38205 Mdot
.632 .38205 Mdot
.632 .38208 Mdot
.632 .38209 Mdot
.632 .38216 Mdot
.632 .3822 Mdot
.632 .38225 Mdot
.632 .38226 Mdot
.632 .38226 Mdot
.632 .38233 Mdot
.632 .38241 Mdot
.632 .38245 Mdot
.632 .38255 Mdot
.632 .3826 Mdot
.632 .38261 Mdot
.632 .38268 Mdot
.632 .38275 Mdot
.632 .3828 Mdot
.632 .38286 Mdot
.632 .38293 Mdot
.632 .38294 Mdot
.632 .38296 Mdot
.632 .38298 Mdot
.632 .38298 Mdot
.632 .38303 Mdot
.632 .38307 Mdot
.632 .38313 Mdot
.632 .38316 Mdot
.632 .38316 Mdot
.632 .38322 Mdot
.632 .38325 Mdot
.632 .38327 Mdot
.632 .38328 Mdot
.632 .38328 Mdot
.632 .3833 Mdot
.632 .3833 Mdot
.632 .3833 Mdot
.632 .38337 Mdot
.632 .38354 Mdot
.632 .38363 Mdot
.632 .38364 Mdot
.632 .38364 Mdot
.632 .38365 Mdot
.632 .38375 Mdot
.632 .38375 Mdot
.632 .38382 Mdot
.632 .38387 Mdot
.632 .38387 Mdot
.632 .38388 Mdot
.632 .38403 Mdot
.632 .38407 Mdot
.632 .3842 Mdot
.632 .38423 Mdot
.632 .38425 Mdot
.632 .38429 Mdot
.632 .38434 Mdot
.632 .38434 Mdot
.632 .38444 Mdot
.632 .38453 Mdot
.632 .38453 Mdot
.632 .38454 Mdot
.632 .38464 Mdot
.632 .3847 Mdot
.632 .38472 Mdot
.632 .38475 Mdot
.632 .38478 Mdot
.632 .38483 Mdot
.632 .38485 Mdot
.632 .38492 Mdot
.632 .38496 Mdot
.632 .38504 Mdot
.632 .3851 Mdot
.632 .3851 Mdot
.632 .38512 Mdot
.632 .38513 Mdot
.632 .38514 Mdot
.632 .38515 Mdot
.632 .38522 Mdot
.632 .38525 Mdot
.632 .38542 Mdot
.632 .38545 Mdot
.632 .38545 Mdot
.632 .38557 Mdot
.632 .38558 Mdot
.632 .38559 Mdot
.632 .38559 Mdot
.632 .38562 Mdot
.632 .38563 Mdot
.632 .38568 Mdot
.632 .38576 Mdot
.632 .38586 Mdot
.632 .38595 Mdot
.632 .38599 Mdot
.632 .38603 Mdot
.632 .38607 Mdot
.632 .38612 Mdot
.632 .38612 Mdot
.632 .38613 Mdot
.632 .38618 Mdot
.632 .38618 Mdot
.632 .38621 Mdot
.632 .38625 Mdot
.632 .38625 Mdot
.632 .38632 Mdot
.632 .38636 Mdot
.632 .38639 Mdot
.632 .3864 Mdot
.632 .3865 Mdot
.632 .38669 Mdot
.632 .3867 Mdot
.632 .38677 Mdot
.632 .38678 Mdot
.632 .38681 Mdot
.632 .38704 Mdot
.632 .38705 Mdot
.632 .38714 Mdot
.632 .38717 Mdot
.632 .38726 Mdot
.632 .38726 Mdot
.632 .38734 Mdot
.632 .3875 Mdot
.632 .38753 Mdot
.632 .38755 Mdot
.632 .38757 Mdot
.634 .28878 Mdot
.634 .28886 Mdot
.634 .28888 Mdot
.634 .28895 Mdot
.634 .28913 Mdot
.634 .28913 Mdot
.634 .28916 Mdot
.634 .28919 Mdot
.634 .2892 Mdot
.634 .28929 Mdot
.634 .28929 Mdot
.634 .28933 Mdot
.634 .28937 Mdot
.634 .28944 Mdot
.634 .28958 Mdot
.634 .28962 Mdot
.634 .28969 Mdot
.634 .28972 Mdot
.634 .28973 Mdot
.634 .28977 Mdot
.634 .28999 Mdot
.634 .28999 Mdot
.634 .29002 Mdot
.634 .29003 Mdot
.634 .29008 Mdot
.634 .2901 Mdot
.634 .29011 Mdot
.634 .29011 Mdot
.634 .29018 Mdot
.634 .29019 Mdot
.634 .29028 Mdot
.634 .29029 Mdot
.634 .29033 Mdot
.634 .29035 Mdot
.634 .29039 Mdot
.634 .29042 Mdot
.634 .29046 Mdot
.634 .29063 Mdot
.634 .29066 Mdot
.634 .29068 Mdot
.634 .29072 Mdot
.634 .29073 Mdot
.634 .29081 Mdot
.634 .29082 Mdot
.634 .29082 Mdot
.634 .29084 Mdot
.634 .29085 Mdot
.634 .29095 Mdot
.634 .29101 Mdot
.634 .29104 Mdot
.634 .29112 Mdot
.634 .29113 Mdot
.634 .29121 Mdot
.634 .29127 Mdot
.634 .29127 Mdot
.634 .29154 Mdot
.634 .29181 Mdot
.634 .29182 Mdot
.634 .29186 Mdot
.634 .29188 Mdot
.634 .29198 Mdot
.634 .29207 Mdot
.634 .29212 Mdot
.634 .29216 Mdot
.634 .29226 Mdot
.634 .29227 Mdot
.634 .29232 Mdot
.634 .29252 Mdot
.634 .29253 Mdot
.634 .2926 Mdot
.634 .29264 Mdot
.634 .29265 Mdot
.634 .29269 Mdot
.634 .29286 Mdot
.634 .29293 Mdot
.634 .29302 Mdot
.634 .29313 Mdot
.634 .29313 Mdot
.634 .29318 Mdot
.634 .29329 Mdot
.634 .29332 Mdot
.634 .29337 Mdot
.634 .29351 Mdot
.634 .29356 Mdot
.634 .2936 Mdot
.634 .29365 Mdot
.634 .29366 Mdot
.634 .29366 Mdot
.634 .29367 Mdot
.634 .29369 Mdot
.634 .29374 Mdot
.634 .29375 Mdot
.634 .29375 Mdot
.634 .29377 Mdot
.634 .29377 Mdot
.634 .29379 Mdot
.634 .29391 Mdot
.634 .29398 Mdot
.634 .2941 Mdot
.634 .29418 Mdot
.634 .29419 Mdot
.634 .29421 Mdot
.634 .29431 Mdot
.634 .29433 Mdot
.634 .29436 Mdot
.634 .29447 Mdot
.634 .29448 Mdot
.634 .29449 Mdot
.634 .29449 Mdot
.634 .29452 Mdot
.634 .29453 Mdot
.634 .29453 Mdot
.634 .29457 Mdot
.634 .29458 Mdot
.634 .29467 Mdot
.634 .29471 Mdot
.634 .29478 Mdot
.634 .29486 Mdot
.634 .29494 Mdot
.634 .29507 Mdot
.634 .29524 Mdot
.634 .29545 Mdot
.634 .29545 Mdot
.634 .29554 Mdot
.634 .29555 Mdot
.634 .29557 Mdot
.634 .29561 Mdot
.634 .29562 Mdot
.634 .29562 Mdot
.634 .29566 Mdot
.634 .29568 Mdot
.634 .29569 Mdot
.634 .2957 Mdot
.634 .29583 Mdot
.634 .29583 Mdot
.634 .29587 Mdot
.634 .29587 Mdot
.634 .2959 Mdot
.634 .2959 Mdot
.634 .29591 Mdot
.634 .29593 Mdot
.634 .29593 Mdot
.634 .29595 Mdot
.634 .29603 Mdot
.634 .29605 Mdot
.634 .29606 Mdot
.634 .29616 Mdot
.634 .29622 Mdot
.634 .29622 Mdot
.634 .29625 Mdot
.634 .29626 Mdot
.634 .29628 Mdot
.634 .29628 Mdot
.634 .29662 Mdot
.634 .29665 Mdot
.634 .29666 Mdot
.634 .29669 Mdot
.634 .29677 Mdot
.634 .29684 Mdot
.634 .29685 Mdot
.634 .29693 Mdot
.634 .29695 Mdot
.634 .29699 Mdot
.634 .29709 Mdot
.634 .29713 Mdot
.634 .29722 Mdot
.634 .29723 Mdot
.634 .29726 Mdot
.634 .29728 Mdot
.634 .29741 Mdot
.634 .29753 Mdot
.634 .29756 Mdot
.634 .2978 Mdot
.634 .2979 Mdot
.634 .29797 Mdot
.634 .29799 Mdot
.634 .29812 Mdot
.634 .29812 Mdot
.634 .29823 Mdot
.634 .29831 Mdot
.634 .29838 Mdot
.634 .2984 Mdot
.634 .29849 Mdot
.634 .29851 Mdot
.634 .29852 Mdot
.634 .29855 Mdot
.634 .29864 Mdot
.634 .29877 Mdot
.634 .29883 Mdot
.634 .29883 Mdot
.634 .29883 Mdot
.634 .29884 Mdot
.634 .29887 Mdot
.634 .2989 Mdot
.634 .29892 Mdot
.634 .29898 Mdot
.634 .29901 Mdot
.634 .29924 Mdot
.634 .2993 Mdot
.634 .29937 Mdot
.634 .29943 Mdot
.634 .29944 Mdot
.634 .2995 Mdot
.634 .29951 Mdot
.634 .29952 Mdot
.634 .29966 Mdot
.634 .29978 Mdot
.634 .2998 Mdot
.634 .29989 Mdot
.634 .30001 Mdot
.634 .30015 Mdot
.634 .30019 Mdot
.634 .30024 Mdot
.634 .30034 Mdot
.634 .30049 Mdot
.634 .30051 Mdot
.634 .30055 Mdot
.634 .30067 Mdot
.634 .30069 Mdot
.634 .30075 Mdot
.634 .30078 Mdot
.634 .30109 Mdot
.634 .30139 Mdot
.634 .30187 Mdot
.634 .30207 Mdot
.634 .30209 Mdot
.634 .30225 Mdot
.634 .30234 Mdot
.634 .30243 Mdot
.634 .30246 Mdot
.634 .30267 Mdot
.634 .30276 Mdot
.634 .30285 Mdot
.634 .3029 Mdot
.634 .30291 Mdot
.634 .30299 Mdot
.634 .30302 Mdot
.634 .30317 Mdot
.634 .30319 Mdot
.634 .30322 Mdot
.634 .30323 Mdot
.634 .30325 Mdot
.634 .30328 Mdot
.634 .30328 Mdot
.634 .30332 Mdot
.634 .30348 Mdot
.634 .30349 Mdot
.634 .30356 Mdot
.634 .3036 Mdot
.634 .30365 Mdot
.634 .30372 Mdot
.634 .30372 Mdot
.634 .3038 Mdot
.634 .30386 Mdot
.634 .30408 Mdot
.634 .30416 Mdot
.634 .30427 Mdot
.634 .30428 Mdot
.634 .30436 Mdot
.634 .30442 Mdot
.634 .30445 Mdot
.634 .30446 Mdot
.634 .30452 Mdot
.634 .30461 Mdot
.634 .30463 Mdot
.634 .30465 Mdot
.634 .30486 Mdot
.634 .30488 Mdot
.634 .30488 Mdot
.634 .3049 Mdot
.634 .3049 Mdot
.634 .30501 Mdot
.634 .30502 Mdot
.634 .30507 Mdot
.634 .30508 Mdot
.634 .3051 Mdot
.634 .30512 Mdot
.634 .30514 Mdot
.634 .30523 Mdot
.634 .30528 Mdot
.634 .3053 Mdot
.634 .30532 Mdot
.634 .30538 Mdot
.634 .30538 Mdot
.634 .3057 Mdot
.634 .30575 Mdot
.634 .30584 Mdot
.634 .30587 Mdot
.634 .30592 Mdot
.634 .30595 Mdot
.634 .30596 Mdot
.634 .30597 Mdot
.634 .30598 Mdot
.634 .30599 Mdot
.634 .30606 Mdot
.634 .30608 Mdot
.634 .30609 Mdot
.634 .30616 Mdot
.634 .30629 Mdot
.634 .30634 Mdot
.634 .30644 Mdot
.634 .30644 Mdot
.634 .30649 Mdot
.634 .30649 Mdot
.634 .30653 Mdot
.634 .30667 Mdot
.634 .3067 Mdot
.634 .30682 Mdot
.634 .30682 Mdot
.634 .30695 Mdot
.634 .30699 Mdot
.634 .30709 Mdot
.634 .30712 Mdot
.634 .30713 Mdot
.634 .3072 Mdot
.634 .3072 Mdot
.634 .30733 Mdot
.634 .30736 Mdot
.634 .30743 Mdot
.634 .30745 Mdot
.634 .30748 Mdot
.634 .30754 Mdot
.634 .3076 Mdot
.634 .30761 Mdot
.634 .30764 Mdot
.634 .30802 Mdot
.634 .30806 Mdot
.634 .30807 Mdot
.634 .30826 Mdot
.634 .30827 Mdot
.634 .30832 Mdot
.634 .30848 Mdot
.634 .30851 Mdot
.634 .30853 Mdot
.634 .30855 Mdot
.634 .30857 Mdot
.634 .30871 Mdot
.634 .30877 Mdot
.634 .30894 Mdot
.634 .309 Mdot
.634 .30903 Mdot
.634 .30916 Mdot
.634 .30919 Mdot
.634 .30929 Mdot
.634 .30942 Mdot
.634 .30947 Mdot
.634 .30948 Mdot
.634 .30953 Mdot
.634 .31008 Mdot
.634 .31008 Mdot
.634 .31012 Mdot
.634 .31013 Mdot
.634 .31018 Mdot
.634 .31018 Mdot
.634 .31027 Mdot
.634 .31043 Mdot
.634 .31045 Mdot
.634 .31048 Mdot
.634 .31062 Mdot
.634 .31064 Mdot
.634 .31064 Mdot
.634 .31068 Mdot
.634 .31069 Mdot
.634 .31069 Mdot
.634 .31073 Mdot
.634 .31074 Mdot
.634 .3108 Mdot
.634 .3108 Mdot
.634 .31102 Mdot
.634 .31103 Mdot
.634 .31105 Mdot
.634 .31108 Mdot
.634 .31114 Mdot
.634 .31115 Mdot
.634 .31115 Mdot
.634 .31121 Mdot
.634 .31125 Mdot
.634 .31127 Mdot
.634 .31141 Mdot
.634 .31142 Mdot
.634 .31175 Mdot
.634 .31203 Mdot
.634 .31224 Mdot
.634 .31236 Mdot
.634 .3125 Mdot
.634 .3126 Mdot
.634 .31267 Mdot
.634 .31281 Mdot
.634 .31284 Mdot
.634 .31289 Mdot
.634 .3129 Mdot
.634 .31292 Mdot
.634 .31295 Mdot
.634 .31297 Mdot
.634 .31297 Mdot
.634 .31298 Mdot
.634 .31317 Mdot
.634 .31322 Mdot
.634 .31324 Mdot
.634 .31341 Mdot
.634 .31344 Mdot
.634 .31346 Mdot
.634 .31359 Mdot
.634 .31377 Mdot
.634 .31388 Mdot
.634 .31408 Mdot
.634 .31412 Mdot
.634 .31412 Mdot
.634 .31414 Mdot
.634 .31416 Mdot
.634 .31416 Mdot
.634 .31425 Mdot
.634 .31427 Mdot
.634 .31429 Mdot
.634 .3143 Mdot
.634 .31431 Mdot
.634 .31439 Mdot
.634 .31446 Mdot
.634 .31453 Mdot
.634 .31476 Mdot
.634 .31483 Mdot
.634 .31488 Mdot
.634 .31506 Mdot
.634 .31514 Mdot
.634 .31515 Mdot
.634 .31533 Mdot
.634 .31547 Mdot
.634 .31558 Mdot
.634 .31585 Mdot
.634 .31592 Mdot
.634 .31594 Mdot
.634 .31599 Mdot
.634 .31612 Mdot
.634 .31612 Mdot
.634 .31645 Mdot
.634 .31653 Mdot
.634 .31654 Mdot
.634 .3167 Mdot
.634 .31677 Mdot
.634 .31685 Mdot
.634 .31699 Mdot
.634 .31716 Mdot
.634 .31718 Mdot
.634 .31726 Mdot
.634 .31727 Mdot
.634 .31771 Mdot
.634 .31813 Mdot
.634 .31814 Mdot
.634 .31824 Mdot
.634 .31836 Mdot
.634 .31837 Mdot
.634 .31851 Mdot
.634 .31856 Mdot
.634 .31865 Mdot
.634 .31881 Mdot
.634 .31882 Mdot
.634 .31885 Mdot
.634 .31887 Mdot
.634 .31888 Mdot
.634 .319 Mdot
.634 .31901 Mdot
.634 .31908 Mdot
.634 .31911 Mdot
.634 .31916 Mdot
.634 .31943 Mdot
.634 .3195 Mdot
.634 .31955 Mdot
.634 .31961 Mdot
.634 .31965 Mdot
.634 .31971 Mdot
.634 .31972 Mdot
.634 .31987 Mdot
.634 .31989 Mdot
.634 .32 Mdot
.634 .32 Mdot
.634 .32002 Mdot
.634 .32004 Mdot
.634 .32012 Mdot
.634 .32014 Mdot
.634 .32019 Mdot
.634 .32019 Mdot
.634 .32055 Mdot
.634 .32061 Mdot
.634 .32063 Mdot
.634 .32068 Mdot
.634 .32078 Mdot
.634 .32085 Mdot
.634 .32108 Mdot
.634 .32119 Mdot
.634 .32126 Mdot
.634 .32132 Mdot
.634 .32132 Mdot
.634 .32146 Mdot
.634 .32148 Mdot
.634 .32153 Mdot
.634 .32157 Mdot
.634 .32158 Mdot
.634 .32186 Mdot
.634 .32198 Mdot
.634 .32202 Mdot
.634 .32215 Mdot
.634 .36222 Mdot
.634 .36233 Mdot
.634 .36235 Mdot
.634 .36245 Mdot
.634 .36267 Mdot
.634 .36268 Mdot
.634 .36271 Mdot
.634 .36275 Mdot
.634 .36276 Mdot
.634 .36287 Mdot
.634 .36288 Mdot
.634 .36293 Mdot
.634 .36298 Mdot
.634 .36306 Mdot
.634 .36325 Mdot
.634 .3633 Mdot
.634 .36338 Mdot
.634 .36342 Mdot
.634 .36343 Mdot
.634 .36349 Mdot
.634 .36377 Mdot
.634 .36377 Mdot
.634 .36381 Mdot
.634 .36382 Mdot
.634 .36388 Mdot
.634 .3639 Mdot
.634 .36391 Mdot
.634 .36392 Mdot
.634 .364 Mdot
.634 .36402 Mdot
.634 .36414 Mdot
.634 .36415 Mdot
.634 .36419 Mdot
.634 .36423 Mdot
.634 .36427 Mdot
.634 .36431 Mdot
.634 .36436 Mdot
.634 .36458 Mdot
.634 .36462 Mdot
.634 .36464 Mdot
.634 .36469 Mdot
.634 .3647 Mdot
.634 .3648 Mdot
.634 .36481 Mdot
.634 .36482 Mdot
.634 .36484 Mdot
.634 .36485 Mdot
.634 .36498 Mdot
.634 .36505 Mdot
.634 .36509 Mdot
.634 .3652 Mdot
.634 .36521 Mdot
.634 .3653 Mdot
.634 .36538 Mdot
.634 .36539 Mdot
.634 .36573 Mdot
.634 .36607 Mdot
.634 .36608 Mdot
.634 .36614 Mdot
.634 .36616 Mdot
.634 .36629 Mdot
.634 .3664 Mdot
.634 .36646 Mdot
.634 .36652 Mdot
.634 .36665 Mdot
.634 .36665 Mdot
.634 .36672 Mdot
.634 .36697 Mdot
.634 .36698 Mdot
.634 .36708 Mdot
.634 .36712 Mdot
.634 .36713 Mdot
.634 .36719 Mdot
.634 .3674 Mdot
.634 .36749 Mdot
.634 .3676 Mdot
.634 .36774 Mdot
.634 .36775 Mdot
.634 .36781 Mdot
.634 .36795 Mdot
.634 .36799 Mdot
.634 .36805 Mdot
.634 .36823 Mdot
.634 .36829 Mdot
.634 .36834 Mdot
.634 .3684 Mdot
.634 .36841 Mdot
.634 .36842 Mdot
.634 .36843 Mdot
.634 .36845 Mdot
.634 .36852 Mdot
.634 .36853 Mdot
.634 .36854 Mdot
.634 .36855 Mdot
.634 .36856 Mdot
.634 .36859 Mdot
.634 .36874 Mdot
.634 .36883 Mdot
.634 .36897 Mdot
.634 .36907 Mdot
.634 .36909 Mdot
.634 .36911 Mdot
.634 .36925 Mdot
.634 .36926 Mdot
.634 .3693 Mdot
.634 .36945 Mdot
.634 .36946 Mdot
.634 .36946 Mdot
.634 .36947 Mdot
.634 .3695 Mdot
.634 .36952 Mdot
.634 .36952 Mdot
.634 .36957 Mdot
.634 .36959 Mdot
.634 .3697 Mdot
.634 .36975 Mdot
.634 .36983 Mdot
.634 .36994 Mdot
.634 .37004 Mdot
.634 .3702 Mdot
.634 .37043 Mdot
.634 .37069 Mdot
.634 .37069 Mdot
.634 .3708 Mdot
.634 .37082 Mdot
.634 .37085 Mdot
.634 .3709 Mdot
.634 .3709 Mdot
.634 .37091 Mdot
.634 .37095 Mdot
.634 .37098 Mdot
.634 .37099 Mdot
.634 .371 Mdot
.634 .37117 Mdot
.634 .37117 Mdot
.634 .37122 Mdot
.634 .37122 Mdot
.634 .37126 Mdot
.634 .37126 Mdot
.634 .37127 Mdot
.634 .3713 Mdot
.634 .3713 Mdot
.634 .37132 Mdot
.634 .37142 Mdot
.634 .37145 Mdot
.634 .37146 Mdot
.634 .37159 Mdot
.634 .37166 Mdot
.634 .37166 Mdot
.634 .3717 Mdot
.634 .37171 Mdot
.634 .37174 Mdot
.634 .37174 Mdot
.634 .37217 Mdot
.634 .37221 Mdot
.634 .37222 Mdot
.634 .37226 Mdot
.634 .37236 Mdot
.634 .37245 Mdot
.634 .37246 Mdot
.634 .37257 Mdot
.634 .37259 Mdot
.634 .37264 Mdot
.634 .37277 Mdot
.634 .37282 Mdot
.634 .37293 Mdot
.634 .37295 Mdot
.634 .37296 Mdot
.634 .37298 Mdot
.634 .373 Mdot
.634 .37313 Mdot
.634 .37317 Mdot
.634 .37317 Mdot
.634 .37333 Mdot
.634 .37333 Mdot
.634 .37336 Mdot
.634 .37366 Mdot
.634 .37369 Mdot
.634 .37369 Mdot
.634 .37375 Mdot
.634 .37379 Mdot
.634 .37381 Mdot
.634 .37383 Mdot
.634 .37388 Mdot
.634 .37391 Mdot
.634 .37401 Mdot
.634 .37401 Mdot
.634 .37407 Mdot
.634 .37407 Mdot
.634 .37409 Mdot
.634 .37418 Mdot
.634 .37421 Mdot
.634 .37431 Mdot
.634 .37431 Mdot
.634 .3744 Mdot
.634 .37443 Mdot
.634 .37454 Mdot
.634 .37457 Mdot
.634 .37458 Mdot
.634 .37461 Mdot
.634 .37461 Mdot
.634 .37469 Mdot
.634 .37473 Mdot
.634 .37483 Mdot
.634 .37489 Mdot
.634 .3749 Mdot
.634 .37491 Mdot
.634 .37497 Mdot
.634 .37497 Mdot
.634 .37498 Mdot
.634 .37499 Mdot
.634 .37499 Mdot
.634 .37502 Mdot
.634 .37506 Mdot
.634 .37508 Mdot
.634 .37516 Mdot
.634 .37519 Mdot
.634 .37545 Mdot
.634 .37545 Mdot
.634 .37549 Mdot
.634 .37551 Mdot
.634 .37553 Mdot
.634 .37557 Mdot
.634 .37563 Mdot
.634 .37565 Mdot
.634 .37567 Mdot
.634 .37568 Mdot
.634 .37569 Mdot
.634 .37573 Mdot
.634 .37574 Mdot
.634 .37582 Mdot
.634 .37582 Mdot
.634 .37584 Mdot
.634 .37584 Mdot
.634 .37585 Mdot
.634 .37602 Mdot
.634 .37604 Mdot
.634 .37606 Mdot
.634 .37613 Mdot
.634 .37617 Mdot
.634 .37618 Mdot
.634 .3762 Mdot
.634 .37625 Mdot
.634 .37632 Mdot
.634 .37632 Mdot
.634 .37641 Mdot
.634 .37647 Mdot
.634 .37665 Mdot
.634 .37669 Mdot
.634 .37675 Mdot
.634 .37676 Mdot
.634 .37681 Mdot
.634 .37685 Mdot
.634 .37688 Mdot
.634 .37694 Mdot
.634 .37695 Mdot
.634 .37708 Mdot
.634 .3771 Mdot
.634 .37711 Mdot
.634 .37712 Mdot
.634 .37714 Mdot
.634 .37715 Mdot
.634 .37718 Mdot
.634 .37719 Mdot
.634 .37731 Mdot
.634 .37734 Mdot
.634 .3774 Mdot
.634 .3774 Mdot
.634 .37744 Mdot
.634 .37751 Mdot
.634 .37758 Mdot
.634 .37775 Mdot
.634 .37777 Mdot
.634 .37784 Mdot
.634 .37792 Mdot
.634 .37804 Mdot
.634 .37806 Mdot
.634 .37822 Mdot
.634 .3786 Mdot
.634 .37883 Mdot
.634 .37908 Mdot
.634 .3791 Mdot
.634 .37914 Mdot
.634 .37916 Mdot
.634 .37926 Mdot
.634 .37929 Mdot
.634 .3793 Mdot
.634 .37942 Mdot
.634 .3795 Mdot
.634 .37954 Mdot
.634 .37957 Mdot
.634 .37968 Mdot
.634 .37978 Mdot
.634 .37985 Mdot
.634 .37986 Mdot
.634 .37996 Mdot
.634 .38007 Mdot
.634 .38007 Mdot
.634 .38008 Mdot
.634 .38013 Mdot
.634 .38014 Mdot
.634 .38019 Mdot
.634 .38024 Mdot
.634 .38029 Mdot
.634 .38047 Mdot
.634 .3805 Mdot
.634 .38054 Mdot
.634 .38056 Mdot
.634 .38058 Mdot
.634 .3806 Mdot
.634 .38061 Mdot
.634 .38061 Mdot
.634 .38062 Mdot
.634 .38066 Mdot
.634 .38077 Mdot
.634 .38084 Mdot
.634 .38086 Mdot
.634 .38086 Mdot
.634 .38088 Mdot
.634 .38095 Mdot
.634 .38097 Mdot
.634 .38103 Mdot
.634 .38109 Mdot
.634 .38117 Mdot
.634 .38118 Mdot
.634 .38127 Mdot
.634 .38129 Mdot
.634 .38135 Mdot
.634 .38143 Mdot
.634 .38161 Mdot
.634 .38163 Mdot
.634 .38173 Mdot
.634 .38184 Mdot
.634 .38185 Mdot
.634 .38187 Mdot
.634 .38188 Mdot
.634 .38195 Mdot
.634 .38198 Mdot
.634 .38206 Mdot
.634 .38209 Mdot
.634 .38211 Mdot
.634 .38217 Mdot
.634 .38218 Mdot
.634 .38224 Mdot
.634 .3823 Mdot
.634 .38232 Mdot
.634 .38233 Mdot
.634 .38235 Mdot
.634 .38262 Mdot
.634 .38263 Mdot
.634 .38264 Mdot
.634 .38265 Mdot
.634 .38267 Mdot
.634 .38267 Mdot
.634 .38272 Mdot
.634 .38279 Mdot
.634 .3828 Mdot
.634 .38282 Mdot
.634 .38289 Mdot
.634 .3829 Mdot
.634 .3829 Mdot
.634 .38292 Mdot
.634 .38292 Mdot
.634 .38292 Mdot
.634 .38294 Mdot
.634 .38295 Mdot
.634 .38298 Mdot
.634 .38298 Mdot
.634 .38308 Mdot
.634 .38309 Mdot
.634 .3831 Mdot
.634 .38311 Mdot
.634 .38314 Mdot
.634 .38315 Mdot
.634 .38315 Mdot
.634 .38318 Mdot
.634 .3832 Mdot
.634 .38321 Mdot
.634 .38328 Mdot
.634 .38328 Mdot
.634 .38344 Mdot
.634 .38358 Mdot
.634 .38368 Mdot
.634 .38374 Mdot
.634 .38381 Mdot
.634 .38386 Mdot
.634 .38389 Mdot
.634 .38396 Mdot
.634 .38398 Mdot
.634 .384 Mdot
.634 .384 Mdot
.634 .38401 Mdot
.634 .38403 Mdot
.634 .38404 Mdot
.634 .38404 Mdot
.634 .38405 Mdot
.634 .38414 Mdot
.634 .38416 Mdot
.634 .38417 Mdot
.634 .38426 Mdot
.634 .38427 Mdot
.634 .38428 Mdot
.634 .38435 Mdot
.634 .38443 Mdot
.634 .38449 Mdot
.634 .38458 Mdot
.634 .3846 Mdot
.634 .38461 Mdot
.634 .38462 Mdot
.634 .38462 Mdot
.634 .38462 Mdot
.634 .38467 Mdot
.634 .38468 Mdot
.634 .38469 Mdot
.634 .38469 Mdot
.634 .3847 Mdot
.634 .38474 Mdot
.634 .38477 Mdot
.634 .3848 Mdot
.634 .38492 Mdot
.634 .38495 Mdot
.634 .38498 Mdot
.634 .38507 Mdot
.634 .3851 Mdot
.634 .38511 Mdot
.634 .3852 Mdot
.634 .38527 Mdot
.634 .38532 Mdot
.634 .38545 Mdot
.634 .38549 Mdot
.634 .3855 Mdot
.634 .38552 Mdot
.634 .38558 Mdot
.634 .38559 Mdot
.634 .38575 Mdot
.634 .38579 Mdot
.634 .38579 Mdot
.634 .38587 Mdot
.634 .38591 Mdot
.634 .38594 Mdot
.634 .38601 Mdot
.634 .3861 Mdot
.634 .38611 Mdot
.634 .38614 Mdot
.634 .38615 Mdot
.634 .38657 Mdot
.634 .38658 Mdot
.634 .38663 Mdot
.634 .38668 Mdot
.634 .38669 Mdot
.634 .38676 Mdot
.634 .38678 Mdot
.634 .38683 Mdot
.634 .38691 Mdot
.634 .38691 Mdot
.634 .38693 Mdot
.634 .38693 Mdot
.634 .38694 Mdot
.634 .387 Mdot
.634 .38701 Mdot
.634 .38704 Mdot
.634 .38705 Mdot
.634 .38708 Mdot
.634 .38721 Mdot
.634 .38724 Mdot
.634 .38727 Mdot
.634 .3873 Mdot
.634 .38732 Mdot
.634 .38735 Mdot
.634 .38735 Mdot
.634 .38742 Mdot
.634 .38744 Mdot
.634 .38749 Mdot
.634 .38749 Mdot
.634 .3875 Mdot
.634 .38751 Mdot
.634 .38755 Mdot
.634 .38756 Mdot
.634 .38758 Mdot
.634 .38758 Mdot
.634 .38776 Mdot
.634 .38779 Mdot
.634 .3878 Mdot
.634 .38782 Mdot
.634 .38787 Mdot
.634 .38791 Mdot
.634 .38802 Mdot
.634 .38807 Mdot
.634 .3881 Mdot
.634 .38814 Mdot
.634 .38814 Mdot
.634 .38821 Mdot
.634 .38821 Mdot
.634 .38824 Mdot
.634 .38826 Mdot
.634 .38826 Mdot
.634 .3884 Mdot
.634 .38846 Mdot
.634 .38848 Mdot
.634 .38854 Mdot
.636 .28789 Mdot
.636 .28792 Mdot
.636 .28795 Mdot
.636 .28796 Mdot
.636 .28797 Mdot
.636 .28808 Mdot
.636 .28813 Mdot
.636 .2882 Mdot
.636 .28825 Mdot
.636 .28828 Mdot
.636 .2883 Mdot
.636 .28838 Mdot
.636 .28844 Mdot
.636 .28848 Mdot
.636 .28853 Mdot
.636 .28864 Mdot
.636 .28869 Mdot
.636 .28875 Mdot
.636 .28877 Mdot
.636 .2889 Mdot
.636 .28895 Mdot
.636 .28898 Mdot
.636 .28909 Mdot
.636 .28909 Mdot
.636 .28911 Mdot
.636 .28912 Mdot
.636 .28926 Mdot
.636 .28926 Mdot
.636 .28927 Mdot
.636 .28932 Mdot
.636 .2894 Mdot
.636 .28941 Mdot
.636 .28947 Mdot
.636 .28951 Mdot
.636 .28962 Mdot
.636 .28962 Mdot
.636 .28969 Mdot
.636 .28975 Mdot
.636 .28982 Mdot
.636 .28997 Mdot
.636 .29005 Mdot
.636 .29009 Mdot
.636 .29016 Mdot
.636 .2902 Mdot
.636 .29023 Mdot
.636 .29027 Mdot
.636 .29028 Mdot
.636 .29029 Mdot
.636 .29043 Mdot
.636 .29045 Mdot
.636 .29045 Mdot
.636 .29053 Mdot
.636 .29057 Mdot
.636 .29062 Mdot
.636 .29062 Mdot
.636 .29066 Mdot
.636 .29068 Mdot
.636 .29085 Mdot
.636 .29105 Mdot
.636 .29111 Mdot
.636 .29131 Mdot
.636 .29134 Mdot
.636 .29141 Mdot
.636 .29157 Mdot
.636 .29158 Mdot
.636 .29159 Mdot
.636 .29166 Mdot
.636 .29174 Mdot
.636 .29174 Mdot
.636 .29181 Mdot
.636 .29183 Mdot
.636 .29184 Mdot
.636 .29189 Mdot
.636 .29194 Mdot
.636 .292 Mdot
.636 .29202 Mdot
.636 .29203 Mdot
.636 .29205 Mdot
.636 .29206 Mdot
.636 .29219 Mdot
.636 .29221 Mdot
.636 .29224 Mdot
.636 .29242 Mdot
.636 .29243 Mdot
.636 .29256 Mdot
.636 .29262 Mdot
.636 .29265 Mdot
.636 .2927 Mdot
.636 .29274 Mdot
.636 .29275 Mdot
.636 .29284 Mdot
.636 .29294 Mdot
.636 .29301 Mdot
.636 .29303 Mdot
.636 .2931 Mdot
.636 .29314 Mdot
.636 .29318 Mdot
.636 .29324 Mdot
.636 .29343 Mdot
.636 .29359 Mdot
.636 .2936 Mdot
.636 .29374 Mdot
.636 .29376 Mdot
.636 .2938 Mdot
.636 .29402 Mdot
.636 .29418 Mdot
.636 .29427 Mdot
.636 .29434 Mdot
.636 .29436 Mdot
.636 .29439 Mdot
.636 .29447 Mdot
.636 .29456 Mdot
.636 .29461 Mdot
.636 .29463 Mdot
.636 .29467 Mdot
.636 .29469 Mdot
.636 .2947 Mdot
.636 .29473 Mdot
.636 .29479 Mdot
.636 .29479 Mdot
.636 .29489 Mdot
.636 .29507 Mdot
.636 .29516 Mdot
.636 .29518 Mdot
.636 .29529 Mdot
.636 .29529 Mdot
.636 .29531 Mdot
.636 .29532 Mdot
.636 .29554 Mdot
.636 .29558 Mdot
.636 .29562 Mdot
.636 .29565 Mdot
.636 .2958 Mdot
.636 .29581 Mdot
.636 .2959 Mdot
.636 .29596 Mdot
.636 .29599 Mdot
.636 .29601 Mdot
.636 .29604 Mdot
.636 .29611 Mdot
.636 .29617 Mdot
.636 .29619 Mdot
.636 .2962 Mdot
.636 .29624 Mdot
.636 .29644 Mdot
.636 .2965 Mdot
.636 .29654 Mdot
.636 .29667 Mdot
.636 .29668 Mdot
.636 .29668 Mdot
.636 .29674 Mdot
.636 .29674 Mdot
.636 .2968 Mdot
.636 .29692 Mdot
.636 .29695 Mdot
.636 .29701 Mdot
.636 .29706 Mdot
.636 .29708 Mdot
.636 .29719 Mdot
.636 .29719 Mdot
.636 .29722 Mdot
.636 .29726 Mdot
.636 .29727 Mdot
.636 .29742 Mdot
.636 .29756 Mdot
.636 .29769 Mdot
.636 .29772 Mdot
.636 .29776 Mdot
.636 .29779 Mdot
.636 .2978 Mdot
.636 .29781 Mdot
.636 .29787 Mdot
.636 .29803 Mdot
.636 .29807 Mdot
.636 .29811 Mdot
.636 .29826 Mdot
.636 .29833 Mdot
.636 .29839 Mdot
.636 .29873 Mdot
.636 .29873 Mdot
.636 .29876 Mdot
.636 .29878 Mdot
.636 .29881 Mdot
.636 .29881 Mdot
.636 .29885 Mdot
.636 .29889 Mdot
.636 .29896 Mdot
.636 .299 Mdot
.636 .29905 Mdot
.636 .29905 Mdot
.636 .29914 Mdot
.636 .29917 Mdot
.636 .2993 Mdot
.636 .29931 Mdot
.636 .29933 Mdot
.636 .29938 Mdot
.636 .29939 Mdot
.636 .2995 Mdot
.636 .29952 Mdot
.636 .29957 Mdot
.636 .29957 Mdot
.636 .29959 Mdot
.636 .29962 Mdot
.636 .2997 Mdot
.636 .29977 Mdot
.636 .29978 Mdot
.636 .29996 Mdot
.636 .3 Mdot
.636 .3 Mdot
.636 .30044 Mdot
.636 .30046 Mdot
.636 .30048 Mdot
.636 .30061 Mdot
.636 .30069 Mdot
.636 .30069 Mdot
.636 .30102 Mdot
.636 .3011 Mdot
.636 .30123 Mdot
.636 .30126 Mdot
.636 .30132 Mdot
.636 .30135 Mdot
.636 .30137 Mdot
.636 .30138 Mdot
.636 .30142 Mdot
.636 .30152 Mdot
.636 .30157 Mdot
.636 .30178 Mdot
.636 .30191 Mdot
.636 .30192 Mdot
.636 .30234 Mdot
.636 .30239 Mdot
.636 .30244 Mdot
.636 .30245 Mdot
.636 .3025 Mdot
.636 .30251 Mdot
.636 .30258 Mdot
.636 .30263 Mdot
.636 .30273 Mdot
.636 .30279 Mdot
.636 .30282 Mdot
.636 .30284 Mdot
.636 .30294 Mdot
.636 .30295 Mdot
.636 .30299 Mdot
.636 .30337 Mdot
.636 .3034 Mdot
.636 .30342 Mdot
.636 .30352 Mdot
.636 .30356 Mdot
.636 .30356 Mdot
.636 .30361 Mdot
.636 .30363 Mdot
.636 .30371 Mdot
.636 .30389 Mdot
.636 .30392 Mdot
.636 .30394 Mdot
.636 .304 Mdot
.636 .30405 Mdot
.636 .30418 Mdot
.636 .30421 Mdot
.636 .30422 Mdot
.636 .30425 Mdot
.636 .30426 Mdot
.636 .30434 Mdot
.636 .30436 Mdot
.636 .30455 Mdot
.636 .30457 Mdot
.636 .30461 Mdot
.636 .30465 Mdot
.636 .30468 Mdot
.636 .3047 Mdot
.636 .30479 Mdot
.636 .30491 Mdot
.636 .30493 Mdot
.636 .30496 Mdot
.636 .30509 Mdot
.636 .3051 Mdot
.636 .30511 Mdot
.636 .30511 Mdot
.636 .30518 Mdot
.636 .30525 Mdot
.636 .30536 Mdot
.636 .30542 Mdot
.636 .30542 Mdot
.636 .30548 Mdot
.636 .30549 Mdot
.636 .30552 Mdot
.636 .30553 Mdot
.636 .30556 Mdot
.636 .30561 Mdot
.636 .30562 Mdot
.636 .30567 Mdot
.636 .30568 Mdot
.636 .3059 Mdot
.636 .30603 Mdot
.636 .30606 Mdot
.636 .30607 Mdot
.636 .30616 Mdot
.636 .30626 Mdot
.636 .30638 Mdot
.636 .30644 Mdot
.636 .30647 Mdot
.636 .30651 Mdot
.636 .30652 Mdot
.636 .30662 Mdot
.636 .30669 Mdot
.636 .30674 Mdot
.636 .3068 Mdot
.636 .30689 Mdot
.636 .307 Mdot
.636 .30701 Mdot
.636 .30711 Mdot
.636 .30713 Mdot
.636 .30714 Mdot
.636 .30718 Mdot
.636 .30725 Mdot
.636 .30731 Mdot
.636 .30736 Mdot
.636 .30741 Mdot
.636 .30751 Mdot
.636 .30755 Mdot
.636 .3077 Mdot
.636 .30773 Mdot
.636 .30796 Mdot
.636 .30797 Mdot
.636 .308 Mdot
.636 .30805 Mdot
.636 .3081 Mdot
.636 .30811 Mdot
.636 .30811 Mdot
.636 .30821 Mdot
.636 .30828 Mdot
.636 .30833 Mdot
.636 .30835 Mdot
.636 .3084 Mdot
.636 .3085 Mdot
.636 .30854 Mdot
.636 .30857 Mdot
.636 .30861 Mdot
.636 .30871 Mdot
.636 .30875 Mdot
.636 .30883 Mdot
.636 .30884 Mdot
.636 .30884 Mdot
.636 .30893 Mdot
.636 .30893 Mdot
.636 .30894 Mdot
.636 .30901 Mdot
.636 .30914 Mdot
.636 .30916 Mdot
.636 .30923 Mdot
.636 .30932 Mdot
.636 .30944 Mdot
.636 .30946 Mdot
.636 .30949 Mdot
.636 .30957 Mdot
.636 .30964 Mdot
.636 .30965 Mdot
.636 .30971 Mdot
.636 .30973 Mdot
.636 .30975 Mdot
.636 .30986 Mdot
.636 .30996 Mdot
.636 .31001 Mdot
.636 .31005 Mdot
.636 .31011 Mdot
.636 .3102 Mdot
.636 .31033 Mdot
.636 .31036 Mdot
.636 .31059 Mdot
.636 .31064 Mdot
.636 .31071 Mdot
.636 .31078 Mdot
.636 .31113 Mdot
.636 .31115 Mdot
.636 .31118 Mdot
.636 .31119 Mdot
.636 .31136 Mdot
.636 .3114 Mdot
.636 .31154 Mdot
.636 .31182 Mdot
.636 .31199 Mdot
.636 .312 Mdot
.636 .31209 Mdot
.636 .31213 Mdot
.636 .31215 Mdot
.636 .31218 Mdot
.636 .31225 Mdot
.636 .31228 Mdot
.636 .31236 Mdot
.636 .31251 Mdot
.636 .31263 Mdot
.636 .31268 Mdot
.636 .31271 Mdot
.636 .31283 Mdot
.636 .31298 Mdot
.636 .31324 Mdot
.636 .3136 Mdot
.636 .31365 Mdot
.636 .3137 Mdot
.636 .31392 Mdot
.636 .31394 Mdot
.636 .3142 Mdot
.636 .31451 Mdot
.636 .3146 Mdot
.636 .31466 Mdot
.636 .31473 Mdot
.636 .31484 Mdot
.636 .31487 Mdot
.636 .31499 Mdot
.636 .31514 Mdot
.636 .31529 Mdot
.636 .31531 Mdot
.636 .31537 Mdot
.636 .31545 Mdot
.636 .3155 Mdot
.636 .3156 Mdot
.636 .31581 Mdot
.636 .31583 Mdot
.636 .31611 Mdot
.636 .31616 Mdot
.636 .3162 Mdot
.636 .31641 Mdot
.636 .31643 Mdot
.636 .31646 Mdot
.636 .31648 Mdot
.636 .31651 Mdot
.636 .31661 Mdot
.636 .31668 Mdot
.636 .31676 Mdot
.636 .31678 Mdot
.636 .31681 Mdot
.636 .31693 Mdot
.636 .31693 Mdot
.636 .31706 Mdot
.636 .31716 Mdot
.636 .31719 Mdot
.636 .31719 Mdot
.636 .31747 Mdot
.636 .31757 Mdot
.636 .31762 Mdot
.636 .31795 Mdot
.636 .31804 Mdot
.636 .31837 Mdot
.636 .31864 Mdot
.636 .31867 Mdot
.636 .31874 Mdot
.636 .31874 Mdot
.636 .31882 Mdot
.636 .31888 Mdot
.636 .31901 Mdot
.636 .31902 Mdot
.636 .31904 Mdot
.636 .31928 Mdot
.636 .31929 Mdot
.636 .3193 Mdot
.636 .31937 Mdot
.636 .31942 Mdot
.636 .31949 Mdot
.636 .31959 Mdot
.636 .31967 Mdot
.636 .3198 Mdot
.636 .32004 Mdot
.636 .32015 Mdot
.636 .32024 Mdot
.636 .32035 Mdot
.636 .32035 Mdot
.636 .32054 Mdot
.636 .3206 Mdot
.636 .32069 Mdot
.636 .32071 Mdot
.636 .32084 Mdot
.636 .32092 Mdot
.636 .32093 Mdot
.636 .32095 Mdot
.636 .32117 Mdot
.636 .32119 Mdot
.636 .32121 Mdot
.636 .32122 Mdot
.636 .32139 Mdot
.636 .32145 Mdot
.636 .32152 Mdot
.636 .32174 Mdot
.636 .32177 Mdot
.636 .32186 Mdot
.636 .32195 Mdot
.636 .32211 Mdot
.636 .3222 Mdot
.636 .32227 Mdot
.636 .32235 Mdot
.636 .32249 Mdot
.636 .32252 Mdot
.636 .32258 Mdot
.636 .32265 Mdot
.636 .32276 Mdot
.636 .32284 Mdot
.636 .32303 Mdot
.636 .32304 Mdot
.636 .32306 Mdot
.636 .3231 Mdot
.636 .32315 Mdot
.636 .3622 Mdot
.636 .36223 Mdot
.636 .36227 Mdot
.636 .36228 Mdot
.636 .36229 Mdot
.636 .36244 Mdot
.636 .3625 Mdot
.636 .36259 Mdot
.636 .36265 Mdot
.636 .3627 Mdot
.636 .36272 Mdot
.636 .36282 Mdot
.636 .36289 Mdot
.636 .36295 Mdot
.636 .36301 Mdot
.636 .36314 Mdot
.636 .36321 Mdot
.636 .36328 Mdot
.636 .36331 Mdot
.636 .36348 Mdot
.636 .36354 Mdot
.636 .36358 Mdot
.636 .36371 Mdot
.636 .36372 Mdot
.636 .36374 Mdot
.636 .36375 Mdot
.636 .36393 Mdot
.636 .36394 Mdot
.636 .36395 Mdot
.636 .36402 Mdot
.636 .36412 Mdot
.636 .36413 Mdot
.636 .3642 Mdot
.636 .36425 Mdot
.636 .3644 Mdot
.636 .3644 Mdot
.636 .36449 Mdot
.636 .36456 Mdot
.636 .36464 Mdot
.636 .36483 Mdot
.636 .36494 Mdot
.636 .36499 Mdot
.636 .36508 Mdot
.636 .36513 Mdot
.636 .36517 Mdot
.636 .36522 Mdot
.636 .36523 Mdot
.636 .36524 Mdot
.636 .36543 Mdot
.636 .36545 Mdot
.636 .36545 Mdot
.636 .36555 Mdot
.636 .3656 Mdot
.636 .36566 Mdot
.636 .36567 Mdot
.636 .36572 Mdot
.636 .36574 Mdot
.636 .36596 Mdot
.636 .36622 Mdot
.636 .36628 Mdot
.636 .36654 Mdot
.636 .36659 Mdot
.636 .36667 Mdot
.636 .36688 Mdot
.636 .36688 Mdot
.636 .3669 Mdot
.636 .36699 Mdot
.636 .36709 Mdot
.636 .36709 Mdot
.636 .36718 Mdot
.636 .36721 Mdot
.636 .36722 Mdot
.636 .36729 Mdot
.636 .36734 Mdot
.636 .36742 Mdot
.636 .36744 Mdot
.636 .36746 Mdot
.636 .36748 Mdot
.636 .3675 Mdot
.636 .36766 Mdot
.636 .36769 Mdot
.636 .36773 Mdot
.636 .36796 Mdot
.636 .36797 Mdot
.636 .36813 Mdot
.636 .36821 Mdot
.636 .36825 Mdot
.636 .36831 Mdot
.636 .36836 Mdot
.636 .36838 Mdot
.636 .36849 Mdot
.636 .36861 Mdot
.636 .36871 Mdot
.636 .36873 Mdot
.636 .36882 Mdot
.636 .36888 Mdot
.636 .36892 Mdot
.636 .36899 Mdot
.636 .36923 Mdot
.636 .36944 Mdot
.636 .36946 Mdot
.636 .36963 Mdot
.636 .36966 Mdot
.636 .36971 Mdot
.636 .36999 Mdot
.636 .3702 Mdot
.636 .37031 Mdot
.636 .3704 Mdot
.636 .37043 Mdot
.636 .37047 Mdot
.636 .37056 Mdot
.636 .37068 Mdot
.636 .37075 Mdot
.636 .37077 Mdot
.636 .37082 Mdot
.636 .37084 Mdot
.636 .37086 Mdot
.636 .3709 Mdot
.636 .37097 Mdot
.636 .37097 Mdot
.636 .3711 Mdot
.636 .37133 Mdot
.636 .37144 Mdot
.636 .37146 Mdot
.636 .3716 Mdot
.636 .37161 Mdot
.636 .37163 Mdot
.636 .37164 Mdot
.636 .37192 Mdot
.636 .37198 Mdot
.636 .37203 Mdot
.636 .37207 Mdot
.636 .37225 Mdot
.636 .37227 Mdot
.636 .37238 Mdot
.636 .37245 Mdot
.636 .3725 Mdot
.636 .37253 Mdot
.636 .37257 Mdot
.636 .37265 Mdot
.636 .37273 Mdot
.636 .37275 Mdot
.636 .37276 Mdot
.636 .37281 Mdot
.636 .37282 Mdot
.636 .37288 Mdot
.636 .37293 Mdot
.636 .37296 Mdot
.636 .37297 Mdot
.636 .37307 Mdot
.636 .37314 Mdot
.636 .3732 Mdot
.636 .37321 Mdot
.636 .37331 Mdot
.636 .37337 Mdot
.636 .37337 Mdot
.636 .37338 Mdot
.636 .37345 Mdot
.636 .37345 Mdot
.636 .37345 Mdot
.636 .37352 Mdot
.636 .37355 Mdot
.636 .37362 Mdot
.636 .37366 Mdot
.636 .37368 Mdot
.636 .37372 Mdot
.636 .37379 Mdot
.636 .37383 Mdot
.636 .37385 Mdot
.636 .37388 Mdot
.636 .37394 Mdot
.636 .37402 Mdot
.636 .37403 Mdot
.636 .37403 Mdot
.636 .37407 Mdot
.636 .37411 Mdot
.636 .37413 Mdot
.636 .37414 Mdot
.636 .37432 Mdot
.636 .37435 Mdot
.636 .37446 Mdot
.636 .37449 Mdot
.636 .37457 Mdot
.636 .37461 Mdot
.636 .37465 Mdot
.636 .3747 Mdot
.636 .37475 Mdot
.636 .37479 Mdot
.636 .37479 Mdot
.636 .37481 Mdot
.636 .37488 Mdot
.636 .3749 Mdot
.636 .37498 Mdot
.636 .37505 Mdot
.636 .3751 Mdot
.636 .37514 Mdot
.636 .37519 Mdot
.636 .37527 Mdot
.636 .37528 Mdot
.636 .37531 Mdot
.636 .37534 Mdot
.636 .37538 Mdot
.636 .37547 Mdot
.636 .37555 Mdot
.636 .37562 Mdot
.636 .37564 Mdot
.636 .37565 Mdot
.636 .37576 Mdot
.636 .37593 Mdot
.636 .37594 Mdot
.636 .37598 Mdot
.636 .37599 Mdot
.636 .37602 Mdot
.636 .37605 Mdot
.636 .37606 Mdot
.636 .37608 Mdot
.636 .37609 Mdot
.636 .37613 Mdot
.636 .37614 Mdot
.636 .37619 Mdot
.636 .37627 Mdot
.636 .37632 Mdot
.636 .37638 Mdot
.636 .37638 Mdot
.636 .37639 Mdot
.636 .37639 Mdot
.636 .3765 Mdot
.636 .37652 Mdot
.636 .37654 Mdot
.636 .37663 Mdot
.636 .3767 Mdot
.636 .37672 Mdot
.636 .37674 Mdot
.636 .37678 Mdot
.636 .37681 Mdot
.636 .37682 Mdot
.636 .37697 Mdot
.636 .37699 Mdot
.636 .37705 Mdot
.636 .37705 Mdot
.636 .37708 Mdot
.636 .37708 Mdot
.636 .37711 Mdot
.636 .37721 Mdot
.636 .37725 Mdot
.636 .3773 Mdot
.636 .37732 Mdot
.636 .37734 Mdot
.636 .37748 Mdot
.636 .37754 Mdot
.636 .37756 Mdot
.636 .3776 Mdot
.636 .3776 Mdot
.636 .37763 Mdot
.636 .37771 Mdot
.636 .37773 Mdot
.636 .37775 Mdot
.636 .37805 Mdot
.636 .37808 Mdot
.636 .37809 Mdot
.636 .37816 Mdot
.636 .37818 Mdot
.636 .3782 Mdot
.636 .37825 Mdot
.636 .37833 Mdot
.636 .37837 Mdot
.636 .37843 Mdot
.636 .37843 Mdot
.636 .37847 Mdot
.636 .37848 Mdot
.636 .37852 Mdot
.636 .37855 Mdot
.636 .37889 Mdot
.636 .3789 Mdot
.636 .379 Mdot
.636 .37916 Mdot
.636 .3792 Mdot
.636 .37928 Mdot
.636 .37931 Mdot
.636 .37932 Mdot
.636 .37934 Mdot
.636 .37936 Mdot
.636 .37941 Mdot
.636 .37943 Mdot
.636 .37953 Mdot
.636 .3796 Mdot
.636 .37985 Mdot
.636 .37986 Mdot
.636 .37992 Mdot
.636 .38002 Mdot
.636 .38004 Mdot
.636 .38005 Mdot
.636 .38039 Mdot
.636 .3804 Mdot
.636 .38043 Mdot
.636 .38057 Mdot
.636 .38058 Mdot
.636 .38063 Mdot
.636 .3807 Mdot
.636 .38072 Mdot
.636 .38073 Mdot
.636 .38074 Mdot
.636 .38077 Mdot
.636 .38079 Mdot
.636 .38088 Mdot
.636 .38089 Mdot
.636 .38092 Mdot
.636 .38094 Mdot
.636 .38095 Mdot
.636 .38105 Mdot
.636 .38108 Mdot
.636 .38114 Mdot
.636 .38115 Mdot
.636 .38118 Mdot
.636 .38122 Mdot
.636 .38127 Mdot
.636 .3813 Mdot
.636 .38133 Mdot
.636 .38134 Mdot
.636 .38135 Mdot
.636 .38137 Mdot
.636 .38139 Mdot
.636 .3814 Mdot
.636 .38166 Mdot
.636 .38171 Mdot
.636 .38177 Mdot
.636 .38189 Mdot
.636 .38192 Mdot
.636 .38194 Mdot
.636 .38207 Mdot
.636 .38212 Mdot
.636 .38213 Mdot
.636 .38213 Mdot
.636 .38216 Mdot
.636 .38219 Mdot
.636 .38222 Mdot
.636 .38232 Mdot
.636 .38242 Mdot
.636 .38254 Mdot
.636 .38255 Mdot
.636 .38258 Mdot
.636 .3826 Mdot
.636 .38261 Mdot
.636 .38269 Mdot
.636 .38271 Mdot
.636 .38275 Mdot
.636 .38279 Mdot
.636 .38282 Mdot
.636 .38292 Mdot
.636 .38296 Mdot
.636 .38296 Mdot
.636 .383 Mdot
.636 .38301 Mdot
.636 .38301 Mdot
.636 .38312 Mdot
.636 .38315 Mdot
.636 .3832 Mdot
.636 .38336 Mdot
.636 .38338 Mdot
.636 .38339 Mdot
.636 .3834 Mdot
.636 .38346 Mdot
.636 .38351 Mdot
.636 .38353 Mdot
.636 .38355 Mdot
.636 .38358 Mdot
.636 .38362 Mdot
.636 .38369 Mdot
.636 .3837 Mdot
.636 .38381 Mdot
.636 .38384 Mdot
.636 .38387 Mdot
.636 .3839 Mdot
.636 .38408 Mdot
.636 .38409 Mdot
.636 .3841 Mdot
.636 .3841 Mdot
.636 .38419 Mdot
.636 .3842 Mdot
.636 .38427 Mdot
.636 .38441 Mdot
.636 .38449 Mdot
.636 .3845 Mdot
.636 .38454 Mdot
.636 .38456 Mdot
.636 .38457 Mdot
.636 .38459 Mdot
.636 .38462 Mdot
.636 .38463 Mdot
.636 .38467 Mdot
.636 .38475 Mdot
.636 .3848 Mdot
.636 .38483 Mdot
.636 .38484 Mdot
.636 .3849 Mdot
.636 .38497 Mdot
.636 .3851 Mdot
.636 .38527 Mdot
.636 .3853 Mdot
.636 .38532 Mdot
.636 .38543 Mdot
.636 .38544 Mdot
.636 .38557 Mdot
.636 .38572 Mdot
.636 .38576 Mdot
.636 .38579 Mdot
.636 .38582 Mdot
.636 .38588 Mdot
.636 .38589 Mdot
.636 .38595 Mdot
.636 .38602 Mdot
.636 .3861 Mdot
.636 .3861 Mdot
.636 .38614 Mdot
.636 .38618 Mdot
.636 .3862 Mdot
.636 .38625 Mdot
.636 .38635 Mdot
.636 .38636 Mdot
.636 .3865 Mdot
.636 .38652 Mdot
.636 .38654 Mdot
.636 .38664 Mdot
.636 .38665 Mdot
.636 .38666 Mdot
.636 .38667 Mdot
.636 .38669 Mdot
.636 .38674 Mdot
.636 .38677 Mdot
.636 .38681 Mdot
.636 .38682 Mdot
.636 .38683 Mdot
.636 .38689 Mdot
.636 .38689 Mdot
.636 .38695 Mdot
.636 .38701 Mdot
.636 .38702 Mdot
.636 .38702 Mdot
.636 .38715 Mdot
.636 .3872 Mdot
.636 .38723 Mdot
.636 .38739 Mdot
.636 .38743 Mdot
.636 .38759 Mdot
.636 .38772 Mdot
.636 .38774 Mdot
.636 .38777 Mdot
.636 .38777 Mdot
.636 .38781 Mdot
.636 .38784 Mdot
.636 .3879 Mdot
.636 .38791 Mdot
.636 .38792 Mdot
.636 .38803 Mdot
.636 .38804 Mdot
.636 .38805 Mdot
.636 .38808 Mdot
.636 .3881 Mdot
.636 .38813 Mdot
.636 .38819 Mdot
.636 .38822 Mdot
.636 .38829 Mdot
.636 .3884 Mdot
.636 .38846 Mdot
.636 .3885 Mdot
.636 .38856 Mdot
.636 .38856 Mdot
.636 .38865 Mdot
.636 .38868 Mdot
.636 .38872 Mdot
.636 .38873 Mdot
.636 .38879 Mdot
.636 .38883 Mdot
.636 .38884 Mdot
.636 .38884 Mdot
.636 .38895 Mdot
.636 .38896 Mdot
.636 .38897 Mdot
.636 .38906 Mdot
.636 .38909 Mdot
.636 .38912 Mdot
.636 .38923 Mdot
.636 .38925 Mdot
.636 .38929 Mdot
.636 .38933 Mdot
.636 .38941 Mdot
.636 .38945 Mdot
.636 .38949 Mdot
.636 .38953 Mdot
.636 .38959 Mdot
.636 .38961 Mdot
.636 .38964 Mdot
.636 .38967 Mdot
.636 .38973 Mdot
.636 .38977 Mdot
.636 .38986 Mdot
.636 .38986 Mdot
.636 .38987 Mdot
.636 .38989 Mdot
.636 .38991 Mdot
.638 .28729 Mdot
.638 .28735 Mdot
.638 .28735 Mdot
.638 .28737 Mdot
.638 .28738 Mdot
.638 .28739 Mdot
.638 .28745 Mdot
.638 .28753 Mdot
.638 .28753 Mdot
.638 .28767 Mdot
.638 .28771 Mdot
.638 .28771 Mdot
.638 .28771 Mdot
.638 .28776 Mdot
.638 .28777 Mdot
.638 .28778 Mdot
.638 .28779 Mdot
.638 .28792 Mdot
.638 .28793 Mdot
.638 .28798 Mdot
.638 .28808 Mdot
.638 .28823 Mdot
.638 .28824 Mdot
.638 .28828 Mdot
.638 .28832 Mdot
.638 .28836 Mdot
.638 .28847 Mdot
.638 .28849 Mdot
.638 .2885 Mdot
.638 .28851 Mdot
.638 .28854 Mdot
.638 .28857 Mdot
.638 .28863 Mdot
.638 .2887 Mdot
.638 .28871 Mdot
.638 .28872 Mdot
.638 .28873 Mdot
.638 .28875 Mdot
.638 .28879 Mdot
.638 .28881 Mdot
.638 .28884 Mdot
.638 .28887 Mdot
.638 .28914 Mdot
.638 .28915 Mdot
.638 .28925 Mdot
.638 .2893 Mdot
.638 .28934 Mdot
.638 .28937 Mdot
.638 .28939 Mdot
.638 .28942 Mdot
.638 .28952 Mdot
.638 .28961 Mdot
.638 .28964 Mdot
.638 .28967 Mdot
.638 .28994 Mdot
.638 .29002 Mdot
.638 .29005 Mdot
.638 .29006 Mdot
.638 .29014 Mdot
.638 .29025 Mdot
.638 .29036 Mdot
.638 .29052 Mdot
.638 .29055 Mdot
.638 .29074 Mdot
.638 .29076 Mdot
.638 .29079 Mdot
.638 .29087 Mdot
.638 .29094 Mdot
.638 .291 Mdot
.638 .29101 Mdot
.638 .29105 Mdot
.638 .29111 Mdot
.638 .29112 Mdot
.638 .29135 Mdot
.638 .29135 Mdot
.638 .29142 Mdot
.638 .29147 Mdot
.638 .29177 Mdot
.638 .29178 Mdot
.638 .29181 Mdot
.638 .29185 Mdot
.638 .29188 Mdot
.638 .29195 Mdot
.638 .29197 Mdot
.638 .29208 Mdot
.638 .29219 Mdot
.638 .29223 Mdot
.638 .29224 Mdot
.638 .29229 Mdot
.638 .29234 Mdot
.638 .2924 Mdot
.638 .29244 Mdot
.638 .29246 Mdot
.638 .2925 Mdot
.638 .29256 Mdot
.638 .29262 Mdot
.638 .2927 Mdot
.638 .29277 Mdot
.638 .29282 Mdot
.638 .29286 Mdot
.638 .2929 Mdot
.638 .29293 Mdot
.638 .29295 Mdot
.638 .2931 Mdot
.638 .29316 Mdot
.638 .29318 Mdot
.638 .29321 Mdot
.638 .29321 Mdot
.638 .29327 Mdot
.638 .29334 Mdot
.638 .29335 Mdot
.638 .29349 Mdot
.638 .29359 Mdot
.638 .29361 Mdot
.638 .29388 Mdot
.638 .29395 Mdot
.638 .29397 Mdot
.638 .294 Mdot
.638 .29401 Mdot
.638 .29418 Mdot
.638 .29429 Mdot
.638 .29431 Mdot
.638 .29434 Mdot
.638 .29434 Mdot
.638 .29443 Mdot
.638 .29447 Mdot
.638 .29447 Mdot
.638 .29455 Mdot
.638 .29464 Mdot
.638 .29465 Mdot
.638 .29471 Mdot
.638 .29503 Mdot
.638 .2951 Mdot
.638 .29511 Mdot
.638 .29517 Mdot
.638 .29528 Mdot
.638 .29532 Mdot
.638 .29533 Mdot
.638 .29534 Mdot
.638 .29536 Mdot
.638 .29539 Mdot
.638 .29551 Mdot
.638 .29552 Mdot
.638 .29563 Mdot
.638 .29568 Mdot
.638 .29569 Mdot
.638 .29569 Mdot
.638 .29573 Mdot
.638 .29585 Mdot
.638 .29592 Mdot
.638 .29595 Mdot
.638 .29608 Mdot
.638 .29616 Mdot
.638 .29618 Mdot
.638 .29622 Mdot
.638 .29629 Mdot
.638 .29632 Mdot
.638 .29638 Mdot
.638 .29639 Mdot
.638 .2965 Mdot
.638 .29662 Mdot
.638 .29666 Mdot
.638 .2967 Mdot
.638 .2968 Mdot
.638 .29682 Mdot
.638 .29692 Mdot
.638 .29695 Mdot
.638 .29696 Mdot
.638 .29699 Mdot
.638 .29704 Mdot
.638 .29727 Mdot
.638 .29734 Mdot
.638 .29763 Mdot
.638 .29769 Mdot
.638 .2978 Mdot
.638 .29786 Mdot
.638 .29789 Mdot
.638 .29793 Mdot
.638 .29796 Mdot
.638 .29805 Mdot
.638 .29811 Mdot
.638 .29814 Mdot
.638 .29815 Mdot
.638 .2983 Mdot
.638 .29841 Mdot
.638 .29843 Mdot
.638 .29845 Mdot
.638 .29856 Mdot
.638 .29857 Mdot
.638 .29863 Mdot
.638 .29866 Mdot
.638 .29895 Mdot
.638 .29896 Mdot
.638 .29897 Mdot
.638 .29909 Mdot
.638 .29909 Mdot
.638 .29919 Mdot
.638 .29927 Mdot
.638 .29927 Mdot
.638 .29935 Mdot
.638 .29944 Mdot
.638 .29958 Mdot
.638 .29968 Mdot
.638 .29989 Mdot
.638 .29992 Mdot
.638 .29993 Mdot
.638 .30007 Mdot
.638 .30011 Mdot
.638 .30012 Mdot
.638 .30017 Mdot
.638 .30021 Mdot
.638 .30032 Mdot
.638 .30037 Mdot
.638 .30047 Mdot
.638 .30056 Mdot
.638 .30059 Mdot
.638 .30076 Mdot
.638 .30076 Mdot
.638 .30084 Mdot
.638 .30089 Mdot
.638 .30138 Mdot
.638 .30149 Mdot
.638 .30156 Mdot
.638 .30165 Mdot
.638 .30178 Mdot
.638 .30178 Mdot
.638 .30189 Mdot
.638 .30204 Mdot
.638 .30211 Mdot
.638 .30219 Mdot
.638 .30225 Mdot
.638 .30241 Mdot
.638 .30249 Mdot
.638 .30249 Mdot
.638 .30267 Mdot
.638 .30269 Mdot
.638 .30273 Mdot
.638 .30273 Mdot
.638 .3028 Mdot
.638 .30282 Mdot
.638 .30283 Mdot
.638 .3029 Mdot
.638 .30301 Mdot
.638 .30312 Mdot
.638 .30315 Mdot
.638 .3032 Mdot
.638 .30353 Mdot
.638 .3037 Mdot
.638 .30372 Mdot
.638 .3038 Mdot
.638 .30388 Mdot
.638 .30393 Mdot
.638 .30407 Mdot
.638 .30413 Mdot
.638 .3042 Mdot
.638 .30421 Mdot
.638 .30434 Mdot
.638 .3044 Mdot
.638 .30448 Mdot
.638 .3045 Mdot
.638 .3045 Mdot
.638 .30453 Mdot
.638 .30461 Mdot
.638 .3047 Mdot
.638 .30471 Mdot
.638 .30472 Mdot
.638 .30472 Mdot
.638 .30485 Mdot
.638 .3051 Mdot
.638 .30513 Mdot
.638 .3052 Mdot
.638 .30525 Mdot
.638 .30534 Mdot
.638 .30536 Mdot
.638 .30553 Mdot
.638 .30557 Mdot
.638 .30561 Mdot
.638 .30579 Mdot
.638 .30585 Mdot
.638 .30593 Mdot
.638 .30602 Mdot
.638 .30602 Mdot
.638 .30604 Mdot
.638 .30605 Mdot
.638 .30609 Mdot
.638 .30618 Mdot
.638 .3062 Mdot
.638 .30621 Mdot
.638 .30624 Mdot
.638 .30626 Mdot
.638 .30629 Mdot
.638 .30633 Mdot
.638 .30639 Mdot
.638 .30645 Mdot
.638 .30648 Mdot
.638 .3065 Mdot
.638 .30659 Mdot
.638 .30664 Mdot
.638 .30671 Mdot
.638 .30678 Mdot
.638 .3068 Mdot
.638 .30684 Mdot
.638 .30686 Mdot
.638 .30688 Mdot
.638 .3069 Mdot
.638 .30731 Mdot
.638 .30735 Mdot
.638 .30742 Mdot
.638 .30746 Mdot
.638 .30753 Mdot
.638 .30754 Mdot
.638 .30784 Mdot
.638 .30791 Mdot
.638 .30796 Mdot
.638 .30796 Mdot
.638 .30798 Mdot
.638 .30803 Mdot
.638 .30819 Mdot
.638 .30821 Mdot
.638 .30823 Mdot
.638 .30835 Mdot
.638 .30837 Mdot
.638 .30838 Mdot
.638 .30846 Mdot
.638 .30851 Mdot
.638 .30871 Mdot
.638 .30873 Mdot
.638 .30873 Mdot
.638 .30877 Mdot
.638 .30878 Mdot
.638 .30889 Mdot
.638 .30891 Mdot
.638 .30892 Mdot
.638 .30892 Mdot
.638 .30893 Mdot
.638 .309 Mdot
.638 .30903 Mdot
.638 .30905 Mdot
.638 .30917 Mdot
.638 .30923 Mdot
.638 .30927 Mdot
.638 .3094 Mdot
.638 .3094 Mdot
.638 .3094 Mdot
.638 .3096 Mdot
.638 .30961 Mdot
.638 .30966 Mdot
.638 .30977 Mdot
.638 .30977 Mdot
.638 .3098 Mdot
.638 .30984 Mdot
.638 .30988 Mdot
.638 .30988 Mdot
.638 .30997 Mdot
.638 .31003 Mdot
.638 .31003 Mdot
.638 .31004 Mdot
.638 .31004 Mdot
.638 .31012 Mdot
.638 .31032 Mdot
.638 .31032 Mdot
.638 .31052 Mdot
.638 .31056 Mdot
.638 .3106 Mdot
.638 .31062 Mdot
.638 .31063 Mdot
.638 .31071 Mdot
.638 .31087 Mdot
.638 .31097 Mdot
.638 .31099 Mdot
.638 .31111 Mdot
.638 .31162 Mdot
.638 .31172 Mdot
.638 .31174 Mdot
.638 .31189 Mdot
.638 .31201 Mdot
.638 .31202 Mdot
.638 .31209 Mdot
.638 .31223 Mdot
.638 .31223 Mdot
.638 .31227 Mdot
.638 .3123 Mdot
.638 .31249 Mdot
.638 .31277 Mdot
.638 .31278 Mdot
.638 .31284 Mdot
.638 .31287 Mdot
.638 .31297 Mdot
.638 .31341 Mdot
.638 .31345 Mdot
.638 .31362 Mdot
.638 .31384 Mdot
.638 .31386 Mdot
.638 .31397 Mdot
.638 .31406 Mdot
.638 .31407 Mdot
.638 .31412 Mdot
.638 .31415 Mdot
.638 .31425 Mdot
.638 .31449 Mdot
.638 .31453 Mdot
.638 .31458 Mdot
.638 .31464 Mdot
.638 .31471 Mdot
.638 .31479 Mdot
.638 .3149 Mdot
.638 .31504 Mdot
.638 .31513 Mdot
.638 .31522 Mdot
.638 .31528 Mdot
.638 .31533 Mdot
.638 .31539 Mdot
.638 .31549 Mdot
.638 .31557 Mdot
.638 .31565 Mdot
.638 .31567 Mdot
.638 .31572 Mdot
.638 .31591 Mdot
.638 .31608 Mdot
.638 .31612 Mdot
.638 .31623 Mdot
.638 .31629 Mdot
.638 .31634 Mdot
.638 .3164 Mdot
.638 .31641 Mdot
.638 .3169 Mdot
.638 .31698 Mdot
.638 .31709 Mdot
.638 .3171 Mdot
.638 .31747 Mdot
.638 .31749 Mdot
.638 .31759 Mdot
.638 .31765 Mdot
.638 .31767 Mdot
.638 .31777 Mdot
.638 .31788 Mdot
.638 .31801 Mdot
.638 .31806 Mdot
.638 .31809 Mdot
.638 .31839 Mdot
.638 .31845 Mdot
.638 .3187 Mdot
.638 .31889 Mdot
.638 .31907 Mdot
.638 .3192 Mdot
.638 .31922 Mdot
.638 .31926 Mdot
.638 .31939 Mdot
.638 .31983 Mdot
.638 .31988 Mdot
.638 .31992 Mdot
.638 .32008 Mdot
.638 .32024 Mdot
.638 .32029 Mdot
.638 .32033 Mdot
.638 .32037 Mdot
.638 .32044 Mdot
.638 .32052 Mdot
.638 .32067 Mdot
.638 .3207 Mdot
.638 .32114 Mdot
.638 .32119 Mdot
.638 .32124 Mdot
.638 .32126 Mdot
.638 .32134 Mdot
.638 .32136 Mdot
.638 .32137 Mdot
.638 .32139 Mdot
.638 .32141 Mdot
.638 .32152 Mdot
.638 .32162 Mdot
.638 .32167 Mdot
.638 .32172 Mdot
.638 .32174 Mdot
.638 .32175 Mdot
.638 .32178 Mdot
.638 .32203 Mdot
.638 .3221 Mdot
.638 .32216 Mdot
.638 .32217 Mdot
.638 .32243 Mdot
.638 .32259 Mdot
.638 .32267 Mdot
.638 .32268 Mdot
.638 .3229 Mdot
.638 .32291 Mdot
.638 .32293 Mdot
.638 .32294 Mdot
.638 .32302 Mdot
.638 .32302 Mdot
.638 .32303 Mdot
.638 .32309 Mdot
.638 .32331 Mdot
.638 .32332 Mdot
.638 .32344 Mdot
.638 .32354 Mdot
.638 .32356 Mdot
.638 .32358 Mdot
.638 .32361 Mdot
.638 .32361 Mdot
.638 .32371 Mdot
.638 .36252 Mdot
.638 .36259 Mdot
.638 .3626 Mdot
.638 .36262 Mdot
.638 .36264 Mdot
.638 .36265 Mdot
.638 .36273 Mdot
.638 .36283 Mdot
.638 .36283 Mdot
.638 .36301 Mdot
.638 .36305 Mdot
.638 .36306 Mdot
.638 .36306 Mdot
.638 .36313 Mdot
.638 .36313 Mdot
.638 .36315 Mdot
.638 .36315 Mdot
.638 .36332 Mdot
.638 .36333 Mdot
.638 .3634 Mdot
.638 .36352 Mdot
.638 .36372 Mdot
.638 .36373 Mdot
.638 .36378 Mdot
.638 .36383 Mdot
.638 .36403 Mdot
.638 .36405 Mdot
.638 .36406 Mdot
.638 .36408 Mdot
.638 .36412 Mdot
.638 .36415 Mdot
.638 .36423 Mdot
.638 .36432 Mdot
.638 .36434 Mdot
.638 .36435 Mdot
.638 .36436 Mdot
.638 .36438 Mdot
.638 .36444 Mdot
.638 .36446 Mdot
.638 .3645 Mdot
.638 .36454 Mdot
.638 .36488 Mdot
.638 .3649 Mdot
.638 .36502 Mdot
.638 .36508 Mdot
.638 .36514 Mdot
.638 .36517 Mdot
.638 .3652 Mdot
.638 .36523 Mdot
.638 .36537 Mdot
.638 .36549 Mdot
.638 .36552 Mdot
.638 .36556 Mdot
.638 .3659 Mdot
.638 .366 Mdot
.638 .36604 Mdot
.638 .36606 Mdot
.638 .36615 Mdot
.638 .3663 Mdot
.638 .36644 Mdot
.638 .36664 Mdot
.638 .36669 Mdot
.638 .36692 Mdot
.638 .36695 Mdot
.638 .36699 Mdot
.638 .36709 Mdot
.638 .36717 Mdot
.638 .36725 Mdot
.638 .36727 Mdot
.638 .36732 Mdot
.638 .36739 Mdot
.638 .36741 Mdot
.638 .3677 Mdot
.638 .36771 Mdot
.638 .36779 Mdot
.638 .36786 Mdot
.638 .36824 Mdot
.638 .36825 Mdot
.638 .36829 Mdot
.638 .36833 Mdot
.638 .36838 Mdot
.638 .36847 Mdot
.638 .3685 Mdot
.638 .36863 Mdot
.638 .36878 Mdot
.638 .36882 Mdot
.638 .36884 Mdot
.638 .36889 Mdot
.638 .36896 Mdot
.638 .36904 Mdot
.638 .36909 Mdot
.638 .36912 Mdot
.638 .36917 Mdot
.638 .36924 Mdot
.638 .36932 Mdot
.638 .36943 Mdot
.638 .36951 Mdot
.638 .36957 Mdot
.638 .36963 Mdot
.638 .36968 Mdot
.638 .36971 Mdot
.638 .36974 Mdot
.638 .36993 Mdot
.638 .37001 Mdot
.638 .37004 Mdot
.638 .37008 Mdot
.638 .37008 Mdot
.638 .37015 Mdot
.638 .37024 Mdot
.638 .37026 Mdot
.638 .37043 Mdot
.638 .37056 Mdot
.638 .37059 Mdot
.638 .37094 Mdot
.638 .37101 Mdot
.638 .37104 Mdot
.638 .37109 Mdot
.638 .37109 Mdot
.638 .37131 Mdot
.638 .37146 Mdot
.638 .37148 Mdot
.638 .37151 Mdot
.638 .37152 Mdot
.638 .37163 Mdot
.638 .37168 Mdot
.638 .37169 Mdot
.638 .37179 Mdot
.638 .3719 Mdot
.638 .37192 Mdot
.638 .37199 Mdot
.638 .3724 Mdot
.638 .37248 Mdot
.638 .3725 Mdot
.638 .37258 Mdot
.638 .37271 Mdot
.638 .37277 Mdot
.638 .37278 Mdot
.638 .37279 Mdot
.638 .37282 Mdot
.638 .37285 Mdot
.638 .37301 Mdot
.638 .37302 Mdot
.638 .37317 Mdot
.638 .37323 Mdot
.638 .37323 Mdot
.638 .37324 Mdot
.638 .37324 Mdot
.638 .37329 Mdot
.638 .37335 Mdot
.638 .37335 Mdot
.638 .37339 Mdot
.638 .37342 Mdot
.638 .37344 Mdot
.638 .37344 Mdot
.638 .37353 Mdot
.638 .37357 Mdot
.638 .37358 Mdot
.638 .37373 Mdot
.638 .37374 Mdot
.638 .37374 Mdot
.638 .37384 Mdot
.638 .37386 Mdot
.638 .37391 Mdot
.638 .37401 Mdot
.638 .37403 Mdot
.638 .37405 Mdot
.638 .3741 Mdot
.638 .37411 Mdot
.638 .37411 Mdot
.638 .37412 Mdot
.638 .37414 Mdot
.638 .37422 Mdot
.638 .37423 Mdot
.638 .37426 Mdot
.638 .37426 Mdot
.638 .37428 Mdot
.638 .37443 Mdot
.638 .37447 Mdot
.638 .37453 Mdot
.638 .37454 Mdot
.638 .37456 Mdot
.638 .37465 Mdot
.638 .37466 Mdot
.638 .37468 Mdot
.638 .37481 Mdot
.638 .37485 Mdot
.638 .37486 Mdot
.638 .37487 Mdot
.638 .3749 Mdot
.638 .37496 Mdot
.638 .37519 Mdot
.638 .3752 Mdot
.638 .37525 Mdot
.638 .37529 Mdot
.638 .37534 Mdot
.638 .37537 Mdot
.638 .37569 Mdot
.638 .37571 Mdot
.638 .37572 Mdot
.638 .37574 Mdot
.638 .37577 Mdot
.638 .37579 Mdot
.638 .37584 Mdot
.638 .37589 Mdot
.638 .37594 Mdot
.638 .37601 Mdot
.638 .37602 Mdot
.638 .37604 Mdot
.638 .3761 Mdot
.638 .37614 Mdot
.638 .37617 Mdot
.638 .37619 Mdot
.638 .37621 Mdot
.638 .37623 Mdot
.638 .37624 Mdot
.638 .37626 Mdot
.638 .37633 Mdot
.638 .37636 Mdot
.638 .37637 Mdot
.638 .37638 Mdot
.638 .37638 Mdot
.638 .37645 Mdot
.638 .37651 Mdot
.638 .37656 Mdot
.638 .37671 Mdot
.638 .37674 Mdot
.638 .37676 Mdot
.638 .3769 Mdot
.638 .37691 Mdot
.638 .37699 Mdot
.638 .37703 Mdot
.638 .37708 Mdot
.638 .3771 Mdot
.638 .3773 Mdot
.638 .3774 Mdot
.638 .3774 Mdot
.638 .37741 Mdot
.638 .37742 Mdot
.638 .37749 Mdot
.638 .37755 Mdot
.638 .37757 Mdot
.638 .37758 Mdot
.638 .37759 Mdot
.638 .37765 Mdot
.638 .3777 Mdot
.638 .3778 Mdot
.638 .37781 Mdot
.638 .37787 Mdot
.638 .37791 Mdot
.638 .37802 Mdot
.638 .37806 Mdot
.638 .37812 Mdot
.638 .37819 Mdot
.638 .3782 Mdot
.638 .37834 Mdot
.638 .37859 Mdot
.638 .37863 Mdot
.638 .37865 Mdot
.638 .37874 Mdot
.638 .37883 Mdot
.638 .37888 Mdot
.638 .37889 Mdot
.638 .3789 Mdot
.638 .37896 Mdot
.638 .37896 Mdot
.638 .37899 Mdot
.638 .379 Mdot
.638 .37915 Mdot
.638 .37915 Mdot
.638 .37921 Mdot
.638 .37934 Mdot
.638 .37938 Mdot
.638 .37945 Mdot
.638 .3795 Mdot
.638 .37962 Mdot
.638 .3797 Mdot
.638 .37971 Mdot
.638 .37981 Mdot
.638 .37988 Mdot
.638 .37994 Mdot
.638 .38002 Mdot
.638 .3804 Mdot
.638 .38044 Mdot
.638 .3805 Mdot
.638 .38051 Mdot
.638 .38063 Mdot
.638 .38066 Mdot
.638 .38073 Mdot
.638 .38081 Mdot
.638 .38085 Mdot
.638 .38094 Mdot
.638 .38097 Mdot
.638 .381 Mdot
.638 .38101 Mdot
.638 .38104 Mdot
.638 .38115 Mdot
.638 .38117 Mdot
.638 .38119 Mdot
.638 .38135 Mdot
.638 .38143 Mdot
.638 .38154 Mdot
.638 .38161 Mdot
.638 .38167 Mdot
.638 .38168 Mdot
.638 .38181 Mdot
.638 .38182 Mdot
.638 .38191 Mdot
.638 .38192 Mdot
.638 .38192 Mdot
.638 .38215 Mdot
.638 .38218 Mdot
.638 .38222 Mdot
.638 .38223 Mdot
.638 .38231 Mdot
.638 .38233 Mdot
.638 .38235 Mdot
.638 .38244 Mdot
.638 .38255 Mdot
.638 .38256 Mdot
.638 .38258 Mdot
.638 .38263 Mdot
.638 .3827 Mdot
.638 .38272 Mdot
.638 .38276 Mdot
.638 .38278 Mdot
.638 .38282 Mdot
.638 .38291 Mdot
.638 .38296 Mdot
.638 .38319 Mdot
.638 .38324 Mdot
.638 .38342 Mdot
.638 .38346 Mdot
.638 .38348 Mdot
.638 .38349 Mdot
.638 .38351 Mdot
.638 .38359 Mdot
.638 .38361 Mdot
.638 .38368 Mdot
.638 .38372 Mdot
.638 .38375 Mdot
.638 .38384 Mdot
.638 .38393 Mdot
.638 .38394 Mdot
.638 .38398 Mdot
.638 .38401 Mdot
.638 .38407 Mdot
.638 .38409 Mdot
.638 .38411 Mdot
.638 .38417 Mdot
.638 .38428 Mdot
.638 .3843 Mdot
.638 .38435 Mdot
.638 .38445 Mdot
.638 .38448 Mdot
.638 .38448 Mdot
.638 .38448 Mdot
.638 .38452 Mdot
.638 .38461 Mdot
.638 .38462 Mdot
.638 .38471 Mdot
.638 .38473 Mdot
.638 .38475 Mdot
.638 .38476 Mdot
.638 .38477 Mdot
.638 .3848 Mdot
.638 .38488 Mdot
.638 .38493 Mdot
.638 .38494 Mdot
.638 .385 Mdot
.638 .38524 Mdot
.638 .38529 Mdot
.638 .3853 Mdot
.638 .38537 Mdot
.638 .38543 Mdot
.638 .38544 Mdot
.638 .38547 Mdot
.638 .38554 Mdot
.638 .38554 Mdot
.638 .38556 Mdot
.638 .38557 Mdot
.638 .38566 Mdot
.638 .3858 Mdot
.638 .3858 Mdot
.638 .38583 Mdot
.638 .38585 Mdot
.638 .38589 Mdot
.638 .3861 Mdot
.638 .38612 Mdot
.638 .38621 Mdot
.638 .38631 Mdot
.638 .38632 Mdot
.638 .38637 Mdot
.638 .38642 Mdot
.638 .38642 Mdot
.638 .38645 Mdot
.638 .38646 Mdot
.638 .38651 Mdot
.638 .38662 Mdot
.638 .38664 Mdot
.638 .38667 Mdot
.638 .3867 Mdot
.638 .38673 Mdot
.638 .38677 Mdot
.638 .38682 Mdot
.638 .38689 Mdot
.638 .38693 Mdot
.638 .38697 Mdot
.638 .38701 Mdot
.638 .38703 Mdot
.638 .38706 Mdot
.638 .38711 Mdot
.638 .38715 Mdot
.638 .38718 Mdot
.638 .38719 Mdot
.638 .38722 Mdot
.638 .38731 Mdot
.638 .38739 Mdot
.638 .38741 Mdot
.638 .38746 Mdot
.638 .38749 Mdot
.638 .38752 Mdot
.638 .38754 Mdot
.638 .38755 Mdot
.638 .38778 Mdot
.638 .38782 Mdot
.638 .38788 Mdot
.638 .38788 Mdot
.638 .38806 Mdot
.638 .38807 Mdot
.638 .38811 Mdot
.638 .38814 Mdot
.638 .38815 Mdot
.638 .3882 Mdot
.638 .38826 Mdot
.638 .38832 Mdot
.638 .38834 Mdot
.638 .38836 Mdot
.638 .3885 Mdot
.638 .38853 Mdot
.638 .38865 Mdot
.638 .38874 Mdot
.638 .38883 Mdot
.638 .38889 Mdot
.638 .3889 Mdot
.638 .38892 Mdot
.638 .38898 Mdot
.638 .38919 Mdot
.638 .38922 Mdot
.638 .38924 Mdot
.638 .38931 Mdot
.638 .38939 Mdot
.638 .38942 Mdot
.638 .38943 Mdot
.638 .38946 Mdot
.638 .38949 Mdot
.638 .38953 Mdot
.638 .3896 Mdot
.638 .38961 Mdot
.638 .38982 Mdot
.638 .38985 Mdot
.638 .38987 Mdot
.638 .38988 Mdot
.638 .38992 Mdot
.638 .38993 Mdot
.638 .38994 Mdot
.638 .38994 Mdot
.638 .38995 Mdot
.638 .39001 Mdot
.638 .39006 Mdot
.638 .39008 Mdot
.638 .3901 Mdot
.638 .39011 Mdot
.638 .39012 Mdot
.638 .39013 Mdot
.638 .39022 Mdot
.638 .39026 Mdot
.638 .39029 Mdot
.638 .39032 Mdot
.638 .39032 Mdot
.638 .39045 Mdot
.638 .39052 Mdot
.638 .39056 Mdot
.638 .39057 Mdot
.638 .39067 Mdot
.638 .39068 Mdot
.638 .39069 Mdot
.638 .39069 Mdot
.638 .39073 Mdot
.638 .39073 Mdot
.638 .39073 Mdot
.638 .39076 Mdot
.638 .39087 Mdot
.638 .39087 Mdot
.638 .39093 Mdot
.638 .39098 Mdot
.638 .39099 Mdot
.638 .391 Mdot
.638 .39102 Mdot
.638 .39102 Mdot
.638 .39106 Mdot
.64 .28664 Mdot
.64 .28666 Mdot
.64 .28666 Mdot
.64 .28683 Mdot
.64 .28685 Mdot
.64 .28688 Mdot
.64 .28695 Mdot
.64 .28695 Mdot
.64 .2871 Mdot
.64 .28714 Mdot
.64 .28716 Mdot
.64 .28716 Mdot
.64 .28717 Mdot
.64 .28732 Mdot
.64 .28733 Mdot
.64 .28733 Mdot
.64 .28741 Mdot
.64 .28744 Mdot
.64 .28748 Mdot
.64 .2876 Mdot
.64 .28767 Mdot
.64 .28771 Mdot
.64 .28775 Mdot
.64 .2879 Mdot
.64 .28791 Mdot
.64 .28791 Mdot
.64 .28798 Mdot
.64 .28799 Mdot
.64 .28803 Mdot
.64 .28814 Mdot
.64 .28816 Mdot
.64 .28819 Mdot
.64 .28819 Mdot
.64 .28832 Mdot
.64 .2884 Mdot
.64 .28845 Mdot
.64 .28854 Mdot
.64 .2886 Mdot
.64 .28862 Mdot
.64 .28864 Mdot
.64 .28867 Mdot
.64 .28875 Mdot
.64 .28881 Mdot
.64 .28882 Mdot
.64 .28893 Mdot
.64 .28896 Mdot
.64 .28905 Mdot
.64 .28908 Mdot
.64 .28911 Mdot
.64 .28913 Mdot
.64 .28923 Mdot
.64 .28935 Mdot
.64 .28936 Mdot
.64 .28958 Mdot
.64 .28968 Mdot
.64 .2897 Mdot
.64 .28979 Mdot
.64 .28982 Mdot
.64 .28986 Mdot
.64 .28992 Mdot
.64 .29002 Mdot
.64 .2901 Mdot
.64 .29012 Mdot
.64 .29035 Mdot
.64 .29037 Mdot
.64 .29057 Mdot
.64 .29062 Mdot
.64 .29063 Mdot
.64 .29067 Mdot
.64 .29068 Mdot
.64 .29072 Mdot
.64 .29072 Mdot
.64 .29094 Mdot
.64 .29103 Mdot
.64 .29106 Mdot
.64 .29106 Mdot
.64 .29109 Mdot
.64 .29111 Mdot
.64 .29115 Mdot
.64 .29123 Mdot
.64 .29127 Mdot
.64 .29139 Mdot
.64 .29143 Mdot
.64 .29147 Mdot
.64 .2915 Mdot
.64 .29151 Mdot
.64 .2917 Mdot
.64 .29173 Mdot
.64 .29181 Mdot
.64 .29184 Mdot
.64 .29193 Mdot
.64 .29194 Mdot
.64 .29197 Mdot
.64 .29202 Mdot
.64 .29221 Mdot
.64 .29226 Mdot
.64 .29226 Mdot
.64 .29233 Mdot
.64 .29238 Mdot
.64 .29251 Mdot
.64 .29255 Mdot
.64 .29257 Mdot
.64 .29279 Mdot
.64 .29285 Mdot
.64 .29286 Mdot
.64 .29291 Mdot
.64 .29297 Mdot
.64 .29311 Mdot
.64 .2932 Mdot
.64 .29322 Mdot
.64 .29324 Mdot
.64 .29326 Mdot
.64 .29335 Mdot
.64 .29346 Mdot
.64 .29348 Mdot
.64 .29357 Mdot
.64 .29362 Mdot
.64 .29374 Mdot
.64 .29375 Mdot
.64 .29376 Mdot
.64 .29385 Mdot
.64 .29388 Mdot
.64 .29391 Mdot
.64 .29395 Mdot
.64 .29405 Mdot
.64 .29407 Mdot
.64 .29416 Mdot
.64 .29433 Mdot
.64 .29437 Mdot
.64 .29438 Mdot
.64 .29442 Mdot
.64 .29463 Mdot
.64 .29464 Mdot
.64 .29466 Mdot
.64 .29469 Mdot
.64 .2947 Mdot
.64 .29475 Mdot
.64 .29477 Mdot
.64 .29482 Mdot
.64 .29488 Mdot
.64 .29493 Mdot
.64 .29499 Mdot
.64 .29514 Mdot
.64 .29515 Mdot
.64 .2952 Mdot
.64 .2953 Mdot
.64 .29536 Mdot
.64 .29548 Mdot
.64 .29548 Mdot
.64 .29561 Mdot
.64 .2957 Mdot
.64 .29572 Mdot
.64 .2958 Mdot
.64 .29586 Mdot
.64 .29599 Mdot
.64 .29608 Mdot
.64 .29611 Mdot
.64 .29613 Mdot
.64 .29626 Mdot
.64 .29634 Mdot
.64 .29636 Mdot
.64 .29652 Mdot
.64 .29657 Mdot
.64 .29662 Mdot
.64 .2967 Mdot
.64 .2969 Mdot
.64 .2969 Mdot
.64 .29699 Mdot
.64 .29707 Mdot
.64 .29709 Mdot
.64 .29726 Mdot
.64 .29727 Mdot
.64 .29738 Mdot
.64 .29739 Mdot
.64 .29749 Mdot
.64 .29753 Mdot
.64 .29761 Mdot
.64 .2977 Mdot
.64 .29773 Mdot
.64 .29775 Mdot
.64 .29781 Mdot
.64 .29806 Mdot
.64 .29807 Mdot
.64 .29811 Mdot
.64 .29815 Mdot
.64 .29821 Mdot
.64 .29825 Mdot
.64 .29841 Mdot
.64 .29847 Mdot
.64 .29849 Mdot
.64 .29849 Mdot
.64 .29858 Mdot
.64 .29859 Mdot
.64 .29864 Mdot
.64 .29868 Mdot
.64 .2987 Mdot
.64 .29872 Mdot
.64 .29877 Mdot
.64 .29898 Mdot
.64 .29902 Mdot
.64 .29913 Mdot
.64 .29931 Mdot
.64 .29943 Mdot
.64 .29956 Mdot
.64 .29957 Mdot
.64 .29961 Mdot
.64 .29961 Mdot
.64 .29974 Mdot
.64 .29974 Mdot
.64 .29986 Mdot
.64 .29988 Mdot
.64 .29992 Mdot
.64 .29999 Mdot
.64 .30002 Mdot
.64 .30009 Mdot
.64 .30037 Mdot
.64 .30042 Mdot
.64 .30055 Mdot
.64 .30062 Mdot
.64 .30124 Mdot
.64 .30127 Mdot
.64 .30144 Mdot
.64 .3015 Mdot
.64 .30155 Mdot
.64 .30176 Mdot
.64 .30176 Mdot
.64 .30185 Mdot
.64 .30192 Mdot
.64 .30203 Mdot
.64 .30212 Mdot
.64 .30231 Mdot
.64 .30236 Mdot
.64 .30242 Mdot
.64 .30242 Mdot
.64 .30247 Mdot
.64 .30259 Mdot
.64 .30266 Mdot
.64 .30268 Mdot
.64 .30268 Mdot
.64 .30287 Mdot
.64 .30289 Mdot
.64 .30309 Mdot
.64 .3031 Mdot
.64 .30317 Mdot
.64 .30317 Mdot
.64 .30327 Mdot
.64 .30329 Mdot
.64 .30339 Mdot
.64 .30359 Mdot
.64 .30363 Mdot
.64 .30388 Mdot
.64 .30389 Mdot
.64 .30395 Mdot
.64 .30403 Mdot
.64 .30406 Mdot
.64 .30411 Mdot
.64 .30413 Mdot
.64 .30433 Mdot
.64 .30443 Mdot
.64 .30446 Mdot
.64 .30456 Mdot
.64 .30459 Mdot
.64 .30462 Mdot
.64 .30469 Mdot
.64 .30471 Mdot
.64 .30474 Mdot
.64 .30477 Mdot
.64 .30478 Mdot
.64 .30491 Mdot
.64 .30493 Mdot
.64 .30494 Mdot
.64 .30496 Mdot
.64 .30506 Mdot
.64 .30512 Mdot
.64 .30519 Mdot
.64 .30526 Mdot
.64 .30531 Mdot
.64 .30532 Mdot
.64 .30539 Mdot
.64 .30548 Mdot
.64 .30549 Mdot
.64 .30556 Mdot
.64 .30561 Mdot
.64 .30562 Mdot
.64 .30564 Mdot
.64 .3057 Mdot
.64 .30586 Mdot
.64 .30605 Mdot
.64 .30607 Mdot
.64 .30615 Mdot
.64 .30618 Mdot
.64 .30622 Mdot
.64 .30637 Mdot
.64 .30642 Mdot
.64 .30642 Mdot
.64 .3065 Mdot
.64 .30654 Mdot
.64 .30657 Mdot
.64 .30673 Mdot
.64 .30675 Mdot
.64 .30683 Mdot
.64 .30693 Mdot
.64 .30694 Mdot
.64 .30696 Mdot
.64 .30697 Mdot
.64 .30716 Mdot
.64 .30716 Mdot
.64 .30719 Mdot
.64 .30722 Mdot
.64 .30726 Mdot
.64 .30739 Mdot
.64 .30753 Mdot
.64 .30754 Mdot
.64 .30759 Mdot
.64 .30769 Mdot
.64 .3078 Mdot
.64 .30786 Mdot
.64 .30799 Mdot
.64 .308 Mdot
.64 .30807 Mdot
.64 .30817 Mdot
.64 .30832 Mdot
.64 .30841 Mdot
.64 .30843 Mdot
.64 .30845 Mdot
.64 .3085 Mdot
.64 .30858 Mdot
.64 .30871 Mdot
.64 .30871 Mdot
.64 .30874 Mdot
.64 .3088 Mdot
.64 .30884 Mdot
.64 .30889 Mdot
.64 .30902 Mdot
.64 .30914 Mdot
.64 .30917 Mdot
.64 .30918 Mdot
.64 .30923 Mdot
.64 .30924 Mdot
.64 .30934 Mdot
.64 .30935 Mdot
.64 .30947 Mdot
.64 .30951 Mdot
.64 .30965 Mdot
.64 .30975 Mdot
.64 .30975 Mdot
.64 .30985 Mdot
.64 .30987 Mdot
.64 .30993 Mdot
.64 .31002 Mdot
.64 .31006 Mdot
.64 .31006 Mdot
.64 .31016 Mdot
.64 .31033 Mdot
.64 .31039 Mdot
.64 .31042 Mdot
.64 .31051 Mdot
.64 .31051 Mdot
.64 .31056 Mdot
.64 .31066 Mdot
.64 .31076 Mdot
.64 .31085 Mdot
.64 .31094 Mdot
.64 .31103 Mdot
.64 .31106 Mdot
.64 .31114 Mdot
.64 .31116 Mdot
.64 .31121 Mdot
.64 .31125 Mdot
.64 .31126 Mdot
.64 .31161 Mdot
.64 .31166 Mdot
.64 .31168 Mdot
.64 .31174 Mdot
.64 .31202 Mdot
.64 .31217 Mdot
.64 .3122 Mdot
.64 .31237 Mdot
.64 .31244 Mdot
.64 .31249 Mdot
.64 .31254 Mdot
.64 .31269 Mdot
.64 .3127 Mdot
.64 .31271 Mdot
.64 .31291 Mdot
.64 .31299 Mdot
.64 .31314 Mdot
.64 .31317 Mdot
.64 .31336 Mdot
.64 .3135 Mdot
.64 .31353 Mdot
.64 .31356 Mdot
.64 .31361 Mdot
.64 .31374 Mdot
.64 .31397 Mdot
.64 .31408 Mdot
.64 .31416 Mdot
.64 .31417 Mdot
.64 .31426 Mdot
.64 .31463 Mdot
.64 .31466 Mdot
.64 .31473 Mdot
.64 .31494 Mdot
.64 .31502 Mdot
.64 .31513 Mdot
.64 .31514 Mdot
.64 .31521 Mdot
.64 .31553 Mdot
.64 .31561 Mdot
.64 .31566 Mdot
.64 .31567 Mdot
.64 .31583 Mdot
.64 .31588 Mdot
.64 .316 Mdot
.64 .31606 Mdot
.64 .31636 Mdot
.64 .31639 Mdot
.64 .31644 Mdot
.64 .31649 Mdot
.64 .31656 Mdot
.64 .31676 Mdot
.64 .31683 Mdot
.64 .31696 Mdot
.64 .31703 Mdot
.64 .31706 Mdot
.64 .3171 Mdot
.64 .31711 Mdot
.64 .31715 Mdot
.64 .3173 Mdot
.64 .31765 Mdot
.64 .31766 Mdot
.64 .31773 Mdot
.64 .31774 Mdot
.64 .31781 Mdot
.64 .31782 Mdot
.64 .31791 Mdot
.64 .31823 Mdot
.64 .31827 Mdot
.64 .31865 Mdot
.64 .31867 Mdot
.64 .31881 Mdot
.64 .31897 Mdot
.64 .31907 Mdot
.64 .31913 Mdot
.64 .31919 Mdot
.64 .31934 Mdot
.64 .31937 Mdot
.64 .31953 Mdot
.64 .31989 Mdot
.64 .3199 Mdot
.64 .32011 Mdot
.64 .32027 Mdot
.64 .3203 Mdot
.64 .32035 Mdot
.64 .3204 Mdot
.64 .32054 Mdot
.64 .3206 Mdot
.64 .32077 Mdot
.64 .32079 Mdot
.64 .32089 Mdot
.64 .32102 Mdot
.64 .32106 Mdot
.64 .3211 Mdot
.64 .32113 Mdot
.64 .32124 Mdot
.64 .32137 Mdot
.64 .32147 Mdot
.64 .3216 Mdot
.64 .32181 Mdot
.64 .32181 Mdot
.64 .32186 Mdot
.64 .32189 Mdot
.64 .32206 Mdot
.64 .32214 Mdot
.64 .32215 Mdot
.64 .32226 Mdot
.64 .32226 Mdot
.64 .32228 Mdot
.64 .32253 Mdot
.64 .32259 Mdot
.64 .32265 Mdot
.64 .32277 Mdot
.64 .32297 Mdot
.64 .32304 Mdot
.64 .32308 Mdot
.64 .32321 Mdot
.64 .32321 Mdot
.64 .32323 Mdot
.64 .32347 Mdot
.64 .32349 Mdot
.64 .3235 Mdot
.64 .32353 Mdot
.64 .3236 Mdot
.64 .32385 Mdot
.64 .32385 Mdot
.64 .32395 Mdot
.64 .32401 Mdot
.64 .32404 Mdot
.64 .32431 Mdot
.64 .32431 Mdot
.64 .32434 Mdot
.64 .36278 Mdot
.64 .36281 Mdot
.64 .36281 Mdot
.64 .36302 Mdot
.64 .36304 Mdot
.64 .36309 Mdot
.64 .36317 Mdot
.64 .36317 Mdot
.64 .36336 Mdot
.64 .36342 Mdot
.64 .36344 Mdot
.64 .36345 Mdot
.64 .36346 Mdot
.64 .36365 Mdot
.64 .36367 Mdot
.64 .36367 Mdot
.64 .36377 Mdot
.64 .3638 Mdot
.64 .36385 Mdot
.64 .36401 Mdot
.64 .3641 Mdot
.64 .36415 Mdot
.64 .3642 Mdot
.64 .36439 Mdot
.64 .3644 Mdot
.64 .36441 Mdot
.64 .3645 Mdot
.64 .3645 Mdot
.64 .36456 Mdot
.64 .3647 Mdot
.64 .36472 Mdot
.64 .36476 Mdot
.64 .36476 Mdot
.64 .36492 Mdot
.64 .36503 Mdot
.64 .3651 Mdot
.64 .36521 Mdot
.64 .36529 Mdot
.64 .36531 Mdot
.64 .36534 Mdot
.64 .36538 Mdot
.64 .36548 Mdot
.64 .36556 Mdot
.64 .36558 Mdot
.64 .36571 Mdot
.64 .36575 Mdot
.64 .36586 Mdot
.64 .3659 Mdot
.64 .36594 Mdot
.64 .36596 Mdot
.64 .36609 Mdot
.64 .36625 Mdot
.64 .36626 Mdot
.64 .36654 Mdot
.64 .36666 Mdot
.64 .36669 Mdot
.64 .36681 Mdot
.64 .36685 Mdot
.64 .3669 Mdot
.64 .36698 Mdot
.64 .3671 Mdot
.64 .36721 Mdot
.64 .36723 Mdot
.64 .36752 Mdot
.64 .36756 Mdot
.64 .36781 Mdot
.64 .36788 Mdot
.64 .36788 Mdot
.64 .36794 Mdot
.64 .36794 Mdot
.64 .368 Mdot
.64 .36801 Mdot
.64 .36829 Mdot
.64 .3684 Mdot
.64 .36843 Mdot
.64 .36844 Mdot
.64 .36847 Mdot
.64 .3685 Mdot
.64 .36855 Mdot
.64 .36865 Mdot
.64 .3687 Mdot
.64 .36886 Mdot
.64 .36892 Mdot
.64 .36896 Mdot
.64 .369 Mdot
.64 .36902 Mdot
.64 .36926 Mdot
.64 .3693 Mdot
.64 .36939 Mdot
.64 .36943 Mdot
.64 .36955 Mdot
.64 .36956 Mdot
.64 .3696 Mdot
.64 .36967 Mdot
.64 .36991 Mdot
.64 .36997 Mdot
.64 .36998 Mdot
.64 .37006 Mdot
.64 .37013 Mdot
.64 .37029 Mdot
.64 .37035 Mdot
.64 .37037 Mdot
.64 .37066 Mdot
.64 .37073 Mdot
.64 .37074 Mdot
.64 .3708 Mdot
.64 .37089 Mdot
.64 .37106 Mdot
.64 .37117 Mdot
.64 .3712 Mdot
.64 .37123 Mdot
.64 .37126 Mdot
.64 .37136 Mdot
.64 .37151 Mdot
.64 .37153 Mdot
.64 .37165 Mdot
.64 .37171 Mdot
.64 .37187 Mdot
.64 .37187 Mdot
.64 .37189 Mdot
.64 .372 Mdot
.64 .37204 Mdot
.64 .37208 Mdot
.64 .37214 Mdot
.64 .37227 Mdot
.64 .37229 Mdot
.64 .37241 Mdot
.64 .37263 Mdot
.64 .37267 Mdot
.64 .37269 Mdot
.64 .37273 Mdot
.64 .373 Mdot
.64 .37301 Mdot
.64 .37304 Mdot
.64 .37308 Mdot
.64 .3731 Mdot
.64 .37315 Mdot
.64 .37318 Mdot
.64 .37326 Mdot
.64 .37333 Mdot
.64 .37339 Mdot
.64 .37347 Mdot
.64 .37355 Mdot
.64 .37358 Mdot
.64 .37358 Mdot
.64 .37366 Mdot
.64 .37368 Mdot
.64 .37373 Mdot
.64 .37386 Mdot
.64 .37394 Mdot
.64 .37394 Mdot
.64 .37397 Mdot
.64 .37404 Mdot
.64 .37409 Mdot
.64 .3741 Mdot
.64 .37418 Mdot
.64 .37418 Mdot
.64 .37426 Mdot
.64 .37437 Mdot
.64 .3744 Mdot
.64 .3745 Mdot
.64 .3745 Mdot
.64 .37458 Mdot
.64 .37459 Mdot
.64 .37463 Mdot
.64 .37464 Mdot
.64 .37466 Mdot
.64 .37475 Mdot
.64 .37486 Mdot
.64 .3749 Mdot
.64 .37492 Mdot
.64 .37497 Mdot
.64 .37499 Mdot
.64 .37499 Mdot
.64 .37509 Mdot
.64 .37516 Mdot
.64 .3752 Mdot
.64 .37521 Mdot
.64 .37523 Mdot
.64 .3753 Mdot
.64 .37542 Mdot
.64 .37549 Mdot
.64 .37555 Mdot
.64 .37555 Mdot
.64 .37566 Mdot
.64 .3757 Mdot
.64 .37579 Mdot
.64 .37587 Mdot
.64 .37591 Mdot
.64 .37591 Mdot
.64 .37603 Mdot
.64 .37613 Mdot
.64 .37616 Mdot
.64 .37618 Mdot
.64 .3762 Mdot
.64 .3762 Mdot
.64 .37635 Mdot
.64 .37636 Mdot
.64 .37638 Mdot
.64 .37639 Mdot
.64 .37646 Mdot
.64 .37652 Mdot
.64 .37654 Mdot
.64 .37667 Mdot
.64 .37669 Mdot
.64 .37672 Mdot
.64 .37678 Mdot
.64 .37678 Mdot
.64 .37682 Mdot
.64 .37694 Mdot
.64 .37697 Mdot
.64 .377 Mdot
.64 .37705 Mdot
.64 .37708 Mdot
.64 .37722 Mdot
.64 .37734 Mdot
.64 .37739 Mdot
.64 .37741 Mdot
.64 .37746 Mdot
.64 .37751 Mdot
.64 .37752 Mdot
.64 .37758 Mdot
.64 .37764 Mdot
.64 .37765 Mdot
.64 .37769 Mdot
.64 .37774 Mdot
.64 .3778 Mdot
.64 .37785 Mdot
.64 .37793 Mdot
.64 .37794 Mdot
.64 .37795 Mdot
.64 .37796 Mdot
.64 .37807 Mdot
.64 .37807 Mdot
.64 .3781 Mdot
.64 .37812 Mdot
.64 .37813 Mdot
.64 .37819 Mdot
.64 .37821 Mdot
.64 .37824 Mdot
.64 .37831 Mdot
.64 .37834 Mdot
.64 .37842 Mdot
.64 .37858 Mdot
.64 .37859 Mdot
.64 .37862 Mdot
.64 .37865 Mdot
.64 .37872 Mdot
.64 .37876 Mdot
.64 .37877 Mdot
.64 .37897 Mdot
.64 .37899 Mdot
.64 .37915 Mdot
.64 .37923 Mdot
.64 .37924 Mdot
.64 .37932 Mdot
.64 .37933 Mdot
.64 .37938 Mdot
.64 .37938 Mdot
.64 .37954 Mdot
.64 .37955 Mdot
.64 .3797 Mdot
.64 .37971 Mdot
.64 .37972 Mdot
.64 .37977 Mdot
.64 .37987 Mdot
.64 .37991 Mdot
.64 .37991 Mdot
.64 .37995 Mdot
.64 .38 Mdot
.64 .38014 Mdot
.64 .38021 Mdot
.64 .3803 Mdot
.64 .38036 Mdot
.64 .38042 Mdot
.64 .38042 Mdot
.64 .38059 Mdot
.64 .38062 Mdot
.64 .38067 Mdot
.64 .3808 Mdot
.64 .38083 Mdot
.64 .38132 Mdot
.64 .38137 Mdot
.64 .38147 Mdot
.64 .38151 Mdot
.64 .38173 Mdot
.64 .38178 Mdot
.64 .38181 Mdot
.64 .38186 Mdot
.64 .38189 Mdot
.64 .38191 Mdot
.64 .382 Mdot
.64 .382 Mdot
.64 .3821 Mdot
.64 .38211 Mdot
.64 .38214 Mdot
.64 .38214 Mdot
.64 .38224 Mdot
.64 .38234 Mdot
.64 .38248 Mdot
.64 .38256 Mdot
.64 .38259 Mdot
.64 .38276 Mdot
.64 .3828 Mdot
.64 .38282 Mdot
.64 .38283 Mdot
.64 .38286 Mdot
.64 .3829 Mdot
.64 .38291 Mdot
.64 .38298 Mdot
.64 .38298 Mdot
.64 .38299 Mdot
.64 .38304 Mdot
.64 .38316 Mdot
.64 .3832 Mdot
.64 .38325 Mdot
.64 .38328 Mdot
.64 .38331 Mdot
.64 .38332 Mdot
.64 .38351 Mdot
.64 .38356 Mdot
.64 .38357 Mdot
.64 .38359 Mdot
.64 .38366 Mdot
.64 .38373 Mdot
.64 .38376 Mdot
.64 .38384 Mdot
.64 .38385 Mdot
.64 .38393 Mdot
.64 .38394 Mdot
.64 .38407 Mdot
.64 .38409 Mdot
.64 .38415 Mdot
.64 .38422 Mdot
.64 .38422 Mdot
.64 .38438 Mdot
.64 .38444 Mdot
.64 .38448 Mdot
.64 .38452 Mdot
.64 .38464 Mdot
.64 .38465 Mdot
.64 .38472 Mdot
.64 .38483 Mdot
.64 .38484 Mdot
.64 .38486 Mdot
.64 .38493 Mdot
.64 .38503 Mdot
.64 .38508 Mdot
.64 .38514 Mdot
.64 .38516 Mdot
.64 .38523 Mdot
.64 .38533 Mdot
.64 .38533 Mdot
.64 .38542 Mdot
.64 .38547 Mdot
.64 .38555 Mdot
.64 .38558 Mdot
.64 .38559 Mdot
.64 .38571 Mdot
.64 .38576 Mdot
.64 .3858 Mdot
.64 .38584 Mdot
.64 .38589 Mdot
.64 .3859 Mdot
.64 .38594 Mdot
.64 .38595 Mdot
.64 .38597 Mdot
.64 .38599 Mdot
.64 .386 Mdot
.64 .38616 Mdot
.64 .38619 Mdot
.64 .3862 Mdot
.64 .38623 Mdot
.64 .38636 Mdot
.64 .38643 Mdot
.64 .38645 Mdot
.64 .38652 Mdot
.64 .38656 Mdot
.64 .38658 Mdot
.64 .38661 Mdot
.64 .38668 Mdot
.64 .38669 Mdot
.64 .38669 Mdot
.64 .38678 Mdot
.64 .38682 Mdot
.64 .38689 Mdot
.64 .38691 Mdot
.64 .387 Mdot
.64 .38706 Mdot
.64 .38708 Mdot
.64 .3871 Mdot
.64 .38711 Mdot
.64 .38718 Mdot
.64 .38729 Mdot
.64 .38734 Mdot
.64 .38738 Mdot
.64 .38739 Mdot
.64 .38743 Mdot
.64 .38761 Mdot
.64 .38762 Mdot
.64 .38765 Mdot
.64 .38775 Mdot
.64 .38779 Mdot
.64 .38784 Mdot
.64 .38785 Mdot
.64 .38788 Mdot
.64 .38803 Mdot
.64 .38807 Mdot
.64 .3881 Mdot
.64 .3881 Mdot
.64 .38818 Mdot
.64 .3882 Mdot
.64 .38826 Mdot
.64 .38828 Mdot
.64 .38843 Mdot
.64 .38844 Mdot
.64 .38846 Mdot
.64 .38849 Mdot
.64 .38852 Mdot
.64 .38862 Mdot
.64 .38865 Mdot
.64 .38872 Mdot
.64 .38875 Mdot
.64 .38876 Mdot
.64 .38878 Mdot
.64 .38879 Mdot
.64 .3888 Mdot
.64 .38887 Mdot
.64 .38905 Mdot
.64 .38905 Mdot
.64 .38908 Mdot
.64 .38909 Mdot
.64 .38912 Mdot
.64 .38912 Mdot
.64 .38917 Mdot
.64 .38932 Mdot
.64 .38934 Mdot
.64 .38952 Mdot
.64 .38953 Mdot
.64 .3896 Mdot
.64 .38967 Mdot
.64 .38972 Mdot
.64 .38975 Mdot
.64 .38978 Mdot
.64 .38985 Mdot
.64 .38987 Mdot
.64 .38994 Mdot
.64 .39011 Mdot
.64 .39012 Mdot
.64 .39022 Mdot
.64 .39029 Mdot
.64 .39031 Mdot
.64 .39033 Mdot
.64 .39036 Mdot
.64 .39042 Mdot
.64 .39045 Mdot
.64 .39053 Mdot
.64 .39054 Mdot
.64 .39059 Mdot
.64 .39065 Mdot
.64 .39067 Mdot
.64 .39069 Mdot
.64 .39071 Mdot
.64 .39075 Mdot
.64 .39082 Mdot
.64 .39086 Mdot
.64 .39093 Mdot
.64 .39103 Mdot
.64 .39103 Mdot
.64 .39105 Mdot
.64 .39106 Mdot
.64 .39115 Mdot
.64 .39119 Mdot
.64 .39119 Mdot
.64 .39124 Mdot
.64 .39124 Mdot
.64 .39125 Mdot
.64 .39137 Mdot
.64 .3914 Mdot
.64 .39143 Mdot
.64 .39149 Mdot
.64 .39158 Mdot
.64 .39161 Mdot
.64 .39163 Mdot
.64 .39169 Mdot
.64 .39169 Mdot
.64 .3917 Mdot
.64 .39182 Mdot
.64 .39183 Mdot
.64 .39183 Mdot
.64 .39185 Mdot
.64 .39188 Mdot
.64 .392 Mdot
.64 .392 Mdot
.64 .39205 Mdot
.64 .39208 Mdot
.64 .39209 Mdot
.64 .39222 Mdot
.64 .39222 Mdot
.64 .39223 Mdot
.642 .28599 Mdot
.642 .286 Mdot
.642 .28601 Mdot
.642 .28603 Mdot
.642 .28614 Mdot
.642 .28615 Mdot
.642 .28618 Mdot
.642 .28619 Mdot
.642 .28624 Mdot
.642 .28625 Mdot
.642 .28636 Mdot
.642 .28653 Mdot
.642 .28656 Mdot
.642 .28659 Mdot
.642 .28661 Mdot
.642 .28677 Mdot
.642 .28677 Mdot
.642 .28691 Mdot
.642 .28692 Mdot
.642 .28696 Mdot
.642 .28707 Mdot
.642 .28707 Mdot
.642 .2871 Mdot
.642 .28712 Mdot
.642 .28713 Mdot
.642 .28735 Mdot
.642 .28739 Mdot
.642 .28739 Mdot
.642 .28753 Mdot
.642 .28755 Mdot
.642 .28757 Mdot
.642 .28761 Mdot
.642 .28762 Mdot
.642 .2877 Mdot
.642 .28773 Mdot
.642 .28787 Mdot
.642 .28788 Mdot
.642 .28793 Mdot
.642 .28803 Mdot
.642 .28805 Mdot
.642 .28805 Mdot
.642 .28812 Mdot
.642 .28814 Mdot
.642 .28816 Mdot
.642 .28818 Mdot
.642 .28819 Mdot
.642 .28824 Mdot
.642 .28842 Mdot
.642 .28842 Mdot
.642 .28852 Mdot
.642 .28859 Mdot
.642 .28861 Mdot
.642 .28865 Mdot
.642 .28869 Mdot
.642 .28887 Mdot
.642 .2891 Mdot
.642 .2891 Mdot
.642 .28915 Mdot
.642 .28917 Mdot
.642 .28927 Mdot
.642 .28936 Mdot
.642 .28945 Mdot
.642 .28945 Mdot
.642 .28948 Mdot
.642 .28954 Mdot
.642 .28966 Mdot
.642 .28969 Mdot
.642 .28982 Mdot
.642 .28982 Mdot
.642 .29006 Mdot
.642 .29029 Mdot
.642 .29041 Mdot
.642 .29047 Mdot
.642 .29054 Mdot
.642 .29065 Mdot
.642 .29082 Mdot
.642 .29083 Mdot
.642 .29083 Mdot
.642 .29085 Mdot
.642 .29085 Mdot
.642 .29093 Mdot
.642 .29104 Mdot
.642 .29116 Mdot
.642 .29121 Mdot
.642 .29126 Mdot
.642 .29129 Mdot
.642 .29131 Mdot
.642 .29134 Mdot
.642 .29134 Mdot
.642 .29135 Mdot
.642 .29139 Mdot
.642 .29151 Mdot
.642 .29152 Mdot
.642 .29156 Mdot
.642 .2917 Mdot
.642 .2917 Mdot
.642 .29179 Mdot
.642 .29181 Mdot
.642 .29192 Mdot
.642 .29196 Mdot
.642 .29199 Mdot
.642 .29202 Mdot
.642 .29204 Mdot
.642 .29225 Mdot
.642 .29249 Mdot
.642 .29249 Mdot
.642 .29255 Mdot
.642 .29256 Mdot
.642 .29256 Mdot
.642 .29258 Mdot
.642 .29271 Mdot
.642 .29281 Mdot
.642 .29282 Mdot
.642 .29282 Mdot
.642 .29284 Mdot
.642 .29305 Mdot
.642 .29309 Mdot
.642 .2931 Mdot
.642 .29319 Mdot
.642 .2932 Mdot
.642 .2932 Mdot
.642 .29325 Mdot
.642 .29326 Mdot
.642 .29327 Mdot
.642 .29328 Mdot
.642 .29328 Mdot
.642 .29333 Mdot
.642 .29338 Mdot
.642 .29342 Mdot
.642 .29344 Mdot
.642 .29345 Mdot
.642 .29365 Mdot
.642 .29403 Mdot
.642 .29406 Mdot
.642 .29409 Mdot
.642 .29445 Mdot
.642 .29447 Mdot
.642 .29448 Mdot
.642 .29454 Mdot
.642 .29466 Mdot
.642 .29472 Mdot
.642 .29481 Mdot
.642 .29489 Mdot
.642 .29489 Mdot
.642 .295 Mdot
.642 .29514 Mdot
.642 .29522 Mdot
.642 .2953 Mdot
.642 .2953 Mdot
.642 .29536 Mdot
.642 .29537 Mdot
.642 .2955 Mdot
.642 .29551 Mdot
.642 .29558 Mdot
.642 .29558 Mdot
.642 .29566 Mdot
.642 .29589 Mdot
.642 .29589 Mdot
.642 .29599 Mdot
.642 .29609 Mdot
.642 .2961 Mdot
.642 .29625 Mdot
.642 .29628 Mdot
.642 .29636 Mdot
.642 .29644 Mdot
.642 .29646 Mdot
.642 .29654 Mdot
.642 .29657 Mdot
.642 .29657 Mdot
.642 .29658 Mdot
.642 .2966 Mdot
.642 .29666 Mdot
.642 .29679 Mdot
.642 .29692 Mdot
.642 .29708 Mdot
.642 .29724 Mdot
.642 .2974 Mdot
.642 .2974 Mdot
.642 .29749 Mdot
.642 .29752 Mdot
.642 .29769 Mdot
.642 .29771 Mdot
.642 .29781 Mdot
.642 .2979 Mdot
.642 .29791 Mdot
.642 .29795 Mdot
.642 .29797 Mdot
.642 .298 Mdot
.642 .29825 Mdot
.642 .29827 Mdot
.642 .29842 Mdot
.642 .29844 Mdot
.642 .29866 Mdot
.642 .29875 Mdot
.642 .2988 Mdot
.642 .29894 Mdot
.642 .29894 Mdot
.642 .29907 Mdot
.642 .29908 Mdot
.642 .29911 Mdot
.642 .29919 Mdot
.642 .2992 Mdot
.642 .29943 Mdot
.642 .29949 Mdot
.642 .29981 Mdot
.642 .29987 Mdot
.642 .30001 Mdot
.642 .30006 Mdot
.642 .30015 Mdot
.642 .30038 Mdot
.642 .3004 Mdot
.642 .30059 Mdot
.642 .3006 Mdot
.642 .30067 Mdot
.642 .30067 Mdot
.642 .3007 Mdot
.642 .3007 Mdot
.642 .30074 Mdot
.642 .30074 Mdot
.642 .30078 Mdot
.642 .30079 Mdot
.642 .3009 Mdot
.642 .30092 Mdot
.642 .30105 Mdot
.642 .30114 Mdot
.642 .30123 Mdot
.642 .30126 Mdot
.642 .30145 Mdot
.642 .30163 Mdot
.642 .30164 Mdot
.642 .3017 Mdot
.642 .30171 Mdot
.642 .30179 Mdot
.642 .30188 Mdot
.642 .30196 Mdot
.642 .3021 Mdot
.642 .3022 Mdot
.642 .30221 Mdot
.642 .30248 Mdot
.642 .30253 Mdot
.642 .30265 Mdot
.642 .30267 Mdot
.642 .30272 Mdot
.642 .30282 Mdot
.642 .30321 Mdot
.642 .30322 Mdot
.642 .3033 Mdot
.642 .30336 Mdot
.642 .30341 Mdot
.642 .30342 Mdot
.642 .30364 Mdot
.642 .30364 Mdot
.642 .30378 Mdot
.642 .30387 Mdot
.642 .30388 Mdot
.642 .30396 Mdot
.642 .304 Mdot
.642 .30405 Mdot
.642 .30409 Mdot
.642 .30424 Mdot
.642 .30446 Mdot
.642 .30449 Mdot
.642 .3045 Mdot
.642 .30451 Mdot
.642 .30475 Mdot
.642 .30477 Mdot
.642 .305 Mdot
.642 .30514 Mdot
.642 .30516 Mdot
.642 .30519 Mdot
.642 .30522 Mdot
.642 .30523 Mdot
.642 .30527 Mdot
.642 .30528 Mdot
.642 .30533 Mdot
.642 .30534 Mdot
.642 .30536 Mdot
.642 .3055 Mdot
.642 .3055 Mdot
.642 .30551 Mdot
.642 .30557 Mdot
.642 .30566 Mdot
.642 .3057 Mdot
.642 .30584 Mdot
.642 .30597 Mdot
.642 .30599 Mdot
.642 .30601 Mdot
.642 .30602 Mdot
.642 .30618 Mdot
.642 .30618 Mdot
.642 .3064 Mdot
.642 .30645 Mdot
.642 .30648 Mdot
.642 .3067 Mdot
.642 .30671 Mdot
.642 .30672 Mdot
.642 .30682 Mdot
.642 .30688 Mdot
.642 .30693 Mdot
.642 .30697 Mdot
.642 .30718 Mdot
.642 .30732 Mdot
.642 .30732 Mdot
.642 .3074 Mdot
.642 .30742 Mdot
.642 .30749 Mdot
.642 .30753 Mdot
.642 .30754 Mdot
.642 .30755 Mdot
.642 .3076 Mdot
.642 .30773 Mdot
.642 .30776 Mdot
.642 .3079 Mdot
.642 .30801 Mdot
.642 .30803 Mdot
.642 .30806 Mdot
.642 .30807 Mdot
.642 .30811 Mdot
.642 .30817 Mdot
.642 .30817 Mdot
.642 .30832 Mdot
.642 .30834 Mdot
.642 .30847 Mdot
.642 .3085 Mdot
.642 .30859 Mdot
.642 .30861 Mdot
.642 .30866 Mdot
.642 .30866 Mdot
.642 .30899 Mdot
.642 .30899 Mdot
.642 .30905 Mdot
.642 .30917 Mdot
.642 .30917 Mdot
.642 .3093 Mdot
.642 .30932 Mdot
.642 .30942 Mdot
.642 .30949 Mdot
.642 .30952 Mdot
.642 .30953 Mdot
.642 .30955 Mdot
.642 .30955 Mdot
.642 .30963 Mdot
.642 .30964 Mdot
.642 .30964 Mdot
.642 .30977 Mdot
.642 .3099 Mdot
.642 .31011 Mdot
.642 .31013 Mdot
.642 .31031 Mdot
.642 .31031 Mdot
.642 .31042 Mdot
.642 .31043 Mdot
.642 .31044 Mdot
.642 .31057 Mdot
.642 .3106 Mdot
.642 .3106 Mdot
.642 .31068 Mdot
.642 .31069 Mdot
.642 .31071 Mdot
.642 .31089 Mdot
.642 .31099 Mdot
.642 .311 Mdot
.642 .311 Mdot
.642 .31104 Mdot
.642 .31106 Mdot
.642 .31108 Mdot
.642 .31111 Mdot
.642 .31164 Mdot
.642 .31168 Mdot
.642 .31174 Mdot
.642 .31236 Mdot
.642 .31269 Mdot
.642 .3127 Mdot
.642 .31274 Mdot
.642 .31281 Mdot
.642 .31288 Mdot
.642 .31296 Mdot
.642 .31297 Mdot
.642 .31299 Mdot
.642 .313 Mdot
.642 .31302 Mdot
.642 .3131 Mdot
.642 .3131 Mdot
.642 .31312 Mdot
.642 .31327 Mdot
.642 .31328 Mdot
.642 .31334 Mdot
.642 .31369 Mdot
.642 .31373 Mdot
.642 .31374 Mdot
.642 .31375 Mdot
.642 .31391 Mdot
.642 .31412 Mdot
.642 .31415 Mdot
.642 .31416 Mdot
.642 .31417 Mdot
.642 .31427 Mdot
.642 .31427 Mdot
.642 .31466 Mdot
.642 .31501 Mdot
.642 .31504 Mdot
.642 .3151 Mdot
.642 .31515 Mdot
.642 .31522 Mdot
.642 .3154 Mdot
.642 .31543 Mdot
.642 .31557 Mdot
.642 .31557 Mdot
.642 .31581 Mdot
.642 .31587 Mdot
.642 .31588 Mdot
.642 .31609 Mdot
.642 .31615 Mdot
.642 .31617 Mdot
.642 .31617 Mdot
.642 .31622 Mdot
.642 .3163 Mdot
.642 .31638 Mdot
.642 .31647 Mdot
.642 .31667 Mdot
.642 .31684 Mdot
.642 .31697 Mdot
.642 .31698 Mdot
.642 .317 Mdot
.642 .31702 Mdot
.642 .31703 Mdot
.642 .3173 Mdot
.642 .31749 Mdot
.642 .3176 Mdot
.642 .31771 Mdot
.642 .3179 Mdot
.642 .31828 Mdot
.642 .31867 Mdot
.642 .31867 Mdot
.642 .31888 Mdot
.642 .31894 Mdot
.642 .31913 Mdot
.642 .31924 Mdot
.642 .31928 Mdot
.642 .31928 Mdot
.642 .31943 Mdot
.642 .31958 Mdot
.642 .31975 Mdot
.642 .31978 Mdot
.642 .31985 Mdot
.642 .31986 Mdot
.642 .32024 Mdot
.642 .32054 Mdot
.642 .3206 Mdot
.642 .32067 Mdot
.642 .3207 Mdot
.642 .32082 Mdot
.642 .32097 Mdot
.642 .32098 Mdot
.642 .32128 Mdot
.642 .32136 Mdot
.642 .32138 Mdot
.642 .32141 Mdot
.642 .32145 Mdot
.642 .32148 Mdot
.642 .32158 Mdot
.642 .32159 Mdot
.642 .32162 Mdot
.642 .32179 Mdot
.642 .32188 Mdot
.642 .32189 Mdot
.642 .32213 Mdot
.642 .32217 Mdot
.642 .32231 Mdot
.642 .32232 Mdot
.642 .32238 Mdot
.642 .32242 Mdot
.642 .32245 Mdot
.642 .32269 Mdot
.642 .32269 Mdot
.642 .32275 Mdot
.642 .3231 Mdot
.642 .32313 Mdot
.642 .32317 Mdot
.642 .3232 Mdot
.642 .3232 Mdot
.642 .32338 Mdot
.642 .32346 Mdot
.642 .32347 Mdot
.642 .3237 Mdot
.642 .3237 Mdot
.642 .32396 Mdot
.642 .324 Mdot
.642 .32404 Mdot
.642 .3241 Mdot
.642 .32438 Mdot
.642 .32457 Mdot
.642 .32457 Mdot
.642 .32466 Mdot
.642 .32467 Mdot
.642 .32473 Mdot
.642 .32474 Mdot
.642 .32492 Mdot
.642 .32496 Mdot
.642 .32497 Mdot
.642 .32499 Mdot
.642 .36303 Mdot
.642 .36305 Mdot
.642 .36306 Mdot
.642 .36309 Mdot
.642 .36322 Mdot
.642 .36324 Mdot
.642 .36328 Mdot
.642 .36329 Mdot
.642 .36336 Mdot
.642 .36336 Mdot
.642 .36351 Mdot
.642 .36373 Mdot
.642 .36377 Mdot
.642 .3638 Mdot
.642 .36383 Mdot
.642 .36404 Mdot
.642 .36404 Mdot
.642 .36422 Mdot
.642 .36422 Mdot
.642 .36428 Mdot
.642 .36442 Mdot
.642 .36442 Mdot
.642 .36445 Mdot
.642 .36448 Mdot
.642 .3645 Mdot
.642 .36478 Mdot
.642 .36482 Mdot
.642 .36483 Mdot
.642 .36501 Mdot
.642 .36503 Mdot
.642 .36506 Mdot
.642 .36511 Mdot
.642 .36512 Mdot
.642 .36522 Mdot
.642 .36526 Mdot
.642 .36545 Mdot
.642 .36546 Mdot
.642 .36552 Mdot
.642 .36565 Mdot
.642 .36568 Mdot
.642 .36568 Mdot
.642 .36576 Mdot
.642 .36579 Mdot
.642 .36582 Mdot
.642 .36584 Mdot
.642 .36585 Mdot
.642 .36592 Mdot
.642 .36615 Mdot
.642 .36616 Mdot
.642 .36628 Mdot
.642 .36637 Mdot
.642 .3664 Mdot
.642 .36645 Mdot
.642 .3665 Mdot
.642 .36673 Mdot
.642 .36702 Mdot
.642 .36703 Mdot
.642 .36709 Mdot
.642 .36711 Mdot
.642 .36724 Mdot
.642 .36736 Mdot
.642 .36748 Mdot
.642 .36748 Mdot
.642 .36751 Mdot
.642 .3676 Mdot
.642 .36774 Mdot
.642 .36779 Mdot
.642 .36795 Mdot
.642 .36795 Mdot
.642 .36825 Mdot
.642 .36855 Mdot
.642 .3687 Mdot
.642 .36878 Mdot
.642 .36887 Mdot
.642 .36902 Mdot
.642 .36923 Mdot
.642 .36924 Mdot
.642 .36925 Mdot
.642 .36927 Mdot
.642 .36928 Mdot
.642 .36937 Mdot
.642 .36951 Mdot
.642 .36966 Mdot
.642 .36974 Mdot
.642 .3698 Mdot
.642 .36986 Mdot
.642 .3699 Mdot
.642 .3699 Mdot
.642 .36992 Mdot
.642 .36996 Mdot
.642 .37012 Mdot
.642 .37013 Mdot
.642 .37018 Mdot
.642 .37037 Mdot
.642 .37037 Mdot
.642 .37048 Mdot
.642 .3705 Mdot
.642 .37064 Mdot
.642 .3707 Mdot
.642 .37073 Mdot
.642 .37078 Mdot
.642 .3708 Mdot
.642 .37108 Mdot
.642 .37138 Mdot
.642 .37138 Mdot
.642 .37146 Mdot
.642 .37146 Mdot
.642 .37147 Mdot
.642 .37149 Mdot
.642 .37166 Mdot
.642 .37179 Mdot
.642 .3718 Mdot
.642 .3718 Mdot
.642 .37183 Mdot
.642 .3721 Mdot
.642 .37215 Mdot
.642 .37216 Mdot
.642 .37227 Mdot
.642 .37229 Mdot
.642 .37229 Mdot
.642 .37235 Mdot
.642 .37237 Mdot
.642 .37237 Mdot
.642 .37239 Mdot
.642 .3724 Mdot
.642 .37246 Mdot
.642 .37252 Mdot
.642 .37257 Mdot
.642 .3726 Mdot
.642 .37261 Mdot
.642 .37287 Mdot
.642 .37335 Mdot
.642 .3734 Mdot
.642 .37343 Mdot
.642 .37384 Mdot
.642 .37386 Mdot
.642 .37388 Mdot
.642 .3739 Mdot
.642 .37393 Mdot
.642 .37393 Mdot
.642 .37394 Mdot
.642 .37401 Mdot
.642 .37415 Mdot
.642 .37417 Mdot
.642 .37417 Mdot
.642 .37424 Mdot
.642 .37424 Mdot
.642 .37426 Mdot
.642 .37436 Mdot
.642 .37437 Mdot
.642 .37438 Mdot
.642 .37446 Mdot
.642 .37447 Mdot
.642 .37461 Mdot
.642 .37462 Mdot
.642 .37478 Mdot
.642 .37488 Mdot
.642 .37498 Mdot
.642 .37499 Mdot
.642 .37499 Mdot
.642 .37505 Mdot
.642 .37506 Mdot
.642 .37507 Mdot
.642 .3751 Mdot
.642 .37516 Mdot
.642 .37524 Mdot
.642 .37525 Mdot
.642 .37535 Mdot
.642 .37535 Mdot
.642 .37544 Mdot
.642 .37549 Mdot
.642 .37549 Mdot
.642 .37575 Mdot
.642 .37575 Mdot
.642 .37579 Mdot
.642 .3758 Mdot
.642 .37587 Mdot
.642 .3759 Mdot
.642 .376 Mdot
.642 .37602 Mdot
.642 .37613 Mdot
.642 .37613 Mdot
.642 .37618 Mdot
.642 .37621 Mdot
.642 .37622 Mdot
.642 .37624 Mdot
.642 .37626 Mdot
.642 .37634 Mdot
.642 .37645 Mdot
.642 .37647 Mdot
.642 .37657 Mdot
.642 .37662 Mdot
.642 .37662 Mdot
.642 .37663 Mdot
.642 .37666 Mdot
.642 .37672 Mdot
.642 .37673 Mdot
.642 .37679 Mdot
.642 .37679 Mdot
.642 .3769 Mdot
.642 .37707 Mdot
.642 .3771 Mdot
.642 .37713 Mdot
.642 .37718 Mdot
.642 .37726 Mdot
.642 .37727 Mdot
.642 .37728 Mdot
.642 .37745 Mdot
.642 .37747 Mdot
.642 .37751 Mdot
.642 .37768 Mdot
.642 .37768 Mdot
.642 .3778 Mdot
.642 .37782 Mdot
.642 .37783 Mdot
.642 .37784 Mdot
.642 .37794 Mdot
.642 .37805 Mdot
.642 .37808 Mdot
.642 .37816 Mdot
.642 .3782 Mdot
.642 .37821 Mdot
.642 .37821 Mdot
.642 .37832 Mdot
.642 .37834 Mdot
.642 .37834 Mdot
.642 .37838 Mdot
.642 .37839 Mdot
.642 .37842 Mdot
.642 .37843 Mdot
.642 .37845 Mdot
.642 .37847 Mdot
.642 .37849 Mdot
.642 .3786 Mdot
.642 .37878 Mdot
.642 .3788 Mdot
.642 .37898 Mdot
.642 .37899 Mdot
.642 .37899 Mdot
.642 .37902 Mdot
.642 .37919 Mdot
.642 .3793 Mdot
.642 .37934 Mdot
.642 .37938 Mdot
.642 .37941 Mdot
.642 .37947 Mdot
.642 .37948 Mdot
.642 .37955 Mdot
.642 .37966 Mdot
.642 .37966 Mdot
.642 .37983 Mdot
.642 .37984 Mdot
.642 .37988 Mdot
.642 .37993 Mdot
.642 .37998 Mdot
.642 .38 Mdot
.642 .38029 Mdot
.642 .38037 Mdot
.642 .38042 Mdot
.642 .38043 Mdot
.642 .38052 Mdot
.642 .38056 Mdot
.642 .38078 Mdot
.642 .38078 Mdot
.642 .38085 Mdot
.642 .38097 Mdot
.642 .38103 Mdot
.642 .3811 Mdot
.642 .38116 Mdot
.642 .38117 Mdot
.642 .38122 Mdot
.642 .38122 Mdot
.642 .38136 Mdot
.642 .38151 Mdot
.642 .38154 Mdot
.642 .3816 Mdot
.642 .38167 Mdot
.642 .38178 Mdot
.642 .38179 Mdot
.642 .38188 Mdot
.642 .38188 Mdot
.642 .38192 Mdot
.642 .38192 Mdot
.642 .38195 Mdot
.642 .38195 Mdot
.642 .38197 Mdot
.642 .38197 Mdot
.642 .38203 Mdot
.642 .38203 Mdot
.642 .38218 Mdot
.642 .3822 Mdot
.642 .38237 Mdot
.642 .38245 Mdot
.642 .38249 Mdot
.642 .38259 Mdot
.642 .38264 Mdot
.642 .38289 Mdot
.642 .38293 Mdot
.642 .38311 Mdot
.642 .38312 Mdot
.642 .38319 Mdot
.642 .38321 Mdot
.642 .38322 Mdot
.642 .38332 Mdot
.642 .38332 Mdot
.642 .38343 Mdot
.642 .38347 Mdot
.642 .38353 Mdot
.642 .38371 Mdot
.642 .38372 Mdot
.642 .38384 Mdot
.642 .38385 Mdot
.642 .38405 Mdot
.642 .38407 Mdot
.642 .38409 Mdot
.642 .38412 Mdot
.642 .38413 Mdot
.642 .3842 Mdot
.642 .38428 Mdot
.642 .38429 Mdot
.642 .38442 Mdot
.642 .38445 Mdot
.642 .38452 Mdot
.642 .38452 Mdot
.642 .38465 Mdot
.642 .38477 Mdot
.642 .38489 Mdot
.642 .38499 Mdot
.642 .3851 Mdot
.642 .38514 Mdot
.642 .38516 Mdot
.642 .38516 Mdot
.642 .38516 Mdot
.642 .38519 Mdot
.642 .38525 Mdot
.642 .38527 Mdot
.642 .38533 Mdot
.642 .38539 Mdot
.642 .38541 Mdot
.642 .38553 Mdot
.642 .38554 Mdot
.642 .38562 Mdot
.642 .38569 Mdot
.642 .38569 Mdot
.642 .38588 Mdot
.642 .38593 Mdot
.642 .38593 Mdot
.642 .38599 Mdot
.642 .386 Mdot
.642 .3861 Mdot
.642 .38611 Mdot
.642 .38615 Mdot
.642 .38615 Mdot
.642 .38622 Mdot
.642 .38628 Mdot
.642 .38638 Mdot
.642 .38647 Mdot
.642 .38647 Mdot
.642 .38653 Mdot
.642 .38661 Mdot
.642 .38665 Mdot
.642 .38675 Mdot
.642 .38679 Mdot
.642 .3868 Mdot
.642 .38681 Mdot
.642 .3871 Mdot
.642 .38712 Mdot
.642 .38715 Mdot
.642 .38744 Mdot
.642 .38759 Mdot
.642 .3876 Mdot
.642 .38762 Mdot
.642 .38765 Mdot
.642 .38769 Mdot
.642 .38772 Mdot
.642 .38773 Mdot
.642 .38774 Mdot
.642 .38774 Mdot
.642 .38775 Mdot
.642 .38779 Mdot
.642 .38779 Mdot
.642 .3878 Mdot
.642 .38787 Mdot
.642 .38787 Mdot
.642 .3879 Mdot
.642 .38807 Mdot
.642 .38809 Mdot
.642 .38809 Mdot
.642 .38809 Mdot
.642 .38817 Mdot
.642 .38827 Mdot
.642 .38828 Mdot
.642 .38829 Mdot
.642 .38829 Mdot
.642 .38834 Mdot
.642 .38834 Mdot
.642 .38853 Mdot
.642 .38869 Mdot
.642 .38871 Mdot
.642 .38873 Mdot
.642 .38876 Mdot
.642 .38879 Mdot
.642 .38887 Mdot
.642 .38889 Mdot
.642 .38895 Mdot
.642 .38895 Mdot
.642 .38907 Mdot
.642 .3891 Mdot
.642 .3891 Mdot
.642 .3892 Mdot
.642 .38923 Mdot
.642 .38924 Mdot
.642 .38924 Mdot
.642 .38926 Mdot
.642 .38928 Mdot
.642 .3893 Mdot
.642 .38934 Mdot
.642 .38938 Mdot
.642 .38947 Mdot
.642 .38956 Mdot
.642 .38962 Mdot
.642 .38962 Mdot
.642 .38963 Mdot
.642 .38964 Mdot
.642 .38965 Mdot
.642 .38977 Mdot
.642 .38986 Mdot
.642 .38992 Mdot
.642 .38996 Mdot
.642 .39006 Mdot
.642 .39024 Mdot
.642 .39042 Mdot
.642 .39042 Mdot
.642 .39052 Mdot
.642 .39055 Mdot
.642 .39064 Mdot
.642 .39069 Mdot
.642 .39071 Mdot
.642 .39071 Mdot
.642 .39078 Mdot
.642 .39085 Mdot
.642 .39093 Mdot
.642 .39095 Mdot
.642 .39098 Mdot
.642 .39098 Mdot
.642 .39116 Mdot
.642 .3913 Mdot
.642 .39133 Mdot
.642 .39136 Mdot
.642 .39138 Mdot
.642 .39144 Mdot
.642 .39151 Mdot
.642 .39151 Mdot
.642 .39165 Mdot
.642 .39169 Mdot
.642 .3917 Mdot
.642 .39172 Mdot
.642 .39173 Mdot
.642 .39175 Mdot
.642 .3918 Mdot
.642 .3918 Mdot
.642 .39181 Mdot
.642 .39189 Mdot
.642 .39193 Mdot
.642 .39194 Mdot
.642 .39205 Mdot
.642 .39208 Mdot
.642 .39214 Mdot
.642 .39214 Mdot
.642 .39217 Mdot
.642 .39219 Mdot
.642 .3922 Mdot
.642 .39232 Mdot
.642 .39232 Mdot
.642 .39235 Mdot
.642 .39251 Mdot
.642 .39253 Mdot
.642 .39254 Mdot
.642 .39256 Mdot
.642 .39256 Mdot
.642 .39265 Mdot
.642 .39268 Mdot
.642 .39269 Mdot
.642 .39279 Mdot
.642 .39279 Mdot
.642 .39292 Mdot
.642 .39294 Mdot
.642 .39296 Mdot
.642 .39298 Mdot
.642 .39312 Mdot
.642 .3932 Mdot
.642 .39321 Mdot
.642 .39325 Mdot
.642 .39326 Mdot
.642 .39328 Mdot
.642 .39329 Mdot
.642 .39337 Mdot
.642 .39339 Mdot
.642 .39339 Mdot
.642 .3934 Mdot
.644 .28529 Mdot
.644 .28533 Mdot
.644 .28543 Mdot
.644 .28543 Mdot
.644 .28547 Mdot
.644 .2855 Mdot
.644 .28556 Mdot
.644 .2857 Mdot
.644 .28574 Mdot
.644 .28575 Mdot
.644 .28587 Mdot
.644 .28589 Mdot
.644 .28592 Mdot
.644 .28596 Mdot
.644 .28599 Mdot
.644 .286 Mdot
.644 .28601 Mdot
.644 .28604 Mdot
.644 .2861 Mdot
.644 .28617 Mdot
.644 .2862 Mdot
.644 .28626 Mdot
.644 .2864 Mdot
.644 .28647 Mdot
.644 .28651 Mdot
.644 .28659 Mdot
.644 .2866 Mdot
.644 .2866 Mdot
.644 .28664 Mdot
.644 .28668 Mdot
.644 .28678 Mdot
.644 .28688 Mdot
.644 .287 Mdot
.644 .28708 Mdot
.644 .28711 Mdot
.644 .28723 Mdot
.644 .28723 Mdot
.644 .2873 Mdot
.644 .28741 Mdot
.644 .28746 Mdot
.644 .28751 Mdot
.644 .28757 Mdot
.644 .28764 Mdot
.644 .28766 Mdot
.644 .28767 Mdot
.644 .28769 Mdot
.644 .2877 Mdot
.644 .28772 Mdot
.644 .28776 Mdot
.644 .28779 Mdot
.644 .28789 Mdot
.644 .2879 Mdot
.644 .28792 Mdot
.644 .28796 Mdot
.644 .28797 Mdot
.644 .28808 Mdot
.644 .2881 Mdot
.644 .28811 Mdot
.644 .28813 Mdot
.644 .28853 Mdot
.644 .28856 Mdot
.644 .28862 Mdot
.644 .28862 Mdot
.644 .28867 Mdot
.644 .28872 Mdot
.644 .28883 Mdot
.644 .28885 Mdot
.644 .28892 Mdot
.644 .289 Mdot
.644 .28901 Mdot
.644 .28918 Mdot
.644 .28931 Mdot
.644 .28951 Mdot
.644 .28954 Mdot
.644 .28968 Mdot
.644 .28978 Mdot
.644 .2898 Mdot
.644 .28988 Mdot
.644 .28991 Mdot
.644 .29001 Mdot
.644 .29003 Mdot
.644 .29019 Mdot
.644 .29025 Mdot
.644 .29031 Mdot
.644 .29052 Mdot
.644 .29056 Mdot
.644 .29056 Mdot
.644 .29056 Mdot
.644 .29059 Mdot
.644 .29068 Mdot
.644 .29072 Mdot
.644 .29076 Mdot
.644 .29079 Mdot
.644 .29092 Mdot
.644 .29107 Mdot
.644 .29109 Mdot
.644 .29125 Mdot
.644 .29131 Mdot
.644 .29143 Mdot
.644 .29145 Mdot
.644 .29148 Mdot
.644 .29151 Mdot
.644 .29152 Mdot
.644 .29165 Mdot
.644 .29168 Mdot
.644 .29171 Mdot
.644 .29173 Mdot
.644 .29174 Mdot
.644 .29178 Mdot
.644 .29186 Mdot
.644 .29187 Mdot
.644 .29195 Mdot
.644 .29202 Mdot
.644 .29209 Mdot
.644 .29215 Mdot
.644 .29227 Mdot
.644 .29246 Mdot
.644 .29253 Mdot
.644 .29257 Mdot
.644 .2926 Mdot
.644 .29268 Mdot
.644 .29269 Mdot
.644 .29274 Mdot
.644 .29282 Mdot
.644 .29283 Mdot
.644 .29294 Mdot
.644 .29301 Mdot
.644 .2931 Mdot
.644 .29313 Mdot
.644 .2933 Mdot
.644 .29333 Mdot
.644 .29347 Mdot
.644 .29351 Mdot
.644 .29361 Mdot
.644 .29363 Mdot
.644 .29364 Mdot
.644 .2937 Mdot
.644 .29371 Mdot
.644 .29372 Mdot
.644 .29389 Mdot
.644 .29395 Mdot
.644 .29396 Mdot
.644 .29406 Mdot
.644 .29407 Mdot
.644 .2941 Mdot
.644 .29414 Mdot
.644 .29422 Mdot
.644 .29422 Mdot
.644 .2943 Mdot
.644 .29445 Mdot
.644 .29445 Mdot
.644 .2945 Mdot
.644 .29457 Mdot
.644 .29459 Mdot
.644 .29466 Mdot
.644 .29467 Mdot
.644 .29468 Mdot
.644 .2947 Mdot
.644 .29476 Mdot
.644 .29486 Mdot
.644 .29492 Mdot
.644 .29524 Mdot
.644 .29541 Mdot
.644 .29544 Mdot
.644 .29562 Mdot
.644 .29574 Mdot
.644 .29585 Mdot
.644 .29588 Mdot
.644 .29592 Mdot
.644 .29632 Mdot
.644 .2965 Mdot
.644 .29661 Mdot
.644 .29664 Mdot
.644 .29669 Mdot
.644 .29675 Mdot
.644 .29687 Mdot
.644 .29688 Mdot
.644 .29693 Mdot
.644 .29694 Mdot
.644 .29697 Mdot
.644 .29713 Mdot
.644 .29723 Mdot
.644 .29723 Mdot
.644 .2973 Mdot
.644 .29731 Mdot
.644 .29731 Mdot
.644 .29739 Mdot
.644 .29741 Mdot
.644 .29751 Mdot
.644 .29765 Mdot
.644 .29771 Mdot
.644 .29789 Mdot
.644 .29796 Mdot
.644 .298 Mdot
.644 .29817 Mdot
.644 .29821 Mdot
.644 .2983 Mdot
.644 .29832 Mdot
.644 .29838 Mdot
.644 .29866 Mdot
.644 .29872 Mdot
.644 .29877 Mdot
.644 .29882 Mdot
.644 .29908 Mdot
.644 .29918 Mdot
.644 .29931 Mdot
.644 .29941 Mdot
.644 .29946 Mdot
.644 .29947 Mdot
.644 .29948 Mdot
.644 .29967 Mdot
.644 .29972 Mdot
.644 .30006 Mdot
.644 .30012 Mdot
.644 .30019 Mdot
.644 .30075 Mdot
.644 .30099 Mdot
.644 .3011 Mdot
.644 .30112 Mdot
.644 .30121 Mdot
.644 .30156 Mdot
.644 .3016 Mdot
.644 .30177 Mdot
.644 .30182 Mdot
.644 .30187 Mdot
.644 .30202 Mdot
.644 .30206 Mdot
.644 .30217 Mdot
.644 .30221 Mdot
.644 .3023 Mdot
.644 .30237 Mdot
.644 .30246 Mdot
.644 .30252 Mdot
.644 .30264 Mdot
.644 .30264 Mdot
.644 .30267 Mdot
.644 .30282 Mdot
.644 .30284 Mdot
.644 .3029 Mdot
.644 .30328 Mdot
.644 .30336 Mdot
.644 .30343 Mdot
.644 .30354 Mdot
.644 .304 Mdot
.644 .30401 Mdot
.644 .30405 Mdot
.644 .30406 Mdot
.644 .30411 Mdot
.644 .30414 Mdot
.644 .30414 Mdot
.644 .30428 Mdot
.644 .30435 Mdot
.644 .30444 Mdot
.644 .30447 Mdot
.644 .30458 Mdot
.644 .30463 Mdot
.644 .30463 Mdot
.644 .30465 Mdot
.644 .3047 Mdot
.644 .30481 Mdot
.644 .30494 Mdot
.644 .30501 Mdot
.644 .30512 Mdot
.644 .30512 Mdot
.644 .30517 Mdot
.644 .3052 Mdot
.644 .30521 Mdot
.644 .30527 Mdot
.644 .30529 Mdot
.644 .30534 Mdot
.644 .30545 Mdot
.644 .30553 Mdot
.644 .30561 Mdot
.644 .30564 Mdot
.644 .3057 Mdot
.644 .30577 Mdot
.644 .30577 Mdot
.644 .30579 Mdot
.644 .30583 Mdot
.644 .30591 Mdot
.644 .30591 Mdot
.644 .30596 Mdot
.644 .30607 Mdot
.644 .30627 Mdot
.644 .30635 Mdot
.644 .30639 Mdot
.644 .30641 Mdot
.644 .30647 Mdot
.644 .30648 Mdot
.644 .30648 Mdot
.644 .30651 Mdot
.644 .3067 Mdot
.644 .3068 Mdot
.644 .30681 Mdot
.644 .30687 Mdot
.644 .30689 Mdot
.644 .30694 Mdot
.644 .3071 Mdot
.644 .30712 Mdot
.644 .30742 Mdot
.644 .30742 Mdot
.644 .30771 Mdot
.644 .30798 Mdot
.644 .30809 Mdot
.644 .30809 Mdot
.644 .30815 Mdot
.644 .3082 Mdot
.644 .30821 Mdot
.644 .30821 Mdot
.644 .30823 Mdot
.644 .30838 Mdot
.644 .30845 Mdot
.644 .30856 Mdot
.644 .30858 Mdot
.644 .30876 Mdot
.644 .30887 Mdot
.644 .30892 Mdot
.644 .30913 Mdot
.644 .30921 Mdot
.644 .3093 Mdot
.644 .30938 Mdot
.644 .30958 Mdot
.644 .30973 Mdot
.644 .30976 Mdot
.644 .30982 Mdot
.644 .30984 Mdot
.644 .30986 Mdot
.644 .30989 Mdot
.644 .30998 Mdot
.644 .31 Mdot
.644 .31008 Mdot
.644 .31011 Mdot
.644 .31013 Mdot
.644 .31015 Mdot
.644 .31016 Mdot
.644 .31017 Mdot
.644 .31022 Mdot
.644 .31028 Mdot
.644 .31032 Mdot
.644 .31044 Mdot
.644 .31052 Mdot
.644 .31052 Mdot
.644 .31055 Mdot
.644 .31057 Mdot
.644 .31069 Mdot
.644 .31076 Mdot
.644 .3109 Mdot
.644 .3109 Mdot
.644 .31104 Mdot
.644 .31107 Mdot
.644 .31111 Mdot
.644 .31115 Mdot
.644 .31116 Mdot
.644 .31122 Mdot
.644 .31132 Mdot
.644 .31134 Mdot
.644 .31135 Mdot
.644 .31143 Mdot
.644 .31143 Mdot
.644 .31144 Mdot
.644 .3117 Mdot
.644 .31174 Mdot
.644 .31174 Mdot
.644 .31177 Mdot
.644 .3118 Mdot
.644 .31187 Mdot
.644 .31188 Mdot
.644 .31192 Mdot
.644 .31208 Mdot
.644 .31215 Mdot
.644 .31238 Mdot
.644 .31244 Mdot
.644 .31272 Mdot
.644 .31276 Mdot
.644 .31291 Mdot
.644 .31303 Mdot
.644 .31321 Mdot
.644 .31323 Mdot
.644 .31336 Mdot
.644 .31345 Mdot
.644 .31347 Mdot
.644 .31358 Mdot
.644 .31364 Mdot
.644 .3137 Mdot
.644 .31383 Mdot
.644 .31414 Mdot
.644 .31434 Mdot
.644 .31444 Mdot
.644 .31456 Mdot
.644 .31466 Mdot
.644 .3148 Mdot
.644 .31481 Mdot
.644 .31495 Mdot
.644 .31502 Mdot
.644 .31503 Mdot
.644 .31507 Mdot
.644 .31512 Mdot
.644 .31517 Mdot
.644 .31539 Mdot
.644 .3154 Mdot
.644 .31544 Mdot
.644 .3155 Mdot
.644 .31554 Mdot
.644 .31573 Mdot
.644 .31584 Mdot
.644 .3161 Mdot
.644 .31614 Mdot
.644 .31638 Mdot
.644 .3166 Mdot
.644 .31664 Mdot
.644 .31671 Mdot
.644 .31677 Mdot
.644 .31693 Mdot
.644 .31697 Mdot
.644 .31698 Mdot
.644 .31698 Mdot
.644 .31704 Mdot
.644 .3174 Mdot
.644 .3175 Mdot
.644 .31758 Mdot
.644 .31786 Mdot
.644 .31789 Mdot
.644 .31805 Mdot
.644 .31811 Mdot
.644 .31824 Mdot
.644 .31828 Mdot
.644 .31843 Mdot
.644 .31867 Mdot
.644 .31872 Mdot
.644 .31905 Mdot
.644 .31927 Mdot
.644 .31954 Mdot
.644 .31956 Mdot
.644 .3197 Mdot
.644 .31982 Mdot
.644 .31984 Mdot
.644 .32003 Mdot
.644 .32012 Mdot
.644 .32019 Mdot
.644 .32019 Mdot
.644 .3203 Mdot
.644 .32035 Mdot
.644 .32101 Mdot
.644 .32104 Mdot
.644 .32105 Mdot
.644 .3211 Mdot
.644 .32127 Mdot
.644 .3213 Mdot
.644 .32136 Mdot
.644 .32139 Mdot
.644 .3214 Mdot
.644 .32158 Mdot
.644 .32162 Mdot
.644 .32169 Mdot
.644 .32172 Mdot
.644 .32173 Mdot
.644 .32178 Mdot
.644 .32179 Mdot
.644 .32182 Mdot
.644 .32193 Mdot
.644 .32203 Mdot
.644 .32211 Mdot
.644 .32219 Mdot
.644 .32238 Mdot
.644 .3225 Mdot
.644 .32251 Mdot
.644 .3227 Mdot
.644 .32274 Mdot
.644 .32288 Mdot
.644 .32308 Mdot
.644 .32325 Mdot
.644 .32341 Mdot
.644 .32348 Mdot
.644 .32354 Mdot
.644 .32355 Mdot
.644 .32356 Mdot
.644 .32369 Mdot
.644 .32376 Mdot
.644 .32388 Mdot
.644 .3241 Mdot
.644 .3242 Mdot
.644 .32426 Mdot
.644 .32437 Mdot
.644 .32448 Mdot
.644 .32452 Mdot
.644 .32454 Mdot
.644 .32456 Mdot
.644 .32461 Mdot
.644 .32468 Mdot
.644 .32472 Mdot
.644 .32476 Mdot
.644 .32496 Mdot
.644 .32497 Mdot
.644 .32505 Mdot
.644 .32527 Mdot
.644 .32537 Mdot
.644 .32542 Mdot
.644 .32549 Mdot
.644 .32549 Mdot
.644 .32565 Mdot
.644 .32571 Mdot
.644 .36322 Mdot
.644 .36327 Mdot
.644 .36339 Mdot
.644 .36339 Mdot
.644 .36345 Mdot
.644 .36349 Mdot
.644 .36356 Mdot
.644 .36374 Mdot
.644 .36379 Mdot
.644 .36381 Mdot
.644 .36396 Mdot
.644 .36399 Mdot
.644 .36402 Mdot
.644 .36407 Mdot
.644 .36411 Mdot
.644 .36413 Mdot
.644 .36415 Mdot
.644 .36418 Mdot
.644 .36426 Mdot
.644 .36435 Mdot
.644 .36439 Mdot
.644 .36447 Mdot
.644 .36464 Mdot
.644 .36473 Mdot
.644 .36479 Mdot
.644 .36489 Mdot
.644 .3649 Mdot
.644 .36491 Mdot
.644 .36496 Mdot
.644 .36501 Mdot
.644 .36513 Mdot
.644 .36527 Mdot
.644 .36542 Mdot
.644 .36553 Mdot
.644 .36556 Mdot
.644 .36571 Mdot
.644 .36572 Mdot
.644 .36581 Mdot
.644 .36595 Mdot
.644 .36602 Mdot
.644 .36608 Mdot
.644 .36616 Mdot
.644 .36624 Mdot
.644 .36627 Mdot
.644 .36627 Mdot
.644 .36631 Mdot
.644 .36632 Mdot
.644 .36635 Mdot
.644 .3664 Mdot
.644 .36643 Mdot
.644 .36657 Mdot
.644 .36658 Mdot
.644 .3666 Mdot
.644 .36665 Mdot
.644 .36667 Mdot
.644 .36681 Mdot
.644 .36684 Mdot
.644 .36685 Mdot
.644 .36687 Mdot
.644 .36738 Mdot
.644 .36742 Mdot
.644 .36751 Mdot
.644 .36751 Mdot
.644 .36756 Mdot
.644 .36764 Mdot
.644 .36778 Mdot
.644 .3678 Mdot
.644 .36789 Mdot
.644 .36799 Mdot
.644 .36801 Mdot
.644 .36823 Mdot
.644 .36839 Mdot
.644 .36865 Mdot
.644 .36869 Mdot
.644 .36887 Mdot
.644 .36899 Mdot
.644 .36902 Mdot
.644 .36912 Mdot
.644 .36917 Mdot
.644 .3693 Mdot
.644 .36932 Mdot
.644 .36953 Mdot
.644 .3696 Mdot
.644 .36968 Mdot
.644 .36995 Mdot
.644 .37 Mdot
.644 .37 Mdot
.644 .37 Mdot
.644 .37004 Mdot
.644 .37016 Mdot
.644 .37021 Mdot
.644 .37026 Mdot
.644 .37029 Mdot
.644 .37046 Mdot
.644 .37065 Mdot
.644 .37069 Mdot
.644 .37089 Mdot
.644 .37097 Mdot
.644 .37112 Mdot
.644 .37115 Mdot
.644 .37119 Mdot
.644 .37122 Mdot
.644 .37124 Mdot
.644 .37141 Mdot
.644 .37145 Mdot
.644 .37149 Mdot
.644 .37152 Mdot
.644 .37152 Mdot
.644 .37157 Mdot
.644 .37168 Mdot
.644 .37169 Mdot
.644 .3718 Mdot
.644 .37188 Mdot
.644 .37197 Mdot
.644 .37205 Mdot
.644 .3722 Mdot
.644 .37245 Mdot
.644 .37255 Mdot
.644 .37259 Mdot
.644 .37264 Mdot
.644 .37273 Mdot
.644 .37274 Mdot
.644 .37281 Mdot
.644 .37291 Mdot
.644 .37292 Mdot
.644 .37307 Mdot
.644 .37316 Mdot
.644 .37328 Mdot
.644 .37331 Mdot
.644 .37353 Mdot
.644 .37357 Mdot
.644 .37375 Mdot
.644 .37381 Mdot
.644 .37393 Mdot
.644 .37396 Mdot
.644 .37397 Mdot
.644 .37402 Mdot
.644 .37405 Mdot
.644 .37407 Mdot
.644 .37407 Mdot
.644 .3741 Mdot
.644 .3743 Mdot
.644 .37431 Mdot
.644 .37431 Mdot
.644 .37437 Mdot
.644 .37438 Mdot
.644 .3744 Mdot
.644 .37447 Mdot
.644 .37452 Mdot
.644 .37453 Mdot
.644 .37456 Mdot
.644 .37459 Mdot
.644 .37461 Mdot
.644 .37472 Mdot
.644 .37472 Mdot
.644 .37483 Mdot
.644 .37488 Mdot
.644 .37498 Mdot
.644 .37499 Mdot
.644 .37501 Mdot
.644 .37502 Mdot
.644 .37507 Mdot
.644 .37517 Mdot
.644 .3752 Mdot
.644 .37525 Mdot
.644 .37529 Mdot
.644 .3753 Mdot
.644 .3753 Mdot
.644 .37532 Mdot
.644 .37533 Mdot
.644 .37536 Mdot
.644 .37542 Mdot
.644 .37544 Mdot
.644 .3755 Mdot
.644 .37553 Mdot
.644 .37554 Mdot
.644 .37556 Mdot
.644 .37561 Mdot
.644 .37563 Mdot
.644 .37575 Mdot
.644 .3759 Mdot
.644 .37597 Mdot
.644 .37603 Mdot
.644 .3761 Mdot
.644 .37626 Mdot
.644 .37629 Mdot
.644 .37638 Mdot
.644 .37652 Mdot
.644 .37653 Mdot
.644 .37663 Mdot
.644 .37668 Mdot
.644 .37679 Mdot
.644 .37681 Mdot
.644 .37681 Mdot
.644 .37682 Mdot
.644 .37685 Mdot
.644 .3769 Mdot
.644 .3769 Mdot
.644 .37699 Mdot
.644 .3772 Mdot
.644 .37742 Mdot
.644 .37743 Mdot
.644 .37766 Mdot
.644 .37767 Mdot
.644 .37779 Mdot
.644 .37783 Mdot
.644 .37785 Mdot
.644 .37789 Mdot
.644 .3779 Mdot
.644 .37798 Mdot
.644 .37813 Mdot
.644 .37815 Mdot
.644 .37815 Mdot
.644 .37816 Mdot
.644 .37821 Mdot
.644 .37822 Mdot
.644 .37826 Mdot
.644 .37832 Mdot
.644 .37847 Mdot
.644 .37855 Mdot
.644 .37859 Mdot
.644 .3786 Mdot
.644 .37866 Mdot
.644 .37869 Mdot
.644 .3787 Mdot
.644 .3787 Mdot
.644 .37876 Mdot
.644 .3788 Mdot
.644 .37883 Mdot
.644 .37889 Mdot
.644 .37895 Mdot
.644 .37904 Mdot
.644 .37907 Mdot
.644 .37909 Mdot
.644 .37914 Mdot
.644 .37915 Mdot
.644 .37917 Mdot
.644 .37921 Mdot
.644 .37921 Mdot
.644 .3793 Mdot
.644 .37935 Mdot
.644 .37945 Mdot
.644 .37953 Mdot
.644 .37958 Mdot
.644 .37959 Mdot
.644 .37959 Mdot
.644 .37963 Mdot
.644 .37971 Mdot
.644 .37974 Mdot
.644 .3798 Mdot
.644 .37986 Mdot
.644 .37997 Mdot
.644 .37997 Mdot
.644 .37999 Mdot
.644 .38003 Mdot
.644 .38004 Mdot
.644 .38007 Mdot
.644 .38008 Mdot
.644 .38044 Mdot
.644 .38052 Mdot
.644 .38057 Mdot
.644 .38064 Mdot
.644 .38093 Mdot
.644 .38098 Mdot
.644 .38099 Mdot
.644 .38111 Mdot
.644 .38113 Mdot
.644 .38114 Mdot
.644 .38123 Mdot
.644 .38127 Mdot
.644 .38135 Mdot
.644 .3814 Mdot
.644 .38147 Mdot
.644 .3815 Mdot
.644 .38158 Mdot
.644 .38161 Mdot
.644 .38173 Mdot
.644 .38177 Mdot
.644 .38181 Mdot
.644 .38194 Mdot
.644 .38197 Mdot
.644 .38224 Mdot
.644 .38232 Mdot
.644 .38233 Mdot
.644 .38241 Mdot
.644 .3826 Mdot
.644 .38303 Mdot
.644 .38309 Mdot
.644 .38313 Mdot
.644 .3834 Mdot
.644 .38344 Mdot
.644 .38359 Mdot
.644 .3836 Mdot
.644 .3836 Mdot
.644 .38364 Mdot
.644 .38372 Mdot
.644 .38382 Mdot
.644 .3839 Mdot
.644 .3841 Mdot
.644 .38414 Mdot
.644 .38417 Mdot
.644 .38422 Mdot
.644 .38444 Mdot
.644 .38449 Mdot
.644 .3845 Mdot
.644 .38457 Mdot
.644 .3846 Mdot
.644 .38473 Mdot
.644 .38477 Mdot
.644 .38482 Mdot
.644 .38496 Mdot
.644 .38501 Mdot
.644 .38512 Mdot
.644 .38519 Mdot
.644 .38521 Mdot
.644 .38527 Mdot
.644 .38527 Mdot
.644 .38528 Mdot
.644 .38533 Mdot
.644 .38533 Mdot
.644 .38541 Mdot
.644 .38554 Mdot
.644 .38556 Mdot
.644 .38557 Mdot
.644 .3856 Mdot
.644 .38561 Mdot
.644 .38571 Mdot
.644 .38576 Mdot
.644 .38579 Mdot
.644 .38582 Mdot
.644 .3859 Mdot
.644 .38604 Mdot
.644 .38635 Mdot
.644 .38638 Mdot
.644 .38641 Mdot
.644 .38649 Mdot
.644 .38658 Mdot
.644 .38672 Mdot
.644 .38674 Mdot
.644 .38688 Mdot
.644 .38712 Mdot
.644 .38717 Mdot
.644 .38725 Mdot
.644 .3873 Mdot
.644 .38731 Mdot
.644 .38732 Mdot
.644 .38733 Mdot
.644 .38738 Mdot
.644 .3874 Mdot
.644 .38746 Mdot
.644 .38749 Mdot
.644 .38749 Mdot
.644 .38761 Mdot
.644 .38767 Mdot
.644 .38767 Mdot
.644 .38774 Mdot
.644 .38777 Mdot
.644 .38779 Mdot
.644 .38779 Mdot
.644 .38787 Mdot
.644 .38788 Mdot
.644 .38792 Mdot
.644 .38806 Mdot
.644 .38806 Mdot
.644 .38807 Mdot
.644 .38812 Mdot
.644 .38813 Mdot
.644 .38815 Mdot
.644 .38822 Mdot
.644 .38826 Mdot
.644 .38836 Mdot
.644 .38839 Mdot
.644 .38852 Mdot
.644 .38854 Mdot
.644 .38861 Mdot
.644 .38867 Mdot
.644 .38875 Mdot
.644 .38876 Mdot
.644 .38882 Mdot
.644 .38886 Mdot
.644 .38887 Mdot
.644 .38893 Mdot
.644 .38895 Mdot
.644 .38898 Mdot
.644 .38904 Mdot
.644 .38919 Mdot
.644 .38928 Mdot
.644 .38933 Mdot
.644 .38938 Mdot
.644 .38943 Mdot
.644 .3895 Mdot
.644 .3895 Mdot
.644 .38957 Mdot
.644 .3896 Mdot
.644 .3896 Mdot
.644 .38962 Mdot
.644 .38964 Mdot
.644 .38967 Mdot
.644 .38977 Mdot
.644 .38978 Mdot
.644 .3898 Mdot
.644 .38982 Mdot
.644 .38984 Mdot
.644 .38993 Mdot
.644 .38998 Mdot
.644 .3901 Mdot
.644 .39012 Mdot
.644 .39024 Mdot
.644 .39034 Mdot
.644 .39036 Mdot
.644 .39039 Mdot
.644 .39042 Mdot
.644 .39049 Mdot
.644 .39051 Mdot
.644 .39051 Mdot
.644 .39051 Mdot
.644 .39054 Mdot
.644 .39071 Mdot
.644 .39076 Mdot
.644 .3908 Mdot
.644 .39092 Mdot
.644 .39094 Mdot
.644 .39101 Mdot
.644 .39104 Mdot
.644 .39111 Mdot
.644 .39112 Mdot
.644 .39119 Mdot
.644 .39131 Mdot
.644 .39133 Mdot
.644 .39149 Mdot
.644 .39158 Mdot
.644 .39171 Mdot
.644 .39172 Mdot
.644 .39179 Mdot
.644 .39184 Mdot
.644 .39185 Mdot
.644 .39194 Mdot
.644 .39198 Mdot
.644 .39202 Mdot
.644 .39202 Mdot
.644 .39207 Mdot
.644 .39209 Mdot
.644 .3924 Mdot
.644 .39242 Mdot
.644 .39242 Mdot
.644 .39244 Mdot
.644 .39252 Mdot
.644 .39253 Mdot
.644 .39256 Mdot
.644 .39258 Mdot
.644 .39258 Mdot
.644 .39267 Mdot
.644 .39268 Mdot
.644 .39272 Mdot
.644 .39273 Mdot
.644 .39274 Mdot
.644 .39276 Mdot
.644 .39277 Mdot
.644 .39278 Mdot
.644 .39283 Mdot
.644 .39288 Mdot
.644 .39292 Mdot
.644 .39295 Mdot
.644 .39304 Mdot
.644 .3931 Mdot
.644 .3931 Mdot
.644 .39319 Mdot
.644 .39321 Mdot
.644 .39328 Mdot
.644 .39337 Mdot
.644 .39345 Mdot
.644 .39352 Mdot
.644 .39355 Mdot
.644 .39358 Mdot
.644 .39359 Mdot
.644 .3936 Mdot
.644 .39366 Mdot
.644 .39369 Mdot
.644 .39385 Mdot
.644 .3939 Mdot
.644 .39392 Mdot
.644 .39397 Mdot
.644 .39403 Mdot
.644 .39404 Mdot
.644 .39405 Mdot
.644 .39406 Mdot
.644 .39409 Mdot
.644 .39412 Mdot
.644 .39414 Mdot
.644 .39416 Mdot
.644 .39425 Mdot
.644 .39425 Mdot
.644 .39429 Mdot
.644 .3944 Mdot
.644 .39444 Mdot
.644 .39447 Mdot
.644 .3945 Mdot
.644 .3945 Mdot
.644 .39457 Mdot
.644 .3946 Mdot
.646 .28455 Mdot
.646 .2846 Mdot
.646 .28461 Mdot
.646 .28476 Mdot
.646 .28478 Mdot
.646 .28486 Mdot
.646 .28499 Mdot
.646 .28511 Mdot
.646 .28512 Mdot
.646 .28518 Mdot
.646 .2853 Mdot
.646 .28531 Mdot
.646 .28531 Mdot
.646 .28538 Mdot
.646 .28544 Mdot
.646 .28551 Mdot
.646 .28554 Mdot
.646 .28555 Mdot
.646 .28559 Mdot
.646 .28565 Mdot
.646 .28573 Mdot
.646 .28574 Mdot
.646 .28586 Mdot
.646 .28589 Mdot
.646 .2859 Mdot
.646 .28593 Mdot
.646 .28593 Mdot
.646 .28593 Mdot
.646 .28596 Mdot
.646 .28598 Mdot
.646 .28605 Mdot
.646 .28605 Mdot
.646 .28609 Mdot
.646 .28619 Mdot
.646 .28626 Mdot
.646 .28628 Mdot
.646 .28634 Mdot
.646 .28641 Mdot
.646 .28647 Mdot
.646 .28649 Mdot
.646 .2865 Mdot
.646 .28661 Mdot
.646 .28663 Mdot
.646 .28676 Mdot
.646 .28679 Mdot
.646 .28681 Mdot
.646 .28682 Mdot
.646 .28687 Mdot
.646 .28691 Mdot
.646 .28702 Mdot
.646 .28702 Mdot
.646 .28722 Mdot
.646 .28727 Mdot
.646 .2874 Mdot
.646 .28743 Mdot
.646 .28754 Mdot
.646 .28758 Mdot
.646 .2876 Mdot
.646 .28771 Mdot
.646 .28781 Mdot
.646 .28792 Mdot
.646 .28796 Mdot
.646 .28802 Mdot
.646 .28803 Mdot
.646 .28826 Mdot
.646 .28828 Mdot
.646 .28836 Mdot
.646 .28847 Mdot
.646 .28859 Mdot
.646 .2886 Mdot
.646 .28866 Mdot
.646 .2887 Mdot
.646 .28872 Mdot
.646 .28874 Mdot
.646 .28881 Mdot
.646 .28892 Mdot
.646 .28897 Mdot
.646 .28907 Mdot
.646 .28916 Mdot
.646 .2892 Mdot
.646 .28923 Mdot
.646 .28934 Mdot
.646 .2894 Mdot
.646 .28945 Mdot
.646 .28946 Mdot
.646 .28991 Mdot
.646 .28999 Mdot
.646 .29 Mdot
.646 .29006 Mdot
.646 .29016 Mdot
.646 .29016 Mdot
.646 .29018 Mdot
.646 .29022 Mdot
.646 .29025 Mdot
.646 .29043 Mdot
.646 .29046 Mdot
.646 .29051 Mdot
.646 .29064 Mdot
.646 .29071 Mdot
.646 .29077 Mdot
.646 .29086 Mdot
.646 .29089 Mdot
.646 .291 Mdot
.646 .29101 Mdot
.646 .29111 Mdot
.646 .29112 Mdot
.646 .29114 Mdot
.646 .29114 Mdot
.646 .29115 Mdot
.646 .29124 Mdot
.646 .29126 Mdot
.646 .29146 Mdot
.646 .29153 Mdot
.646 .29174 Mdot
.646 .2919 Mdot
.646 .29205 Mdot
.646 .29215 Mdot
.646 .29222 Mdot
.646 .29231 Mdot
.646 .29239 Mdot
.646 .29249 Mdot
.646 .29258 Mdot
.646 .29261 Mdot
.646 .29289 Mdot
.646 .29304 Mdot
.646 .29306 Mdot
.646 .29318 Mdot
.646 .2933 Mdot
.646 .29338 Mdot
.646 .29354 Mdot
.646 .29367 Mdot
.646 .29374 Mdot
.646 .29384 Mdot
.646 .29394 Mdot
.646 .29399 Mdot
.646 .29413 Mdot
.646 .29423 Mdot
.646 .29427 Mdot
.646 .29427 Mdot
.646 .29433 Mdot
.646 .29435 Mdot
.646 .29435 Mdot
.646 .29463 Mdot
.646 .29465 Mdot
.646 .29483 Mdot
.646 .29495 Mdot
.646 .29497 Mdot
.646 .29505 Mdot
.646 .29512 Mdot
.646 .29514 Mdot
.646 .29524 Mdot
.646 .2953 Mdot
.646 .29533 Mdot
.646 .29546 Mdot
.646 .29552 Mdot
.646 .29566 Mdot
.646 .2957 Mdot
.646 .2958 Mdot
.646 .29584 Mdot
.646 .29612 Mdot
.646 .29614 Mdot
.646 .29616 Mdot
.646 .29625 Mdot
.646 .29639 Mdot
.646 .29658 Mdot
.646 .29659 Mdot
.646 .29664 Mdot
.646 .29675 Mdot
.646 .29684 Mdot
.646 .29689 Mdot
.646 .29691 Mdot
.646 .29695 Mdot
.646 .29698 Mdot
.646 .29699 Mdot
.646 .297 Mdot
.646 .29703 Mdot
.646 .29714 Mdot
.646 .29727 Mdot
.646 .29738 Mdot
.646 .29745 Mdot
.646 .29748 Mdot
.646 .29752 Mdot
.646 .29769 Mdot
.646 .29777 Mdot
.646 .2979 Mdot
.646 .29807 Mdot
.646 .29837 Mdot
.646 .29843 Mdot
.646 .29843 Mdot
.646 .29847 Mdot
.646 .29863 Mdot
.646 .29878 Mdot
.646 .29879 Mdot
.646 .29888 Mdot
.646 .29895 Mdot
.646 .29895 Mdot
.646 .29897 Mdot
.646 .29906 Mdot
.646 .29911 Mdot
.646 .29915 Mdot
.646 .29929 Mdot
.646 .29938 Mdot
.646 .29948 Mdot
.646 .29959 Mdot
.646 .29961 Mdot
.646 .29969 Mdot
.646 .29974 Mdot
.646 .29977 Mdot
.646 .29995 Mdot
.646 .30004 Mdot
.646 .30008 Mdot
.646 .30021 Mdot
.646 .30032 Mdot
.646 .30039 Mdot
.646 .30047 Mdot
.646 .30059 Mdot
.646 .30067 Mdot
.646 .30075 Mdot
.646 .30081 Mdot
.646 .30095 Mdot
.646 .301 Mdot
.646 .30107 Mdot
.646 .30111 Mdot
.646 .30116 Mdot
.646 .30117 Mdot
.646 .30126 Mdot
.646 .30136 Mdot
.646 .30138 Mdot
.646 .30138 Mdot
.646 .30141 Mdot
.646 .30159 Mdot
.646 .30169 Mdot
.646 .30177 Mdot
.646 .30192 Mdot
.646 .30201 Mdot
.646 .30215 Mdot
.646 .30222 Mdot
.646 .30224 Mdot
.646 .30229 Mdot
.646 .3023 Mdot
.646 .30245 Mdot
.646 .30248 Mdot
.646 .30249 Mdot
.646 .3026 Mdot
.646 .30275 Mdot
.646 .30276 Mdot
.646 .30293 Mdot
.646 .30295 Mdot
.646 .30301 Mdot
.646 .30312 Mdot
.646 .30324 Mdot
.646 .30329 Mdot
.646 .30335 Mdot
.646 .30336 Mdot
.646 .30345 Mdot
.646 .30353 Mdot
.646 .30382 Mdot
.646 .30395 Mdot
.646 .30413 Mdot
.646 .30419 Mdot
.646 .30423 Mdot
.646 .30431 Mdot
.646 .30445 Mdot
.646 .30459 Mdot
.646 .30461 Mdot
.646 .3047 Mdot
.646 .30486 Mdot
.646 .30494 Mdot
.646 .30499 Mdot
.646 .30505 Mdot
.646 .3051 Mdot
.646 .3052 Mdot
.646 .30529 Mdot
.646 .30551 Mdot
.646 .30569 Mdot
.646 .30574 Mdot
.646 .30575 Mdot
.646 .30575 Mdot
.646 .30576 Mdot
.646 .30576 Mdot
.646 .30583 Mdot
.646 .30589 Mdot
.646 .30591 Mdot
.646 .306 Mdot
.646 .30605 Mdot
.646 .30615 Mdot
.646 .30617 Mdot
.646 .3063 Mdot
.646 .30632 Mdot
.646 .30633 Mdot
.646 .30639 Mdot
.646 .30643 Mdot
.646 .30644 Mdot
.646 .30648 Mdot
.646 .30675 Mdot
.646 .30682 Mdot
.646 .30689 Mdot
.646 .30699 Mdot
.646 .30714 Mdot
.646 .30718 Mdot
.646 .30719 Mdot
.646 .30721 Mdot
.646 .30723 Mdot
.646 .30727 Mdot
.646 .30746 Mdot
.646 .30765 Mdot
.646 .30767 Mdot
.646 .30774 Mdot
.646 .3078 Mdot
.646 .30787 Mdot
.646 .3079 Mdot
.646 .30797 Mdot
.646 .30806 Mdot
.646 .30821 Mdot
.646 .30828 Mdot
.646 .30831 Mdot
.646 .30835 Mdot
.646 .30845 Mdot
.646 .30846 Mdot
.646 .30853 Mdot
.646 .30858 Mdot
.646 .30865 Mdot
.646 .30867 Mdot
.646 .30871 Mdot
.646 .30877 Mdot
.646 .30879 Mdot
.646 .3088 Mdot
.646 .30885 Mdot
.646 .30886 Mdot
.646 .30887 Mdot
.646 .30891 Mdot
.646 .30898 Mdot
.646 .30899 Mdot
.646 .30912 Mdot
.646 .30916 Mdot
.646 .30931 Mdot
.646 .30936 Mdot
.646 .30936 Mdot
.646 .30957 Mdot
.646 .30966 Mdot
.646 .3097 Mdot
.646 .30973 Mdot
.646 .30984 Mdot
.646 .30988 Mdot
.646 .30996 Mdot
.646 .31015 Mdot
.646 .31016 Mdot
.646 .31016 Mdot
.646 .3102 Mdot
.646 .31029 Mdot
.646 .3103 Mdot
.646 .31032 Mdot
.646 .31036 Mdot
.646 .3105 Mdot
.646 .31051 Mdot
.646 .31052 Mdot
.646 .31055 Mdot
.646 .31077 Mdot
.646 .31085 Mdot
.646 .31087 Mdot
.646 .31102 Mdot
.646 .31106 Mdot
.646 .31106 Mdot
.646 .31118 Mdot
.646 .3113 Mdot
.646 .3114 Mdot
.646 .31151 Mdot
.646 .31178 Mdot
.646 .31178 Mdot
.646 .31192 Mdot
.646 .31198 Mdot
.646 .31205 Mdot
.646 .31212 Mdot
.646 .31231 Mdot
.646 .31235 Mdot
.646 .31246 Mdot
.646 .31248 Mdot
.646 .31261 Mdot
.646 .31264 Mdot
.646 .31306 Mdot
.646 .31311 Mdot
.646 .31327 Mdot
.646 .31343 Mdot
.646 .31357 Mdot
.646 .31372 Mdot
.646 .31384 Mdot
.646 .31401 Mdot
.646 .31425 Mdot
.646 .31451 Mdot
.646 .31487 Mdot
.646 .31499 Mdot
.646 .31532 Mdot
.646 .31535 Mdot
.646 .3155 Mdot
.646 .31552 Mdot
.646 .31552 Mdot
.646 .31556 Mdot
.646 .31557 Mdot
.646 .31574 Mdot
.646 .31575 Mdot
.646 .31593 Mdot
.646 .31599 Mdot
.646 .31614 Mdot
.646 .31624 Mdot
.646 .31636 Mdot
.646 .31666 Mdot
.646 .31671 Mdot
.646 .31701 Mdot
.646 .31706 Mdot
.646 .31713 Mdot
.646 .31715 Mdot
.646 .31716 Mdot
.646 .31732 Mdot
.646 .31743 Mdot
.646 .31744 Mdot
.646 .31757 Mdot
.646 .31833 Mdot
.646 .31834 Mdot
.646 .31842 Mdot
.646 .31853 Mdot
.646 .31871 Mdot
.646 .31877 Mdot
.646 .31882 Mdot
.646 .31898 Mdot
.646 .31914 Mdot
.646 .31923 Mdot
.646 .3194 Mdot
.646 .31952 Mdot
.646 .31955 Mdot
.646 .31959 Mdot
.646 .31965 Mdot
.646 .31977 Mdot
.646 .31978 Mdot
.646 .31997 Mdot
.646 .32016 Mdot
.646 .3203 Mdot
.646 .32033 Mdot
.646 .32071 Mdot
.646 .32072 Mdot
.646 .32083 Mdot
.646 .32089 Mdot
.646 .32107 Mdot
.646 .32124 Mdot
.646 .32143 Mdot
.646 .32146 Mdot
.646 .32154 Mdot
.646 .32171 Mdot
.646 .32177 Mdot
.646 .32198 Mdot
.646 .32207 Mdot
.646 .32239 Mdot
.646 .3224 Mdot
.646 .32258 Mdot
.646 .32265 Mdot
.646 .32273 Mdot
.646 .32274 Mdot
.646 .32278 Mdot
.646 .32284 Mdot
.646 .32304 Mdot
.646 .32308 Mdot
.646 .32326 Mdot
.646 .32329 Mdot
.646 .32331 Mdot
.646 .32342 Mdot
.646 .32354 Mdot
.646 .32363 Mdot
.646 .32367 Mdot
.646 .32379 Mdot
.646 .32396 Mdot
.646 .32401 Mdot
.646 .32402 Mdot
.646 .32414 Mdot
.646 .32417 Mdot
.646 .32421 Mdot
.646 .32422 Mdot
.646 .32422 Mdot
.646 .32427 Mdot
.646 .32429 Mdot
.646 .32433 Mdot
.646 .32454 Mdot
.646 .32456 Mdot
.646 .32469 Mdot
.646 .32478 Mdot
.646 .32485 Mdot
.646 .32487 Mdot
.646 .32492 Mdot
.646 .32503 Mdot
.646 .32514 Mdot
.646 .32524 Mdot
.646 .32525 Mdot
.646 .32528 Mdot
.646 .32547 Mdot
.646 .32558 Mdot
.646 .32558 Mdot
.646 .32579 Mdot
.646 .32601 Mdot
.646 .32613 Mdot
.646 .32617 Mdot
.646 .32642 Mdot
.646 .32643 Mdot
.646 .32652 Mdot
.646 .36334 Mdot
.646 .36341 Mdot
.646 .36342 Mdot
.646 .36361 Mdot
.646 .36364 Mdot
.646 .36374 Mdot
.646 .36391 Mdot
.646 .36407 Mdot
.646 .36407 Mdot
.646 .36416 Mdot
.646 .3643 Mdot
.646 .36433 Mdot
.646 .36433 Mdot
.646 .36441 Mdot
.646 .36449 Mdot
.646 .36458 Mdot
.646 .36462 Mdot
.646 .36464 Mdot
.646 .36469 Mdot
.646 .36476 Mdot
.646 .36486 Mdot
.646 .36488 Mdot
.646 .36503 Mdot
.646 .36507 Mdot
.646 .36509 Mdot
.646 .36512 Mdot
.646 .36512 Mdot
.646 .36513 Mdot
.646 .36516 Mdot
.646 .36518 Mdot
.646 .36528 Mdot
.646 .36528 Mdot
.646 .36533 Mdot
.646 .36546 Mdot
.646 .36555 Mdot
.646 .36558 Mdot
.646 .36565 Mdot
.646 .36574 Mdot
.646 .36583 Mdot
.646 .36585 Mdot
.646 .36586 Mdot
.646 .366 Mdot
.646 .36603 Mdot
.646 .36619 Mdot
.646 .36623 Mdot
.646 .36627 Mdot
.646 .36628 Mdot
.646 .36634 Mdot
.646 .36639 Mdot
.646 .36653 Mdot
.646 .36654 Mdot
.646 .36679 Mdot
.646 .36686 Mdot
.646 .36702 Mdot
.646 .36706 Mdot
.646 .3672 Mdot
.646 .36726 Mdot
.646 .36728 Mdot
.646 .36743 Mdot
.646 .36756 Mdot
.646 .3677 Mdot
.646 .36775 Mdot
.646 .36783 Mdot
.646 .36784 Mdot
.646 .36814 Mdot
.646 .36816 Mdot
.646 .36827 Mdot
.646 .36841 Mdot
.646 .36856 Mdot
.646 .36857 Mdot
.646 .36866 Mdot
.646 .3687 Mdot
.646 .36873 Mdot
.646 .36876 Mdot
.646 .36885 Mdot
.646 .36898 Mdot
.646 .36905 Mdot
.646 .36918 Mdot
.646 .3693 Mdot
.646 .36934 Mdot
.646 .36939 Mdot
.646 .36953 Mdot
.646 .36961 Mdot
.646 .36967 Mdot
.646 .36969 Mdot
.646 .37027 Mdot
.646 .37037 Mdot
.646 .37038 Mdot
.646 .37046 Mdot
.646 .37059 Mdot
.646 .37059 Mdot
.646 .37061 Mdot
.646 .37066 Mdot
.646 .3707 Mdot
.646 .37094 Mdot
.646 .37098 Mdot
.646 .37121 Mdot
.646 .3713 Mdot
.646 .37138 Mdot
.646 .37149 Mdot
.646 .37154 Mdot
.646 .37168 Mdot
.646 .37169 Mdot
.646 .37182 Mdot
.646 .37183 Mdot
.646 .37185 Mdot
.646 .37186 Mdot
.646 .37187 Mdot
.646 .37199 Mdot
.646 .37201 Mdot
.646 .37227 Mdot
.646 .37236 Mdot
.646 .37264 Mdot
.646 .37284 Mdot
.646 .37303 Mdot
.646 .37316 Mdot
.646 .37325 Mdot
.646 .37337 Mdot
.646 .37348 Mdot
.646 .3736 Mdot
.646 .37372 Mdot
.646 .37376 Mdot
.646 .37409 Mdot
.646 .37411 Mdot
.646 .37421 Mdot
.646 .37422 Mdot
.646 .37431 Mdot
.646 .37434 Mdot
.646 .37449 Mdot
.646 .37454 Mdot
.646 .37459 Mdot
.646 .37464 Mdot
.646 .37475 Mdot
.646 .37475 Mdot
.646 .37496 Mdot
.646 .37504 Mdot
.646 .37513 Mdot
.646 .37522 Mdot
.646 .37531 Mdot
.646 .37531 Mdot
.646 .37534 Mdot
.646 .37546 Mdot
.646 .37547 Mdot
.646 .37553 Mdot
.646 .3757 Mdot
.646 .37572 Mdot
.646 .37574 Mdot
.646 .37574 Mdot
.646 .37585 Mdot
.646 .37588 Mdot
.646 .3759 Mdot
.646 .3759 Mdot
.646 .37598 Mdot
.646 .37601 Mdot
.646 .37601 Mdot
.646 .37602 Mdot
.646 .37616 Mdot
.646 .37622 Mdot
.646 .37625 Mdot
.646 .37634 Mdot
.646 .37636 Mdot
.646 .37639 Mdot
.646 .37646 Mdot
.646 .37663 Mdot
.646 .37663 Mdot
.646 .37666 Mdot
.646 .37678 Mdot
.646 .37681 Mdot
.646 .37691 Mdot
.646 .37692 Mdot
.646 .37697 Mdot
.646 .377 Mdot
.646 .37701 Mdot
.646 .37702 Mdot
.646 .37706 Mdot
.646 .37706 Mdot
.646 .37708 Mdot
.646 .37713 Mdot
.646 .37716 Mdot
.646 .37717 Mdot
.646 .37723 Mdot
.646 .37727 Mdot
.646 .37732 Mdot
.646 .37733 Mdot
.646 .3774 Mdot
.646 .37744 Mdot
.646 .37751 Mdot
.646 .37763 Mdot
.646 .3777 Mdot
.646 .37775 Mdot
.646 .37778 Mdot
.646 .37783 Mdot
.646 .37788 Mdot
.646 .37793 Mdot
.646 .37795 Mdot
.646 .37809 Mdot
.646 .37824 Mdot
.646 .37827 Mdot
.646 .37829 Mdot
.646 .3783 Mdot
.646 .37831 Mdot
.646 .37834 Mdot
.646 .37846 Mdot
.646 .37854 Mdot
.646 .37859 Mdot
.646 .37864 Mdot
.646 .37885 Mdot
.646 .37889 Mdot
.646 .37889 Mdot
.646 .37892 Mdot
.646 .37897 Mdot
.646 .37898 Mdot
.646 .37899 Mdot
.646 .37909 Mdot
.646 .37911 Mdot
.646 .37919 Mdot
.646 .37922 Mdot
.646 .37929 Mdot
.646 .37931 Mdot
.646 .37936 Mdot
.646 .37941 Mdot
.646 .37941 Mdot
.646 .37942 Mdot
.646 .37942 Mdot
.646 .37943 Mdot
.646 .37947 Mdot
.646 .3796 Mdot
.646 .37977 Mdot
.646 .37984 Mdot
.646 .37992 Mdot
.646 .37996 Mdot
.646 .38 Mdot
.646 .38005 Mdot
.646 .3801 Mdot
.646 .38023 Mdot
.646 .3803 Mdot
.646 .38031 Mdot
.646 .38042 Mdot
.646 .38053 Mdot
.646 .3806 Mdot
.646 .38063 Mdot
.646 .38067 Mdot
.646 .38081 Mdot
.646 .38091 Mdot
.646 .38113 Mdot
.646 .3812 Mdot
.646 .38127 Mdot
.646 .38127 Mdot
.646 .38133 Mdot
.646 .38136 Mdot
.646 .38145 Mdot
.646 .38154 Mdot
.646 .38158 Mdot
.646 .3816 Mdot
.646 .38173 Mdot
.646 .38174 Mdot
.646 .38186 Mdot
.646 .38195 Mdot
.646 .38195 Mdot
.646 .38197 Mdot
.646 .38209 Mdot
.646 .3821 Mdot
.646 .38213 Mdot
.646 .38215 Mdot
.646 .3822 Mdot
.646 .38232 Mdot
.646 .38238 Mdot
.646 .3825 Mdot
.646 .38256 Mdot
.646 .38264 Mdot
.646 .38278 Mdot
.646 .3828 Mdot
.646 .3828 Mdot
.646 .38282 Mdot
.646 .3829 Mdot
.646 .38297 Mdot
.646 .38297 Mdot
.646 .38301 Mdot
.646 .38304 Mdot
.646 .38309 Mdot
.646 .38313 Mdot
.646 .38324 Mdot
.646 .38329 Mdot
.646 .38335 Mdot
.646 .38341 Mdot
.646 .38351 Mdot
.646 .38357 Mdot
.646 .38363 Mdot
.646 .38371 Mdot
.646 .38381 Mdot
.646 .38384 Mdot
.646 .38391 Mdot
.646 .38404 Mdot
.646 .38407 Mdot
.646 .38411 Mdot
.646 .38417 Mdot
.646 .38419 Mdot
.646 .38427 Mdot
.646 .38435 Mdot
.646 .38442 Mdot
.646 .38453 Mdot
.646 .38456 Mdot
.646 .3846 Mdot
.646 .38467 Mdot
.646 .38468 Mdot
.646 .38468 Mdot
.646 .38474 Mdot
.646 .38481 Mdot
.646 .38481 Mdot
.646 .38493 Mdot
.646 .38505 Mdot
.646 .38508 Mdot
.646 .38509 Mdot
.646 .38513 Mdot
.646 .38536 Mdot
.646 .38549 Mdot
.646 .3856 Mdot
.646 .38566 Mdot
.646 .38579 Mdot
.646 .38582 Mdot
.646 .38585 Mdot
.646 .38589 Mdot
.646 .38598 Mdot
.646 .38609 Mdot
.646 .38617 Mdot
.646 .38619 Mdot
.646 .3862 Mdot
.646 .3862 Mdot
.646 .38623 Mdot
.646 .38626 Mdot
.646 .38627 Mdot
.646 .38631 Mdot
.646 .38638 Mdot
.646 .38647 Mdot
.646 .38651 Mdot
.646 .38651 Mdot
.646 .38666 Mdot
.646 .38677 Mdot
.646 .38684 Mdot
.646 .38686 Mdot
.646 .38687 Mdot
.646 .38709 Mdot
.646 .38712 Mdot
.646 .3872 Mdot
.646 .38722 Mdot
.646 .38734 Mdot
.646 .38738 Mdot
.646 .38749 Mdot
.646 .38751 Mdot
.646 .38755 Mdot
.646 .38763 Mdot
.646 .38764 Mdot
.646 .3877 Mdot
.646 .38776 Mdot
.646 .38778 Mdot
.646 .38787 Mdot
.646 .38801 Mdot
.646 .38803 Mdot
.646 .38824 Mdot
.646 .38824 Mdot
.646 .38826 Mdot
.646 .3883 Mdot
.646 .38831 Mdot
.646 .38833 Mdot
.646 .38841 Mdot
.646 .38852 Mdot
.646 .38856 Mdot
.646 .38864 Mdot
.646 .38871 Mdot
.646 .38877 Mdot
.646 .38887 Mdot
.646 .38899 Mdot
.646 .38906 Mdot
.646 .38915 Mdot
.646 .38924 Mdot
.646 .38926 Mdot
.646 .38938 Mdot
.646 .38959 Mdot
.646 .38961 Mdot
.646 .38968 Mdot
.646 .38976 Mdot
.646 .38982 Mdot
.646 .38989 Mdot
.646 .38995 Mdot
.646 .39003 Mdot
.646 .39014 Mdot
.646 .39026 Mdot
.646 .39042 Mdot
.646 .39048 Mdot
.646 .39063 Mdot
.646 .39065 Mdot
.646 .39072 Mdot
.646 .39073 Mdot
.646 .39073 Mdot
.646 .39074 Mdot
.646 .39075 Mdot
.646 .39083 Mdot
.646 .39083 Mdot
.646 .39092 Mdot
.646 .39094 Mdot
.646 .39101 Mdot
.646 .39106 Mdot
.646 .39111 Mdot
.646 .39121 Mdot
.646 .39125 Mdot
.646 .39128 Mdot
.646 .39142 Mdot
.646 .39144 Mdot
.646 .39147 Mdot
.646 .39148 Mdot
.646 .39148 Mdot
.646 .39156 Mdot
.646 .39161 Mdot
.646 .39162 Mdot
.646 .39168 Mdot
.646 .39203 Mdot
.646 .39203 Mdot
.646 .39207 Mdot
.646 .39212 Mdot
.646 .39221 Mdot
.646 .39223 Mdot
.646 .39226 Mdot
.646 .39233 Mdot
.646 .39241 Mdot
.646 .39245 Mdot
.646 .39253 Mdot
.646 .39258 Mdot
.646 .3926 Mdot
.646 .39262 Mdot
.646 .39264 Mdot
.646 .3927 Mdot
.646 .3927 Mdot
.646 .39279 Mdot
.646 .39288 Mdot
.646 .39294 Mdot
.646 .39296 Mdot
.646 .39313 Mdot
.646 .39314 Mdot
.646 .39319 Mdot
.646 .39322 Mdot
.646 .3933 Mdot
.646 .39338 Mdot
.646 .39347 Mdot
.646 .39348 Mdot
.646 .39352 Mdot
.646 .3936 Mdot
.646 .39362 Mdot
.646 .39372 Mdot
.646 .39376 Mdot
.646 .39391 Mdot
.646 .39392 Mdot
.646 .394 Mdot
.646 .39403 Mdot
.646 .39407 Mdot
.646 .39407 Mdot
.646 .39409 Mdot
.646 .39412 Mdot
.646 .39421 Mdot
.646 .39423 Mdot
.646 .39432 Mdot
.646 .39433 Mdot
.646 .39434 Mdot
.646 .39439 Mdot
.646 .39444 Mdot
.646 .39449 Mdot
.646 .3945 Mdot
.646 .39456 Mdot
.646 .39464 Mdot
.646 .39466 Mdot
.646 .39467 Mdot
.646 .39472 Mdot
.646 .39474 Mdot
.646 .39476 Mdot
.646 .39476 Mdot
.646 .39476 Mdot
.646 .39478 Mdot
.646 .39479 Mdot
.646 .39481 Mdot
.646 .39491 Mdot
.646 .39492 Mdot
.646 .39498 Mdot
.646 .39502 Mdot
.646 .39505 Mdot
.646 .39506 Mdot
.646 .39509 Mdot
.646 .39514 Mdot
.646 .39519 Mdot
.646 .39524 Mdot
.646 .39524 Mdot
.646 .39525 Mdot
.646 .39534 Mdot
.646 .39539 Mdot
.646 .39539 Mdot
.646 .39549 Mdot
.646 .39559 Mdot
.646 .39565 Mdot
.646 .39567 Mdot
.646 .39578 Mdot
.646 .39579 Mdot
.646 .39583 Mdot
.648 .28397 Mdot
.648 .28399 Mdot
.648 .28406 Mdot
.648 .28414 Mdot
.648 .28426 Mdot
.648 .28427 Mdot
.648 .28427 Mdot
.648 .28429 Mdot
.648 .28437 Mdot
.648 .28441 Mdot
.648 .28441 Mdot
.648 .28445 Mdot
.648 .28454 Mdot
.648 .28468 Mdot
.648 .28489 Mdot
.648 .28504 Mdot
.648 .28506 Mdot
.648 .28521 Mdot
.648 .28524 Mdot
.648 .28524 Mdot
.648 .28527 Mdot
.648 .28527 Mdot
.648 .28544 Mdot
.648 .28545 Mdot
.648 .28548 Mdot
.648 .28548 Mdot
.648 .28554 Mdot
.648 .28562 Mdot
.648 .28563 Mdot
.648 .28568 Mdot
.648 .28571 Mdot
.648 .28571 Mdot
.648 .28573 Mdot
.648 .28607 Mdot
.648 .28609 Mdot
.648 .28612 Mdot
.648 .28614 Mdot
.648 .28618 Mdot
.648 .28623 Mdot
.648 .28631 Mdot
.648 .28633 Mdot
.648 .28636 Mdot
.648 .28638 Mdot
.648 .28647 Mdot
.648 .2865 Mdot
.648 .2865 Mdot
.648 .28653 Mdot
.648 .28656 Mdot
.648 .28657 Mdot
.648 .28662 Mdot
.648 .28662 Mdot
.648 .28673 Mdot
.648 .28676 Mdot
.648 .28677 Mdot
.648 .28717 Mdot
.648 .28725 Mdot
.648 .28728 Mdot
.648 .28732 Mdot
.648 .28735 Mdot
.648 .28741 Mdot
.648 .28753 Mdot
.648 .28753 Mdot
.648 .28771 Mdot
.648 .28793 Mdot
.648 .28793 Mdot
.648 .28799 Mdot
.648 .28803 Mdot
.648 .28804 Mdot
.648 .28806 Mdot
.648 .28808 Mdot
.648 .28821 Mdot
.648 .28834 Mdot
.648 .28842 Mdot
.648 .28846 Mdot
.648 .28855 Mdot
.648 .28857 Mdot
.648 .28858 Mdot
.648 .28865 Mdot
.648 .28876 Mdot
.648 .28898 Mdot
.648 .289 Mdot
.648 .28932 Mdot
.648 .28934 Mdot
.648 .28935 Mdot
.648 .28944 Mdot
.648 .28947 Mdot
.648 .28961 Mdot
.648 .28964 Mdot
.648 .28971 Mdot
.648 .29012 Mdot
.648 .29024 Mdot
.648 .29025 Mdot
.648 .29026 Mdot
.648 .29026 Mdot
.648 .2904 Mdot
.648 .29053 Mdot
.648 .29058 Mdot
.648 .29077 Mdot
.648 .29078 Mdot
.648 .29081 Mdot
.648 .29083 Mdot
.648 .29083 Mdot
.648 .29084 Mdot
.648 .29092 Mdot
.648 .29093 Mdot
.648 .29103 Mdot
.648 .29106 Mdot
.648 .29133 Mdot
.648 .29141 Mdot
.648 .29147 Mdot
.648 .29148 Mdot
.648 .29148 Mdot
.648 .29149 Mdot
.648 .2915 Mdot
.648 .29155 Mdot
.648 .29163 Mdot
.648 .29175 Mdot
.648 .29176 Mdot
.648 .2918 Mdot
.648 .29183 Mdot
.648 .29184 Mdot
.648 .29185 Mdot
.648 .29204 Mdot
.648 .29226 Mdot
.648 .29237 Mdot
.648 .29282 Mdot
.648 .29286 Mdot
.648 .293 Mdot
.648 .29305 Mdot
.648 .29309 Mdot
.648 .2931 Mdot
.648 .29327 Mdot
.648 .29337 Mdot
.648 .29342 Mdot
.648 .29343 Mdot
.648 .2935 Mdot
.648 .29364 Mdot
.648 .29366 Mdot
.648 .29368 Mdot
.648 .29373 Mdot
.648 .29381 Mdot
.648 .29382 Mdot
.648 .29383 Mdot
.648 .29389 Mdot
.648 .29394 Mdot
.648 .29402 Mdot
.648 .29416 Mdot
.648 .29427 Mdot
.648 .29436 Mdot
.648 .29438 Mdot
.648 .29452 Mdot
.648 .29455 Mdot
.648 .29489 Mdot
.648 .29491 Mdot
.648 .29494 Mdot
.648 .29514 Mdot
.648 .29515 Mdot
.648 .29518 Mdot
.648 .29524 Mdot
.648 .29527 Mdot
.648 .29527 Mdot
.648 .29529 Mdot
.648 .29534 Mdot
.648 .29568 Mdot
.648 .2958 Mdot
.648 .29593 Mdot
.648 .29598 Mdot
.648 .29598 Mdot
.648 .29658 Mdot
.648 .29676 Mdot
.648 .29681 Mdot
.648 .29701 Mdot
.648 .29701 Mdot
.648 .29702 Mdot
.648 .29702 Mdot
.648 .29711 Mdot
.648 .29733 Mdot
.648 .29749 Mdot
.648 .2975 Mdot
.648 .29757 Mdot
.648 .29759 Mdot
.648 .29765 Mdot
.648 .29773 Mdot
.648 .29787 Mdot
.648 .29791 Mdot
.648 .29803 Mdot
.648 .29823 Mdot
.648 .29824 Mdot
.648 .29832 Mdot
.648 .29834 Mdot
.648 .29854 Mdot
.648 .29859 Mdot
.648 .29861 Mdot
.648 .29882 Mdot
.648 .29889 Mdot
.648 .29897 Mdot
.648 .29934 Mdot
.648 .29941 Mdot
.648 .29941 Mdot
.648 .29944 Mdot
.648 .29952 Mdot
.648 .29953 Mdot
.648 .29954 Mdot
.648 .29982 Mdot
.648 .29982 Mdot
.648 .29983 Mdot
.648 .29987 Mdot
.648 .29997 Mdot
.648 .29997 Mdot
.648 .29999 Mdot
.648 .30002 Mdot
.648 .30003 Mdot
.648 .30009 Mdot
.648 .3001 Mdot
.648 .3001 Mdot
.648 .30016 Mdot
.648 .30018 Mdot
.648 .30019 Mdot
.648 .30036 Mdot
.648 .30036 Mdot
.648 .30042 Mdot
.648 .30043 Mdot
.648 .30044 Mdot
.648 .30048 Mdot
.648 .30069 Mdot
.648 .30091 Mdot
.648 .30092 Mdot
.648 .30095 Mdot
.648 .30107 Mdot
.648 .30108 Mdot
.648 .30113 Mdot
.648 .30114 Mdot
.648 .30125 Mdot
.648 .30143 Mdot
.648 .30148 Mdot
.648 .30153 Mdot
.648 .30157 Mdot
.648 .30167 Mdot
.648 .30186 Mdot
.648 .30186 Mdot
.648 .30186 Mdot
.648 .30201 Mdot
.648 .30212 Mdot
.648 .30247 Mdot
.648 .30247 Mdot
.648 .30251 Mdot
.648 .30258 Mdot
.648 .30292 Mdot
.648 .30295 Mdot
.648 .30297 Mdot
.648 .30298 Mdot
.648 .3031 Mdot
.648 .30311 Mdot
.648 .30332 Mdot
.648 .30344 Mdot
.648 .30349 Mdot
.648 .30356 Mdot
.648 .30365 Mdot
.648 .30369 Mdot
.648 .30372 Mdot
.648 .30377 Mdot
.648 .30395 Mdot
.648 .30399 Mdot
.648 .30409 Mdot
.648 .30419 Mdot
.648 .30422 Mdot
.648 .30433 Mdot
.648 .30435 Mdot
.648 .30463 Mdot
.648 .30499 Mdot
.648 .30511 Mdot
.648 .30514 Mdot
.648 .30515 Mdot
.648 .30516 Mdot
.648 .30516 Mdot
.648 .30516 Mdot
.648 .30524 Mdot
.648 .30549 Mdot
.648 .30554 Mdot
.648 .30556 Mdot
.648 .30558 Mdot
.648 .30569 Mdot
.648 .30572 Mdot
.648 .3058 Mdot
.648 .30588 Mdot
.648 .30588 Mdot
.648 .30589 Mdot
.648 .30597 Mdot
.648 .30621 Mdot
.648 .30627 Mdot
.648 .30635 Mdot
.648 .30642 Mdot
.648 .30664 Mdot
.648 .30678 Mdot
.648 .30688 Mdot
.648 .30688 Mdot
.648 .3069 Mdot
.648 .30695 Mdot
.648 .30698 Mdot
.648 .30702 Mdot
.648 .3071 Mdot
.648 .30719 Mdot
.648 .3074 Mdot
.648 .30797 Mdot
.648 .30805 Mdot
.648 .30805 Mdot
.648 .30808 Mdot
.648 .30809 Mdot
.648 .3081 Mdot
.648 .30812 Mdot
.648 .30814 Mdot
.648 .30819 Mdot
.648 .30823 Mdot
.648 .30828 Mdot
.648 .30831 Mdot
.648 .30833 Mdot
.648 .30836 Mdot
.648 .30859 Mdot
.648 .30859 Mdot
.648 .30864 Mdot
.648 .30869 Mdot
.648 .30873 Mdot
.648 .30875 Mdot
.648 .30875 Mdot
.648 .30885 Mdot
.648 .30887 Mdot
.648 .30929 Mdot
.648 .30934 Mdot
.648 .30936 Mdot
.648 .30936 Mdot
.648 .30944 Mdot
.648 .30944 Mdot
.648 .30953 Mdot
.648 .30957 Mdot
.648 .30961 Mdot
.648 .30977 Mdot
.648 .30994 Mdot
.648 .30994 Mdot
.648 .31001 Mdot
.648 .31019 Mdot
.648 .31032 Mdot
.648 .3104 Mdot
.648 .31042 Mdot
.648 .3105 Mdot
.648 .31052 Mdot
.648 .31054 Mdot
.648 .31067 Mdot
.648 .31076 Mdot
.648 .31079 Mdot
.648 .31082 Mdot
.648 .31102 Mdot
.648 .31105 Mdot
.648 .31117 Mdot
.648 .31119 Mdot
.648 .31127 Mdot
.648 .31141 Mdot
.648 .31144 Mdot
.648 .31167 Mdot
.648 .31172 Mdot
.648 .31174 Mdot
.648 .31176 Mdot
.648 .31178 Mdot
.648 .31181 Mdot
.648 .31189 Mdot
.648 .31189 Mdot
.648 .31212 Mdot
.648 .31212 Mdot
.648 .31216 Mdot
.648 .31218 Mdot
.648 .31219 Mdot
.648 .31221 Mdot
.648 .31255 Mdot
.648 .31276 Mdot
.648 .31296 Mdot
.648 .31296 Mdot
.648 .31302 Mdot
.648 .31314 Mdot
.648 .31351 Mdot
.648 .31382 Mdot
.648 .31385 Mdot
.648 .31385 Mdot
.648 .31391 Mdot
.648 .31397 Mdot
.648 .31399 Mdot
.648 .3142 Mdot
.648 .31433 Mdot
.648 .31441 Mdot
.648 .31443 Mdot
.648 .31445 Mdot
.648 .31445 Mdot
.648 .31446 Mdot
.648 .31457 Mdot
.648 .3147 Mdot
.648 .31515 Mdot
.648 .31521 Mdot
.648 .31536 Mdot
.648 .31539 Mdot
.648 .31553 Mdot
.648 .31554 Mdot
.648 .31555 Mdot
.648 .31558 Mdot
.648 .31563 Mdot
.648 .31564 Mdot
.648 .31597 Mdot
.648 .31605 Mdot
.648 .31627 Mdot
.648 .31649 Mdot
.648 .3165 Mdot
.648 .31651 Mdot
.648 .31654 Mdot
.648 .31674 Mdot
.648 .31741 Mdot
.648 .31754 Mdot
.648 .31759 Mdot
.648 .31782 Mdot
.648 .31787 Mdot
.648 .31802 Mdot
.648 .31804 Mdot
.648 .31807 Mdot
.648 .31861 Mdot
.648 .31865 Mdot
.648 .31902 Mdot
.648 .31921 Mdot
.648 .31932 Mdot
.648 .31933 Mdot
.648 .31937 Mdot
.648 .31953 Mdot
.648 .3196 Mdot
.648 .31972 Mdot
.648 .31995 Mdot
.648 .32016 Mdot
.648 .32019 Mdot
.648 .32022 Mdot
.648 .32024 Mdot
.648 .32031 Mdot
.648 .32042 Mdot
.648 .32042 Mdot
.648 .32078 Mdot
.648 .32108 Mdot
.648 .32108 Mdot
.648 .32129 Mdot
.648 .32139 Mdot
.648 .32143 Mdot
.648 .32151 Mdot
.648 .32155 Mdot
.648 .32169 Mdot
.648 .32235 Mdot
.648 .32238 Mdot
.648 .32243 Mdot
.648 .32261 Mdot
.648 .32262 Mdot
.648 .3227 Mdot
.648 .32272 Mdot
.648 .32276 Mdot
.648 .32281 Mdot
.648 .32282 Mdot
.648 .32286 Mdot
.648 .32301 Mdot
.648 .32304 Mdot
.648 .32309 Mdot
.648 .32313 Mdot
.648 .32327 Mdot
.648 .32335 Mdot
.648 .32342 Mdot
.648 .32345 Mdot
.648 .32349 Mdot
.648 .32354 Mdot
.648 .3241 Mdot
.648 .32413 Mdot
.648 .32415 Mdot
.648 .32419 Mdot
.648 .32427 Mdot
.648 .32429 Mdot
.648 .32442 Mdot
.648 .32443 Mdot
.648 .32452 Mdot
.648 .32452 Mdot
.648 .32458 Mdot
.648 .32459 Mdot
.648 .32488 Mdot
.648 .32489 Mdot
.648 .32493 Mdot
.648 .32493 Mdot
.648 .32498 Mdot
.648 .32523 Mdot
.648 .32527 Mdot
.648 .32551 Mdot
.648 .32587 Mdot
.648 .3261 Mdot
.648 .32626 Mdot
.648 .32631 Mdot
.648 .32632 Mdot
.648 .32639 Mdot
.648 .32653 Mdot
.648 .32655 Mdot
.648 .32656 Mdot
.648 .32658 Mdot
.648 .32678 Mdot
.648 .32691 Mdot
.648 .32703 Mdot
.648 .32707 Mdot
.648 .36367 Mdot
.648 .36369 Mdot
.648 .36379 Mdot
.648 .36388 Mdot
.648 .36404 Mdot
.648 .36405 Mdot
.648 .36406 Mdot
.648 .36408 Mdot
.648 .36419 Mdot
.648 .36424 Mdot
.648 .36425 Mdot
.648 .36429 Mdot
.648 .36441 Mdot
.648 .36459 Mdot
.648 .36486 Mdot
.648 .36505 Mdot
.648 .36509 Mdot
.648 .36527 Mdot
.648 .36531 Mdot
.648 .36532 Mdot
.648 .36535 Mdot
.648 .36535 Mdot
.648 .36557 Mdot
.648 .36558 Mdot
.648 .36563 Mdot
.648 .36563 Mdot
.648 .3657 Mdot
.648 .36581 Mdot
.648 .36582 Mdot
.648 .36589 Mdot
.648 .36592 Mdot
.648 .36593 Mdot
.648 .36595 Mdot
.648 .36639 Mdot
.648 .36642 Mdot
.648 .36646 Mdot
.648 .36648 Mdot
.648 .36654 Mdot
.648 .3666 Mdot
.648 .3667 Mdot
.648 .36673 Mdot
.648 .36677 Mdot
.648 .3668 Mdot
.648 .36691 Mdot
.648 .36694 Mdot
.648 .36695 Mdot
.648 .36699 Mdot
.648 .36702 Mdot
.648 .36703 Mdot
.648 .3671 Mdot
.648 .36711 Mdot
.648 .36724 Mdot
.648 .36728 Mdot
.648 .3673 Mdot
.648 .36782 Mdot
.648 .36792 Mdot
.648 .36796 Mdot
.648 .36802 Mdot
.648 .36804 Mdot
.648 .36812 Mdot
.648 .36828 Mdot
.648 .36829 Mdot
.648 .36851 Mdot
.648 .3688 Mdot
.648 .3688 Mdot
.648 .36888 Mdot
.648 .36893 Mdot
.648 .36895 Mdot
.648 .36897 Mdot
.648 .36899 Mdot
.648 .36916 Mdot
.648 .36933 Mdot
.648 .36943 Mdot
.648 .36948 Mdot
.648 .36961 Mdot
.648 .36964 Mdot
.648 .36964 Mdot
.648 .36973 Mdot
.648 .36987 Mdot
.648 .37016 Mdot
.648 .37019 Mdot
.648 .37061 Mdot
.648 .37063 Mdot
.648 .37065 Mdot
.648 .37076 Mdot
.648 .3708 Mdot
.648 .37098 Mdot
.648 .37102 Mdot
.648 .37111 Mdot
.648 .37164 Mdot
.648 .37179 Mdot
.648 .37181 Mdot
.648 .37182 Mdot
.648 .37182 Mdot
.648 .372 Mdot
.648 .37217 Mdot
.648 .37223 Mdot
.648 .37249 Mdot
.648 .37249 Mdot
.648 .37253 Mdot
.648 .37255 Mdot
.648 .37256 Mdot
.648 .37257 Mdot
.648 .37267 Mdot
.648 .3727 Mdot
.648 .37282 Mdot
.648 .37286 Mdot
.648 .37321 Mdot
.648 .37331 Mdot
.648 .37339 Mdot
.648 .3734 Mdot
.648 .3734 Mdot
.648 .37342 Mdot
.648 .37343 Mdot
.648 .3735 Mdot
.648 .3736 Mdot
.648 .37376 Mdot
.648 .37377 Mdot
.648 .37381 Mdot
.648 .37386 Mdot
.648 .37386 Mdot
.648 .37389 Mdot
.648 .37412 Mdot
.648 .37441 Mdot
.648 .3745 Mdot
.648 .37455 Mdot
.648 .37455 Mdot
.648 .3747 Mdot
.648 .37487 Mdot
.648 .37513 Mdot
.648 .37514 Mdot
.648 .37515 Mdot
.648 .37517 Mdot
.648 .3752 Mdot
.648 .3752 Mdot
.648 .37538 Mdot
.648 .37538 Mdot
.648 .37544 Mdot
.648 .37546 Mdot
.648 .37547 Mdot
.648 .3755 Mdot
.648 .37551 Mdot
.648 .37554 Mdot
.648 .37573 Mdot
.648 .37575 Mdot
.648 .37585 Mdot
.648 .37591 Mdot
.648 .37593 Mdot
.648 .37603 Mdot
.648 .37605 Mdot
.648 .37621 Mdot
.648 .37623 Mdot
.648 .37625 Mdot
.648 .37632 Mdot
.648 .37642 Mdot
.648 .37643 Mdot
.648 .37645 Mdot
.648 .37651 Mdot
.648 .37652 Mdot
.648 .37659 Mdot
.648 .37669 Mdot
.648 .37683 Mdot
.648 .37688 Mdot
.648 .37688 Mdot
.648 .37702 Mdot
.648 .37713 Mdot
.648 .37716 Mdot
.648 .3772 Mdot
.648 .37726 Mdot
.648 .37727 Mdot
.648 .37733 Mdot
.648 .37733 Mdot
.648 .37734 Mdot
.648 .37739 Mdot
.648 .37771 Mdot
.648 .37772 Mdot
.648 .3778 Mdot
.648 .3778 Mdot
.648 .37782 Mdot
.648 .37784 Mdot
.648 .37788 Mdot
.648 .37792 Mdot
.648 .37792 Mdot
.648 .3781 Mdot
.648 .37812 Mdot
.648 .37814 Mdot
.648 .37816 Mdot
.648 .3782 Mdot
.648 .37823 Mdot
.648 .37827 Mdot
.648 .37828 Mdot
.648 .3783 Mdot
.648 .37831 Mdot
.648 .37832 Mdot
.648 .37834 Mdot
.648 .37834 Mdot
.648 .3784 Mdot
.648 .37884 Mdot
.648 .379 Mdot
.648 .37907 Mdot
.648 .37913 Mdot
.648 .37917 Mdot
.648 .37918 Mdot
.648 .37923 Mdot
.648 .37924 Mdot
.648 .37924 Mdot
.648 .37932 Mdot
.648 .37942 Mdot
.648 .3796 Mdot
.648 .37965 Mdot
.648 .37971 Mdot
.648 .37976 Mdot
.648 .37995 Mdot
.648 .38 Mdot
.648 .38001 Mdot
.648 .38001 Mdot
.648 .38008 Mdot
.648 .38014 Mdot
.648 .38016 Mdot
.648 .38025 Mdot
.648 .38026 Mdot
.648 .38028 Mdot
.648 .38031 Mdot
.648 .3805 Mdot
.648 .38057 Mdot
.648 .38057 Mdot
.648 .38057 Mdot
.648 .38058 Mdot
.648 .38058 Mdot
.648 .38061 Mdot
.648 .3807 Mdot
.648 .38098 Mdot
.648 .38119 Mdot
.648 .38121 Mdot
.648 .38129 Mdot
.648 .38132 Mdot
.648 .3814 Mdot
.648 .38147 Mdot
.648 .3815 Mdot
.648 .38164 Mdot
.648 .38168 Mdot
.648 .3817 Mdot
.648 .38174 Mdot
.648 .38181 Mdot
.648 .38185 Mdot
.648 .3819 Mdot
.648 .38199 Mdot
.648 .38215 Mdot
.648 .38216 Mdot
.648 .38225 Mdot
.648 .38226 Mdot
.648 .38227 Mdot
.648 .3823 Mdot
.648 .38256 Mdot
.648 .38262 Mdot
.648 .38264 Mdot
.648 .38264 Mdot
.648 .38292 Mdot
.648 .383 Mdot
.648 .38311 Mdot
.648 .38311 Mdot
.648 .38312 Mdot
.648 .38326 Mdot
.648 .38334 Mdot
.648 .38337 Mdot
.648 .38341 Mdot
.648 .38344 Mdot
.648 .38358 Mdot
.648 .38367 Mdot
.648 .38368 Mdot
.648 .38372 Mdot
.648 .38373 Mdot
.648 .38382 Mdot
.648 .38384 Mdot
.648 .38385 Mdot
.648 .38402 Mdot
.648 .38418 Mdot
.648 .38421 Mdot
.648 .38422 Mdot
.648 .38423 Mdot
.648 .38427 Mdot
.648 .38428 Mdot
.648 .38441 Mdot
.648 .38441 Mdot
.648 .38443 Mdot
.648 .38447 Mdot
.648 .38448 Mdot
.648 .38448 Mdot
.648 .38453 Mdot
.648 .38453 Mdot
.648 .38456 Mdot
.648 .38457 Mdot
.648 .38457 Mdot
.648 .38465 Mdot
.648 .38468 Mdot
.648 .38469 Mdot
.648 .38469 Mdot
.648 .38491 Mdot
.648 .38491 Mdot
.648 .38492 Mdot
.648 .38498 Mdot
.648 .38501 Mdot
.648 .38501 Mdot
.648 .38506 Mdot
.648 .38534 Mdot
.648 .38541 Mdot
.648 .38546 Mdot
.648 .38562 Mdot
.648 .38564 Mdot
.648 .38567 Mdot
.648 .38583 Mdot
.648 .38584 Mdot
.648 .38591 Mdot
.648 .38592 Mdot
.648 .38607 Mdot
.648 .38616 Mdot
.648 .3862 Mdot
.648 .3863 Mdot
.648 .38636 Mdot
.648 .38641 Mdot
.648 .38643 Mdot
.648 .38648 Mdot
.648 .38649 Mdot
.648 .38661 Mdot
.648 .38678 Mdot
.648 .38685 Mdot
.648 .38685 Mdot
.648 .38686 Mdot
.648 .38686 Mdot
.648 .38701 Mdot
.648 .38705 Mdot
.648 .38719 Mdot
.648 .38765 Mdot
.648 .38765 Mdot
.648 .38769 Mdot
.648 .38779 Mdot
.648 .38789 Mdot
.648 .38815 Mdot
.648 .38818 Mdot
.648 .3882 Mdot
.648 .3882 Mdot
.648 .38823 Mdot
.648 .38827 Mdot
.648 .38829 Mdot
.648 .3883 Mdot
.648 .38846 Mdot
.648 .38848 Mdot
.648 .3885 Mdot
.648 .38875 Mdot
.648 .38878 Mdot
.648 .38888 Mdot
.648 .3889 Mdot
.648 .38897 Mdot
.648 .38906 Mdot
.648 .38917 Mdot
.648 .38923 Mdot
.648 .38927 Mdot
.648 .38931 Mdot
.648 .38932 Mdot
.648 .38933 Mdot
.648 .38939 Mdot
.648 .38943 Mdot
.648 .38944 Mdot
.648 .38946 Mdot
.648 .38956 Mdot
.648 .38962 Mdot
.648 .38963 Mdot
.648 .38966 Mdot
.648 .38974 Mdot
.648 .38987 Mdot
.648 .38988 Mdot
.648 .38991 Mdot
.648 .38995 Mdot
.648 .39006 Mdot
.648 .39009 Mdot
.648 .39044 Mdot
.648 .39053 Mdot
.648 .39069 Mdot
.648 .39084 Mdot
.648 .39085 Mdot
.648 .39085 Mdot
.648 .39088 Mdot
.648 .3909 Mdot
.648 .39091 Mdot
.648 .39101 Mdot
.648 .39107 Mdot
.648 .39111 Mdot
.648 .39112 Mdot
.648 .39113 Mdot
.648 .39113 Mdot
.648 .39113 Mdot
.648 .39118 Mdot
.648 .39124 Mdot
.648 .39145 Mdot
.648 .39147 Mdot
.648 .39155 Mdot
.648 .39156 Mdot
.648 .39162 Mdot
.648 .39162 Mdot
.648 .39163 Mdot
.648 .39164 Mdot
.648 .39167 Mdot
.648 .39167 Mdot
.648 .39182 Mdot
.648 .39186 Mdot
.648 .39196 Mdot
.648 .39206 Mdot
.648 .39207 Mdot
.648 .39207 Mdot
.648 .39208 Mdot
.648 .39218 Mdot
.648 .39249 Mdot
.648 .39254 Mdot
.648 .39257 Mdot
.648 .39267 Mdot
.648 .3927 Mdot
.648 .39277 Mdot
.648 .39278 Mdot
.648 .39279 Mdot
.648 .39304 Mdot
.648 .39305 Mdot
.648 .39323 Mdot
.648 .39331 Mdot
.648 .39336 Mdot
.648 .39337 Mdot
.648 .39339 Mdot
.648 .39346 Mdot
.648 .39349 Mdot
.648 .39355 Mdot
.648 .39365 Mdot
.648 .39375 Mdot
.648 .39376 Mdot
.648 .39378 Mdot
.648 .39379 Mdot
.648 .39382 Mdot
.648 .39387 Mdot
.648 .39387 Mdot
.648 .39404 Mdot
.648 .39417 Mdot
.648 .39417 Mdot
.648 .39427 Mdot
.648 .39431 Mdot
.648 .39433 Mdot
.648 .39437 Mdot
.648 .39439 Mdot
.648 .39445 Mdot
.648 .39476 Mdot
.648 .39477 Mdot
.648 .39479 Mdot
.648 .39487 Mdot
.648 .39488 Mdot
.648 .39492 Mdot
.648 .39492 Mdot
.648 .39494 Mdot
.648 .39497 Mdot
.648 .39497 Mdot
.648 .39499 Mdot
.648 .39506 Mdot
.648 .39507 Mdot
.648 .39509 Mdot
.648 .39511 Mdot
.648 .39518 Mdot
.648 .39521 Mdot
.648 .39525 Mdot
.648 .39526 Mdot
.648 .39528 Mdot
.648 .3953 Mdot
.648 .39556 Mdot
.648 .39557 Mdot
.648 .39558 Mdot
.648 .3956 Mdot
.648 .39564 Mdot
.648 .39565 Mdot
.648 .39571 Mdot
.648 .39575 Mdot
.648 .39575 Mdot
.648 .39578 Mdot
.648 .39579 Mdot
.648 .39592 Mdot
.648 .39592 Mdot
.648 .39594 Mdot
.648 .39594 Mdot
.648 .39596 Mdot
.648 .39608 Mdot
.648 .3961 Mdot
.648 .39621 Mdot
.648 .39637 Mdot
.648 .39648 Mdot
.648 .39655 Mdot
.648 .39658 Mdot
.648 .39658 Mdot
.648 .39661 Mdot
.648 .39667 Mdot
.648 .39668 Mdot
.648 .39669 Mdot
.648 .3967 Mdot
.648 .39679 Mdot
.648 .39685 Mdot
.648 .3969 Mdot
.648 .39692 Mdot
.65 .28316 Mdot
.65 .28318 Mdot
.65 .28331 Mdot
.65 .28348 Mdot
.65 .28368 Mdot
.65 .28376 Mdot
.65 .28378 Mdot
.65 .28391 Mdot
.65 .28395 Mdot
.65 .28403 Mdot
.65 .28423 Mdot
.65 .28435 Mdot
.65 .28482 Mdot
.65 .28487 Mdot
.65 .28505 Mdot
.65 .28509 Mdot
.65 .28509 Mdot
.65 .28527 Mdot
.65 .2853 Mdot
.65 .28536 Mdot
.65 .28536 Mdot
.65 .28539 Mdot
.65 .2854 Mdot
.65 .28544 Mdot
.65 .28551 Mdot
.65 .28564 Mdot
.65 .28575 Mdot
.65 .28592 Mdot
.65 .28595 Mdot
.65 .28602 Mdot
.65 .28603 Mdot
.65 .28604 Mdot
.65 .2861 Mdot
.65 .28612 Mdot
.65 .28626 Mdot
.65 .28636 Mdot
.65 .28639 Mdot
.65 .28639 Mdot
.65 .28642 Mdot
.65 .28652 Mdot
.65 .28655 Mdot
.65 .28656 Mdot
.65 .28666 Mdot
.65 .28668 Mdot
.65 .28669 Mdot
.65 .28673 Mdot
.65 .28676 Mdot
.65 .28677 Mdot
.65 .28694 Mdot
.65 .28694 Mdot
.65 .28696 Mdot
.65 .28708 Mdot
.65 .2871 Mdot
.65 .28733 Mdot
.65 .28747 Mdot
.65 .28753 Mdot
.65 .28754 Mdot
.65 .28757 Mdot
.65 .28763 Mdot
.65 .2877 Mdot
.65 .28774 Mdot
.65 .28775 Mdot
.65 .28781 Mdot
.65 .28784 Mdot
.65 .28804 Mdot
.65 .28808 Mdot
.65 .28815 Mdot
.65 .28821 Mdot
.65 .28826 Mdot
.65 .28827 Mdot
.65 .28836 Mdot
.65 .28854 Mdot
.65 .28856 Mdot
.65 .28898 Mdot
.65 .28899 Mdot
.65 .28899 Mdot
.65 .28906 Mdot
.65 .28915 Mdot
.65 .28915 Mdot
.65 .28924 Mdot
.65 .28958 Mdot
.65 .28959 Mdot
.65 .28962 Mdot
.65 .28966 Mdot
.65 .28972 Mdot
.65 .28981 Mdot
.65 .28983 Mdot
.65 .28992 Mdot
.65 .29005 Mdot
.65 .29026 Mdot
.65 .29027 Mdot
.65 .29045 Mdot
.65 .29046 Mdot
.65 .29047 Mdot
.65 .29053 Mdot
.65 .29059 Mdot
.65 .29062 Mdot
.65 .29068 Mdot
.65 .29073 Mdot
.65 .29073 Mdot
.65 .29076 Mdot
.65 .29081 Mdot
.65 .29093 Mdot
.65 .29098 Mdot
.65 .2911 Mdot
.65 .29117 Mdot
.65 .29118 Mdot
.65 .2912 Mdot
.65 .29124 Mdot
.65 .29132 Mdot
.65 .29133 Mdot
.65 .29135 Mdot
.65 .29138 Mdot
.65 .29143 Mdot
.65 .2915 Mdot
.65 .29165 Mdot
.65 .29169 Mdot
.65 .29173 Mdot
.65 .29189 Mdot
.65 .29189 Mdot
.65 .29194 Mdot
.65 .29195 Mdot
.65 .29209 Mdot
.65 .29216 Mdot
.65 .29222 Mdot
.65 .29235 Mdot
.65 .29238 Mdot
.65 .29245 Mdot
.65 .29245 Mdot
.65 .2926 Mdot
.65 .29265 Mdot
.65 .29266 Mdot
.65 .29272 Mdot
.65 .29275 Mdot
.65 .29276 Mdot
.65 .2928 Mdot
.65 .29284 Mdot
.65 .29297 Mdot
.65 .29298 Mdot
.65 .29298 Mdot
.65 .29302 Mdot
.65 .29307 Mdot
.65 .29312 Mdot
.65 .2932 Mdot
.65 .2932 Mdot
.65 .29323 Mdot
.65 .29324 Mdot
.65 .29371 Mdot
.65 .29377 Mdot
.65 .2938 Mdot
.65 .29399 Mdot
.65 .294 Mdot
.65 .29404 Mdot
.65 .2941 Mdot
.65 .29425 Mdot
.65 .29437 Mdot
.65 .29441 Mdot
.65 .29467 Mdot
.65 .29476 Mdot
.65 .29479 Mdot
.65 .29481 Mdot
.65 .29503 Mdot
.65 .29508 Mdot
.65 .29522 Mdot
.65 .29534 Mdot
.65 .29545 Mdot
.65 .2955 Mdot
.65 .2956 Mdot
.65 .29563 Mdot
.65 .29571 Mdot
.65 .29574 Mdot
.65 .29578 Mdot
.65 .29588 Mdot
.65 .29648 Mdot
.65 .29654 Mdot
.65 .2966 Mdot
.65 .29667 Mdot
.65 .29671 Mdot
.65 .29682 Mdot
.65 .29686 Mdot
.65 .29689 Mdot
.65 .29696 Mdot
.65 .29698 Mdot
.65 .29705 Mdot
.65 .29707 Mdot
.65 .29721 Mdot
.65 .29732 Mdot
.65 .29734 Mdot
.65 .29743 Mdot
.65 .29743 Mdot
.65 .29746 Mdot
.65 .29768 Mdot
.65 .29788 Mdot
.65 .29792 Mdot
.65 .29807 Mdot
.65 .29822 Mdot
.65 .2983 Mdot
.65 .29835 Mdot
.65 .29841 Mdot
.65 .29866 Mdot
.65 .2987 Mdot
.65 .29872 Mdot
.65 .29879 Mdot
.65 .29886 Mdot
.65 .29895 Mdot
.65 .29921 Mdot
.65 .29929 Mdot
.65 .29933 Mdot
.65 .29944 Mdot
.65 .29946 Mdot
.65 .29949 Mdot
.65 .29952 Mdot
.65 .29965 Mdot
.65 .29969 Mdot
.65 .29978 Mdot
.65 .29981 Mdot
.65 .29982 Mdot
.65 .29983 Mdot
.65 .29984 Mdot
.65 .29986 Mdot
.65 .29991 Mdot
.65 .30003 Mdot
.65 .30006 Mdot
.65 .30012 Mdot
.65 .30014 Mdot
.65 .30035 Mdot
.65 .3004 Mdot
.65 .30044 Mdot
.65 .30048 Mdot
.65 .30067 Mdot
.65 .3007 Mdot
.65 .30073 Mdot
.65 .30078 Mdot
.65 .30087 Mdot
.65 .30096 Mdot
.65 .30098 Mdot
.65 .3011 Mdot
.65 .3013 Mdot
.65 .30131 Mdot
.65 .30146 Mdot
.65 .30147 Mdot
.65 .30157 Mdot
.65 .30158 Mdot
.65 .30161 Mdot
.65 .30169 Mdot
.65 .30173 Mdot
.65 .30177 Mdot
.65 .30181 Mdot
.65 .30217 Mdot
.65 .30222 Mdot
.65 .30233 Mdot
.65 .30242 Mdot
.65 .30255 Mdot
.65 .30279 Mdot
.65 .30281 Mdot
.65 .30288 Mdot
.65 .30306 Mdot
.65 .30313 Mdot
.65 .30321 Mdot
.65 .30325 Mdot
.65 .30328 Mdot
.65 .30328 Mdot
.65 .30345 Mdot
.65 .30375 Mdot
.65 .3038 Mdot
.65 .30382 Mdot
.65 .30388 Mdot
.65 .30388 Mdot
.65 .30388 Mdot
.65 .30399 Mdot
.65 .30402 Mdot
.65 .30403 Mdot
.65 .30407 Mdot
.65 .30407 Mdot
.65 .30425 Mdot
.65 .30436 Mdot
.65 .3044 Mdot
.65 .30449 Mdot
.65 .30449 Mdot
.65 .30453 Mdot
.65 .30464 Mdot
.65 .30467 Mdot
.65 .30476 Mdot
.65 .3048 Mdot
.65 .30484 Mdot
.65 .30485 Mdot
.65 .30486 Mdot
.65 .30491 Mdot
.65 .30494 Mdot
.65 .30509 Mdot
.65 .30516 Mdot
.65 .30521 Mdot
.65 .30527 Mdot
.65 .30537 Mdot
.65 .30548 Mdot
.65 .30562 Mdot
.65 .30569 Mdot
.65 .30584 Mdot
.65 .30587 Mdot
.65 .30589 Mdot
.65 .30609 Mdot
.65 .3062 Mdot
.65 .3065 Mdot
.65 .30666 Mdot
.65 .30667 Mdot
.65 .30674 Mdot
.65 .30678 Mdot
.65 .30692 Mdot
.65 .30697 Mdot
.65 .307 Mdot
.65 .30714 Mdot
.65 .30722 Mdot
.65 .30737 Mdot
.65 .30755 Mdot
.65 .30761 Mdot
.65 .30768 Mdot
.65 .3077 Mdot
.65 .30778 Mdot
.65 .30778 Mdot
.65 .30785 Mdot
.65 .30794 Mdot
.65 .30795 Mdot
.65 .30804 Mdot
.65 .3083 Mdot
.65 .30834 Mdot
.65 .30839 Mdot
.65 .30855 Mdot
.65 .30855 Mdot
.65 .30857 Mdot
.65 .30868 Mdot
.65 .30899 Mdot
.65 .30905 Mdot
.65 .30918 Mdot
.65 .30925 Mdot
.65 .30933 Mdot
.65 .3095 Mdot
.65 .3096 Mdot
.65 .30968 Mdot
.65 .30969 Mdot
.65 .31001 Mdot
.65 .31006 Mdot
.65 .31017 Mdot
.65 .31069 Mdot
.65 .31095 Mdot
.65 .31097 Mdot
.65 .31101 Mdot
.65 .31102 Mdot
.65 .31103 Mdot
.65 .31117 Mdot
.65 .31124 Mdot
.65 .31134 Mdot
.65 .3114 Mdot
.65 .3114 Mdot
.65 .31141 Mdot
.65 .31159 Mdot
.65 .31163 Mdot
.65 .31171 Mdot
.65 .31178 Mdot
.65 .31179 Mdot
.65 .31181 Mdot
.65 .31183 Mdot
.65 .31194 Mdot
.65 .31194 Mdot
.65 .31195 Mdot
.65 .31204 Mdot
.65 .31229 Mdot
.65 .31229 Mdot
.65 .31231 Mdot
.65 .31235 Mdot
.65 .31242 Mdot
.65 .31246 Mdot
.65 .31259 Mdot
.65 .31269 Mdot
.65 .31278 Mdot
.65 .3129 Mdot
.65 .31314 Mdot
.65 .31315 Mdot
.65 .31315 Mdot
.65 .31325 Mdot
.65 .31325 Mdot
.65 .31351 Mdot
.65 .31358 Mdot
.65 .31364 Mdot
.65 .31365 Mdot
.65 .3139 Mdot
.65 .31402 Mdot
.65 .31403 Mdot
.65 .31407 Mdot
.65 .3141 Mdot
.65 .31415 Mdot
.65 .31418 Mdot
.65 .3142 Mdot
.65 .31433 Mdot
.65 .3144 Mdot
.65 .31444 Mdot
.65 .31446 Mdot
.65 .31457 Mdot
.65 .31478 Mdot
.65 .31487 Mdot
.65 .31506 Mdot
.65 .31516 Mdot
.65 .3152 Mdot
.65 .3152 Mdot
.65 .31529 Mdot
.65 .31538 Mdot
.65 .31543 Mdot
.65 .31554 Mdot
.65 .31565 Mdot
.65 .31566 Mdot
.65 .31567 Mdot
.65 .31598 Mdot
.65 .316 Mdot
.65 .31636 Mdot
.65 .31657 Mdot
.65 .31673 Mdot
.65 .31676 Mdot
.65 .31691 Mdot
.65 .31701 Mdot
.65 .31708 Mdot
.65 .31713 Mdot
.65 .31715 Mdot
.65 .31772 Mdot
.65 .31787 Mdot
.65 .31788 Mdot
.65 .31802 Mdot
.65 .31815 Mdot
.65 .31815 Mdot
.65 .31817 Mdot
.65 .31887 Mdot
.65 .3189 Mdot
.65 .3192 Mdot
.65 .31935 Mdot
.65 .31938 Mdot
.65 .31946 Mdot
.65 .31957 Mdot
.65 .31968 Mdot
.65 .31975 Mdot
.65 .32008 Mdot
.65 .32013 Mdot
.65 .32024 Mdot
.65 .32025 Mdot
.65 .32032 Mdot
.65 .32044 Mdot
.65 .32054 Mdot
.65 .3206 Mdot
.65 .32062 Mdot
.65 .32071 Mdot
.65 .32095 Mdot
.65 .32133 Mdot
.65 .32137 Mdot
.65 .32157 Mdot
.65 .32161 Mdot
.65 .32161 Mdot
.65 .32189 Mdot
.65 .32192 Mdot
.65 .32197 Mdot
.65 .32203 Mdot
.65 .32204 Mdot
.65 .32208 Mdot
.65 .32225 Mdot
.65 .32227 Mdot
.65 .32232 Mdot
.65 .32248 Mdot
.65 .32254 Mdot
.65 .32254 Mdot
.65 .32259 Mdot
.65 .32275 Mdot
.65 .32299 Mdot
.65 .32303 Mdot
.65 .32312 Mdot
.65 .32314 Mdot
.65 .32315 Mdot
.65 .32327 Mdot
.65 .32333 Mdot
.65 .32361 Mdot
.65 .32381 Mdot
.65 .32403 Mdot
.65 .32414 Mdot
.65 .32421 Mdot
.65 .32423 Mdot
.65 .32427 Mdot
.65 .32427 Mdot
.65 .32437 Mdot
.65 .32442 Mdot
.65 .32473 Mdot
.65 .32474 Mdot
.65 .3248 Mdot
.65 .3251 Mdot
.65 .32519 Mdot
.65 .32599 Mdot
.65 .32618 Mdot
.65 .32653 Mdot
.65 .32666 Mdot
.65 .32673 Mdot
.65 .32695 Mdot
.65 .32698 Mdot
.65 .32712 Mdot
.65 .32745 Mdot
.65 .32774 Mdot
.65 .32797 Mdot
.65 .32799 Mdot
.65 .3637 Mdot
.65 .36371 Mdot
.65 .36389 Mdot
.65 .36411 Mdot
.65 .36437 Mdot
.65 .36448 Mdot
.65 .36449 Mdot
.65 .36466 Mdot
.65 .36472 Mdot
.65 .36482 Mdot
.65 .36509 Mdot
.65 .36523 Mdot
.65 .36585 Mdot
.65 .36592 Mdot
.65 .36615 Mdot
.65 .3662 Mdot
.65 .36621 Mdot
.65 .36644 Mdot
.65 .36648 Mdot
.65 .36656 Mdot
.65 .36656 Mdot
.65 .36659 Mdot
.65 .3666 Mdot
.65 .36666 Mdot
.65 .36674 Mdot
.65 .36691 Mdot
.65 .36707 Mdot
.65 .36728 Mdot
.65 .36733 Mdot
.65 .36742 Mdot
.65 .36743 Mdot
.65 .36744 Mdot
.65 .36751 Mdot
.65 .36754 Mdot
.65 .36773 Mdot
.65 .36785 Mdot
.65 .36789 Mdot
.65 .36789 Mdot
.65 .36793 Mdot
.65 .36805 Mdot
.65 .36809 Mdot
.65 .36811 Mdot
.65 .36824 Mdot
.65 .36827 Mdot
.65 .36828 Mdot
.65 .36833 Mdot
.65 .36837 Mdot
.65 .36839 Mdot
.65 .36861 Mdot
.65 .36861 Mdot
.65 .36864 Mdot
.65 .36879 Mdot
.65 .36882 Mdot
.65 .36911 Mdot
.65 .36929 Mdot
.65 .36937 Mdot
.65 .36939 Mdot
.65 .36943 Mdot
.65 .36951 Mdot
.65 .3696 Mdot
.65 .36965 Mdot
.65 .36966 Mdot
.65 .36974 Mdot
.65 .36978 Mdot
.65 .37003 Mdot
.65 .37009 Mdot
.65 .37018 Mdot
.65 .37026 Mdot
.65 .37032 Mdot
.65 .37034 Mdot
.65 .37046 Mdot
.65 .37069 Mdot
.65 .37071 Mdot
.65 .37125 Mdot
.65 .37127 Mdot
.65 .37127 Mdot
.65 .37137 Mdot
.65 .37147 Mdot
.65 .37148 Mdot
.65 .3716 Mdot
.65 .37204 Mdot
.65 .37205 Mdot
.65 .37209 Mdot
.65 .37215 Mdot
.65 .37222 Mdot
.65 .37234 Mdot
.65 .37236 Mdot
.65 .37248 Mdot
.65 .37264 Mdot
.65 .37292 Mdot
.65 .37293 Mdot
.65 .37317 Mdot
.65 .37318 Mdot
.65 .37319 Mdot
.65 .37328 Mdot
.65 .37336 Mdot
.65 .3734 Mdot
.65 .37347 Mdot
.65 .37353 Mdot
.65 .37354 Mdot
.65 .37357 Mdot
.65 .37364 Mdot
.65 .37379 Mdot
.65 .37386 Mdot
.65 .37402 Mdot
.65 .3741 Mdot
.65 .37412 Mdot
.65 .37415 Mdot
.65 .3742 Mdot
.65 .37431 Mdot
.65 .37432 Mdot
.65 .37434 Mdot
.65 .37438 Mdot
.65 .37441 Mdot
.65 .37444 Mdot
.65 .37444 Mdot
.65 .37453 Mdot
.65 .37473 Mdot
.65 .37474 Mdot
.65 .37478 Mdot
.65 .37484 Mdot
.65 .37504 Mdot
.65 .37504 Mdot
.65 .37511 Mdot
.65 .37511 Mdot
.65 .37512 Mdot
.65 .37531 Mdot
.65 .3754 Mdot
.65 .37547 Mdot
.65 .37554 Mdot
.65 .37565 Mdot
.65 .37568 Mdot
.65 .37573 Mdot
.65 .37576 Mdot
.65 .37577 Mdot
.65 .37578 Mdot
.65 .37597 Mdot
.65 .37603 Mdot
.65 .37604 Mdot
.65 .37604 Mdot
.65 .37613 Mdot
.65 .37614 Mdot
.65 .37616 Mdot
.65 .37617 Mdot
.65 .37622 Mdot
.65 .37628 Mdot
.65 .37631 Mdot
.65 .37645 Mdot
.65 .37646 Mdot
.65 .37646 Mdot
.65 .37651 Mdot
.65 .37658 Mdot
.65 .37664 Mdot
.65 .37674 Mdot
.65 .37675 Mdot
.65 .37676 Mdot
.65 .37679 Mdot
.65 .3768 Mdot
.65 .37701 Mdot
.65 .3774 Mdot
.65 .37749 Mdot
.65 .37753 Mdot
.65 .37778 Mdot
.65 .37778 Mdot
.65 .37784 Mdot
.65 .37792 Mdot
.65 .37805 Mdot
.65 .37811 Mdot
.65 .37817 Mdot
.65 .37826 Mdot
.65 .37831 Mdot
.65 .37855 Mdot
.65 .37863 Mdot
.65 .37865 Mdot
.65 .37865 Mdot
.65 .37878 Mdot
.65 .37881 Mdot
.65 .37884 Mdot
.65 .37905 Mdot
.65 .37911 Mdot
.65 .37912 Mdot
.65 .37919 Mdot
.65 .37924 Mdot
.65 .37924 Mdot
.65 .3793 Mdot
.65 .37932 Mdot
.65 .37938 Mdot
.65 .37942 Mdot
.65 .37956 Mdot
.65 .37967 Mdot
.65 .37974 Mdot
.65 .37984 Mdot
.65 .37986 Mdot
.65 .37991 Mdot
.65 .38001 Mdot
.65 .38004 Mdot
.65 .38009 Mdot
.65 .3801 Mdot
.65 .38022 Mdot
.65 .38046 Mdot
.65 .38054 Mdot
.65 .3807 Mdot
.65 .38071 Mdot
.65 .38073 Mdot
.65 .38085 Mdot
.65 .38091 Mdot
.65 .38101 Mdot
.65 .38109 Mdot
.65 .38117 Mdot
.65 .38122 Mdot
.65 .38126 Mdot
.65 .38131 Mdot
.65 .38142 Mdot
.65 .38145 Mdot
.65 .38149 Mdot
.65 .38149 Mdot
.65 .3815 Mdot
.65 .38154 Mdot
.65 .38157 Mdot
.65 .38164 Mdot
.65 .38166 Mdot
.65 .38175 Mdot
.65 .38177 Mdot
.65 .38177 Mdot
.65 .38184 Mdot
.65 .38187 Mdot
.65 .38196 Mdot
.65 .38209 Mdot
.65 .3821 Mdot
.65 .38213 Mdot
.65 .38214 Mdot
.65 .38216 Mdot
.65 .38224 Mdot
.65 .38224 Mdot
.65 .38224 Mdot
.65 .38229 Mdot
.65 .38231 Mdot
.65 .38234 Mdot
.65 .38257 Mdot
.65 .3827 Mdot
.65 .38271 Mdot
.65 .38276 Mdot
.65 .38282 Mdot
.65 .38288 Mdot
.65 .38301 Mdot
.65 .38307 Mdot
.65 .38308 Mdot
.65 .38327 Mdot
.65 .38337 Mdot
.65 .38344 Mdot
.65 .38352 Mdot
.65 .38356 Mdot
.65 .38384 Mdot
.65 .38387 Mdot
.65 .38389 Mdot
.65 .38392 Mdot
.65 .38399 Mdot
.65 .38401 Mdot
.65 .38402 Mdot
.65 .3841 Mdot
.65 .3841 Mdot
.65 .38422 Mdot
.65 .38423 Mdot
.65 .38439 Mdot
.65 .38447 Mdot
.65 .38449 Mdot
.65 .38456 Mdot
.65 .38463 Mdot
.65 .38466 Mdot
.65 .38469 Mdot
.65 .38472 Mdot
.65 .38486 Mdot
.65 .38489 Mdot
.65 .38492 Mdot
.65 .38496 Mdot
.65 .38512 Mdot
.65 .38513 Mdot
.65 .38518 Mdot
.65 .38521 Mdot
.65 .3853 Mdot
.65 .38534 Mdot
.65 .38535 Mdot
.65 .38536 Mdot
.65 .38537 Mdot
.65 .38537 Mdot
.65 .3854 Mdot
.65 .38547 Mdot
.65 .38549 Mdot
.65 .3856 Mdot
.65 .38562 Mdot
.65 .38564 Mdot
.65 .38566 Mdot
.65 .38574 Mdot
.65 .38577 Mdot
.65 .38583 Mdot
.65 .38604 Mdot
.65 .3861 Mdot
.65 .38616 Mdot
.65 .38621 Mdot
.65 .38623 Mdot
.65 .38626 Mdot
.65 .38645 Mdot
.65 .3865 Mdot
.65 .38654 Mdot
.65 .3866 Mdot
.65 .38671 Mdot
.65 .38683 Mdot
.65 .38686 Mdot
.65 .38701 Mdot
.65 .38718 Mdot
.65 .3872 Mdot
.65 .38721 Mdot
.65 .38727 Mdot
.65 .38729 Mdot
.65 .38737 Mdot
.65 .38748 Mdot
.65 .3875 Mdot
.65 .38755 Mdot
.65 .38756 Mdot
.65 .38762 Mdot
.65 .38764 Mdot
.65 .38767 Mdot
.65 .38776 Mdot
.65 .38779 Mdot
.65 .38784 Mdot
.65 .38789 Mdot
.65 .38794 Mdot
.65 .3884 Mdot
.65 .38848 Mdot
.65 .38851 Mdot
.65 .38853 Mdot
.65 .38859 Mdot
.65 .38861 Mdot
.65 .38869 Mdot
.65 .38873 Mdot
.65 .38881 Mdot
.65 .3889 Mdot
.65 .38901 Mdot
.65 .38905 Mdot
.65 .38922 Mdot
.65 .38923 Mdot
.65 .38926 Mdot
.65 .38933 Mdot
.65 .38953 Mdot
.65 .38956 Mdot
.65 .38965 Mdot
.65 .38976 Mdot
.65 .38981 Mdot
.65 .38985 Mdot
.65 .38985 Mdot
.65 .39 Mdot
.65 .39002 Mdot
.65 .39007 Mdot
.65 .39043 Mdot
.65 .39043 Mdot
.65 .39046 Mdot
.65 .39046 Mdot
.65 .39052 Mdot
.65 .39055 Mdot
.65 .3906 Mdot
.65 .39063 Mdot
.65 .39063 Mdot
.65 .39063 Mdot
.65 .39073 Mdot
.65 .39077 Mdot
.65 .3908 Mdot
.65 .39081 Mdot
.65 .39083 Mdot
.65 .39087 Mdot
.65 .39088 Mdot
.65 .39092 Mdot
.65 .39103 Mdot
.65 .39104 Mdot
.65 .39109 Mdot
.65 .39111 Mdot
.65 .39122 Mdot
.65 .39126 Mdot
.65 .39131 Mdot
.65 .39142 Mdot
.65 .39143 Mdot
.65 .39147 Mdot
.65 .39147 Mdot
.65 .39159 Mdot
.65 .39162 Mdot
.65 .39165 Mdot
.65 .39177 Mdot
.65 .39182 Mdot
.65 .39186 Mdot
.65 .39188 Mdot
.65 .39189 Mdot
.65 .3919 Mdot
.65 .39196 Mdot
.65 .392 Mdot
.65 .39201 Mdot
.65 .39202 Mdot
.65 .39207 Mdot
.65 .39217 Mdot
.65 .39221 Mdot
.65 .3923 Mdot
.65 .39234 Mdot
.65 .39236 Mdot
.65 .39236 Mdot
.65 .3924 Mdot
.65 .39244 Mdot
.65 .39246 Mdot
.65 .39251 Mdot
.65 .39256 Mdot
.65 .39257 Mdot
.65 .39257 Mdot
.65 .39271 Mdot
.65 .39272 Mdot
.65 .39289 Mdot
.65 .39298 Mdot
.65 .39305 Mdot
.65 .39307 Mdot
.65 .39314 Mdot
.65 .39318 Mdot
.65 .39321 Mdot
.65 .39324 Mdot
.65 .39324 Mdot
.65 .39351 Mdot
.65 .39357 Mdot
.65 .39358 Mdot
.65 .39364 Mdot
.65 .3937 Mdot
.65 .3937 Mdot
.65 .39371 Mdot
.65 .39403 Mdot
.65 .39404 Mdot
.65 .39418 Mdot
.65 .39425 Mdot
.65 .39426 Mdot
.65 .3943 Mdot
.65 .39435 Mdot
.65 .3944 Mdot
.65 .39443 Mdot
.65 .39458 Mdot
.65 .3946 Mdot
.65 .39465 Mdot
.65 .39466 Mdot
.65 .39469 Mdot
.65 .39474 Mdot
.65 .39479 Mdot
.65 .39481 Mdot
.65 .39482 Mdot
.65 .39487 Mdot
.65 .39497 Mdot
.65 .39515 Mdot
.65 .39517 Mdot
.65 .39526 Mdot
.65 .39527 Mdot
.65 .39527 Mdot
.65 .3954 Mdot
.65 .39541 Mdot
.65 .39544 Mdot
.65 .39547 Mdot
.65 .39547 Mdot
.65 .39549 Mdot
.65 .39557 Mdot
.65 .39558 Mdot
.65 .3956 Mdot
.65 .39567 Mdot
.65 .3957 Mdot
.65 .3957 Mdot
.65 .39572 Mdot
.65 .39579 Mdot
.65 .3959 Mdot
.65 .39592 Mdot
.65 .39596 Mdot
.65 .39597 Mdot
.65 .39598 Mdot
.65 .39603 Mdot
.65 .39606 Mdot
.65 .39619 Mdot
.65 .39628 Mdot
.65 .39638 Mdot
.65 .39643 Mdot
.65 .39646 Mdot
.65 .39647 Mdot
.65 .39649 Mdot
.65 .39649 Mdot
.65 .39653 Mdot
.65 .39656 Mdot
.65 .39669 Mdot
.65 .3967 Mdot
.65 .39673 Mdot
.65 .39686 Mdot
.65 .3969 Mdot
.65 .39727 Mdot
.65 .39736 Mdot
.65 .39751 Mdot
.65 .39757 Mdot
.65 .39761 Mdot
.65 .39771 Mdot
.65 .39772 Mdot
.65 .39778 Mdot
.65 .39793 Mdot
.65 .39806 Mdot
.65 .39817 Mdot
.65 .39818 Mdot
.652 .2825 Mdot
.652 .28251 Mdot
.652 .28277 Mdot
.652 .28289 Mdot
.652 .28305 Mdot
.652 .28305 Mdot
.652 .28312 Mdot
.652 .28328 Mdot
.652 .28341 Mdot
.652 .28348 Mdot
.652 .28349 Mdot
.652 .2835 Mdot
.652 .28354 Mdot
.652 .28361 Mdot
.652 .28364 Mdot
.652 .28365 Mdot
.652 .28374 Mdot
.652 .28375 Mdot
.652 .28382 Mdot
.652 .28402 Mdot
.652 .28436 Mdot
.652 .28436 Mdot
.652 .28445 Mdot
.652 .28448 Mdot
.652 .28448 Mdot
.652 .2845 Mdot
.652 .28463 Mdot
.652 .28465 Mdot
.652 .28473 Mdot
.652 .28475 Mdot
.652 .28482 Mdot
.652 .28486 Mdot
.652 .28487 Mdot
.652 .28488 Mdot
.652 .28492 Mdot
.652 .28495 Mdot
.652 .28523 Mdot
.652 .28524 Mdot
.652 .28529 Mdot
.652 .28531 Mdot
.652 .28539 Mdot
.652 .28552 Mdot
.652 .28552 Mdot
.652 .28556 Mdot
.652 .28562 Mdot
.652 .28566 Mdot
.652 .28571 Mdot
.652 .28579 Mdot
.652 .28581 Mdot
.652 .28587 Mdot
.652 .28595 Mdot
.652 .28602 Mdot
.652 .28605 Mdot
.652 .28608 Mdot
.652 .28609 Mdot
.652 .28616 Mdot
.652 .28618 Mdot
.652 .28637 Mdot
.652 .28643 Mdot
.652 .28652 Mdot
.652 .28654 Mdot
.652 .28662 Mdot
.652 .28678 Mdot
.652 .28687 Mdot
.652 .2869 Mdot
.652 .28697 Mdot
.652 .28701 Mdot
.652 .28713 Mdot
.652 .28721 Mdot
.652 .28733 Mdot
.652 .28736 Mdot
.652 .28742 Mdot
.652 .28746 Mdot
.652 .28755 Mdot
.652 .28758 Mdot
.652 .28762 Mdot
.652 .28772 Mdot
.652 .28793 Mdot
.652 .2881 Mdot
.652 .28814 Mdot
.652 .28825 Mdot
.652 .28827 Mdot
.652 .28835 Mdot
.652 .28844 Mdot
.652 .28852 Mdot
.652 .28853 Mdot
.652 .28865 Mdot
.652 .28873 Mdot
.652 .28873 Mdot
.652 .28887 Mdot
.652 .28896 Mdot
.652 .28906 Mdot
.652 .28907 Mdot
.652 .28919 Mdot
.652 .28925 Mdot
.652 .28929 Mdot
.652 .28939 Mdot
.652 .28945 Mdot
.652 .28948 Mdot
.652 .28949 Mdot
.652 .28959 Mdot
.652 .28964 Mdot
.652 .28965 Mdot
.652 .28966 Mdot
.652 .28968 Mdot
.652 .28991 Mdot
.652 .29005 Mdot
.652 .29006 Mdot
.652 .29017 Mdot
.652 .29018 Mdot
.652 .29028 Mdot
.652 .29032 Mdot
.652 .29046 Mdot
.652 .29057 Mdot
.652 .29071 Mdot
.652 .29085 Mdot
.652 .29094 Mdot
.652 .29095 Mdot
.652 .29099 Mdot
.652 .29108 Mdot
.652 .29119 Mdot
.652 .29122 Mdot
.652 .29123 Mdot
.652 .29133 Mdot
.652 .29137 Mdot
.652 .29152 Mdot
.652 .29156 Mdot
.652 .29169 Mdot
.652 .29189 Mdot
.652 .29189 Mdot
.652 .29201 Mdot
.652 .2921 Mdot
.652 .29222 Mdot
.652 .29231 Mdot
.652 .29242 Mdot
.652 .29251 Mdot
.652 .29255 Mdot
.652 .29286 Mdot
.652 .29287 Mdot
.652 .2929 Mdot
.652 .29291 Mdot
.652 .293 Mdot
.652 .29321 Mdot
.652 .2933 Mdot
.652 .29351 Mdot
.652 .29364 Mdot
.652 .29364 Mdot
.652 .29378 Mdot
.652 .2939 Mdot
.652 .29396 Mdot
.652 .294 Mdot
.652 .29405 Mdot
.652 .29408 Mdot
.652 .29414 Mdot
.652 .29421 Mdot
.652 .29436 Mdot
.652 .29438 Mdot
.652 .29451 Mdot
.652 .29452 Mdot
.652 .29463 Mdot
.652 .29463 Mdot
.652 .2948 Mdot
.652 .29493 Mdot
.652 .29496 Mdot
.652 .29505 Mdot
.652 .29509 Mdot
.652 .29517 Mdot
.652 .2952 Mdot
.652 .29521 Mdot
.652 .29525 Mdot
.652 .29539 Mdot
.652 .2954 Mdot
.652 .29571 Mdot
.652 .29574 Mdot
.652 .29577 Mdot
.652 .29589 Mdot
.652 .29603 Mdot
.652 .29607 Mdot
.652 .29616 Mdot
.652 .29616 Mdot
.652 .2963 Mdot
.652 .29652 Mdot
.652 .29665 Mdot
.652 .29669 Mdot
.652 .2967 Mdot
.652 .29694 Mdot
.652 .29708 Mdot
.652 .29712 Mdot
.652 .29727 Mdot
.652 .29732 Mdot
.652 .29749 Mdot
.652 .29754 Mdot
.652 .29763 Mdot
.652 .29779 Mdot
.652 .2978 Mdot
.652 .29788 Mdot
.652 .29803 Mdot
.652 .29807 Mdot
.652 .29808 Mdot
.652 .2981 Mdot
.652 .29828 Mdot
.652 .29841 Mdot
.652 .29841 Mdot
.652 .29854 Mdot
.652 .29874 Mdot
.652 .29887 Mdot
.652 .29901 Mdot
.652 .29908 Mdot
.652 .29919 Mdot
.652 .29946 Mdot
.652 .29955 Mdot
.652 .29963 Mdot
.652 .29968 Mdot
.652 .29984 Mdot
.652 .29991 Mdot
.652 .30003 Mdot
.652 .30011 Mdot
.652 .3003 Mdot
.652 .30038 Mdot
.652 .30049 Mdot
.652 .3005 Mdot
.652 .30061 Mdot
.652 .30066 Mdot
.652 .30076 Mdot
.652 .30084 Mdot
.652 .30106 Mdot
.652 .30109 Mdot
.652 .30133 Mdot
.652 .30141 Mdot
.652 .30162 Mdot
.652 .30163 Mdot
.652 .30168 Mdot
.652 .30178 Mdot
.652 .30185 Mdot
.652 .302 Mdot
.652 .30207 Mdot
.652 .30216 Mdot
.652 .30219 Mdot
.652 .30221 Mdot
.652 .30228 Mdot
.652 .30233 Mdot
.652 .30235 Mdot
.652 .30252 Mdot
.652 .30267 Mdot
.652 .30268 Mdot
.652 .30281 Mdot
.652 .30295 Mdot
.652 .30302 Mdot
.652 .30311 Mdot
.652 .30311 Mdot
.652 .30318 Mdot
.652 .30336 Mdot
.652 .30348 Mdot
.652 .30354 Mdot
.652 .30356 Mdot
.652 .30382 Mdot
.652 .30389 Mdot
.652 .30406 Mdot
.652 .30413 Mdot
.652 .30414 Mdot
.652 .30433 Mdot
.652 .30436 Mdot
.652 .30447 Mdot
.652 .30453 Mdot
.652 .30453 Mdot
.652 .30455 Mdot
.652 .30461 Mdot
.652 .30475 Mdot
.652 .30483 Mdot
.652 .30498 Mdot
.652 .30514 Mdot
.652 .30521 Mdot
.652 .30522 Mdot
.652 .30544 Mdot
.652 .30544 Mdot
.652 .30546 Mdot
.652 .30557 Mdot
.652 .30561 Mdot
.652 .30567 Mdot
.652 .30569 Mdot
.652 .30586 Mdot
.652 .30591 Mdot
.652 .30599 Mdot
.652 .30599 Mdot
.652 .30611 Mdot
.652 .30616 Mdot
.652 .30622 Mdot
.652 .30637 Mdot
.652 .30659 Mdot
.652 .30665 Mdot
.652 .30674 Mdot
.652 .30677 Mdot
.652 .3068 Mdot
.652 .30682 Mdot
.652 .30701 Mdot
.652 .30707 Mdot
.652 .30709 Mdot
.652 .30714 Mdot
.652 .30728 Mdot
.652 .30735 Mdot
.652 .30749 Mdot
.652 .30755 Mdot
.652 .30763 Mdot
.652 .30771 Mdot
.652 .30777 Mdot
.652 .30782 Mdot
.652 .30786 Mdot
.652 .30788 Mdot
.652 .30802 Mdot
.652 .30805 Mdot
.652 .30805 Mdot
.652 .30822 Mdot
.652 .30823 Mdot
.652 .30826 Mdot
.652 .30826 Mdot
.652 .30848 Mdot
.652 .3085 Mdot
.652 .30851 Mdot
.652 .30856 Mdot
.652 .30876 Mdot
.652 .30888 Mdot
.652 .30892 Mdot
.652 .30898 Mdot
.652 .30899 Mdot
.652 .30901 Mdot
.652 .30905 Mdot
.652 .30907 Mdot
.652 .30913 Mdot
.652 .3092 Mdot
.652 .3093 Mdot
.652 .30933 Mdot
.652 .30934 Mdot
.652 .3095 Mdot
.652 .30974 Mdot
.652 .30974 Mdot
.652 .30996 Mdot
.652 .31031 Mdot
.652 .31032 Mdot
.652 .31047 Mdot
.652 .31083 Mdot
.652 .3109 Mdot
.652 .31099 Mdot
.652 .311 Mdot
.652 .31105 Mdot
.652 .31106 Mdot
.652 .3111 Mdot
.652 .31112 Mdot
.652 .31139 Mdot
.652 .31143 Mdot
.652 .31151 Mdot
.652 .31159 Mdot
.652 .31167 Mdot
.652 .31172 Mdot
.652 .31181 Mdot
.652 .31182 Mdot
.652 .31185 Mdot
.652 .31189 Mdot
.652 .31201 Mdot
.652 .3121 Mdot
.652 .31216 Mdot
.652 .31236 Mdot
.652 .31246 Mdot
.652 .31251 Mdot
.652 .31271 Mdot
.652 .31272 Mdot
.652 .31293 Mdot
.652 .31305 Mdot
.652 .31312 Mdot
.652 .31313 Mdot
.652 .31327 Mdot
.652 .31335 Mdot
.652 .31359 Mdot
.652 .3136 Mdot
.652 .31367 Mdot
.652 .31384 Mdot
.652 .31384 Mdot
.652 .3139 Mdot
.652 .31394 Mdot
.652 .31409 Mdot
.652 .31424 Mdot
.652 .31431 Mdot
.652 .31434 Mdot
.652 .31448 Mdot
.652 .3147 Mdot
.652 .3147 Mdot
.652 .31473 Mdot
.652 .31495 Mdot
.652 .31514 Mdot
.652 .31538 Mdot
.652 .31545 Mdot
.652 .31562 Mdot
.652 .31564 Mdot
.652 .31583 Mdot
.652 .31585 Mdot
.652 .31609 Mdot
.652 .31647 Mdot
.652 .3165 Mdot
.652 .31652 Mdot
.652 .31654 Mdot
.652 .31662 Mdot
.652 .3168 Mdot
.652 .31681 Mdot
.652 .31687 Mdot
.652 .31697 Mdot
.652 .31714 Mdot
.652 .31721 Mdot
.652 .31731 Mdot
.652 .3175 Mdot
.652 .31752 Mdot
.652 .31769 Mdot
.652 .31785 Mdot
.652 .31808 Mdot
.652 .31809 Mdot
.652 .31822 Mdot
.652 .31842 Mdot
.652 .31845 Mdot
.652 .31858 Mdot
.652 .31873 Mdot
.652 .31886 Mdot
.652 .3189 Mdot
.652 .31909 Mdot
.652 .31917 Mdot
.652 .31944 Mdot
.652 .31981 Mdot
.652 .31997 Mdot
.652 .32004 Mdot
.652 .32009 Mdot
.652 .32025 Mdot
.652 .32032 Mdot
.652 .32042 Mdot
.652 .32047 Mdot
.652 .32066 Mdot
.652 .32081 Mdot
.652 .32101 Mdot
.652 .32108 Mdot
.652 .3212 Mdot
.652 .32124 Mdot
.652 .3214 Mdot
.652 .32141 Mdot
.652 .32168 Mdot
.652 .3218 Mdot
.652 .32185 Mdot
.652 .322 Mdot
.652 .32211 Mdot
.652 .32242 Mdot
.652 .32246 Mdot
.652 .32257 Mdot
.652 .32259 Mdot
.652 .32265 Mdot
.652 .32269 Mdot
.652 .32282 Mdot
.652 .32295 Mdot
.652 .32305 Mdot
.652 .32309 Mdot
.652 .32322 Mdot
.652 .3233 Mdot
.652 .32337 Mdot
.652 .32347 Mdot
.652 .32355 Mdot
.652 .32355 Mdot
.652 .32377 Mdot
.652 .3239 Mdot
.652 .32393 Mdot
.652 .32403 Mdot
.652 .32404 Mdot
.652 .32451 Mdot
.652 .32456 Mdot
.652 .32463 Mdot
.652 .32465 Mdot
.652 .32466 Mdot
.652 .32474 Mdot
.652 .32486 Mdot
.652 .32488 Mdot
.652 .32502 Mdot
.652 .32506 Mdot
.652 .32527 Mdot
.652 .32531 Mdot
.652 .32532 Mdot
.652 .32536 Mdot
.652 .32551 Mdot
.652 .32552 Mdot
.652 .32609 Mdot
.652 .32644 Mdot
.652 .32655 Mdot
.652 .32657 Mdot
.652 .32672 Mdot
.652 .32675 Mdot
.652 .32679 Mdot
.652 .32692 Mdot
.652 .32698 Mdot
.652 .32699 Mdot
.652 .32702 Mdot
.652 .32714 Mdot
.652 .32735 Mdot
.652 .32763 Mdot
.652 .32774 Mdot
.652 .32775 Mdot
.652 .32802 Mdot
.652 .32822 Mdot
.652 .32867 Mdot
.652 .32867 Mdot
.652 .36391 Mdot
.652 .36392 Mdot
.652 .36426 Mdot
.652 .36441 Mdot
.652 .36462 Mdot
.652 .36463 Mdot
.652 .36471 Mdot
.652 .36493 Mdot
.652 .36509 Mdot
.652 .36518 Mdot
.652 .3652 Mdot
.652 .36521 Mdot
.652 .36526 Mdot
.652 .36535 Mdot
.652 .36539 Mdot
.652 .36541 Mdot
.652 .36553 Mdot
.652 .36554 Mdot
.652 .36563 Mdot
.652 .36589 Mdot
.652 .36633 Mdot
.652 .36633 Mdot
.652 .36645 Mdot
.652 .36648 Mdot
.652 .36649 Mdot
.652 .36652 Mdot
.652 .36668 Mdot
.652 .36671 Mdot
.652 .36682 Mdot
.652 .36684 Mdot
.652 .36693 Mdot
.652 .36699 Mdot
.652 .367 Mdot
.652 .36702 Mdot
.652 .36707 Mdot
.652 .3671 Mdot
.652 .36747 Mdot
.652 .36748 Mdot
.652 .36755 Mdot
.652 .36757 Mdot
.652 .36767 Mdot
.652 .36784 Mdot
.652 .36784 Mdot
.652 .3679 Mdot
.652 .36798 Mdot
.652 .36803 Mdot
.652 .36809 Mdot
.652 .36819 Mdot
.652 .36823 Mdot
.652 .3683 Mdot
.652 .3684 Mdot
.652 .3685 Mdot
.652 .36853 Mdot
.652 .36858 Mdot
.652 .36859 Mdot
.652 .36868 Mdot
.652 .36871 Mdot
.652 .36895 Mdot
.652 .36903 Mdot
.652 .36914 Mdot
.652 .36918 Mdot
.652 .36928 Mdot
.652 .36949 Mdot
.652 .36961 Mdot
.652 .36964 Mdot
.652 .36974 Mdot
.652 .36979 Mdot
.652 .36994 Mdot
.652 .37005 Mdot
.652 .3702 Mdot
.652 .37024 Mdot
.652 .37032 Mdot
.652 .37037 Mdot
.652 .3705 Mdot
.652 .37053 Mdot
.652 .37059 Mdot
.652 .37071 Mdot
.652 .37099 Mdot
.652 .3712 Mdot
.652 .37126 Mdot
.652 .37141 Mdot
.652 .37143 Mdot
.652 .37154 Mdot
.652 .37165 Mdot
.652 .37175 Mdot
.652 .37177 Mdot
.652 .37193 Mdot
.652 .37203 Mdot
.652 .37204 Mdot
.652 .37221 Mdot
.652 .37233 Mdot
.652 .37246 Mdot
.652 .37248 Mdot
.652 .37262 Mdot
.652 .3727 Mdot
.652 .37276 Mdot
.652 .37289 Mdot
.652 .37296 Mdot
.652 .37301 Mdot
.652 .37302 Mdot
.652 .37315 Mdot
.652 .37321 Mdot
.652 .37323 Mdot
.652 .37325 Mdot
.652 .37327 Mdot
.652 .37357 Mdot
.652 .37375 Mdot
.652 .37376 Mdot
.652 .3739 Mdot
.652 .37392 Mdot
.652 .37405 Mdot
.652 .37411 Mdot
.652 .37429 Mdot
.652 .37444 Mdot
.652 .37461 Mdot
.652 .37462 Mdot
.652 .37463 Mdot
.652 .37479 Mdot
.652 .37491 Mdot
.652 .37493 Mdot
.652 .37498 Mdot
.652 .3751 Mdot
.652 .37521 Mdot
.652 .37524 Mdot
.652 .37528 Mdot
.652 .37529 Mdot
.652 .37542 Mdot
.652 .37547 Mdot
.652 .37548 Mdot
.652 .37566 Mdot
.652 .37572 Mdot
.652 .37583 Mdot
.652 .37584 Mdot
.652 .37589 Mdot
.652 .37599 Mdot
.652 .37615 Mdot
.652 .37616 Mdot
.652 .37631 Mdot
.652 .37635 Mdot
.652 .37642 Mdot
.652 .37658 Mdot
.652 .37663 Mdot
.652 .37669 Mdot
.652 .37679 Mdot
.652 .37682 Mdot
.652 .37684 Mdot
.652 .37685 Mdot
.652 .37692 Mdot
.652 .37695 Mdot
.652 .37701 Mdot
.652 .37708 Mdot
.652 .37713 Mdot
.652 .37717 Mdot
.652 .37737 Mdot
.652 .37739 Mdot
.652 .37742 Mdot
.652 .37743 Mdot
.652 .37747 Mdot
.652 .37748 Mdot
.652 .37754 Mdot
.652 .3776 Mdot
.652 .37788 Mdot
.652 .37799 Mdot
.652 .37799 Mdot
.652 .37826 Mdot
.652 .37843 Mdot
.652 .37843 Mdot
.652 .37862 Mdot
.652 .37874 Mdot
.652 .37874 Mdot
.652 .37877 Mdot
.652 .37885 Mdot
.652 .3789 Mdot
.652 .37895 Mdot
.652 .37896 Mdot
.652 .37899 Mdot
.652 .37901 Mdot
.652 .37901 Mdot
.652 .37906 Mdot
.652 .37909 Mdot
.652 .37918 Mdot
.652 .37933 Mdot
.652 .37938 Mdot
.652 .37938 Mdot
.652 .3794 Mdot
.652 .37956 Mdot
.652 .37957 Mdot
.652 .37959 Mdot
.652 .3796 Mdot
.652 .37973 Mdot
.652 .37973 Mdot
.652 .37975 Mdot
.652 .37985 Mdot
.652 .37988 Mdot
.652 .3799 Mdot
.652 .37994 Mdot
.652 .37999 Mdot
.652 .38005 Mdot
.652 .38011 Mdot
.652 .38016 Mdot
.652 .38027 Mdot
.652 .38032 Mdot
.652 .38043 Mdot
.652 .38047 Mdot
.652 .38048 Mdot
.652 .38053 Mdot
.652 .38067 Mdot
.652 .38069 Mdot
.652 .38071 Mdot
.652 .38073 Mdot
.652 .3808 Mdot
.652 .38085 Mdot
.652 .38102 Mdot
.652 .38113 Mdot
.652 .38117 Mdot
.652 .38121 Mdot
.652 .3813 Mdot
.652 .38131 Mdot
.652 .38137 Mdot
.652 .38141 Mdot
.652 .38154 Mdot
.652 .38156 Mdot
.652 .3816 Mdot
.652 .38163 Mdot
.652 .38171 Mdot
.652 .38173 Mdot
.652 .38173 Mdot
.652 .3819 Mdot
.652 .3819 Mdot
.652 .38196 Mdot
.652 .38209 Mdot
.652 .38219 Mdot
.652 .38226 Mdot
.652 .38236 Mdot
.652 .38241 Mdot
.652 .38243 Mdot
.652 .38243 Mdot
.652 .38248 Mdot
.652 .38256 Mdot
.652 .38258 Mdot
.652 .38273 Mdot
.652 .38273 Mdot
.652 .38278 Mdot
.652 .38292 Mdot
.652 .38297 Mdot
.652 .38317 Mdot
.652 .38319 Mdot
.652 .38323 Mdot
.652 .38333 Mdot
.652 .38346 Mdot
.652 .38352 Mdot
.652 .38352 Mdot
.652 .38358 Mdot
.652 .38364 Mdot
.652 .38375 Mdot
.652 .38384 Mdot
.652 .38385 Mdot
.652 .38397 Mdot
.652 .3841 Mdot
.652 .38411 Mdot
.652 .38415 Mdot
.652 .38421 Mdot
.652 .38422 Mdot
.652 .38424 Mdot
.652 .38431 Mdot
.652 .38437 Mdot
.652 .38448 Mdot
.652 .38453 Mdot
.652 .38461 Mdot
.652 .38465 Mdot
.652 .38466 Mdot
.652 .38482 Mdot
.652 .38488 Mdot
.652 .38507 Mdot
.652 .38509 Mdot
.652 .38526 Mdot
.652 .38532 Mdot
.652 .38539 Mdot
.652 .38543 Mdot
.652 .38552 Mdot
.652 .38553 Mdot
.652 .38561 Mdot
.652 .38567 Mdot
.652 .38582 Mdot
.652 .38588 Mdot
.652 .38597 Mdot
.652 .38602 Mdot
.652 .38614 Mdot
.652 .38618 Mdot
.652 .38624 Mdot
.652 .38632 Mdot
.652 .38652 Mdot
.652 .38661 Mdot
.652 .38666 Mdot
.652 .38677 Mdot
.652 .38687 Mdot
.652 .38702 Mdot
.652 .38712 Mdot
.652 .38712 Mdot
.652 .38722 Mdot
.652 .38736 Mdot
.652 .38737 Mdot
.652 .38738 Mdot
.652 .38742 Mdot
.652 .38752 Mdot
.652 .38759 Mdot
.652 .3876 Mdot
.652 .38772 Mdot
.652 .38779 Mdot
.652 .38782 Mdot
.652 .38796 Mdot
.652 .38799 Mdot
.652 .38811 Mdot
.652 .38814 Mdot
.652 .38825 Mdot
.652 .38843 Mdot
.652 .38844 Mdot
.652 .38847 Mdot
.652 .38857 Mdot
.652 .38874 Mdot
.652 .38884 Mdot
.652 .38885 Mdot
.652 .38892 Mdot
.652 .38894 Mdot
.652 .38905 Mdot
.652 .38914 Mdot
.652 .38917 Mdot
.652 .38919 Mdot
.652 .38943 Mdot
.652 .38944 Mdot
.652 .38955 Mdot
.652 .38958 Mdot
.652 .38958 Mdot
.652 .38961 Mdot
.652 .38967 Mdot
.652 .3897 Mdot
.652 .38977 Mdot
.652 .38979 Mdot
.652 .38989 Mdot
.652 .39002 Mdot
.652 .39002 Mdot
.652 .3901 Mdot
.652 .39011 Mdot
.652 .39021 Mdot
.652 .39022 Mdot
.652 .39034 Mdot
.652 .39039 Mdot
.652 .39044 Mdot
.652 .39047 Mdot
.652 .3905 Mdot
.652 .39054 Mdot
.652 .39058 Mdot
.652 .39067 Mdot
.652 .39078 Mdot
.652 .39078 Mdot
.652 .39088 Mdot
.652 .39104 Mdot
.652 .39111 Mdot
.652 .39127 Mdot
.652 .39134 Mdot
.652 .39135 Mdot
.652 .39137 Mdot
.652 .39137 Mdot
.652 .39162 Mdot
.652 .39165 Mdot
.652 .39171 Mdot
.652 .3918 Mdot
.652 .39187 Mdot
.652 .39196 Mdot
.652 .39203 Mdot
.652 .39212 Mdot
.652 .39212 Mdot
.652 .39227 Mdot
.652 .39237 Mdot
.652 .39241 Mdot
.652 .39252 Mdot
.652 .39255 Mdot
.652 .39263 Mdot
.652 .39263 Mdot
.652 .39266 Mdot
.652 .39274 Mdot
.652 .39281 Mdot
.652 .39284 Mdot
.652 .39285 Mdot
.652 .39292 Mdot
.652 .39303 Mdot
.652 .39313 Mdot
.652 .39321 Mdot
.652 .39332 Mdot
.652 .39335 Mdot
.652 .39343 Mdot
.652 .39344 Mdot
.652 .39353 Mdot
.652 .39353 Mdot
.652 .39364 Mdot
.652 .39382 Mdot
.652 .39383 Mdot
.652 .39384 Mdot
.652 .39385 Mdot
.652 .39388 Mdot
.652 .39396 Mdot
.652 .39397 Mdot
.652 .39399 Mdot
.652 .39404 Mdot
.652 .39411 Mdot
.652 .39415 Mdot
.652 .39419 Mdot
.652 .39428 Mdot
.652 .39429 Mdot
.652 .39437 Mdot
.652 .39444 Mdot
.652 .39454 Mdot
.652 .39454 Mdot
.652 .39461 Mdot
.652 .39469 Mdot
.652 .39471 Mdot
.652 .39477 Mdot
.652 .39483 Mdot
.652 .39489 Mdot
.652 .39491 Mdot
.652 .395 Mdot
.652 .39503 Mdot
.652 .39515 Mdot
.652 .39532 Mdot
.652 .39539 Mdot
.652 .39543 Mdot
.652 .39545 Mdot
.652 .39552 Mdot
.652 .39555 Mdot
.652 .39559 Mdot
.652 .39562 Mdot
.652 .39571 Mdot
.652 .39577 Mdot
.652 .39586 Mdot
.652 .39589 Mdot
.652 .39595 Mdot
.652 .39597 Mdot
.652 .39604 Mdot
.652 .39616 Mdot
.652 .39622 Mdot
.652 .39624 Mdot
.652 .39631 Mdot
.652 .39636 Mdot
.652 .3965 Mdot
.652 .39652 Mdot
.652 .39657 Mdot
.652 .39657 Mdot
.652 .3966 Mdot
.652 .39662 Mdot
.652 .39668 Mdot
.652 .39674 Mdot
.652 .39678 Mdot
.652 .3968 Mdot
.652 .39686 Mdot
.652 .3969 Mdot
.652 .39693 Mdot
.652 .39697 Mdot
.652 .39701 Mdot
.652 .39701 Mdot
.652 .39711 Mdot
.652 .39717 Mdot
.652 .39718 Mdot
.652 .39722 Mdot
.652 .39723 Mdot
.652 .39744 Mdot
.652 .39746 Mdot
.652 .39749 Mdot
.652 .3975 Mdot
.652 .39751 Mdot
.652 .39754 Mdot
.652 .3976 Mdot
.652 .39761 Mdot
.652 .39767 Mdot
.652 .39769 Mdot
.652 .39778 Mdot
.652 .3978 Mdot
.652 .39781 Mdot
.652 .39782 Mdot
.652 .39789 Mdot
.652 .39789 Mdot
.652 .39815 Mdot
.652 .39831 Mdot
.652 .39836 Mdot
.652 .39837 Mdot
.652 .39844 Mdot
.652 .39845 Mdot
.652 .39847 Mdot
.652 .39853 Mdot
.652 .39855 Mdot
.652 .39856 Mdot
.652 .39857 Mdot
.652 .39863 Mdot
.652 .39872 Mdot
.652 .39885 Mdot
.652 .3989 Mdot
.652 .3989 Mdot
.652 .39902 Mdot
.652 .39911 Mdot
.652 .39932 Mdot
.652 .39932 Mdot
.654 .28174 Mdot
.654 .28192 Mdot
.654 .28199 Mdot
.654 .28205 Mdot
.654 .28212 Mdot
.654 .28235 Mdot
.654 .28245 Mdot
.654 .28245 Mdot
.654 .28257 Mdot
.654 .28267 Mdot
.654 .28271 Mdot
.654 .28278 Mdot
.654 .2828 Mdot
.654 .28287 Mdot
.654 .28291 Mdot
.654 .28292 Mdot
.654 .28301 Mdot
.654 .28309 Mdot
.654 .28329 Mdot
.654 .2833 Mdot
.654 .28355 Mdot
.654 .28356 Mdot
.654 .28359 Mdot
.654 .28363 Mdot
.654 .28363 Mdot
.654 .28398 Mdot
.654 .2841 Mdot
.654 .28415 Mdot
.654 .28416 Mdot
.654 .28416 Mdot
.654 .28437 Mdot
.654 .28448 Mdot
.654 .28449 Mdot
.654 .28462 Mdot
.654 .28466 Mdot
.654 .28514 Mdot
.654 .28515 Mdot
.654 .2852 Mdot
.654 .28528 Mdot
.654 .28543 Mdot
.654 .28551 Mdot
.654 .28558 Mdot
.654 .2858 Mdot
.654 .28581 Mdot
.654 .28585 Mdot
.654 .28593 Mdot
.654 .28595 Mdot
.654 .28598 Mdot
.654 .28601 Mdot
.654 .28608 Mdot
.654 .28609 Mdot
.654 .2861 Mdot
.654 .28613 Mdot
.654 .28628 Mdot
.654 .28629 Mdot
.654 .28638 Mdot
.654 .28663 Mdot
.654 .28666 Mdot
.654 .28672 Mdot
.654 .28674 Mdot
.654 .28675 Mdot
.654 .28706 Mdot
.654 .28707 Mdot
.654 .2871 Mdot
.654 .28723 Mdot
.654 .28726 Mdot
.654 .28727 Mdot
.654 .28734 Mdot
.654 .28766 Mdot
.654 .28767 Mdot
.654 .28777 Mdot
.654 .28794 Mdot
.654 .28813 Mdot
.654 .28819 Mdot
.654 .28836 Mdot
.654 .28836 Mdot
.654 .28839 Mdot
.654 .28839 Mdot
.654 .28851 Mdot
.654 .28853 Mdot
.654 .28856 Mdot
.654 .28859 Mdot
.654 .28861 Mdot
.654 .28878 Mdot
.654 .28882 Mdot
.654 .28886 Mdot
.654 .28893 Mdot
.654 .28908 Mdot
.654 .28918 Mdot
.654 .28922 Mdot
.654 .28923 Mdot
.654 .28927 Mdot
.654 .2894 Mdot
.654 .28944 Mdot
.654 .28949 Mdot
.654 .28951 Mdot
.654 .28969 Mdot
.654 .28985 Mdot
.654 .28987 Mdot
.654 .28995 Mdot
.654 .28999 Mdot
.654 .29 Mdot
.654 .29002 Mdot
.654 .29002 Mdot
.654 .29006 Mdot
.654 .29009 Mdot
.654 .29015 Mdot
.654 .29024 Mdot
.654 .29027 Mdot
.654 .29032 Mdot
.654 .29033 Mdot
.654 .29036 Mdot
.654 .29037 Mdot
.654 .29037 Mdot
.654 .29038 Mdot
.654 .29038 Mdot
.654 .29038 Mdot
.654 .2904 Mdot
.654 .29042 Mdot
.654 .29043 Mdot
.654 .2905 Mdot
.654 .29051 Mdot
.654 .29053 Mdot
.654 .29056 Mdot
.654 .29068 Mdot
.654 .2907 Mdot
.654 .29071 Mdot
.654 .29076 Mdot
.654 .29078 Mdot
.654 .291 Mdot
.654 .29101 Mdot
.654 .29106 Mdot
.654 .29115 Mdot
.654 .29121 Mdot
.654 .2913 Mdot
.654 .29142 Mdot
.654 .29145 Mdot
.654 .2915 Mdot
.654 .29151 Mdot
.654 .29165 Mdot
.654 .29178 Mdot
.654 .29185 Mdot
.654 .29188 Mdot
.654 .29189 Mdot
.654 .29194 Mdot
.654 .29194 Mdot
.654 .29207 Mdot
.654 .29217 Mdot
.654 .29235 Mdot
.654 .29239 Mdot
.654 .2925 Mdot
.654 .29257 Mdot
.654 .29271 Mdot
.654 .29287 Mdot
.654 .29293 Mdot
.654 .29298 Mdot
.654 .29312 Mdot
.654 .29323 Mdot
.654 .29325 Mdot
.654 .29327 Mdot
.654 .29335 Mdot
.654 .29348 Mdot
.654 .29363 Mdot
.654 .29375 Mdot
.654 .29378 Mdot
.654 .29388 Mdot
.654 .29398 Mdot
.654 .29417 Mdot
.654 .29425 Mdot
.654 .29428 Mdot
.654 .29464 Mdot
.654 .29475 Mdot
.654 .29484 Mdot
.654 .29494 Mdot
.654 .29506 Mdot
.654 .29506 Mdot
.654 .29537 Mdot
.654 .29555 Mdot
.654 .29561 Mdot
.654 .2957 Mdot
.654 .29575 Mdot
.654 .2958 Mdot
.654 .29586 Mdot
.654 .29589 Mdot
.654 .296 Mdot
.654 .29607 Mdot
.654 .29613 Mdot
.654 .29619 Mdot
.654 .2962 Mdot
.654 .29622 Mdot
.654 .29628 Mdot
.654 .2963 Mdot
.654 .29634 Mdot
.654 .29635 Mdot
.654 .29643 Mdot
.654 .29651 Mdot
.654 .29656 Mdot
.654 .29678 Mdot
.654 .29691 Mdot
.654 .29697 Mdot
.654 .29753 Mdot
.654 .2979 Mdot
.654 .29801 Mdot
.654 .29814 Mdot
.654 .29818 Mdot
.654 .29824 Mdot
.654 .2983 Mdot
.654 .29834 Mdot
.654 .29834 Mdot
.654 .29853 Mdot
.654 .29867 Mdot
.654 .29887 Mdot
.654 .29899 Mdot
.654 .29909 Mdot
.654 .29913 Mdot
.654 .2992 Mdot
.654 .29928 Mdot
.654 .29947 Mdot
.654 .29951 Mdot
.654 .29954 Mdot
.654 .2996 Mdot
.654 .29967 Mdot
.654 .29979 Mdot
.654 .29987 Mdot
.654 .29998 Mdot
.654 .30003 Mdot
.654 .30007 Mdot
.654 .3001 Mdot
.654 .30024 Mdot
.654 .30058 Mdot
.654 .30081 Mdot
.654 .30102 Mdot
.654 .30105 Mdot
.654 .30109 Mdot
.654 .30114 Mdot
.654 .30115 Mdot
.654 .30122 Mdot
.654 .30127 Mdot
.654 .30131 Mdot
.654 .30134 Mdot
.654 .30141 Mdot
.654 .30149 Mdot
.654 .30171 Mdot
.654 .3019 Mdot
.654 .30207 Mdot
.654 .30235 Mdot
.654 .30237 Mdot
.654 .30253 Mdot
.654 .30282 Mdot
.654 .3029 Mdot
.654 .30294 Mdot
.654 .30297 Mdot
.654 .30318 Mdot
.654 .30327 Mdot
.654 .30335 Mdot
.654 .30339 Mdot
.654 .30348 Mdot
.654 .30358 Mdot
.654 .30364 Mdot
.654 .30375 Mdot
.654 .30377 Mdot
.654 .30381 Mdot
.654 .30418 Mdot
.654 .30427 Mdot
.654 .30441 Mdot
.654 .30444 Mdot
.654 .30455 Mdot
.654 .30456 Mdot
.654 .30464 Mdot
.654 .30464 Mdot
.654 .30466 Mdot
.654 .30477 Mdot
.654 .3048 Mdot
.654 .30482 Mdot
.654 .30486 Mdot
.654 .30493 Mdot
.654 .30503 Mdot
.654 .30514 Mdot
.654 .3053 Mdot
.654 .30533 Mdot
.654 .30539 Mdot
.654 .30548 Mdot
.654 .30554 Mdot
.654 .30557 Mdot
.654 .30566 Mdot
.654 .30568 Mdot
.654 .30573 Mdot
.654 .30581 Mdot
.654 .30591 Mdot
.654 .30622 Mdot
.654 .30676 Mdot
.654 .30676 Mdot
.654 .30697 Mdot
.654 .30712 Mdot
.654 .30713 Mdot
.654 .30723 Mdot
.654 .30728 Mdot
.654 .30748 Mdot
.654 .30761 Mdot
.654 .30766 Mdot
.654 .30797 Mdot
.654 .30808 Mdot
.654 .30814 Mdot
.654 .30827 Mdot
.654 .30857 Mdot
.654 .30857 Mdot
.654 .3086 Mdot
.654 .30861 Mdot
.654 .30877 Mdot
.654 .30877 Mdot
.654 .30894 Mdot
.654 .30899 Mdot
.654 .30911 Mdot
.654 .3092 Mdot
.654 .30946 Mdot
.654 .30968 Mdot
.654 .30982 Mdot
.654 .30986 Mdot
.654 .30989 Mdot
.654 .31007 Mdot
.654 .31012 Mdot
.654 .31013 Mdot
.654 .31026 Mdot
.654 .31032 Mdot
.654 .31033 Mdot
.654 .31037 Mdot
.654 .31039 Mdot
.654 .3105 Mdot
.654 .31077 Mdot
.654 .31102 Mdot
.654 .31109 Mdot
.654 .31113 Mdot
.654 .31113 Mdot
.654 .31132 Mdot
.654 .3114 Mdot
.654 .3117 Mdot
.654 .31171 Mdot
.654 .31187 Mdot
.654 .31196 Mdot
.654 .31209 Mdot
.654 .31209 Mdot
.654 .31217 Mdot
.654 .31219 Mdot
.654 .31221 Mdot
.654 .31225 Mdot
.654 .31225 Mdot
.654 .31237 Mdot
.654 .31237 Mdot
.654 .31257 Mdot
.654 .31259 Mdot
.654 .31262 Mdot
.654 .31282 Mdot
.654 .31283 Mdot
.654 .31284 Mdot
.654 .31294 Mdot
.654 .31295 Mdot
.654 .31299 Mdot
.654 .31318 Mdot
.654 .31324 Mdot
.654 .31333 Mdot
.654 .31345 Mdot
.654 .31358 Mdot
.654 .3136 Mdot
.654 .3136 Mdot
.654 .31368 Mdot
.654 .3137 Mdot
.654 .31387 Mdot
.654 .31408 Mdot
.654 .31411 Mdot
.654 .31419 Mdot
.654 .31421 Mdot
.654 .31424 Mdot
.654 .31445 Mdot
.654 .31451 Mdot
.654 .31454 Mdot
.654 .31455 Mdot
.654 .31455 Mdot
.654 .31468 Mdot
.654 .3147 Mdot
.654 .31473 Mdot
.654 .31475 Mdot
.654 .31476 Mdot
.654 .31476 Mdot
.654 .31477 Mdot
.654 .31477 Mdot
.654 .31478 Mdot
.654 .31479 Mdot
.654 .31485 Mdot
.654 .31487 Mdot
.654 .31494 Mdot
.654 .31495 Mdot
.654 .31499 Mdot
.654 .31513 Mdot
.654 .31516 Mdot
.654 .31525 Mdot
.654 .3153 Mdot
.654 .31537 Mdot
.654 .31539 Mdot
.654 .31542 Mdot
.654 .31542 Mdot
.654 .31551 Mdot
.654 .31564 Mdot
.654 .31567 Mdot
.654 .31568 Mdot
.654 .31594 Mdot
.654 .31625 Mdot
.654 .31628 Mdot
.654 .31636 Mdot
.654 .31644 Mdot
.654 .31666 Mdot
.654 .31673 Mdot
.654 .31675 Mdot
.654 .31681 Mdot
.654 .31698 Mdot
.654 .31725 Mdot
.654 .31737 Mdot
.654 .31743 Mdot
.654 .3175 Mdot
.654 .31779 Mdot
.654 .31782 Mdot
.654 .31787 Mdot
.654 .31793 Mdot
.654 .31796 Mdot
.654 .31816 Mdot
.654 .31817 Mdot
.654 .31821 Mdot
.654 .31822 Mdot
.654 .3185 Mdot
.654 .31862 Mdot
.654 .31894 Mdot
.654 .31922 Mdot
.654 .31939 Mdot
.654 .31941 Mdot
.654 .31996 Mdot
.654 .32008 Mdot
.654 .3201 Mdot
.654 .32015 Mdot
.654 .32037 Mdot
.654 .32043 Mdot
.654 .32044 Mdot
.654 .32098 Mdot
.654 .321 Mdot
.654 .32102 Mdot
.654 .32113 Mdot
.654 .32117 Mdot
.654 .3216 Mdot
.654 .32176 Mdot
.654 .32177 Mdot
.654 .32203 Mdot
.654 .32208 Mdot
.654 .3221 Mdot
.654 .32212 Mdot
.654 .32224 Mdot
.654 .32229 Mdot
.654 .32234 Mdot
.654 .32237 Mdot
.654 .32251 Mdot
.654 .32257 Mdot
.654 .32259 Mdot
.654 .32298 Mdot
.654 .32309 Mdot
.654 .32322 Mdot
.654 .32349 Mdot
.654 .32362 Mdot
.654 .3237 Mdot
.654 .32373 Mdot
.654 .32454 Mdot
.654 .32461 Mdot
.654 .32483 Mdot
.654 .32486 Mdot
.654 .32505 Mdot
.654 .3254 Mdot
.654 .3254 Mdot
.654 .32542 Mdot
.654 .32551 Mdot
.654 .32571 Mdot
.654 .3263 Mdot
.654 .32631 Mdot
.654 .32638 Mdot
.654 .32642 Mdot
.654 .32645 Mdot
.654 .32687 Mdot
.654 .32689 Mdot
.654 .32723 Mdot
.654 .32737 Mdot
.654 .32752 Mdot
.654 .32755 Mdot
.654 .32762 Mdot
.654 .32773 Mdot
.654 .32776 Mdot
.654 .32788 Mdot
.654 .32795 Mdot
.654 .32812 Mdot
.654 .32832 Mdot
.654 .32833 Mdot
.654 .32849 Mdot
.654 .32889 Mdot
.654 .32901 Mdot
.654 .32912 Mdot
.654 .32923 Mdot
.654 .32955 Mdot
.654 .36398 Mdot
.654 .36422 Mdot
.654 .36431 Mdot
.654 .36439 Mdot
.654 .36448 Mdot
.654 .36479 Mdot
.654 .36491 Mdot
.654 .36492 Mdot
.654 .36507 Mdot
.654 .3652 Mdot
.654 .36526 Mdot
.654 .36534 Mdot
.654 .36537 Mdot
.654 .36546 Mdot
.654 .36551 Mdot
.654 .36553 Mdot
.654 .36564 Mdot
.654 .36575 Mdot
.654 .36601 Mdot
.654 .36603 Mdot
.654 .36635 Mdot
.654 .36637 Mdot
.654 .3664 Mdot
.654 .36646 Mdot
.654 .36646 Mdot
.654 .36691 Mdot
.654 .36706 Mdot
.654 .36714 Mdot
.654 .36715 Mdot
.654 .36715 Mdot
.654 .36742 Mdot
.654 .36756 Mdot
.654 .36758 Mdot
.654 .36775 Mdot
.654 .36781 Mdot
.654 .36843 Mdot
.654 .36845 Mdot
.654 .36851 Mdot
.654 .36861 Mdot
.654 .36881 Mdot
.654 .36891 Mdot
.654 .369 Mdot
.654 .3693 Mdot
.654 .36931 Mdot
.654 .36936 Mdot
.654 .36947 Mdot
.654 .36949 Mdot
.654 .36953 Mdot
.654 .36957 Mdot
.654 .36966 Mdot
.654 .36967 Mdot
.654 .36969 Mdot
.654 .36973 Mdot
.654 .36993 Mdot
.654 .36994 Mdot
.654 .37006 Mdot
.654 .37038 Mdot
.654 .37042 Mdot
.654 .3705 Mdot
.654 .37052 Mdot
.654 .37053 Mdot
.654 .37094 Mdot
.654 .37095 Mdot
.654 .37099 Mdot
.654 .37116 Mdot
.654 .3712 Mdot
.654 .37122 Mdot
.654 .37131 Mdot
.654 .37173 Mdot
.654 .37175 Mdot
.654 .37188 Mdot
.654 .37209 Mdot
.654 .37234 Mdot
.654 .37242 Mdot
.654 .37264 Mdot
.654 .37265 Mdot
.654 .37268 Mdot
.654 .37269 Mdot
.654 .37284 Mdot
.654 .37286 Mdot
.654 .37291 Mdot
.654 .37295 Mdot
.654 .37297 Mdot
.654 .37319 Mdot
.654 .37325 Mdot
.654 .37329 Mdot
.654 .37338 Mdot
.654 .37359 Mdot
.654 .37372 Mdot
.654 .37376 Mdot
.654 .37378 Mdot
.654 .37383 Mdot
.654 .374 Mdot
.654 .37406 Mdot
.654 .37412 Mdot
.654 .37414 Mdot
.654 .37439 Mdot
.654 .37459 Mdot
.654 .37459 Mdot
.654 .37461 Mdot
.654 .37472 Mdot
.654 .37478 Mdot
.654 .37478 Mdot
.654 .37481 Mdot
.654 .37482 Mdot
.654 .37487 Mdot
.654 .37491 Mdot
.654 .37498 Mdot
.654 .375 Mdot
.654 .37511 Mdot
.654 .37514 Mdot
.654 .37515 Mdot
.654 .3752 Mdot
.654 .37522 Mdot
.654 .37526 Mdot
.654 .37527 Mdot
.654 .37527 Mdot
.654 .37528 Mdot
.654 .37528 Mdot
.654 .37529 Mdot
.654 .37529 Mdot
.654 .37531 Mdot
.654 .37533 Mdot
.654 .37534 Mdot
.654 .37544 Mdot
.654 .37545 Mdot
.654 .37546 Mdot
.654 .37548 Mdot
.654 .37552 Mdot
.654 .37568 Mdot
.654 .3757 Mdot
.654 .37572 Mdot
.654 .37578 Mdot
.654 .3758 Mdot
.654 .37597 Mdot
.654 .3761 Mdot
.654 .37611 Mdot
.654 .37617 Mdot
.654 .37617 Mdot
.654 .37619 Mdot
.654 .37629 Mdot
.654 .37638 Mdot
.654 .37645 Mdot
.654 .37649 Mdot
.654 .37664 Mdot
.654 .37667 Mdot
.654 .37668 Mdot
.654 .37675 Mdot
.654 .37676 Mdot
.654 .37677 Mdot
.654 .37692 Mdot
.654 .37695 Mdot
.654 .37696 Mdot
.654 .37711 Mdot
.654 .37711 Mdot
.654 .3772 Mdot
.654 .37721 Mdot
.654 .37724 Mdot
.654 .37725 Mdot
.654 .37726 Mdot
.654 .37732 Mdot
.654 .37733 Mdot
.654 .37743 Mdot
.654 .37749 Mdot
.654 .37762 Mdot
.654 .37763 Mdot
.654 .37786 Mdot
.654 .37791 Mdot
.654 .37806 Mdot
.654 .37806 Mdot
.654 .37809 Mdot
.654 .37814 Mdot
.654 .37834 Mdot
.654 .37854 Mdot
.654 .37862 Mdot
.654 .37864 Mdot
.654 .37867 Mdot
.654 .37868 Mdot
.654 .37873 Mdot
.654 .37883 Mdot
.654 .37883 Mdot
.654 .37887 Mdot
.654 .37901 Mdot
.654 .37903 Mdot
.654 .37906 Mdot
.654 .37917 Mdot
.654 .37934 Mdot
.654 .37954 Mdot
.654 .3796 Mdot
.654 .3797 Mdot
.654 .37974 Mdot
.654 .37986 Mdot
.654 .37987 Mdot
.654 .37998 Mdot
.654 .38 Mdot
.654 .38001 Mdot
.654 .38002 Mdot
.654 .38025 Mdot
.654 .38034 Mdot
.654 .38039 Mdot
.654 .38047 Mdot
.654 .38071 Mdot
.654 .38075 Mdot
.654 .38085 Mdot
.654 .381 Mdot
.654 .38104 Mdot
.654 .38112 Mdot
.654 .38113 Mdot
.654 .38124 Mdot
.654 .3814 Mdot
.654 .38141 Mdot
.654 .38181 Mdot
.654 .38205 Mdot
.654 .38213 Mdot
.654 .38219 Mdot
.654 .38223 Mdot
.654 .38224 Mdot
.654 .38232 Mdot
.654 .38233 Mdot
.654 .38238 Mdot
.654 .38245 Mdot
.654 .38249 Mdot
.654 .38251 Mdot
.654 .38264 Mdot
.654 .38272 Mdot
.654 .3828 Mdot
.654 .38286 Mdot
.654 .38289 Mdot
.654 .3829 Mdot
.654 .38293 Mdot
.654 .38301 Mdot
.654 .38302 Mdot
.654 .38303 Mdot
.654 .38309 Mdot
.654 .38309 Mdot
.654 .38318 Mdot
.654 .3832 Mdot
.654 .38331 Mdot
.654 .38337 Mdot
.654 .38365 Mdot
.654 .38369 Mdot
.654 .38371 Mdot
.654 .38378 Mdot
.654 .38383 Mdot
.654 .38391 Mdot
.654 .38398 Mdot
.654 .38401 Mdot
.654 .38407 Mdot
.654 .38414 Mdot
.654 .3843 Mdot
.654 .38432 Mdot
.654 .38436 Mdot
.654 .38441 Mdot
.654 .38464 Mdot
.654 .38476 Mdot
.654 .38477 Mdot
.654 .38498 Mdot
.654 .38512 Mdot
.654 .38526 Mdot
.654 .38543 Mdot
.654 .38549 Mdot
.654 .38554 Mdot
.654 .38557 Mdot
.654 .3856 Mdot
.654 .38564 Mdot
.654 .38569 Mdot
.654 .3857 Mdot
.654 .38573 Mdot
.654 .38577 Mdot
.654 .38579 Mdot
.654 .38595 Mdot
.654 .38613 Mdot
.654 .38639 Mdot
.654 .3865 Mdot
.654 .38652 Mdot
.654 .38654 Mdot
.654 .38659 Mdot
.654 .38667 Mdot
.654 .38673 Mdot
.654 .38682 Mdot
.654 .38688 Mdot
.654 .38692 Mdot
.654 .38694 Mdot
.654 .38697 Mdot
.654 .38712 Mdot
.654 .38718 Mdot
.654 .38723 Mdot
.654 .38727 Mdot
.654 .38734 Mdot
.654 .38743 Mdot
.654 .38759 Mdot
.654 .38769 Mdot
.654 .38784 Mdot
.654 .38784 Mdot
.654 .38787 Mdot
.654 .38791 Mdot
.654 .38796 Mdot
.654 .38799 Mdot
.654 .38809 Mdot
.654 .38818 Mdot
.654 .38846 Mdot
.654 .38888 Mdot
.654 .38893 Mdot
.654 .38903 Mdot
.654 .3892 Mdot
.654 .38924 Mdot
.654 .3893 Mdot
.654 .38936 Mdot
.654 .38937 Mdot
.654 .3894 Mdot
.654 .38941 Mdot
.654 .38946 Mdot
.654 .38947 Mdot
.654 .38948 Mdot
.654 .38953 Mdot
.654 .38958 Mdot
.654 .38963 Mdot
.654 .38971 Mdot
.654 .38974 Mdot
.654 .38978 Mdot
.654 .38982 Mdot
.654 .38986 Mdot
.654 .38993 Mdot
.654 .38997 Mdot
.654 .39011 Mdot
.654 .39035 Mdot
.654 .39035 Mdot
.654 .39044 Mdot
.654 .39051 Mdot
.654 .39058 Mdot
.654 .39067 Mdot
.654 .39094 Mdot
.654 .39097 Mdot
.654 .39103 Mdot
.654 .39117 Mdot
.654 .39125 Mdot
.654 .39132 Mdot
.654 .39135 Mdot
.654 .39144 Mdot
.654 .39156 Mdot
.654 .39166 Mdot
.654 .39172 Mdot
.654 .39173 Mdot
.654 .39175 Mdot
.654 .39183 Mdot
.654 .39194 Mdot
.654 .39197 Mdot
.654 .39202 Mdot
.654 .39214 Mdot
.654 .39225 Mdot
.654 .3923 Mdot
.654 .39239 Mdot
.654 .39242 Mdot
.654 .39256 Mdot
.654 .39263 Mdot
.654 .39273 Mdot
.654 .39273 Mdot
.654 .39277 Mdot
.654 .39278 Mdot
.654 .3928 Mdot
.654 .39286 Mdot
.654 .39295 Mdot
.654 .39306 Mdot
.654 .39307 Mdot
.654 .39311 Mdot
.654 .39313 Mdot
.654 .39322 Mdot
.654 .39329 Mdot
.654 .39334 Mdot
.654 .39341 Mdot
.654 .39344 Mdot
.654 .39345 Mdot
.654 .39362 Mdot
.654 .39363 Mdot
.654 .39367 Mdot
.654 .39368 Mdot
.654 .39369 Mdot
.654 .39379 Mdot
.654 .39381 Mdot
.654 .39383 Mdot
.654 .39383 Mdot
.654 .39389 Mdot
.654 .3939 Mdot
.654 .39391 Mdot
.654 .39392 Mdot
.654 .39392 Mdot
.654 .39393 Mdot
.654 .39393 Mdot
.654 .39393 Mdot
.654 .39394 Mdot
.654 .39396 Mdot
.654 .39397 Mdot
.654 .39401 Mdot
.654 .39403 Mdot
.654 .3941 Mdot
.654 .39414 Mdot
.654 .39417 Mdot
.654 .3942 Mdot
.654 .3942 Mdot
.654 .39422 Mdot
.654 .39422 Mdot
.654 .39426 Mdot
.654 .39432 Mdot
.654 .39433 Mdot
.654 .39445 Mdot
.654 .39459 Mdot
.654 .3946 Mdot
.654 .39464 Mdot
.654 .39467 Mdot
.654 .39477 Mdot
.654 .39481 Mdot
.654 .39481 Mdot
.654 .39484 Mdot
.654 .39492 Mdot
.654 .39504 Mdot
.654 .39509 Mdot
.654 .39512 Mdot
.654 .39515 Mdot
.654 .39528 Mdot
.654 .39529 Mdot
.654 .39531 Mdot
.654 .39534 Mdot
.654 .39536 Mdot
.654 .39544 Mdot
.654 .39545 Mdot
.654 .39547 Mdot
.654 .39547 Mdot
.654 .3956 Mdot
.654 .39565 Mdot
.654 .39579 Mdot
.654 .39592 Mdot
.654 .39599 Mdot
.654 .396 Mdot
.654 .39625 Mdot
.654 .3963 Mdot
.654 .39631 Mdot
.654 .39643 Mdot
.654 .39646 Mdot
.654 .39646 Mdot
.654 .3967 Mdot
.654 .39671 Mdot
.654 .39672 Mdot
.654 .39677 Mdot
.654 .39679 Mdot
.654 .39698 Mdot
.654 .39705 Mdot
.654 .39706 Mdot
.654 .39717 Mdot
.654 .39719 Mdot
.654 .39721 Mdot
.654 .39721 Mdot
.654 .39727 Mdot
.654 .39729 Mdot
.654 .39731 Mdot
.654 .39732 Mdot
.654 .39739 Mdot
.654 .39742 Mdot
.654 .39742 Mdot
.654 .3976 Mdot
.654 .39765 Mdot
.654 .39771 Mdot
.654 .39782 Mdot
.654 .39789 Mdot
.654 .39792 Mdot
.654 .39793 Mdot
.654 .3983 Mdot
.654 .39833 Mdot
.654 .39843 Mdot
.654 .39844 Mdot
.654 .39852 Mdot
.654 .39868 Mdot
.654 .39868 Mdot
.654 .39869 Mdot
.654 .39873 Mdot
.654 .39882 Mdot
.654 .39908 Mdot
.654 .39908 Mdot
.654 .39912 Mdot
.654 .39914 Mdot
.654 .39915 Mdot
.654 .39933 Mdot
.654 .39934 Mdot
.654 .3995 Mdot
.654 .39956 Mdot
.654 .39963 Mdot
.654 .39964 Mdot
.654 .39967 Mdot
.654 .39972 Mdot
.654 .39973 Mdot
.654 .39979 Mdot
.654 .39982 Mdot
.654 .3999 Mdot
.654 .39999 Mdot
.654 .39999 Mdot
.654 .40006 Mdot
.654 .40024 Mdot
.654 .40029 Mdot
.654 .40034 Mdot
.654 .40039 Mdot
.654 .40053 Mdot
.656 .28113 Mdot
.656 .28116 Mdot
.656 .28142 Mdot
.656 .28147 Mdot
.656 .28154 Mdot
.656 .28164 Mdot
.656 .28176 Mdot
.656 .28182 Mdot
.656 .28193 Mdot
.656 .28206 Mdot
.656 .28207 Mdot
.656 .28217 Mdot
.656 .28227 Mdot
.656 .28233 Mdot
.656 .28242 Mdot
.656 .2825 Mdot
.656 .28252 Mdot
.656 .28253 Mdot
.656 .28267 Mdot
.656 .28277 Mdot
.656 .28285 Mdot
.656 .28297 Mdot
.656 .28311 Mdot
.656 .28319 Mdot
.656 .28323 Mdot
.656 .28341 Mdot
.656 .28349 Mdot
.656 .28354 Mdot
.656 .28359 Mdot
.656 .28362 Mdot
.656 .28363 Mdot
.656 .28366 Mdot
.656 .28376 Mdot
.656 .28382 Mdot
.656 .28387 Mdot
.656 .28389 Mdot
.656 .2839 Mdot
.656 .28394 Mdot
.656 .28414 Mdot
.656 .28415 Mdot
.656 .2843 Mdot
.656 .28436 Mdot
.656 .2845 Mdot
.656 .28478 Mdot
.656 .2848 Mdot
.656 .28482 Mdot
.656 .28482 Mdot
.656 .28505 Mdot
.656 .28507 Mdot
.656 .28512 Mdot
.656 .28516 Mdot
.656 .28517 Mdot
.656 .28517 Mdot
.656 .28529 Mdot
.656 .28543 Mdot
.656 .28545 Mdot
.656 .28558 Mdot
.656 .2856 Mdot
.656 .28567 Mdot
.656 .28575 Mdot
.656 .28576 Mdot
.656 .28598 Mdot
.656 .28605 Mdot
.656 .28616 Mdot
.656 .28624 Mdot
.656 .28626 Mdot
.656 .28627 Mdot
.656 .28635 Mdot
.656 .28658 Mdot
.656 .2867 Mdot
.656 .28672 Mdot
.656 .28683 Mdot
.656 .28685 Mdot
.656 .2869 Mdot
.656 .28696 Mdot
.656 .28697 Mdot
.656 .287 Mdot
.656 .28724 Mdot
.656 .28738 Mdot
.656 .28742 Mdot
.656 .28776 Mdot
.656 .28781 Mdot
.656 .2879 Mdot
.656 .28809 Mdot
.656 .28812 Mdot
.656 .28818 Mdot
.656 .2883 Mdot
.656 .28841 Mdot
.656 .28842 Mdot
.656 .28852 Mdot
.656 .28859 Mdot
.656 .28862 Mdot
.656 .28865 Mdot
.656 .28865 Mdot
.656 .28866 Mdot
.656 .2887 Mdot
.656 .28871 Mdot
.656 .28887 Mdot
.656 .28897 Mdot
.656 .28917 Mdot
.656 .28918 Mdot
.656 .28926 Mdot
.656 .28934 Mdot
.656 .28939 Mdot
.656 .28944 Mdot
.656 .28955 Mdot
.656 .28956 Mdot
.656 .28962 Mdot
.656 .28964 Mdot
.656 .28977 Mdot
.656 .2898 Mdot
.656 .28989 Mdot
.656 .28991 Mdot
.656 .2901 Mdot
.656 .29016 Mdot
.656 .29019 Mdot
.656 .29022 Mdot
.656 .29025 Mdot
.656 .29035 Mdot
.656 .29041 Mdot
.656 .29041 Mdot
.656 .29042 Mdot
.656 .29043 Mdot
.656 .2905 Mdot
.656 .29059 Mdot
.656 .29068 Mdot
.656 .29073 Mdot
.656 .29098 Mdot
.656 .291 Mdot
.656 .29102 Mdot
.656 .29104 Mdot
.656 .29108 Mdot
.656 .29123 Mdot
.656 .29124 Mdot
.656 .2914 Mdot
.656 .29151 Mdot
.656 .29156 Mdot
.656 .29172 Mdot
.656 .29172 Mdot
.656 .29173 Mdot
.656 .29183 Mdot
.656 .29188 Mdot
.656 .29203 Mdot
.656 .29211 Mdot
.656 .29215 Mdot
.656 .29234 Mdot
.656 .29239 Mdot
.656 .29249 Mdot
.656 .29253 Mdot
.656 .29258 Mdot
.656 .29296 Mdot
.656 .29296 Mdot
.656 .2932 Mdot
.656 .29328 Mdot
.656 .29333 Mdot
.656 .29342 Mdot
.656 .29373 Mdot
.656 .29376 Mdot
.656 .29389 Mdot
.656 .29391 Mdot
.656 .29391 Mdot
.656 .294 Mdot
.656 .29408 Mdot
.656 .2943 Mdot
.656 .29443 Mdot
.656 .29452 Mdot
.656 .29457 Mdot
.656 .2946 Mdot
.656 .29462 Mdot
.656 .29476 Mdot
.656 .29491 Mdot
.656 .29494 Mdot
.656 .29513 Mdot
.656 .29532 Mdot
.656 .29542 Mdot
.656 .29549 Mdot
.656 .29556 Mdot
.656 .29585 Mdot
.656 .29591 Mdot
.656 .29594 Mdot
.656 .29599 Mdot
.656 .29603 Mdot
.656 .29613 Mdot
.656 .2962 Mdot
.656 .2963 Mdot
.656 .29639 Mdot
.656 .29642 Mdot
.656 .29653 Mdot
.656 .29657 Mdot
.656 .29664 Mdot
.656 .29691 Mdot
.656 .29714 Mdot
.656 .29755 Mdot
.656 .2976 Mdot
.656 .29767 Mdot
.656 .29779 Mdot
.656 .29805 Mdot
.656 .29809 Mdot
.656 .29815 Mdot
.656 .29819 Mdot
.656 .29826 Mdot
.656 .2983 Mdot
.656 .29839 Mdot
.656 .29847 Mdot
.656 .29869 Mdot
.656 .29878 Mdot
.656 .29881 Mdot
.656 .29885 Mdot
.656 .29889 Mdot
.656 .29892 Mdot
.656 .29899 Mdot
.656 .29902 Mdot
.656 .2991 Mdot
.656 .29922 Mdot
.656 .29923 Mdot
.656 .29932 Mdot
.656 .29936 Mdot
.656 .29941 Mdot
.656 .29954 Mdot
.656 .29958 Mdot
.656 .29964 Mdot
.656 .29966 Mdot
.656 .2997 Mdot
.656 .29972 Mdot
.656 .29978 Mdot
.656 .29993 Mdot
.656 .30004 Mdot
.656 .30031 Mdot
.656 .30044 Mdot
.656 .3006 Mdot
.656 .30066 Mdot
.656 .30073 Mdot
.656 .30079 Mdot
.656 .30085 Mdot
.656 .30096 Mdot
.656 .30098 Mdot
.656 .30101 Mdot
.656 .30103 Mdot
.656 .30106 Mdot
.656 .30131 Mdot
.656 .30148 Mdot
.656 .30161 Mdot
.656 .30169 Mdot
.656 .3018 Mdot
.656 .30183 Mdot
.656 .30189 Mdot
.656 .30247 Mdot
.656 .30252 Mdot
.656 .3026 Mdot
.656 .30274 Mdot
.656 .30296 Mdot
.656 .30299 Mdot
.656 .30301 Mdot
.656 .3034 Mdot
.656 .30346 Mdot
.656 .30346 Mdot
.656 .30358 Mdot
.656 .30364 Mdot
.656 .30383 Mdot
.656 .30387 Mdot
.656 .30388 Mdot
.656 .30403 Mdot
.656 .30421 Mdot
.656 .30422 Mdot
.656 .30422 Mdot
.656 .30425 Mdot
.656 .30433 Mdot
.656 .30437 Mdot
.656 .30451 Mdot
.656 .30452 Mdot
.656 .30457 Mdot
.656 .30459 Mdot
.656 .30467 Mdot
.656 .30472 Mdot
.656 .30481 Mdot
.656 .30526 Mdot
.656 .30527 Mdot
.656 .30531 Mdot
.656 .30532 Mdot
.656 .30538 Mdot
.656 .30544 Mdot
.656 .30555 Mdot
.656 .30573 Mdot
.656 .30606 Mdot
.656 .30622 Mdot
.656 .30638 Mdot
.656 .30644 Mdot
.656 .30663 Mdot
.656 .30669 Mdot
.656 .30679 Mdot
.656 .30693 Mdot
.656 .30697 Mdot
.656 .30701 Mdot
.656 .30711 Mdot
.656 .30726 Mdot
.656 .30727 Mdot
.656 .30729 Mdot
.656 .30749 Mdot
.656 .30786 Mdot
.656 .30786 Mdot
.656 .30798 Mdot
.656 .308 Mdot
.656 .30802 Mdot
.656 .30808 Mdot
.656 .30816 Mdot
.656 .30816 Mdot
.656 .30818 Mdot
.656 .30824 Mdot
.656 .30839 Mdot
.656 .30841 Mdot
.656 .30846 Mdot
.656 .30871 Mdot
.656 .3088 Mdot
.656 .30881 Mdot
.656 .30891 Mdot
.656 .309 Mdot
.656 .30907 Mdot
.656 .30915 Mdot
.656 .30921 Mdot
.656 .30925 Mdot
.656 .30937 Mdot
.656 .30944 Mdot
.656 .30978 Mdot
.656 .3098 Mdot
.656 .30998 Mdot
.656 .31008 Mdot
.656 .31032 Mdot
.656 .31045 Mdot
.656 .31053 Mdot
.656 .31059 Mdot
.656 .31073 Mdot
.656 .31078 Mdot
.656 .31085 Mdot
.656 .31111 Mdot
.656 .31118 Mdot
.656 .31125 Mdot
.656 .31134 Mdot
.656 .31139 Mdot
.656 .31163 Mdot
.656 .31166 Mdot
.656 .31174 Mdot
.656 .31192 Mdot
.656 .31192 Mdot
.656 .31193 Mdot
.656 .31206 Mdot
.656 .31207 Mdot
.656 .31213 Mdot
.656 .3122 Mdot
.656 .31229 Mdot
.656 .31237 Mdot
.656 .31247 Mdot
.656 .31264 Mdot
.656 .31275 Mdot
.656 .31277 Mdot
.656 .31282 Mdot
.656 .31303 Mdot
.656 .31309 Mdot
.656 .31311 Mdot
.656 .31313 Mdot
.656 .31317 Mdot
.656 .31319 Mdot
.656 .31342 Mdot
.656 .31344 Mdot
.656 .31363 Mdot
.656 .31372 Mdot
.656 .31383 Mdot
.656 .31388 Mdot
.656 .31402 Mdot
.656 .31415 Mdot
.656 .31415 Mdot
.656 .31416 Mdot
.656 .31418 Mdot
.656 .31419 Mdot
.656 .31428 Mdot
.656 .31434 Mdot
.656 .31445 Mdot
.656 .31446 Mdot
.656 .3145 Mdot
.656 .31455 Mdot
.656 .31461 Mdot
.656 .31468 Mdot
.656 .31471 Mdot
.656 .31499 Mdot
.656 .31505 Mdot
.656 .31508 Mdot
.656 .31518 Mdot
.656 .31523 Mdot
.656 .31528 Mdot
.656 .31533 Mdot
.656 .31551 Mdot
.656 .31554 Mdot
.656 .31565 Mdot
.656 .31566 Mdot
.656 .31584 Mdot
.656 .31594 Mdot
.656 .31603 Mdot
.656 .31612 Mdot
.656 .31616 Mdot
.656 .31619 Mdot
.656 .3163 Mdot
.656 .31632 Mdot
.656 .31665 Mdot
.656 .31684 Mdot
.656 .3171 Mdot
.656 .31712 Mdot
.656 .3172 Mdot
.656 .3172 Mdot
.656 .31721 Mdot
.656 .31726 Mdot
.656 .31731 Mdot
.656 .31743 Mdot
.656 .31761 Mdot
.656 .31762 Mdot
.656 .31781 Mdot
.656 .31803 Mdot
.656 .31812 Mdot
.656 .31817 Mdot
.656 .3185 Mdot
.656 .31865 Mdot
.656 .31875 Mdot
.656 .31932 Mdot
.656 .31939 Mdot
.656 .31964 Mdot
.656 .32005 Mdot
.656 .3201 Mdot
.656 .32012 Mdot
.656 .32022 Mdot
.656 .3203 Mdot
.656 .32035 Mdot
.656 .32053 Mdot
.656 .32057 Mdot
.656 .32077 Mdot
.656 .32117 Mdot
.656 .32131 Mdot
.656 .32133 Mdot
.656 .32136 Mdot
.656 .3215 Mdot
.656 .32168 Mdot
.656 .32181 Mdot
.656 .32218 Mdot
.656 .32221 Mdot
.656 .32233 Mdot
.656 .32246 Mdot
.656 .32249 Mdot
.656 .32272 Mdot
.656 .32275 Mdot
.656 .32299 Mdot
.656 .3232 Mdot
.656 .3232 Mdot
.656 .32321 Mdot
.656 .32328 Mdot
.656 .32337 Mdot
.656 .32341 Mdot
.656 .3238 Mdot
.656 .32381 Mdot
.656 .32383 Mdot
.656 .32387 Mdot
.656 .32436 Mdot
.656 .3246 Mdot
.656 .32469 Mdot
.656 .32496 Mdot
.656 .32498 Mdot
.656 .32531 Mdot
.656 .32538 Mdot
.656 .3254 Mdot
.656 .32544 Mdot
.656 .32553 Mdot
.656 .32562 Mdot
.656 .32581 Mdot
.656 .32586 Mdot
.656 .32586 Mdot
.656 .32592 Mdot
.656 .32601 Mdot
.656 .3261 Mdot
.656 .32623 Mdot
.656 .32654 Mdot
.656 .3266 Mdot
.656 .32674 Mdot
.656 .32698 Mdot
.656 .3272 Mdot
.656 .32733 Mdot
.656 .3275 Mdot
.656 .32775 Mdot
.656 .32776 Mdot
.656 .32779 Mdot
.656 .32793 Mdot
.656 .32809 Mdot
.656 .32819 Mdot
.656 .32836 Mdot
.656 .32854 Mdot
.656 .32855 Mdot
.656 .32878 Mdot
.656 .32897 Mdot
.656 .32908 Mdot
.656 .32915 Mdot
.656 .32927 Mdot
.656 .32946 Mdot
.656 .32957 Mdot
.656 .32965 Mdot
.656 .33011 Mdot
.656 .33015 Mdot
.656 .36426 Mdot
.656 .36429 Mdot
.656 .36464 Mdot
.656 .3647 Mdot
.656 .36478 Mdot
.656 .36492 Mdot
.656 .36507 Mdot
.656 .36516 Mdot
.656 .3653 Mdot
.656 .36547 Mdot
.656 .36548 Mdot
.656 .36562 Mdot
.656 .36575 Mdot
.656 .36583 Mdot
.656 .36595 Mdot
.656 .36605 Mdot
.656 .36608 Mdot
.656 .36608 Mdot
.656 .36628 Mdot
.656 .3664 Mdot
.656 .36651 Mdot
.656 .36667 Mdot
.656 .36685 Mdot
.656 .36696 Mdot
.656 .367 Mdot
.656 .36724 Mdot
.656 .36735 Mdot
.656 .36741 Mdot
.656 .36748 Mdot
.656 .36752 Mdot
.656 .36753 Mdot
.656 .36756 Mdot
.656 .36771 Mdot
.656 .36777 Mdot
.656 .36785 Mdot
.656 .36787 Mdot
.656 .36789 Mdot
.656 .36794 Mdot
.656 .3682 Mdot
.656 .36821 Mdot
.656 .36841 Mdot
.656 .36849 Mdot
.656 .36867 Mdot
.656 .36904 Mdot
.656 .36907 Mdot
.656 .36909 Mdot
.656 .36909 Mdot
.656 .36939 Mdot
.656 .36942 Mdot
.656 .36949 Mdot
.656 .36954 Mdot
.656 .36955 Mdot
.656 .36955 Mdot
.656 .36971 Mdot
.656 .36989 Mdot
.656 .36992 Mdot
.656 .37009 Mdot
.656 .37011 Mdot
.656 .37021 Mdot
.656 .37031 Mdot
.656 .37033 Mdot
.656 .37061 Mdot
.656 .37071 Mdot
.656 .37084 Mdot
.656 .37096 Mdot
.656 .37098 Mdot
.656 .37099 Mdot
.656 .3711 Mdot
.656 .37141 Mdot
.656 .37156 Mdot
.656 .37158 Mdot
.656 .37173 Mdot
.656 .37176 Mdot
.656 .37182 Mdot
.656 .3719 Mdot
.656 .37191 Mdot
.656 .37195 Mdot
.656 .37227 Mdot
.656 .37246 Mdot
.656 .37251 Mdot
.656 .37294 Mdot
.656 .37302 Mdot
.656 .37314 Mdot
.656 .37339 Mdot
.656 .37342 Mdot
.656 .3735 Mdot
.656 .37366 Mdot
.656 .3738 Mdot
.656 .37382 Mdot
.656 .37395 Mdot
.656 .37404 Mdot
.656 .37408 Mdot
.656 .37412 Mdot
.656 .37412 Mdot
.656 .37413 Mdot
.656 .37419 Mdot
.656 .3742 Mdot
.656 .3744 Mdot
.656 .37454 Mdot
.656 .3748 Mdot
.656 .37481 Mdot
.656 .3749 Mdot
.656 .37492 Mdot
.656 .37495 Mdot
.656 .37502 Mdot
.656 .37509 Mdot
.656 .37516 Mdot
.656 .3753 Mdot
.656 .37531 Mdot
.656 .37539 Mdot
.656 .37542 Mdot
.656 .37555 Mdot
.656 .37559 Mdot
.656 .37563 Mdot
.656 .37566 Mdot
.656 .37574 Mdot
.656 .37577 Mdot
.656 .37581 Mdot
.656 .37602 Mdot
.656 .37605 Mdot
.656 .3761 Mdot
.656 .37614 Mdot
.656 .37618 Mdot
.656 .37621 Mdot
.656 .37622 Mdot
.656 .37631 Mdot
.656 .37635 Mdot
.656 .37642 Mdot
.656 .37643 Mdot
.656 .37645 Mdot
.656 .37645 Mdot
.656 .37645 Mdot
.656 .37655 Mdot
.656 .37666 Mdot
.656 .3767 Mdot
.656 .37678 Mdot
.656 .37685 Mdot
.656 .37699 Mdot
.656 .37701 Mdot
.656 .37718 Mdot
.656 .3772 Mdot
.656 .37722 Mdot
.656 .37724 Mdot
.656 .37726 Mdot
.656 .3773 Mdot
.656 .37747 Mdot
.656 .3775 Mdot
.656 .37752 Mdot
.656 .3776 Mdot
.656 .37773 Mdot
.656 .37781 Mdot
.656 .37787 Mdot
.656 .37794 Mdot
.656 .37799 Mdot
.656 .37803 Mdot
.656 .37804 Mdot
.656 .37814 Mdot
.656 .37815 Mdot
.656 .37815 Mdot
.656 .37829 Mdot
.656 .37835 Mdot
.656 .37837 Mdot
.656 .37856 Mdot
.656 .37859 Mdot
.656 .37866 Mdot
.656 .37871 Mdot
.656 .37877 Mdot
.656 .37896 Mdot
.656 .37902 Mdot
.656 .37905 Mdot
.656 .37916 Mdot
.656 .37921 Mdot
.656 .37927 Mdot
.656 .37937 Mdot
.656 .37955 Mdot
.656 .37963 Mdot
.656 .37977 Mdot
.656 .37978 Mdot
.656 .38004 Mdot
.656 .38009 Mdot
.656 .38019 Mdot
.656 .38022 Mdot
.656 .38026 Mdot
.656 .38033 Mdot
.656 .38037 Mdot
.656 .38044 Mdot
.656 .38052 Mdot
.656 .38053 Mdot
.656 .38059 Mdot
.656 .38079 Mdot
.656 .38082 Mdot
.656 .38084 Mdot
.656 .38095 Mdot
.656 .381 Mdot
.656 .38101 Mdot
.656 .38102 Mdot
.656 .38108 Mdot
.656 .38112 Mdot
.656 .38114 Mdot
.656 .38116 Mdot
.656 .38124 Mdot
.656 .38125 Mdot
.656 .38153 Mdot
.656 .38168 Mdot
.656 .3817 Mdot
.656 .3817 Mdot
.656 .38181 Mdot
.656 .38189 Mdot
.656 .38192 Mdot
.656 .38195 Mdot
.656 .38206 Mdot
.656 .38214 Mdot
.656 .38218 Mdot
.656 .38232 Mdot
.656 .38238 Mdot
.656 .3825 Mdot
.656 .38262 Mdot
.656 .38287 Mdot
.656 .38301 Mdot
.656 .38309 Mdot
.656 .38313 Mdot
.656 .38318 Mdot
.656 .38319 Mdot
.656 .38321 Mdot
.656 .38323 Mdot
.656 .38357 Mdot
.656 .38364 Mdot
.656 .38368 Mdot
.656 .38374 Mdot
.656 .38375 Mdot
.656 .38379 Mdot
.656 .3838 Mdot
.656 .38391 Mdot
.656 .38394 Mdot
.656 .38399 Mdot
.656 .38402 Mdot
.656 .38402 Mdot
.656 .38403 Mdot
.656 .38416 Mdot
.656 .38428 Mdot
.656 .38429 Mdot
.656 .38432 Mdot
.656 .38446 Mdot
.656 .3845 Mdot
.656 .3846 Mdot
.656 .3846 Mdot
.656 .38465 Mdot
.656 .38494 Mdot
.656 .38496 Mdot
.656 .38498 Mdot
.656 .38515 Mdot
.656 .38526 Mdot
.656 .38531 Mdot
.656 .38535 Mdot
.656 .3858 Mdot
.656 .38584 Mdot
.656 .38586 Mdot
.656 .38595 Mdot
.656 .38601 Mdot
.656 .38611 Mdot
.656 .38624 Mdot
.656 .38643 Mdot
.656 .38645 Mdot
.656 .38647 Mdot
.656 .38649 Mdot
.656 .38651 Mdot
.656 .38658 Mdot
.656 .38663 Mdot
.656 .38668 Mdot
.656 .38673 Mdot
.656 .38678 Mdot
.656 .3869 Mdot
.656 .387 Mdot
.656 .3872 Mdot
.656 .38729 Mdot
.656 .3874 Mdot
.656 .38745 Mdot
.656 .38746 Mdot
.656 .3875 Mdot
.656 .38751 Mdot
.656 .38755 Mdot
.656 .38759 Mdot
.656 .38768 Mdot
.656 .38772 Mdot
.656 .38776 Mdot
.656 .38782 Mdot
.656 .38783 Mdot
.656 .38792 Mdot
.656 .38798 Mdot
.656 .388 Mdot
.656 .38806 Mdot
.656 .38808 Mdot
.656 .38811 Mdot
.656 .38814 Mdot
.656 .38817 Mdot
.656 .38824 Mdot
.656 .3884 Mdot
.656 .38846 Mdot
.656 .38853 Mdot
.656 .38856 Mdot
.656 .38862 Mdot
.656 .38864 Mdot
.656 .38869 Mdot
.656 .38872 Mdot
.656 .38892 Mdot
.656 .38901 Mdot
.656 .38906 Mdot
.656 .3891 Mdot
.656 .38942 Mdot
.656 .38959 Mdot
.656 .3898 Mdot
.656 .38985 Mdot
.656 .38988 Mdot
.656 .38996 Mdot
.656 .38998 Mdot
.656 .39005 Mdot
.656 .39013 Mdot
.656 .39018 Mdot
.656 .39026 Mdot
.656 .39029 Mdot
.656 .39033 Mdot
.656 .39035 Mdot
.656 .3904 Mdot
.656 .39062 Mdot
.656 .39068 Mdot
.656 .39072 Mdot
.656 .3908 Mdot
.656 .39095 Mdot
.656 .39109 Mdot
.656 .39112 Mdot
.656 .39123 Mdot
.656 .39133 Mdot
.656 .39135 Mdot
.656 .39137 Mdot
.656 .39141 Mdot
.656 .39148 Mdot
.656 .39158 Mdot
.656 .39175 Mdot
.656 .39181 Mdot
.656 .39188 Mdot
.656 .39188 Mdot
.656 .39189 Mdot
.656 .39199 Mdot
.656 .39201 Mdot
.656 .39225 Mdot
.656 .39232 Mdot
.656 .39236 Mdot
.656 .39242 Mdot
.656 .3926 Mdot
.656 .3926 Mdot
.656 .39289 Mdot
.656 .39293 Mdot
.656 .39296 Mdot
.656 .39304 Mdot
.656 .39307 Mdot
.656 .39322 Mdot
.656 .39325 Mdot
.656 .39331 Mdot
.656 .39343 Mdot
.656 .39346 Mdot
.656 .39354 Mdot
.656 .39355 Mdot
.656 .39355 Mdot
.656 .39367 Mdot
.656 .39371 Mdot
.656 .39379 Mdot
.656 .39391 Mdot
.656 .39392 Mdot
.656 .39403 Mdot
.656 .39406 Mdot
.656 .39408 Mdot
.656 .3941 Mdot
.656 .39411 Mdot
.656 .3943 Mdot
.656 .39434 Mdot
.656 .39441 Mdot
.656 .39447 Mdot
.656 .39453 Mdot
.656 .39453 Mdot
.656 .39454 Mdot
.656 .39455 Mdot
.656 .39459 Mdot
.656 .39466 Mdot
.656 .39469 Mdot
.656 .39471 Mdot
.656 .39474 Mdot
.656 .39478 Mdot
.656 .39493 Mdot
.656 .39494 Mdot
.656 .39501 Mdot
.656 .39503 Mdot
.656 .39513 Mdot
.656 .39515 Mdot
.656 .3952 Mdot
.656 .3952 Mdot
.656 .39528 Mdot
.656 .39532 Mdot
.656 .39536 Mdot
.656 .39542 Mdot
.656 .39548 Mdot
.656 .39549 Mdot
.656 .39564 Mdot
.656 .39572 Mdot
.656 .39584 Mdot
.656 .39585 Mdot
.656 .39588 Mdot
.656 .39588 Mdot
.656 .39588 Mdot
.656 .39591 Mdot
.656 .39593 Mdot
.656 .39598 Mdot
.656 .39606 Mdot
.656 .39607 Mdot
.656 .39615 Mdot
.656 .39625 Mdot
.656 .39629 Mdot
.656 .39631 Mdot
.656 .39646 Mdot
.656 .39652 Mdot
.656 .39657 Mdot
.656 .39682 Mdot
.656 .39685 Mdot
.656 .39696 Mdot
.656 .39714 Mdot
.656 .39717 Mdot
.656 .39717 Mdot
.656 .39722 Mdot
.656 .39725 Mdot
.656 .39728 Mdot
.656 .39736 Mdot
.656 .39737 Mdot
.656 .39746 Mdot
.656 .39764 Mdot
.656 .3977 Mdot
.656 .39771 Mdot
.656 .39772 Mdot
.656 .39779 Mdot
.656 .39786 Mdot
.656 .39792 Mdot
.656 .39809 Mdot
.656 .3981 Mdot
.656 .39815 Mdot
.656 .39821 Mdot
.656 .39823 Mdot
.656 .39832 Mdot
.656 .39834 Mdot
.656 .39845 Mdot
.656 .39854 Mdot
.656 .39854 Mdot
.656 .39854 Mdot
.656 .39857 Mdot
.656 .39861 Mdot
.656 .39863 Mdot
.656 .3988 Mdot
.656 .39881 Mdot
.656 .39882 Mdot
.656 .39884 Mdot
.656 .39905 Mdot
.656 .39916 Mdot
.656 .3992 Mdot
.656 .39932 Mdot
.656 .39933 Mdot
.656 .39947 Mdot
.656 .3995 Mdot
.656 .39951 Mdot
.656 .39953 Mdot
.656 .39957 Mdot
.656 .39961 Mdot
.656 .39969 Mdot
.656 .39972 Mdot
.656 .39972 Mdot
.656 .39974 Mdot
.656 .39978 Mdot
.656 .39982 Mdot
.656 .39988 Mdot
.656 .40002 Mdot
.656 .40004 Mdot
.656 .40011 Mdot
.656 .40021 Mdot
.656 .40031 Mdot
.656 .40037 Mdot
.656 .40044 Mdot
.656 .40055 Mdot
.656 .40056 Mdot
.656 .40057 Mdot
.656 .40063 Mdot
.656 .4007 Mdot
.656 .40075 Mdot
.656 .40082 Mdot
.656 .4009 Mdot
.656 .40091 Mdot
.656 .40101 Mdot
.656 .40109 Mdot
.656 .40114 Mdot
.656 .40123 Mdot
.656 .40131 Mdot
.656 .40136 Mdot
.656 .40139 Mdot
.656 .4016 Mdot
.656 .40161 Mdot
.658 .28024 Mdot
.658 .28027 Mdot
.658 .28028 Mdot
.658 .28047 Mdot
.658 .28077 Mdot
.658 .28114 Mdot
.658 .28142 Mdot
.658 .28169 Mdot
.658 .28169 Mdot
.658 .28173 Mdot
.658 .28173 Mdot
.658 .2818 Mdot
.658 .28201 Mdot
.658 .28207 Mdot
.658 .28207 Mdot
.658 .28211 Mdot
.658 .28219 Mdot
.658 .28224 Mdot
.658 .28231 Mdot
.658 .28251 Mdot
.658 .28259 Mdot
.658 .28269 Mdot
.658 .28286 Mdot
.658 .28309 Mdot
.658 .28315 Mdot
.658 .28322 Mdot
.658 .28332 Mdot
.658 .28334 Mdot
.658 .28342 Mdot
.658 .28348 Mdot
.658 .28367 Mdot
.658 .28377 Mdot
.658 .28378 Mdot
.658 .28398 Mdot
.658 .28404 Mdot
.658 .28406 Mdot
.658 .28408 Mdot
.658 .28413 Mdot
.658 .28413 Mdot
.658 .28419 Mdot
.658 .28437 Mdot
.658 .2844 Mdot
.658 .28443 Mdot
.658 .28459 Mdot
.658 .2846 Mdot
.658 .28461 Mdot
.658 .28468 Mdot
.658 .28469 Mdot
.658 .2847 Mdot
.658 .28472 Mdot
.658 .28472 Mdot
.658 .2848 Mdot
.658 .28486 Mdot
.658 .28492 Mdot
.658 .28498 Mdot
.658 .28536 Mdot
.658 .28541 Mdot
.658 .28548 Mdot
.658 .28551 Mdot
.658 .28567 Mdot
.658 .28577 Mdot
.658 .28598 Mdot
.658 .28603 Mdot
.658 .28616 Mdot
.658 .28616 Mdot
.658 .28617 Mdot
.658 .28619 Mdot
.658 .28629 Mdot
.658 .28633 Mdot
.658 .28634 Mdot
.658 .28636 Mdot
.658 .28637 Mdot
.658 .28645 Mdot
.658 .28654 Mdot
.658 .28656 Mdot
.658 .28658 Mdot
.658 .28673 Mdot
.658 .28674 Mdot
.658 .28677 Mdot
.658 .28681 Mdot
.658 .28682 Mdot
.658 .28701 Mdot
.658 .2871 Mdot
.658 .28717 Mdot
.658 .28754 Mdot
.658 .28756 Mdot
.658 .28777 Mdot
.658 .28804 Mdot
.658 .28812 Mdot
.658 .28812 Mdot
.658 .2882 Mdot
.658 .28834 Mdot
.658 .28871 Mdot
.658 .28876 Mdot
.658 .28877 Mdot
.658 .28902 Mdot
.658 .28904 Mdot
.658 .28911 Mdot
.658 .28912 Mdot
.658 .2892 Mdot
.658 .2892 Mdot
.658 .28921 Mdot
.658 .28926 Mdot
.658 .28926 Mdot
.658 .28929 Mdot
.658 .28935 Mdot
.658 .28941 Mdot
.658 .28948 Mdot
.658 .28965 Mdot
.658 .28973 Mdot
.658 .28975 Mdot
.658 .28985 Mdot
.658 .28985 Mdot
.658 .28986 Mdot
.658 .29006 Mdot
.658 .29025 Mdot
.658 .29026 Mdot
.658 .29043 Mdot
.658 .2905 Mdot
.658 .29052 Mdot
.658 .29053 Mdot
.658 .29058 Mdot
.658 .29065 Mdot
.658 .29067 Mdot
.658 .29071 Mdot
.658 .29071 Mdot
.658 .29088 Mdot
.658 .29094 Mdot
.658 .29098 Mdot
.658 .29115 Mdot
.658 .29117 Mdot
.658 .29123 Mdot
.658 .29123 Mdot
.658 .29124 Mdot
.658 .29139 Mdot
.658 .29139 Mdot
.658 .29182 Mdot
.658 .292 Mdot
.658 .29202 Mdot
.658 .2921 Mdot
.658 .29217 Mdot
.658 .29219 Mdot
.658 .29251 Mdot
.658 .29268 Mdot
.658 .29269 Mdot
.658 .29277 Mdot
.658 .29318 Mdot
.658 .2933 Mdot
.658 .29334 Mdot
.658 .29344 Mdot
.658 .29368 Mdot
.658 .29371 Mdot
.658 .29372 Mdot
.658 .29383 Mdot
.658 .29387 Mdot
.658 .29394 Mdot
.658 .29395 Mdot
.658 .29396 Mdot
.658 .29397 Mdot
.658 .29417 Mdot
.658 .29417 Mdot
.658 .29418 Mdot
.658 .29418 Mdot
.658 .29441 Mdot
.658 .29444 Mdot
.658 .2946 Mdot
.658 .2948 Mdot
.658 .295 Mdot
.658 .29531 Mdot
.658 .29562 Mdot
.658 .29564 Mdot
.658 .29568 Mdot
.658 .2957 Mdot
.658 .29575 Mdot
.658 .29577 Mdot
.658 .29611 Mdot
.658 .29616 Mdot
.658 .29635 Mdot
.658 .29641 Mdot
.658 .29641 Mdot
.658 .29655 Mdot
.658 .29664 Mdot
.658 .29667 Mdot
.658 .29678 Mdot
.658 .29683 Mdot
.658 .29686 Mdot
.658 .29705 Mdot
.658 .29727 Mdot
.658 .29733 Mdot
.658 .29733 Mdot
.658 .29734 Mdot
.658 .29741 Mdot
.658 .29742 Mdot
.658 .29748 Mdot
.658 .29782 Mdot
.658 .29784 Mdot
.658 .29786 Mdot
.658 .29787 Mdot
.658 .29798 Mdot
.658 .298 Mdot
.658 .29806 Mdot
.658 .29808 Mdot
.658 .29813 Mdot
.658 .29822 Mdot
.658 .29823 Mdot
.658 .29829 Mdot
.658 .29839 Mdot
.658 .29842 Mdot
.658 .29855 Mdot
.658 .29856 Mdot
.658 .29863 Mdot
.658 .29869 Mdot
.658 .29879 Mdot
.658 .29887 Mdot
.658 .29894 Mdot
.658 .29898 Mdot
.658 .29912 Mdot
.658 .2992 Mdot
.658 .29922 Mdot
.658 .29927 Mdot
.658 .29931 Mdot
.658 .29931 Mdot
.658 .29941 Mdot
.658 .29944 Mdot
.658 .29952 Mdot
.658 .29954 Mdot
.658 .29974 Mdot
.658 .29977 Mdot
.658 .29978 Mdot
.658 .29983 Mdot
.658 .29983 Mdot
.658 .29983 Mdot
.658 .29999 Mdot
.658 .3001 Mdot
.658 .30011 Mdot
.658 .30021 Mdot
.658 .30023 Mdot
.658 .30028 Mdot
.658 .30036 Mdot
.658 .30036 Mdot
.658 .30039 Mdot
.658 .30051 Mdot
.658 .30053 Mdot
.658 .30073 Mdot
.658 .30074 Mdot
.658 .30078 Mdot
.658 .3008 Mdot
.658 .30099 Mdot
.658 .30129 Mdot
.658 .3014 Mdot
.658 .30149 Mdot
.658 .30151 Mdot
.658 .30165 Mdot
.658 .30165 Mdot
.658 .30165 Mdot
.658 .30177 Mdot
.658 .30177 Mdot
.658 .30185 Mdot
.658 .30207 Mdot
.658 .30213 Mdot
.658 .30222 Mdot
.658 .30246 Mdot
.658 .30252 Mdot
.658 .30261 Mdot
.658 .3028 Mdot
.658 .30285 Mdot
.658 .30301 Mdot
.658 .30326 Mdot
.658 .30326 Mdot
.658 .30335 Mdot
.658 .30335 Mdot
.658 .30355 Mdot
.658 .30369 Mdot
.658 .30373 Mdot
.658 .30377 Mdot
.658 .30391 Mdot
.658 .30415 Mdot
.658 .30415 Mdot
.658 .3042 Mdot
.658 .30422 Mdot
.658 .30426 Mdot
.658 .30436 Mdot
.658 .3044 Mdot
.658 .30447 Mdot
.658 .30449 Mdot
.658 .30449 Mdot
.658 .30452 Mdot
.658 .30452 Mdot
.658 .30458 Mdot
.658 .30463 Mdot
.658 .30502 Mdot
.658 .3051 Mdot
.658 .30515 Mdot
.658 .30519 Mdot
.658 .30569 Mdot
.658 .30574 Mdot
.658 .3059 Mdot
.658 .30592 Mdot
.658 .30604 Mdot
.658 .30606 Mdot
.658 .30611 Mdot
.658 .30618 Mdot
.658 .30635 Mdot
.658 .30638 Mdot
.658 .30665 Mdot
.658 .30671 Mdot
.658 .30696 Mdot
.658 .307 Mdot
.658 .30711 Mdot
.658 .30711 Mdot
.658 .30712 Mdot
.658 .30713 Mdot
.658 .30728 Mdot
.658 .30748 Mdot
.658 .30749 Mdot
.658 .3075 Mdot
.658 .30754 Mdot
.658 .30765 Mdot
.658 .30771 Mdot
.658 .30786 Mdot
.658 .30791 Mdot
.658 .30792 Mdot
.658 .30798 Mdot
.658 .30805 Mdot
.658 .30828 Mdot
.658 .30834 Mdot
.658 .30839 Mdot
.658 .30857 Mdot
.658 .30864 Mdot
.658 .30864 Mdot
.658 .30884 Mdot
.658 .30886 Mdot
.658 .30902 Mdot
.658 .30956 Mdot
.658 .30969 Mdot
.658 .30971 Mdot
.658 .30972 Mdot
.658 .31 Mdot
.658 .31022 Mdot
.658 .31053 Mdot
.658 .31056 Mdot
.658 .3106 Mdot
.658 .31072 Mdot
.658 .31077 Mdot
.658 .31085 Mdot
.658 .31089 Mdot
.658 .31121 Mdot
.658 .31137 Mdot
.658 .31157 Mdot
.658 .31173 Mdot
.658 .31194 Mdot
.658 .31194 Mdot
.658 .31198 Mdot
.658 .31208 Mdot
.658 .3121 Mdot
.658 .31221 Mdot
.658 .31222 Mdot
.658 .31222 Mdot
.658 .31227 Mdot
.658 .31233 Mdot
.658 .31236 Mdot
.658 .31265 Mdot
.658 .31272 Mdot
.658 .31283 Mdot
.658 .31289 Mdot
.658 .31311 Mdot
.658 .31311 Mdot
.658 .31312 Mdot
.658 .31313 Mdot
.658 .31319 Mdot
.658 .31322 Mdot
.658 .31323 Mdot
.658 .31323 Mdot
.658 .31334 Mdot
.658 .31344 Mdot
.658 .31345 Mdot
.658 .31349 Mdot
.658 .31361 Mdot
.658 .31391 Mdot
.658 .31392 Mdot
.658 .31404 Mdot
.658 .31425 Mdot
.658 .31459 Mdot
.658 .31462 Mdot
.658 .31462 Mdot
.658 .31478 Mdot
.658 .31482 Mdot
.658 .31487 Mdot
.658 .31496 Mdot
.658 .31525 Mdot
.658 .31537 Mdot
.658 .31547 Mdot
.658 .31558 Mdot
.658 .31563 Mdot
.658 .31564 Mdot
.658 .31572 Mdot
.658 .31574 Mdot
.658 .31574 Mdot
.658 .31587 Mdot
.658 .3159 Mdot
.658 .31599 Mdot
.658 .31601 Mdot
.658 .31604 Mdot
.658 .31649 Mdot
.658 .3165 Mdot
.658 .31658 Mdot
.658 .31688 Mdot
.658 .31724 Mdot
.658 .31746 Mdot
.658 .31748 Mdot
.658 .31748 Mdot
.658 .31757 Mdot
.658 .3176 Mdot
.658 .31762 Mdot
.658 .31775 Mdot
.658 .31822 Mdot
.658 .31857 Mdot
.658 .31862 Mdot
.658 .31925 Mdot
.658 .31953 Mdot
.658 .31986 Mdot
.658 .31987 Mdot
.658 .31994 Mdot
.658 .32 Mdot
.658 .32002 Mdot
.658 .32028 Mdot
.658 .32031 Mdot
.658 .32035 Mdot
.658 .32049 Mdot
.658 .32064 Mdot
.658 .32065 Mdot
.658 .32069 Mdot
.658 .32071 Mdot
.658 .32079 Mdot
.658 .32096 Mdot
.658 .32098 Mdot
.658 .321 Mdot
.658 .32101 Mdot
.658 .32123 Mdot
.658 .32131 Mdot
.658 .32168 Mdot
.658 .32185 Mdot
.658 .32213 Mdot
.658 .32217 Mdot
.658 .3223 Mdot
.658 .32239 Mdot
.658 .32304 Mdot
.658 .32316 Mdot
.658 .32326 Mdot
.658 .32337 Mdot
.658 .3235 Mdot
.658 .3235 Mdot
.658 .32353 Mdot
.658 .32354 Mdot
.658 .32357 Mdot
.658 .32369 Mdot
.658 .3237 Mdot
.658 .32372 Mdot
.658 .32401 Mdot
.658 .32405 Mdot
.658 .3241 Mdot
.658 .32442 Mdot
.658 .32451 Mdot
.658 .32453 Mdot
.658 .3246 Mdot
.658 .32463 Mdot
.658 .32467 Mdot
.658 .32477 Mdot
.658 .32512 Mdot
.658 .32515 Mdot
.658 .32531 Mdot
.658 .32565 Mdot
.658 .32575 Mdot
.658 .32589 Mdot
.658 .32592 Mdot
.658 .32609 Mdot
.658 .32622 Mdot
.658 .32631 Mdot
.658 .32672 Mdot
.658 .32701 Mdot
.658 .32719 Mdot
.658 .32733 Mdot
.658 .32767 Mdot
.658 .32778 Mdot
.658 .32788 Mdot
.658 .32802 Mdot
.658 .32808 Mdot
.658 .32809 Mdot
.658 .32819 Mdot
.658 .32855 Mdot
.658 .32868 Mdot
.658 .32868 Mdot
.658 .32874 Mdot
.658 .32875 Mdot
.658 .32921 Mdot
.658 .32969 Mdot
.658 .33034 Mdot
.658 .33086 Mdot
.658 .33119 Mdot
.658 .3312 Mdot
.658 .33125 Mdot
.658 .36415 Mdot
.658 .36419 Mdot
.658 .3642 Mdot
.658 .36445 Mdot
.658 .36484 Mdot
.658 .36533 Mdot
.658 .3657 Mdot
.658 .36605 Mdot
.658 .36606 Mdot
.658 .3661 Mdot
.658 .3661 Mdot
.658 .3662 Mdot
.658 .36648 Mdot
.658 .36655 Mdot
.658 .36656 Mdot
.658 .3666 Mdot
.658 .36671 Mdot
.658 .36678 Mdot
.658 .36687 Mdot
.658 .36713 Mdot
.658 .36724 Mdot
.658 .36738 Mdot
.658 .36759 Mdot
.658 .3679 Mdot
.658 .36797 Mdot
.658 .36807 Mdot
.658 .3682 Mdot
.658 .36823 Mdot
.658 .36833 Mdot
.658 .36841 Mdot
.658 .36866 Mdot
.658 .36879 Mdot
.658 .36881 Mdot
.658 .36907 Mdot
.658 .36915 Mdot
.658 .36918 Mdot
.658 .3692 Mdot
.658 .36926 Mdot
.658 .36927 Mdot
.658 .36934 Mdot
.658 .36958 Mdot
.658 .36962 Mdot
.658 .36965 Mdot
.658 .36987 Mdot
.658 .36989 Mdot
.658 .3699 Mdot
.658 .36999 Mdot
.658 .37001 Mdot
.658 .37001 Mdot
.658 .37004 Mdot
.658 .37004 Mdot
.658 .37014 Mdot
.658 .37022 Mdot
.658 .3703 Mdot
.658 .37039 Mdot
.658 .37088 Mdot
.658 .37095 Mdot
.658 .37105 Mdot
.658 .37108 Mdot
.658 .37129 Mdot
.658 .37142 Mdot
.658 .3717 Mdot
.658 .37177 Mdot
.658 .37193 Mdot
.658 .37193 Mdot
.658 .37195 Mdot
.658 .37197 Mdot
.658 .3721 Mdot
.658 .37216 Mdot
.658 .37218 Mdot
.658 .3722 Mdot
.658 .37221 Mdot
.658 .37232 Mdot
.658 .37243 Mdot
.658 .37246 Mdot
.658 .37249 Mdot
.658 .37268 Mdot
.658 .3727 Mdot
.658 .37275 Mdot
.658 .37279 Mdot
.658 .37281 Mdot
.658 .37306 Mdot
.658 .37327 Mdot
.658 .37375 Mdot
.658 .37378 Mdot
.658 .37405 Mdot
.658 .37441 Mdot
.658 .37451 Mdot
.658 .37452 Mdot
.658 .37455 Mdot
.658 .37461 Mdot
.658 .37462 Mdot
.658 .37463 Mdot
.658 .3748 Mdot
.658 .37507 Mdot
.658 .37529 Mdot
.658 .37536 Mdot
.658 .37537 Mdot
.658 .3757 Mdot
.658 .37573 Mdot
.658 .37574 Mdot
.658 .37582 Mdot
.658 .37583 Mdot
.658 .37593 Mdot
.658 .37594 Mdot
.658 .37595 Mdot
.658 .37601 Mdot
.658 .37602 Mdot
.658 .37606 Mdot
.658 .37614 Mdot
.658 .37622 Mdot
.658 .37631 Mdot
.658 .37653 Mdot
.658 .3766 Mdot
.658 .37663 Mdot
.658 .37667 Mdot
.658 .37679 Mdot
.658 .37679 Mdot
.658 .37681 Mdot
.658 .37707 Mdot
.658 .37723 Mdot
.658 .37732 Mdot
.658 .37733 Mdot
.658 .37756 Mdot
.658 .37764 Mdot
.658 .37768 Mdot
.658 .37768 Mdot
.658 .37776 Mdot
.658 .37784 Mdot
.658 .37784 Mdot
.658 .37785 Mdot
.658 .37788 Mdot
.658 .37792 Mdot
.658 .37792 Mdot
.658 .37793 Mdot
.658 .37793 Mdot
.658 .3781 Mdot
.658 .37815 Mdot
.658 .37823 Mdot
.658 .37828 Mdot
.658 .3785 Mdot
.658 .37853 Mdot
.658 .37857 Mdot
.658 .37861 Mdot
.658 .37861 Mdot
.658 .37862 Mdot
.658 .3787 Mdot
.658 .37872 Mdot
.658 .3788 Mdot
.658 .37882 Mdot
.658 .37882 Mdot
.658 .37898 Mdot
.658 .37911 Mdot
.658 .37925 Mdot
.658 .37938 Mdot
.658 .37962 Mdot
.658 .37965 Mdot
.658 .37971 Mdot
.658 .37975 Mdot
.658 .37984 Mdot
.658 .37988 Mdot
.658 .37989 Mdot
.658 .38013 Mdot
.658 .3803 Mdot
.658 .38051 Mdot
.658 .38051 Mdot
.658 .38053 Mdot
.658 .38063 Mdot
.658 .38104 Mdot
.658 .38116 Mdot
.658 .38118 Mdot
.658 .38133 Mdot
.658 .38133 Mdot
.658 .38138 Mdot
.658 .38152 Mdot
.658 .38156 Mdot
.658 .3816 Mdot
.658 .38178 Mdot
.658 .38184 Mdot
.658 .38188 Mdot
.658 .38189 Mdot
.658 .38192 Mdot
.658 .38203 Mdot
.658 .38208 Mdot
.658 .38217 Mdot
.658 .38219 Mdot
.658 .38221 Mdot
.658 .38221 Mdot
.658 .38236 Mdot
.658 .38248 Mdot
.658 .38248 Mdot
.658 .38249 Mdot
.658 .38249 Mdot
.658 .38258 Mdot
.658 .38261 Mdot
.658 .3828 Mdot
.658 .38284 Mdot
.658 .38305 Mdot
.658 .38307 Mdot
.658 .3832 Mdot
.658 .38325 Mdot
.658 .38329 Mdot
.658 .38331 Mdot
.658 .38339 Mdot
.658 .38342 Mdot
.658 .38354 Mdot
.658 .38357 Mdot
.658 .38395 Mdot
.658 .38398 Mdot
.658 .38402 Mdot
.658 .38408 Mdot
.658 .38438 Mdot
.658 .38442 Mdot
.658 .38446 Mdot
.658 .38446 Mdot
.658 .38448 Mdot
.658 .38449 Mdot
.658 .3845 Mdot
.658 .38455 Mdot
.658 .38458 Mdot
.658 .38466 Mdot
.658 .38469 Mdot
.658 .3847 Mdot
.658 .38474 Mdot
.658 .38474 Mdot
.658 .38492 Mdot
.658 .38503 Mdot
.658 .38507 Mdot
.658 .38509 Mdot
.658 .3852 Mdot
.658 .38535 Mdot
.658 .38535 Mdot
.658 .38542 Mdot
.658 .38542 Mdot
.658 .38561 Mdot
.658 .38573 Mdot
.658 .38577 Mdot
.658 .38591 Mdot
.658 .38598 Mdot
.658 .38602 Mdot
.658 .38621 Mdot
.658 .38627 Mdot
.658 .38632 Mdot
.658 .38649 Mdot
.658 .38655 Mdot
.658 .38655 Mdot
.658 .38664 Mdot
.658 .38664 Mdot
.658 .38664 Mdot
.658 .38675 Mdot
.658 .38676 Mdot
.658 .38683 Mdot
.658 .38692 Mdot
.658 .38714 Mdot
.658 .38729 Mdot
.658 .3873 Mdot
.658 .38733 Mdot
.658 .38734 Mdot
.658 .38749 Mdot
.658 .38751 Mdot
.658 .3876 Mdot
.658 .38762 Mdot
.658 .38762 Mdot
.658 .38768 Mdot
.658 .38774 Mdot
.658 .38781 Mdot
.658 .38782 Mdot
.658 .38791 Mdot
.658 .38803 Mdot
.658 .38803 Mdot
.658 .38803 Mdot
.658 .38806 Mdot
.658 .38807 Mdot
.658 .38809 Mdot
.658 .38824 Mdot
.658 .38826 Mdot
.658 .38832 Mdot
.658 .38835 Mdot
.658 .38842 Mdot
.658 .38842 Mdot
.658 .38845 Mdot
.658 .38849 Mdot
.658 .3885 Mdot
.658 .38856 Mdot
.658 .38867 Mdot
.658 .3887 Mdot
.658 .38875 Mdot
.658 .38881 Mdot
.658 .38889 Mdot
.658 .38894 Mdot
.658 .38899 Mdot
.658 .389 Mdot
.658 .3891 Mdot
.658 .38912 Mdot
.658 .38919 Mdot
.658 .38924 Mdot
.658 .38925 Mdot
.658 .38932 Mdot
.658 .38936 Mdot
.658 .38937 Mdot
.658 .38942 Mdot
.658 .38943 Mdot
.658 .38952 Mdot
.658 .38952 Mdot
.658 .38954 Mdot
.658 .38955 Mdot
.658 .38981 Mdot
.658 .38985 Mdot
.658 .38986 Mdot
.658 .38992 Mdot
.658 .38992 Mdot
.658 .38992 Mdot
.658 .38997 Mdot
.658 .39013 Mdot
.658 .39028 Mdot
.658 .3903 Mdot
.658 .39034 Mdot
.658 .39042 Mdot
.658 .39045 Mdot
.658 .39052 Mdot
.658 .39063 Mdot
.658 .39063 Mdot
.658 .39067 Mdot
.658 .39082 Mdot
.658 .39085 Mdot
.658 .39111 Mdot
.658 .39113 Mdot
.658 .39117 Mdot
.658 .39118 Mdot
.658 .39121 Mdot
.658 .39123 Mdot
.658 .39146 Mdot
.658 .3917 Mdot
.658 .39185 Mdot
.658 .392 Mdot
.658 .39212 Mdot
.658 .39214 Mdot
.658 .39232 Mdot
.658 .39232 Mdot
.658 .39232 Mdot
.658 .39233 Mdot
.658 .39248 Mdot
.658 .39248 Mdot
.658 .39249 Mdot
.658 .3925 Mdot
.658 .39256 Mdot
.658 .39258 Mdot
.658 .39267 Mdot
.658 .39267 Mdot
.658 .3927 Mdot
.658 .39288 Mdot
.658 .39296 Mdot
.658 .39299 Mdot
.658 .39308 Mdot
.658 .39339 Mdot
.658 .39345 Mdot
.658 .39346 Mdot
.658 .39359 Mdot
.658 .39383 Mdot
.658 .39385 Mdot
.658 .3939 Mdot
.658 .39396 Mdot
.658 .39398 Mdot
.658 .39412 Mdot
.658 .39444 Mdot
.658 .39444 Mdot
.658 .39455 Mdot
.658 .39456 Mdot
.658 .39456 Mdot
.658 .39461 Mdot
.658 .39462 Mdot
.658 .39475 Mdot
.658 .39478 Mdot
.658 .39483 Mdot
.658 .39495 Mdot
.658 .39496 Mdot
.658 .39498 Mdot
.658 .395 Mdot
.658 .39505 Mdot
.658 .39509 Mdot
.658 .3951 Mdot
.658 .39512 Mdot
.658 .39517 Mdot
.658 .3953 Mdot
.658 .39531 Mdot
.658 .39545 Mdot
.658 .3956 Mdot
.658 .39561 Mdot
.658 .39561 Mdot
.658 .39568 Mdot
.658 .3957 Mdot
.658 .39576 Mdot
.658 .39589 Mdot
.658 .39594 Mdot
.658 .39599 Mdot
.658 .39603 Mdot
.658 .39606 Mdot
.658 .39606 Mdot
.658 .39609 Mdot
.658 .3961 Mdot
.658 .3961 Mdot
.658 .39616 Mdot
.658 .39617 Mdot
.658 .39622 Mdot
.658 .39624 Mdot
.658 .39643 Mdot
.658 .39644 Mdot
.658 .39647 Mdot
.658 .39676 Mdot
.658 .39687 Mdot
.658 .39692 Mdot
.658 .39693 Mdot
.658 .39698 Mdot
.658 .39719 Mdot
.658 .39735 Mdot
.658 .39737 Mdot
.658 .39764 Mdot
.658 .3977 Mdot
.658 .39777 Mdot
.658 .39791 Mdot
.658 .39792 Mdot
.658 .39795 Mdot
.658 .39797 Mdot
.658 .39798 Mdot
.658 .39809 Mdot
.658 .39811 Mdot
.658 .39813 Mdot
.658 .39819 Mdot
.658 .39826 Mdot
.658 .39826 Mdot
.658 .39827 Mdot
.658 .39828 Mdot
.658 .39832 Mdot
.658 .39839 Mdot
.658 .3984 Mdot
.658 .39841 Mdot
.658 .39841 Mdot
.658 .39851 Mdot
.658 .39855 Mdot
.658 .39871 Mdot
.658 .39878 Mdot
.658 .39891 Mdot
.658 .39893 Mdot
.658 .39898 Mdot
.658 .39902 Mdot
.658 .39931 Mdot
.658 .39936 Mdot
.658 .3994 Mdot
.658 .39945 Mdot
.658 .39951 Mdot
.658 .39951 Mdot
.658 .39952 Mdot
.658 .39953 Mdot
.658 .39954 Mdot
.658 .39959 Mdot
.658 .3996 Mdot
.658 .3996 Mdot
.658 .39973 Mdot
.658 .39975 Mdot
.658 .39977 Mdot
.658 .39991 Mdot
.658 .39995 Mdot
.658 .39996 Mdot
.658 .39999 Mdot
.658 .40001 Mdot
.658 .40002 Mdot
.658 .40007 Mdot
.658 .40022 Mdot
.658 .40023 Mdot
.658 .4003 Mdot
.658 .40045 Mdot
.658 .4005 Mdot
.658 .40056 Mdot
.658 .40057 Mdot
.658 .40065 Mdot
.658 .4007 Mdot
.658 .40074 Mdot
.658 .40092 Mdot
.658 .40105 Mdot
.658 .40113 Mdot
.658 .40119 Mdot
.658 .40134 Mdot
.658 .40139 Mdot
.658 .40143 Mdot
.658 .40149 Mdot
.658 .40152 Mdot
.658 .40152 Mdot
.658 .40157 Mdot
.658 .40172 Mdot
.658 .40178 Mdot
.658 .40178 Mdot
.658 .40181 Mdot
.658 .40181 Mdot
.658 .40202 Mdot
.658 .40222 Mdot
.658 .40251 Mdot
.658 .40274 Mdot
.658 .40288 Mdot
.658 .40289 Mdot
.658 .40291 Mdot
.66 .27951 Mdot
.66 .27955 Mdot
.66 .27985 Mdot
.66 .27992 Mdot
.66 .27998 Mdot
.66 .28006 Mdot
.66 .2801 Mdot
.66 .28012 Mdot
.66 .2803 Mdot
.66 .28031 Mdot
.66 .28042 Mdot
.66 .28045 Mdot
.66 .28048 Mdot
.66 .28049 Mdot
.66 .28052 Mdot
.66 .28074 Mdot
.66 .28077 Mdot
.66 .28102 Mdot
.66 .28126 Mdot
.66 .28129 Mdot
.66 .28135 Mdot
.66 .28143 Mdot
.66 .28145 Mdot
.66 .28147 Mdot
.66 .28153 Mdot
.66 .28156 Mdot
.66 .28162 Mdot
.66 .28175 Mdot
.66 .28176 Mdot
.66 .28177 Mdot
.66 .2818 Mdot
.66 .28185 Mdot
.66 .28194 Mdot
.66 .28197 Mdot
.66 .28198 Mdot
.66 .28201 Mdot
.66 .28204 Mdot
.66 .28223 Mdot
.66 .28226 Mdot
.66 .28226 Mdot
.66 .28248 Mdot
.66 .28249 Mdot
.66 .28253 Mdot
.66 .2827 Mdot
.66 .28276 Mdot
.66 .28279 Mdot
.66 .2828 Mdot
.66 .28284 Mdot
.66 .28289 Mdot
.66 .28293 Mdot
.66 .28298 Mdot
.66 .28298 Mdot
.66 .28352 Mdot
.66 .28356 Mdot
.66 .28358 Mdot
.66 .28363 Mdot
.66 .28366 Mdot
.66 .28368 Mdot
.66 .28369 Mdot
.66 .28372 Mdot
.66 .28374 Mdot
.66 .28381 Mdot
.66 .28389 Mdot
.66 .28399 Mdot
.66 .28413 Mdot
.66 .28423 Mdot
.66 .28446 Mdot
.66 .28457 Mdot
.66 .28459 Mdot
.66 .28463 Mdot
.66 .28469 Mdot
.66 .2847 Mdot
.66 .28479 Mdot
.66 .2848 Mdot
.66 .28511 Mdot
.66 .28529 Mdot
.66 .28534 Mdot
.66 .28541 Mdot
.66 .28556 Mdot
.66 .28556 Mdot
.66 .28559 Mdot
.66 .2857 Mdot
.66 .28592 Mdot
.66 .2861 Mdot
.66 .28613 Mdot
.66 .28619 Mdot
.66 .2862 Mdot
.66 .28625 Mdot
.66 .28639 Mdot
.66 .28643 Mdot
.66 .28654 Mdot
.66 .28661 Mdot
.66 .28666 Mdot
.66 .28672 Mdot
.66 .28682 Mdot
.66 .28684 Mdot
.66 .28687 Mdot
.66 .28705 Mdot
.66 .28713 Mdot
.66 .28734 Mdot
.66 .28749 Mdot
.66 .28757 Mdot
.66 .28776 Mdot
.66 .28784 Mdot
.66 .28786 Mdot
.66 .28801 Mdot
.66 .28817 Mdot
.66 .28818 Mdot
.66 .28831 Mdot
.66 .28857 Mdot
.66 .28858 Mdot
.66 .28858 Mdot
.66 .28859 Mdot
.66 .28885 Mdot
.66 .28892 Mdot
.66 .28914 Mdot
.66 .28928 Mdot
.66 .28937 Mdot
.66 .2895 Mdot
.66 .28964 Mdot
.66 .2897 Mdot
.66 .28984 Mdot
.66 .28994 Mdot
.66 .29 Mdot
.66 .29015 Mdot
.66 .29035 Mdot
.66 .29061 Mdot
.66 .29065 Mdot
.66 .29091 Mdot
.66 .29094 Mdot
.66 .29096 Mdot
.66 .29097 Mdot
.66 .29099 Mdot
.66 .291 Mdot
.66 .29101 Mdot
.66 .29102 Mdot
.66 .29103 Mdot
.66 .29121 Mdot
.66 .29127 Mdot
.66 .29128 Mdot
.66 .29145 Mdot
.66 .29145 Mdot
.66 .29153 Mdot
.66 .2916 Mdot
.66 .29161 Mdot
.66 .29172 Mdot
.66 .29178 Mdot
.66 .29194 Mdot
.66 .29205 Mdot
.66 .29215 Mdot
.66 .29217 Mdot
.66 .2922 Mdot
.66 .29234 Mdot
.66 .29237 Mdot
.66 .29269 Mdot
.66 .29269 Mdot
.66 .2927 Mdot
.66 .29277 Mdot
.66 .29295 Mdot
.66 .29303 Mdot
.66 .29317 Mdot
.66 .29318 Mdot
.66 .29322 Mdot
.66 .29345 Mdot
.66 .29346 Mdot
.66 .29374 Mdot
.66 .29392 Mdot
.66 .29404 Mdot
.66 .29405 Mdot
.66 .2941 Mdot
.66 .29427 Mdot
.66 .29455 Mdot
.66 .29463 Mdot
.66 .2947 Mdot
.66 .29474 Mdot
.66 .29485 Mdot
.66 .295 Mdot
.66 .29511 Mdot
.66 .29535 Mdot
.66 .29536 Mdot
.66 .29547 Mdot
.66 .29561 Mdot
.66 .29615 Mdot
.66 .29616 Mdot
.66 .29616 Mdot
.66 .29624 Mdot
.66 .29624 Mdot
.66 .2963 Mdot
.66 .2963 Mdot
.66 .2966 Mdot
.66 .29671 Mdot
.66 .29674 Mdot
.66 .2968 Mdot
.66 .29687 Mdot
.66 .29696 Mdot
.66 .29711 Mdot
.66 .29716 Mdot
.66 .29717 Mdot
.66 .29732 Mdot
.66 .29751 Mdot
.66 .29762 Mdot
.66 .29788 Mdot
.66 .29803 Mdot
.66 .29804 Mdot
.66 .29817 Mdot
.66 .29818 Mdot
.66 .29823 Mdot
.66 .29842 Mdot
.66 .29851 Mdot
.66 .29898 Mdot
.66 .29905 Mdot
.66 .29914 Mdot
.66 .29946 Mdot
.66 .29956 Mdot
.66 .29958 Mdot
.66 .29972 Mdot
.66 .2998 Mdot
.66 .29981 Mdot
.66 .30005 Mdot
.66 .30008 Mdot
.66 .30013 Mdot
.66 .30013 Mdot
.66 .30053 Mdot
.66 .30059 Mdot
.66 .30073 Mdot
.66 .3008 Mdot
.66 .30096 Mdot
.66 .30106 Mdot
.66 .30131 Mdot
.66 .30134 Mdot
.66 .30141 Mdot
.66 .30152 Mdot
.66 .30168 Mdot
.66 .30184 Mdot
.66 .30197 Mdot
.66 .30207 Mdot
.66 .30212 Mdot
.66 .30231 Mdot
.66 .30243 Mdot
.66 .30249 Mdot
.66 .30274 Mdot
.66 .30279 Mdot
.66 .30283 Mdot
.66 .30283 Mdot
.66 .30293 Mdot
.66 .30294 Mdot
.66 .30297 Mdot
.66 .30307 Mdot
.66 .30308 Mdot
.66 .30308 Mdot
.66 .3031 Mdot
.66 .30314 Mdot
.66 .30346 Mdot
.66 .30403 Mdot
.66 .30416 Mdot
.66 .30429 Mdot
.66 .30447 Mdot
.66 .30448 Mdot
.66 .30449 Mdot
.66 .3049 Mdot
.66 .30491 Mdot
.66 .3051 Mdot
.66 .30519 Mdot
.66 .30536 Mdot
.66 .30546 Mdot
.66 .30554 Mdot
.66 .30561 Mdot
.66 .30565 Mdot
.66 .30572 Mdot
.66 .30574 Mdot
.66 .30582 Mdot
.66 .30585 Mdot
.66 .30589 Mdot
.66 .30591 Mdot
.66 .30601 Mdot
.66 .30613 Mdot
.66 .30621 Mdot
.66 .30634 Mdot
.66 .30637 Mdot
.66 .30666 Mdot
.66 .30675 Mdot
.66 .30677 Mdot
.66 .30697 Mdot
.66 .30729 Mdot
.66 .30777 Mdot
.66 .30781 Mdot
.66 .30795 Mdot
.66 .30797 Mdot
.66 .30812 Mdot
.66 .30819 Mdot
.66 .30823 Mdot
.66 .30827 Mdot
.66 .30829 Mdot
.66 .3084 Mdot
.66 .30851 Mdot
.66 .30852 Mdot
.66 .30856 Mdot
.66 .30863 Mdot
.66 .30866 Mdot
.66 .30882 Mdot
.66 .30898 Mdot
.66 .30911 Mdot
.66 .30912 Mdot
.66 .30913 Mdot
.66 .30935 Mdot
.66 .30945 Mdot
.66 .30949 Mdot
.66 .30969 Mdot
.66 .30973 Mdot
.66 .30998 Mdot
.66 .31002 Mdot
.66 .31006 Mdot
.66 .31016 Mdot
.66 .31017 Mdot
.66 .31023 Mdot
.66 .31025 Mdot
.66 .31043 Mdot
.66 .31071 Mdot
.66 .31081 Mdot
.66 .31082 Mdot
.66 .31092 Mdot
.66 .311 Mdot
.66 .311 Mdot
.66 .31102 Mdot
.66 .31105 Mdot
.66 .31112 Mdot
.66 .31114 Mdot
.66 .31128 Mdot
.66 .31128 Mdot
.66 .31141 Mdot
.66 .31154 Mdot
.66 .31157 Mdot
.66 .3116 Mdot
.66 .31165 Mdot
.66 .31167 Mdot
.66 .3117 Mdot
.66 .3117 Mdot
.66 .31201 Mdot
.66 .31203 Mdot
.66 .31205 Mdot
.66 .31207 Mdot
.66 .31209 Mdot
.66 .3121 Mdot
.66 .31213 Mdot
.66 .31214 Mdot
.66 .31217 Mdot
.66 .31222 Mdot
.66 .31228 Mdot
.66 .31236 Mdot
.66 .31255 Mdot
.66 .31261 Mdot
.66 .31268 Mdot
.66 .31269 Mdot
.66 .31275 Mdot
.66 .31292 Mdot
.66 .31309 Mdot
.66 .31318 Mdot
.66 .3132 Mdot
.66 .31355 Mdot
.66 .31381 Mdot
.66 .31391 Mdot
.66 .31392 Mdot
.66 .31408 Mdot
.66 .31433 Mdot
.66 .31444 Mdot
.66 .31468 Mdot
.66 .31469 Mdot
.66 .31476 Mdot
.66 .31491 Mdot
.66 .31507 Mdot
.66 .31531 Mdot
.66 .31544 Mdot
.66 .31552 Mdot
.66 .31556 Mdot
.66 .31564 Mdot
.66 .31569 Mdot
.66 .31573 Mdot
.66 .31581 Mdot
.66 .31608 Mdot
.66 .3161 Mdot
.66 .31627 Mdot
.66 .31628 Mdot
.66 .31628 Mdot
.66 .3163 Mdot
.66 .31665 Mdot
.66 .31672 Mdot
.66 .31675 Mdot
.66 .31684 Mdot
.66 .31698 Mdot
.66 .31699 Mdot
.66 .31707 Mdot
.66 .31727 Mdot
.66 .31727 Mdot
.66 .31747 Mdot
.66 .31755 Mdot
.66 .31758 Mdot
.66 .31771 Mdot
.66 .31805 Mdot
.66 .31818 Mdot
.66 .31839 Mdot
.66 .31845 Mdot
.66 .31851 Mdot
.66 .3188 Mdot
.66 .31895 Mdot
.66 .31926 Mdot
.66 .31931 Mdot
.66 .31934 Mdot
.66 .31952 Mdot
.66 .31963 Mdot
.66 .31972 Mdot
.66 .31985 Mdot
.66 .32004 Mdot
.66 .3201 Mdot
.66 .32034 Mdot
.66 .32042 Mdot
.66 .32045 Mdot
.66 .32056 Mdot
.66 .32061 Mdot
.66 .32092 Mdot
.66 .32131 Mdot
.66 .3215 Mdot
.66 .32154 Mdot
.66 .32154 Mdot
.66 .32181 Mdot
.66 .32192 Mdot
.66 .32202 Mdot
.66 .32234 Mdot
.66 .32286 Mdot
.66 .32289 Mdot
.66 .32304 Mdot
.66 .32307 Mdot
.66 .32317 Mdot
.66 .32323 Mdot
.66 .32327 Mdot
.66 .32345 Mdot
.66 .32385 Mdot
.66 .32404 Mdot
.66 .32428 Mdot
.66 .32445 Mdot
.66 .3246 Mdot
.66 .32471 Mdot
.66 .32475 Mdot
.66 .32481 Mdot
.66 .32483 Mdot
.66 .32486 Mdot
.66 .32492 Mdot
.66 .32499 Mdot
.66 .32503 Mdot
.66 .3251 Mdot
.66 .32603 Mdot
.66 .32604 Mdot
.66 .32613 Mdot
.66 .32619 Mdot
.66 .32629 Mdot
.66 .32635 Mdot
.66 .32638 Mdot
.66 .32642 Mdot
.66 .32653 Mdot
.66 .32683 Mdot
.66 .32689 Mdot
.66 .32691 Mdot
.66 .3273 Mdot
.66 .3273 Mdot
.66 .32735 Mdot
.66 .32768 Mdot
.66 .32773 Mdot
.66 .32778 Mdot
.66 .32781 Mdot
.66 .32785 Mdot
.66 .32802 Mdot
.66 .32809 Mdot
.66 .32815 Mdot
.66 .32816 Mdot
.66 .32818 Mdot
.66 .32841 Mdot
.66 .32852 Mdot
.66 .32856 Mdot
.66 .32867 Mdot
.66 .32871 Mdot
.66 .32875 Mdot
.66 .32888 Mdot
.66 .32898 Mdot
.66 .32903 Mdot
.66 .32945 Mdot
.66 .32989 Mdot
.66 .32994 Mdot
.66 .33033 Mdot
.66 .33037 Mdot
.66 .3304 Mdot
.66 .33044 Mdot
.66 .33049 Mdot
.66 .3307 Mdot
.66 .33071 Mdot
.66 .33102 Mdot
.66 .33106 Mdot
.66 .33113 Mdot
.66 .33127 Mdot
.66 .33138 Mdot
.66 .33149 Mdot
.66 .33202 Mdot
.66 .33209 Mdot
.66 .36424 Mdot
.66 .3643 Mdot
.66 .36469 Mdot
.66 .36478 Mdot
.66 .36487 Mdot
.66 .36497 Mdot
.66 .36502 Mdot
.66 .36505 Mdot
.66 .36529 Mdot
.66 .3653 Mdot
.66 .36545 Mdot
.66 .36549 Mdot
.66 .36553 Mdot
.66 .36554 Mdot
.66 .36558 Mdot
.66 .36587 Mdot
.66 .36591 Mdot
.66 .36624 Mdot
.66 .36656 Mdot
.66 .3666 Mdot
.66 .36667 Mdot
.66 .36677 Mdot
.66 .36681 Mdot
.66 .36683 Mdot
.66 .36692 Mdot
.66 .36695 Mdot
.66 .36703 Mdot
.66 .3672 Mdot
.66 .36722 Mdot
.66 .36722 Mdot
.66 .36727 Mdot
.66 .36733 Mdot
.66 .36746 Mdot
.66 .36749 Mdot
.66 .36751 Mdot
.66 .36754 Mdot
.66 .36758 Mdot
.66 .36783 Mdot
.66 .36787 Mdot
.66 .36787 Mdot
.66 .36816 Mdot
.66 .36818 Mdot
.66 .36823 Mdot
.66 .36846 Mdot
.66 .36854 Mdot
.66 .36857 Mdot
.66 .36859 Mdot
.66 .36864 Mdot
.66 .36871 Mdot
.66 .36876 Mdot
.66 .36882 Mdot
.66 .36883 Mdot
.66 .36953 Mdot
.66 .36959 Mdot
.66 .36962 Mdot
.66 .36968 Mdot
.66 .36972 Mdot
.66 .36974 Mdot
.66 .36976 Mdot
.66 .3698 Mdot
.66 .36983 Mdot
.66 .36992 Mdot
.66 .37003 Mdot
.66 .37016 Mdot
.66 .37034 Mdot
.66 .37048 Mdot
.66 .37078 Mdot
.66 .37092 Mdot
.66 .37095 Mdot
.66 .371 Mdot
.66 .37108 Mdot
.66 .3711 Mdot
.66 .37121 Mdot
.66 .37123 Mdot
.66 .37163 Mdot
.66 .37187 Mdot
.66 .37194 Mdot
.66 .37203 Mdot
.66 .37223 Mdot
.66 .37223 Mdot
.66 .37227 Mdot
.66 .37241 Mdot
.66 .3727 Mdot
.66 .37294 Mdot
.66 .37298 Mdot
.66 .37306 Mdot
.66 .37308 Mdot
.66 .37314 Mdot
.66 .37332 Mdot
.66 .37337 Mdot
.66 .37352 Mdot
.66 .37361 Mdot
.66 .37368 Mdot
.66 .37377 Mdot
.66 .3739 Mdot
.66 .37392 Mdot
.66 .37396 Mdot
.66 .3742 Mdot
.66 .37431 Mdot
.66 .37453 Mdot
.66 .37458 Mdot
.66 .37462 Mdot
.66 .37478 Mdot
.66 .37488 Mdot
.66 .37514 Mdot
.66 .37524 Mdot
.66 .37526 Mdot
.66 .37532 Mdot
.66 .37547 Mdot
.66 .37547 Mdot
.66 .37562 Mdot
.66 .37568 Mdot
.66 .37569 Mdot
.66 .37579 Mdot
.66 .37587 Mdot
.66 .37589 Mdot
.66 .37594 Mdot
.66 .3762 Mdot
.66 .37622 Mdot
.66 .37622 Mdot
.66 .37623 Mdot
.66 .37636 Mdot
.66 .37637 Mdot
.66 .37657 Mdot
.66 .37664 Mdot
.66 .37666 Mdot
.66 .37671 Mdot
.66 .37677 Mdot
.66 .3768 Mdot
.66 .37686 Mdot
.66 .37695 Mdot
.66 .37714 Mdot
.66 .37725 Mdot
.66 .37737 Mdot
.66 .37743 Mdot
.66 .37743 Mdot
.66 .37761 Mdot
.66 .3777 Mdot
.66 .37788 Mdot
.66 .37801 Mdot
.66 .37802 Mdot
.66 .37809 Mdot
.66 .37829 Mdot
.66 .37856 Mdot
.66 .37857 Mdot
.66 .37863 Mdot
.66 .37877 Mdot
.66 .3789 Mdot
.66 .37894 Mdot
.66 .37895 Mdot
.66 .379 Mdot
.66 .37904 Mdot
.66 .37919 Mdot
.66 .37925 Mdot
.66 .37929 Mdot
.66 .37933 Mdot
.66 .37936 Mdot
.66 .37937 Mdot
.66 .37939 Mdot
.66 .37939 Mdot
.66 .37941 Mdot
.66 .37943 Mdot
.66 .37944 Mdot
.66 .37946 Mdot
.66 .37969 Mdot
.66 .37969 Mdot
.66 .37971 Mdot
.66 .37973 Mdot
.66 .37977 Mdot
.66 .37978 Mdot
.66 .37981 Mdot
.66 .37991 Mdot
.66 .38 Mdot
.66 .38 Mdot
.66 .38011 Mdot
.66 .38013 Mdot
.66 .38018 Mdot
.66 .3802 Mdot
.66 .38022 Mdot
.66 .38022 Mdot
.66 .38028 Mdot
.66 .38035 Mdot
.66 .38037 Mdot
.66 .38044 Mdot
.66 .38065 Mdot
.66 .38079 Mdot
.66 .3808 Mdot
.66 .38085 Mdot
.66 .38085 Mdot
.66 .38093 Mdot
.66 .38096 Mdot
.66 .38099 Mdot
.66 .38118 Mdot
.66 .38121 Mdot
.66 .38136 Mdot
.66 .38139 Mdot
.66 .38147 Mdot
.66 .38164 Mdot
.66 .38164 Mdot
.66 .38165 Mdot
.66 .38175 Mdot
.66 .38187 Mdot
.66 .38199 Mdot
.66 .38202 Mdot
.66 .38207 Mdot
.66 .3821 Mdot
.66 .38211 Mdot
.66 .38219 Mdot
.66 .38227 Mdot
.66 .38229 Mdot
.66 .38232 Mdot
.66 .38235 Mdot
.66 .3824 Mdot
.66 .38251 Mdot
.66 .38253 Mdot
.66 .38264 Mdot
.66 .38266 Mdot
.66 .38303 Mdot
.66 .38327 Mdot
.66 .38342 Mdot
.66 .38344 Mdot
.66 .38351 Mdot
.66 .38373 Mdot
.66 .38375 Mdot
.66 .38385 Mdot
.66 .38391 Mdot
.66 .384 Mdot
.66 .38408 Mdot
.66 .38409 Mdot
.66 .38412 Mdot
.66 .38415 Mdot
.66 .38421 Mdot
.66 .38422 Mdot
.66 .38427 Mdot
.66 .3843 Mdot
.66 .38435 Mdot
.66 .38442 Mdot
.66 .38449 Mdot
.66 .38462 Mdot
.66 .38469 Mdot
.66 .38484 Mdot
.66 .38484 Mdot
.66 .38515 Mdot
.66 .38516 Mdot
.66 .38516 Mdot
.66 .38531 Mdot
.66 .3854 Mdot
.66 .3855 Mdot
.66 .38593 Mdot
.66 .38617 Mdot
.66 .38621 Mdot
.66 .38622 Mdot
.66 .38622 Mdot
.66 .38623 Mdot
.66 .3863 Mdot
.66 .38633 Mdot
.66 .38633 Mdot
.66 .38641 Mdot
.66 .38641 Mdot
.66 .38644 Mdot
.66 .38648 Mdot
.66 .38667 Mdot
.66 .38671 Mdot
.66 .38681 Mdot
.66 .38695 Mdot
.66 .38698 Mdot
.66 .38706 Mdot
.66 .38716 Mdot
.66 .38728 Mdot
.66 .3874 Mdot
.66 .38748 Mdot
.66 .38754 Mdot
.66 .38756 Mdot
.66 .38775 Mdot
.66 .38782 Mdot
.66 .38795 Mdot
.66 .388 Mdot
.66 .3881 Mdot
.66 .38815 Mdot
.66 .38845 Mdot
.66 .38846 Mdot
.66 .38849 Mdot
.66 .38852 Mdot
.66 .38869 Mdot
.66 .38871 Mdot
.66 .38876 Mdot
.66 .38887 Mdot
.66 .38889 Mdot
.66 .38896 Mdot
.66 .3892 Mdot
.66 .38927 Mdot
.66 .38933 Mdot
.66 .38968 Mdot
.66 .38975 Mdot
.66 .38989 Mdot
.66 .38993 Mdot
.66 .38994 Mdot
.66 .39004 Mdot
.66 .39004 Mdot
.66 .39016 Mdot
.66 .39035 Mdot
.66 .39044 Mdot
.66 .39058 Mdot
.66 .39069 Mdot
.66 .39071 Mdot
.66 .39074 Mdot
.66 .39085 Mdot
.66 .39092 Mdot
.66 .39098 Mdot
.66 .39103 Mdot
.66 .39104 Mdot
.66 .39113 Mdot
.66 .39136 Mdot
.66 .39136 Mdot
.66 .3914 Mdot
.66 .3914 Mdot
.66 .39146 Mdot
.66 .39147 Mdot
.66 .39147 Mdot
.66 .39188 Mdot
.66 .39199 Mdot
.66 .39207 Mdot
.66 .39207 Mdot
.66 .39226 Mdot
.66 .39234 Mdot
.66 .39245 Mdot
.66 .39254 Mdot
.66 .39256 Mdot
.66 .39262 Mdot
.66 .39268 Mdot
.66 .39289 Mdot
.66 .39302 Mdot
.66 .39306 Mdot
.66 .39307 Mdot
.66 .39316 Mdot
.66 .39329 Mdot
.66 .3935 Mdot
.66 .39352 Mdot
.66 .39369 Mdot
.66 .39372 Mdot
.66 .39373 Mdot
.66 .39383 Mdot
.66 .39389 Mdot
.66 .39403 Mdot
.66 .39408 Mdot
.66 .39409 Mdot
.66 .39409 Mdot
.66 .39434 Mdot
.66 .39435 Mdot
.66 .39446 Mdot
.66 .39448 Mdot
.66 .3945 Mdot
.66 .39457 Mdot
.66 .39466 Mdot
.66 .39478 Mdot
.66 .39482 Mdot
.66 .39491 Mdot
.66 .39492 Mdot
.66 .39497 Mdot
.66 .39503 Mdot
.66 .39503 Mdot
.66 .39516 Mdot
.66 .39517 Mdot
.66 .39521 Mdot
.66 .39535 Mdot
.66 .39536 Mdot
.66 .39536 Mdot
.66 .39537 Mdot
.66 .39538 Mdot
.66 .3954 Mdot
.66 .3954 Mdot
.66 .39542 Mdot
.66 .39544 Mdot
.66 .39564 Mdot
.66 .39567 Mdot
.66 .39586 Mdot
.66 .39602 Mdot
.66 .39613 Mdot
.66 .39617 Mdot
.66 .39625 Mdot
.66 .39636 Mdot
.66 .3964 Mdot
.66 .39651 Mdot
.66 .39661 Mdot
.66 .39668 Mdot
.66 .39678 Mdot
.66 .39695 Mdot
.66 .397 Mdot
.66 .3972 Mdot
.66 .3972 Mdot
.66 .3972 Mdot
.66 .39721 Mdot
.66 .39741 Mdot
.66 .39751 Mdot
.66 .39751 Mdot
.66 .39775 Mdot
.66 .39777 Mdot
.66 .39782 Mdot
.66 .39797 Mdot
.66 .39803 Mdot
.66 .39815 Mdot
.66 .3983 Mdot
.66 .39836 Mdot
.66 .3985 Mdot
.66 .39852 Mdot
.66 .39853 Mdot
.66 .39861 Mdot
.66 .39866 Mdot
.66 .3987 Mdot
.66 .39875 Mdot
.66 .39884 Mdot
.66 .39886 Mdot
.66 .39897 Mdot
.66 .399 Mdot
.66 .39902 Mdot
.66 .39906 Mdot
.66 .39909 Mdot
.66 .39922 Mdot
.66 .39939 Mdot
.66 .39947 Mdot
.66 .39949 Mdot
.66 .39949 Mdot
.66 .39961 Mdot
.66 .39966 Mdot
.66 .3997 Mdot
.66 .39984 Mdot
.66 .40006 Mdot
.66 .40008 Mdot
.66 .40014 Mdot
.66 .40015 Mdot
.66 .4002 Mdot
.66 .40023 Mdot
.66 .40024 Mdot
.66 .40032 Mdot
.66 .4005 Mdot
.66 .40058 Mdot
.66 .40068 Mdot
.66 .40075 Mdot
.66 .40082 Mdot
.66 .40087 Mdot
.66 .40088 Mdot
.66 .40091 Mdot
.66 .40092 Mdot
.66 .40093 Mdot
.66 .40096 Mdot
.66 .40099 Mdot
.66 .40101 Mdot
.66 .40104 Mdot
.66 .40144 Mdot
.66 .40145 Mdot
.66 .40149 Mdot
.66 .40151 Mdot
.66 .40155 Mdot
.66 .40158 Mdot
.66 .40159 Mdot
.66 .40161 Mdot
.66 .40166 Mdot
.66 .40179 Mdot
.66 .40182 Mdot
.66 .40183 Mdot
.66 .40199 Mdot
.66 .402 Mdot
.66 .40202 Mdot
.66 .40216 Mdot
.66 .40218 Mdot
.66 .4022 Mdot
.66 .40222 Mdot
.66 .40223 Mdot
.66 .40231 Mdot
.66 .40234 Mdot
.66 .40237 Mdot
.66 .40237 Mdot
.66 .40238 Mdot
.66 .40248 Mdot
.66 .40252 Mdot
.66 .40254 Mdot
.66 .40259 Mdot
.66 .40261 Mdot
.66 .40262 Mdot
.66 .40268 Mdot
.66 .40273 Mdot
.66 .40275 Mdot
.66 .40293 Mdot
.66 .40312 Mdot
.66 .40314 Mdot
.66 .40331 Mdot
.66 .40333 Mdot
.66 .40334 Mdot
.66 .40336 Mdot
.66 .40338 Mdot
.66 .40347 Mdot
.66 .40348 Mdot
.66 .40361 Mdot
.66 .40363 Mdot
.66 .40366 Mdot
.66 .40372 Mdot
.66 .40377 Mdot
.66 .40382 Mdot
.66 .40405 Mdot
.66 .40408 Mdot
.662 .2788 Mdot
.662 .27889 Mdot
.662 .27899 Mdot
.662 .279 Mdot
.662 .27903 Mdot
.662 .27905 Mdot
.662 .27915 Mdot
.662 .27919 Mdot
.662 .27928 Mdot
.662 .27932 Mdot
.662 .27948 Mdot
.662 .27949 Mdot
.662 .27961 Mdot
.662 .27963 Mdot
.662 .27986 Mdot
.662 .27996 Mdot
.662 .27997 Mdot
.662 .28001 Mdot
.662 .28011 Mdot
.662 .2803 Mdot
.662 .28048 Mdot
.662 .2806 Mdot
.662 .28081 Mdot
.662 .28097 Mdot
.662 .28109 Mdot
.662 .28113 Mdot
.662 .28135 Mdot
.662 .28138 Mdot
.662 .28139 Mdot
.662 .2814 Mdot
.662 .28172 Mdot
.662 .28173 Mdot
.662 .28174 Mdot
.662 .28179 Mdot
.662 .28185 Mdot
.662 .28187 Mdot
.662 .28187 Mdot
.662 .282 Mdot
.662 .28201 Mdot
.662 .2821 Mdot
.662 .28221 Mdot
.662 .28228 Mdot
.662 .2824 Mdot
.662 .28254 Mdot
.662 .28256 Mdot
.662 .28275 Mdot
.662 .28284 Mdot
.662 .28284 Mdot
.662 .28302 Mdot
.662 .28316 Mdot
.662 .28324 Mdot
.662 .28339 Mdot
.662 .2835 Mdot
.662 .28353 Mdot
.662 .28353 Mdot
.662 .28355 Mdot
.662 .28363 Mdot
.662 .28368 Mdot
.662 .28393 Mdot
.662 .284 Mdot
.662 .28401 Mdot
.662 .28413 Mdot
.662 .28435 Mdot
.662 .28446 Mdot
.662 .28458 Mdot
.662 .28461 Mdot
.662 .28461 Mdot
.662 .28478 Mdot
.662 .28488 Mdot
.662 .28494 Mdot
.662 .28496 Mdot
.662 .28521 Mdot
.662 .28532 Mdot
.662 .28553 Mdot
.662 .28564 Mdot
.662 .28573 Mdot
.662 .28573 Mdot
.662 .28578 Mdot
.662 .2858 Mdot
.662 .28592 Mdot
.662 .28605 Mdot
.662 .28611 Mdot
.662 .28615 Mdot
.662 .28623 Mdot
.662 .28624 Mdot
.662 .28648 Mdot
.662 .28658 Mdot
.662 .28666 Mdot
.662 .28668 Mdot
.662 .28669 Mdot
.662 .28673 Mdot
.662 .28692 Mdot
.662 .28692 Mdot
.662 .28696 Mdot
.662 .28705 Mdot
.662 .28719 Mdot
.662 .28723 Mdot
.662 .28727 Mdot
.662 .2873 Mdot
.662 .28731 Mdot
.662 .28742 Mdot
.662 .28762 Mdot
.662 .28767 Mdot
.662 .28767 Mdot
.662 .28775 Mdot
.662 .28794 Mdot
.662 .28802 Mdot
.662 .28808 Mdot
.662 .28813 Mdot
.662 .28834 Mdot
.662 .2884 Mdot
.662 .28854 Mdot
.662 .28861 Mdot
.662 .28865 Mdot
.662 .28912 Mdot
.662 .2892 Mdot
.662 .28925 Mdot
.662 .28935 Mdot
.662 .28937 Mdot
.662 .28943 Mdot
.662 .28945 Mdot
.662 .28948 Mdot
.662 .28973 Mdot
.662 .28975 Mdot
.662 .28982 Mdot
.662 .28989 Mdot
.662 .29 Mdot
.662 .29006 Mdot
.662 .29013 Mdot
.662 .29028 Mdot
.662 .29044 Mdot
.662 .29072 Mdot
.662 .29088 Mdot
.662 .29106 Mdot
.662 .29117 Mdot
.662 .29126 Mdot
.662 .2913 Mdot
.662 .29135 Mdot
.662 .29163 Mdot
.662 .29174 Mdot
.662 .2919 Mdot
.662 .29201 Mdot
.662 .29208 Mdot
.662 .29212 Mdot
.662 .29214 Mdot
.662 .29222 Mdot
.662 .29227 Mdot
.662 .29254 Mdot
.662 .29264 Mdot
.662 .29288 Mdot
.662 .2929 Mdot
.662 .2929 Mdot
.662 .29301 Mdot
.662 .29305 Mdot
.662 .29313 Mdot
.662 .29316 Mdot
.662 .29323 Mdot
.662 .29327 Mdot
.662 .29337 Mdot
.662 .29337 Mdot
.662 .2935 Mdot
.662 .29359 Mdot
.662 .2936 Mdot
.662 .29364 Mdot
.662 .29372 Mdot
.662 .29375 Mdot
.662 .29386 Mdot
.662 .29394 Mdot
.662 .29395 Mdot
.662 .29405 Mdot
.662 .29431 Mdot
.662 .29433 Mdot
.662 .29437 Mdot
.662 .29443 Mdot
.662 .29445 Mdot
.662 .29447 Mdot
.662 .29448 Mdot
.662 .29462 Mdot
.662 .2947 Mdot
.662 .29483 Mdot
.662 .29494 Mdot
.662 .29503 Mdot
.662 .29507 Mdot
.662 .29509 Mdot
.662 .29516 Mdot
.662 .29518 Mdot
.662 .29523 Mdot
.662 .29525 Mdot
.662 .29549 Mdot
.662 .29561 Mdot
.662 .29574 Mdot
.662 .29579 Mdot
.662 .29608 Mdot
.662 .29627 Mdot
.662 .29653 Mdot
.662 .29656 Mdot
.662 .29673 Mdot
.662 .2968 Mdot
.662 .29687 Mdot
.662 .29691 Mdot
.662 .29692 Mdot
.662 .29698 Mdot
.662 .29711 Mdot
.662 .29735 Mdot
.662 .29736 Mdot
.662 .29753 Mdot
.662 .29768 Mdot
.662 .29789 Mdot
.662 .29795 Mdot
.662 .29797 Mdot
.662 .29809 Mdot
.662 .29809 Mdot
.662 .2982 Mdot
.662 .29837 Mdot
.662 .29859 Mdot
.662 .29872 Mdot
.662 .29889 Mdot
.662 .29907 Mdot
.662 .29907 Mdot
.662 .29928 Mdot
.662 .29933 Mdot
.662 .29935 Mdot
.662 .29943 Mdot
.662 .29969 Mdot
.662 .2998 Mdot
.662 .30007 Mdot
.662 .30036 Mdot
.662 .30037 Mdot
.662 .30045 Mdot
.662 .30052 Mdot
.662 .30072 Mdot
.662 .3008 Mdot
.662 .30102 Mdot
.662 .30102 Mdot
.662 .30113 Mdot
.662 .30114 Mdot
.662 .30121 Mdot
.662 .30134 Mdot
.662 .30146 Mdot
.662 .30153 Mdot
.662 .30155 Mdot
.662 .30162 Mdot
.662 .30176 Mdot
.662 .30182 Mdot
.662 .302 Mdot
.662 .30228 Mdot
.662 .30234 Mdot
.662 .3026 Mdot
.662 .30302 Mdot
.662 .30311 Mdot
.662 .30319 Mdot
.662 .30337 Mdot
.662 .30341 Mdot
.662 .30342 Mdot
.662 .30363 Mdot
.662 .30364 Mdot
.662 .30406 Mdot
.662 .3041 Mdot
.662 .30418 Mdot
.662 .30421 Mdot
.662 .30434 Mdot
.662 .30436 Mdot
.662 .3044 Mdot
.662 .30444 Mdot
.662 .30455 Mdot
.662 .3046 Mdot
.662 .3048 Mdot
.662 .30481 Mdot
.662 .30485 Mdot
.662 .30487 Mdot
.662 .30495 Mdot
.662 .30502 Mdot
.662 .30516 Mdot
.662 .30528 Mdot
.662 .30541 Mdot
.662 .30542 Mdot
.662 .30546 Mdot
.662 .30549 Mdot
.662 .3056 Mdot
.662 .30568 Mdot
.662 .3057 Mdot
.662 .30575 Mdot
.662 .306 Mdot
.662 .30615 Mdot
.662 .30634 Mdot
.662 .30634 Mdot
.662 .30643 Mdot
.662 .30649 Mdot
.662 .30669 Mdot
.662 .30673 Mdot
.662 .30687 Mdot
.662 .30695 Mdot
.662 .30696 Mdot
.662 .30696 Mdot
.662 .30698 Mdot
.662 .30713 Mdot
.662 .30725 Mdot
.662 .30735 Mdot
.662 .30735 Mdot
.662 .30752 Mdot
.662 .3076 Mdot
.662 .30771 Mdot
.662 .30778 Mdot
.662 .30783 Mdot
.662 .3079 Mdot
.662 .30791 Mdot
.662 .30798 Mdot
.662 .30817 Mdot
.662 .30818 Mdot
.662 .3082 Mdot
.662 .30833 Mdot
.662 .30863 Mdot
.662 .3087 Mdot
.662 .3088 Mdot
.662 .30891 Mdot
.662 .30926 Mdot
.662 .30927 Mdot
.662 .30936 Mdot
.662 .30951 Mdot
.662 .30952 Mdot
.662 .30954 Mdot
.662 .30955 Mdot
.662 .3096 Mdot
.662 .30973 Mdot
.662 .30993 Mdot
.662 .30996 Mdot
.662 .31001 Mdot
.662 .3102 Mdot
.662 .31021 Mdot
.662 .31034 Mdot
.662 .3104 Mdot
.662 .3104 Mdot
.662 .31043 Mdot
.662 .31088 Mdot
.662 .31098 Mdot
.662 .31104 Mdot
.662 .31121 Mdot
.662 .3114 Mdot
.662 .31141 Mdot
.662 .31144 Mdot
.662 .31148 Mdot
.662 .31157 Mdot
.662 .31172 Mdot
.662 .31199 Mdot
.662 .31222 Mdot
.662 .31236 Mdot
.662 .31249 Mdot
.662 .31271 Mdot
.662 .31278 Mdot
.662 .31303 Mdot
.662 .31315 Mdot
.662 .3132 Mdot
.662 .31325 Mdot
.662 .31346 Mdot
.662 .31357 Mdot
.662 .31369 Mdot
.662 .31373 Mdot
.662 .31387 Mdot
.662 .31417 Mdot
.662 .31422 Mdot
.662 .31423 Mdot
.662 .31426 Mdot
.662 .31437 Mdot
.662 .31439 Mdot
.662 .31457 Mdot
.662 .31465 Mdot
.662 .31477 Mdot
.662 .3148 Mdot
.662 .31536 Mdot
.662 .31562 Mdot
.662 .31567 Mdot
.662 .3157 Mdot
.662 .3158 Mdot
.662 .31581 Mdot
.662 .31583 Mdot
.662 .31606 Mdot
.662 .31613 Mdot
.662 .31616 Mdot
.662 .31654 Mdot
.662 .31663 Mdot
.662 .31673 Mdot
.662 .31685 Mdot
.662 .31687 Mdot
.662 .3169 Mdot
.662 .31721 Mdot
.662 .31727 Mdot
.662 .31731 Mdot
.662 .31734 Mdot
.662 .31734 Mdot
.662 .31742 Mdot
.662 .31778 Mdot
.662 .31778 Mdot
.662 .31791 Mdot
.662 .31797 Mdot
.662 .31799 Mdot
.662 .31805 Mdot
.662 .31812 Mdot
.662 .31818 Mdot
.662 .3182 Mdot
.662 .31833 Mdot
.662 .31844 Mdot
.662 .31858 Mdot
.662 .31862 Mdot
.662 .31865 Mdot
.662 .31866 Mdot
.662 .31868 Mdot
.662 .31876 Mdot
.662 .3188 Mdot
.662 .31899 Mdot
.662 .31907 Mdot
.662 .31908 Mdot
.662 .31911 Mdot
.662 .31912 Mdot
.662 .31926 Mdot
.662 .3194 Mdot
.662 .31943 Mdot
.662 .31985 Mdot
.662 .31987 Mdot
.662 .32 Mdot
.662 .32007 Mdot
.662 .32018 Mdot
.662 .32042 Mdot
.662 .32063 Mdot
.662 .32066 Mdot
.662 .32074 Mdot
.662 .32074 Mdot
.662 .3209 Mdot
.662 .3211 Mdot
.662 .32146 Mdot
.662 .32166 Mdot
.662 .32209 Mdot
.662 .32212 Mdot
.662 .32224 Mdot
.662 .32241 Mdot
.662 .3227 Mdot
.662 .32271 Mdot
.662 .32276 Mdot
.662 .32297 Mdot
.662 .32316 Mdot
.662 .32355 Mdot
.662 .32375 Mdot
.662 .32377 Mdot
.662 .3239 Mdot
.662 .32434 Mdot
.662 .32443 Mdot
.662 .32457 Mdot
.662 .3246 Mdot
.662 .32461 Mdot
.662 .32466 Mdot
.662 .32484 Mdot
.662 .32511 Mdot
.662 .32525 Mdot
.662 .3255 Mdot
.662 .3258 Mdot
.662 .32581 Mdot
.662 .32597 Mdot
.662 .3263 Mdot
.662 .32634 Mdot
.662 .32658 Mdot
.662 .32679 Mdot
.662 .32691 Mdot
.662 .32711 Mdot
.662 .32726 Mdot
.662 .32728 Mdot
.662 .32751 Mdot
.662 .32751 Mdot
.662 .32754 Mdot
.662 .32765 Mdot
.662 .32773 Mdot
.662 .32776 Mdot
.662 .32778 Mdot
.662 .32834 Mdot
.662 .32836 Mdot
.662 .32838 Mdot
.662 .32843 Mdot
.662 .3288 Mdot
.662 .32888 Mdot
.662 .32908 Mdot
.662 .32936 Mdot
.662 .32974 Mdot
.662 .32994 Mdot
.662 .33026 Mdot
.662 .33059 Mdot
.662 .33077 Mdot
.662 .33084 Mdot
.662 .33086 Mdot
.662 .33103 Mdot
.662 .33144 Mdot
.662 .33147 Mdot
.662 .33168 Mdot
.662 .33171 Mdot
.662 .33197 Mdot
.662 .33205 Mdot
.662 .33221 Mdot
.662 .33228 Mdot
.662 .33245 Mdot
.662 .33249 Mdot
.662 .33253 Mdot
.662 .33256 Mdot
.662 .33273 Mdot
.662 .3329 Mdot
.662 .36436 Mdot
.662 .36449 Mdot
.662 .36462 Mdot
.662 .36463 Mdot
.662 .36467 Mdot
.662 .3647 Mdot
.662 .36482 Mdot
.662 .36488 Mdot
.662 .365 Mdot
.662 .36506 Mdot
.662 .36526 Mdot
.662 .36528 Mdot
.662 .36544 Mdot
.662 .36546 Mdot
.662 .36577 Mdot
.662 .3659 Mdot
.662 .36591 Mdot
.662 .36597 Mdot
.662 .3661 Mdot
.662 .36635 Mdot
.662 .36659 Mdot
.662 .36674 Mdot
.662 .36703 Mdot
.662 .36724 Mdot
.662 .36739 Mdot
.662 .36745 Mdot
.662 .36773 Mdot
.662 .36777 Mdot
.662 .36779 Mdot
.662 .3678 Mdot
.662 .36823 Mdot
.662 .36824 Mdot
.662 .36826 Mdot
.662 .36832 Mdot
.662 .3684 Mdot
.662 .36843 Mdot
.662 .36843 Mdot
.662 .3686 Mdot
.662 .36861 Mdot
.662 .36873 Mdot
.662 .36888 Mdot
.662 .36897 Mdot
.662 .36913 Mdot
.662 .36931 Mdot
.662 .36934 Mdot
.662 .36959 Mdot
.662 .36971 Mdot
.662 .36972 Mdot
.662 .36995 Mdot
.662 .37013 Mdot
.662 .37024 Mdot
.662 .37045 Mdot
.662 .37058 Mdot
.662 .37062 Mdot
.662 .37063 Mdot
.662 .37065 Mdot
.662 .37076 Mdot
.662 .37082 Mdot
.662 .37115 Mdot
.662 .37125 Mdot
.662 .37127 Mdot
.662 .37142 Mdot
.662 .37171 Mdot
.662 .37186 Mdot
.662 .37202 Mdot
.662 .37205 Mdot
.662 .37206 Mdot
.662 .37228 Mdot
.662 .37241 Mdot
.662 .3725 Mdot
.662 .37252 Mdot
.662 .37285 Mdot
.662 .373 Mdot
.662 .37327 Mdot
.662 .37342 Mdot
.662 .37354 Mdot
.662 .37354 Mdot
.662 .3736 Mdot
.662 .37363 Mdot
.662 .37378 Mdot
.662 .37396 Mdot
.662 .37405 Mdot
.662 .3741 Mdot
.662 .3742 Mdot
.662 .37421 Mdot
.662 .37453 Mdot
.662 .37455 Mdot
.662 .37466 Mdot
.662 .37477 Mdot
.662 .37478 Mdot
.662 .3748 Mdot
.662 .3748 Mdot
.662 .37486 Mdot
.662 .375 Mdot
.662 .37504 Mdot
.662 .3751 Mdot
.662 .37511 Mdot
.662 .37512 Mdot
.662 .37514 Mdot
.662 .37517 Mdot
.662 .37528 Mdot
.662 .37536 Mdot
.662 .37546 Mdot
.662 .37548 Mdot
.662 .37552 Mdot
.662 .37558 Mdot
.662 .37562 Mdot
.662 .37564 Mdot
.662 .37568 Mdot
.662 .37578 Mdot
.662 .37578 Mdot
.662 .37605 Mdot
.662 .37611 Mdot
.662 .37611 Mdot
.662 .37613 Mdot
.662 .37616 Mdot
.662 .37621 Mdot
.662 .37644 Mdot
.662 .37647 Mdot
.662 .37648 Mdot
.662 .37657 Mdot
.662 .37665 Mdot
.662 .37671 Mdot
.662 .377 Mdot
.662 .37703 Mdot
.662 .37708 Mdot
.662 .37725 Mdot
.662 .37727 Mdot
.662 .37727 Mdot
.662 .37735 Mdot
.662 .37737 Mdot
.662 .37741 Mdot
.662 .37761 Mdot
.662 .37803 Mdot
.662 .37805 Mdot
.662 .37814 Mdot
.662 .3782 Mdot
.662 .37834 Mdot
.662 .37835 Mdot
.662 .37844 Mdot
.662 .37846 Mdot
.662 .37847 Mdot
.662 .3785 Mdot
.662 .37873 Mdot
.662 .37884 Mdot
.662 .37887 Mdot
.662 .37895 Mdot
.662 .37904 Mdot
.662 .3792 Mdot
.662 .37923 Mdot
.662 .37928 Mdot
.662 .37936 Mdot
.662 .37956 Mdot
.662 .37961 Mdot
.662 .37977 Mdot
.662 .37987 Mdot
.662 .37997 Mdot
.662 .38015 Mdot
.662 .38035 Mdot
.662 .38047 Mdot
.662 .38054 Mdot
.662 .38056 Mdot
.662 .38059 Mdot
.662 .3806 Mdot
.662 .38074 Mdot
.662 .38087 Mdot
.662 .38092 Mdot
.662 .38098 Mdot
.662 .38133 Mdot
.662 .38135 Mdot
.662 .38135 Mdot
.662 .38139 Mdot
.662 .3815 Mdot
.662 .3815 Mdot
.662 .38164 Mdot
.662 .38169 Mdot
.662 .3817 Mdot
.662 .38185 Mdot
.662 .38195 Mdot
.662 .38199 Mdot
.662 .382 Mdot
.662 .38201 Mdot
.662 .38202 Mdot
.662 .38214 Mdot
.662 .3822 Mdot
.662 .38221 Mdot
.662 .38248 Mdot
.662 .38256 Mdot
.662 .38264 Mdot
.662 .38269 Mdot
.662 .38292 Mdot
.662 .38301 Mdot
.662 .38303 Mdot
.662 .38303 Mdot
.662 .38318 Mdot
.662 .38323 Mdot
.662 .38324 Mdot
.662 .38329 Mdot
.662 .38333 Mdot
.662 .38338 Mdot
.662 .38346 Mdot
.662 .38352 Mdot
.662 .38365 Mdot
.662 .38365 Mdot
.662 .38373 Mdot
.662 .38382 Mdot
.662 .38394 Mdot
.662 .38395 Mdot
.662 .38395 Mdot
.662 .38396 Mdot
.662 .38401 Mdot
.662 .38412 Mdot
.662 .38415 Mdot
.662 .3843 Mdot
.662 .38435 Mdot
.662 .38441 Mdot
.662 .38442 Mdot
.662 .38456 Mdot
.662 .38467 Mdot
.662 .38486 Mdot
.662 .3849 Mdot
.662 .38492 Mdot
.662 .38498 Mdot
.662 .38506 Mdot
.662 .38508 Mdot
.662 .38511 Mdot
.662 .38512 Mdot
.662 .38522 Mdot
.662 .38531 Mdot
.662 .38541 Mdot
.662 .38546 Mdot
.662 .38553 Mdot
.662 .38554 Mdot
.662 .38557 Mdot
.662 .38558 Mdot
.662 .38573 Mdot
.662 .38577 Mdot
.662 .38585 Mdot
.662 .38588 Mdot
.662 .38591 Mdot
.662 .38593 Mdot
.662 .38602 Mdot
.662 .38605 Mdot
.662 .38611 Mdot
.662 .38614 Mdot
.662 .38646 Mdot
.662 .38647 Mdot
.662 .38662 Mdot
.662 .38663 Mdot
.662 .38666 Mdot
.662 .38679 Mdot
.662 .38686 Mdot
.662 .38693 Mdot
.662 .38724 Mdot
.662 .38744 Mdot
.662 .38749 Mdot
.662 .3877 Mdot
.662 .38783 Mdot
.662 .38787 Mdot
.662 .38798 Mdot
.662 .38804 Mdot
.662 .38805 Mdot
.662 .3881 Mdot
.662 .38819 Mdot
.662 .38829 Mdot
.662 .38834 Mdot
.662 .38835 Mdot
.662 .38844 Mdot
.662 .38844 Mdot
.662 .3886 Mdot
.662 .38866 Mdot
.662 .38882 Mdot
.662 .38887 Mdot
.662 .38892 Mdot
.662 .38893 Mdot
.662 .38916 Mdot
.662 .38936 Mdot
.662 .38944 Mdot
.662 .38964 Mdot
.662 .3897 Mdot
.662 .38972 Mdot
.662 .38975 Mdot
.662 .3899 Mdot
.662 .38991 Mdot
.662 .39005 Mdot
.662 .39017 Mdot
.662 .39027 Mdot
.662 .39044 Mdot
.662 .39057 Mdot
.662 .39065 Mdot
.662 .39065 Mdot
.662 .39074 Mdot
.662 .39076 Mdot
.662 .3908 Mdot
.662 .39096 Mdot
.662 .39107 Mdot
.662 .3912 Mdot
.662 .39121 Mdot
.662 .39139 Mdot
.662 .39148 Mdot
.662 .39153 Mdot
.662 .39154 Mdot
.662 .39157 Mdot
.662 .39163 Mdot
.662 .39168 Mdot
.662 .39181 Mdot
.662 .39183 Mdot
.662 .39203 Mdot
.662 .39217 Mdot
.662 .39239 Mdot
.662 .39242 Mdot
.662 .39252 Mdot
.662 .39261 Mdot
.662 .3928 Mdot
.662 .39281 Mdot
.662 .39285 Mdot
.662 .39286 Mdot
.662 .39291 Mdot
.662 .39293 Mdot
.662 .39296 Mdot
.662 .39303 Mdot
.662 .39311 Mdot
.662 .39321 Mdot
.662 .39327 Mdot
.662 .39338 Mdot
.662 .39338 Mdot
.662 .3934 Mdot
.662 .39341 Mdot
.662 .39346 Mdot
.662 .39349 Mdot
.662 .3935 Mdot
.662 .3937 Mdot
.662 .39378 Mdot
.662 .39378 Mdot
.662 .39384 Mdot
.662 .39393 Mdot
.662 .39395 Mdot
.662 .39401 Mdot
.662 .39404 Mdot
.662 .39404 Mdot
.662 .39412 Mdot
.662 .39421 Mdot
.662 .39421 Mdot
.662 .39429 Mdot
.662 .39432 Mdot
.662 .39437 Mdot
.662 .3944 Mdot
.662 .39445 Mdot
.662 .39448 Mdot
.662 .39457 Mdot
.662 .39457 Mdot
.662 .39458 Mdot
.662 .39477 Mdot
.662 .39484 Mdot
.662 .39504 Mdot
.662 .39508 Mdot
.662 .39515 Mdot
.662 .39516 Mdot
.662 .39518 Mdot
.662 .39524 Mdot
.662 .39533 Mdot
.662 .39544 Mdot
.662 .39553 Mdot
.662 .39574 Mdot
.662 .39578 Mdot
.662 .3958 Mdot
.662 .39587 Mdot
.662 .39596 Mdot
.662 .3961 Mdot
.662 .39621 Mdot
.662 .39643 Mdot
.662 .39655 Mdot
.662 .39666 Mdot
.662 .39671 Mdot
.662 .39676 Mdot
.662 .39684 Mdot
.662 .39689 Mdot
.662 .39694 Mdot
.662 .39696 Mdot
.662 .39715 Mdot
.662 .39718 Mdot
.662 .39719 Mdot
.662 .39724 Mdot
.662 .39725 Mdot
.662 .39732 Mdot
.662 .39736 Mdot
.662 .39742 Mdot
.662 .39778 Mdot
.662 .39781 Mdot
.662 .39786 Mdot
.662 .39797 Mdot
.662 .39801 Mdot
.662 .39817 Mdot
.662 .39821 Mdot
.662 .39825 Mdot
.662 .39831 Mdot
.662 .39846 Mdot
.662 .39852 Mdot
.662 .39852 Mdot
.662 .39855 Mdot
.662 .39871 Mdot
.662 .39879 Mdot
.662 .3988 Mdot
.662 .39882 Mdot
.662 .39885 Mdot
.662 .39888 Mdot
.662 .39899 Mdot
.662 .39905 Mdot
.662 .39908 Mdot
.662 .39909 Mdot
.662 .39923 Mdot
.662 .39926 Mdot
.662 .39927 Mdot
.662 .39928 Mdot
.662 .39934 Mdot
.662 .39942 Mdot
.662 .3996 Mdot
.662 .39961 Mdot
.662 .39966 Mdot
.662 .39969 Mdot
.662 .39974 Mdot
.662 .39984 Mdot
.662 .39993 Mdot
.662 .39995 Mdot
.662 .39998 Mdot
.662 .39998 Mdot
.662 .40005 Mdot
.662 .40014 Mdot
.662 .40029 Mdot
.662 .40038 Mdot
.662 .40056 Mdot
.662 .40058 Mdot
.662 .40063 Mdot
.662 .4007 Mdot
.662 .40083 Mdot
.662 .40083 Mdot
.662 .40085 Mdot
.662 .40094 Mdot
.662 .40103 Mdot
.662 .40119 Mdot
.662 .40128 Mdot
.662 .40129 Mdot
.662 .40135 Mdot
.662 .40153 Mdot
.662 .40157 Mdot
.662 .40163 Mdot
.662 .40164 Mdot
.662 .40165 Mdot
.662 .40167 Mdot
.662 .40175 Mdot
.662 .40187 Mdot
.662 .40193 Mdot
.662 .40203 Mdot
.662 .40216 Mdot
.662 .40217 Mdot
.662 .40223 Mdot
.662 .40239 Mdot
.662 .4025 Mdot
.662 .40259 Mdot
.662 .40264 Mdot
.662 .40273 Mdot
.662 .40279 Mdot
.662 .4028 Mdot
.662 .4029 Mdot
.662 .4029 Mdot
.662 .40291 Mdot
.662 .40296 Mdot
.662 .40299 Mdot
.662 .40301 Mdot
.662 .40301 Mdot
.662 .40326 Mdot
.662 .40326 Mdot
.662 .40327 Mdot
.662 .4033 Mdot
.662 .40346 Mdot
.662 .40349 Mdot
.662 .40358 Mdot
.662 .4037 Mdot
.662 .40386 Mdot
.662 .40395 Mdot
.662 .40408 Mdot
.662 .40423 Mdot
.662 .4043 Mdot
.662 .40434 Mdot
.662 .40434 Mdot
.662 .40442 Mdot
.662 .40459 Mdot
.662 .40461 Mdot
.662 .4047 Mdot
.662 .40471 Mdot
.662 .40482 Mdot
.662 .40485 Mdot
.662 .40493 Mdot
.662 .40496 Mdot
.662 .40503 Mdot
.662 .40504 Mdot
.662 .40506 Mdot
.662 .40507 Mdot
.662 .40515 Mdot
.662 .40522 Mdot
.664 .27797 Mdot
.664 .278 Mdot
.664 .27809 Mdot
.664 .27818 Mdot
.664 .27846 Mdot
.664 .2785 Mdot
.664 .27855 Mdot
.664 .27863 Mdot
.664 .27882 Mdot
.664 .27912 Mdot
.664 .27931 Mdot
.664 .27946 Mdot
.664 .27958 Mdot
.664 .27975 Mdot
.664 .27984 Mdot
.664 .27985 Mdot
.664 .28016 Mdot
.664 .28016 Mdot
.664 .28019 Mdot
.664 .28034 Mdot
.664 .2804 Mdot
.664 .28042 Mdot
.664 .28061 Mdot
.664 .28063 Mdot
.664 .28064 Mdot
.664 .2807 Mdot
.664 .28085 Mdot
.664 .28093 Mdot
.664 .28096 Mdot
.664 .28105 Mdot
.664 .28109 Mdot
.664 .2811 Mdot
.664 .28129 Mdot
.664 .28134 Mdot
.664 .2814 Mdot
.664 .28146 Mdot
.664 .2815 Mdot
.664 .28152 Mdot
.664 .28179 Mdot
.664 .28206 Mdot
.664 .28234 Mdot
.664 .28256 Mdot
.664 .28269 Mdot
.664 .28274 Mdot
.664 .28281 Mdot
.664 .28297 Mdot
.664 .28301 Mdot
.664 .28328 Mdot
.664 .28339 Mdot
.664 .28341 Mdot
.664 .28341 Mdot
.664 .28356 Mdot
.664 .28369 Mdot
.664 .28381 Mdot
.664 .28389 Mdot
.664 .28397 Mdot
.664 .28419 Mdot
.664 .2843 Mdot
.664 .2844 Mdot
.664 .28474 Mdot
.664 .28477 Mdot
.664 .2848 Mdot
.664 .28484 Mdot
.664 .28502 Mdot
.664 .28509 Mdot
.664 .28511 Mdot
.664 .28517 Mdot
.664 .28532 Mdot
.664 .28532 Mdot
.664 .28537 Mdot
.664 .28543 Mdot
.664 .28543 Mdot
.664 .2855 Mdot
.664 .28551 Mdot
.664 .28551 Mdot
.664 .28554 Mdot
.664 .28561 Mdot
.664 .28562 Mdot
.664 .28568 Mdot
.664 .2857 Mdot
.664 .28591 Mdot
.664 .28595 Mdot
.664 .28605 Mdot
.664 .28625 Mdot
.664 .28632 Mdot
.664 .2864 Mdot
.664 .28649 Mdot
.664 .2865 Mdot
.664 .28651 Mdot
.664 .28669 Mdot
.664 .28698 Mdot
.664 .28701 Mdot
.664 .28703 Mdot
.664 .28729 Mdot
.664 .28756 Mdot
.664 .28765 Mdot
.664 .28768 Mdot
.664 .28771 Mdot
.664 .28795 Mdot
.664 .28798 Mdot
.664 .28799 Mdot
.664 .28801 Mdot
.664 .28802 Mdot
.664 .28806 Mdot
.664 .28811 Mdot
.664 .28832 Mdot
.664 .28844 Mdot
.664 .28847 Mdot
.664 .28847 Mdot
.664 .28848 Mdot
.664 .28848 Mdot
.664 .28858 Mdot
.664 .28889 Mdot
.664 .28913 Mdot
.664 .28915 Mdot
.664 .28924 Mdot
.664 .28927 Mdot
.664 .28927 Mdot
.664 .28932 Mdot
.664 .28941 Mdot
.664 .28943 Mdot
.664 .28949 Mdot
.664 .28952 Mdot
.664 .28963 Mdot
.664 .2899 Mdot
.664 .28995 Mdot
.664 .28999 Mdot
.664 .29038 Mdot
.664 .29047 Mdot
.664 .29056 Mdot
.664 .29058 Mdot
.664 .29061 Mdot
.664 .29082 Mdot
.664 .29084 Mdot
.664 .29094 Mdot
.664 .291 Mdot
.664 .29109 Mdot
.664 .2911 Mdot
.664 .29113 Mdot
.664 .29127 Mdot
.664 .29151 Mdot
.664 .29154 Mdot
.664 .29169 Mdot
.664 .29192 Mdot
.664 .29218 Mdot
.664 .29249 Mdot
.664 .29256 Mdot
.664 .29263 Mdot
.664 .29267 Mdot
.664 .29271 Mdot
.664 .29277 Mdot
.664 .29281 Mdot
.664 .29331 Mdot
.664 .29332 Mdot
.664 .29345 Mdot
.664 .29345 Mdot
.664 .29354 Mdot
.664 .2937 Mdot
.664 .2939 Mdot
.664 .2941 Mdot
.664 .2941 Mdot
.664 .29413 Mdot
.664 .29414 Mdot
.664 .29416 Mdot
.664 .29418 Mdot
.664 .29419 Mdot
.664 .29439 Mdot
.664 .29442 Mdot
.664 .29444 Mdot
.664 .29445 Mdot
.664 .29445 Mdot
.664 .29461 Mdot
.664 .2947 Mdot
.664 .29482 Mdot
.664 .29491 Mdot
.664 .29495 Mdot
.664 .29508 Mdot
.664 .29511 Mdot
.664 .29522 Mdot
.664 .29533 Mdot
.664 .29535 Mdot
.664 .29554 Mdot
.664 .29575 Mdot
.664 .29584 Mdot
.664 .29587 Mdot
.664 .29592 Mdot
.664 .29593 Mdot
.664 .29598 Mdot
.664 .29607 Mdot
.664 .29619 Mdot
.664 .29627 Mdot
.664 .29646 Mdot
.664 .29647 Mdot
.664 .29664 Mdot
.664 .29668 Mdot
.664 .29668 Mdot
.664 .29689 Mdot
.664 .29691 Mdot
.664 .29692 Mdot
.664 .29699 Mdot
.664 .297 Mdot
.664 .297 Mdot
.664 .29712 Mdot
.664 .29716 Mdot
.664 .29721 Mdot
.664 .29722 Mdot
.664 .29725 Mdot
.664 .29729 Mdot
.664 .29729 Mdot
.664 .29746 Mdot
.664 .29748 Mdot
.664 .29765 Mdot
.664 .29765 Mdot
.664 .29779 Mdot
.664 .29782 Mdot
.664 .29782 Mdot
.664 .29782 Mdot
.664 .29809 Mdot
.664 .29828 Mdot
.664 .29844 Mdot
.664 .29845 Mdot
.664 .29853 Mdot
.664 .29874 Mdot
.664 .2989 Mdot
.664 .2989 Mdot
.664 .29891 Mdot
.664 .29895 Mdot
.664 .2992 Mdot
.664 .29921 Mdot
.664 .29931 Mdot
.664 .29943 Mdot
.664 .2995 Mdot
.664 .29951 Mdot
.664 .29954 Mdot
.664 .29961 Mdot
.664 .29983 Mdot
.664 .29985 Mdot
.664 .29991 Mdot
.664 .29997 Mdot
.664 .29999 Mdot
.664 .30006 Mdot
.664 .30014 Mdot
.664 .30035 Mdot
.664 .30035 Mdot
.664 .30037 Mdot
.664 .3005 Mdot
.664 .30051 Mdot
.664 .30054 Mdot
.664 .30066 Mdot
.664 .30091 Mdot
.664 .30092 Mdot
.664 .30098 Mdot
.664 .30099 Mdot
.664 .30128 Mdot
.664 .3013 Mdot
.664 .30133 Mdot
.664 .30163 Mdot
.664 .30178 Mdot
.664 .302 Mdot
.664 .30201 Mdot
.664 .30215 Mdot
.664 .30223 Mdot
.664 .30225 Mdot
.664 .30225 Mdot
.664 .30234 Mdot
.664 .3024 Mdot
.664 .30252 Mdot
.664 .30255 Mdot
.664 .30287 Mdot
.664 .30293 Mdot
.664 .30326 Mdot
.664 .30328 Mdot
.664 .3033 Mdot
.664 .3035 Mdot
.664 .30368 Mdot
.664 .30373 Mdot
.664 .30374 Mdot
.664 .30375 Mdot
.664 .30382 Mdot
.664 .30397 Mdot
.664 .30403 Mdot
.664 .30417 Mdot
.664 .30421 Mdot
.664 .30441 Mdot
.664 .30457 Mdot
.664 .30485 Mdot
.664 .30485 Mdot
.664 .30486 Mdot
.664 .30491 Mdot
.664 .30496 Mdot
.664 .305 Mdot
.664 .30511 Mdot
.664 .30531 Mdot
.664 .30532 Mdot
.664 .30536 Mdot
.664 .3054 Mdot
.664 .30542 Mdot
.664 .30546 Mdot
.664 .30546 Mdot
.664 .30561 Mdot
.664 .30582 Mdot
.664 .30583 Mdot
.664 .30617 Mdot
.664 .30638 Mdot
.664 .30645 Mdot
.664 .30661 Mdot
.664 .30662 Mdot
.664 .30683 Mdot
.664 .30685 Mdot
.664 .30709 Mdot
.664 .30775 Mdot
.664 .30781 Mdot
.664 .30792 Mdot
.664 .30794 Mdot
.664 .308 Mdot
.664 .30806 Mdot
.664 .30818 Mdot
.664 .30831 Mdot
.664 .30878 Mdot
.664 .30885 Mdot
.664 .30932 Mdot
.664 .30963 Mdot
.664 .3097 Mdot
.664 .30972 Mdot
.664 .30982 Mdot
.664 .30998 Mdot
.664 .31 Mdot
.664 .31003 Mdot
.664 .31018 Mdot
.664 .31035 Mdot
.664 .31046 Mdot
.664 .31071 Mdot
.664 .31076 Mdot
.664 .31077 Mdot
.664 .31094 Mdot
.664 .31094 Mdot
.664 .31096 Mdot
.664 .31105 Mdot
.664 .31109 Mdot
.664 .31121 Mdot
.664 .31125 Mdot
.664 .31138 Mdot
.664 .31147 Mdot
.664 .31161 Mdot
.664 .31168 Mdot
.664 .3117 Mdot
.664 .31171 Mdot
.664 .31187 Mdot
.664 .31202 Mdot
.664 .31218 Mdot
.664 .31238 Mdot
.664 .31241 Mdot
.664 .31245 Mdot
.664 .31271 Mdot
.664 .31279 Mdot
.664 .31287 Mdot
.664 .31306 Mdot
.664 .3131 Mdot
.664 .31329 Mdot
.664 .31335 Mdot
.664 .31354 Mdot
.664 .3136 Mdot
.664 .3137 Mdot
.664 .31374 Mdot
.664 .31375 Mdot
.664 .31387 Mdot
.664 .31387 Mdot
.664 .3139 Mdot
.664 .31398 Mdot
.664 .31398 Mdot
.664 .31403 Mdot
.664 .3142 Mdot
.664 .31423 Mdot
.664 .31465 Mdot
.664 .31481 Mdot
.664 .31484 Mdot
.664 .31514 Mdot
.664 .31521 Mdot
.664 .31538 Mdot
.664 .31539 Mdot
.664 .3154 Mdot
.664 .3154 Mdot
.664 .31545 Mdot
.664 .31565 Mdot
.664 .31566 Mdot
.664 .31603 Mdot
.664 .31604 Mdot
.664 .31611 Mdot
.664 .31619 Mdot
.664 .3162 Mdot
.664 .31623 Mdot
.664 .31625 Mdot
.664 .31631 Mdot
.664 .31649 Mdot
.664 .31674 Mdot
.664 .31679 Mdot
.664 .31685 Mdot
.664 .317 Mdot
.664 .31709 Mdot
.664 .31748 Mdot
.664 .31793 Mdot
.664 .31797 Mdot
.664 .31802 Mdot
.664 .31803 Mdot
.664 .31853 Mdot
.664 .31862 Mdot
.664 .31885 Mdot
.664 .31886 Mdot
.664 .31887 Mdot
.664 .3189 Mdot
.664 .31901 Mdot
.664 .31904 Mdot
.664 .31914 Mdot
.664 .31919 Mdot
.664 .31931 Mdot
.664 .31966 Mdot
.664 .31983 Mdot
.664 .31991 Mdot
.664 .32003 Mdot
.664 .32029 Mdot
.664 .32031 Mdot
.664 .32031 Mdot
.664 .32043 Mdot
.664 .32045 Mdot
.664 .32056 Mdot
.664 .32058 Mdot
.664 .32061 Mdot
.664 .32061 Mdot
.664 .32063 Mdot
.664 .32066 Mdot
.664 .32075 Mdot
.664 .32076 Mdot
.664 .32086 Mdot
.664 .32096 Mdot
.664 .32096 Mdot
.664 .32122 Mdot
.664 .32131 Mdot
.664 .32136 Mdot
.664 .32148 Mdot
.664 .3218 Mdot
.664 .32187 Mdot
.664 .32191 Mdot
.664 .32197 Mdot
.664 .32257 Mdot
.664 .32276 Mdot
.664 .32295 Mdot
.664 .32333 Mdot
.664 .32347 Mdot
.664 .32362 Mdot
.664 .32382 Mdot
.664 .32405 Mdot
.664 .32431 Mdot
.664 .32432 Mdot
.664 .32436 Mdot
.664 .32456 Mdot
.664 .32503 Mdot
.664 .32509 Mdot
.664 .32537 Mdot
.664 .3255 Mdot
.664 .32581 Mdot
.664 .32621 Mdot
.664 .3267 Mdot
.664 .32717 Mdot
.664 .32765 Mdot
.664 .3277 Mdot
.664 .32776 Mdot
.664 .32787 Mdot
.664 .32797 Mdot
.664 .32806 Mdot
.664 .3284 Mdot
.664 .32841 Mdot
.664 .32848 Mdot
.664 .32864 Mdot
.664 .3287 Mdot
.664 .32883 Mdot
.664 .3291 Mdot
.664 .32921 Mdot
.664 .32923 Mdot
.664 .32925 Mdot
.664 .3296 Mdot
.664 .32962 Mdot
.664 .32973 Mdot
.664 .32999 Mdot
.664 .33006 Mdot
.664 .33006 Mdot
.664 .33059 Mdot
.664 .33061 Mdot
.664 .33078 Mdot
.664 .33107 Mdot
.664 .33128 Mdot
.664 .33155 Mdot
.664 .33188 Mdot
.664 .33242 Mdot
.664 .33275 Mdot
.664 .33289 Mdot
.664 .33297 Mdot
.664 .33304 Mdot
.664 .33355 Mdot
.664 .33371 Mdot
.664 .33387 Mdot
.664 .33391 Mdot
.664 .36432 Mdot
.664 .36435 Mdot
.664 .36447 Mdot
.664 .36459 Mdot
.664 .36497 Mdot
.664 .36503 Mdot
.664 .36509 Mdot
.664 .36519 Mdot
.664 .36544 Mdot
.664 .36585 Mdot
.664 .3661 Mdot
.664 .3663 Mdot
.664 .36646 Mdot
.664 .36668 Mdot
.664 .36681 Mdot
.664 .36682 Mdot
.664 .36722 Mdot
.664 .36722 Mdot
.664 .36727 Mdot
.664 .36747 Mdot
.664 .36755 Mdot
.664 .36757 Mdot
.664 .36783 Mdot
.664 .36785 Mdot
.664 .36786 Mdot
.664 .36794 Mdot
.664 .36815 Mdot
.664 .36824 Mdot
.664 .36829 Mdot
.664 .36841 Mdot
.664 .36846 Mdot
.664 .36847 Mdot
.664 .36872 Mdot
.664 .3688 Mdot
.664 .36887 Mdot
.664 .36895 Mdot
.664 .369 Mdot
.664 .36903 Mdot
.664 .3694 Mdot
.664 .36975 Mdot
.664 .37012 Mdot
.664 .37042 Mdot
.664 .37065 Mdot
.664 .37075 Mdot
.664 .37096 Mdot
.664 .37101 Mdot
.664 .37136 Mdot
.664 .37151 Mdot
.664 .37154 Mdot
.664 .37155 Mdot
.664 .37174 Mdot
.664 .37192 Mdot
.664 .37207 Mdot
.664 .37218 Mdot
.664 .37228 Mdot
.664 .37257 Mdot
.664 .37272 Mdot
.664 .37286 Mdot
.664 .37331 Mdot
.664 .37335 Mdot
.664 .37339 Mdot
.664 .37344 Mdot
.664 .37368 Mdot
.664 .37377 Mdot
.664 .3738 Mdot
.664 .37388 Mdot
.664 .37407 Mdot
.664 .37407 Mdot
.664 .37414 Mdot
.664 .37422 Mdot
.664 .37423 Mdot
.664 .3743 Mdot
.664 .37432 Mdot
.664 .37433 Mdot
.664 .37434 Mdot
.664 .37435 Mdot
.664 .37437 Mdot
.664 .37446 Mdot
.664 .37447 Mdot
.664 .37456 Mdot
.664 .37456 Mdot
.664 .37458 Mdot
.664 .37477 Mdot
.664 .37486 Mdot
.664 .37492 Mdot
.664 .37505 Mdot
.664 .37532 Mdot
.664 .37541 Mdot
.664 .37544 Mdot
.664 .37552 Mdot
.664 .37554 Mdot
.664 .37563 Mdot
.664 .37565 Mdot
.664 .37565 Mdot
.664 .37566 Mdot
.664 .37583 Mdot
.664 .3759 Mdot
.664 .37628 Mdot
.664 .37629 Mdot
.664 .37632 Mdot
.664 .37635 Mdot
.664 .37669 Mdot
.664 .37699 Mdot
.664 .37705 Mdot
.664 .37717 Mdot
.664 .37721 Mdot
.664 .37725 Mdot
.664 .37743 Mdot
.664 .37757 Mdot
.664 .37762 Mdot
.664 .37763 Mdot
.664 .37766 Mdot
.664 .37766 Mdot
.664 .37772 Mdot
.664 .37778 Mdot
.664 .37778 Mdot
.664 .37806 Mdot
.664 .37807 Mdot
.664 .37822 Mdot
.664 .37826 Mdot
.664 .37826 Mdot
.664 .37827 Mdot
.664 .37827 Mdot
.664 .3784 Mdot
.664 .37845 Mdot
.664 .37868 Mdot
.664 .3787 Mdot
.664 .37883 Mdot
.664 .37914 Mdot
.664 .37916 Mdot
.664 .37929 Mdot
.664 .37933 Mdot
.664 .37933 Mdot
.664 .37939 Mdot
.664 .37941 Mdot
.664 .37941 Mdot
.664 .3795 Mdot
.664 .37951 Mdot
.664 .37954 Mdot
.664 .37962 Mdot
.664 .37966 Mdot
.664 .3798 Mdot
.664 .37985 Mdot
.664 .37999 Mdot
.664 .38002 Mdot
.664 .38016 Mdot
.664 .38023 Mdot
.664 .38028 Mdot
.664 .38048 Mdot
.664 .38051 Mdot
.664 .38054 Mdot
.664 .38068 Mdot
.664 .3808 Mdot
.664 .38092 Mdot
.664 .38103 Mdot
.664 .38104 Mdot
.664 .38106 Mdot
.664 .38111 Mdot
.664 .38121 Mdot
.664 .38129 Mdot
.664 .38138 Mdot
.664 .38141 Mdot
.664 .3815 Mdot
.664 .38154 Mdot
.664 .3816 Mdot
.664 .38162 Mdot
.664 .38162 Mdot
.664 .38175 Mdot
.664 .38175 Mdot
.664 .38179 Mdot
.664 .38198 Mdot
.664 .38206 Mdot
.664 .38219 Mdot
.664 .3823 Mdot
.664 .38232 Mdot
.664 .38234 Mdot
.664 .38246 Mdot
.664 .38254 Mdot
.664 .38255 Mdot
.664 .38261 Mdot
.664 .38284 Mdot
.664 .38319 Mdot
.664 .38324 Mdot
.664 .3836 Mdot
.664 .38369 Mdot
.664 .38379 Mdot
.664 .38383 Mdot
.664 .38387 Mdot
.664 .38389 Mdot
.664 .38397 Mdot
.664 .38402 Mdot
.664 .38452 Mdot
.664 .38469 Mdot
.664 .38471 Mdot
.664 .38487 Mdot
.664 .38488 Mdot
.664 .385 Mdot
.664 .38505 Mdot
.664 .38521 Mdot
.664 .38546 Mdot
.664 .38547 Mdot
.664 .38563 Mdot
.664 .38574 Mdot
.664 .38574 Mdot
.664 .38577 Mdot
.664 .38579 Mdot
.664 .38582 Mdot
.664 .38585 Mdot
.664 .38586 Mdot
.664 .38601 Mdot
.664 .38609 Mdot
.664 .38612 Mdot
.664 .38616 Mdot
.664 .38619 Mdot
.664 .3862 Mdot
.664 .3862 Mdot
.664 .38642 Mdot
.664 .38654 Mdot
.664 .38669 Mdot
.664 .38671 Mdot
.664 .38682 Mdot
.664 .38687 Mdot
.664 .38698 Mdot
.664 .38703 Mdot
.664 .38704 Mdot
.664 .38704 Mdot
.664 .38709 Mdot
.664 .38722 Mdot
.664 .38737 Mdot
.664 .38738 Mdot
.664 .3874 Mdot
.664 .38765 Mdot
.664 .38769 Mdot
.664 .38793 Mdot
.664 .38796 Mdot
.664 .38804 Mdot
.664 .38809 Mdot
.664 .38816 Mdot
.664 .38816 Mdot
.664 .38817 Mdot
.664 .38823 Mdot
.664 .38834 Mdot
.664 .38835 Mdot
.664 .38851 Mdot
.664 .38863 Mdot
.664 .38885 Mdot
.664 .38888 Mdot
.664 .38889 Mdot
.664 .38911 Mdot
.664 .38911 Mdot
.664 .38917 Mdot
.664 .38917 Mdot
.664 .38936 Mdot
.664 .38945 Mdot
.664 .38947 Mdot
.664 .38948 Mdot
.664 .38958 Mdot
.664 .38959 Mdot
.664 .38959 Mdot
.664 .38975 Mdot
.664 .38981 Mdot
.664 .38986 Mdot
.664 .38988 Mdot
.664 .38992 Mdot
.664 .38997 Mdot
.664 .38998 Mdot
.664 .39015 Mdot
.664 .3902 Mdot
.664 .39022 Mdot
.664 .39023 Mdot
.664 .39028 Mdot
.664 .39037 Mdot
.664 .39045 Mdot
.664 .39046 Mdot
.664 .39064 Mdot
.664 .39068 Mdot
.664 .39068 Mdot
.664 .39068 Mdot
.664 .3908 Mdot
.664 .39096 Mdot
.664 .39102 Mdot
.664 .39103 Mdot
.664 .39115 Mdot
.664 .3913 Mdot
.664 .39149 Mdot
.664 .39149 Mdot
.664 .3915 Mdot
.664 .39152 Mdot
.664 .39162 Mdot
.664 .39162 Mdot
.664 .39175 Mdot
.664 .39177 Mdot
.664 .39189 Mdot
.664 .3919 Mdot
.664 .39193 Mdot
.664 .39195 Mdot
.664 .39196 Mdot
.664 .39199 Mdot
.664 .39202 Mdot
.664 .39211 Mdot
.664 .39211 Mdot
.664 .39212 Mdot
.664 .39217 Mdot
.664 .39218 Mdot
.664 .3922 Mdot
.664 .39235 Mdot
.664 .39235 Mdot
.664 .39238 Mdot
.664 .39251 Mdot
.664 .39252 Mdot
.664 .39266 Mdot
.664 .39272 Mdot
.664 .39282 Mdot
.664 .39288 Mdot
.664 .39292 Mdot
.664 .39292 Mdot
.664 .39296 Mdot
.664 .39299 Mdot
.664 .39305 Mdot
.664 .39321 Mdot
.664 .39335 Mdot
.664 .39337 Mdot
.664 .39346 Mdot
.664 .39353 Mdot
.664 .39356 Mdot
.664 .39366 Mdot
.664 .39369 Mdot
.664 .39376 Mdot
.664 .39385 Mdot
.664 .39391 Mdot
.664 .39403 Mdot
.664 .39404 Mdot
.664 .39404 Mdot
.664 .39406 Mdot
.664 .39408 Mdot
.664 .39423 Mdot
.664 .39423 Mdot
.664 .39425 Mdot
.664 .39427 Mdot
.664 .39428 Mdot
.664 .39429 Mdot
.664 .3943 Mdot
.664 .39445 Mdot
.664 .3946 Mdot
.664 .39472 Mdot
.664 .39478 Mdot
.664 .39479 Mdot
.664 .39488 Mdot
.664 .39489 Mdot
.664 .39527 Mdot
.664 .3953 Mdot
.664 .39535 Mdot
.664 .39538 Mdot
.664 .3954 Mdot
.664 .39546 Mdot
.664 .39551 Mdot
.664 .39574 Mdot
.664 .39594 Mdot
.664 .39611 Mdot
.664 .39623 Mdot
.664 .39625 Mdot
.664 .39643 Mdot
.664 .39654 Mdot
.664 .39656 Mdot
.664 .39656 Mdot
.664 .39664 Mdot
.664 .39668 Mdot
.664 .39675 Mdot
.664 .39677 Mdot
.664 .39692 Mdot
.664 .39695 Mdot
.664 .39697 Mdot
.664 .39703 Mdot
.664 .3971 Mdot
.664 .39739 Mdot
.664 .39742 Mdot
.664 .39746 Mdot
.664 .39766 Mdot
.664 .39775 Mdot
.664 .39777 Mdot
.664 .39781 Mdot
.664 .39783 Mdot
.664 .3979 Mdot
.664 .39793 Mdot
.664 .39793 Mdot
.664 .39795 Mdot
.664 .39803 Mdot
.664 .39804 Mdot
.664 .39822 Mdot
.664 .39846 Mdot
.664 .39853 Mdot
.664 .39853 Mdot
.664 .39854 Mdot
.664 .39854 Mdot
.664 .39856 Mdot
.664 .39865 Mdot
.664 .39881 Mdot
.664 .39884 Mdot
.664 .39888 Mdot
.664 .39888 Mdot
.664 .3989 Mdot
.664 .3989 Mdot
.664 .39893 Mdot
.664 .39911 Mdot
.664 .39913 Mdot
.664 .39916 Mdot
.664 .39922 Mdot
.664 .39943 Mdot
.664 .39962 Mdot
.664 .39964 Mdot
.664 .39966 Mdot
.664 .39988 Mdot
.664 .40001 Mdot
.664 .40002 Mdot
.664 .40003 Mdot
.664 .40009 Mdot
.664 .40016 Mdot
.664 .40021 Mdot
.664 .40036 Mdot
.664 .40043 Mdot
.664 .40047 Mdot
.664 .40063 Mdot
.664 .40064 Mdot
.664 .40069 Mdot
.664 .40069 Mdot
.664 .40074 Mdot
.664 .40076 Mdot
.664 .40077 Mdot
.664 .40077 Mdot
.664 .40082 Mdot
.664 .40083 Mdot
.664 .40087 Mdot
.664 .40091 Mdot
.664 .40091 Mdot
.664 .40102 Mdot
.664 .40106 Mdot
.664 .40108 Mdot
.664 .40113 Mdot
.664 .40127 Mdot
.664 .4013 Mdot
.664 .40132 Mdot
.664 .40134 Mdot
.664 .4016 Mdot
.664 .40168 Mdot
.664 .40176 Mdot
.664 .40193 Mdot
.664 .40198 Mdot
.664 .40205 Mdot
.664 .40214 Mdot
.664 .40223 Mdot
.664 .40234 Mdot
.664 .40235 Mdot
.664 .40236 Mdot
.664 .40245 Mdot
.664 .40265 Mdot
.664 .40268 Mdot
.664 .4028 Mdot
.664 .40285 Mdot
.664 .40289 Mdot
.664 .40298 Mdot
.664 .40316 Mdot
.664 .40336 Mdot
.664 .40356 Mdot
.664 .40377 Mdot
.664 .40379 Mdot
.664 .40382 Mdot
.664 .40386 Mdot
.664 .4039 Mdot
.664 .40395 Mdot
.664 .40409 Mdot
.664 .40409 Mdot
.664 .40412 Mdot
.664 .40419 Mdot
.664 .40422 Mdot
.664 .40427 Mdot
.664 .40439 Mdot
.664 .40444 Mdot
.664 .40444 Mdot
.664 .4046 Mdot
.664 .40461 Mdot
.664 .40466 Mdot
.664 .40477 Mdot
.664 .4048 Mdot
.664 .4048 Mdot
.664 .40503 Mdot
.664 .40503 Mdot
.664 .4051 Mdot
.664 .40523 Mdot
.664 .40532 Mdot
.664 .40543 Mdot
.664 .40558 Mdot
.664 .40581 Mdot
.664 .40595 Mdot
.664 .40601 Mdot
.664 .40604 Mdot
.664 .40607 Mdot
.664 .40629 Mdot
.664 .40636 Mdot
.664 .40642 Mdot
.664 .40644 Mdot
.666 .2772 Mdot
.666 .27723 Mdot
.666 .27777 Mdot
.666 .2778 Mdot
.666 .27787 Mdot
.666 .27805 Mdot
.666 .27812 Mdot
.666 .27814 Mdot
.666 .27841 Mdot
.666 .27859 Mdot
.666 .27863 Mdot
.666 .27867 Mdot
.666 .27874 Mdot
.666 .27881 Mdot
.666 .27898 Mdot
.666 .27903 Mdot
.666 .27908 Mdot
.666 .27934 Mdot
.666 .27938 Mdot
.666 .27941 Mdot
.666 .27963 Mdot
.666 .27976 Mdot
.666 .27985 Mdot
.666 .27988 Mdot
.666 .27991 Mdot
.666 .27993 Mdot
.666 .28003 Mdot
.666 .28006 Mdot
.666 .28007 Mdot
.666 .28011 Mdot
.666 .28026 Mdot
.666 .28026 Mdot
.666 .28027 Mdot
.666 .28038 Mdot
.666 .28042 Mdot
.666 .28066 Mdot
.666 .28071 Mdot
.666 .28089 Mdot
.666 .28093 Mdot
.666 .28094 Mdot
.666 .28104 Mdot
.666 .28143 Mdot
.666 .28148 Mdot
.666 .28152 Mdot
.666 .28153 Mdot
.666 .28154 Mdot
.666 .28155 Mdot
.666 .28159 Mdot
.666 .2816 Mdot
.666 .28194 Mdot
.666 .28207 Mdot
.666 .28214 Mdot
.666 .28218 Mdot
.666 .28222 Mdot
.666 .28227 Mdot
.666 .28236 Mdot
.666 .28236 Mdot
.666 .28256 Mdot
.666 .28263 Mdot
.666 .28265 Mdot
.666 .28266 Mdot
.666 .28268 Mdot
.666 .28284 Mdot
.666 .28292 Mdot
.666 .28293 Mdot
.666 .2833 Mdot
.666 .28333 Mdot
.666 .28342 Mdot
.666 .28347 Mdot
.666 .28353 Mdot
.666 .28354 Mdot
.666 .28366 Mdot
.666 .28375 Mdot
.666 .2838 Mdot
.666 .28383 Mdot
.666 .28383 Mdot
.666 .28386 Mdot
.666 .28387 Mdot
.666 .28402 Mdot
.666 .28402 Mdot
.666 .28434 Mdot
.666 .28434 Mdot
.666 .28441 Mdot
.666 .28453 Mdot
.666 .28456 Mdot
.666 .28484 Mdot
.666 .28495 Mdot
.666 .28508 Mdot
.666 .28512 Mdot
.666 .28514 Mdot
.666 .2852 Mdot
.666 .28522 Mdot
.666 .28528 Mdot
.666 .28566 Mdot
.666 .28569 Mdot
.666 .28587 Mdot
.666 .28605 Mdot
.666 .28617 Mdot
.666 .2862 Mdot
.666 .28625 Mdot
.666 .28631 Mdot
.666 .28635 Mdot
.666 .28647 Mdot
.666 .28649 Mdot
.666 .2866 Mdot
.666 .28668 Mdot
.666 .2867 Mdot
.666 .28672 Mdot
.666 .28686 Mdot
.666 .28699 Mdot
.666 .28722 Mdot
.666 .28739 Mdot
.666 .28741 Mdot
.666 .28767 Mdot
.666 .28774 Mdot
.666 .28812 Mdot
.666 .28813 Mdot
.666 .28835 Mdot
.666 .28842 Mdot
.666 .28861 Mdot
.666 .28868 Mdot
.666 .28882 Mdot
.666 .28884 Mdot
.666 .28908 Mdot
.666 .28925 Mdot
.666 .28955 Mdot
.666 .28963 Mdot
.666 .28966 Mdot
.666 .28973 Mdot
.666 .28979 Mdot
.666 .28998 Mdot
.666 .28999 Mdot
.666 .29002 Mdot
.666 .29025 Mdot
.666 .29036 Mdot
.666 .29044 Mdot
.666 .29045 Mdot
.666 .2905 Mdot
.666 .29052 Mdot
.666 .29066 Mdot
.666 .29077 Mdot
.666 .2909 Mdot
.666 .29098 Mdot
.666 .29107 Mdot
.666 .29115 Mdot
.666 .29139 Mdot
.666 .29168 Mdot
.666 .29182 Mdot
.666 .29183 Mdot
.666 .29187 Mdot
.666 .29189 Mdot
.666 .29194 Mdot
.666 .29219 Mdot
.666 .29228 Mdot
.666 .29235 Mdot
.666 .29256 Mdot
.666 .29256 Mdot
.666 .2926 Mdot
.666 .29277 Mdot
.666 .29277 Mdot
.666 .29288 Mdot
.666 .29292 Mdot
.666 .29297 Mdot
.666 .29299 Mdot
.666 .29311 Mdot
.666 .29331 Mdot
.666 .29337 Mdot
.666 .29347 Mdot
.666 .29348 Mdot
.666 .29349 Mdot
.666 .29354 Mdot
.666 .29364 Mdot
.666 .2938 Mdot
.666 .29384 Mdot
.666 .29389 Mdot
.666 .29392 Mdot
.666 .29394 Mdot
.666 .29423 Mdot
.666 .29436 Mdot
.666 .2944 Mdot
.666 .29444 Mdot
.666 .29449 Mdot
.666 .29485 Mdot
.666 .29492 Mdot
.666 .29507 Mdot
.666 .29515 Mdot
.666 .2952 Mdot
.666 .2953 Mdot
.666 .29544 Mdot
.666 .29556 Mdot
.666 .2956 Mdot
.666 .29561 Mdot
.666 .29597 Mdot
.666 .29619 Mdot
.666 .29636 Mdot
.666 .29655 Mdot
.666 .2966 Mdot
.666 .29668 Mdot
.666 .29679 Mdot
.666 .29683 Mdot
.666 .29684 Mdot
.666 .29685 Mdot
.666 .29698 Mdot
.666 .2971 Mdot
.666 .29721 Mdot
.666 .29741 Mdot
.666 .29773 Mdot
.666 .29841 Mdot
.666 .29847 Mdot
.666 .29862 Mdot
.666 .29862 Mdot
.666 .29871 Mdot
.666 .29898 Mdot
.666 .2991 Mdot
.666 .29931 Mdot
.666 .29932 Mdot
.666 .29934 Mdot
.666 .29954 Mdot
.666 .29974 Mdot
.666 .29997 Mdot
.666 .29999 Mdot
.666 .30001 Mdot
.666 .30009 Mdot
.666 .30028 Mdot
.666 .30031 Mdot
.666 .30033 Mdot
.666 .30042 Mdot
.666 .30051 Mdot
.666 .3008 Mdot
.666 .30082 Mdot
.666 .30085 Mdot
.666 .30091 Mdot
.666 .30091 Mdot
.666 .30103 Mdot
.666 .30115 Mdot
.666 .30118 Mdot
.666 .30144 Mdot
.666 .30153 Mdot
.666 .30182 Mdot
.666 .30187 Mdot
.666 .30204 Mdot
.666 .30218 Mdot
.666 .30219 Mdot
.666 .30222 Mdot
.666 .30227 Mdot
.666 .30248 Mdot
.666 .30248 Mdot
.666 .30259 Mdot
.666 .30273 Mdot
.666 .3029 Mdot
.666 .30299 Mdot
.666 .30312 Mdot
.666 .3034 Mdot
.666 .30353 Mdot
.666 .30375 Mdot
.666 .30378 Mdot
.666 .30404 Mdot
.666 .30417 Mdot
.666 .30424 Mdot
.666 .30432 Mdot
.666 .30439 Mdot
.666 .30453 Mdot
.666 .30459 Mdot
.666 .30462 Mdot
.666 .30463 Mdot
.666 .3047 Mdot
.666 .3049 Mdot
.666 .30513 Mdot
.666 .30518 Mdot
.666 .30522 Mdot
.666 .30532 Mdot
.666 .30538 Mdot
.666 .30554 Mdot
.666 .30555 Mdot
.666 .30566 Mdot
.666 .30584 Mdot
.666 .30584 Mdot
.666 .30593 Mdot
.666 .30595 Mdot
.666 .30597 Mdot
.666 .306 Mdot
.666 .30611 Mdot
.666 .30615 Mdot
.666 .30623 Mdot
.666 .30625 Mdot
.666 .30646 Mdot
.666 .30661 Mdot
.666 .30683 Mdot
.666 .30686 Mdot
.666 .30688 Mdot
.666 .30694 Mdot
.666 .30702 Mdot
.666 .30721 Mdot
.666 .30721 Mdot
.666 .30752 Mdot
.666 .30758 Mdot
.666 .30758 Mdot
.666 .30795 Mdot
.666 .30796 Mdot
.666 .30796 Mdot
.666 .30808 Mdot
.666 .30809 Mdot
.666 .30814 Mdot
.666 .30816 Mdot
.666 .30818 Mdot
.666 .30824 Mdot
.666 .30832 Mdot
.666 .30846 Mdot
.666 .30868 Mdot
.666 .30878 Mdot
.666 .30882 Mdot
.666 .30888 Mdot
.666 .30891 Mdot
.666 .30915 Mdot
.666 .30967 Mdot
.666 .30971 Mdot
.666 .31003 Mdot
.666 .31004 Mdot
.666 .31008 Mdot
.666 .31018 Mdot
.666 .31023 Mdot
.666 .31039 Mdot
.666 .31053 Mdot
.666 .31074 Mdot
.666 .31077 Mdot
.666 .31091 Mdot
.666 .31095 Mdot
.666 .3112 Mdot
.666 .31124 Mdot
.666 .31132 Mdot
.666 .31135 Mdot
.666 .3115 Mdot
.666 .31165 Mdot
.666 .31169 Mdot
.666 .31178 Mdot
.666 .31209 Mdot
.666 .31212 Mdot
.666 .31214 Mdot
.666 .31215 Mdot
.666 .31215 Mdot
.666 .31216 Mdot
.666 .31249 Mdot
.666 .31261 Mdot
.666 .31262 Mdot
.666 .31273 Mdot
.666 .31277 Mdot
.666 .31278 Mdot
.666 .3128 Mdot
.666 .31288 Mdot
.666 .31293 Mdot
.666 .31321 Mdot
.666 .31327 Mdot
.666 .31335 Mdot
.666 .31344 Mdot
.666 .31346 Mdot
.666 .31373 Mdot
.666 .31377 Mdot
.666 .31415 Mdot
.666 .31418 Mdot
.666 .31423 Mdot
.666 .31448 Mdot
.666 .3146 Mdot
.666 .31484 Mdot
.666 .31493 Mdot
.666 .31494 Mdot
.666 .31505 Mdot
.666 .31506 Mdot
.666 .31545 Mdot
.666 .31546 Mdot
.666 .31586 Mdot
.666 .31603 Mdot
.666 .31614 Mdot
.666 .31617 Mdot
.666 .31625 Mdot
.666 .31671 Mdot
.666 .31673 Mdot
.666 .31677 Mdot
.666 .31693 Mdot
.666 .31706 Mdot
.666 .31717 Mdot
.666 .31729 Mdot
.666 .31743 Mdot
.666 .31747 Mdot
.666 .3177 Mdot
.666 .31794 Mdot
.666 .31797 Mdot
.666 .31799 Mdot
.666 .31802 Mdot
.666 .31815 Mdot
.666 .31836 Mdot
.666 .31838 Mdot
.666 .3186 Mdot
.666 .31867 Mdot
.666 .31879 Mdot
.666 .31882 Mdot
.666 .31888 Mdot
.666 .31889 Mdot
.666 .31892 Mdot
.666 .31913 Mdot
.666 .31914 Mdot
.666 .31945 Mdot
.666 .31969 Mdot
.666 .31978 Mdot
.666 .31982 Mdot
.666 .31991 Mdot
.666 .31999 Mdot
.666 .3205 Mdot
.666 .32061 Mdot
.666 .32064 Mdot
.666 .32075 Mdot
.666 .32078 Mdot
.666 .32086 Mdot
.666 .3211 Mdot
.666 .32128 Mdot
.666 .3217 Mdot
.666 .32178 Mdot
.666 .32178 Mdot
.666 .32183 Mdot
.666 .32205 Mdot
.666 .32217 Mdot
.666 .32217 Mdot
.666 .32273 Mdot
.666 .32274 Mdot
.666 .32301 Mdot
.666 .32302 Mdot
.666 .32307 Mdot
.666 .32307 Mdot
.666 .32314 Mdot
.666 .32322 Mdot
.666 .32337 Mdot
.666 .32358 Mdot
.666 .32361 Mdot
.666 .32371 Mdot
.666 .32381 Mdot
.666 .32396 Mdot
.666 .32402 Mdot
.666 .32467 Mdot
.666 .32469 Mdot
.666 .32483 Mdot
.666 .32511 Mdot
.666 .32514 Mdot
.666 .32517 Mdot
.666 .32521 Mdot
.666 .32532 Mdot
.666 .32568 Mdot
.666 .32569 Mdot
.666 .32585 Mdot
.666 .32594 Mdot
.666 .326 Mdot
.666 .32607 Mdot
.666 .3262 Mdot
.666 .32643 Mdot
.666 .32704 Mdot
.666 .32704 Mdot
.666 .32712 Mdot
.666 .32714 Mdot
.666 .32716 Mdot
.666 .32716 Mdot
.666 .32725 Mdot
.666 .32732 Mdot
.666 .32803 Mdot
.666 .32821 Mdot
.666 .32822 Mdot
.666 .3283 Mdot
.666 .32861 Mdot
.666 .32871 Mdot
.666 .32913 Mdot
.666 .3292 Mdot
.666 .32939 Mdot
.666 .3294 Mdot
.666 .32941 Mdot
.666 .32967 Mdot
.666 .32975 Mdot
.666 .32977 Mdot
.666 .32982 Mdot
.666 .33 Mdot
.666 .33004 Mdot
.666 .33008 Mdot
.666 .33013 Mdot
.666 .3303 Mdot
.666 .33053 Mdot
.666 .33092 Mdot
.666 .33097 Mdot
.666 .33105 Mdot
.666 .3315 Mdot
.666 .33159 Mdot
.666 .33167 Mdot
.666 .33198 Mdot
.666 .3321 Mdot
.666 .33223 Mdot
.666 .3323 Mdot
.666 .33238 Mdot
.666 .33269 Mdot
.666 .33316 Mdot
.666 .3332 Mdot
.666 .33334 Mdot
.666 .33366 Mdot
.666 .33378 Mdot
.666 .33382 Mdot
.666 .33479 Mdot
.666 .33483 Mdot
.666 .36435 Mdot
.666 .36438 Mdot
.666 .36511 Mdot
.666 .36514 Mdot
.666 .36523 Mdot
.666 .36547 Mdot
.666 .36557 Mdot
.666 .3656 Mdot
.666 .36596 Mdot
.666 .36619 Mdot
.666 .36625 Mdot
.666 .3663 Mdot
.666 .3664 Mdot
.666 .36649 Mdot
.666 .36672 Mdot
.666 .36678 Mdot
.666 .36685 Mdot
.666 .36719 Mdot
.666 .36725 Mdot
.666 .36729 Mdot
.666 .36758 Mdot
.666 .36776 Mdot
.666 .36788 Mdot
.666 .36792 Mdot
.666 .36795 Mdot
.666 .36798 Mdot
.666 .36811 Mdot
.666 .36815 Mdot
.666 .36816 Mdot
.666 .36823 Mdot
.666 .36842 Mdot
.666 .36843 Mdot
.666 .36844 Mdot
.666 .36858 Mdot
.666 .36863 Mdot
.666 .36895 Mdot
.666 .36902 Mdot
.666 .36926 Mdot
.666 .36932 Mdot
.666 .36932 Mdot
.666 .36946 Mdot
.666 .36999 Mdot
.666 .37005 Mdot
.666 .37011 Mdot
.666 .37011 Mdot
.666 .37012 Mdot
.666 .37014 Mdot
.666 .3702 Mdot
.666 .3702 Mdot
.666 .37065 Mdot
.666 .37083 Mdot
.666 .37093 Mdot
.666 .37098 Mdot
.666 .37103 Mdot
.666 .37109 Mdot
.666 .37122 Mdot
.666 .37122 Mdot
.666 .37149 Mdot
.666 .37158 Mdot
.666 .37161 Mdot
.666 .37162 Mdot
.666 .37165 Mdot
.666 .37186 Mdot
.666 .37196 Mdot
.666 .37198 Mdot
.666 .37247 Mdot
.666 .37252 Mdot
.666 .37263 Mdot
.666 .3727 Mdot
.666 .37277 Mdot
.666 .37279 Mdot
.666 .37296 Mdot
.666 .37306 Mdot
.666 .37313 Mdot
.666 .37318 Mdot
.666 .37318 Mdot
.666 .37322 Mdot
.666 .37323 Mdot
.666 .37343 Mdot
.666 .37343 Mdot
.666 .37386 Mdot
.666 .37386 Mdot
.666 .37394 Mdot
.666 .37411 Mdot
.666 .37415 Mdot
.666 .37415 Mdot
.666 .37421 Mdot
.666 .37452 Mdot
.666 .37466 Mdot
.666 .37484 Mdot
.666 .3749 Mdot
.666 .37492 Mdot
.666 .375 Mdot
.666 .37503 Mdot
.666 .37511 Mdot
.666 .3755 Mdot
.666 .37555 Mdot
.666 .37562 Mdot
.666 .37565 Mdot
.666 .37572 Mdot
.666 .3759 Mdot
.666 .37613 Mdot
.666 .37614 Mdot
.666 .3763 Mdot
.666 .37632 Mdot
.666 .37633 Mdot
.666 .37637 Mdot
.666 .37639 Mdot
.666 .37648 Mdot
.666 .37653 Mdot
.666 .3767 Mdot
.666 .37671 Mdot
.666 .37687 Mdot
.666 .37697 Mdot
.666 .377 Mdot
.666 .37701 Mdot
.666 .37703 Mdot
.666 .37721 Mdot
.666 .37738 Mdot
.666 .37742 Mdot
.666 .37752 Mdot
.666 .37761 Mdot
.666 .37769 Mdot
.666 .37779 Mdot
.666 .37791 Mdot
.666 .37794 Mdot
.666 .37795 Mdot
.666 .3783 Mdot
.666 .37836 Mdot
.666 .37838 Mdot
.666 .37847 Mdot
.666 .37859 Mdot
.666 .37889 Mdot
.666 .3789 Mdot
.666 .37919 Mdot
.666 .3792 Mdot
.666 .37928 Mdot
.666 .37929 Mdot
.666 .37936 Mdot
.666 .37954 Mdot
.666 .37963 Mdot
.666 .37982 Mdot
.666 .37985 Mdot
.666 .37988 Mdot
.666 .38016 Mdot
.666 .38019 Mdot
.666 .38039 Mdot
.666 .38041 Mdot
.666 .38048 Mdot
.666 .38053 Mdot
.666 .38058 Mdot
.666 .38079 Mdot
.666 .38083 Mdot
.666 .38089 Mdot
.666 .38091 Mdot
.666 .38092 Mdot
.666 .38094 Mdot
.666 .38103 Mdot
.666 .38103 Mdot
.666 .38112 Mdot
.666 .38137 Mdot
.666 .38138 Mdot
.666 .38138 Mdot
.666 .38138 Mdot
.666 .3814 Mdot
.666 .38142 Mdot
.666 .38165 Mdot
.666 .38173 Mdot
.666 .38175 Mdot
.666 .38187 Mdot
.666 .38198 Mdot
.666 .382 Mdot
.666 .38206 Mdot
.666 .38209 Mdot
.666 .38228 Mdot
.666 .38231 Mdot
.666 .38242 Mdot
.666 .38244 Mdot
.666 .38259 Mdot
.666 .3827 Mdot
.666 .38282 Mdot
.666 .38286 Mdot
.666 .38293 Mdot
.666 .38296 Mdot
.666 .38297 Mdot
.666 .38321 Mdot
.666 .38324 Mdot
.666 .38363 Mdot
.666 .38381 Mdot
.666 .38383 Mdot
.666 .38388 Mdot
.666 .38391 Mdot
.666 .38398 Mdot
.666 .38415 Mdot
.666 .38425 Mdot
.666 .38431 Mdot
.666 .38436 Mdot
.666 .38437 Mdot
.666 .38439 Mdot
.666 .38442 Mdot
.666 .38444 Mdot
.666 .38452 Mdot
.666 .38452 Mdot
.666 .38453 Mdot
.666 .38481 Mdot
.666 .38481 Mdot
.666 .38485 Mdot
.666 .38509 Mdot
.666 .38509 Mdot
.666 .38523 Mdot
.666 .38529 Mdot
.666 .38534 Mdot
.666 .38535 Mdot
.666 .38537 Mdot
.666 .38554 Mdot
.666 .38565 Mdot
.666 .38581 Mdot
.666 .38582 Mdot
.666 .38588 Mdot
.666 .38591 Mdot
.666 .386 Mdot
.666 .38602 Mdot
.666 .38603 Mdot
.666 .38605 Mdot
.666 .38611 Mdot
.666 .38612 Mdot
.666 .38625 Mdot
.666 .38633 Mdot
.666 .38634 Mdot
.666 .38646 Mdot
.666 .38651 Mdot
.666 .38658 Mdot
.666 .38661 Mdot
.666 .38665 Mdot
.666 .38682 Mdot
.666 .38697 Mdot
.666 .38702 Mdot
.666 .38703 Mdot
.666 .38706 Mdot
.666 .3871 Mdot
.666 .38721 Mdot
.666 .38726 Mdot
.666 .38731 Mdot
.666 .38737 Mdot
.666 .38747 Mdot
.666 .38766 Mdot
.666 .38769 Mdot
.666 .38785 Mdot
.666 .38795 Mdot
.666 .38815 Mdot
.666 .38825 Mdot
.666 .38833 Mdot
.666 .38845 Mdot
.666 .38856 Mdot
.666 .38864 Mdot
.666 .38864 Mdot
.666 .38879 Mdot
.666 .38884 Mdot
.666 .38886 Mdot
.666 .38887 Mdot
.666 .38897 Mdot
.666 .3891 Mdot
.666 .38913 Mdot
.666 .38935 Mdot
.666 .38942 Mdot
.666 .38961 Mdot
.666 .38964 Mdot
.666 .38973 Mdot
.666 .38982 Mdot
.666 .38982 Mdot
.666 .38986 Mdot
.666 .38988 Mdot
.666 .3899 Mdot
.666 .39012 Mdot
.666 .39019 Mdot
.666 .39025 Mdot
.666 .39027 Mdot
.666 .39029 Mdot
.666 .39044 Mdot
.666 .39049 Mdot
.666 .39051 Mdot
.666 .39052 Mdot
.666 .3907 Mdot
.666 .39085 Mdot
.666 .39099 Mdot
.666 .39101 Mdot
.666 .39102 Mdot
.666 .39117 Mdot
.666 .39126 Mdot
.666 .39147 Mdot
.666 .39153 Mdot
.666 .39154 Mdot
.666 .39165 Mdot
.666 .39169 Mdot
.666 .3922 Mdot
.666 .39245 Mdot
.666 .3926 Mdot
.666 .39268 Mdot
.666 .39277 Mdot
.666 .39286 Mdot
.666 .39287 Mdot
.666 .39288 Mdot
.666 .39291 Mdot
.666 .39299 Mdot
.666 .39305 Mdot
.666 .39309 Mdot
.666 .39323 Mdot
.666 .39336 Mdot
.666 .39352 Mdot
.666 .3938 Mdot
.666 .3938 Mdot
.666 .39384 Mdot
.666 .39392 Mdot
.666 .39403 Mdot
.666 .3941 Mdot
.666 .39414 Mdot
.666 .3942 Mdot
.666 .39431 Mdot
.666 .39437 Mdot
.666 .39464 Mdot
.666 .39467 Mdot
.666 .3947 Mdot
.666 .39473 Mdot
.666 .39483 Mdot
.666 .39505 Mdot
.666 .39507 Mdot
.666 .39509 Mdot
.666 .39513 Mdot
.666 .39515 Mdot
.666 .39527 Mdot
.666 .39535 Mdot
.666 .39538 Mdot
.666 .39539 Mdot
.666 .3954 Mdot
.666 .39548 Mdot
.666 .39552 Mdot
.666 .39567 Mdot
.666 .39577 Mdot
.666 .39578 Mdot
.666 .39581 Mdot
.666 .39584 Mdot
.666 .39593 Mdot
.666 .39593 Mdot
.666 .39606 Mdot
.666 .39608 Mdot
.666 .39608 Mdot
.666 .39624 Mdot
.666 .39629 Mdot
.666 .39636 Mdot
.666 .39655 Mdot
.666 .39659 Mdot
.666 .39661 Mdot
.666 .39663 Mdot
.666 .39664 Mdot
.666 .39675 Mdot
.666 .39697 Mdot
.666 .39714 Mdot
.666 .3972 Mdot
.666 .39727 Mdot
.666 .39733 Mdot
.666 .39743 Mdot
.666 .39751 Mdot
.666 .39761 Mdot
.666 .39763 Mdot
.666 .39767 Mdot
.666 .39768 Mdot
.666 .39774 Mdot
.666 .39782 Mdot
.666 .39799 Mdot
.666 .39802 Mdot
.666 .39802 Mdot
.666 .39816 Mdot
.666 .39821 Mdot
.666 .39826 Mdot
.666 .39828 Mdot
.666 .39835 Mdot
.666 .39857 Mdot
.666 .3987 Mdot
.666 .39888 Mdot
.666 .39889 Mdot
.666 .399 Mdot
.666 .39905 Mdot
.666 .3992 Mdot
.666 .39924 Mdot
.666 .39941 Mdot
.666 .39942 Mdot
.666 .3997 Mdot
.666 .39975 Mdot
.666 .39995 Mdot
.666 .39997 Mdot
.666 .40009 Mdot
.666 .40027 Mdot
.666 .40037 Mdot
.666 .40047 Mdot
.666 .40049 Mdot
.666 .4005 Mdot
.666 .40056 Mdot
.666 .40065 Mdot
.666 .40065 Mdot
.666 .40075 Mdot
.666 .40078 Mdot
.666 .40083 Mdot
.666 .40086 Mdot
.666 .40088 Mdot
.666 .40098 Mdot
.666 .40111 Mdot
.666 .40125 Mdot
.666 .40126 Mdot
.666 .40155 Mdot
.666 .4016 Mdot
.666 .40161 Mdot
.666 .40165 Mdot
.666 .40167 Mdot
.666 .4017 Mdot
.666 .4018 Mdot
.666 .40188 Mdot
.666 .40209 Mdot
.666 .40211 Mdot
.666 .40221 Mdot
.666 .40226 Mdot
.666 .40226 Mdot
.666 .40249 Mdot
.666 .4025 Mdot
.666 .40261 Mdot
.666 .40262 Mdot
.666 .40264 Mdot
.666 .40264 Mdot
.666 .40267 Mdot
.666 .4027 Mdot
.666 .40276 Mdot
.666 .40285 Mdot
.666 .40287 Mdot
.666 .40291 Mdot
.666 .40295 Mdot
.666 .40301 Mdot
.666 .40304 Mdot
.666 .40331 Mdot
.666 .40332 Mdot
.666 .40338 Mdot
.666 .4035 Mdot
.666 .40351 Mdot
.666 .40352 Mdot
.666 .40354 Mdot
.666 .40359 Mdot
.666 .40374 Mdot
.666 .40374 Mdot
.666 .40381 Mdot
.666 .40385 Mdot
.666 .40388 Mdot
.666 .40391 Mdot
.666 .40396 Mdot
.666 .40406 Mdot
.666 .40432 Mdot
.666 .40432 Mdot
.666 .40435 Mdot
.666 .40436 Mdot
.666 .40437 Mdot
.666 .40437 Mdot
.666 .4044 Mdot
.666 .40444 Mdot
.666 .40474 Mdot
.666 .40481 Mdot
.666 .40482 Mdot
.666 .40485 Mdot
.666 .40498 Mdot
.666 .40502 Mdot
.666 .40523 Mdot
.666 .40531 Mdot
.666 .40532 Mdot
.666 .40532 Mdot
.666 .40543 Mdot
.666 .40546 Mdot
.666 .40547 Mdot
.666 .40549 Mdot
.666 .40557 Mdot
.666 .40559 Mdot
.666 .4056 Mdot
.666 .40563 Mdot
.666 .40569 Mdot
.666 .40579 Mdot
.666 .40596 Mdot
.666 .40598 Mdot
.666 .40601 Mdot
.666 .4062 Mdot
.666 .40624 Mdot
.666 .40628 Mdot
.666 .40641 Mdot
.666 .40646 Mdot
.666 .40651 Mdot
.666 .40655 Mdot
.666 .40658 Mdot
.666 .40671 Mdot
.666 .40691 Mdot
.666 .40693 Mdot
.666 .40698 Mdot
.666 .40712 Mdot
.666 .40717 Mdot
.666 .40719 Mdot
.666 .40759 Mdot
.666 .40761 Mdot
.668 .2765 Mdot
.668 .27652 Mdot
.668 .2767 Mdot
.668 .27671 Mdot
.668 .27672 Mdot
.668 .27683 Mdot
.668 .27685 Mdot
.668 .27724 Mdot
.668 .27744 Mdot
.668 .27753 Mdot
.668 .2776 Mdot
.668 .27781 Mdot
.668 .27819 Mdot
.668 .27831 Mdot
.668 .27839 Mdot
.668 .27842 Mdot
.668 .27849 Mdot
.668 .27875 Mdot
.668 .27877 Mdot
.668 .27881 Mdot
.668 .27891 Mdot
.668 .27895 Mdot
.668 .27896 Mdot
.668 .27898 Mdot
.668 .27911 Mdot
.668 .27923 Mdot
.668 .27968 Mdot
.668 .27968 Mdot
.668 .2798 Mdot
.668 .27981 Mdot
.668 .27989 Mdot
.668 .28011 Mdot
.668 .28013 Mdot
.668 .28024 Mdot
.668 .28025 Mdot
.668 .28027 Mdot
.668 .28037 Mdot
.668 .28066 Mdot
.668 .28078 Mdot
.668 .28083 Mdot
.668 .2812 Mdot
.668 .28156 Mdot
.668 .28157 Mdot
.668 .28159 Mdot
.668 .28169 Mdot
.668 .28189 Mdot
.668 .28195 Mdot
.668 .28197 Mdot
.668 .28204 Mdot
.668 .28211 Mdot
.668 .28224 Mdot
.668 .28236 Mdot
.668 .28255 Mdot
.668 .28262 Mdot
.668 .28268 Mdot
.668 .28283 Mdot
.668 .283 Mdot
.668 .28302 Mdot
.668 .28319 Mdot
.668 .28328 Mdot
.668 .2834 Mdot
.668 .28376 Mdot
.668 .28379 Mdot
.668 .28381 Mdot
.668 .28385 Mdot
.668 .28396 Mdot
.668 .28408 Mdot
.668 .28418 Mdot
.668 .28429 Mdot
.668 .2844 Mdot
.668 .28449 Mdot
.668 .28465 Mdot
.668 .28479 Mdot
.668 .285 Mdot
.668 .28503 Mdot
.668 .28504 Mdot
.668 .28506 Mdot
.668 .28508 Mdot
.668 .28512 Mdot
.668 .28516 Mdot
.668 .28537 Mdot
.668 .28551 Mdot
.668 .28552 Mdot
.668 .28565 Mdot
.668 .2857 Mdot
.668 .28576 Mdot
.668 .28579 Mdot
.668 .28587 Mdot
.668 .28592 Mdot
.668 .2862 Mdot
.668 .28621 Mdot
.668 .28647 Mdot
.668 .28647 Mdot
.668 .28654 Mdot
.668 .28669 Mdot
.668 .28677 Mdot
.668 .28678 Mdot
.668 .28678 Mdot
.668 .28681 Mdot
.668 .28682 Mdot
.668 .287 Mdot
.668 .28706 Mdot
.668 .28718 Mdot
.668 .28729 Mdot
.668 .28747 Mdot
.668 .28756 Mdot
.668 .28769 Mdot
.668 .28777 Mdot
.668 .28778 Mdot
.668 .28778 Mdot
.668 .28796 Mdot
.668 .28818 Mdot
.668 .28822 Mdot
.668 .28832 Mdot
.668 .28833 Mdot
.668 .28833 Mdot
.668 .28834 Mdot
.668 .2887 Mdot
.668 .28872 Mdot
.668 .28884 Mdot
.668 .28891 Mdot
.668 .28908 Mdot
.668 .28917 Mdot
.668 .28927 Mdot
.668 .28931 Mdot
.668 .28941 Mdot
.668 .28953 Mdot
.668 .28982 Mdot
.668 .28983 Mdot
.668 .28987 Mdot
.668 .28997 Mdot
.668 .28997 Mdot
.668 .29001 Mdot
.668 .29001 Mdot
.668 .29015 Mdot
.668 .29023 Mdot
.668 .29024 Mdot
.668 .29025 Mdot
.668 .29029 Mdot
.668 .2904 Mdot
.668 .29071 Mdot
.668 .29077 Mdot
.668 .29094 Mdot
.668 .29094 Mdot
.668 .29094 Mdot
.668 .291 Mdot
.668 .29107 Mdot
.668 .29118 Mdot
.668 .2917 Mdot
.668 .29178 Mdot
.668 .2918 Mdot
.668 .2922 Mdot
.668 .29238 Mdot
.668 .2927 Mdot
.668 .29287 Mdot
.668 .29297 Mdot
.668 .29306 Mdot
.668 .29311 Mdot
.668 .29312 Mdot
.668 .2932 Mdot
.668 .29335 Mdot
.668 .29341 Mdot
.668 .29355 Mdot
.668 .29358 Mdot
.668 .29378 Mdot
.668 .29379 Mdot
.668 .29398 Mdot
.668 .29401 Mdot
.668 .29412 Mdot
.668 .29422 Mdot
.668 .29429 Mdot
.668 .29437 Mdot
.668 .29442 Mdot
.668 .29446 Mdot
.668 .29458 Mdot
.668 .29461 Mdot
.668 .29461 Mdot
.668 .29474 Mdot
.668 .29475 Mdot
.668 .29479 Mdot
.668 .29495 Mdot
.668 .29512 Mdot
.668 .29516 Mdot
.668 .29525 Mdot
.668 .29538 Mdot
.668 .2954 Mdot
.668 .29544 Mdot
.668 .29552 Mdot
.668 .29555 Mdot
.668 .2956 Mdot
.668 .29562 Mdot
.668 .29565 Mdot
.668 .29624 Mdot
.668 .29627 Mdot
.668 .29629 Mdot
.668 .29643 Mdot
.668 .2965 Mdot
.668 .2966 Mdot
.668 .29664 Mdot
.668 .29676 Mdot
.668 .2968 Mdot
.668 .29681 Mdot
.668 .29693 Mdot
.668 .29707 Mdot
.668 .29727 Mdot
.668 .29738 Mdot
.668 .29744 Mdot
.668 .29748 Mdot
.668 .29753 Mdot
.668 .29763 Mdot
.668 .29765 Mdot
.668 .2977 Mdot
.668 .29773 Mdot
.668 .29774 Mdot
.668 .29776 Mdot
.668 .2978 Mdot
.668 .29788 Mdot
.668 .2979 Mdot
.668 .29794 Mdot
.668 .29811 Mdot
.668 .29819 Mdot
.668 .29826 Mdot
.668 .29827 Mdot
.668 .29836 Mdot
.668 .29837 Mdot
.668 .29843 Mdot
.668 .29847 Mdot
.668 .29856 Mdot
.668 .29858 Mdot
.668 .29892 Mdot
.668 .29893 Mdot
.668 .29918 Mdot
.668 .2993 Mdot
.668 .29939 Mdot
.668 .29941 Mdot
.668 .29942 Mdot
.668 .29949 Mdot
.668 .29949 Mdot
.668 .2995 Mdot
.668 .2996 Mdot
.668 .29963 Mdot
.668 .29971 Mdot
.668 .29977 Mdot
.668 .29995 Mdot
.668 .30007 Mdot
.668 .30033 Mdot
.668 .30036 Mdot
.668 .30041 Mdot
.668 .30074 Mdot
.668 .30112 Mdot
.668 .30141 Mdot
.668 .30147 Mdot
.668 .30151 Mdot
.668 .30155 Mdot
.668 .30164 Mdot
.668 .30185 Mdot
.668 .30191 Mdot
.668 .30193 Mdot
.668 .30194 Mdot
.668 .30199 Mdot
.668 .30217 Mdot
.668 .30234 Mdot
.668 .30241 Mdot
.668 .30254 Mdot
.668 .30272 Mdot
.668 .303 Mdot
.668 .30302 Mdot
.668 .30307 Mdot
.668 .30309 Mdot
.668 .30322 Mdot
.668 .30332 Mdot
.668 .30333 Mdot
.668 .30337 Mdot
.668 .30344 Mdot
.668 .30359 Mdot
.668 .30366 Mdot
.668 .30376 Mdot
.668 .30389 Mdot
.668 .30401 Mdot
.668 .30405 Mdot
.668 .3042 Mdot
.668 .30439 Mdot
.668 .30443 Mdot
.668 .30445 Mdot
.668 .30479 Mdot
.668 .30481 Mdot
.668 .30483 Mdot
.668 .30507 Mdot
.668 .30516 Mdot
.668 .30521 Mdot
.668 .30527 Mdot
.668 .30534 Mdot
.668 .30546 Mdot
.668 .30554 Mdot
.668 .30557 Mdot
.668 .30584 Mdot
.668 .30598 Mdot
.668 .30599 Mdot
.668 .30609 Mdot
.668 .30617 Mdot
.668 .30625 Mdot
.668 .30642 Mdot
.668 .30649 Mdot
.668 .30657 Mdot
.668 .30658 Mdot
.668 .30673 Mdot
.668 .30731 Mdot
.668 .30762 Mdot
.668 .30774 Mdot
.668 .30834 Mdot
.668 .30837 Mdot
.668 .30852 Mdot
.668 .30891 Mdot
.668 .30906 Mdot
.668 .30944 Mdot
.668 .30945 Mdot
.668 .30964 Mdot
.668 .30977 Mdot
.668 .30987 Mdot
.668 .30987 Mdot
.668 .30988 Mdot
.668 .31017 Mdot
.668 .31028 Mdot
.668 .31037 Mdot
.668 .3107 Mdot
.668 .31077 Mdot
.668 .31081 Mdot
.668 .31083 Mdot
.668 .31103 Mdot
.668 .31111 Mdot
.668 .31113 Mdot
.668 .31113 Mdot
.668 .31115 Mdot
.668 .31122 Mdot
.668 .31129 Mdot
.668 .31153 Mdot
.668 .31154 Mdot
.668 .31161 Mdot
.668 .31161 Mdot
.668 .31179 Mdot
.668 .31185 Mdot
.668 .31186 Mdot
.668 .31187 Mdot
.668 .31193 Mdot
.668 .31216 Mdot
.668 .31218 Mdot
.668 .31239 Mdot
.668 .31259 Mdot
.668 .31259 Mdot
.668 .31261 Mdot
.668 .31278 Mdot
.668 .31286 Mdot
.668 .31304 Mdot
.668 .31318 Mdot
.668 .3135 Mdot
.668 .31362 Mdot
.668 .31384 Mdot
.668 .31387 Mdot
.668 .314 Mdot
.668 .3144 Mdot
.668 .31452 Mdot
.668 .31453 Mdot
.668 .31454 Mdot
.668 .31455 Mdot
.668 .31472 Mdot
.668 .3148 Mdot
.668 .31481 Mdot
.668 .31488 Mdot
.668 .31491 Mdot
.668 .31503 Mdot
.668 .31519 Mdot
.668 .31534 Mdot
.668 .31547 Mdot
.668 .31551 Mdot
.668 .31551 Mdot
.668 .31553 Mdot
.668 .31554 Mdot
.668 .31567 Mdot
.668 .3159 Mdot
.668 .31607 Mdot
.668 .31638 Mdot
.668 .31638 Mdot
.668 .31659 Mdot
.668 .3166 Mdot
.668 .31671 Mdot
.668 .31681 Mdot
.668 .31691 Mdot
.668 .31693 Mdot
.668 .31722 Mdot
.668 .31724 Mdot
.668 .3173 Mdot
.668 .3173 Mdot
.668 .31732 Mdot
.668 .31732 Mdot
.668 .31745 Mdot
.668 .31772 Mdot
.668 .31785 Mdot
.668 .31785 Mdot
.668 .31832 Mdot
.668 .31833 Mdot
.668 .31855 Mdot
.668 .31883 Mdot
.668 .31893 Mdot
.668 .31906 Mdot
.668 .31911 Mdot
.668 .3192 Mdot
.668 .31923 Mdot
.668 .31931 Mdot
.668 .31944 Mdot
.668 .31955 Mdot
.668 .31957 Mdot
.668 .31972 Mdot
.668 .31982 Mdot
.668 .32019 Mdot
.668 .32026 Mdot
.668 .32034 Mdot
.668 .32035 Mdot
.668 .32036 Mdot
.668 .32041 Mdot
.668 .32043 Mdot
.668 .32048 Mdot
.668 .32084 Mdot
.668 .3211 Mdot
.668 .32139 Mdot
.668 .32154 Mdot
.668 .3216 Mdot
.668 .32166 Mdot
.668 .32173 Mdot
.668 .32195 Mdot
.668 .322 Mdot
.668 .32204 Mdot
.668 .32206 Mdot
.668 .32212 Mdot
.668 .32232 Mdot
.668 .32253 Mdot
.668 .32259 Mdot
.668 .32264 Mdot
.668 .32264 Mdot
.668 .3227 Mdot
.668 .32271 Mdot
.668 .32334 Mdot
.668 .32355 Mdot
.668 .32371 Mdot
.668 .32401 Mdot
.668 .32404 Mdot
.668 .32435 Mdot
.668 .32461 Mdot
.668 .32472 Mdot
.668 .32485 Mdot
.668 .32519 Mdot
.668 .3254 Mdot
.668 .32563 Mdot
.668 .32576 Mdot
.668 .32587 Mdot
.668 .32591 Mdot
.668 .32603 Mdot
.668 .32638 Mdot
.668 .32656 Mdot
.668 .3266 Mdot
.668 .32661 Mdot
.668 .32726 Mdot
.668 .32791 Mdot
.668 .328 Mdot
.668 .32822 Mdot
.668 .32873 Mdot
.668 .32892 Mdot
.668 .32896 Mdot
.668 .32898 Mdot
.668 .32917 Mdot
.668 .32921 Mdot
.668 .3296 Mdot
.668 .32973 Mdot
.668 .32975 Mdot
.668 .32998 Mdot
.668 .32998 Mdot
.668 .33077 Mdot
.668 .33099 Mdot
.668 .33122 Mdot
.668 .33126 Mdot
.668 .33127 Mdot
.668 .33134 Mdot
.668 .33152 Mdot
.668 .33159 Mdot
.668 .33162 Mdot
.668 .3321 Mdot
.668 .33222 Mdot
.668 .33228 Mdot
.668 .33241 Mdot
.668 .33263 Mdot
.668 .33332 Mdot
.668 .33368 Mdot
.668 .33381 Mdot
.668 .33397 Mdot
.668 .33432 Mdot
.668 .33502 Mdot
.668 .33506 Mdot
.668 .33525 Mdot
.668 .33527 Mdot
.668 .33528 Mdot
.668 .33561 Mdot
.668 .33565 Mdot
.668 .36446 Mdot
.668 .36449 Mdot
.668 .36473 Mdot
.668 .36474 Mdot
.668 .36476 Mdot
.668 .3649 Mdot
.668 .36493 Mdot
.668 .36545 Mdot
.668 .36571 Mdot
.668 .36583 Mdot
.668 .36593 Mdot
.668 .3662 Mdot
.668 .36672 Mdot
.668 .36688 Mdot
.668 .36698 Mdot
.668 .36702 Mdot
.668 .36711 Mdot
.668 .36747 Mdot
.668 .3675 Mdot
.668 .36755 Mdot
.668 .36768 Mdot
.668 .36773 Mdot
.668 .36774 Mdot
.668 .36777 Mdot
.668 .36794 Mdot
.668 .36811 Mdot
.668 .3687 Mdot
.668 .3687 Mdot
.668 .36887 Mdot
.668 .36889 Mdot
.668 .36898 Mdot
.668 .36928 Mdot
.668 .36931 Mdot
.668 .36945 Mdot
.668 .36947 Mdot
.668 .3695 Mdot
.668 .36963 Mdot
.668 .37002 Mdot
.668 .37018 Mdot
.668 .37025 Mdot
.668 .37074 Mdot
.668 .37122 Mdot
.668 .37123 Mdot
.668 .37126 Mdot
.668 .3714 Mdot
.668 .37166 Mdot
.668 .37175 Mdot
.668 .37177 Mdot
.668 .37186 Mdot
.668 .37196 Mdot
.668 .37213 Mdot
.668 .37229 Mdot
.668 .37254 Mdot
.668 .37264 Mdot
.668 .37272 Mdot
.668 .37292 Mdot
.668 .37315 Mdot
.668 .37317 Mdot
.668 .37339 Mdot
.668 .37351 Mdot
.668 .37367 Mdot
.668 .37414 Mdot
.668 .37415 Mdot
.668 .37419 Mdot
.668 .3742 Mdot
.668 .37423 Mdot
.668 .37428 Mdot
.668 .37443 Mdot
.668 .37459 Mdot
.668 .37463 Mdot
.668 .37464 Mdot
.668 .37467 Mdot
.668 .37472 Mdot
.668 .37487 Mdot
.668 .37493 Mdot
.668 .37497 Mdot
.668 .37502 Mdot
.668 .37513 Mdot
.668 .37534 Mdot
.668 .37554 Mdot
.668 .37581 Mdot
.668 .37585 Mdot
.668 .37586 Mdot
.668 .3759 Mdot
.668 .37591 Mdot
.668 .37592 Mdot
.668 .37597 Mdot
.668 .37603 Mdot
.668 .37631 Mdot
.668 .37638 Mdot
.668 .3765 Mdot
.668 .37651 Mdot
.668 .37659 Mdot
.668 .37669 Mdot
.668 .37675 Mdot
.668 .37677 Mdot
.668 .37684 Mdot
.668 .37687 Mdot
.668 .37697 Mdot
.668 .37704 Mdot
.668 .37725 Mdot
.668 .37742 Mdot
.668 .37743 Mdot
.668 .37778 Mdot
.668 .37778 Mdot
.668 .37788 Mdot
.668 .37808 Mdot
.668 .37817 Mdot
.668 .37817 Mdot
.668 .37819 Mdot
.668 .37819 Mdot
.668 .37823 Mdot
.668 .37825 Mdot
.668 .37847 Mdot
.668 .37848 Mdot
.668 .37856 Mdot
.668 .37864 Mdot
.668 .37872 Mdot
.668 .37872 Mdot
.668 .37888 Mdot
.668 .37888 Mdot
.668 .37911 Mdot
.668 .37924 Mdot
.668 .37941 Mdot
.668 .37951 Mdot
.668 .37952 Mdot
.668 .37953 Mdot
.668 .37953 Mdot
.668 .37956 Mdot
.668 .37966 Mdot
.668 .37977 Mdot
.668 .37989 Mdot
.668 .37998 Mdot
.668 .38 Mdot
.668 .38006 Mdot
.668 .38006 Mdot
.668 .38012 Mdot
.668 .38025 Mdot
.668 .38026 Mdot
.668 .38026 Mdot
.668 .38028 Mdot
.668 .38036 Mdot
.668 .38066 Mdot
.668 .38076 Mdot
.668 .38078 Mdot
.668 .38095 Mdot
.668 .38104 Mdot
.668 .38127 Mdot
.668 .38138 Mdot
.668 .38152 Mdot
.668 .38158 Mdot
.668 .3817 Mdot
.668 .38171 Mdot
.668 .38172 Mdot
.668 .38187 Mdot
.668 .38202 Mdot
.668 .38204 Mdot
.668 .38221 Mdot
.668 .38226 Mdot
.668 .38227 Mdot
.668 .38232 Mdot
.668 .38245 Mdot
.668 .38245 Mdot
.668 .38251 Mdot
.668 .38251 Mdot
.668 .38269 Mdot
.668 .38275 Mdot
.668 .3828 Mdot
.668 .38281 Mdot
.668 .38281 Mdot
.668 .38283 Mdot
.668 .38289 Mdot
.668 .38303 Mdot
.668 .38305 Mdot
.668 .38308 Mdot
.668 .38313 Mdot
.668 .38338 Mdot
.668 .38345 Mdot
.668 .38353 Mdot
.668 .38375 Mdot
.668 .38375 Mdot
.668 .38375 Mdot
.668 .38383 Mdot
.668 .38393 Mdot
.668 .38407 Mdot
.668 .38407 Mdot
.668 .38436 Mdot
.668 .38448 Mdot
.668 .38476 Mdot
.668 .38487 Mdot
.668 .3849 Mdot
.668 .38535 Mdot
.668 .38544 Mdot
.668 .38567 Mdot
.668 .3861 Mdot
.668 .38621 Mdot
.668 .38622 Mdot
.668 .38628 Mdot
.668 .38633 Mdot
.668 .38646 Mdot
.668 .38652 Mdot
.668 .38658 Mdot
.668 .38666 Mdot
.668 .38666 Mdot
.668 .38677 Mdot
.668 .38697 Mdot
.668 .38699 Mdot
.668 .38706 Mdot
.668 .38715 Mdot
.668 .3872 Mdot
.668 .38724 Mdot
.668 .38728 Mdot
.668 .38734 Mdot
.668 .38752 Mdot
.668 .38754 Mdot
.668 .38756 Mdot
.668 .38781 Mdot
.668 .38782 Mdot
.668 .38786 Mdot
.668 .388 Mdot
.668 .38811 Mdot
.668 .38814 Mdot
.668 .38823 Mdot
.668 .38833 Mdot
.668 .3884 Mdot
.668 .38845 Mdot
.668 .38857 Mdot
.668 .38862 Mdot
.668 .38865 Mdot
.668 .38866 Mdot
.668 .38873 Mdot
.668 .38882 Mdot
.668 .38884 Mdot
.668 .38888 Mdot
.668 .38889 Mdot
.668 .3891 Mdot
.668 .38924 Mdot
.668 .38934 Mdot
.668 .38939 Mdot
.668 .38951 Mdot
.668 .38965 Mdot
.668 .38969 Mdot
.668 .38969 Mdot
.668 .38971 Mdot
.668 .38976 Mdot
.668 .38991 Mdot
.668 .38998 Mdot
.668 .39001 Mdot
.668 .39004 Mdot
.668 .39008 Mdot
.668 .3903 Mdot
.668 .39059 Mdot
.668 .39083 Mdot
.668 .39087 Mdot
.668 .3909 Mdot
.668 .39109 Mdot
.668 .39118 Mdot
.668 .39132 Mdot
.668 .39136 Mdot
.668 .39142 Mdot
.668 .39144 Mdot
.668 .39151 Mdot
.668 .39152 Mdot
.668 .39152 Mdot
.668 .39158 Mdot
.668 .39158 Mdot
.668 .3916 Mdot
.668 .39166 Mdot
.668 .39175 Mdot
.668 .39194 Mdot
.668 .39195 Mdot
.668 .39221 Mdot
.668 .39222 Mdot
.668 .39229 Mdot
.668 .39231 Mdot
.668 .39236 Mdot
.668 .39237 Mdot
.668 .39244 Mdot
.668 .39245 Mdot
.668 .39249 Mdot
.668 .39256 Mdot
.668 .39268 Mdot
.668 .39271 Mdot
.668 .39273 Mdot
.668 .39279 Mdot
.668 .39282 Mdot
.668 .39283 Mdot
.668 .39284 Mdot
.668 .39286 Mdot
.668 .3929 Mdot
.668 .39292 Mdot
.668 .39299 Mdot
.668 .39302 Mdot
.668 .39306 Mdot
.668 .3931 Mdot
.668 .39319 Mdot
.668 .39333 Mdot
.668 .39344 Mdot
.668 .39353 Mdot
.668 .39354 Mdot
.668 .39357 Mdot
.668 .39366 Mdot
.668 .39368 Mdot
.668 .39376 Mdot
.668 .39381 Mdot
.668 .39392 Mdot
.668 .39393 Mdot
.668 .39395 Mdot
.668 .3944 Mdot
.668 .39442 Mdot
.668 .39443 Mdot
.668 .39447 Mdot
.668 .3945 Mdot
.668 .39456 Mdot
.668 .39458 Mdot
.668 .3946 Mdot
.668 .39469 Mdot
.668 .39476 Mdot
.668 .39479 Mdot
.668 .39492 Mdot
.668 .39504 Mdot
.668 .39507 Mdot
.668 .39508 Mdot
.668 .39517 Mdot
.668 .39518 Mdot
.668 .39519 Mdot
.668 .39529 Mdot
.668 .39532 Mdot
.668 .39536 Mdot
.668 .39541 Mdot
.668 .39546 Mdot
.668 .39554 Mdot
.668 .39562 Mdot
.668 .39565 Mdot
.668 .39579 Mdot
.668 .3958 Mdot
.668 .39595 Mdot
.668 .39597 Mdot
.668 .39607 Mdot
.668 .39612 Mdot
.668 .39623 Mdot
.668 .39629 Mdot
.668 .3963 Mdot
.668 .39634 Mdot
.668 .3964 Mdot
.668 .39648 Mdot
.668 .3966 Mdot
.668 .39685 Mdot
.668 .39698 Mdot
.668 .39728 Mdot
.668 .39729 Mdot
.668 .39736 Mdot
.668 .39774 Mdot
.668 .39782 Mdot
.668 .39788 Mdot
.668 .39792 Mdot
.668 .39792 Mdot
.668 .39793 Mdot
.668 .39805 Mdot
.668 .39809 Mdot
.668 .39832 Mdot
.668 .39841 Mdot
.668 .39844 Mdot
.668 .39845 Mdot
.668 .39845 Mdot
.668 .39852 Mdot
.668 .39862 Mdot
.668 .39862 Mdot
.668 .39865 Mdot
.668 .39865 Mdot
.668 .39873 Mdot
.668 .39875 Mdot
.668 .39876 Mdot
.668 .39898 Mdot
.668 .39907 Mdot
.668 .39914 Mdot
.668 .39917 Mdot
.668 .39925 Mdot
.668 .39931 Mdot
.668 .39944 Mdot
.668 .39949 Mdot
.668 .39959 Mdot
.668 .3996 Mdot
.668 .39987 Mdot
.668 .39988 Mdot
.668 .39988 Mdot
.668 .39989 Mdot
.668 .39996 Mdot
.668 .39999 Mdot
.668 .40015 Mdot
.668 .40029 Mdot
.668 .40029 Mdot
.668 .4003 Mdot
.668 .40035 Mdot
.668 .40045 Mdot
.668 .40052 Mdot
.668 .40065 Mdot
.668 .40074 Mdot
.668 .40083 Mdot
.668 .40087 Mdot
.668 .40101 Mdot
.668 .40101 Mdot
.668 .40104 Mdot
.668 .40104 Mdot
.668 .40105 Mdot
.668 .4011 Mdot
.668 .40121 Mdot
.668 .40127 Mdot
.668 .40127 Mdot
.668 .40146 Mdot
.668 .40147 Mdot
.668 .40168 Mdot
.668 .40172 Mdot
.668 .40178 Mdot
.668 .4018 Mdot
.668 .40185 Mdot
.668 .40188 Mdot
.668 .40198 Mdot
.668 .40199 Mdot
.668 .40209 Mdot
.668 .40225 Mdot
.668 .40228 Mdot
.668 .40231 Mdot
.668 .40232 Mdot
.668 .40234 Mdot
.668 .40235 Mdot
.668 .40237 Mdot
.668 .40252 Mdot
.668 .40263 Mdot
.668 .40275 Mdot
.668 .40281 Mdot
.668 .4029 Mdot
.668 .40299 Mdot
.668 .40306 Mdot
.668 .40314 Mdot
.668 .40323 Mdot
.668 .40326 Mdot
.668 .40328 Mdot
.668 .4033 Mdot
.668 .40357 Mdot
.668 .40366 Mdot
.668 .40373 Mdot
.668 .40385 Mdot
.668 .40386 Mdot
.668 .40399 Mdot
.668 .4041 Mdot
.668 .40415 Mdot
.668 .4042 Mdot
.668 .40435 Mdot
.668 .40444 Mdot
.668 .40453 Mdot
.668 .40459 Mdot
.668 .40463 Mdot
.668 .40465 Mdot
.668 .4047 Mdot
.668 .40485 Mdot
.668 .40492 Mdot
.668 .40494 Mdot
.668 .40494 Mdot
.668 .40521 Mdot
.668 .40549 Mdot
.668 .40552 Mdot
.668 .40562 Mdot
.668 .40583 Mdot
.668 .40591 Mdot
.668 .40593 Mdot
.668 .40594 Mdot
.668 .40601 Mdot
.668 .40603 Mdot
.668 .4062 Mdot
.668 .40625 Mdot
.668 .40626 Mdot
.668 .40635 Mdot
.668 .40635 Mdot
.668 .40668 Mdot
.668 .40678 Mdot
.668 .40687 Mdot
.668 .40689 Mdot
.668 .4069 Mdot
.668 .40693 Mdot
.668 .407 Mdot
.668 .40703 Mdot
.668 .40704 Mdot
.668 .40724 Mdot
.668 .4073 Mdot
.668 .40732 Mdot
.668 .40737 Mdot
.668 .40747 Mdot
.668 .40775 Mdot
.668 .4079 Mdot
.668 .40796 Mdot
.668 .40803 Mdot
.668 .40817 Mdot
.668 .40847 Mdot
.668 .40848 Mdot
.668 .40856 Mdot
.668 .40857 Mdot
.668 .40858 Mdot
.668 .40872 Mdot
.668 .40873 Mdot
.67 .27563 Mdot
.67 .27566 Mdot
.67 .27587 Mdot
.67 .27589 Mdot
.67 .27593 Mdot
.67 .27595 Mdot
.67 .27608 Mdot
.67 .27613 Mdot
.67 .27624 Mdot
.67 .27648 Mdot
.67 .27649 Mdot
.67 .2766 Mdot
.67 .27666 Mdot
.67 .27668 Mdot
.67 .27689 Mdot
.67 .27711 Mdot
.67 .27717 Mdot
.67 .27721 Mdot
.67 .2774 Mdot
.67 .27741 Mdot
.67 .27745 Mdot
.67 .27752 Mdot
.67 .27753 Mdot
.67 .27763 Mdot
.67 .27769 Mdot
.67 .27772 Mdot
.67 .27783 Mdot
.67 .27789 Mdot
.67 .27808 Mdot
.67 .27831 Mdot
.67 .27836 Mdot
.67 .27872 Mdot
.67 .2791 Mdot
.67 .27911 Mdot
.67 .27913 Mdot
.67 .27919 Mdot
.67 .27921 Mdot
.67 .27924 Mdot
.67 .27934 Mdot
.67 .27938 Mdot
.67 .27941 Mdot
.67 .2797 Mdot
.67 .27978 Mdot
.67 .27982 Mdot
.67 .27994 Mdot
.67 .28014 Mdot
.67 .28019 Mdot
.67 .28022 Mdot
.67 .28028 Mdot
.67 .28075 Mdot
.67 .28079 Mdot
.67 .28084 Mdot
.67 .28091 Mdot
.67 .28094 Mdot
.67 .28105 Mdot
.67 .28118 Mdot
.67 .28126 Mdot
.67 .28129 Mdot
.67 .28136 Mdot
.67 .28138 Mdot
.67 .28146 Mdot
.67 .28152 Mdot
.67 .28155 Mdot
.67 .28166 Mdot
.67 .28169 Mdot
.67 .2817 Mdot
.67 .2819 Mdot
.67 .28192 Mdot
.67 .28205 Mdot
.67 .28211 Mdot
.67 .28211 Mdot
.67 .28213 Mdot
.67 .28214 Mdot
.67 .28229 Mdot
.67 .28244 Mdot
.67 .28246 Mdot
.67 .28255 Mdot
.67 .2827 Mdot
.67 .28282 Mdot
.67 .28331 Mdot
.67 .28333 Mdot
.67 .28346 Mdot
.67 .28363 Mdot
.67 .28374 Mdot
.67 .28383 Mdot
.67 .28383 Mdot
.67 .28396 Mdot
.67 .28421 Mdot
.67 .28448 Mdot
.67 .28462 Mdot
.67 .28467 Mdot
.67 .28586 Mdot
.67 .28587 Mdot
.67 .28599 Mdot
.67 .28599 Mdot
.67 .28607 Mdot
.67 .28611 Mdot
.67 .28612 Mdot
.67 .28624 Mdot
.67 .28636 Mdot
.67 .28636 Mdot
.67 .28637 Mdot
.67 .28656 Mdot
.67 .28663 Mdot
.67 .28665 Mdot
.67 .28669 Mdot
.67 .28681 Mdot
.67 .28702 Mdot
.67 .28707 Mdot
.67 .28708 Mdot
.67 .28716 Mdot
.67 .28723 Mdot
.67 .28728 Mdot
.67 .28731 Mdot
.67 .28737 Mdot
.67 .28737 Mdot
.67 .28745 Mdot
.67 .28746 Mdot
.67 .28748 Mdot
.67 .28811 Mdot
.67 .28815 Mdot
.67 .28855 Mdot
.67 .28858 Mdot
.67 .28868 Mdot
.67 .28868 Mdot
.67 .28874 Mdot
.67 .28875 Mdot
.67 .28892 Mdot
.67 .28895 Mdot
.67 .28897 Mdot
.67 .28908 Mdot
.67 .2891 Mdot
.67 .2894 Mdot
.67 .28953 Mdot
.67 .28958 Mdot
.67 .28958 Mdot
.67 .28961 Mdot
.67 .28962 Mdot
.67 .28962 Mdot
.67 .28974 Mdot
.67 .29 Mdot
.67 .29006 Mdot
.67 .2901 Mdot
.67 .29011 Mdot
.67 .29014 Mdot
.67 .29037 Mdot
.67 .2904 Mdot
.67 .29043 Mdot
.67 .29051 Mdot
.67 .29055 Mdot
.67 .29062 Mdot
.67 .29069 Mdot
.67 .2908 Mdot
.67 .29081 Mdot
.67 .29111 Mdot
.67 .29117 Mdot
.67 .29119 Mdot
.67 .29121 Mdot
.67 .29128 Mdot
.67 .29136 Mdot
.67 .2914 Mdot
.67 .29155 Mdot
.67 .29156 Mdot
.67 .29214 Mdot
.67 .29247 Mdot
.67 .29252 Mdot
.67 .29259 Mdot
.67 .2926 Mdot
.67 .29271 Mdot
.67 .29273 Mdot
.67 .29283 Mdot
.67 .2931 Mdot
.67 .29315 Mdot
.67 .29338 Mdot
.67 .29401 Mdot
.67 .29404 Mdot
.67 .29413 Mdot
.67 .29436 Mdot
.67 .29436 Mdot
.67 .29438 Mdot
.67 .29476 Mdot
.67 .29478 Mdot
.67 .29489 Mdot
.67 .29499 Mdot
.67 .29504 Mdot
.67 .29521 Mdot
.67 .29522 Mdot
.67 .29557 Mdot
.67 .29565 Mdot
.67 .29566 Mdot
.67 .29584 Mdot
.67 .29596 Mdot
.67 .29598 Mdot
.67 .29605 Mdot
.67 .29643 Mdot
.67 .29652 Mdot
.67 .29653 Mdot
.67 .29665 Mdot
.67 .29672 Mdot
.67 .29699 Mdot
.67 .29702 Mdot
.67 .29703 Mdot
.67 .29735 Mdot
.67 .29776 Mdot
.67 .29777 Mdot
.67 .29778 Mdot
.67 .29804 Mdot
.67 .2981 Mdot
.67 .29835 Mdot
.67 .29836 Mdot
.67 .2984 Mdot
.67 .29842 Mdot
.67 .29877 Mdot
.67 .2989 Mdot
.67 .29895 Mdot
.67 .29901 Mdot
.67 .29902 Mdot
.67 .29924 Mdot
.67 .29925 Mdot
.67 .29938 Mdot
.67 .29942 Mdot
.67 .29944 Mdot
.67 .29979 Mdot
.67 .29992 Mdot
.67 .3001 Mdot
.67 .30017 Mdot
.67 .30023 Mdot
.67 .30023 Mdot
.67 .30027 Mdot
.67 .30048 Mdot
.67 .30081 Mdot
.67 .30081 Mdot
.67 .30096 Mdot
.67 .30102 Mdot
.67 .30139 Mdot
.67 .30147 Mdot
.67 .30159 Mdot
.67 .30161 Mdot
.67 .30162 Mdot
.67 .30189 Mdot
.67 .30191 Mdot
.67 .30201 Mdot
.67 .30218 Mdot
.67 .30219 Mdot
.67 .30226 Mdot
.67 .30237 Mdot
.67 .30241 Mdot
.67 .30273 Mdot
.67 .3031 Mdot
.67 .30314 Mdot
.67 .30314 Mdot
.67 .30322 Mdot
.67 .30326 Mdot
.67 .3033 Mdot
.67 .3033 Mdot
.67 .30352 Mdot
.67 .30355 Mdot
.67 .3037 Mdot
.67 .30377 Mdot
.67 .30391 Mdot
.67 .30398 Mdot
.67 .30464 Mdot
.67 .30467 Mdot
.67 .30475 Mdot
.67 .3049 Mdot
.67 .30511 Mdot
.67 .30523 Mdot
.67 .30532 Mdot
.67 .30539 Mdot
.67 .3054 Mdot
.67 .30567 Mdot
.67 .30574 Mdot
.67 .30589 Mdot
.67 .30597 Mdot
.67 .30605 Mdot
.67 .30606 Mdot
.67 .30611 Mdot
.67 .3063 Mdot
.67 .3063 Mdot
.67 .30632 Mdot
.67 .30643 Mdot
.67 .30653 Mdot
.67 .30672 Mdot
.67 .30709 Mdot
.67 .30712 Mdot
.67 .30717 Mdot
.67 .30741 Mdot
.67 .30757 Mdot
.67 .3077 Mdot
.67 .30816 Mdot
.67 .30818 Mdot
.67 .30845 Mdot
.67 .30851 Mdot
.67 .30866 Mdot
.67 .3088 Mdot
.67 .30882 Mdot
.67 .30886 Mdot
.67 .30898 Mdot
.67 .3092 Mdot
.67 .3094 Mdot
.67 .3095 Mdot
.67 .30951 Mdot
.67 .30954 Mdot
.67 .30968 Mdot
.67 .30973 Mdot
.67 .30985 Mdot
.67 .30997 Mdot
.67 .31006 Mdot
.67 .3102 Mdot
.67 .31025 Mdot
.67 .31029 Mdot
.67 .3103 Mdot
.67 .3107 Mdot
.67 .3107 Mdot
.67 .31077 Mdot
.67 .31078 Mdot
.67 .31083 Mdot
.67 .31086 Mdot
.67 .31097 Mdot
.67 .31108 Mdot
.67 .31144 Mdot
.67 .31165 Mdot
.67 .31165 Mdot
.67 .31166 Mdot
.67 .31171 Mdot
.67 .31173 Mdot
.67 .3118 Mdot
.67 .31203 Mdot
.67 .31205 Mdot
.67 .31212 Mdot
.67 .31225 Mdot
.67 .31257 Mdot
.67 .31259 Mdot
.67 .31262 Mdot
.67 .31266 Mdot
.67 .31273 Mdot
.67 .31281 Mdot
.67 .31285 Mdot
.67 .3129 Mdot
.67 .31292 Mdot
.67 .31299 Mdot
.67 .31301 Mdot
.67 .31321 Mdot
.67 .31322 Mdot
.67 .31332 Mdot
.67 .31333 Mdot
.67 .31352 Mdot
.67 .31357 Mdot
.67 .31423 Mdot
.67 .31428 Mdot
.67 .31435 Mdot
.67 .31542 Mdot
.67 .31549 Mdot
.67 .31553 Mdot
.67 .31555 Mdot
.67 .31555 Mdot
.67 .31569 Mdot
.67 .31569 Mdot
.67 .3158 Mdot
.67 .31585 Mdot
.67 .31594 Mdot
.67 .31606 Mdot
.67 .3162 Mdot
.67 .31622 Mdot
.67 .3163 Mdot
.67 .31632 Mdot
.67 .31669 Mdot
.67 .31691 Mdot
.67 .31693 Mdot
.67 .31699 Mdot
.67 .31702 Mdot
.67 .31712 Mdot
.67 .31715 Mdot
.67 .31746 Mdot
.67 .31749 Mdot
.67 .3175 Mdot
.67 .31751 Mdot
.67 .31757 Mdot
.67 .31772 Mdot
.67 .31775 Mdot
.67 .31794 Mdot
.67 .31796 Mdot
.67 .31803 Mdot
.67 .31806 Mdot
.67 .3181 Mdot
.67 .31816 Mdot
.67 .31817 Mdot
.67 .31833 Mdot
.67 .31838 Mdot
.67 .31839 Mdot
.67 .31848 Mdot
.67 .3185 Mdot
.67 .31909 Mdot
.67 .31924 Mdot
.67 .31945 Mdot
.67 .32014 Mdot
.67 .32053 Mdot
.67 .32062 Mdot
.67 .32082 Mdot
.67 .32087 Mdot
.67 .32087 Mdot
.67 .32109 Mdot
.67 .32136 Mdot
.67 .32142 Mdot
.67 .32146 Mdot
.67 .32181 Mdot
.67 .32204 Mdot
.67 .32205 Mdot
.67 .3222 Mdot
.67 .32223 Mdot
.67 .32241 Mdot
.67 .3226 Mdot
.67 .3227 Mdot
.67 .32274 Mdot
.67 .32294 Mdot
.67 .32298 Mdot
.67 .32317 Mdot
.67 .32324 Mdot
.67 .32338 Mdot
.67 .32342 Mdot
.67 .32386 Mdot
.67 .32406 Mdot
.67 .3241 Mdot
.67 .32419 Mdot
.67 .32434 Mdot
.67 .32451 Mdot
.67 .32455 Mdot
.67 .32481 Mdot
.67 .32508 Mdot
.67 .3251 Mdot
.67 .32512 Mdot
.67 .32513 Mdot
.67 .32525 Mdot
.67 .32546 Mdot
.67 .3255 Mdot
.67 .32587 Mdot
.67 .32589 Mdot
.67 .32593 Mdot
.67 .32613 Mdot
.67 .3262 Mdot
.67 .3263 Mdot
.67 .32645 Mdot
.67 .32648 Mdot
.67 .32661 Mdot
.67 .32666 Mdot
.67 .3268 Mdot
.67 .32703 Mdot
.67 .32723 Mdot
.67 .32728 Mdot
.67 .32741 Mdot
.67 .32751 Mdot
.67 .32757 Mdot
.67 .32841 Mdot
.67 .32852 Mdot
.67 .32858 Mdot
.67 .32868 Mdot
.67 .32902 Mdot
.67 .32925 Mdot
.67 .32932 Mdot
.67 .32946 Mdot
.67 .32998 Mdot
.67 .33004 Mdot
.67 .33011 Mdot
.67 .33029 Mdot
.67 .33034 Mdot
.67 .33038 Mdot
.67 .33048 Mdot
.67 .33052 Mdot
.67 .33053 Mdot
.67 .33121 Mdot
.67 .33187 Mdot
.67 .33195 Mdot
.67 .33237 Mdot
.67 .33271 Mdot
.67 .33282 Mdot
.67 .33301 Mdot
.67 .33307 Mdot
.67 .33317 Mdot
.67 .33335 Mdot
.67 .33337 Mdot
.67 .3335 Mdot
.67 .33358 Mdot
.67 .33359 Mdot
.67 .33392 Mdot
.67 .334 Mdot
.67 .33412 Mdot
.67 .33451 Mdot
.67 .33488 Mdot
.67 .33491 Mdot
.67 .33503 Mdot
.67 .33522 Mdot
.67 .33524 Mdot
.67 .33567 Mdot
.67 .33587 Mdot
.67 .33595 Mdot
.67 .33619 Mdot
.67 .33623 Mdot
.67 .33631 Mdot
.67 .33633 Mdot
.67 .33671 Mdot
.67 .33676 Mdot
.67 .36435 Mdot
.67 .36438 Mdot
.67 .36467 Mdot
.67 .36468 Mdot
.67 .36474 Mdot
.67 .36477 Mdot
.67 .36495 Mdot
.67 .36501 Mdot
.67 .36516 Mdot
.67 .36548 Mdot
.67 .3655 Mdot
.67 .36564 Mdot
.67 .36573 Mdot
.67 .36575 Mdot
.67 .36603 Mdot
.67 .36632 Mdot
.67 .3664 Mdot
.67 .36646 Mdot
.67 .36671 Mdot
.67 .36672 Mdot
.67 .36678 Mdot
.67 .36688 Mdot
.67 .36689 Mdot
.67 .36702 Mdot
.67 .3671 Mdot
.67 .36714 Mdot
.67 .36729 Mdot
.67 .36737 Mdot
.67 .36762 Mdot
.67 .36794 Mdot
.67 .36799 Mdot
.67 .36848 Mdot
.67 .36899 Mdot
.67 .369 Mdot
.67 .36903 Mdot
.67 .36911 Mdot
.67 .36914 Mdot
.67 .36918 Mdot
.67 .36931 Mdot
.67 .36936 Mdot
.67 .3694 Mdot
.67 .3698 Mdot
.67 .3699 Mdot
.67 .36995 Mdot
.67 .37012 Mdot
.67 .37038 Mdot
.67 .37045 Mdot
.67 .37049 Mdot
.67 .37057 Mdot
.67 .3712 Mdot
.67 .37125 Mdot
.67 .37132 Mdot
.67 .37142 Mdot
.67 .37145 Mdot
.67 .37161 Mdot
.67 .37178 Mdot
.67 .37188 Mdot
.67 .37192 Mdot
.67 .37202 Mdot
.67 .37204 Mdot
.67 .37216 Mdot
.67 .37223 Mdot
.67 .37227 Mdot
.67 .37243 Mdot
.67 .37246 Mdot
.67 .37247 Mdot
.67 .37275 Mdot
.67 .37278 Mdot
.67 .37294 Mdot
.67 .37303 Mdot
.67 .37303 Mdot
.67 .37305 Mdot
.67 .37306 Mdot
.67 .37327 Mdot
.67 .37346 Mdot
.67 .37349 Mdot
.67 .37362 Mdot
.67 .37373 Mdot
.67 .37379 Mdot
.67 .37382 Mdot
.67 .37398 Mdot
.67 .3743 Mdot
.67 .37433 Mdot
.67 .37443 Mdot
.67 .37449 Mdot
.67 .37463 Mdot
.67 .37466 Mdot
.67 .37481 Mdot
.67 .37484 Mdot
.67 .37491 Mdot
.67 .37506 Mdot
.67 .37519 Mdot
.67 .37521 Mdot
.67 .37532 Mdot
.67 .37533 Mdot
.67 .3755 Mdot
.67 .37576 Mdot
.67 .37579 Mdot
.67 .37584 Mdot
.67 .37604 Mdot
.67 .37621 Mdot
.67 .37621 Mdot
.67 .37624 Mdot
.67 .37639 Mdot
.67 .37646 Mdot
.67 .37675 Mdot
.67 .37727 Mdot
.67 .37742 Mdot
.67 .37753 Mdot
.67 .37798 Mdot
.67 .37799 Mdot
.67 .37805 Mdot
.67 .37806 Mdot
.67 .3781 Mdot
.67 .37822 Mdot
.67 .37823 Mdot
.67 .37827 Mdot
.67 .3783 Mdot
.67 .37833 Mdot
.67 .37838 Mdot
.67 .37839 Mdot
.67 .37853 Mdot
.67 .37856 Mdot
.67 .37867 Mdot
.67 .37871 Mdot
.67 .37872 Mdot
.67 .37873 Mdot
.67 .37875 Mdot
.67 .37898 Mdot
.67 .37901 Mdot
.67 .37908 Mdot
.67 .3791 Mdot
.67 .37915 Mdot
.67 .37916 Mdot
.67 .37932 Mdot
.67 .3796 Mdot
.67 .37961 Mdot
.67 .37968 Mdot
.67 .37969 Mdot
.67 .3798 Mdot
.67 .37988 Mdot
.67 .37995 Mdot
.67 .37999 Mdot
.67 .38007 Mdot
.67 .38007 Mdot
.67 .38017 Mdot
.67 .38017 Mdot
.67 .38019 Mdot
.67 .38022 Mdot
.67 .38027 Mdot
.67 .38107 Mdot
.67 .38112 Mdot
.67 .38116 Mdot
.67 .38165 Mdot
.67 .38169 Mdot
.67 .38183 Mdot
.67 .38183 Mdot
.67 .38191 Mdot
.67 .38192 Mdot
.67 .38207 Mdot
.67 .38208 Mdot
.67 .38214 Mdot
.67 .38215 Mdot
.67 .38219 Mdot
.67 .38222 Mdot
.67 .38228 Mdot
.67 .38233 Mdot
.67 .38236 Mdot
.67 .38239 Mdot
.67 .3824 Mdot
.67 .38263 Mdot
.67 .38274 Mdot
.67 .38279 Mdot
.67 .3828 Mdot
.67 .38297 Mdot
.67 .38303 Mdot
.67 .38304 Mdot
.67 .38307 Mdot
.67 .38308 Mdot
.67 .38309 Mdot
.67 .38324 Mdot
.67 .38351 Mdot
.67 .38359 Mdot
.67 .38367 Mdot
.67 .3837 Mdot
.67 .38374 Mdot
.67 .38374 Mdot
.67 .38379 Mdot
.67 .38379 Mdot
.67 .38409 Mdot
.67 .3841 Mdot
.67 .38413 Mdot
.67 .38417 Mdot
.67 .38427 Mdot
.67 .38434 Mdot
.67 .38443 Mdot
.67 .38452 Mdot
.67 .38456 Mdot
.67 .38466 Mdot
.67 .38468 Mdot
.67 .38469 Mdot
.67 .38476 Mdot
.67 .38491 Mdot
.67 .38508 Mdot
.67 .38517 Mdot
.67 .3852 Mdot
.67 .38521 Mdot
.67 .38531 Mdot
.67 .38543 Mdot
.67 .38547 Mdot
.67 .38567 Mdot
.67 .38569 Mdot
.67 .38603 Mdot
.67 .38613 Mdot
.67 .38625 Mdot
.67 .38643 Mdot
.67 .38646 Mdot
.67 .38649 Mdot
.67 .38676 Mdot
.67 .38691 Mdot
.67 .38698 Mdot
.67 .38706 Mdot
.67 .38707 Mdot
.67 .38708 Mdot
.67 .38722 Mdot
.67 .38726 Mdot
.67 .38726 Mdot
.67 .38732 Mdot
.67 .38738 Mdot
.67 .3875 Mdot
.67 .38754 Mdot
.67 .38775 Mdot
.67 .38776 Mdot
.67 .38781 Mdot
.67 .38788 Mdot
.67 .38796 Mdot
.67 .38812 Mdot
.67 .38824 Mdot
.67 .38829 Mdot
.67 .38832 Mdot
.67 .38881 Mdot
.67 .38886 Mdot
.67 .38897 Mdot
.67 .38902 Mdot
.67 .38913 Mdot
.67 .38915 Mdot
.67 .38931 Mdot
.67 .38932 Mdot
.67 .38935 Mdot
.67 .38938 Mdot
.67 .38943 Mdot
.67 .38943 Mdot
.67 .38947 Mdot
.67 .38974 Mdot
.67 .38998 Mdot
.67 .39001 Mdot
.67 .39009 Mdot
.67 .39015 Mdot
.67 .39015 Mdot
.67 .39028 Mdot
.67 .39035 Mdot
.67 .39037 Mdot
.67 .39057 Mdot
.67 .39057 Mdot
.67 .39059 Mdot
.67 .39068 Mdot
.67 .39074 Mdot
.67 .39102 Mdot
.67 .39106 Mdot
.67 .39117 Mdot
.67 .39118 Mdot
.67 .39142 Mdot
.67 .39158 Mdot
.67 .3916 Mdot
.67 .39161 Mdot
.67 .39165 Mdot
.67 .3917 Mdot
.67 .39184 Mdot
.67 .39193 Mdot
.67 .39219 Mdot
.67 .39221 Mdot
.67 .39224 Mdot
.67 .39234 Mdot
.67 .39235 Mdot
.67 .39251 Mdot
.67 .39252 Mdot
.67 .39256 Mdot
.67 .3926 Mdot
.67 .3927 Mdot
.67 .39295 Mdot
.67 .39297 Mdot
.67 .393 Mdot
.67 .39301 Mdot
.67 .3932 Mdot
.67 .39324 Mdot
.67 .39344 Mdot
.67 .39345 Mdot
.67 .39345 Mdot
.67 .39376 Mdot
.67 .394 Mdot
.67 .394 Mdot
.67 .39402 Mdot
.67 .39423 Mdot
.67 .39428 Mdot
.67 .39437 Mdot
.67 .39437 Mdot
.67 .39444 Mdot
.67 .39473 Mdot
.67 .39478 Mdot
.67 .3948 Mdot
.67 .39489 Mdot
.67 .39502 Mdot
.67 .39502 Mdot
.67 .39508 Mdot
.67 .39535 Mdot
.67 .39536 Mdot
.67 .39548 Mdot
.67 .39552 Mdot
.67 .39559 Mdot
.67 .39567 Mdot
.67 .39569 Mdot
.67 .39597 Mdot
.67 .39599 Mdot
.67 .39599 Mdot
.67 .39616 Mdot
.67 .39622 Mdot
.67 .39625 Mdot
.67 .39672 Mdot
.67 .39689 Mdot
.67 .39692 Mdot
.67 .39713 Mdot
.67 .3972 Mdot
.67 .39722 Mdot
.67 .3973 Mdot
.67 .39731 Mdot
.67 .39736 Mdot
.67 .3974 Mdot
.67 .39764 Mdot
.67 .39808 Mdot
.67 .39809 Mdot
.67 .3982 Mdot
.67 .39822 Mdot
.67 .39829 Mdot
.67 .39834 Mdot
.67 .39835 Mdot
.67 .39837 Mdot
.67 .39842 Mdot
.67 .39864 Mdot
.67 .39865 Mdot
.67 .39873 Mdot
.67 .39878 Mdot
.67 .39883 Mdot
.67 .39886 Mdot
.67 .39892 Mdot
.67 .39895 Mdot
.67 .39896 Mdot
.67 .39913 Mdot
.67 .39916 Mdot
.67 .39916 Mdot
.67 .3992 Mdot
.67 .39924 Mdot
.67 .39944 Mdot
.67 .39953 Mdot
.67 .39953 Mdot
.67 .39953 Mdot
.67 .39955 Mdot
.67 .39956 Mdot
.67 .39959 Mdot
.67 .39969 Mdot
.67 .39992 Mdot
.67 .39993 Mdot
.67 .40001 Mdot
.67 .40003 Mdot
.67 .40005 Mdot
.67 .40017 Mdot
.67 .40018 Mdot
.67 .40022 Mdot
.67 .40022 Mdot
.67 .4003 Mdot
.67 .40032 Mdot
.67 .40062 Mdot
.67 .40065 Mdot
.67 .40112 Mdot
.67 .40114 Mdot
.67 .40115 Mdot
.67 .40121 Mdot
.67 .40121 Mdot
.67 .40125 Mdot
.67 .40127 Mdot
.67 .40131 Mdot
.67 .40136 Mdot
.67 .40142 Mdot
.67 .40143 Mdot
.67 .40147 Mdot
.67 .40162 Mdot
.67 .40171 Mdot
.67 .40174 Mdot
.67 .40176 Mdot
.67 .40181 Mdot
.67 .40195 Mdot
.67 .40196 Mdot
.67 .40196 Mdot
.67 .40205 Mdot
.67 .40214 Mdot
.67 .40215 Mdot
.67 .40218 Mdot
.67 .40223 Mdot
.67 .40224 Mdot
.67 .40232 Mdot
.67 .40233 Mdot
.67 .40322 Mdot
.67 .40325 Mdot
.67 .40336 Mdot
.67 .40356 Mdot
.67 .40375 Mdot
.67 .40385 Mdot
.67 .40385 Mdot
.67 .40391 Mdot
.67 .404 Mdot
.67 .40412 Mdot
.67 .40422 Mdot
.67 .40423 Mdot
.67 .4046 Mdot
.67 .40469 Mdot
.67 .4048 Mdot
.67 .40487 Mdot
.67 .40489 Mdot
.67 .40499 Mdot
.67 .40511 Mdot
.67 .40512 Mdot
.67 .40513 Mdot
.67 .40513 Mdot
.67 .40518 Mdot
.67 .40527 Mdot
.67 .40528 Mdot
.67 .40544 Mdot
.67 .40544 Mdot
.67 .40546 Mdot
.67 .40555 Mdot
.67 .40557 Mdot
.67 .40561 Mdot
.67 .40568 Mdot
.67 .40569 Mdot
.67 .40574 Mdot
.67 .40576 Mdot
.67 .40582 Mdot
.67 .40592 Mdot
.67 .406 Mdot
.67 .40602 Mdot
.67 .40608 Mdot
.67 .40612 Mdot
.67 .40614 Mdot
.67 .40649 Mdot
.67 .40654 Mdot
.67 .40656 Mdot
.67 .4066 Mdot
.67 .40675 Mdot
.67 .40684 Mdot
.67 .40687 Mdot
.67 .40693 Mdot
.67 .40715 Mdot
.67 .40717 Mdot
.67 .40727 Mdot
.67 .40729 Mdot
.67 .40731 Mdot
.67 .40735 Mdot
.67 .40737 Mdot
.67 .40737 Mdot
.67 .40766 Mdot
.67 .40793 Mdot
.67 .40796 Mdot
.67 .40814 Mdot
.67 .40828 Mdot
.67 .40832 Mdot
.67 .4084 Mdot
.67 .40843 Mdot
.67 .40847 Mdot
.67 .40854 Mdot
.67 .40855 Mdot
.67 .40861 Mdot
.67 .40864 Mdot
.67 .40864 Mdot
.67 .40878 Mdot
.67 .40882 Mdot
.67 .40886 Mdot
.67 .40903 Mdot
.67 .40918 Mdot
.67 .40919 Mdot
.67 .40924 Mdot
.67 .40932 Mdot
.67 .40933 Mdot
.67 .40951 Mdot
.67 .40959 Mdot
.67 .40963 Mdot
.67 .40973 Mdot
.67 .40974 Mdot
.67 .40977 Mdot
.67 .40978 Mdot
.67 .40994 Mdot
.67 .40996 Mdot
.672 .27487 Mdot
.672 .27492 Mdot
.672 .2752 Mdot
.672 .27527 Mdot
.672 .27533 Mdot
.672 .27537 Mdot
.672 .27555 Mdot
.672 .27558 Mdot
.672 .27563 Mdot
.672 .27589 Mdot
.672 .27608 Mdot
.672 .27617 Mdot
.672 .27618 Mdot
.672 .2762 Mdot
.672 .27622 Mdot
.672 .27644 Mdot
.672 .2765 Mdot
.672 .27655 Mdot
.672 .27657 Mdot
.672 .27675 Mdot
.672 .27688 Mdot
.672 .27699 Mdot
.672 .27706 Mdot
.672 .2771 Mdot
.672 .27751 Mdot
.672 .27768 Mdot
.672 .27768 Mdot
.672 .278 Mdot
.672 .27801 Mdot
.672 .27811 Mdot
.672 .27821 Mdot
.672 .27855 Mdot
.672 .27867 Mdot
.672 .27869 Mdot
.672 .27885 Mdot
.672 .2789 Mdot
.672 .27902 Mdot
.672 .27938 Mdot
.672 .27953 Mdot
.672 .27966 Mdot
.672 .27981 Mdot
.672 .27986 Mdot
.672 .27991 Mdot
.672 .27995 Mdot
.672 .28005 Mdot
.672 .28007 Mdot
.672 .28013 Mdot
.672 .28022 Mdot
.672 .28025 Mdot
.672 .28031 Mdot
.672 .28034 Mdot
.672 .28058 Mdot
.672 .28059 Mdot
.672 .28061 Mdot
.672 .2807 Mdot
.672 .2807 Mdot
.672 .28071 Mdot
.672 .28078 Mdot
.672 .28086 Mdot
.672 .28086 Mdot
.672 .28088 Mdot
.672 .28089 Mdot
.672 .28111 Mdot
.672 .28133 Mdot
.672 .28139 Mdot
.672 .28141 Mdot
.672 .28172 Mdot
.672 .28176 Mdot
.672 .28177 Mdot
.672 .28177 Mdot
.672 .28189 Mdot
.672 .28199 Mdot
.672 .28224 Mdot
.672 .2823 Mdot
.672 .28285 Mdot
.672 .283 Mdot
.672 .28302 Mdot
.672 .28323 Mdot
.672 .28343 Mdot
.672 .28344 Mdot
.672 .28353 Mdot
.672 .28398 Mdot
.672 .284 Mdot
.672 .28408 Mdot
.672 .2843 Mdot
.672 .2843 Mdot
.672 .28457 Mdot
.672 .28459 Mdot
.672 .28465 Mdot
.672 .28482 Mdot
.672 .28489 Mdot
.672 .28495 Mdot
.672 .28502 Mdot
.672 .28503 Mdot
.672 .28505 Mdot
.672 .28512 Mdot
.672 .28512 Mdot
.672 .28512 Mdot
.672 .28528 Mdot
.672 .28529 Mdot
.672 .28544 Mdot
.672 .28547 Mdot
.672 .28555 Mdot
.672 .28609 Mdot
.672 .28614 Mdot
.672 .2863 Mdot
.672 .28649 Mdot
.672 .28656 Mdot
.672 .28657 Mdot
.672 .28657 Mdot
.672 .2867 Mdot
.672 .28672 Mdot
.672 .28679 Mdot
.672 .28685 Mdot
.672 .28707 Mdot
.672 .28711 Mdot
.672 .28715 Mdot
.672 .28716 Mdot
.672 .2872 Mdot
.672 .28721 Mdot
.672 .28721 Mdot
.672 .28724 Mdot
.672 .28746 Mdot
.672 .28746 Mdot
.672 .28755 Mdot
.672 .28785 Mdot
.672 .2879 Mdot
.672 .28809 Mdot
.672 .28823 Mdot
.672 .28844 Mdot
.672 .28856 Mdot
.672 .28856 Mdot
.672 .28859 Mdot
.672 .28875 Mdot
.672 .28908 Mdot
.672 .28993 Mdot
.672 .28994 Mdot
.672 .29019 Mdot
.672 .29021 Mdot
.672 .29025 Mdot
.672 .29033 Mdot
.672 .29052 Mdot
.672 .29061 Mdot
.672 .29077 Mdot
.672 .2908 Mdot
.672 .2909 Mdot
.672 .29092 Mdot
.672 .29097 Mdot
.672 .29101 Mdot
.672 .29107 Mdot
.672 .29126 Mdot
.672 .29126 Mdot
.672 .29136 Mdot
.672 .29139 Mdot
.672 .29162 Mdot
.672 .29183 Mdot
.672 .29191 Mdot
.672 .29193 Mdot
.672 .29194 Mdot
.672 .29195 Mdot
.672 .29198 Mdot
.672 .29205 Mdot
.672 .29206 Mdot
.672 .29216 Mdot
.672 .29221 Mdot
.672 .29224 Mdot
.672 .29239 Mdot
.672 .2925 Mdot
.672 .29267 Mdot
.672 .29289 Mdot
.672 .29302 Mdot
.672 .29305 Mdot
.672 .29322 Mdot
.672 .29345 Mdot
.672 .29348 Mdot
.672 .29351 Mdot
.672 .29364 Mdot
.672 .29384 Mdot
.672 .29385 Mdot
.672 .29398 Mdot
.672 .29415 Mdot
.672 .29425 Mdot
.672 .29439 Mdot
.672 .29449 Mdot
.672 .29459 Mdot
.672 .29459 Mdot
.672 .29475 Mdot
.672 .29514 Mdot
.672 .29527 Mdot
.672 .29532 Mdot
.672 .29534 Mdot
.672 .29536 Mdot
.672 .29542 Mdot
.672 .29559 Mdot
.672 .29563 Mdot
.672 .29564 Mdot
.672 .29577 Mdot
.672 .29596 Mdot
.672 .29621 Mdot
.672 .2963 Mdot
.672 .29667 Mdot
.672 .29676 Mdot
.672 .29694 Mdot
.672 .29697 Mdot
.672 .29708 Mdot
.672 .29711 Mdot
.672 .29742 Mdot
.672 .29744 Mdot
.672 .29753 Mdot
.672 .29758 Mdot
.672 .29779 Mdot
.672 .29784 Mdot
.672 .29808 Mdot
.672 .29816 Mdot
.672 .29832 Mdot
.672 .29865 Mdot
.672 .29879 Mdot
.672 .29885 Mdot
.672 .29892 Mdot
.672 .29898 Mdot
.672 .29907 Mdot
.672 .29914 Mdot
.672 .29933 Mdot
.672 .2996 Mdot
.672 .29995 Mdot
.672 .30013 Mdot
.672 .30018 Mdot
.672 .30019 Mdot
.672 .30027 Mdot
.672 .30038 Mdot
.672 .30058 Mdot
.672 .30068 Mdot
.672 .30072 Mdot
.672 .30074 Mdot
.672 .30077 Mdot
.672 .30085 Mdot
.672 .30109 Mdot
.672 .30114 Mdot
.672 .30116 Mdot
.672 .30131 Mdot
.672 .30179 Mdot
.672 .30207 Mdot
.672 .30207 Mdot
.672 .30214 Mdot
.672 .30225 Mdot
.672 .30244 Mdot
.672 .30247 Mdot
.672 .30268 Mdot
.672 .30282 Mdot
.672 .30285 Mdot
.672 .30285 Mdot
.672 .30288 Mdot
.672 .3029 Mdot
.672 .30302 Mdot
.672 .30309 Mdot
.672 .30318 Mdot
.672 .30341 Mdot
.672 .30344 Mdot
.672 .30379 Mdot
.672 .30402 Mdot
.672 .30403 Mdot
.672 .30407 Mdot
.672 .3041 Mdot
.672 .30414 Mdot
.672 .30428 Mdot
.672 .30455 Mdot
.672 .30486 Mdot
.672 .30491 Mdot
.672 .30502 Mdot
.672 .30515 Mdot
.672 .30554 Mdot
.672 .30571 Mdot
.672 .30577 Mdot
.672 .30583 Mdot
.672 .30584 Mdot
.672 .30586 Mdot
.672 .30604 Mdot
.672 .30607 Mdot
.672 .30632 Mdot
.672 .30633 Mdot
.672 .30634 Mdot
.672 .30634 Mdot
.672 .30638 Mdot
.672 .30647 Mdot
.672 .30663 Mdot
.672 .30664 Mdot
.672 .30667 Mdot
.672 .30669 Mdot
.672 .30674 Mdot
.672 .30679 Mdot
.672 .30684 Mdot
.672 .30686 Mdot
.672 .30689 Mdot
.672 .30692 Mdot
.672 .30707 Mdot
.672 .30745 Mdot
.672 .30754 Mdot
.672 .30761 Mdot
.672 .3078 Mdot
.672 .30786 Mdot
.672 .30791 Mdot
.672 .30792 Mdot
.672 .3081 Mdot
.672 .3081 Mdot
.672 .30819 Mdot
.672 .30842 Mdot
.672 .30844 Mdot
.672 .30848 Mdot
.672 .30854 Mdot
.672 .30861 Mdot
.672 .30871 Mdot
.672 .30875 Mdot
.672 .30878 Mdot
.672 .30892 Mdot
.672 .30893 Mdot
.672 .30898 Mdot
.672 .30909 Mdot
.672 .30926 Mdot
.672 .30927 Mdot
.672 .30943 Mdot
.672 .30974 Mdot
.672 .30977 Mdot
.672 .30992 Mdot
.672 .31 Mdot
.672 .31002 Mdot
.672 .31016 Mdot
.672 .31048 Mdot
.672 .31049 Mdot
.672 .31067 Mdot
.672 .31184 Mdot
.672 .31204 Mdot
.672 .31224 Mdot
.672 .31239 Mdot
.672 .31262 Mdot
.672 .3129 Mdot
.672 .31291 Mdot
.672 .31297 Mdot
.672 .31297 Mdot
.672 .31297 Mdot
.672 .31319 Mdot
.672 .31336 Mdot
.672 .31356 Mdot
.672 .31382 Mdot
.672 .31416 Mdot
.672 .31425 Mdot
.672 .31448 Mdot
.672 .31478 Mdot
.672 .31479 Mdot
.672 .31496 Mdot
.672 .31496 Mdot
.672 .31512 Mdot
.672 .31516 Mdot
.672 .31536 Mdot
.672 .31541 Mdot
.672 .31542 Mdot
.672 .31542 Mdot
.672 .31551 Mdot
.672 .31551 Mdot
.672 .31559 Mdot
.672 .31565 Mdot
.672 .31607 Mdot
.672 .31617 Mdot
.672 .31621 Mdot
.672 .31622 Mdot
.672 .31629 Mdot
.672 .31634 Mdot
.672 .31657 Mdot
.672 .31657 Mdot
.672 .31659 Mdot
.672 .31671 Mdot
.672 .31676 Mdot
.672 .31706 Mdot
.672 .31734 Mdot
.672 .31743 Mdot
.672 .31808 Mdot
.672 .31822 Mdot
.672 .3184 Mdot
.672 .31845 Mdot
.672 .31856 Mdot
.672 .31861 Mdot
.672 .31881 Mdot
.672 .31887 Mdot
.672 .31889 Mdot
.672 .31917 Mdot
.672 .31918 Mdot
.672 .31919 Mdot
.672 .31925 Mdot
.672 .31931 Mdot
.672 .31934 Mdot
.672 .31936 Mdot
.672 .3195 Mdot
.672 .3196 Mdot
.672 .31972 Mdot
.672 .31981 Mdot
.672 .3199 Mdot
.672 .32003 Mdot
.672 .32005 Mdot
.672 .32013 Mdot
.672 .32024 Mdot
.672 .32066 Mdot
.672 .32066 Mdot
.672 .32096 Mdot
.672 .32103 Mdot
.672 .32106 Mdot
.672 .32108 Mdot
.672 .32112 Mdot
.672 .32121 Mdot
.672 .32124 Mdot
.672 .32142 Mdot
.672 .32204 Mdot
.672 .32205 Mdot
.672 .32222 Mdot
.672 .32223 Mdot
.672 .32259 Mdot
.672 .3229 Mdot
.672 .32298 Mdot
.672 .32301 Mdot
.672 .32306 Mdot
.672 .32314 Mdot
.672 .32328 Mdot
.672 .32373 Mdot
.672 .32386 Mdot
.672 .32406 Mdot
.672 .32428 Mdot
.672 .3243 Mdot
.672 .32438 Mdot
.672 .32484 Mdot
.672 .32502 Mdot
.672 .32522 Mdot
.672 .32523 Mdot
.672 .32523 Mdot
.672 .32526 Mdot
.672 .32533 Mdot
.672 .32536 Mdot
.672 .32588 Mdot
.672 .32593 Mdot
.672 .32602 Mdot
.672 .32643 Mdot
.672 .32681 Mdot
.672 .32685 Mdot
.672 .32688 Mdot
.672 .32689 Mdot
.672 .32702 Mdot
.672 .32716 Mdot
.672 .32716 Mdot
.672 .32716 Mdot
.672 .32732 Mdot
.672 .32736 Mdot
.672 .32738 Mdot
.672 .32783 Mdot
.672 .32787 Mdot
.672 .32797 Mdot
.672 .32803 Mdot
.672 .32819 Mdot
.672 .32831 Mdot
.672 .32835 Mdot
.672 .32851 Mdot
.672 .3286 Mdot
.672 .32868 Mdot
.672 .32878 Mdot
.672 .32905 Mdot
.672 .32928 Mdot
.672 .32956 Mdot
.672 .33021 Mdot
.672 .33043 Mdot
.672 .33051 Mdot
.672 .3308 Mdot
.672 .33083 Mdot
.672 .33105 Mdot
.672 .33167 Mdot
.672 .33184 Mdot
.672 .33203 Mdot
.672 .33204 Mdot
.672 .33263 Mdot
.672 .33263 Mdot
.672 .33293 Mdot
.672 .33366 Mdot
.672 .33374 Mdot
.672 .33387 Mdot
.672 .33407 Mdot
.672 .33431 Mdot
.672 .33462 Mdot
.672 .33467 Mdot
.672 .33475 Mdot
.672 .33486 Mdot
.672 .33526 Mdot
.672 .3353 Mdot
.672 .33533 Mdot
.672 .33534 Mdot
.672 .33551 Mdot
.672 .33585 Mdot
.672 .33633 Mdot
.672 .33642 Mdot
.672 .33646 Mdot
.672 .33679 Mdot
.672 .33686 Mdot
.672 .33697 Mdot
.672 .3371 Mdot
.672 .33761 Mdot
.672 .33769 Mdot
.672 .36437 Mdot
.672 .36443 Mdot
.672 .36481 Mdot
.672 .3649 Mdot
.672 .36498 Mdot
.672 .36504 Mdot
.672 .36528 Mdot
.672 .36532 Mdot
.672 .36538 Mdot
.672 .36574 Mdot
.672 .36599 Mdot
.672 .36611 Mdot
.672 .36613 Mdot
.672 .36615 Mdot
.672 .36618 Mdot
.672 .36648 Mdot
.672 .36656 Mdot
.672 .36662 Mdot
.672 .36665 Mdot
.672 .36688 Mdot
.672 .36706 Mdot
.672 .36721 Mdot
.672 .36731 Mdot
.672 .36736 Mdot
.672 .36791 Mdot
.672 .36813 Mdot
.672 .36814 Mdot
.672 .36857 Mdot
.672 .36858 Mdot
.672 .36872 Mdot
.672 .36885 Mdot
.672 .36931 Mdot
.672 .36947 Mdot
.672 .3695 Mdot
.672 .36971 Mdot
.672 .36977 Mdot
.672 .36993 Mdot
.672 .37042 Mdot
.672 .37063 Mdot
.672 .3708 Mdot
.672 .371 Mdot
.672 .37107 Mdot
.672 .37113 Mdot
.672 .3712 Mdot
.672 .37132 Mdot
.672 .37135 Mdot
.672 .37144 Mdot
.672 .37155 Mdot
.672 .3716 Mdot
.672 .37168 Mdot
.672 .37171 Mdot
.672 .37204 Mdot
.672 .37206 Mdot
.672 .37208 Mdot
.672 .3722 Mdot
.672 .3722 Mdot
.672 .37221 Mdot
.672 .37231 Mdot
.672 .37241 Mdot
.672 .37241 Mdot
.672 .37244 Mdot
.672 .37246 Mdot
.672 .37274 Mdot
.672 .37305 Mdot
.672 .37312 Mdot
.672 .37316 Mdot
.672 .37354 Mdot
.672 .37357 Mdot
.672 .37362 Mdot
.672 .37364 Mdot
.672 .37364 Mdot
.672 .37365 Mdot
.672 .3738 Mdot
.672 .37393 Mdot
.672 .37427 Mdot
.672 .37433 Mdot
.672 .37434 Mdot
.672 .37451 Mdot
.672 .37466 Mdot
.672 .37476 Mdot
.672 .37509 Mdot
.672 .3752 Mdot
.672 .37526 Mdot
.672 .37529 Mdot
.672 .37531 Mdot
.672 .37537 Mdot
.672 .3756 Mdot
.672 .37587 Mdot
.672 .37588 Mdot
.672 .37601 Mdot
.672 .37602 Mdot
.672 .37648 Mdot
.672 .37661 Mdot
.672 .37663 Mdot
.672 .3767 Mdot
.672 .37672 Mdot
.672 .37674 Mdot
.672 .37676 Mdot
.672 .37682 Mdot
.672 .37704 Mdot
.672 .37704 Mdot
.672 .37735 Mdot
.672 .3774 Mdot
.672 .37743 Mdot
.672 .3775 Mdot
.672 .37751 Mdot
.672 .37761 Mdot
.672 .37768 Mdot
.672 .37774 Mdot
.672 .37783 Mdot
.672 .3779 Mdot
.672 .37801 Mdot
.672 .37802 Mdot
.672 .37804 Mdot
.672 .37809 Mdot
.672 .37813 Mdot
.672 .37814 Mdot
.672 .37815 Mdot
.672 .37836 Mdot
.672 .37837 Mdot
.672 .37841 Mdot
.672 .37856 Mdot
.672 .3786 Mdot
.672 .37868 Mdot
.672 .37872 Mdot
.672 .37885 Mdot
.672 .37896 Mdot
.672 .37945 Mdot
.672 .37951 Mdot
.672 .37972 Mdot
.672 .37994 Mdot
.672 .37998 Mdot
.672 .38007 Mdot
.672 .38008 Mdot
.672 .38008 Mdot
.672 .38026 Mdot
.672 .38029 Mdot
.672 .38035 Mdot
.672 .38035 Mdot
.672 .38038 Mdot
.672 .38046 Mdot
.672 .38076 Mdot
.672 .38081 Mdot
.672 .38087 Mdot
.672 .38087 Mdot
.672 .38094 Mdot
.672 .38094 Mdot
.672 .38094 Mdot
.672 .38098 Mdot
.672 .38113 Mdot
.672 .38116 Mdot
.672 .38128 Mdot
.672 .38128 Mdot
.672 .38141 Mdot
.672 .38141 Mdot
.672 .38164 Mdot
.672 .38181 Mdot
.672 .38188 Mdot
.672 .38213 Mdot
.672 .38232 Mdot
.672 .38247 Mdot
.672 .3826 Mdot
.672 .38276 Mdot
.672 .38276 Mdot
.672 .38276 Mdot
.672 .38281 Mdot
.672 .38281 Mdot
.672 .38302 Mdot
.672 .38319 Mdot
.672 .38331 Mdot
.672 .38346 Mdot
.672 .3836 Mdot
.672 .38447 Mdot
.672 .38461 Mdot
.672 .38462 Mdot
.672 .38485 Mdot
.672 .38496 Mdot
.672 .38497 Mdot
.672 .38503 Mdot
.672 .38515 Mdot
.672 .38516 Mdot
.672 .3854 Mdot
.672 .38551 Mdot
.672 .38552 Mdot
.672 .38565 Mdot
.672 .38573 Mdot
.672 .38577 Mdot
.672 .38577 Mdot
.672 .38588 Mdot
.672 .3859 Mdot
.672 .38593 Mdot
.672 .386 Mdot
.672 .38606 Mdot
.672 .3861 Mdot
.672 .38613 Mdot
.672 .38615 Mdot
.672 .38632 Mdot
.672 .38639 Mdot
.672 .38639 Mdot
.672 .38652 Mdot
.672 .38652 Mdot
.672 .38657 Mdot
.672 .38661 Mdot
.672 .38675 Mdot
.672 .3868 Mdot
.672 .38687 Mdot
.672 .38715 Mdot
.672 .38726 Mdot
.672 .38729 Mdot
.672 .38731 Mdot
.672 .38732 Mdot
.672 .38736 Mdot
.672 .3874 Mdot
.672 .38743 Mdot
.672 .38745 Mdot
.672 .38747 Mdot
.672 .38748 Mdot
.672 .3876 Mdot
.672 .38767 Mdot
.672 .3877 Mdot
.672 .3877 Mdot
.672 .38771 Mdot
.672 .38771 Mdot
.672 .38789 Mdot
.672 .38792 Mdot
.672 .38805 Mdot
.672 .38807 Mdot
.672 .38807 Mdot
.672 .38812 Mdot
.672 .38816 Mdot
.672 .38829 Mdot
.672 .38858 Mdot
.672 .38868 Mdot
.672 .38876 Mdot
.672 .3888 Mdot
.672 .38902 Mdot
.672 .38923 Mdot
.672 .38933 Mdot
.672 .38936 Mdot
.672 .38938 Mdot
.672 .38942 Mdot
.672 .38942 Mdot
.672 .3896 Mdot
.672 .38985 Mdot
.672 .38987 Mdot
.672 .39005 Mdot
.672 .39011 Mdot
.672 .39016 Mdot
.672 .39026 Mdot
.672 .39027 Mdot
.672 .39029 Mdot
.672 .39029 Mdot
.672 .39031 Mdot
.672 .39042 Mdot
.672 .39058 Mdot
.672 .3906 Mdot
.672 .39073 Mdot
.672 .39082 Mdot
.672 .39087 Mdot
.672 .39087 Mdot
.672 .39108 Mdot
.672 .39144 Mdot
.672 .39155 Mdot
.672 .39156 Mdot
.672 .3916 Mdot
.672 .39178 Mdot
.672 .39184 Mdot
.672 .39186 Mdot
.672 .39188 Mdot
.672 .3919 Mdot
.672 .39198 Mdot
.672 .39213 Mdot
.672 .39221 Mdot
.672 .39227 Mdot
.672 .39228 Mdot
.672 .39231 Mdot
.672 .39245 Mdot
.672 .39271 Mdot
.672 .39291 Mdot
.672 .39305 Mdot
.672 .3931 Mdot
.672 .39317 Mdot
.672 .39322 Mdot
.672 .39327 Mdot
.672 .39331 Mdot
.672 .39342 Mdot
.672 .39366 Mdot
.672 .39378 Mdot
.672 .39384 Mdot
.672 .39402 Mdot
.672 .39406 Mdot
.672 .39421 Mdot
.672 .39425 Mdot
.672 .39432 Mdot
.672 .39433 Mdot
.672 .39457 Mdot
.672 .39459 Mdot
.672 .39467 Mdot
.672 .39469 Mdot
.672 .39482 Mdot
.672 .39489 Mdot
.672 .39516 Mdot
.672 .39523 Mdot
.672 .39542 Mdot
.672 .39556 Mdot
.672 .39566 Mdot
.672 .39566 Mdot
.672 .39569 Mdot
.672 .39582 Mdot
.672 .39586 Mdot
.672 .39588 Mdot
.672 .3959 Mdot
.672 .39593 Mdot
.672 .39603 Mdot
.672 .39632 Mdot
.672 .39644 Mdot
.672 .39644 Mdot
.672 .39651 Mdot
.672 .39659 Mdot
.672 .39669 Mdot
.672 .39677 Mdot
.672 .39689 Mdot
.672 .39699 Mdot
.672 .397 Mdot
.672 .39714 Mdot
.672 .39724 Mdot
.672 .39726 Mdot
.672 .39729 Mdot
.672 .39746 Mdot
.672 .39758 Mdot
.672 .39761 Mdot
.672 .3977 Mdot
.672 .39786 Mdot
.672 .398 Mdot
.672 .39807 Mdot
.672 .39818 Mdot
.672 .39821 Mdot
.672 .39825 Mdot
.672 .39832 Mdot
.672 .39833 Mdot
.672 .39838 Mdot
.672 .3984 Mdot
.672 .39841 Mdot
.672 .39842 Mdot
.672 .39843 Mdot
.672 .39849 Mdot
.672 .39865 Mdot
.672 .39882 Mdot
.672 .39884 Mdot
.672 .39892 Mdot
.672 .39892 Mdot
.672 .39906 Mdot
.672 .3991 Mdot
.672 .39913 Mdot
.672 .39917 Mdot
.672 .39919 Mdot
.672 .39926 Mdot
.672 .39928 Mdot
.672 .3994 Mdot
.672 .39947 Mdot
.672 .39961 Mdot
.672 .39967 Mdot
.672 .3997 Mdot
.672 .39971 Mdot
.672 .3999 Mdot
.672 .3999 Mdot
.672 .40054 Mdot
.672 .40078 Mdot
.672 .4009 Mdot
.672 .40092 Mdot
.672 .40093 Mdot
.672 .40102 Mdot
.672 .40117 Mdot
.672 .40128 Mdot
.672 .40141 Mdot
.672 .40145 Mdot
.672 .40167 Mdot
.672 .40175 Mdot
.672 .40175 Mdot
.672 .40191 Mdot
.672 .40193 Mdot
.672 .40193 Mdot
.672 .40193 Mdot
.672 .40197 Mdot
.672 .40197 Mdot
.672 .402 Mdot
.672 .40203 Mdot
.672 .4022 Mdot
.672 .40224 Mdot
.672 .40229 Mdot
.672 .40231 Mdot
.672 .40241 Mdot
.672 .40241 Mdot
.672 .40241 Mdot
.672 .40246 Mdot
.672 .40261 Mdot
.672 .40272 Mdot
.672 .40276 Mdot
.672 .40316 Mdot
.672 .40323 Mdot
.672 .40325 Mdot
.672 .40335 Mdot
.672 .40336 Mdot
.672 .40348 Mdot
.672 .40348 Mdot
.672 .40349 Mdot
.672 .40354 Mdot
.672 .40355 Mdot
.672 .40356 Mdot
.672 .40361 Mdot
.672 .40365 Mdot
.672 .4037 Mdot
.672 .40383 Mdot
.672 .40388 Mdot
.672 .40389 Mdot
.672 .40409 Mdot
.672 .40409 Mdot
.672 .40426 Mdot
.672 .40432 Mdot
.672 .40433 Mdot
.672 .40466 Mdot
.672 .40474 Mdot
.672 .40474 Mdot
.672 .40489 Mdot
.672 .40505 Mdot
.672 .40506 Mdot
.672 .40517 Mdot
.672 .40558 Mdot
.672 .40562 Mdot
.672 .40581 Mdot
.672 .40589 Mdot
.672 .40598 Mdot
.672 .40598 Mdot
.672 .40599 Mdot
.672 .40601 Mdot
.672 .40624 Mdot
.672 .40626 Mdot
.672 .4063 Mdot
.672 .40647 Mdot
.672 .40663 Mdot
.672 .40664 Mdot
.672 .40665 Mdot
.672 .40666 Mdot
.672 .40671 Mdot
.672 .40677 Mdot
.672 .40677 Mdot
.672 .40677 Mdot
.672 .40684 Mdot
.672 .40685 Mdot
.672 .40686 Mdot
.672 .40704 Mdot
.672 .40706 Mdot
.672 .4071 Mdot
.672 .40713 Mdot
.672 .40719 Mdot
.672 .40724 Mdot
.672 .40726 Mdot
.672 .40733 Mdot
.672 .40736 Mdot
.672 .4074 Mdot
.672 .40744 Mdot
.672 .40755 Mdot
.672 .40764 Mdot
.672 .40776 Mdot
.672 .40803 Mdot
.672 .40812 Mdot
.672 .40815 Mdot
.672 .40827 Mdot
.672 .40828 Mdot
.672 .40837 Mdot
.672 .40863 Mdot
.672 .4087 Mdot
.672 .40877 Mdot
.672 .40878 Mdot
.672 .40902 Mdot
.672 .40902 Mdot
.672 .40915 Mdot
.672 .40945 Mdot
.672 .40948 Mdot
.672 .40953 Mdot
.672 .40962 Mdot
.672 .40971 Mdot
.672 .40984 Mdot
.672 .40986 Mdot
.672 .4099 Mdot
.672 .40994 Mdot
.672 .4101 Mdot
.672 .41012 Mdot
.672 .41013 Mdot
.672 .41014 Mdot
.672 .41021 Mdot
.672 .41035 Mdot
.672 .41055 Mdot
.672 .41058 Mdot
.672 .4106 Mdot
.672 .41074 Mdot
.672 .41077 Mdot
.672 .41081 Mdot
.672 .41087 Mdot
.672 .41108 Mdot
.672 .41111 Mdot
.674 .27405 Mdot
.674 .27423 Mdot
.674 .27441 Mdot
.674 .27446 Mdot
.674 .27463 Mdot
.674 .27478 Mdot
.674 .27483 Mdot
.674 .2749 Mdot
.674 .27518 Mdot
.674 .27518 Mdot
.674 .27518 Mdot
.674 .27522 Mdot
.674 .27548 Mdot
.674 .2755 Mdot
.674 .2756 Mdot
.674 .27571 Mdot
.674 .27576 Mdot
.674 .27588 Mdot
.674 .27599 Mdot
.674 .27617 Mdot
.674 .2762 Mdot
.674 .27633 Mdot
.674 .27664 Mdot
.674 .27717 Mdot
.674 .27718 Mdot
.674 .27723 Mdot
.674 .27736 Mdot
.674 .27737 Mdot
.674 .27743 Mdot
.674 .27748 Mdot
.674 .27754 Mdot
.674 .27771 Mdot
.674 .27773 Mdot
.674 .27775 Mdot
.674 .27791 Mdot
.674 .27793 Mdot
.674 .27805 Mdot
.674 .27818 Mdot
.674 .2782 Mdot
.674 .27822 Mdot
.674 .27827 Mdot
.674 .27831 Mdot
.674 .2785 Mdot
.674 .2785 Mdot
.674 .27856 Mdot
.674 .27883 Mdot
.674 .27885 Mdot
.674 .27893 Mdot
.674 .27902 Mdot
.674 .27918 Mdot
.674 .2793 Mdot
.674 .27937 Mdot
.674 .27943 Mdot
.674 .27947 Mdot
.674 .27958 Mdot
.674 .27966 Mdot
.674 .27975 Mdot
.674 .27979 Mdot
.674 .27985 Mdot
.674 .27997 Mdot
.674 .27998 Mdot
.674 .28009 Mdot
.674 .28018 Mdot
.674 .28073 Mdot
.674 .28077 Mdot
.674 .28101 Mdot
.674 .28137 Mdot
.674 .2814 Mdot
.674 .28152 Mdot
.674 .28165 Mdot
.674 .28171 Mdot
.674 .28181 Mdot
.674 .28208 Mdot
.674 .28217 Mdot
.674 .2825 Mdot
.674 .28252 Mdot
.674 .28257 Mdot
.674 .28277 Mdot
.674 .28279 Mdot
.674 .28292 Mdot
.674 .28303 Mdot
.674 .28306 Mdot
.674 .28329 Mdot
.674 .28355 Mdot
.674 .28359 Mdot
.674 .28382 Mdot
.674 .28386 Mdot
.674 .28392 Mdot
.674 .28402 Mdot
.674 .28439 Mdot
.674 .28442 Mdot
.674 .28448 Mdot
.674 .28455 Mdot
.674 .28468 Mdot
.674 .28472 Mdot
.674 .28484 Mdot
.674 .28506 Mdot
.674 .28506 Mdot
.674 .28509 Mdot
.674 .28549 Mdot
.674 .28563 Mdot
.674 .28588 Mdot
.674 .28605 Mdot
.674 .28608 Mdot
.674 .28614 Mdot
.674 .28619 Mdot
.674 .28628 Mdot
.674 .28635 Mdot
.674 .28637 Mdot
.674 .28651 Mdot
.674 .28655 Mdot
.674 .28668 Mdot
.674 .28683 Mdot
.674 .28688 Mdot
.674 .28702 Mdot
.674 .28704 Mdot
.674 .28705 Mdot
.674 .28713 Mdot
.674 .28714 Mdot
.674 .28737 Mdot
.674 .28758 Mdot
.674 .28771 Mdot
.674 .28779 Mdot
.674 .28822 Mdot
.674 .28826 Mdot
.674 .28851 Mdot
.674 .28856 Mdot
.674 .28857 Mdot
.674 .28867 Mdot
.674 .28884 Mdot
.674 .2889 Mdot
.674 .28898 Mdot
.674 .28901 Mdot
.674 .28943 Mdot
.674 .28946 Mdot
.674 .2895 Mdot
.674 .28979 Mdot
.674 .28984 Mdot
.674 .28996 Mdot
.674 .29006 Mdot
.674 .29017 Mdot
.674 .2903 Mdot
.674 .2904 Mdot
.674 .2904 Mdot
.674 .29049 Mdot
.674 .29053 Mdot
.674 .29101 Mdot
.674 .29102 Mdot
.674 .29107 Mdot
.674 .29112 Mdot
.674 .29117 Mdot
.674 .29127 Mdot
.674 .29131 Mdot
.674 .29132 Mdot
.674 .29132 Mdot
.674 .29154 Mdot
.674 .29165 Mdot
.674 .29167 Mdot
.674 .2917 Mdot
.674 .29174 Mdot
.674 .2918 Mdot
.674 .29208 Mdot
.674 .2921 Mdot
.674 .29228 Mdot
.674 .29232 Mdot
.674 .29252 Mdot
.674 .29262 Mdot
.674 .29263 Mdot
.674 .29333 Mdot
.674 .29369 Mdot
.674 .29379 Mdot
.674 .29385 Mdot
.674 .29402 Mdot
.674 .2941 Mdot
.674 .29416 Mdot
.674 .29435 Mdot
.674 .29436 Mdot
.674 .29445 Mdot
.674 .29449 Mdot
.674 .29459 Mdot
.674 .29473 Mdot
.674 .29483 Mdot
.674 .29484 Mdot
.674 .29488 Mdot
.674 .29491 Mdot
.674 .29504 Mdot
.674 .2952 Mdot
.674 .29521 Mdot
.674 .29528 Mdot
.674 .29529 Mdot
.674 .29529 Mdot
.674 .29541 Mdot
.674 .29542 Mdot
.674 .29569 Mdot
.674 .29621 Mdot
.674 .29624 Mdot
.674 .29628 Mdot
.674 .29638 Mdot
.674 .29646 Mdot
.674 .29647 Mdot
.674 .29685 Mdot
.674 .29685 Mdot
.674 .29697 Mdot
.674 .297 Mdot
.674 .29704 Mdot
.674 .29711 Mdot
.674 .29711 Mdot
.674 .29732 Mdot
.674 .29732 Mdot
.674 .29746 Mdot
.674 .2979 Mdot
.674 .29797 Mdot
.674 .29797 Mdot
.674 .29801 Mdot
.674 .29802 Mdot
.674 .29817 Mdot
.674 .29819 Mdot
.674 .29821 Mdot
.674 .29822 Mdot
.674 .29835 Mdot
.674 .29842 Mdot
.674 .29848 Mdot
.674 .29862 Mdot
.674 .29879 Mdot
.674 .29884 Mdot
.674 .29943 Mdot
.674 .29989 Mdot
.674 .29992 Mdot
.674 .29994 Mdot
.674 .29996 Mdot
.674 .30015 Mdot
.674 .30015 Mdot
.674 .30018 Mdot
.674 .30023 Mdot
.674 .30029 Mdot
.674 .30031 Mdot
.674 .30032 Mdot
.674 .30059 Mdot
.674 .3006 Mdot
.674 .30084 Mdot
.674 .3009 Mdot
.674 .30097 Mdot
.674 .30099 Mdot
.674 .30115 Mdot
.674 .30117 Mdot
.674 .30142 Mdot
.674 .30148 Mdot
.674 .30152 Mdot
.674 .30161 Mdot
.674 .30166 Mdot
.674 .30167 Mdot
.674 .30184 Mdot
.674 .30186 Mdot
.674 .30209 Mdot
.674 .30221 Mdot
.674 .30232 Mdot
.674 .30246 Mdot
.674 .3025 Mdot
.674 .30251 Mdot
.674 .30259 Mdot
.674 .30278 Mdot
.674 .3028 Mdot
.674 .30288 Mdot
.674 .30305 Mdot
.674 .30371 Mdot
.674 .30378 Mdot
.674 .30391 Mdot
.674 .30457 Mdot
.674 .30469 Mdot
.674 .30496 Mdot
.674 .30499 Mdot
.674 .305 Mdot
.674 .30519 Mdot
.674 .30554 Mdot
.674 .30563 Mdot
.674 .30596 Mdot
.674 .30598 Mdot
.674 .30649 Mdot
.674 .30652 Mdot
.674 .30661 Mdot
.674 .30667 Mdot
.674 .30673 Mdot
.674 .30677 Mdot
.674 .30683 Mdot
.674 .30697 Mdot
.674 .30717 Mdot
.674 .30721 Mdot
.674 .30736 Mdot
.674 .30737 Mdot
.674 .30738 Mdot
.674 .30746 Mdot
.674 .30762 Mdot
.674 .30764 Mdot
.674 .30773 Mdot
.674 .30779 Mdot
.674 .30783 Mdot
.674 .3079 Mdot
.674 .30793 Mdot
.674 .30794 Mdot
.674 .30823 Mdot
.674 .30849 Mdot
.674 .3088 Mdot
.674 .30886 Mdot
.674 .30887 Mdot
.674 .30901 Mdot
.674 .30903 Mdot
.674 .30903 Mdot
.674 .30919 Mdot
.674 .30923 Mdot
.674 .30943 Mdot
.674 .30945 Mdot
.674 .30965 Mdot
.674 .30984 Mdot
.674 .31006 Mdot
.674 .31014 Mdot
.674 .31036 Mdot
.674 .31065 Mdot
.674 .31068 Mdot
.674 .31074 Mdot
.674 .31081 Mdot
.674 .31092 Mdot
.674 .31099 Mdot
.674 .31156 Mdot
.674 .31162 Mdot
.674 .31176 Mdot
.674 .31186 Mdot
.674 .31187 Mdot
.674 .31206 Mdot
.674 .31208 Mdot
.674 .31219 Mdot
.674 .31237 Mdot
.674 .31238 Mdot
.674 .31247 Mdot
.674 .3127 Mdot
.674 .31283 Mdot
.674 .31293 Mdot
.674 .313 Mdot
.674 .313 Mdot
.674 .31306 Mdot
.674 .31311 Mdot
.674 .31357 Mdot
.674 .31378 Mdot
.674 .31392 Mdot
.674 .31395 Mdot
.674 .31401 Mdot
.674 .31416 Mdot
.674 .31454 Mdot
.674 .31455 Mdot
.674 .31462 Mdot
.674 .31468 Mdot
.674 .31496 Mdot
.674 .31499 Mdot
.674 .31512 Mdot
.674 .31514 Mdot
.674 .31517 Mdot
.674 .31522 Mdot
.674 .31543 Mdot
.674 .31545 Mdot
.674 .31552 Mdot
.674 .31559 Mdot
.674 .3158 Mdot
.674 .3158 Mdot
.674 .31582 Mdot
.674 .31604 Mdot
.674 .31611 Mdot
.674 .31625 Mdot
.674 .31636 Mdot
.674 .31639 Mdot
.674 .31642 Mdot
.674 .31647 Mdot
.674 .31652 Mdot
.674 .31669 Mdot
.674 .31677 Mdot
.674 .31689 Mdot
.674 .31694 Mdot
.674 .31726 Mdot
.674 .3177 Mdot
.674 .31795 Mdot
.674 .3182 Mdot
.674 .31861 Mdot
.674 .31868 Mdot
.674 .31874 Mdot
.674 .31874 Mdot
.674 .31913 Mdot
.674 .31924 Mdot
.674 .31936 Mdot
.674 .31942 Mdot
.674 .31966 Mdot
.674 .31967 Mdot
.674 .31977 Mdot
.674 .31979 Mdot
.674 .3199 Mdot
.674 .31996 Mdot
.674 .32035 Mdot
.674 .32063 Mdot
.674 .32073 Mdot
.674 .3208 Mdot
.674 .32092 Mdot
.674 .32099 Mdot
.674 .32112 Mdot
.674 .32129 Mdot
.674 .32142 Mdot
.674 .32149 Mdot
.674 .32165 Mdot
.674 .32195 Mdot
.674 .32197 Mdot
.674 .32203 Mdot
.674 .32237 Mdot
.674 .32243 Mdot
.674 .32262 Mdot
.674 .32286 Mdot
.674 .3229 Mdot
.674 .3229 Mdot
.674 .32302 Mdot
.674 .32304 Mdot
.674 .32304 Mdot
.674 .32326 Mdot
.674 .32336 Mdot
.674 .32338 Mdot
.674 .32396 Mdot
.674 .324 Mdot
.674 .32415 Mdot
.674 .32419 Mdot
.674 .32434 Mdot
.674 .32465 Mdot
.674 .32484 Mdot
.674 .32485 Mdot
.674 .32494 Mdot
.674 .32517 Mdot
.674 .3254 Mdot
.674 .3254 Mdot
.674 .32545 Mdot
.674 .32556 Mdot
.674 .3261 Mdot
.674 .32617 Mdot
.674 .32653 Mdot
.674 .3266 Mdot
.674 .32675 Mdot
.674 .32761 Mdot
.674 .32778 Mdot
.674 .32797 Mdot
.674 .32799 Mdot
.674 .32821 Mdot
.674 .32831 Mdot
.674 .32839 Mdot
.674 .32855 Mdot
.674 .32869 Mdot
.674 .32889 Mdot
.674 .32898 Mdot
.674 .32908 Mdot
.674 .32921 Mdot
.674 .32972 Mdot
.674 .32988 Mdot
.674 .33003 Mdot
.674 .33007 Mdot
.674 .33055 Mdot
.674 .33066 Mdot
.674 .33067 Mdot
.674 .33101 Mdot
.674 .33108 Mdot
.674 .33117 Mdot
.674 .33121 Mdot
.674 .33124 Mdot
.674 .33149 Mdot
.674 .3317 Mdot
.674 .33173 Mdot
.674 .33203 Mdot
.674 .33207 Mdot
.674 .3321 Mdot
.674 .3324 Mdot
.674 .33252 Mdot
.674 .3326 Mdot
.674 .33271 Mdot
.674 .33272 Mdot
.674 .33296 Mdot
.674 .33306 Mdot
.674 .33308 Mdot
.674 .33404 Mdot
.674 .33461 Mdot
.674 .33484 Mdot
.674 .3349 Mdot
.674 .33522 Mdot
.674 .33543 Mdot
.674 .33564 Mdot
.674 .33574 Mdot
.674 .33593 Mdot
.674 .33611 Mdot
.674 .33614 Mdot
.674 .33662 Mdot
.674 .33669 Mdot
.674 .3367 Mdot
.674 .3367 Mdot
.674 .3372 Mdot
.674 .33733 Mdot
.674 .33742 Mdot
.674 .3377 Mdot
.674 .338 Mdot
.674 .33809 Mdot
.674 .33842 Mdot
.674 .33874 Mdot
.674 .3643 Mdot
.674 .36454 Mdot
.674 .36479 Mdot
.674 .36485 Mdot
.674 .36508 Mdot
.674 .36529 Mdot
.674 .36535 Mdot
.674 .36544 Mdot
.674 .36582 Mdot
.674 .36582 Mdot
.674 .36582 Mdot
.674 .36587 Mdot
.674 .36623 Mdot
.674 .36625 Mdot
.674 .36639 Mdot
.674 .36653 Mdot
.674 .3666 Mdot
.674 .36676 Mdot
.674 .36692 Mdot
.674 .36715 Mdot
.674 .3672 Mdot
.674 .36737 Mdot
.674 .36779 Mdot
.674 .3685 Mdot
.674 .36852 Mdot
.674 .36859 Mdot
.674 .36877 Mdot
.674 .36877 Mdot
.674 .36886 Mdot
.674 .36892 Mdot
.674 .36901 Mdot
.674 .36923 Mdot
.674 .36925 Mdot
.674 .36928 Mdot
.674 .36951 Mdot
.674 .36953 Mdot
.674 .36968 Mdot
.674 .36987 Mdot
.674 .36989 Mdot
.674 .36992 Mdot
.674 .36999 Mdot
.674 .37004 Mdot
.674 .37029 Mdot
.674 .3703 Mdot
.674 .37038 Mdot
.674 .37074 Mdot
.674 .37076 Mdot
.674 .37088 Mdot
.674 .37099 Mdot
.674 .37121 Mdot
.674 .37137 Mdot
.674 .37147 Mdot
.674 .37154 Mdot
.674 .37161 Mdot
.674 .37176 Mdot
.674 .37186 Mdot
.674 .37198 Mdot
.674 .37204 Mdot
.674 .37211 Mdot
.674 .37228 Mdot
.674 .3723 Mdot
.674 .37243 Mdot
.674 .37256 Mdot
.674 .3732 Mdot
.674 .37331 Mdot
.674 .37336 Mdot
.674 .37363 Mdot
.674 .37368 Mdot
.674 .37408 Mdot
.674 .37417 Mdot
.674 .3742 Mdot
.674 .3742 Mdot
.674 .37437 Mdot
.674 .37454 Mdot
.674 .3746 Mdot
.674 .37462 Mdot
.674 .37475 Mdot
.674 .37498 Mdot
.674 .3751 Mdot
.674 .37513 Mdot
.674 .37524 Mdot
.674 .37527 Mdot
.674 .3757 Mdot
.674 .37572 Mdot
.674 .37579 Mdot
.674 .37595 Mdot
.674 .37595 Mdot
.674 .37596 Mdot
.674 .37605 Mdot
.674 .37605 Mdot
.674 .37608 Mdot
.674 .37626 Mdot
.674 .3764 Mdot
.674 .37645 Mdot
.674 .3767 Mdot
.674 .37674 Mdot
.674 .37676 Mdot
.674 .37698 Mdot
.674 .3771 Mdot
.674 .37715 Mdot
.674 .37725 Mdot
.674 .37738 Mdot
.674 .37747 Mdot
.674 .37752 Mdot
.674 .37761 Mdot
.674 .37766 Mdot
.674 .37774 Mdot
.674 .37795 Mdot
.674 .37824 Mdot
.674 .37828 Mdot
.674 .37836 Mdot
.674 .37838 Mdot
.674 .37845 Mdot
.674 .37845 Mdot
.674 .37863 Mdot
.674 .37868 Mdot
.674 .37877 Mdot
.674 .37885 Mdot
.674 .37914 Mdot
.674 .37914 Mdot
.674 .37919 Mdot
.674 .37924 Mdot
.674 .37954 Mdot
.674 .37972 Mdot
.674 .37991 Mdot
.674 .38024 Mdot
.674 .38047 Mdot
.674 .38051 Mdot
.674 .3806 Mdot
.674 .38066 Mdot
.674 .38079 Mdot
.674 .38082 Mdot
.674 .38086 Mdot
.674 .38088 Mdot
.674 .38091 Mdot
.674 .38099 Mdot
.674 .38109 Mdot
.674 .38115 Mdot
.674 .38131 Mdot
.674 .38132 Mdot
.674 .38132 Mdot
.674 .38148 Mdot
.674 .38153 Mdot
.674 .38158 Mdot
.674 .3816 Mdot
.674 .38175 Mdot
.674 .38179 Mdot
.674 .38181 Mdot
.674 .38183 Mdot
.674 .38192 Mdot
.674 .38194 Mdot
.674 .38215 Mdot
.674 .38219 Mdot
.674 .38225 Mdot
.674 .38226 Mdot
.674 .38254 Mdot
.674 .38265 Mdot
.674 .38269 Mdot
.674 .38271 Mdot
.674 .38282 Mdot
.674 .38298 Mdot
.674 .38331 Mdot
.674 .38335 Mdot
.674 .3834 Mdot
.674 .3834 Mdot
.674 .38345 Mdot
.674 .38353 Mdot
.674 .38362 Mdot
.674 .38379 Mdot
.674 .38386 Mdot
.674 .38387 Mdot
.674 .384 Mdot
.674 .38408 Mdot
.674 .38409 Mdot
.674 .38423 Mdot
.674 .38424 Mdot
.674 .38432 Mdot
.674 .38442 Mdot
.674 .38446 Mdot
.674 .38489 Mdot
.674 .38494 Mdot
.674 .38502 Mdot
.674 .38507 Mdot
.674 .38512 Mdot
.674 .38514 Mdot
.674 .38536 Mdot
.674 .38552 Mdot
.674 .38558 Mdot
.674 .38575 Mdot
.674 .38588 Mdot
.674 .38603 Mdot
.674 .38605 Mdot
.674 .3862 Mdot
.674 .38623 Mdot
.674 .38634 Mdot
.674 .38634 Mdot
.674 .38636 Mdot
.674 .38647 Mdot
.674 .38647 Mdot
.674 .38651 Mdot
.674 .38674 Mdot
.674 .38694 Mdot
.674 .38715 Mdot
.674 .38716 Mdot
.674 .38718 Mdot
.674 .38724 Mdot
.674 .38726 Mdot
.674 .38731 Mdot
.674 .38737 Mdot
.674 .38739 Mdot
.674 .38751 Mdot
.674 .38757 Mdot
.674 .38757 Mdot
.674 .38758 Mdot
.674 .3877 Mdot
.674 .38772 Mdot
.674 .38787 Mdot
.674 .38797 Mdot
.674 .38802 Mdot
.674 .38805 Mdot
.674 .38809 Mdot
.674 .38814 Mdot
.674 .38821 Mdot
.674 .38823 Mdot
.674 .38861 Mdot
.674 .38862 Mdot
.674 .38887 Mdot
.674 .38893 Mdot
.674 .38919 Mdot
.674 .38933 Mdot
.674 .38934 Mdot
.674 .38936 Mdot
.674 .38956 Mdot
.674 .38965 Mdot
.674 .39014 Mdot
.674 .39024 Mdot
.674 .39029 Mdot
.674 .39078 Mdot
.674 .3909 Mdot
.674 .39097 Mdot
.674 .39098 Mdot
.674 .39112 Mdot
.674 .39118 Mdot
.674 .39118 Mdot
.674 .39122 Mdot
.674 .39132 Mdot
.674 .3914 Mdot
.674 .39149 Mdot
.674 .39166 Mdot
.674 .39168 Mdot
.674 .3918 Mdot
.674 .39181 Mdot
.674 .39185 Mdot
.674 .39192 Mdot
.674 .39194 Mdot
.674 .39199 Mdot
.674 .39217 Mdot
.674 .39219 Mdot
.674 .39231 Mdot
.674 .39233 Mdot
.674 .39238 Mdot
.674 .39242 Mdot
.674 .39259 Mdot
.674 .39261 Mdot
.674 .3928 Mdot
.674 .39281 Mdot
.674 .39283 Mdot
.674 .39287 Mdot
.674 .39291 Mdot
.674 .39293 Mdot
.674 .39293 Mdot
.674 .39307 Mdot
.674 .39309 Mdot
.674 .3931 Mdot
.674 .39313 Mdot
.674 .39346 Mdot
.674 .3939 Mdot
.674 .39394 Mdot
.674 .39406 Mdot
.674 .39417 Mdot
.674 .39421 Mdot
.674 .39427 Mdot
.674 .39436 Mdot
.674 .39437 Mdot
.674 .39438 Mdot
.674 .3944 Mdot
.674 .39451 Mdot
.674 .39452 Mdot
.674 .39455 Mdot
.674 .39455 Mdot
.674 .3946 Mdot
.674 .39493 Mdot
.674 .39503 Mdot
.674 .39503 Mdot
.674 .39519 Mdot
.674 .39519 Mdot
.674 .39524 Mdot
.674 .39527 Mdot
.674 .39529 Mdot
.674 .39538 Mdot
.674 .39538 Mdot
.674 .39566 Mdot
.674 .39566 Mdot
.674 .39573 Mdot
.674 .3958 Mdot
.674 .39583 Mdot
.674 .39585 Mdot
.674 .39624 Mdot
.674 .39644 Mdot
.674 .39645 Mdot
.674 .39654 Mdot
.674 .39654 Mdot
.674 .39655 Mdot
.674 .39659 Mdot
.674 .39661 Mdot
.674 .39672 Mdot
.674 .39682 Mdot
.674 .39684 Mdot
.674 .39687 Mdot
.674 .39688 Mdot
.674 .39695 Mdot
.674 .39705 Mdot
.674 .39713 Mdot
.674 .39716 Mdot
.674 .39722 Mdot
.674 .39723 Mdot
.674 .39738 Mdot
.674 .39742 Mdot
.674 .39748 Mdot
.674 .39761 Mdot
.674 .39765 Mdot
.674 .39772 Mdot
.674 .39799 Mdot
.674 .39851 Mdot
.674 .39852 Mdot
.674 .39859 Mdot
.674 .39874 Mdot
.674 .39877 Mdot
.674 .39891 Mdot
.674 .39891 Mdot
.674 .39913 Mdot
.674 .39917 Mdot
.674 .3992 Mdot
.674 .39922 Mdot
.674 .39924 Mdot
.674 .39932 Mdot
.674 .39948 Mdot
.674 .39948 Mdot
.674 .39949 Mdot
.674 .39952 Mdot
.674 .39959 Mdot
.674 .39963 Mdot
.674 .39967 Mdot
.674 .3997 Mdot
.674 .39971 Mdot
.674 .40007 Mdot
.674 .40009 Mdot
.674 .40016 Mdot
.674 .40016 Mdot
.674 .40024 Mdot
.674 .40033 Mdot
.674 .40042 Mdot
.674 .40049 Mdot
.674 .40058 Mdot
.674 .40061 Mdot
.674 .40083 Mdot
.674 .40086 Mdot
.674 .40089 Mdot
.674 .4012 Mdot
.674 .40122 Mdot
.674 .40128 Mdot
.674 .40132 Mdot
.674 .40145 Mdot
.674 .40152 Mdot
.674 .40153 Mdot
.674 .40157 Mdot
.674 .40175 Mdot
.674 .40178 Mdot
.674 .4021 Mdot
.674 .40216 Mdot
.674 .40226 Mdot
.674 .40241 Mdot
.674 .40258 Mdot
.674 .40259 Mdot
.674 .40265 Mdot
.674 .40265 Mdot
.674 .40267 Mdot
.674 .40277 Mdot
.674 .40281 Mdot
.674 .40292 Mdot
.674 .40302 Mdot
.674 .40305 Mdot
.674 .40315 Mdot
.674 .40317 Mdot
.674 .40322 Mdot
.674 .40329 Mdot
.674 .40332 Mdot
.674 .40337 Mdot
.674 .40339 Mdot
.674 .40352 Mdot
.674 .4037 Mdot
.674 .4038 Mdot
.674 .4041 Mdot
.674 .40412 Mdot
.674 .40412 Mdot
.674 .40429 Mdot
.674 .40438 Mdot
.674 .4044 Mdot
.674 .4045 Mdot
.674 .40456 Mdot
.674 .4046 Mdot
.674 .40462 Mdot
.674 .4049 Mdot
.674 .40497 Mdot
.674 .40501 Mdot
.674 .40504 Mdot
.674 .40522 Mdot
.674 .40525 Mdot
.674 .40544 Mdot
.674 .40561 Mdot
.674 .40563 Mdot
.674 .40571 Mdot
.674 .40581 Mdot
.674 .40582 Mdot
.674 .40597 Mdot
.674 .40601 Mdot
.674 .40602 Mdot
.674 .40627 Mdot
.674 .40633 Mdot
.674 .40654 Mdot
.674 .40661 Mdot
.674 .40665 Mdot
.674 .40675 Mdot
.674 .40684 Mdot
.674 .40686 Mdot
.674 .40713 Mdot
.674 .40731 Mdot
.674 .40734 Mdot
.674 .40774 Mdot
.674 .40782 Mdot
.674 .40789 Mdot
.674 .4079 Mdot
.674 .40799 Mdot
.674 .40803 Mdot
.674 .40806 Mdot
.674 .40813 Mdot
.674 .40819 Mdot
.674 .40827 Mdot
.674 .40831 Mdot
.674 .40834 Mdot
.674 .4084 Mdot
.674 .40849 Mdot
.674 .40861 Mdot
.674 .40867 Mdot
.674 .40873 Mdot
.674 .40875 Mdot
.674 .40895 Mdot
.674 .40899 Mdot
.674 .409 Mdot
.674 .40913 Mdot
.674 .40916 Mdot
.674 .4092 Mdot
.674 .40921 Mdot
.674 .40923 Mdot
.674 .40933 Mdot
.674 .40942 Mdot
.674 .40943 Mdot
.674 .40955 Mdot
.674 .40957 Mdot
.674 .40958 Mdot
.674 .4097 Mdot
.674 .40975 Mdot
.674 .40978 Mdot
.674 .40983 Mdot
.674 .40983 Mdot
.674 .40993 Mdot
.674 .40997 Mdot
.674 .40998 Mdot
.674 .41037 Mdot
.674 .4106 Mdot
.674 .4107 Mdot
.674 .41072 Mdot
.674 .41085 Mdot
.674 .41094 Mdot
.674 .41103 Mdot
.674 .41106 Mdot
.674 .41114 Mdot
.674 .41122 Mdot
.674 .41123 Mdot
.674 .41143 Mdot
.674 .41145 Mdot
.674 .41146 Mdot
.674 .41146 Mdot
.674 .41166 Mdot
.674 .41172 Mdot
.674 .41175 Mdot
.674 .41186 Mdot
.674 .41199 Mdot
.674 .41202 Mdot
.674 .41216 Mdot
.674 .41229 Mdot
.676 .27316 Mdot
.676 .2732 Mdot
.676 .27321 Mdot
.676 .27329 Mdot
.676 .27333 Mdot
.676 .27346 Mdot
.676 .27381 Mdot
.676 .27387 Mdot
.676 .27391 Mdot
.676 .27396 Mdot
.676 .27404 Mdot
.676 .27407 Mdot
.676 .27418 Mdot
.676 .27419 Mdot
.676 .27426 Mdot
.676 .27427 Mdot
.676 .27505 Mdot
.676 .27533 Mdot
.676 .27546 Mdot
.676 .27549 Mdot
.676 .27562 Mdot
.676 .27571 Mdot
.676 .27574 Mdot
.676 .27574 Mdot
.676 .27592 Mdot
.676 .27617 Mdot
.676 .27629 Mdot
.676 .27633 Mdot
.676 .27636 Mdot
.676 .2765 Mdot
.676 .27675 Mdot
.676 .27677 Mdot
.676 .27695 Mdot
.676 .27722 Mdot
.676 .27725 Mdot
.676 .2773 Mdot
.676 .27731 Mdot
.676 .27737 Mdot
.676 .27745 Mdot
.676 .27771 Mdot
.676 .27783 Mdot
.676 .27794 Mdot
.676 .27808 Mdot
.676 .27808 Mdot
.676 .27817 Mdot
.676 .27845 Mdot
.676 .27876 Mdot
.676 .27877 Mdot
.676 .27879 Mdot
.676 .27881 Mdot
.676 .27889 Mdot
.676 .27891 Mdot
.676 .27895 Mdot
.676 .27915 Mdot
.676 .27922 Mdot
.676 .27926 Mdot
.676 .27929 Mdot
.676 .27931 Mdot
.676 .27943 Mdot
.676 .27943 Mdot
.676 .27945 Mdot
.676 .27951 Mdot
.676 .27957 Mdot
.676 .27979 Mdot
.676 .28005 Mdot
.676 .28025 Mdot
.676 .28037 Mdot
.676 .28038 Mdot
.676 .2804 Mdot
.676 .28061 Mdot
.676 .28078 Mdot
.676 .28085 Mdot
.676 .28099 Mdot
.676 .28101 Mdot
.676 .2811 Mdot
.676 .28118 Mdot
.676 .28119 Mdot
.676 .28137 Mdot
.676 .28166 Mdot
.676 .28182 Mdot
.676 .28201 Mdot
.676 .28205 Mdot
.676 .28207 Mdot
.676 .2821 Mdot
.676 .28218 Mdot
.676 .28225 Mdot
.676 .28236 Mdot
.676 .28237 Mdot
.676 .28257 Mdot
.676 .28259 Mdot
.676 .28295 Mdot
.676 .28296 Mdot
.676 .28302 Mdot
.676 .28318 Mdot
.676 .28397 Mdot
.676 .28403 Mdot
.676 .28424 Mdot
.676 .28442 Mdot
.676 .28451 Mdot
.676 .28465 Mdot
.676 .28467 Mdot
.676 .28468 Mdot
.676 .28481 Mdot
.676 .28483 Mdot
.676 .28484 Mdot
.676 .28522 Mdot
.676 .28525 Mdot
.676 .28527 Mdot
.676 .28529 Mdot
.676 .28534 Mdot
.676 .28542 Mdot
.676 .28545 Mdot
.676 .28546 Mdot
.676 .28556 Mdot
.676 .28579 Mdot
.676 .28583 Mdot
.676 .2859 Mdot
.676 .28599 Mdot
.676 .28603 Mdot
.676 .28607 Mdot
.676 .28621 Mdot
.676 .2863 Mdot
.676 .28677 Mdot
.676 .28688 Mdot
.676 .28694 Mdot
.676 .287 Mdot
.676 .28724 Mdot
.676 .28732 Mdot
.676 .28735 Mdot
.676 .2874 Mdot
.676 .28747 Mdot
.676 .28753 Mdot
.676 .28754 Mdot
.676 .28754 Mdot
.676 .28771 Mdot
.676 .2878 Mdot
.676 .28786 Mdot
.676 .28788 Mdot
.676 .28791 Mdot
.676 .28797 Mdot
.676 .28798 Mdot
.676 .28801 Mdot
.676 .28802 Mdot
.676 .28811 Mdot
.676 .28876 Mdot
.676 .28893 Mdot
.676 .28896 Mdot
.676 .28901 Mdot
.676 .28905 Mdot
.676 .28939 Mdot
.676 .28943 Mdot
.676 .2895 Mdot
.676 .28969 Mdot
.676 .28975 Mdot
.676 .28992 Mdot
.676 .28994 Mdot
.676 .29001 Mdot
.676 .29048 Mdot
.676 .29048 Mdot
.676 .29065 Mdot
.676 .29078 Mdot
.676 .29084 Mdot
.676 .29118 Mdot
.676 .29138 Mdot
.676 .29154 Mdot
.676 .29158 Mdot
.676 .29159 Mdot
.676 .29177 Mdot
.676 .29183 Mdot
.676 .29211 Mdot
.676 .2923 Mdot
.676 .29236 Mdot
.676 .29237 Mdot
.676 .29294 Mdot
.676 .29296 Mdot
.676 .29315 Mdot
.676 .29315 Mdot
.676 .2932 Mdot
.676 .2932 Mdot
.676 .29332 Mdot
.676 .29332 Mdot
.676 .29354 Mdot
.676 .29356 Mdot
.676 .29401 Mdot
.676 .29401 Mdot
.676 .2941 Mdot
.676 .29443 Mdot
.676 .29494 Mdot
.676 .2951 Mdot
.676 .29521 Mdot
.676 .29545 Mdot
.676 .29563 Mdot
.676 .29569 Mdot
.676 .2957 Mdot
.676 .29581 Mdot
.676 .29594 Mdot
.676 .29643 Mdot
.676 .29652 Mdot
.676 .29691 Mdot
.676 .29696 Mdot
.676 .29722 Mdot
.676 .2974 Mdot
.676 .29763 Mdot
.676 .29769 Mdot
.676 .29805 Mdot
.676 .29828 Mdot
.676 .29829 Mdot
.676 .29853 Mdot
.676 .29854 Mdot
.676 .29866 Mdot
.676 .29873 Mdot
.676 .29873 Mdot
.676 .29876 Mdot
.676 .29886 Mdot
.676 .29887 Mdot
.676 .29918 Mdot
.676 .29948 Mdot
.676 .29963 Mdot
.676 .29983 Mdot
.676 .30002 Mdot
.676 .30012 Mdot
.676 .30061 Mdot
.676 .30065 Mdot
.676 .301 Mdot
.676 .30104 Mdot
.676 .30106 Mdot
.676 .30115 Mdot
.676 .30158 Mdot
.676 .30162 Mdot
.676 .30165 Mdot
.676 .30182 Mdot
.676 .30182 Mdot
.676 .30183 Mdot
.676 .3019 Mdot
.676 .30199 Mdot
.676 .30218 Mdot
.676 .30225 Mdot
.676 .3025 Mdot
.676 .30265 Mdot
.676 .30267 Mdot
.676 .30272 Mdot
.676 .30278 Mdot
.676 .30296 Mdot
.676 .30305 Mdot
.676 .30307 Mdot
.676 .30309 Mdot
.676 .3033 Mdot
.676 .30331 Mdot
.676 .30339 Mdot
.676 .30339 Mdot
.676 .3034 Mdot
.676 .30353 Mdot
.676 .30374 Mdot
.676 .30378 Mdot
.676 .30421 Mdot
.676 .30429 Mdot
.676 .30433 Mdot
.676 .30472 Mdot
.676 .30482 Mdot
.676 .30483 Mdot
.676 .30495 Mdot
.676 .3053 Mdot
.676 .30539 Mdot
.676 .30552 Mdot
.676 .30581 Mdot
.676 .30592 Mdot
.676 .30625 Mdot
.676 .30626 Mdot
.676 .30626 Mdot
.676 .30634 Mdot
.676 .30635 Mdot
.676 .30656 Mdot
.676 .30662 Mdot
.676 .307 Mdot
.676 .307 Mdot
.676 .30707 Mdot
.676 .30713 Mdot
.676 .3072 Mdot
.676 .30734 Mdot
.676 .30739 Mdot
.676 .30745 Mdot
.676 .30747 Mdot
.676 .30762 Mdot
.676 .30773 Mdot
.676 .30786 Mdot
.676 .30794 Mdot
.676 .30796 Mdot
.676 .30805 Mdot
.676 .30818 Mdot
.676 .30828 Mdot
.676 .30828 Mdot
.676 .30842 Mdot
.676 .30908 Mdot
.676 .30913 Mdot
.676 .30921 Mdot
.676 .30925 Mdot
.676 .30928 Mdot
.676 .3093 Mdot
.676 .30952 Mdot
.676 .3096 Mdot
.676 .30962 Mdot
.676 .30966 Mdot
.676 .30969 Mdot
.676 .30972 Mdot
.676 .31006 Mdot
.676 .3102 Mdot
.676 .31027 Mdot
.676 .31074 Mdot
.676 .31089 Mdot
.676 .31096 Mdot
.676 .31105 Mdot
.676 .3111 Mdot
.676 .31142 Mdot
.676 .31168 Mdot
.676 .31197 Mdot
.676 .31197 Mdot
.676 .31244 Mdot
.676 .3126 Mdot
.676 .31277 Mdot
.676 .31278 Mdot
.676 .3128 Mdot
.676 .31285 Mdot
.676 .31287 Mdot
.676 .31298 Mdot
.676 .31302 Mdot
.676 .31307 Mdot
.676 .31318 Mdot
.676 .31321 Mdot
.676 .31333 Mdot
.676 .31365 Mdot
.676 .31365 Mdot
.676 .31367 Mdot
.676 .31378 Mdot
.676 .31391 Mdot
.676 .31399 Mdot
.676 .31404 Mdot
.676 .3141 Mdot
.676 .31419 Mdot
.676 .31435 Mdot
.676 .31454 Mdot
.676 .3146 Mdot
.676 .31464 Mdot
.676 .31473 Mdot
.676 .31474 Mdot
.676 .31485 Mdot
.676 .31486 Mdot
.676 .31506 Mdot
.676 .31577 Mdot
.676 .31592 Mdot
.676 .31607 Mdot
.676 .31633 Mdot
.676 .31637 Mdot
.676 .31641 Mdot
.676 .31643 Mdot
.676 .31648 Mdot
.676 .31664 Mdot
.676 .31677 Mdot
.676 .31684 Mdot
.676 .31724 Mdot
.676 .31727 Mdot
.676 .31745 Mdot
.676 .31747 Mdot
.676 .31753 Mdot
.676 .31766 Mdot
.676 .31771 Mdot
.676 .31776 Mdot
.676 .3178 Mdot
.676 .31783 Mdot
.676 .31783 Mdot
.676 .31788 Mdot
.676 .31837 Mdot
.676 .31858 Mdot
.676 .3186 Mdot
.676 .31864 Mdot
.676 .31887 Mdot
.676 .31889 Mdot
.676 .31892 Mdot
.676 .31918 Mdot
.676 .31918 Mdot
.676 .31934 Mdot
.676 .31967 Mdot
.676 .31978 Mdot
.676 .31979 Mdot
.676 .31988 Mdot
.676 .32007 Mdot
.676 .32017 Mdot
.676 .32021 Mdot
.676 .32064 Mdot
.676 .32073 Mdot
.676 .32116 Mdot
.676 .32162 Mdot
.676 .3219 Mdot
.676 .32203 Mdot
.676 .32204 Mdot
.676 .32209 Mdot
.676 .3227 Mdot
.676 .32272 Mdot
.676 .32309 Mdot
.676 .32312 Mdot
.676 .32332 Mdot
.676 .32345 Mdot
.676 .32359 Mdot
.676 .32365 Mdot
.676 .32369 Mdot
.676 .32376 Mdot
.676 .3241 Mdot
.676 .3244 Mdot
.676 .32472 Mdot
.676 .32474 Mdot
.676 .32493 Mdot
.676 .32497 Mdot
.676 .32502 Mdot
.676 .32525 Mdot
.676 .32527 Mdot
.676 .32539 Mdot
.676 .32543 Mdot
.676 .32547 Mdot
.676 .32558 Mdot
.676 .32562 Mdot
.676 .32576 Mdot
.676 .32587 Mdot
.676 .32591 Mdot
.676 .32601 Mdot
.676 .32606 Mdot
.676 .32624 Mdot
.676 .32632 Mdot
.676 .32669 Mdot
.676 .32674 Mdot
.676 .32676 Mdot
.676 .32697 Mdot
.676 .32734 Mdot
.676 .32741 Mdot
.676 .32781 Mdot
.676 .32786 Mdot
.676 .32797 Mdot
.676 .32822 Mdot
.676 .32826 Mdot
.676 .32829 Mdot
.676 .32833 Mdot
.676 .32841 Mdot
.676 .32843 Mdot
.676 .32846 Mdot
.676 .32847 Mdot
.676 .32869 Mdot
.676 .32873 Mdot
.676 .32879 Mdot
.676 .32886 Mdot
.676 .32899 Mdot
.676 .32936 Mdot
.676 .32942 Mdot
.676 .32946 Mdot
.676 .3296 Mdot
.676 .32965 Mdot
.676 .32967 Mdot
.676 .32969 Mdot
.676 .33026 Mdot
.676 .33077 Mdot
.676 .33093 Mdot
.676 .33094 Mdot
.676 .33119 Mdot
.676 .33139 Mdot
.676 .33161 Mdot
.676 .3321 Mdot
.676 .33224 Mdot
.676 .33234 Mdot
.676 .33237 Mdot
.676 .33245 Mdot
.676 .33252 Mdot
.676 .33301 Mdot
.676 .33334 Mdot
.676 .33337 Mdot
.676 .33382 Mdot
.676 .33408 Mdot
.676 .33414 Mdot
.676 .33444 Mdot
.676 .33488 Mdot
.676 .33521 Mdot
.676 .33521 Mdot
.676 .33526 Mdot
.676 .33544 Mdot
.676 .33568 Mdot
.676 .33573 Mdot
.676 .33596 Mdot
.676 .33647 Mdot
.676 .33791 Mdot
.676 .33792 Mdot
.676 .33805 Mdot
.676 .33807 Mdot
.676 .33827 Mdot
.676 .33832 Mdot
.676 .33848 Mdot
.676 .33856 Mdot
.676 .33864 Mdot
.676 .33874 Mdot
.676 .33938 Mdot
.676 .33963 Mdot
.676 .33969 Mdot
.676 .33985 Mdot
.676 .33986 Mdot
.676 .33993 Mdot
.676 .36414 Mdot
.676 .36418 Mdot
.676 .3642 Mdot
.676 .36431 Mdot
.676 .36436 Mdot
.676 .36454 Mdot
.676 .36501 Mdot
.676 .36509 Mdot
.676 .36515 Mdot
.676 .36521 Mdot
.676 .36532 Mdot
.676 .36536 Mdot
.676 .36551 Mdot
.676 .36553 Mdot
.676 .36562 Mdot
.676 .36563 Mdot
.676 .36669 Mdot
.676 .36707 Mdot
.676 .36724 Mdot
.676 .36728 Mdot
.676 .36745 Mdot
.676 .36759 Mdot
.676 .36762 Mdot
.676 .36763 Mdot
.676 .36787 Mdot
.676 .3682 Mdot
.676 .36837 Mdot
.676 .36841 Mdot
.676 .36846 Mdot
.676 .36865 Mdot
.676 .36898 Mdot
.676 .36901 Mdot
.676 .36925 Mdot
.676 .36962 Mdot
.676 .36967 Mdot
.676 .36972 Mdot
.676 .36975 Mdot
.676 .36982 Mdot
.676 .36993 Mdot
.676 .37029 Mdot
.676 .37045 Mdot
.676 .3706 Mdot
.676 .37079 Mdot
.676 .37079 Mdot
.676 .37091 Mdot
.676 .37129 Mdot
.676 .37171 Mdot
.676 .37172 Mdot
.676 .37174 Mdot
.676 .37178 Mdot
.676 .37188 Mdot
.676 .3719 Mdot
.676 .37195 Mdot
.676 .37222 Mdot
.676 .37232 Mdot
.676 .37238 Mdot
.676 .37242 Mdot
.676 .37245 Mdot
.676 .37261 Mdot
.676 .37262 Mdot
.676 .37264 Mdot
.676 .37266 Mdot
.676 .37272 Mdot
.676 .37274 Mdot
.676 .37277 Mdot
.676 .3728 Mdot
.676 .37298 Mdot
.676 .37306 Mdot
.676 .3731 Mdot
.676 .3734 Mdot
.676 .37345 Mdot
.676 .37372 Mdot
.676 .37388 Mdot
.676 .37389 Mdot
.676 .37393 Mdot
.676 .3742 Mdot
.676 .37426 Mdot
.676 .3744 Mdot
.676 .37443 Mdot
.676 .37451 Mdot
.676 .37453 Mdot
.676 .37462 Mdot
.676 .37472 Mdot
.676 .37475 Mdot
.676 .37483 Mdot
.676 .37486 Mdot
.676 .37489 Mdot
.676 .37497 Mdot
.676 .37499 Mdot
.676 .37516 Mdot
.676 .3752 Mdot
.676 .37523 Mdot
.676 .37537 Mdot
.676 .37538 Mdot
.676 .37562 Mdot
.676 .37584 Mdot
.676 .37609 Mdot
.676 .37615 Mdot
.676 .37617 Mdot
.676 .37622 Mdot
.676 .37633 Mdot
.676 .37642 Mdot
.676 .37657 Mdot
.676 .37659 Mdot
.676 .37686 Mdot
.676 .37688 Mdot
.676 .37733 Mdot
.676 .37737 Mdot
.676 .37738 Mdot
.676 .37747 Mdot
.676 .37768 Mdot
.676 .37802 Mdot
.676 .37834 Mdot
.676 .3784 Mdot
.676 .37872 Mdot
.676 .37875 Mdot
.676 .37883 Mdot
.676 .37896 Mdot
.676 .37903 Mdot
.676 .37904 Mdot
.676 .37912 Mdot
.676 .37936 Mdot
.676 .37948 Mdot
.676 .37948 Mdot
.676 .37967 Mdot
.676 .3797 Mdot
.676 .37971 Mdot
.676 .37988 Mdot
.676 .37991 Mdot
.676 .37992 Mdot
.676 .38008 Mdot
.676 .38044 Mdot
.676 .38048 Mdot
.676 .38048 Mdot
.676 .3805 Mdot
.676 .38053 Mdot
.676 .38057 Mdot
.676 .3806 Mdot
.676 .3807 Mdot
.676 .38075 Mdot
.676 .38076 Mdot
.676 .38089 Mdot
.676 .38092 Mdot
.676 .38121 Mdot
.676 .38127 Mdot
.676 .38136 Mdot
.676 .38148 Mdot
.676 .38152 Mdot
.676 .38153 Mdot
.676 .38156 Mdot
.676 .38159 Mdot
.676 .38178 Mdot
.676 .3819 Mdot
.676 .38201 Mdot
.676 .38253 Mdot
.676 .38268 Mdot
.676 .38268 Mdot
.676 .38276 Mdot
.676 .38277 Mdot
.676 .38284 Mdot
.676 .38287 Mdot
.676 .38291 Mdot
.676 .38305 Mdot
.676 .38317 Mdot
.676 .38324 Mdot
.676 .38328 Mdot
.676 .38332 Mdot
.676 .38338 Mdot
.676 .38348 Mdot
.676 .38356 Mdot
.676 .38357 Mdot
.676 .38357 Mdot
.676 .38381 Mdot
.676 .3839 Mdot
.676 .38392 Mdot
.676 .384 Mdot
.676 .38404 Mdot
.676 .38407 Mdot
.676 .38415 Mdot
.676 .38416 Mdot
.676 .3842 Mdot
.676 .38421 Mdot
.676 .38422 Mdot
.676 .38435 Mdot
.676 .38446 Mdot
.676 .38481 Mdot
.676 .38482 Mdot
.676 .38503 Mdot
.676 .38522 Mdot
.676 .38546 Mdot
.676 .3855 Mdot
.676 .38556 Mdot
.676 .38561 Mdot
.676 .38573 Mdot
.676 .38607 Mdot
.676 .38612 Mdot
.676 .38623 Mdot
.676 .38648 Mdot
.676 .3865 Mdot
.676 .38652 Mdot
.676 .38656 Mdot
.676 .38657 Mdot
.676 .38662 Mdot
.676 .38679 Mdot
.676 .38681 Mdot
.676 .38682 Mdot
.676 .38686 Mdot
.676 .38691 Mdot
.676 .38695 Mdot
.676 .38744 Mdot
.676 .38755 Mdot
.676 .38755 Mdot
.676 .38762 Mdot
.676 .38772 Mdot
.676 .38778 Mdot
.676 .3878 Mdot
.676 .38785 Mdot
.676 .38795 Mdot
.676 .38803 Mdot
.676 .38814 Mdot
.676 .38816 Mdot
.676 .3882 Mdot
.676 .38824 Mdot
.676 .38834 Mdot
.676 .38839 Mdot
.676 .38844 Mdot
.676 .38849 Mdot
.676 .38849 Mdot
.676 .38877 Mdot
.676 .38882 Mdot
.676 .38897 Mdot
.676 .38898 Mdot
.676 .38904 Mdot
.676 .38904 Mdot
.676 .38905 Mdot
.676 .38929 Mdot
.676 .38937 Mdot
.676 .38958 Mdot
.676 .38968 Mdot
.676 .38975 Mdot
.676 .39001 Mdot
.676 .3901 Mdot
.676 .39011 Mdot
.676 .39018 Mdot
.676 .39047 Mdot
.676 .39049 Mdot
.676 .39056 Mdot
.676 .39088 Mdot
.676 .3909 Mdot
.676 .39106 Mdot
.676 .39115 Mdot
.676 .39116 Mdot
.676 .39116 Mdot
.676 .39122 Mdot
.676 .39123 Mdot
.676 .39138 Mdot
.676 .39139 Mdot
.676 .39141 Mdot
.676 .39148 Mdot
.676 .39161 Mdot
.676 .39166 Mdot
.676 .39169 Mdot
.676 .39171 Mdot
.676 .39182 Mdot
.676 .39201 Mdot
.676 .39205 Mdot
.676 .3922 Mdot
.676 .39226 Mdot
.676 .39232 Mdot
.676 .39232 Mdot
.676 .39232 Mdot
.676 .39245 Mdot
.676 .39247 Mdot
.676 .3925 Mdot
.676 .39281 Mdot
.676 .39288 Mdot
.676 .3929 Mdot
.676 .39293 Mdot
.676 .39319 Mdot
.676 .39322 Mdot
.676 .39358 Mdot
.676 .39365 Mdot
.676 .39379 Mdot
.676 .39394 Mdot
.676 .39406 Mdot
.676 .39427 Mdot
.676 .39451 Mdot
.676 .39451 Mdot
.676 .39459 Mdot
.676 .39461 Mdot
.676 .39461 Mdot
.676 .39466 Mdot
.676 .39475 Mdot
.676 .39475 Mdot
.676 .39494 Mdot
.676 .39494 Mdot
.676 .39511 Mdot
.676 .39538 Mdot
.676 .39542 Mdot
.676 .39559 Mdot
.676 .39572 Mdot
.676 .39592 Mdot
.676 .39596 Mdot
.676 .39624 Mdot
.676 .39631 Mdot
.676 .39667 Mdot
.676 .39677 Mdot
.676 .39685 Mdot
.676 .39686 Mdot
.676 .3969 Mdot
.676 .39703 Mdot
.676 .39721 Mdot
.676 .39729 Mdot
.676 .39741 Mdot
.676 .39778 Mdot
.676 .39803 Mdot
.676 .3981 Mdot
.676 .3981 Mdot
.676 .39843 Mdot
.676 .39844 Mdot
.676 .39861 Mdot
.676 .39861 Mdot
.676 .3987 Mdot
.676 .3987 Mdot
.676 .39873 Mdot
.676 .39874 Mdot
.676 .39888 Mdot
.676 .39889 Mdot
.676 .39931 Mdot
.676 .39932 Mdot
.676 .39937 Mdot
.676 .39951 Mdot
.676 .39971 Mdot
.676 .39976 Mdot
.676 .39989 Mdot
.676 .39989 Mdot
.676 .39993 Mdot
.676 .40004 Mdot
.676 .40019 Mdot
.676 .40044 Mdot
.676 .40049 Mdot
.676 .40058 Mdot
.676 .40071 Mdot
.676 .40071 Mdot
.676 .40106 Mdot
.676 .40111 Mdot
.676 .40113 Mdot
.676 .40125 Mdot
.676 .4013 Mdot
.676 .40143 Mdot
.676 .40149 Mdot
.676 .40152 Mdot
.676 .40177 Mdot
.676 .4018 Mdot
.676 .40183 Mdot
.676 .40185 Mdot
.676 .40198 Mdot
.676 .40246 Mdot
.676 .40253 Mdot
.676 .40253 Mdot
.676 .40256 Mdot
.676 .40257 Mdot
.676 .40261 Mdot
.676 .40263 Mdot
.676 .40265 Mdot
.676 .40269 Mdot
.676 .40276 Mdot
.676 .40288 Mdot
.676 .40289 Mdot
.676 .40289 Mdot
.676 .40294 Mdot
.676 .40299 Mdot
.676 .40302 Mdot
.676 .40305 Mdot
.676 .40311 Mdot
.676 .40328 Mdot
.676 .40333 Mdot
.676 .40337 Mdot
.676 .40346 Mdot
.676 .4038 Mdot
.676 .40387 Mdot
.676 .40397 Mdot
.676 .404 Mdot
.676 .40403 Mdot
.676 .40409 Mdot
.676 .40415 Mdot
.676 .40418 Mdot
.676 .40435 Mdot
.676 .40442 Mdot
.676 .40443 Mdot
.676 .40446 Mdot
.676 .40451 Mdot
.676 .40455 Mdot
.676 .40457 Mdot
.676 .40458 Mdot
.676 .4046 Mdot
.676 .40488 Mdot
.676 .40489 Mdot
.676 .40491 Mdot
.676 .405 Mdot
.676 .405 Mdot
.676 .40502 Mdot
.676 .40512 Mdot
.676 .40519 Mdot
.676 .40532 Mdot
.676 .40548 Mdot
.676 .40552 Mdot
.676 .40611 Mdot
.676 .40622 Mdot
.676 .40628 Mdot
.676 .40628 Mdot
.676 .40655 Mdot
.676 .40656 Mdot
.676 .40671 Mdot
.676 .40672 Mdot
.676 .4068 Mdot
.676 .40685 Mdot
.676 .40691 Mdot
.676 .40693 Mdot
.676 .40695 Mdot
.676 .40698 Mdot
.676 .40711 Mdot
.676 .40723 Mdot
.676 .40745 Mdot
.676 .40758 Mdot
.676 .40759 Mdot
.676 .40765 Mdot
.676 .40771 Mdot
.676 .40773 Mdot
.676 .40783 Mdot
.676 .40789 Mdot
.676 .40801 Mdot
.676 .40816 Mdot
.676 .40818 Mdot
.676 .40819 Mdot
.676 .40827 Mdot
.676 .40842 Mdot
.676 .40862 Mdot
.676 .40878 Mdot
.676 .40882 Mdot
.676 .40887 Mdot
.676 .40888 Mdot
.676 .40888 Mdot
.676 .40897 Mdot
.676 .40899 Mdot
.676 .40901 Mdot
.676 .40904 Mdot
.676 .40909 Mdot
.676 .40924 Mdot
.676 .40927 Mdot
.676 .40928 Mdot
.676 .40934 Mdot
.676 .40936 Mdot
.676 .40937 Mdot
.676 .40937 Mdot
.676 .40961 Mdot
.676 .40981 Mdot
.676 .40988 Mdot
.676 .40988 Mdot
.676 .40998 Mdot
.676 .41006 Mdot
.676 .41015 Mdot
.676 .41035 Mdot
.676 .41041 Mdot
.676 .41045 Mdot
.676 .41046 Mdot
.676 .41049 Mdot
.676 .41052 Mdot
.676 .41072 Mdot
.676 .41085 Mdot
.676 .41087 Mdot
.676 .41105 Mdot
.676 .41115 Mdot
.676 .41118 Mdot
.676 .4112 Mdot
.676 .4113 Mdot
.676 .41148 Mdot
.676 .41161 Mdot
.676 .41161 Mdot
.676 .41163 Mdot
.676 .4117 Mdot
.676 .4118 Mdot
.676 .41182 Mdot
.676 .41191 Mdot
.676 .41212 Mdot
.676 .4127 Mdot
.676 .41271 Mdot
.676 .41276 Mdot
.676 .41277 Mdot
.676 .41285 Mdot
.676 .41287 Mdot
.676 .41293 Mdot
.676 .41297 Mdot
.676 .413 Mdot
.676 .41304 Mdot
.676 .4133 Mdot
.676 .4134 Mdot
.676 .41342 Mdot
.676 .41349 Mdot
.676 .41349 Mdot
.676 .41352 Mdot
.678 .27252 Mdot
.678 .27271 Mdot
.678 .27279 Mdot
.678 .27293 Mdot
.678 .27314 Mdot
.678 .27317 Mdot
.678 .27342 Mdot
.678 .27343 Mdot
.678 .27357 Mdot
.678 .27412 Mdot
.678 .27429 Mdot
.678 .2743 Mdot
.678 .27469 Mdot
.678 .2749 Mdot
.678 .27505 Mdot
.678 .27512 Mdot
.678 .27515 Mdot
.678 .27516 Mdot
.678 .27529 Mdot
.678 .27542 Mdot
.678 .27565 Mdot
.678 .27574 Mdot
.678 .27593 Mdot
.678 .27597 Mdot
.678 .27627 Mdot
.678 .27628 Mdot
.678 .27653 Mdot
.678 .27675 Mdot
.678 .2771 Mdot
.678 .27735 Mdot
.678 .27759 Mdot
.678 .27785 Mdot
.678 .27787 Mdot
.678 .27799 Mdot
.678 .27799 Mdot
.678 .2781 Mdot
.678 .27827 Mdot
.678 .27841 Mdot
.678 .27849 Mdot
.678 .27889 Mdot
.678 .27894 Mdot
.678 .27912 Mdot
.678 .27916 Mdot
.678 .2792 Mdot
.678 .27922 Mdot
.678 .27937 Mdot
.678 .27941 Mdot
.678 .27942 Mdot
.678 .27945 Mdot
.678 .27947 Mdot
.678 .27952 Mdot
.678 .27953 Mdot
.678 .27953 Mdot
.678 .27969 Mdot
.678 .27971 Mdot
.678 .27984 Mdot
.678 .27984 Mdot
.678 .27989 Mdot
.678 .27994 Mdot
.678 .27994 Mdot
.678 .27999 Mdot
.678 .28038 Mdot
.678 .28067 Mdot
.678 .28071 Mdot
.678 .28086 Mdot
.678 .28089 Mdot
.678 .28089 Mdot
.678 .28101 Mdot
.678 .28107 Mdot
.678 .28118 Mdot
.678 .28153 Mdot
.678 .28155 Mdot
.678 .28159 Mdot
.678 .28183 Mdot
.678 .28185 Mdot
.678 .28195 Mdot
.678 .28201 Mdot
.678 .28203 Mdot
.678 .28204 Mdot
.678 .28212 Mdot
.678 .28228 Mdot
.678 .2823 Mdot
.678 .28233 Mdot
.678 .28234 Mdot
.678 .28244 Mdot
.678 .28247 Mdot
.678 .28259 Mdot
.678 .28265 Mdot
.678 .28275 Mdot
.678 .28276 Mdot
.678 .28284 Mdot
.678 .28301 Mdot
.678 .2832 Mdot
.678 .28322 Mdot
.678 .28328 Mdot
.678 .28336 Mdot
.678 .28345 Mdot
.678 .28348 Mdot
.678 .28367 Mdot
.678 .28369 Mdot
.678 .28422 Mdot
.678 .28485 Mdot
.678 .28495 Mdot
.678 .28495 Mdot
.678 .28499 Mdot
.678 .28507 Mdot
.678 .2852 Mdot
.678 .28523 Mdot
.678 .2853 Mdot
.678 .28532 Mdot
.678 .286 Mdot
.678 .28606 Mdot
.678 .28607 Mdot
.678 .2862 Mdot
.678 .28628 Mdot
.678 .28632 Mdot
.678 .2864 Mdot
.678 .28683 Mdot
.678 .28684 Mdot
.678 .28689 Mdot
.678 .28698 Mdot
.678 .28709 Mdot
.678 .28711 Mdot
.678 .28718 Mdot
.678 .28723 Mdot
.678 .28725 Mdot
.678 .28726 Mdot
.678 .28733 Mdot
.678 .28756 Mdot
.678 .28819 Mdot
.678 .28828 Mdot
.678 .28835 Mdot
.678 .28838 Mdot
.678 .28866 Mdot
.678 .28883 Mdot
.678 .28911 Mdot
.678 .28912 Mdot
.678 .28922 Mdot
.678 .28948 Mdot
.678 .28969 Mdot
.678 .2902 Mdot
.678 .29021 Mdot
.678 .29025 Mdot
.678 .29028 Mdot
.678 .29061 Mdot
.678 .291 Mdot
.678 .29108 Mdot
.678 .29119 Mdot
.678 .29131 Mdot
.678 .29138 Mdot
.678 .29145 Mdot
.678 .29148 Mdot
.678 .29155 Mdot
.678 .29185 Mdot
.678 .29195 Mdot
.678 .29199 Mdot
.678 .29209 Mdot
.678 .29211 Mdot
.678 .29222 Mdot
.678 .29224 Mdot
.678 .29231 Mdot
.678 .29232 Mdot
.678 .29242 Mdot
.678 .29248 Mdot
.678 .29259 Mdot
.678 .29259 Mdot
.678 .29261 Mdot
.678 .29273 Mdot
.678 .29289 Mdot
.678 .29307 Mdot
.678 .29311 Mdot
.678 .29314 Mdot
.678 .2932 Mdot
.678 .29343 Mdot
.678 .29347 Mdot
.678 .29351 Mdot
.678 .29376 Mdot
.678 .29381 Mdot
.678 .2942 Mdot
.678 .29433 Mdot
.678 .29437 Mdot
.678 .29466 Mdot
.678 .29468 Mdot
.678 .29478 Mdot
.678 .29489 Mdot
.678 .29495 Mdot
.678 .29498 Mdot
.678 .295 Mdot
.678 .29503 Mdot
.678 .29518 Mdot
.678 .29521 Mdot
.678 .29526 Mdot
.678 .29531 Mdot
.678 .29536 Mdot
.678 .29542 Mdot
.678 .29552 Mdot
.678 .29561 Mdot
.678 .29562 Mdot
.678 .29571 Mdot
.678 .29604 Mdot
.678 .29606 Mdot
.678 .29608 Mdot
.678 .29618 Mdot
.678 .29626 Mdot
.678 .29679 Mdot
.678 .29702 Mdot
.678 .29708 Mdot
.678 .29713 Mdot
.678 .29716 Mdot
.678 .29719 Mdot
.678 .29722 Mdot
.678 .29726 Mdot
.678 .29734 Mdot
.678 .29737 Mdot
.678 .29739 Mdot
.678 .29742 Mdot
.678 .29772 Mdot
.678 .29779 Mdot
.678 .29803 Mdot
.678 .29819 Mdot
.678 .29821 Mdot
.678 .29833 Mdot
.678 .29838 Mdot
.678 .29859 Mdot
.678 .29867 Mdot
.678 .29873 Mdot
.678 .29876 Mdot
.678 .29881 Mdot
.678 .29886 Mdot
.678 .29894 Mdot
.678 .29899 Mdot
.678 .29929 Mdot
.678 .29933 Mdot
.678 .29936 Mdot
.678 .29943 Mdot
.678 .29953 Mdot
.678 .29974 Mdot
.678 .29992 Mdot
.678 .29996 Mdot
.678 .29997 Mdot
.678 .30036 Mdot
.678 .3005 Mdot
.678 .30056 Mdot
.678 .30056 Mdot
.678 .30081 Mdot
.678 .30096 Mdot
.678 .30097 Mdot
.678 .30106 Mdot
.678 .30153 Mdot
.678 .30157 Mdot
.678 .30161 Mdot
.678 .30172 Mdot
.678 .30177 Mdot
.678 .30208 Mdot
.678 .30214 Mdot
.678 .30222 Mdot
.678 .30262 Mdot
.678 .30264 Mdot
.678 .30267 Mdot
.678 .30269 Mdot
.678 .30276 Mdot
.678 .3028 Mdot
.678 .30288 Mdot
.678 .30322 Mdot
.678 .30352 Mdot
.678 .30373 Mdot
.678 .30376 Mdot
.678 .30377 Mdot
.678 .30397 Mdot
.678 .30402 Mdot
.678 .30407 Mdot
.678 .30417 Mdot
.678 .30419 Mdot
.678 .30425 Mdot
.678 .30426 Mdot
.678 .30427 Mdot
.678 .30436 Mdot
.678 .30441 Mdot
.678 .30441 Mdot
.678 .30445 Mdot
.678 .30451 Mdot
.678 .30452 Mdot
.678 .30465 Mdot
.678 .30467 Mdot
.678 .30469 Mdot
.678 .30487 Mdot
.678 .30493 Mdot
.678 .30497 Mdot
.678 .30503 Mdot
.678 .30513 Mdot
.678 .30555 Mdot
.678 .30558 Mdot
.678 .3056 Mdot
.678 .30567 Mdot
.678 .30577 Mdot
.678 .30577 Mdot
.678 .3058 Mdot
.678 .30584 Mdot
.678 .30586 Mdot
.678 .30594 Mdot
.678 .30597 Mdot
.678 .306 Mdot
.678 .30609 Mdot
.678 .30612 Mdot
.678 .30634 Mdot
.678 .30655 Mdot
.678 .30661 Mdot
.678 .30661 Mdot
.678 .30667 Mdot
.678 .30668 Mdot
.678 .30682 Mdot
.678 .30696 Mdot
.678 .30709 Mdot
.678 .3074 Mdot
.678 .30754 Mdot
.678 .30773 Mdot
.678 .308 Mdot
.678 .30808 Mdot
.678 .30814 Mdot
.678 .30817 Mdot
.678 .30829 Mdot
.678 .30909 Mdot
.678 .30909 Mdot
.678 .30936 Mdot
.678 .30948 Mdot
.678 .30981 Mdot
.678 .30996 Mdot
.678 .31015 Mdot
.678 .31016 Mdot
.678 .31038 Mdot
.678 .31068 Mdot
.678 .31077 Mdot
.678 .31078 Mdot
.678 .31099 Mdot
.678 .31118 Mdot
.678 .31124 Mdot
.678 .31151 Mdot
.678 .31156 Mdot
.678 .31169 Mdot
.678 .31185 Mdot
.678 .31211 Mdot
.678 .31294 Mdot
.678 .31301 Mdot
.678 .31344 Mdot
.678 .31356 Mdot
.678 .31358 Mdot
.678 .31362 Mdot
.678 .31371 Mdot
.678 .31379 Mdot
.678 .31384 Mdot
.678 .31387 Mdot
.678 .31408 Mdot
.678 .31424 Mdot
.678 .31435 Mdot
.678 .31436 Mdot
.678 .31497 Mdot
.678 .31515 Mdot
.678 .31529 Mdot
.678 .31538 Mdot
.678 .31551 Mdot
.678 .31571 Mdot
.678 .31575 Mdot
.678 .31577 Mdot
.678 .31589 Mdot
.678 .31657 Mdot
.678 .31657 Mdot
.678 .31714 Mdot
.678 .31718 Mdot
.678 .31729 Mdot
.678 .31736 Mdot
.678 .31759 Mdot
.678 .3176 Mdot
.678 .31774 Mdot
.678 .31774 Mdot
.678 .31781 Mdot
.678 .31782 Mdot
.678 .31799 Mdot
.678 .31838 Mdot
.678 .31868 Mdot
.678 .31915 Mdot
.678 .31945 Mdot
.678 .3199 Mdot
.678 .32012 Mdot
.678 .32016 Mdot
.678 .32032 Mdot
.678 .32038 Mdot
.678 .32046 Mdot
.678 .32052 Mdot
.678 .32057 Mdot
.678 .32072 Mdot
.678 .32073 Mdot
.678 .32089 Mdot
.678 .32099 Mdot
.678 .32102 Mdot
.678 .32122 Mdot
.678 .32139 Mdot
.678 .32169 Mdot
.678 .32185 Mdot
.678 .32186 Mdot
.678 .32191 Mdot
.678 .32204 Mdot
.678 .32215 Mdot
.678 .32237 Mdot
.678 .32242 Mdot
.678 .32261 Mdot
.678 .32262 Mdot
.678 .32268 Mdot
.678 .32272 Mdot
.678 .32301 Mdot
.678 .32316 Mdot
.678 .32319 Mdot
.678 .32322 Mdot
.678 .32324 Mdot
.678 .32326 Mdot
.678 .32332 Mdot
.678 .32351 Mdot
.678 .32355 Mdot
.678 .32385 Mdot
.678 .32399 Mdot
.678 .32406 Mdot
.678 .32411 Mdot
.678 .32474 Mdot
.678 .32495 Mdot
.678 .32506 Mdot
.678 .32528 Mdot
.678 .32528 Mdot
.678 .32533 Mdot
.678 .32561 Mdot
.678 .32569 Mdot
.678 .32572 Mdot
.678 .32618 Mdot
.678 .32621 Mdot
.678 .32622 Mdot
.678 .32694 Mdot
.678 .32702 Mdot
.678 .32703 Mdot
.678 .32706 Mdot
.678 .32713 Mdot
.678 .32715 Mdot
.678 .32721 Mdot
.678 .32721 Mdot
.678 .32746 Mdot
.678 .32749 Mdot
.678 .32777 Mdot
.678 .32779 Mdot
.678 .3278 Mdot
.678 .32789 Mdot
.678 .32789 Mdot
.678 .32793 Mdot
.678 .32798 Mdot
.678 .328 Mdot
.678 .32807 Mdot
.678 .32835 Mdot
.678 .32835 Mdot
.678 .32838 Mdot
.678 .32847 Mdot
.678 .32854 Mdot
.678 .32861 Mdot
.678 .32886 Mdot
.678 .32896 Mdot
.678 .32926 Mdot
.678 .3297 Mdot
.678 .32985 Mdot
.678 .33009 Mdot
.678 .3304 Mdot
.678 .33061 Mdot
.678 .33062 Mdot
.678 .33084 Mdot
.678 .33087 Mdot
.678 .33134 Mdot
.678 .33179 Mdot
.678 .33226 Mdot
.678 .3329 Mdot
.678 .3333 Mdot
.678 .33376 Mdot
.678 .33377 Mdot
.678 .33432 Mdot
.678 .3344 Mdot
.678 .33475 Mdot
.678 .33491 Mdot
.678 .33533 Mdot
.678 .33558 Mdot
.678 .33581 Mdot
.678 .33584 Mdot
.678 .33588 Mdot
.678 .33603 Mdot
.678 .3363 Mdot
.678 .33667 Mdot
.678 .33739 Mdot
.678 .33741 Mdot
.678 .33772 Mdot
.678 .33874 Mdot
.678 .33899 Mdot
.678 .33901 Mdot
.678 .33947 Mdot
.678 .33952 Mdot
.678 .33992 Mdot
.678 .34017 Mdot
.678 .34032 Mdot
.678 .34067 Mdot
.678 .3643 Mdot
.678 .36456 Mdot
.678 .36466 Mdot
.678 .36485 Mdot
.678 .36515 Mdot
.678 .36518 Mdot
.678 .36552 Mdot
.678 .36553 Mdot
.678 .36572 Mdot
.678 .36647 Mdot
.678 .3667 Mdot
.678 .36671 Mdot
.678 .36725 Mdot
.678 .36752 Mdot
.678 .36772 Mdot
.678 .36783 Mdot
.678 .36786 Mdot
.678 .36788 Mdot
.678 .36805 Mdot
.678 .36823 Mdot
.678 .36854 Mdot
.678 .36866 Mdot
.678 .36892 Mdot
.678 .36898 Mdot
.678 .36939 Mdot
.678 .36939 Mdot
.678 .36974 Mdot
.678 .37003 Mdot
.678 .3705 Mdot
.678 .37085 Mdot
.678 .37118 Mdot
.678 .37153 Mdot
.678 .37155 Mdot
.678 .37171 Mdot
.678 .37171 Mdot
.678 .37187 Mdot
.678 .3721 Mdot
.678 .37228 Mdot
.678 .37239 Mdot
.678 .37271 Mdot
.678 .37294 Mdot
.678 .37301 Mdot
.678 .37319 Mdot
.678 .37324 Mdot
.678 .3733 Mdot
.678 .37336 Mdot
.678 .37338 Mdot
.678 .37338 Mdot
.678 .37359 Mdot
.678 .37364 Mdot
.678 .37365 Mdot
.678 .37369 Mdot
.678 .37372 Mdot
.678 .37372 Mdot
.678 .37379 Mdot
.678 .3738 Mdot
.678 .37381 Mdot
.678 .37402 Mdot
.678 .37404 Mdot
.678 .37422 Mdot
.678 .37423 Mdot
.678 .37427 Mdot
.678 .37429 Mdot
.678 .37433 Mdot
.678 .37436 Mdot
.678 .37436 Mdot
.678 .37442 Mdot
.678 .37496 Mdot
.678 .37496 Mdot
.678 .37498 Mdot
.678 .37533 Mdot
.678 .37535 Mdot
.678 .37541 Mdot
.678 .37561 Mdot
.678 .37564 Mdot
.678 .37565 Mdot
.678 .37581 Mdot
.678 .37589 Mdot
.678 .37605 Mdot
.678 .37651 Mdot
.678 .37654 Mdot
.678 .3766 Mdot
.678 .3767 Mdot
.678 .37692 Mdot
.678 .37695 Mdot
.678 .37709 Mdot
.678 .37714 Mdot
.678 .37715 Mdot
.678 .37716 Mdot
.678 .37719 Mdot
.678 .37721 Mdot
.678 .37732 Mdot
.678 .37754 Mdot
.678 .37757 Mdot
.678 .37761 Mdot
.678 .37762 Mdot
.678 .37776 Mdot
.678 .3778 Mdot
.678 .37795 Mdot
.678 .37804 Mdot
.678 .37813 Mdot
.678 .37817 Mdot
.678 .37818 Mdot
.678 .37829 Mdot
.678 .37852 Mdot
.678 .37864 Mdot
.678 .37879 Mdot
.678 .37881 Mdot
.678 .37889 Mdot
.678 .379 Mdot
.678 .37901 Mdot
.678 .37912 Mdot
.678 .37916 Mdot
.678 .3792 Mdot
.678 .37926 Mdot
.678 .3793 Mdot
.678 .37942 Mdot
.678 .37945 Mdot
.678 .37961 Mdot
.678 .37995 Mdot
.678 .38017 Mdot
.678 .38052 Mdot
.678 .38073 Mdot
.678 .38102 Mdot
.678 .38115 Mdot
.678 .38116 Mdot
.678 .38121 Mdot
.678 .38121 Mdot
.678 .38131 Mdot
.678 .38132 Mdot
.678 .38149 Mdot
.678 .38154 Mdot
.678 .38162 Mdot
.678 .38165 Mdot
.678 .38207 Mdot
.678 .38207 Mdot
.678 .38257 Mdot
.678 .38266 Mdot
.678 .38267 Mdot
.678 .38271 Mdot
.678 .38285 Mdot
.678 .38295 Mdot
.678 .38302 Mdot
.678 .38312 Mdot
.678 .38325 Mdot
.678 .3837 Mdot
.678 .38371 Mdot
.678 .38379 Mdot
.678 .3839 Mdot
.678 .38406 Mdot
.678 .38408 Mdot
.678 .38412 Mdot
.678 .38418 Mdot
.678 .38425 Mdot
.678 .38428 Mdot
.678 .38429 Mdot
.678 .38438 Mdot
.678 .3847 Mdot
.678 .38475 Mdot
.678 .38536 Mdot
.678 .38555 Mdot
.678 .38567 Mdot
.678 .38577 Mdot
.678 .3858 Mdot
.678 .386 Mdot
.678 .38604 Mdot
.678 .38618 Mdot
.678 .38634 Mdot
.678 .38634 Mdot
.678 .38641 Mdot
.678 .38664 Mdot
.678 .3868 Mdot
.678 .38681 Mdot
.678 .38695 Mdot
.678 .38706 Mdot
.678 .3873 Mdot
.678 .38739 Mdot
.678 .38759 Mdot
.678 .38759 Mdot
.678 .38818 Mdot
.678 .38827 Mdot
.678 .38828 Mdot
.678 .38833 Mdot
.678 .38839 Mdot
.678 .38859 Mdot
.678 .38873 Mdot
.678 .38883 Mdot
.678 .38906 Mdot
.678 .38916 Mdot
.678 .38926 Mdot
.678 .38936 Mdot
.678 .38937 Mdot
.678 .38942 Mdot
.678 .38942 Mdot
.678 .38946 Mdot
.678 .38962 Mdot
.678 .38978 Mdot
.678 .3898 Mdot
.678 .38987 Mdot
.678 .38989 Mdot
.678 .38991 Mdot
.678 .38997 Mdot
.678 .38999 Mdot
.678 .39001 Mdot
.678 .39003 Mdot
.678 .39004 Mdot
.678 .39011 Mdot
.678 .39016 Mdot
.678 .39018 Mdot
.678 .3902 Mdot
.678 .39051 Mdot
.678 .39058 Mdot
.678 .39063 Mdot
.678 .39065 Mdot
.678 .3907 Mdot
.678 .39084 Mdot
.678 .39085 Mdot
.678 .39086 Mdot
.678 .39096 Mdot
.678 .39097 Mdot
.678 .39101 Mdot
.678 .39104 Mdot
.678 .39104 Mdot
.678 .39108 Mdot
.678 .39114 Mdot
.678 .39115 Mdot
.678 .39116 Mdot
.678 .3912 Mdot
.678 .39122 Mdot
.678 .39129 Mdot
.678 .39133 Mdot
.678 .39136 Mdot
.678 .39151 Mdot
.678 .39152 Mdot
.678 .39154 Mdot
.678 .3917 Mdot
.678 .39192 Mdot
.678 .39217 Mdot
.678 .39222 Mdot
.678 .39226 Mdot
.678 .39231 Mdot
.678 .39232 Mdot
.678 .39235 Mdot
.678 .39236 Mdot
.678 .39265 Mdot
.678 .39271 Mdot
.678 .39276 Mdot
.678 .39299 Mdot
.678 .39302 Mdot
.678 .3931 Mdot
.678 .39314 Mdot
.678 .39316 Mdot
.678 .39351 Mdot
.678 .39357 Mdot
.678 .39358 Mdot
.678 .3937 Mdot
.678 .39388 Mdot
.678 .39388 Mdot
.678 .39392 Mdot
.678 .39403 Mdot
.678 .39431 Mdot
.678 .39432 Mdot
.678 .39435 Mdot
.678 .39448 Mdot
.678 .39464 Mdot
.678 .39471 Mdot
.678 .39476 Mdot
.678 .39479 Mdot
.678 .39482 Mdot
.678 .39503 Mdot
.678 .39507 Mdot
.678 .39513 Mdot
.678 .39516 Mdot
.678 .39521 Mdot
.678 .39523 Mdot
.678 .39527 Mdot
.678 .39533 Mdot
.678 .39536 Mdot
.678 .39548 Mdot
.678 .39552 Mdot
.678 .39561 Mdot
.678 .39563 Mdot
.678 .39574 Mdot
.678 .39592 Mdot
.678 .39597 Mdot
.678 .3962 Mdot
.678 .39622 Mdot
.678 .39623 Mdot
.678 .39625 Mdot
.678 .39631 Mdot
.678 .39634 Mdot
.678 .39637 Mdot
.678 .39639 Mdot
.678 .39641 Mdot
.678 .39645 Mdot
.678 .39649 Mdot
.678 .39666 Mdot
.678 .39705 Mdot
.678 .39711 Mdot
.678 .39718 Mdot
.678 .3972 Mdot
.678 .39721 Mdot
.678 .39745 Mdot
.678 .39752 Mdot
.678 .39753 Mdot
.678 .3976 Mdot
.678 .39767 Mdot
.678 .39771 Mdot
.678 .39775 Mdot
.678 .39779 Mdot
.678 .39782 Mdot
.678 .39784 Mdot
.678 .39796 Mdot
.678 .39798 Mdot
.678 .39799 Mdot
.678 .39802 Mdot
.678 .39806 Mdot
.678 .39814 Mdot
.678 .39821 Mdot
.678 .39823 Mdot
.678 .39845 Mdot
.678 .39847 Mdot
.678 .39857 Mdot
.678 .39886 Mdot
.678 .39889 Mdot
.678 .39908 Mdot
.678 .3991 Mdot
.678 .39913 Mdot
.678 .3993 Mdot
.678 .39935 Mdot
.678 .39937 Mdot
.678 .3994 Mdot
.678 .39954 Mdot
.678 .39966 Mdot
.678 .39974 Mdot
.678 .39975 Mdot
.678 .39976 Mdot
.678 .39984 Mdot
.678 .39988 Mdot
.678 .39995 Mdot
.678 .39996 Mdot
.678 .40002 Mdot
.678 .40003 Mdot
.678 .40011 Mdot
.678 .40012 Mdot
.678 .4002 Mdot
.678 .40022 Mdot
.678 .4003 Mdot
.678 .40052 Mdot
.678 .40057 Mdot
.678 .40059 Mdot
.678 .40065 Mdot
.678 .4007 Mdot
.678 .40079 Mdot
.678 .40087 Mdot
.678 .40093 Mdot
.678 .40121 Mdot
.678 .40146 Mdot
.678 .40148 Mdot
.678 .40151 Mdot
.678 .40152 Mdot
.678 .40189 Mdot
.678 .40205 Mdot
.678 .40224 Mdot
.678 .40232 Mdot
.678 .40232 Mdot
.678 .40253 Mdot
.678 .40265 Mdot
.678 .40286 Mdot
.678 .40288 Mdot
.678 .40293 Mdot
.678 .403 Mdot
.678 .40346 Mdot
.678 .40364 Mdot
.678 .40368 Mdot
.678 .40369 Mdot
.678 .40371 Mdot
.678 .40374 Mdot
.678 .4038 Mdot
.678 .40381 Mdot
.678 .40389 Mdot
.678 .40396 Mdot
.678 .404 Mdot
.678 .404 Mdot
.678 .40432 Mdot
.678 .40438 Mdot
.678 .40441 Mdot
.678 .40447 Mdot
.678 .40456 Mdot
.678 .40457 Mdot
.678 .40462 Mdot
.678 .40512 Mdot
.678 .40514 Mdot
.678 .40518 Mdot
.678 .40521 Mdot
.678 .4053 Mdot
.678 .40536 Mdot
.678 .40539 Mdot
.678 .40539 Mdot
.678 .40546 Mdot
.678 .40593 Mdot
.678 .40632 Mdot
.678 .40633 Mdot
.678 .40648 Mdot
.678 .4065 Mdot
.678 .40656 Mdot
.678 .40662 Mdot
.678 .40666 Mdot
.678 .40668 Mdot
.678 .40682 Mdot
.678 .40694 Mdot
.678 .40701 Mdot
.678 .40701 Mdot
.678 .40708 Mdot
.678 .40713 Mdot
.678 .40722 Mdot
.678 .40724 Mdot
.678 .40731 Mdot
.678 .40732 Mdot
.678 .40734 Mdot
.678 .40736 Mdot
.678 .40747 Mdot
.678 .40754 Mdot
.678 .40755 Mdot
.678 .40756 Mdot
.678 .4076 Mdot
.678 .40768 Mdot
.678 .40769 Mdot
.678 .40787 Mdot
.678 .4079 Mdot
.678 .40791 Mdot
.678 .40817 Mdot
.678 .40825 Mdot
.678 .40829 Mdot
.678 .40838 Mdot
.678 .40839 Mdot
.678 .4084 Mdot
.678 .40851 Mdot
.678 .40855 Mdot
.678 .40876 Mdot
.678 .40905 Mdot
.678 .40908 Mdot
.678 .40909 Mdot
.678 .40912 Mdot
.678 .40916 Mdot
.678 .40916 Mdot
.678 .40926 Mdot
.678 .40927 Mdot
.678 .40938 Mdot
.678 .40939 Mdot
.678 .4094 Mdot
.678 .40943 Mdot
.678 .40945 Mdot
.678 .40947 Mdot
.678 .40948 Mdot
.678 .4095 Mdot
.678 .40962 Mdot
.678 .40963 Mdot
.678 .40966 Mdot
.678 .40969 Mdot
.678 .40982 Mdot
.678 .40986 Mdot
.678 .41016 Mdot
.678 .41022 Mdot
.678 .41031 Mdot
.678 .41044 Mdot
.678 .41052 Mdot
.678 .41052 Mdot
.678 .41061 Mdot
.678 .41062 Mdot
.678 .41081 Mdot
.678 .411 Mdot
.678 .41118 Mdot
.678 .41144 Mdot
.678 .4116 Mdot
.678 .41179 Mdot
.678 .41179 Mdot
.678 .41201 Mdot
.678 .41204 Mdot
.678 .41218 Mdot
.678 .41225 Mdot
.678 .41242 Mdot
.678 .41251 Mdot
.678 .41261 Mdot
.678 .41262 Mdot
.678 .41264 Mdot
.678 .41269 Mdot
.678 .4128 Mdot
.678 .41295 Mdot
.678 .41324 Mdot
.678 .41325 Mdot
.678 .41338 Mdot
.678 .41378 Mdot
.678 .41388 Mdot
.678 .41389 Mdot
.678 .41408 Mdot
.678 .4141 Mdot
.678 .41426 Mdot
.678 .41436 Mdot
.678 .41441 Mdot
.678 .41456 Mdot
.68 .2716 Mdot
.68 .27164 Mdot
.68 .27168 Mdot
.68 .2719 Mdot
.68 .272 Mdot
.68 .27232 Mdot
.68 .27235 Mdot
.68 .27257 Mdot
.68 .27257 Mdot
.68 .2729 Mdot
.68 .273 Mdot
.68 .27324 Mdot
.68 .27343 Mdot
.68 .2736 Mdot
.68 .27363 Mdot
.68 .27372 Mdot
.68 .27375 Mdot
.68 .27385 Mdot
.68 .27391 Mdot
.68 .27392 Mdot
.68 .27394 Mdot
.68 .27396 Mdot
.68 .27398 Mdot
.68 .27398 Mdot
.68 .27401 Mdot
.68 .27431 Mdot
.68 .27455 Mdot
.68 .27459 Mdot
.68 .27462 Mdot
.68 .27491 Mdot
.68 .27491 Mdot
.68 .275 Mdot
.68 .27501 Mdot
.68 .27504 Mdot
.68 .27518 Mdot
.68 .27552 Mdot
.68 .27563 Mdot
.68 .27621 Mdot
.68 .27627 Mdot
.68 .27629 Mdot
.68 .27658 Mdot
.68 .2766 Mdot
.68 .27675 Mdot
.68 .27719 Mdot
.68 .27746 Mdot
.68 .27747 Mdot
.68 .27748 Mdot
.68 .27753 Mdot
.68 .27783 Mdot
.68 .27792 Mdot
.68 .27819 Mdot
.68 .27834 Mdot
.68 .27844 Mdot
.68 .27849 Mdot
.68 .27861 Mdot
.68 .27866 Mdot
.68 .27892 Mdot
.68 .27894 Mdot
.68 .27936 Mdot
.68 .27944 Mdot
.68 .2795 Mdot
.68 .27955 Mdot
.68 .28015 Mdot
.68 .2803 Mdot
.68 .28033 Mdot
.68 .28036 Mdot
.68 .28074 Mdot
.68 .28074 Mdot
.68 .28103 Mdot
.68 .28104 Mdot
.68 .28133 Mdot
.68 .28145 Mdot
.68 .28148 Mdot
.68 .28152 Mdot
.68 .28172 Mdot
.68 .28177 Mdot
.68 .28181 Mdot
.68 .28184 Mdot
.68 .28192 Mdot
.68 .28203 Mdot
.68 .28221 Mdot
.68 .28269 Mdot
.68 .28288 Mdot
.68 .28294 Mdot
.68 .2831 Mdot
.68 .28326 Mdot
.68 .28326 Mdot
.68 .28338 Mdot
.68 .28344 Mdot
.68 .28348 Mdot
.68 .28399 Mdot
.68 .2841 Mdot
.68 .28419 Mdot
.68 .28441 Mdot
.68 .28469 Mdot
.68 .28533 Mdot
.68 .28552 Mdot
.68 .28558 Mdot
.68 .28558 Mdot
.68 .28601 Mdot
.68 .28602 Mdot
.68 .28623 Mdot
.68 .28632 Mdot
.68 .28666 Mdot
.68 .2867 Mdot
.68 .28694 Mdot
.68 .28697 Mdot
.68 .28714 Mdot
.68 .28728 Mdot
.68 .28735 Mdot
.68 .28802 Mdot
.68 .28802 Mdot
.68 .28811 Mdot
.68 .2882 Mdot
.68 .28828 Mdot
.68 .28831 Mdot
.68 .28836 Mdot
.68 .2887 Mdot
.68 .28887 Mdot
.68 .28897 Mdot
.68 .28898 Mdot
.68 .28928 Mdot
.68 .28929 Mdot
.68 .28945 Mdot
.68 .28955 Mdot
.68 .28976 Mdot
.68 .28976 Mdot
.68 .28994 Mdot
.68 .29006 Mdot
.68 .29006 Mdot
.68 .29007 Mdot
.68 .29041 Mdot
.68 .29044 Mdot
.68 .29053 Mdot
.68 .29057 Mdot
.68 .29078 Mdot
.68 .2908 Mdot
.68 .29113 Mdot
.68 .2912 Mdot
.68 .29121 Mdot
.68 .29157 Mdot
.68 .29162 Mdot
.68 .29174 Mdot
.68 .29195 Mdot
.68 .29202 Mdot
.68 .29212 Mdot
.68 .29231 Mdot
.68 .29236 Mdot
.68 .29238 Mdot
.68 .29243 Mdot
.68 .29251 Mdot
.68 .29253 Mdot
.68 .29269 Mdot
.68 .29281 Mdot
.68 .29289 Mdot
.68 .29315 Mdot
.68 .29315 Mdot
.68 .29328 Mdot
.68 .29347 Mdot
.68 .29348 Mdot
.68 .29355 Mdot
.68 .29387 Mdot
.68 .29389 Mdot
.68 .29394 Mdot
.68 .29411 Mdot
.68 .29414 Mdot
.68 .29415 Mdot
.68 .29424 Mdot
.68 .29443 Mdot
.68 .29446 Mdot
.68 .2946 Mdot
.68 .29467 Mdot
.68 .29478 Mdot
.68 .29504 Mdot
.68 .29514 Mdot
.68 .29518 Mdot
.68 .29523 Mdot
.68 .29529 Mdot
.68 .29537 Mdot
.68 .2954 Mdot
.68 .29546 Mdot
.68 .29548 Mdot
.68 .2956 Mdot
.68 .29565 Mdot
.68 .29566 Mdot
.68 .29575 Mdot
.68 .29579 Mdot
.68 .29592 Mdot
.68 .29595 Mdot
.68 .29596 Mdot
.68 .29597 Mdot
.68 .29601 Mdot
.68 .29604 Mdot
.68 .29605 Mdot
.68 .29608 Mdot
.68 .2961 Mdot
.68 .2961 Mdot
.68 .29617 Mdot
.68 .2962 Mdot
.68 .29621 Mdot
.68 .29626 Mdot
.68 .29629 Mdot
.68 .29632 Mdot
.68 .29638 Mdot
.68 .29639 Mdot
.68 .29641 Mdot
.68 .29643 Mdot
.68 .29646 Mdot
.68 .29648 Mdot
.68 .29662 Mdot
.68 .29662 Mdot
.68 .29665 Mdot
.68 .29671 Mdot
.68 .29672 Mdot
.68 .29677 Mdot
.68 .29682 Mdot
.68 .29685 Mdot
.68 .29687 Mdot
.68 .2969 Mdot
.68 .29695 Mdot
.68 .29715 Mdot
.68 .29719 Mdot
.68 .29726 Mdot
.68 .29728 Mdot
.68 .29739 Mdot
.68 .29744 Mdot
.68 .29744 Mdot
.68 .29745 Mdot
.68 .29754 Mdot
.68 .29759 Mdot
.68 .29776 Mdot
.68 .2978 Mdot
.68 .2978 Mdot
.68 .2979 Mdot
.68 .29797 Mdot
.68 .29811 Mdot
.68 .29816 Mdot
.68 .29822 Mdot
.68 .29831 Mdot
.68 .29836 Mdot
.68 .29839 Mdot
.68 .29858 Mdot
.68 .2988 Mdot
.68 .29883 Mdot
.68 .29907 Mdot
.68 .29925 Mdot
.68 .29939 Mdot
.68 .29945 Mdot
.68 .29964 Mdot
.68 .29971 Mdot
.68 .2998 Mdot
.68 .29981 Mdot
.68 .30006 Mdot
.68 .30023 Mdot
.68 .30024 Mdot
.68 .30029 Mdot
.68 .3006 Mdot
.68 .30065 Mdot
.68 .3007 Mdot
.68 .30075 Mdot
.68 .30111 Mdot
.68 .30122 Mdot
.68 .30131 Mdot
.68 .30133 Mdot
.68 .30146 Mdot
.68 .30148 Mdot
.68 .30183 Mdot
.68 .30184 Mdot
.68 .30207 Mdot
.68 .30207 Mdot
.68 .3022 Mdot
.68 .30255 Mdot
.68 .3027 Mdot
.68 .30282 Mdot
.68 .30293 Mdot
.68 .30322 Mdot
.68 .30326 Mdot
.68 .30341 Mdot
.68 .3035 Mdot
.68 .30353 Mdot
.68 .30363 Mdot
.68 .30389 Mdot
.68 .30399 Mdot
.68 .30405 Mdot
.68 .30415 Mdot
.68 .30426 Mdot
.68 .3043 Mdot
.68 .30452 Mdot
.68 .30468 Mdot
.68 .30489 Mdot
.68 .3049 Mdot
.68 .30492 Mdot
.68 .305 Mdot
.68 .30566 Mdot
.68 .30567 Mdot
.68 .30581 Mdot
.68 .30598 Mdot
.68 .30606 Mdot
.68 .30626 Mdot
.68 .30642 Mdot
.68 .30645 Mdot
.68 .30645 Mdot
.68 .30684 Mdot
.68 .30692 Mdot
.68 .30693 Mdot
.68 .30709 Mdot
.68 .3071 Mdot
.68 .30713 Mdot
.68 .30751 Mdot
.68 .30769 Mdot
.68 .30777 Mdot
.68 .30778 Mdot
.68 .30779 Mdot
.68 .30801 Mdot
.68 .30803 Mdot
.68 .30834 Mdot
.68 .30835 Mdot
.68 .30848 Mdot
.68 .30852 Mdot
.68 .30874 Mdot
.68 .30892 Mdot
.68 .3091 Mdot
.68 .30922 Mdot
.68 .30923 Mdot
.68 .30946 Mdot
.68 .30977 Mdot
.68 .30979 Mdot
.68 .30981 Mdot
.68 .30999 Mdot
.68 .31029 Mdot
.68 .31052 Mdot
.68 .31076 Mdot
.68 .31079 Mdot
.68 .31085 Mdot
.68 .31093 Mdot
.68 .31098 Mdot
.68 .31102 Mdot
.68 .31102 Mdot
.68 .31103 Mdot
.68 .31105 Mdot
.68 .31107 Mdot
.68 .31123 Mdot
.68 .3114 Mdot
.68 .31156 Mdot
.68 .31156 Mdot
.68 .31195 Mdot
.68 .31279 Mdot
.68 .31293 Mdot
.68 .31319 Mdot
.68 .31347 Mdot
.68 .3135 Mdot
.68 .31356 Mdot
.68 .31397 Mdot
.68 .31401 Mdot
.68 .31404 Mdot
.68 .31407 Mdot
.68 .31471 Mdot
.68 .31487 Mdot
.68 .31503 Mdot
.68 .31511 Mdot
.68 .31527 Mdot
.68 .31529 Mdot
.68 .31531 Mdot
.68 .31607 Mdot
.68 .31607 Mdot
.68 .31619 Mdot
.68 .31653 Mdot
.68 .31729 Mdot
.68 .31768 Mdot
.68 .31772 Mdot
.68 .31824 Mdot
.68 .31865 Mdot
.68 .3188 Mdot
.68 .31883 Mdot
.68 .31902 Mdot
.68 .31933 Mdot
.68 .31942 Mdot
.68 .31947 Mdot
.68 .31975 Mdot
.68 .31975 Mdot
.68 .31995 Mdot
.68 .32003 Mdot
.68 .32015 Mdot
.68 .32037 Mdot
.68 .32037 Mdot
.68 .32066 Mdot
.68 .32077 Mdot
.68 .32086 Mdot
.68 .32096 Mdot
.68 .32099 Mdot
.68 .32107 Mdot
.68 .32142 Mdot
.68 .32182 Mdot
.68 .3223 Mdot
.68 .32264 Mdot
.68 .32282 Mdot
.68 .32285 Mdot
.68 .32294 Mdot
.68 .32295 Mdot
.68 .32298 Mdot
.68 .32301 Mdot
.68 .32305 Mdot
.68 .32308 Mdot
.68 .32312 Mdot
.68 .32317 Mdot
.68 .32317 Mdot
.68 .32321 Mdot
.68 .3234 Mdot
.68 .32358 Mdot
.68 .32365 Mdot
.68 .32371 Mdot
.68 .32374 Mdot
.68 .32382 Mdot
.68 .32393 Mdot
.68 .32413 Mdot
.68 .32424 Mdot
.68 .32448 Mdot
.68 .32449 Mdot
.68 .32483 Mdot
.68 .32502 Mdot
.68 .32502 Mdot
.68 .32548 Mdot
.68 .32572 Mdot
.68 .32578 Mdot
.68 .32583 Mdot
.68 .32611 Mdot
.68 .32631 Mdot
.68 .32665 Mdot
.68 .32722 Mdot
.68 .32731 Mdot
.68 .32743 Mdot
.68 .32757 Mdot
.68 .32777 Mdot
.68 .32778 Mdot
.68 .32836 Mdot
.68 .3284 Mdot
.68 .32851 Mdot
.68 .32861 Mdot
.68 .32887 Mdot
.68 .32896 Mdot
.68 .32918 Mdot
.68 .32928 Mdot
.68 .32946 Mdot
.68 .32971 Mdot
.68 .32973 Mdot
.68 .33004 Mdot
.68 .33024 Mdot
.68 .3304 Mdot
.68 .33081 Mdot
.68 .33094 Mdot
.68 .33096 Mdot
.68 .33099 Mdot
.68 .33106 Mdot
.68 .33108 Mdot
.68 .33109 Mdot
.68 .3311 Mdot
.68 .33158 Mdot
.68 .3324 Mdot
.68 .33267 Mdot
.68 .33271 Mdot
.68 .33325 Mdot
.68 .33329 Mdot
.68 .3334 Mdot
.68 .33447 Mdot
.68 .33468 Mdot
.68 .3353 Mdot
.68 .33557 Mdot
.68 .33562 Mdot
.68 .33565 Mdot
.68 .3358 Mdot
.68 .3358 Mdot
.68 .33635 Mdot
.68 .3364 Mdot
.68 .33647 Mdot
.68 .33692 Mdot
.68 .33746 Mdot
.68 .33753 Mdot
.68 .33753 Mdot
.68 .33757 Mdot
.68 .3376 Mdot
.68 .33765 Mdot
.68 .33765 Mdot
.68 .33778 Mdot
.68 .33796 Mdot
.68 .338 Mdot
.68 .33817 Mdot
.68 .33823 Mdot
.68 .33855 Mdot
.68 .3389 Mdot
.68 .33935 Mdot
.68 .33953 Mdot
.68 .34013 Mdot
.68 .34014 Mdot
.68 .34053 Mdot
.68 .34059 Mdot
.68 .34118 Mdot
.68 .34137 Mdot
.68 .34178 Mdot
.68 .34185 Mdot
.68 .34193 Mdot
.68 .36408 Mdot
.68 .36414 Mdot
.68 .36419 Mdot
.68 .36449 Mdot
.68 .36463 Mdot
.68 .36506 Mdot
.68 .3651 Mdot
.68 .36539 Mdot
.68 .3654 Mdot
.68 .36584 Mdot
.68 .36598 Mdot
.68 .36631 Mdot
.68 .36657 Mdot
.68 .3668 Mdot
.68 .36685 Mdot
.68 .36697 Mdot
.68 .367 Mdot
.68 .36713 Mdot
.68 .36723 Mdot
.68 .36723 Mdot
.68 .36726 Mdot
.68 .36729 Mdot
.68 .36731 Mdot
.68 .36732 Mdot
.68 .36736 Mdot
.68 .36776 Mdot
.68 .36809 Mdot
.68 .36814 Mdot
.68 .36818 Mdot
.68 .36858 Mdot
.68 .36858 Mdot
.68 .3687 Mdot
.68 .36872 Mdot
.68 .36875 Mdot
.68 .36895 Mdot
.68 .36941 Mdot
.68 .36956 Mdot
.68 .37035 Mdot
.68 .37043 Mdot
.68 .37046 Mdot
.68 .37085 Mdot
.68 .37088 Mdot
.68 .37108 Mdot
.68 .37169 Mdot
.68 .37204 Mdot
.68 .37205 Mdot
.68 .37206 Mdot
.68 .37207 Mdot
.68 .37212 Mdot
.68 .37215 Mdot
.68 .37216 Mdot
.68 .37225 Mdot
.68 .37255 Mdot
.68 .37268 Mdot
.68 .37282 Mdot
.68 .37305 Mdot
.68 .37307 Mdot
.68 .37324 Mdot
.68 .37338 Mdot
.68 .37345 Mdot
.68 .37361 Mdot
.68 .37368 Mdot
.68 .37387 Mdot
.68 .37395 Mdot
.68 .37403 Mdot
.68 .37406 Mdot
.68 .37448 Mdot
.68 .37449 Mdot
.68 .37464 Mdot
.68 .37474 Mdot
.68 .37483 Mdot
.68 .37489 Mdot
.68 .37532 Mdot
.68 .37556 Mdot
.68 .37571 Mdot
.68 .37591 Mdot
.68 .37595 Mdot
.68 .376 Mdot
.68 .37618 Mdot
.68 .37651 Mdot
.68 .37651 Mdot
.68 .37665 Mdot
.68 .3769 Mdot
.68 .37691 Mdot
.68 .37709 Mdot
.68 .37717 Mdot
.68 .37731 Mdot
.68 .3774 Mdot
.68 .37746 Mdot
.68 .37748 Mdot
.68 .37752 Mdot
.68 .37757 Mdot
.68 .3777 Mdot
.68 .37784 Mdot
.68 .37787 Mdot
.68 .37788 Mdot
.68 .37791 Mdot
.68 .37794 Mdot
.68 .37796 Mdot
.68 .37799 Mdot
.68 .37801 Mdot
.68 .37804 Mdot
.68 .37804 Mdot
.68 .37811 Mdot
.68 .37813 Mdot
.68 .37826 Mdot
.68 .37851 Mdot
.68 .37887 Mdot
.68 .37916 Mdot
.68 .37941 Mdot
.68 .37947 Mdot
.68 .37949 Mdot
.68 .37957 Mdot
.68 .37964 Mdot
.68 .37972 Mdot
.68 .37993 Mdot
.68 .37993 Mdot
.68 .38009 Mdot
.68 .38018 Mdot
.68 .38024 Mdot
.68 .38038 Mdot
.68 .38039 Mdot
.68 .38059 Mdot
.68 .38063 Mdot
.68 .3807 Mdot
.68 .38093 Mdot
.68 .38106 Mdot
.68 .38108 Mdot
.68 .3812 Mdot
.68 .38149 Mdot
.68 .38188 Mdot
.68 .38191 Mdot
.68 .38219 Mdot
.68 .38276 Mdot
.68 .383 Mdot
.68 .38309 Mdot
.68 .38309 Mdot
.68 .38365 Mdot
.68 .38367 Mdot
.68 .38368 Mdot
.68 .3838 Mdot
.68 .38386 Mdot
.68 .38398 Mdot
.68 .38409 Mdot
.68 .38457 Mdot
.68 .38458 Mdot
.68 .38461 Mdot
.68 .38464 Mdot
.68 .38494 Mdot
.68 .38499 Mdot
.68 .38501 Mdot
.68 .38521 Mdot
.68 .3854 Mdot
.68 .3855 Mdot
.68 .38612 Mdot
.68 .38641 Mdot
.68 .38641 Mdot
.68 .38653 Mdot
.68 .38665 Mdot
.68 .38677 Mdot
.68 .38678 Mdot
.68 .3868 Mdot
.68 .38681 Mdot
.68 .38681 Mdot
.68 .38683 Mdot
.68 .38687 Mdot
.68 .38693 Mdot
.68 .38698 Mdot
.68 .387 Mdot
.68 .38717 Mdot
.68 .38734 Mdot
.68 .38757 Mdot
.68 .3877 Mdot
.68 .38771 Mdot
.68 .38773 Mdot
.68 .38795 Mdot
.68 .38812 Mdot
.68 .38813 Mdot
.68 .38822 Mdot
.68 .38835 Mdot
.68 .38848 Mdot
.68 .38864 Mdot
.68 .38868 Mdot
.68 .38877 Mdot
.68 .38878 Mdot
.68 .38901 Mdot
.68 .38902 Mdot
.68 .38918 Mdot
.68 .38919 Mdot
.68 .3892 Mdot
.68 .38926 Mdot
.68 .38939 Mdot
.68 .38967 Mdot
.68 .38969 Mdot
.68 .3897 Mdot
.68 .38981 Mdot
.68 .38982 Mdot
.68 .38988 Mdot
.68 .39016 Mdot
.68 .39017 Mdot
.68 .39019 Mdot
.68 .39031 Mdot
.68 .39045 Mdot
.68 .39051 Mdot
.68 .39064 Mdot
.68 .39074 Mdot
.68 .39075 Mdot
.68 .39123 Mdot
.68 .39129 Mdot
.68 .3913 Mdot
.68 .39132 Mdot
.68 .39147 Mdot
.68 .39158 Mdot
.68 .39175 Mdot
.68 .39178 Mdot
.68 .39186 Mdot
.68 .39193 Mdot
.68 .39198 Mdot
.68 .39205 Mdot
.68 .39224 Mdot
.68 .39232 Mdot
.68 .39234 Mdot
.68 .39241 Mdot
.68 .39251 Mdot
.68 .39254 Mdot
.68 .39276 Mdot
.68 .39284 Mdot
.68 .39292 Mdot
.68 .39304 Mdot
.68 .39329 Mdot
.68 .39339 Mdot
.68 .39339 Mdot
.68 .39356 Mdot
.68 .39356 Mdot
.68 .39382 Mdot
.68 .39383 Mdot
.68 .39393 Mdot
.68 .39394 Mdot
.68 .39401 Mdot
.68 .3941 Mdot
.68 .39436 Mdot
.68 .39439 Mdot
.68 .39443 Mdot
.68 .39446 Mdot
.68 .3947 Mdot
.68 .39474 Mdot
.68 .39474 Mdot
.68 .39486 Mdot
.68 .39505 Mdot
.68 .39505 Mdot
.68 .39512 Mdot
.68 .39517 Mdot
.68 .39531 Mdot
.68 .39536 Mdot
.68 .39546 Mdot
.68 .3956 Mdot
.68 .39577 Mdot
.68 .39579 Mdot
.68 .39595 Mdot
.68 .39609 Mdot
.68 .39611 Mdot
.68 .39615 Mdot
.68 .39622 Mdot
.68 .39626 Mdot
.68 .3963 Mdot
.68 .3964 Mdot
.68 .39645 Mdot
.68 .39653 Mdot
.68 .39653 Mdot
.68 .39656 Mdot
.68 .39668 Mdot
.68 .39671 Mdot
.68 .39678 Mdot
.68 .39679 Mdot
.68 .3968 Mdot
.68 .39683 Mdot
.68 .39691 Mdot
.68 .39692 Mdot
.68 .39698 Mdot
.68 .39701 Mdot
.68 .39715 Mdot
.68 .39719 Mdot
.68 .39721 Mdot
.68 .39723 Mdot
.68 .39725 Mdot
.68 .39728 Mdot
.68 .39732 Mdot
.68 .39733 Mdot
.68 .39737 Mdot
.68 .39739 Mdot
.68 .3974 Mdot
.68 .3975 Mdot
.68 .39751 Mdot
.68 .39754 Mdot
.68 .39755 Mdot
.68 .39756 Mdot
.68 .39757 Mdot
.68 .39761 Mdot
.68 .39764 Mdot
.68 .39766 Mdot
.68 .39769 Mdot
.68 .3977 Mdot
.68 .39772 Mdot
.68 .39778 Mdot
.68 .39778 Mdot
.68 .39779 Mdot
.68 .39782 Mdot
.68 .39782 Mdot
.68 .39784 Mdot
.68 .39787 Mdot
.68 .39788 Mdot
.68 .39789 Mdot
.68 .39791 Mdot
.68 .39801 Mdot
.68 .39804 Mdot
.68 .3981 Mdot
.68 .39811 Mdot
.68 .39815 Mdot
.68 .39823 Mdot
.68 .39825 Mdot
.68 .39829 Mdot
.68 .39832 Mdot
.68 .39837 Mdot
.68 .39842 Mdot
.68 .39845 Mdot
.68 .39848 Mdot
.68 .39856 Mdot
.68 .39875 Mdot
.68 .39883 Mdot
.68 .39888 Mdot
.68 .39898 Mdot
.68 .39901 Mdot
.68 .39915 Mdot
.68 .39921 Mdot
.68 .39922 Mdot
.68 .39924 Mdot
.68 .39936 Mdot
.68 .3994 Mdot
.68 .39942 Mdot
.68 .39965 Mdot
.68 .3997 Mdot
.68 .39971 Mdot
.68 .39985 Mdot
.68 .39994 Mdot
.68 .39994 Mdot
.68 .40014 Mdot
.68 .4002 Mdot
.68 .40029 Mdot
.68 .4004 Mdot
.68 .40042 Mdot
.68 .40048 Mdot
.68 .40051 Mdot
.68 .40053 Mdot
.68 .40057 Mdot
.68 .40071 Mdot
.68 .40077 Mdot
.68 .40083 Mdot
.68 .40098 Mdot
.68 .40107 Mdot
.68 .40111 Mdot
.68 .40137 Mdot
.68 .40138 Mdot
.68 .40143 Mdot
.68 .40167 Mdot
.68 .40169 Mdot
.68 .40184 Mdot
.68 .40187 Mdot
.68 .40194 Mdot
.68 .40196 Mdot
.68 .40221 Mdot
.68 .40222 Mdot
.68 .40222 Mdot
.68 .40231 Mdot
.68 .40244 Mdot
.68 .40244 Mdot
.68 .4026 Mdot
.68 .40267 Mdot
.68 .40279 Mdot
.68 .40279 Mdot
.68 .40302 Mdot
.68 .40302 Mdot
.68 .40309 Mdot
.68 .40321 Mdot
.68 .40347 Mdot
.68 .4035 Mdot
.68 .40353 Mdot
.68 .40359 Mdot
.68 .40365 Mdot
.68 .40372 Mdot
.68 .40372 Mdot
.68 .40421 Mdot
.68 .40426 Mdot
.68 .40436 Mdot
.68 .40449 Mdot
.68 .40451 Mdot
.68 .40469 Mdot
.68 .40472 Mdot
.68 .40497 Mdot
.68 .40503 Mdot
.68 .40519 Mdot
.68 .4052 Mdot
.68 .40551 Mdot
.68 .40551 Mdot
.68 .40556 Mdot
.68 .40569 Mdot
.68 .40617 Mdot
.68 .40638 Mdot
.68 .40654 Mdot
.68 .4066 Mdot
.68 .40668 Mdot
.68 .40706 Mdot
.68 .40708 Mdot
.68 .40713 Mdot
.68 .40722 Mdot
.68 .40722 Mdot
.68 .40733 Mdot
.68 .40746 Mdot
.68 .4075 Mdot
.68 .40764 Mdot
.68 .40799 Mdot
.68 .40812 Mdot
.68 .40821 Mdot
.68 .40826 Mdot
.68 .40829 Mdot
.68 .40831 Mdot
.68 .40835 Mdot
.68 .4085 Mdot
.68 .40853 Mdot
.68 .40855 Mdot
.68 .40864 Mdot
.68 .40885 Mdot
.68 .40886 Mdot
.68 .40907 Mdot
.68 .40907 Mdot
.68 .40935 Mdot
.68 .40937 Mdot
.68 .40939 Mdot
.68 .4095 Mdot
.68 .40995 Mdot
.68 .40998 Mdot
.68 .41003 Mdot
.68 .41008 Mdot
.68 .4104 Mdot
.68 .41041 Mdot
.68 .4106 Mdot
.68 .41064 Mdot
.68 .41072 Mdot
.68 .41076 Mdot
.68 .41084 Mdot
.68 .41094 Mdot
.68 .41114 Mdot
.68 .41121 Mdot
.68 .41143 Mdot
.68 .41147 Mdot
.68 .41148 Mdot
.68 .41149 Mdot
.68 .41168 Mdot
.68 .412 Mdot
.68 .41211 Mdot
.68 .41213 Mdot
.68 .41234 Mdot
.68 .41236 Mdot
.68 .4124 Mdot
.68 .41283 Mdot
.68 .41291 Mdot
.68 .41316 Mdot
.68 .41326 Mdot
.68 .41328 Mdot
.68 .4133 Mdot
.68 .41336 Mdot
.68 .41336 Mdot
.68 .41357 Mdot
.68 .41359 Mdot
.68 .41362 Mdot
.68 .4138 Mdot
.68 .41402 Mdot
.68 .41404 Mdot
.68 .41404 Mdot
.68 .41406 Mdot
.68 .41407 Mdot
.68 .41409 Mdot
.68 .41409 Mdot
.68 .41414 Mdot
.68 .41421 Mdot
.68 .41423 Mdot
.68 .4143 Mdot
.68 .41432 Mdot
.68 .4144 Mdot
.68 .41445 Mdot
.68 .41459 Mdot
.68 .41477 Mdot
.68 .41484 Mdot
.68 .41508 Mdot
.68 .41508 Mdot
.68 .41524 Mdot
.68 .41526 Mdot
.68 .4155 Mdot
.68 .41557 Mdot
.68 .41573 Mdot
.68 .41576 Mdot
.68 .41579 Mdot
.682 .27066 Mdot
.682 .27072 Mdot
.682 .27075 Mdot
.682 .27092 Mdot
.682 .27093 Mdot
.682 .27107 Mdot
.682 .27107 Mdot
.682 .2711 Mdot
.682 .27122 Mdot
.682 .27123 Mdot
.682 .27124 Mdot
.682 .27136 Mdot
.682 .27138 Mdot
.682 .27171 Mdot
.682 .27178 Mdot
.682 .27182 Mdot
.682 .27193 Mdot
.682 .27205 Mdot
.682 .27221 Mdot
.682 .27233 Mdot
.682 .27248 Mdot
.682 .27283 Mdot
.682 .27292 Mdot
.682 .27305 Mdot
.682 .27327 Mdot
.682 .27332 Mdot
.682 .27359 Mdot
.682 .27366 Mdot
.682 .27374 Mdot
.682 .27377 Mdot
.682 .27382 Mdot
.682 .27383 Mdot
.682 .27399 Mdot
.682 .27407 Mdot
.682 .27459 Mdot
.682 .27469 Mdot
.682 .27517 Mdot
.682 .27538 Mdot
.682 .27553 Mdot
.682 .27559 Mdot
.682 .27585 Mdot
.682 .27589 Mdot
.682 .27593 Mdot
.682 .27607 Mdot
.682 .27622 Mdot
.682 .27632 Mdot
.682 .27633 Mdot
.682 .27634 Mdot
.682 .27646 Mdot
.682 .27651 Mdot
.682 .27658 Mdot
.682 .27659 Mdot
.682 .27662 Mdot
.682 .27686 Mdot
.682 .27711 Mdot
.682 .2773 Mdot
.682 .27732 Mdot
.682 .27745 Mdot
.682 .2775 Mdot
.682 .27751 Mdot
.682 .27752 Mdot
.682 .27759 Mdot
.682 .27776 Mdot
.682 .27788 Mdot
.682 .2779 Mdot
.682 .27822 Mdot
.682 .27828 Mdot
.682 .27832 Mdot
.682 .27833 Mdot
.682 .27837 Mdot
.682 .27847 Mdot
.682 .2786 Mdot
.682 .2786 Mdot
.682 .27874 Mdot
.682 .27893 Mdot
.682 .27899 Mdot
.682 .27918 Mdot
.682 .27927 Mdot
.682 .27928 Mdot
.682 .27929 Mdot
.682 .27934 Mdot
.682 .2795 Mdot
.682 .2797 Mdot
.682 .27985 Mdot
.682 .2801 Mdot
.682 .28013 Mdot
.682 .28028 Mdot
.682 .28032 Mdot
.682 .28046 Mdot
.682 .2806 Mdot
.682 .28061 Mdot
.682 .28064 Mdot
.682 .28081 Mdot
.682 .28083 Mdot
.682 .28112 Mdot
.682 .28128 Mdot
.682 .28172 Mdot
.682 .28182 Mdot
.682 .2821 Mdot
.682 .28225 Mdot
.682 .28225 Mdot
.682 .28258 Mdot
.682 .28262 Mdot
.682 .28263 Mdot
.682 .28267 Mdot
.682 .28274 Mdot
.682 .28277 Mdot
.682 .28277 Mdot
.682 .28283 Mdot
.682 .28294 Mdot
.682 .28313 Mdot
.682 .28346 Mdot
.682 .28359 Mdot
.682 .28403 Mdot
.682 .28412 Mdot
.682 .28415 Mdot
.682 .28439 Mdot
.682 .2845 Mdot
.682 .28463 Mdot
.682 .28468 Mdot
.682 .28498 Mdot
.682 .28513 Mdot
.682 .28516 Mdot
.682 .28518 Mdot
.682 .28523 Mdot
.682 .28545 Mdot
.682 .28548 Mdot
.682 .28634 Mdot
.682 .28638 Mdot
.682 .28642 Mdot
.682 .28675 Mdot
.682 .28704 Mdot
.682 .28754 Mdot
.682 .28783 Mdot
.682 .28799 Mdot
.682 .28805 Mdot
.682 .28819 Mdot
.682 .28827 Mdot
.682 .28856 Mdot
.682 .28865 Mdot
.682 .28867 Mdot
.682 .28872 Mdot
.682 .28882 Mdot
.682 .28915 Mdot
.682 .28946 Mdot
.682 .28962 Mdot
.682 .28966 Mdot
.682 .28987 Mdot
.682 .29031 Mdot
.682 .29038 Mdot
.682 .29052 Mdot
.682 .29057 Mdot
.682 .29062 Mdot
.682 .29091 Mdot
.682 .29092 Mdot
.682 .29109 Mdot
.682 .29111 Mdot
.682 .29119 Mdot
.682 .29121 Mdot
.682 .29126 Mdot
.682 .29132 Mdot
.682 .29136 Mdot
.682 .29144 Mdot
.682 .29148 Mdot
.682 .29158 Mdot
.682 .29159 Mdot
.682 .29163 Mdot
.682 .29177 Mdot
.682 .29205 Mdot
.682 .29256 Mdot
.682 .29259 Mdot
.682 .29274 Mdot
.682 .29289 Mdot
.682 .2929 Mdot
.682 .29291 Mdot
.682 .29343 Mdot
.682 .29358 Mdot
.682 .29366 Mdot
.682 .29387 Mdot
.682 .29395 Mdot
.682 .29419 Mdot
.682 .2944 Mdot
.682 .29445 Mdot
.682 .29447 Mdot
.682 .29456 Mdot
.682 .29468 Mdot
.682 .29475 Mdot
.682 .29513 Mdot
.682 .29558 Mdot
.682 .29628 Mdot
.682 .29683 Mdot
.682 .29687 Mdot
.682 .29688 Mdot
.682 .29719 Mdot
.682 .29772 Mdot
.682 .2978 Mdot
.682 .2979 Mdot
.682 .29843 Mdot
.682 .29848 Mdot
.682 .29855 Mdot
.682 .29857 Mdot
.682 .2986 Mdot
.682 .29863 Mdot
.682 .29878 Mdot
.682 .29894 Mdot
.682 .29897 Mdot
.682 .29907 Mdot
.682 .29911 Mdot
.682 .29946 Mdot
.682 .29948 Mdot
.682 .29957 Mdot
.682 .29973 Mdot
.682 .29991 Mdot
.682 .3 Mdot
.682 .30005 Mdot
.682 .30025 Mdot
.682 .30036 Mdot
.682 .30044 Mdot
.682 .3006 Mdot
.682 .30087 Mdot
.682 .30122 Mdot
.682 .30172 Mdot
.682 .30184 Mdot
.682 .30187 Mdot
.682 .30188 Mdot
.682 .30216 Mdot
.682 .30229 Mdot
.682 .30242 Mdot
.682 .30243 Mdot
.682 .30249 Mdot
.682 .30297 Mdot
.682 .30316 Mdot
.682 .30318 Mdot
.682 .30321 Mdot
.682 .30324 Mdot
.682 .30344 Mdot
.682 .30352 Mdot
.682 .30397 Mdot
.682 .30405 Mdot
.682 .3042 Mdot
.682 .30422 Mdot
.682 .30431 Mdot
.682 .30432 Mdot
.682 .30441 Mdot
.682 .3045 Mdot
.682 .30458 Mdot
.682 .30473 Mdot
.682 .30481 Mdot
.682 .30492 Mdot
.682 .305 Mdot
.682 .30503 Mdot
.682 .30504 Mdot
.682 .30504 Mdot
.682 .3052 Mdot
.682 .30523 Mdot
.682 .30553 Mdot
.682 .30555 Mdot
.682 .30555 Mdot
.682 .30557 Mdot
.682 .30586 Mdot
.682 .30599 Mdot
.682 .3061 Mdot
.682 .30621 Mdot
.682 .30634 Mdot
.682 .30649 Mdot
.682 .30649 Mdot
.682 .30653 Mdot
.682 .30655 Mdot
.682 .30663 Mdot
.682 .30668 Mdot
.682 .30676 Mdot
.682 .30684 Mdot
.682 .30725 Mdot
.682 .3075 Mdot
.682 .30788 Mdot
.682 .30797 Mdot
.682 .30797 Mdot
.682 .30802 Mdot
.682 .30827 Mdot
.682 .30846 Mdot
.682 .30884 Mdot
.682 .30905 Mdot
.682 .30928 Mdot
.682 .3093 Mdot
.682 .30936 Mdot
.682 .30937 Mdot
.682 .30945 Mdot
.682 .30953 Mdot
.682 .30953 Mdot
.682 .30964 Mdot
.682 .30972 Mdot
.682 .30977 Mdot
.682 .30994 Mdot
.682 .30996 Mdot
.682 .31003 Mdot
.682 .31029 Mdot
.682 .31033 Mdot
.682 .3104 Mdot
.682 .31047 Mdot
.682 .31062 Mdot
.682 .3107 Mdot
.682 .31089 Mdot
.682 .311 Mdot
.682 .31115 Mdot
.682 .3113 Mdot
.682 .31133 Mdot
.682 .3114 Mdot
.682 .31155 Mdot
.682 .31184 Mdot
.682 .31226 Mdot
.682 .31234 Mdot
.682 .31237 Mdot
.682 .31251 Mdot
.682 .31253 Mdot
.682 .31277 Mdot
.682 .31277 Mdot
.682 .31293 Mdot
.682 .3133 Mdot
.682 .31337 Mdot
.682 .3134 Mdot
.682 .31341 Mdot
.682 .31344 Mdot
.682 .3136 Mdot
.682 .31361 Mdot
.682 .31379 Mdot
.682 .31392 Mdot
.682 .31399 Mdot
.682 .31399 Mdot
.682 .31407 Mdot
.682 .3143 Mdot
.682 .31479 Mdot
.682 .31492 Mdot
.682 .31507 Mdot
.682 .31567 Mdot
.682 .31572 Mdot
.682 .31595 Mdot
.682 .31613 Mdot
.682 .31616 Mdot
.682 .31623 Mdot
.682 .31626 Mdot
.682 .31632 Mdot
.682 .3166 Mdot
.682 .31667 Mdot
.682 .31716 Mdot
.682 .31726 Mdot
.682 .31742 Mdot
.682 .3175 Mdot
.682 .31769 Mdot
.682 .31815 Mdot
.682 .31819 Mdot
.682 .31837 Mdot
.682 .31907 Mdot
.682 .31919 Mdot
.682 .3194 Mdot
.682 .31943 Mdot
.682 .32005 Mdot
.682 .3204 Mdot
.682 .3206 Mdot
.682 .3207 Mdot
.682 .32071 Mdot
.682 .32077 Mdot
.682 .32089 Mdot
.682 .32097 Mdot
.682 .321 Mdot
.682 .32107 Mdot
.682 .32122 Mdot
.682 .32151 Mdot
.682 .32167 Mdot
.682 .32168 Mdot
.682 .32196 Mdot
.682 .32204 Mdot
.682 .32209 Mdot
.682 .32224 Mdot
.682 .32237 Mdot
.682 .32248 Mdot
.682 .32263 Mdot
.682 .32267 Mdot
.682 .32287 Mdot
.682 .32349 Mdot
.682 .32379 Mdot
.682 .32382 Mdot
.682 .32398 Mdot
.682 .32431 Mdot
.682 .32436 Mdot
.682 .32467 Mdot
.682 .32472 Mdot
.682 .32474 Mdot
.682 .32476 Mdot
.682 .32501 Mdot
.682 .32521 Mdot
.682 .32526 Mdot
.682 .32535 Mdot
.682 .32549 Mdot
.682 .32562 Mdot
.682 .32568 Mdot
.682 .32615 Mdot
.682 .32642 Mdot
.682 .32672 Mdot
.682 .32679 Mdot
.682 .32709 Mdot
.682 .32719 Mdot
.682 .3272 Mdot
.682 .32722 Mdot
.682 .32724 Mdot
.682 .32739 Mdot
.682 .32767 Mdot
.682 .32775 Mdot
.682 .32786 Mdot
.682 .3282 Mdot
.682 .3282 Mdot
.682 .32846 Mdot
.682 .32848 Mdot
.682 .32864 Mdot
.682 .32871 Mdot
.682 .3289 Mdot
.682 .32898 Mdot
.682 .32898 Mdot
.682 .329 Mdot
.682 .32906 Mdot
.682 .32913 Mdot
.682 .32917 Mdot
.682 .32939 Mdot
.682 .32977 Mdot
.682 .3298 Mdot
.682 .33004 Mdot
.682 .33035 Mdot
.682 .33048 Mdot
.682 .33049 Mdot
.682 .33052 Mdot
.682 .33053 Mdot
.682 .33061 Mdot
.682 .33062 Mdot
.682 .33085 Mdot
.682 .33088 Mdot
.682 .33102 Mdot
.682 .33104 Mdot
.682 .33108 Mdot
.682 .33124 Mdot
.682 .33149 Mdot
.682 .33158 Mdot
.682 .33162 Mdot
.682 .3317 Mdot
.682 .33208 Mdot
.682 .33212 Mdot
.682 .33214 Mdot
.682 .33222 Mdot
.682 .33223 Mdot
.682 .33235 Mdot
.682 .33244 Mdot
.682 .33268 Mdot
.682 .33269 Mdot
.682 .3327 Mdot
.682 .33272 Mdot
.682 .3328 Mdot
.682 .3329 Mdot
.682 .33301 Mdot
.682 .33318 Mdot
.682 .33344 Mdot
.682 .33351 Mdot
.682 .33359 Mdot
.682 .33406 Mdot
.682 .33418 Mdot
.682 .33445 Mdot
.682 .33485 Mdot
.682 .33574 Mdot
.682 .33592 Mdot
.682 .3369 Mdot
.682 .33705 Mdot
.682 .33734 Mdot
.682 .33736 Mdot
.682 .33745 Mdot
.682 .33752 Mdot
.682 .33766 Mdot
.682 .33779 Mdot
.682 .33829 Mdot
.682 .33838 Mdot
.682 .3388 Mdot
.682 .33904 Mdot
.682 .33919 Mdot
.682 .33985 Mdot
.682 .34013 Mdot
.682 .34036 Mdot
.682 .34065 Mdot
.682 .34089 Mdot
.682 .34108 Mdot
.682 .34115 Mdot
.682 .34129 Mdot
.682 .3419 Mdot
.682 .34195 Mdot
.682 .34217 Mdot
.682 .34218 Mdot
.682 .3422 Mdot
.682 .34242 Mdot
.682 .34247 Mdot
.682 .34249 Mdot
.682 .34274 Mdot
.682 .34276 Mdot
.682 .34306 Mdot
.682 .34312 Mdot
.682 .34323 Mdot
.682 .36383 Mdot
.682 .36391 Mdot
.682 .36395 Mdot
.682 .36418 Mdot
.682 .36419 Mdot
.682 .36438 Mdot
.682 .36439 Mdot
.682 .36443 Mdot
.682 .36459 Mdot
.682 .3646 Mdot
.682 .36461 Mdot
.682 .36477 Mdot
.682 .36481 Mdot
.682 .36526 Mdot
.682 .36536 Mdot
.682 .36541 Mdot
.682 .36555 Mdot
.682 .36572 Mdot
.682 .36593 Mdot
.682 .3661 Mdot
.682 .36631 Mdot
.682 .36679 Mdot
.682 .3669 Mdot
.682 .36708 Mdot
.682 .36738 Mdot
.682 .36745 Mdot
.682 .36782 Mdot
.682 .36792 Mdot
.682 .36802 Mdot
.682 .36807 Mdot
.682 .36813 Mdot
.682 .36815 Mdot
.682 .36836 Mdot
.682 .36847 Mdot
.682 .36919 Mdot
.682 .36932 Mdot
.682 .36997 Mdot
.682 .37027 Mdot
.682 .37047 Mdot
.682 .37055 Mdot
.682 .3709 Mdot
.682 .37096 Mdot
.682 .37101 Mdot
.682 .3712 Mdot
.682 .37132 Mdot
.682 .3714 Mdot
.682 .37147 Mdot
.682 .37154 Mdot
.682 .37155 Mdot
.682 .37156 Mdot
.682 .37157 Mdot
.682 .37174 Mdot
.682 .3718 Mdot
.682 .3719 Mdot
.682 .37191 Mdot
.682 .37196 Mdot
.682 .37197 Mdot
.682 .372 Mdot
.682 .37228 Mdot
.682 .37234 Mdot
.682 .37237 Mdot
.682 .37244 Mdot
.682 .37262 Mdot
.682 .37274 Mdot
.682 .37277 Mdot
.682 .37278 Mdot
.682 .37288 Mdot
.682 .37291 Mdot
.682 .37308 Mdot
.682 .37308 Mdot
.682 .37314 Mdot
.682 .37315 Mdot
.682 .37317 Mdot
.682 .37318 Mdot
.682 .37327 Mdot
.682 .3735 Mdot
.682 .37368 Mdot
.682 .3737 Mdot
.682 .37398 Mdot
.682 .37414 Mdot
.682 .37417 Mdot
.682 .37422 Mdot
.682 .37426 Mdot
.682 .37428 Mdot
.682 .37428 Mdot
.682 .37434 Mdot
.682 .37448 Mdot
.682 .37453 Mdot
.682 .37465 Mdot
.682 .37466 Mdot
.682 .37485 Mdot
.682 .37485 Mdot
.682 .3751 Mdot
.682 .37518 Mdot
.682 .37524 Mdot
.682 .37545 Mdot
.682 .37556 Mdot
.682 .37557 Mdot
.682 .37558 Mdot
.682 .37559 Mdot
.682 .37567 Mdot
.682 .37588 Mdot
.682 .37593 Mdot
.682 .37616 Mdot
.682 .37635 Mdot
.682 .37669 Mdot
.682 .37674 Mdot
.682 .37683 Mdot
.682 .37694 Mdot
.682 .37701 Mdot
.682 .37704 Mdot
.682 .37719 Mdot
.682 .37737 Mdot
.682 .37739 Mdot
.682 .3774 Mdot
.682 .37743 Mdot
.682 .37766 Mdot
.682 .3777 Mdot
.682 .37794 Mdot
.682 .37806 Mdot
.682 .37809 Mdot
.682 .3783 Mdot
.682 .37876 Mdot
.682 .37891 Mdot
.682 .37893 Mdot
.682 .37904 Mdot
.682 .37912 Mdot
.682 .37922 Mdot
.682 .37933 Mdot
.682 .37937 Mdot
.682 .37942 Mdot
.682 .37963 Mdot
.682 .37963 Mdot
.682 .37975 Mdot
.682 .37997 Mdot
.682 .38008 Mdot
.682 .38013 Mdot
.682 .38015 Mdot
.682 .38021 Mdot
.682 .3803 Mdot
.682 .38034 Mdot
.682 .38035 Mdot
.682 .38042 Mdot
.682 .38057 Mdot
.682 .38083 Mdot
.682 .38128 Mdot
.682 .3813 Mdot
.682 .38146 Mdot
.682 .38155 Mdot
.682 .38206 Mdot
.682 .38219 Mdot
.682 .38222 Mdot
.682 .38256 Mdot
.682 .3827 Mdot
.682 .38275 Mdot
.682 .38287 Mdot
.682 .38295 Mdot
.682 .3833 Mdot
.682 .38335 Mdot
.682 .38356 Mdot
.682 .3836 Mdot
.682 .38363 Mdot
.682 .38368 Mdot
.682 .3837 Mdot
.682 .38383 Mdot
.682 .384 Mdot
.682 .38404 Mdot
.682 .38448 Mdot
.682 .38459 Mdot
.682 .38468 Mdot
.682 .38504 Mdot
.682 .38521 Mdot
.682 .38527 Mdot
.682 .38527 Mdot
.682 .38532 Mdot
.682 .38542 Mdot
.682 .38554 Mdot
.682 .38555 Mdot
.682 .38567 Mdot
.682 .3857 Mdot
.682 .3857 Mdot
.682 .38572 Mdot
.682 .38577 Mdot
.682 .38605 Mdot
.682 .38616 Mdot
.682 .38616 Mdot
.682 .38634 Mdot
.682 .38635 Mdot
.682 .38645 Mdot
.682 .38648 Mdot
.682 .38654 Mdot
.682 .38685 Mdot
.682 .38705 Mdot
.682 .38717 Mdot
.682 .38721 Mdot
.682 .38724 Mdot
.682 .38735 Mdot
.682 .38746 Mdot
.682 .38754 Mdot
.682 .38768 Mdot
.682 .38774 Mdot
.682 .38785 Mdot
.682 .3879 Mdot
.682 .38795 Mdot
.682 .38798 Mdot
.682 .38817 Mdot
.682 .38822 Mdot
.682 .38824 Mdot
.682 .38836 Mdot
.682 .3884 Mdot
.682 .38846 Mdot
.682 .38854 Mdot
.682 .38854 Mdot
.682 .3886 Mdot
.682 .38865 Mdot
.682 .38866 Mdot
.682 .38871 Mdot
.682 .38872 Mdot
.682 .38889 Mdot
.682 .38904 Mdot
.682 .38932 Mdot
.682 .38946 Mdot
.682 .38965 Mdot
.682 .38968 Mdot
.682 .38968 Mdot
.682 .38974 Mdot
.682 .39002 Mdot
.682 .39021 Mdot
.682 .39051 Mdot
.682 .39057 Mdot
.682 .39062 Mdot
.682 .39066 Mdot
.682 .39072 Mdot
.682 .39074 Mdot
.682 .39077 Mdot
.682 .39077 Mdot
.682 .39088 Mdot
.682 .39091 Mdot
.682 .39098 Mdot
.682 .39105 Mdot
.682 .39114 Mdot
.682 .39123 Mdot
.682 .39144 Mdot
.682 .39145 Mdot
.682 .39146 Mdot
.682 .39147 Mdot
.682 .39169 Mdot
.682 .39172 Mdot
.682 .39183 Mdot
.682 .39183 Mdot
.682 .39183 Mdot
.682 .39186 Mdot
.682 .39192 Mdot
.682 .392 Mdot
.682 .39205 Mdot
.682 .39217 Mdot
.682 .39222 Mdot
.682 .39229 Mdot
.682 .39236 Mdot
.682 .39237 Mdot
.682 .39243 Mdot
.682 .39244 Mdot
.682 .39255 Mdot
.682 .39262 Mdot
.682 .39294 Mdot
.682 .393 Mdot
.682 .39315 Mdot
.682 .39317 Mdot
.682 .39319 Mdot
.682 .39321 Mdot
.682 .39335 Mdot
.682 .3937 Mdot
.682 .39374 Mdot
.682 .39375 Mdot
.682 .39385 Mdot
.682 .39394 Mdot
.682 .39415 Mdot
.682 .39416 Mdot
.682 .39418 Mdot
.682 .39426 Mdot
.682 .39463 Mdot
.682 .39489 Mdot
.682 .39509 Mdot
.682 .3952 Mdot
.682 .39526 Mdot
.682 .39534 Mdot
.682 .39549 Mdot
.682 .39552 Mdot
.682 .39559 Mdot
.682 .39572 Mdot
.682 .39584 Mdot
.682 .3959 Mdot
.682 .39592 Mdot
.682 .39618 Mdot
.682 .39621 Mdot
.682 .39628 Mdot
.682 .3963 Mdot
.682 .39642 Mdot
.682 .39653 Mdot
.682 .39655 Mdot
.682 .39657 Mdot
.682 .39659 Mdot
.682 .39664 Mdot
.682 .39668 Mdot
.682 .39707 Mdot
.682 .39713 Mdot
.682 .3972 Mdot
.682 .39758 Mdot
.682 .39781 Mdot
.682 .39782 Mdot
.682 .39785 Mdot
.682 .39825 Mdot
.682 .39876 Mdot
.682 .3991 Mdot
.682 .39938 Mdot
.682 .39942 Mdot
.682 .39952 Mdot
.682 .39958 Mdot
.682 .39959 Mdot
.682 .39963 Mdot
.682 .39978 Mdot
.682 .39996 Mdot
.682 .40002 Mdot
.682 .40017 Mdot
.682 .40023 Mdot
.682 .40034 Mdot
.682 .40072 Mdot
.682 .40073 Mdot
.682 .40074 Mdot
.682 .40085 Mdot
.682 .40096 Mdot
.682 .40098 Mdot
.682 .40135 Mdot
.682 .40156 Mdot
.682 .40166 Mdot
.682 .40169 Mdot
.682 .4017 Mdot
.682 .40177 Mdot
.682 .4018 Mdot
.682 .40186 Mdot
.682 .40189 Mdot
.682 .40193 Mdot
.682 .40197 Mdot
.682 .40198 Mdot
.682 .40204 Mdot
.682 .40206 Mdot
.682 .40218 Mdot
.682 .40219 Mdot
.682 .4024 Mdot
.682 .40244 Mdot
.682 .40248 Mdot
.682 .40258 Mdot
.682 .40263 Mdot
.682 .40295 Mdot
.682 .4031 Mdot
.682 .40314 Mdot
.682 .40325 Mdot
.682 .40348 Mdot
.682 .40372 Mdot
.682 .40379 Mdot
.682 .40383 Mdot
.682 .40385 Mdot
.682 .40391 Mdot
.682 .40412 Mdot
.682 .40418 Mdot
.682 .40429 Mdot
.682 .40433 Mdot
.682 .40445 Mdot
.682 .40466 Mdot
.682 .40503 Mdot
.682 .40524 Mdot
.682 .40548 Mdot
.682 .40551 Mdot
.682 .40554 Mdot
.682 .40617 Mdot
.682 .40619 Mdot
.682 .40635 Mdot
.682 .40639 Mdot
.682 .4064 Mdot
.682 .40643 Mdot
.682 .40654 Mdot
.682 .40676 Mdot
.682 .4068 Mdot
.682 .40689 Mdot
.682 .40697 Mdot
.682 .40715 Mdot
.682 .40716 Mdot
.682 .40724 Mdot
.682 .40756 Mdot
.682 .40765 Mdot
.682 .4079 Mdot
.682 .40803 Mdot
.682 .40812 Mdot
.682 .40815 Mdot
.682 .40816 Mdot
.682 .40818 Mdot
.682 .40823 Mdot
.682 .40826 Mdot
.682 .40827 Mdot
.682 .4083 Mdot
.682 .40854 Mdot
.682 .40854 Mdot
.682 .40865 Mdot
.682 .40886 Mdot
.682 .40893 Mdot
.682 .40925 Mdot
.682 .40937 Mdot
.682 .40958 Mdot
.682 .4096 Mdot
.682 .40972 Mdot
.682 .40974 Mdot
.682 .40974 Mdot
.682 .40985 Mdot
.682 .40995 Mdot
.682 .40998 Mdot
.682 .41009 Mdot
.682 .41012 Mdot
.682 .4103 Mdot
.682 .41041 Mdot
.682 .41055 Mdot
.682 .41067 Mdot
.682 .41071 Mdot
.682 .41071 Mdot
.682 .41072 Mdot
.682 .41079 Mdot
.682 .41093 Mdot
.682 .41097 Mdot
.682 .41111 Mdot
.682 .41121 Mdot
.682 .41122 Mdot
.682 .41131 Mdot
.682 .41138 Mdot
.682 .41142 Mdot
.682 .41142 Mdot
.682 .41145 Mdot
.682 .41149 Mdot
.682 .41173 Mdot
.682 .41174 Mdot
.682 .41183 Mdot
.682 .41196 Mdot
.682 .41201 Mdot
.682 .41201 Mdot
.682 .41202 Mdot
.682 .41206 Mdot
.682 .41215 Mdot
.682 .41217 Mdot
.682 .41231 Mdot
.682 .41249 Mdot
.682 .41266 Mdot
.682 .41269 Mdot
.682 .4127 Mdot
.682 .41275 Mdot
.682 .41278 Mdot
.682 .41287 Mdot
.682 .41288 Mdot
.682 .41289 Mdot
.682 .41296 Mdot
.682 .41307 Mdot
.682 .41317 Mdot
.682 .4132 Mdot
.682 .41323 Mdot
.682 .41342 Mdot
.682 .41346 Mdot
.682 .41357 Mdot
.682 .41373 Mdot
.682 .41408 Mdot
.682 .41415 Mdot
.682 .41454 Mdot
.682 .4146 Mdot
.682 .41471 Mdot
.682 .41472 Mdot
.682 .41475 Mdot
.682 .41478 Mdot
.682 .41484 Mdot
.682 .41489 Mdot
.682 .41509 Mdot
.682 .41512 Mdot
.682 .41529 Mdot
.682 .41538 Mdot
.682 .41544 Mdot
.682 .4157 Mdot
.682 .41581 Mdot
.682 .4159 Mdot
.682 .41601 Mdot
.682 .41611 Mdot
.682 .41618 Mdot
.682 .41621 Mdot
.682 .41627 Mdot
.682 .41651 Mdot
.682 .41652 Mdot
.682 .41661 Mdot
.682 .41662 Mdot
.682 .41662 Mdot
.682 .41671 Mdot
.682 .41673 Mdot
.682 .41674 Mdot
.682 .41684 Mdot
.682 .41685 Mdot
.682 .41697 Mdot
.682 .41699 Mdot
.682 .41703 Mdot
.684 .2699 Mdot
.684 .26991 Mdot
.684 .26997 Mdot
.684 .27002 Mdot
.684 .27009 Mdot
.684 .2702 Mdot
.684 .27032 Mdot
.684 .27039 Mdot
.684 .27059 Mdot
.684 .27061 Mdot
.684 .27073 Mdot
.684 .27075 Mdot
.684 .27086 Mdot
.684 .27089 Mdot
.684 .27093 Mdot
.684 .27094 Mdot
.684 .27118 Mdot
.684 .2713 Mdot
.684 .27135 Mdot
.684 .27144 Mdot
.684 .27163 Mdot
.684 .27169 Mdot
.684 .27187 Mdot
.684 .2722 Mdot
.684 .27241 Mdot
.684 .27247 Mdot
.684 .27271 Mdot
.684 .27272 Mdot
.684 .27299 Mdot
.684 .27339 Mdot
.684 .27346 Mdot
.684 .27357 Mdot
.684 .27359 Mdot
.684 .27377 Mdot
.684 .27383 Mdot
.684 .27421 Mdot
.684 .2743 Mdot
.684 .27431 Mdot
.684 .27436 Mdot
.684 .27458 Mdot
.684 .27474 Mdot
.684 .27489 Mdot
.684 .27505 Mdot
.684 .27523 Mdot
.684 .27525 Mdot
.684 .27527 Mdot
.684 .27537 Mdot
.684 .27555 Mdot
.684 .27589 Mdot
.684 .2761 Mdot
.684 .27618 Mdot
.684 .27639 Mdot
.684 .27665 Mdot
.684 .27676 Mdot
.684 .27692 Mdot
.684 .27703 Mdot
.684 .27707 Mdot
.684 .27707 Mdot
.684 .27735 Mdot
.684 .27753 Mdot
.684 .27773 Mdot
.684 .27775 Mdot
.684 .27779 Mdot
.684 .27817 Mdot
.684 .2784 Mdot
.684 .27883 Mdot
.684 .27891 Mdot
.684 .27897 Mdot
.684 .27906 Mdot
.684 .27911 Mdot
.684 .27928 Mdot
.684 .27937 Mdot
.684 .2798 Mdot
.684 .27994 Mdot
.684 .28007 Mdot
.684 .28011 Mdot
.684 .28031 Mdot
.684 .28047 Mdot
.684 .28055 Mdot
.684 .28063 Mdot
.684 .28072 Mdot
.684 .28082 Mdot
.684 .28082 Mdot
.684 .28098 Mdot
.684 .28107 Mdot
.684 .28121 Mdot
.684 .28131 Mdot
.684 .28132 Mdot
.684 .28143 Mdot
.684 .28149 Mdot
.684 .28151 Mdot
.684 .28163 Mdot
.684 .28197 Mdot
.684 .28208 Mdot
.684 .2821 Mdot
.684 .28214 Mdot
.684 .28217 Mdot
.684 .2823 Mdot
.684 .28244 Mdot
.684 .28265 Mdot
.684 .28291 Mdot
.684 .28295 Mdot
.684 .28302 Mdot
.684 .28312 Mdot
.684 .28321 Mdot
.684 .28362 Mdot
.684 .28373 Mdot
.684 .28396 Mdot
.684 .28407 Mdot
.684 .28421 Mdot
.684 .28426 Mdot
.684 .28436 Mdot
.684 .28458 Mdot
.684 .28473 Mdot
.684 .28499 Mdot
.684 .28508 Mdot
.684 .28512 Mdot
.684 .28524 Mdot
.684 .28548 Mdot
.684 .28568 Mdot
.684 .28595 Mdot
.684 .28607 Mdot
.684 .28626 Mdot
.684 .2863 Mdot
.684 .2867 Mdot
.684 .28684 Mdot
.684 .28703 Mdot
.684 .28705 Mdot
.684 .28708 Mdot
.684 .28726 Mdot
.684 .28765 Mdot
.684 .28774 Mdot
.684 .28781 Mdot
.684 .28807 Mdot
.684 .28829 Mdot
.684 .28843 Mdot
.684 .28845 Mdot
.684 .28853 Mdot
.684 .28867 Mdot
.684 .28879 Mdot
.684 .28881 Mdot
.684 .28883 Mdot
.684 .28913 Mdot
.684 .28919 Mdot
.684 .28941 Mdot
.684 .2895 Mdot
.684 .28965 Mdot
.684 .28973 Mdot
.684 .29016 Mdot
.684 .29025 Mdot
.684 .29044 Mdot
.684 .29052 Mdot
.684 .29057 Mdot
.684 .29082 Mdot
.684 .29094 Mdot
.684 .29098 Mdot
.684 .29137 Mdot
.684 .29141 Mdot
.684 .29151 Mdot
.684 .29165 Mdot
.684 .2917 Mdot
.684 .29174 Mdot
.684 .29184 Mdot
.684 .29188 Mdot
.684 .29189 Mdot
.684 .29211 Mdot
.684 .29217 Mdot
.684 .29252 Mdot
.684 .29259 Mdot
.684 .2927 Mdot
.684 .29284 Mdot
.684 .29301 Mdot
.684 .29323 Mdot
.684 .2933 Mdot
.684 .29335 Mdot
.684 .29351 Mdot
.684 .29364 Mdot
.684 .29371 Mdot
.684 .29379 Mdot
.684 .29388 Mdot
.684 .2939 Mdot
.684 .29399 Mdot
.684 .29437 Mdot
.684 .29441 Mdot
.684 .29452 Mdot
.684 .29467 Mdot
.684 .29475 Mdot
.684 .29505 Mdot
.684 .29513 Mdot
.684 .29517 Mdot
.684 .29524 Mdot
.684 .29547 Mdot
.684 .29558 Mdot
.684 .29569 Mdot
.684 .29595 Mdot
.684 .29611 Mdot
.684 .29613 Mdot
.684 .29617 Mdot
.684 .29638 Mdot
.684 .29646 Mdot
.684 .29679 Mdot
.684 .2968 Mdot
.684 .29693 Mdot
.684 .297 Mdot
.684 .29708 Mdot
.684 .29715 Mdot
.684 .29736 Mdot
.684 .29743 Mdot
.684 .29753 Mdot
.684 .29772 Mdot
.684 .29787 Mdot
.684 .29789 Mdot
.684 .29814 Mdot
.684 .29835 Mdot
.684 .29844 Mdot
.684 .2986 Mdot
.684 .29874 Mdot
.684 .29906 Mdot
.684 .29914 Mdot
.684 .29919 Mdot
.684 .29931 Mdot
.684 .29934 Mdot
.684 .2995 Mdot
.684 .29951 Mdot
.684 .29966 Mdot
.684 .2997 Mdot
.684 .29979 Mdot
.684 .30004 Mdot
.684 .30034 Mdot
.684 .30044 Mdot
.684 .30057 Mdot
.684 .30087 Mdot
.684 .30097 Mdot
.684 .30119 Mdot
.684 .30129 Mdot
.684 .30151 Mdot
.684 .30155 Mdot
.684 .30177 Mdot
.684 .30189 Mdot
.684 .3021 Mdot
.684 .30228 Mdot
.684 .30255 Mdot
.684 .30261 Mdot
.684 .30266 Mdot
.684 .30281 Mdot
.684 .30299 Mdot
.684 .30308 Mdot
.684 .3031 Mdot
.684 .30311 Mdot
.684 .30317 Mdot
.684 .30335 Mdot
.684 .30343 Mdot
.684 .30352 Mdot
.684 .30378 Mdot
.684 .30397 Mdot
.684 .30405 Mdot
.684 .30416 Mdot
.684 .30455 Mdot
.684 .3046 Mdot
.684 .30477 Mdot
.684 .30485 Mdot
.684 .30507 Mdot
.684 .3054 Mdot
.684 .30554 Mdot
.684 .30564 Mdot
.684 .30578 Mdot
.684 .3058 Mdot
.684 .30615 Mdot
.684 .3063 Mdot
.684 .30641 Mdot
.684 .30675 Mdot
.684 .30677 Mdot
.684 .30695 Mdot
.684 .30711 Mdot
.684 .30726 Mdot
.684 .30752 Mdot
.684 .30755 Mdot
.684 .30764 Mdot
.684 .30771 Mdot
.684 .30812 Mdot
.684 .30824 Mdot
.684 .30828 Mdot
.684 .30879 Mdot
.684 .30884 Mdot
.684 .30887 Mdot
.684 .30909 Mdot
.684 .3091 Mdot
.684 .30916 Mdot
.684 .30924 Mdot
.684 .30925 Mdot
.684 .30935 Mdot
.684 .30939 Mdot
.684 .30946 Mdot
.684 .30951 Mdot
.684 .30955 Mdot
.684 .30962 Mdot
.684 .30978 Mdot
.684 .30981 Mdot
.684 .31022 Mdot
.684 .31033 Mdot
.684 .31033 Mdot
.684 .31046 Mdot
.684 .3107 Mdot
.684 .31074 Mdot
.684 .31083 Mdot
.684 .311 Mdot
.684 .31128 Mdot
.684 .31143 Mdot
.684 .31164 Mdot
.684 .31174 Mdot
.684 .31208 Mdot
.684 .31213 Mdot
.684 .31216 Mdot
.684 .31236 Mdot
.684 .31253 Mdot
.684 .31264 Mdot
.684 .3127 Mdot
.684 .31279 Mdot
.684 .31313 Mdot
.684 .31338 Mdot
.684 .31344 Mdot
.684 .31353 Mdot
.684 .31361 Mdot
.684 .31396 Mdot
.684 .31397 Mdot
.684 .3142 Mdot
.684 .31459 Mdot
.684 .31467 Mdot
.684 .3147 Mdot
.684 .31507 Mdot
.684 .31514 Mdot
.684 .31521 Mdot
.684 .31547 Mdot
.684 .31551 Mdot
.684 .31556 Mdot
.684 .31561 Mdot
.684 .3157 Mdot
.684 .31575 Mdot
.684 .31582 Mdot
.684 .31588 Mdot
.684 .31594 Mdot
.684 .31598 Mdot
.684 .31633 Mdot
.684 .31648 Mdot
.684 .31675 Mdot
.684 .31689 Mdot
.684 .31716 Mdot
.684 .31735 Mdot
.684 .31742 Mdot
.684 .31745 Mdot
.684 .3177 Mdot
.684 .31791 Mdot
.684 .31798 Mdot
.684 .31835 Mdot
.684 .31854 Mdot
.684 .31875 Mdot
.684 .31893 Mdot
.684 .31894 Mdot
.684 .31926 Mdot
.684 .31931 Mdot
.684 .31949 Mdot
.684 .31968 Mdot
.684 .31981 Mdot
.684 .31987 Mdot
.684 .32037 Mdot
.684 .32061 Mdot
.684 .32075 Mdot
.684 .32082 Mdot
.684 .32102 Mdot
.684 .32127 Mdot
.684 .32132 Mdot
.684 .3214 Mdot
.684 .32143 Mdot
.684 .32145 Mdot
.684 .32152 Mdot
.684 .32164 Mdot
.684 .3219 Mdot
.684 .32213 Mdot
.684 .32228 Mdot
.684 .3225 Mdot
.684 .32254 Mdot
.684 .32265 Mdot
.684 .32285 Mdot
.684 .32288 Mdot
.684 .32306 Mdot
.684 .32332 Mdot
.684 .3235 Mdot
.684 .32356 Mdot
.684 .32378 Mdot
.684 .32379 Mdot
.684 .32397 Mdot
.684 .32415 Mdot
.684 .3243 Mdot
.684 .32445 Mdot
.684 .32449 Mdot
.684 .32454 Mdot
.684 .32474 Mdot
.684 .32511 Mdot
.684 .32519 Mdot
.684 .32536 Mdot
.684 .32543 Mdot
.684 .32559 Mdot
.684 .3257 Mdot
.684 .32633 Mdot
.684 .32649 Mdot
.684 .32667 Mdot
.684 .32698 Mdot
.684 .32708 Mdot
.684 .32725 Mdot
.684 .32736 Mdot
.684 .32746 Mdot
.684 .32752 Mdot
.684 .32808 Mdot
.684 .32829 Mdot
.684 .32832 Mdot
.684 .32875 Mdot
.684 .32896 Mdot
.684 .32929 Mdot
.684 .32947 Mdot
.684 .32948 Mdot
.684 .32957 Mdot
.684 .32988 Mdot
.684 .32995 Mdot
.684 .33028 Mdot
.684 .33072 Mdot
.684 .33076 Mdot
.684 .3308 Mdot
.684 .3308 Mdot
.684 .33088 Mdot
.684 .33091 Mdot
.684 .331 Mdot
.684 .33109 Mdot
.684 .33138 Mdot
.684 .33138 Mdot
.684 .33145 Mdot
.684 .3316 Mdot
.684 .33189 Mdot
.684 .33197 Mdot
.684 .33208 Mdot
.684 .33247 Mdot
.684 .33261 Mdot
.684 .33265 Mdot
.684 .33288 Mdot
.684 .33301 Mdot
.684 .33305 Mdot
.684 .33333 Mdot
.684 .33366 Mdot
.684 .3337 Mdot
.684 .33395 Mdot
.684 .33399 Mdot
.684 .33413 Mdot
.684 .33418 Mdot
.684 .3342 Mdot
.684 .33425 Mdot
.684 .33435 Mdot
.684 .33438 Mdot
.684 .33459 Mdot
.684 .33489 Mdot
.684 .33517 Mdot
.684 .33547 Mdot
.684 .33588 Mdot
.684 .33598 Mdot
.684 .33598 Mdot
.684 .33615 Mdot
.684 .33687 Mdot
.684 .33699 Mdot
.684 .33732 Mdot
.684 .33736 Mdot
.684 .33756 Mdot
.684 .33768 Mdot
.684 .33845 Mdot
.684 .33895 Mdot
.684 .33897 Mdot
.684 .33941 Mdot
.684 .33954 Mdot
.684 .33993 Mdot
.684 .34053 Mdot
.684 .34087 Mdot
.684 .34098 Mdot
.684 .34134 Mdot
.684 .34151 Mdot
.684 .34161 Mdot
.684 .34183 Mdot
.684 .34228 Mdot
.684 .3423 Mdot
.684 .34238 Mdot
.684 .34243 Mdot
.684 .34263 Mdot
.684 .34267 Mdot
.684 .3429 Mdot
.684 .34294 Mdot
.684 .34331 Mdot
.684 .34343 Mdot
.684 .34352 Mdot
.684 .34367 Mdot
.684 .34387 Mdot
.684 .344 Mdot
.684 .3441 Mdot
.684 .34421 Mdot
.684 .34423 Mdot
.684 .3638 Mdot
.684 .36382 Mdot
.684 .3639 Mdot
.684 .36397 Mdot
.684 .36407 Mdot
.684 .36421 Mdot
.684 .36432 Mdot
.684 .36439 Mdot
.684 .36448 Mdot
.684 .36475 Mdot
.684 .36477 Mdot
.684 .36495 Mdot
.684 .36497 Mdot
.684 .36512 Mdot
.684 .36516 Mdot
.684 .36522 Mdot
.684 .36523 Mdot
.684 .36556 Mdot
.684 .36572 Mdot
.684 .36579 Mdot
.684 .36592 Mdot
.684 .36618 Mdot
.684 .36626 Mdot
.684 .36651 Mdot
.684 .36695 Mdot
.684 .36723 Mdot
.684 .36733 Mdot
.684 .36765 Mdot
.684 .36767 Mdot
.684 .36803 Mdot
.684 .36859 Mdot
.684 .36868 Mdot
.684 .36883 Mdot
.684 .36885 Mdot
.684 .3691 Mdot
.684 .36918 Mdot
.684 .36971 Mdot
.684 .36983 Mdot
.684 .36984 Mdot
.684 .36991 Mdot
.684 .37021 Mdot
.684 .37043 Mdot
.684 .37063 Mdot
.684 .37085 Mdot
.684 .37101 Mdot
.684 .37103 Mdot
.684 .3711 Mdot
.684 .37113 Mdot
.684 .37115 Mdot
.684 .37119 Mdot
.684 .37129 Mdot
.684 .37132 Mdot
.684 .3715 Mdot
.684 .37153 Mdot
.684 .37177 Mdot
.684 .37198 Mdot
.684 .372 Mdot
.684 .3721 Mdot
.684 .37227 Mdot
.684 .3723 Mdot
.684 .3724 Mdot
.684 .37268 Mdot
.684 .37277 Mdot
.684 .37282 Mdot
.684 .37304 Mdot
.684 .37315 Mdot
.684 .3732 Mdot
.684 .3732 Mdot
.684 .37341 Mdot
.684 .37348 Mdot
.684 .37354 Mdot
.684 .37356 Mdot
.684 .37362 Mdot
.684 .37362 Mdot
.684 .37365 Mdot
.684 .37368 Mdot
.684 .374 Mdot
.684 .37425 Mdot
.684 .3743 Mdot
.684 .37452 Mdot
.684 .37454 Mdot
.684 .37459 Mdot
.684 .3746 Mdot
.684 .37473 Mdot
.684 .37496 Mdot
.684 .37512 Mdot
.684 .37543 Mdot
.684 .37545 Mdot
.684 .37561 Mdot
.684 .37602 Mdot
.684 .37606 Mdot
.684 .37614 Mdot
.684 .37621 Mdot
.684 .37634 Mdot
.684 .37641 Mdot
.684 .37664 Mdot
.684 .37677 Mdot
.684 .37689 Mdot
.684 .37735 Mdot
.684 .37743 Mdot
.684 .37755 Mdot
.684 .3776 Mdot
.684 .37772 Mdot
.684 .37778 Mdot
.684 .37805 Mdot
.684 .3782 Mdot
.684 .37824 Mdot
.684 .37826 Mdot
.684 .37837 Mdot
.684 .37849 Mdot
.684 .37862 Mdot
.684 .37874 Mdot
.684 .37875 Mdot
.684 .37891 Mdot
.684 .37896 Mdot
.684 .37909 Mdot
.684 .37928 Mdot
.684 .37941 Mdot
.684 .37943 Mdot
.684 .37958 Mdot
.684 .37966 Mdot
.684 .37969 Mdot
.684 .37985 Mdot
.684 .37996 Mdot
.684 .38013 Mdot
.684 .38031 Mdot
.684 .38041 Mdot
.684 .38046 Mdot
.684 .38047 Mdot
.684 .38049 Mdot
.684 .38055 Mdot
.684 .38059 Mdot
.684 .38077 Mdot
.684 .38091 Mdot
.684 .38097 Mdot
.684 .38107 Mdot
.684 .38124 Mdot
.684 .38161 Mdot
.684 .38166 Mdot
.684 .38175 Mdot
.684 .38189 Mdot
.684 .38202 Mdot
.684 .38206 Mdot
.684 .38229 Mdot
.684 .3823 Mdot
.684 .38243 Mdot
.684 .38258 Mdot
.684 .38272 Mdot
.684 .383 Mdot
.684 .38305 Mdot
.684 .3832 Mdot
.684 .38338 Mdot
.684 .3834 Mdot
.684 .38345 Mdot
.684 .38359 Mdot
.684 .38379 Mdot
.684 .38389 Mdot
.684 .38409 Mdot
.684 .3842 Mdot
.684 .38446 Mdot
.684 .38449 Mdot
.684 .38453 Mdot
.684 .38457 Mdot
.684 .38463 Mdot
.684 .38466 Mdot
.684 .38472 Mdot
.684 .38476 Mdot
.684 .3848 Mdot
.684 .38483 Mdot
.684 .38502 Mdot
.684 .38507 Mdot
.684 .38512 Mdot
.684 .38539 Mdot
.684 .38541 Mdot
.684 .38547 Mdot
.684 .38576 Mdot
.684 .38592 Mdot
.684 .38593 Mdot
.684 .38619 Mdot
.684 .38625 Mdot
.684 .38631 Mdot
.684 .38635 Mdot
.684 .38654 Mdot
.684 .38678 Mdot
.684 .38685 Mdot
.684 .3869 Mdot
.684 .38698 Mdot
.684 .3871 Mdot
.684 .38725 Mdot
.684 .38727 Mdot
.684 .3873 Mdot
.684 .38756 Mdot
.684 .38762 Mdot
.684 .38778 Mdot
.684 .38789 Mdot
.684 .38809 Mdot
.684 .38822 Mdot
.684 .38829 Mdot
.684 .38831 Mdot
.684 .38849 Mdot
.684 .38858 Mdot
.684 .38859 Mdot
.684 .38866 Mdot
.684 .38896 Mdot
.684 .38899 Mdot
.684 .38911 Mdot
.684 .38915 Mdot
.684 .38918 Mdot
.684 .38922 Mdot
.684 .38927 Mdot
.684 .3893 Mdot
.684 .38937 Mdot
.684 .38938 Mdot
.684 .38944 Mdot
.684 .38948 Mdot
.684 .38949 Mdot
.684 .38965 Mdot
.684 .38967 Mdot
.684 .38971 Mdot
.684 .39009 Mdot
.684 .39011 Mdot
.684 .3902 Mdot
.684 .3905 Mdot
.684 .39055 Mdot
.684 .39062 Mdot
.684 .39064 Mdot
.684 .39083 Mdot
.684 .39094 Mdot
.684 .39106 Mdot
.684 .39119 Mdot
.684 .3912 Mdot
.684 .39145 Mdot
.684 .39153 Mdot
.684 .39164 Mdot
.684 .39189 Mdot
.684 .39191 Mdot
.684 .39202 Mdot
.684 .39209 Mdot
.684 .39219 Mdot
.684 .39243 Mdot
.684 .39259 Mdot
.684 .39265 Mdot
.684 .39277 Mdot
.684 .39281 Mdot
.684 .3931 Mdot
.684 .39318 Mdot
.684 .39323 Mdot
.684 .39337 Mdot
.684 .39356 Mdot
.684 .39363 Mdot
.684 .39369 Mdot
.684 .39382 Mdot
.684 .39387 Mdot
.684 .39387 Mdot
.684 .39389 Mdot
.684 .39395 Mdot
.684 .39409 Mdot
.684 .39419 Mdot
.684 .39423 Mdot
.684 .39427 Mdot
.684 .39447 Mdot
.684 .3946 Mdot
.684 .39476 Mdot
.684 .39484 Mdot
.684 .395 Mdot
.684 .39504 Mdot
.684 .39519 Mdot
.684 .39527 Mdot
.684 .39542 Mdot
.684 .3955 Mdot
.684 .39572 Mdot
.684 .39582 Mdot
.684 .39589 Mdot
.684 .3961 Mdot
.684 .39629 Mdot
.684 .39635 Mdot
.684 .39639 Mdot
.684 .39649 Mdot
.684 .3965 Mdot
.684 .39662 Mdot
.684 .39664 Mdot
.684 .39673 Mdot
.684 .39676 Mdot
.684 .39682 Mdot
.684 .39705 Mdot
.684 .39716 Mdot
.684 .39728 Mdot
.684 .39734 Mdot
.684 .39749 Mdot
.684 .39768 Mdot
.684 .3977 Mdot
.684 .39781 Mdot
.684 .39794 Mdot
.684 .39801 Mdot
.684 .39807 Mdot
.684 .39822 Mdot
.684 .39827 Mdot
.684 .39833 Mdot
.684 .39838 Mdot
.684 .39848 Mdot
.684 .39848 Mdot
.684 .39873 Mdot
.684 .39878 Mdot
.684 .39893 Mdot
.684 .39896 Mdot
.684 .39898 Mdot
.684 .39909 Mdot
.684 .39928 Mdot
.684 .39937 Mdot
.684 .39945 Mdot
.684 .39961 Mdot
.684 .39966 Mdot
.684 .39969 Mdot
.684 .39975 Mdot
.684 .39997 Mdot
.684 .40003 Mdot
.684 .40014 Mdot
.684 .40022 Mdot
.684 .40025 Mdot
.684 .40053 Mdot
.684 .40059 Mdot
.684 .40061 Mdot
.684 .40067 Mdot
.684 .40073 Mdot
.684 .40078 Mdot
.684 .40088 Mdot
.684 .401 Mdot
.684 .40104 Mdot
.684 .40109 Mdot
.684 .40125 Mdot
.684 .40137 Mdot
.684 .40147 Mdot
.684 .40156 Mdot
.684 .4016 Mdot
.684 .40186 Mdot
.684 .4019 Mdot
.684 .40207 Mdot
.684 .40207 Mdot
.684 .4021 Mdot
.684 .40217 Mdot
.684 .4022 Mdot
.684 .40224 Mdot
.684 .40234 Mdot
.684 .40241 Mdot
.684 .40245 Mdot
.684 .40273 Mdot
.684 .40276 Mdot
.684 .40285 Mdot
.684 .40303 Mdot
.684 .40307 Mdot
.684 .40312 Mdot
.684 .40327 Mdot
.684 .40333 Mdot
.684 .40364 Mdot
.684 .4037 Mdot
.684 .40381 Mdot
.684 .40388 Mdot
.684 .40403 Mdot
.684 .40408 Mdot
.684 .4043 Mdot
.684 .40432 Mdot
.684 .40433 Mdot
.684 .40441 Mdot
.684 .40452 Mdot
.684 .40458 Mdot
.684 .4046 Mdot
.684 .4047 Mdot
.684 .40486 Mdot
.684 .40505 Mdot
.684 .4051 Mdot
.684 .40516 Mdot
.684 .40545 Mdot
.684 .40558 Mdot
.684 .4056 Mdot
.684 .40561 Mdot
.684 .40576 Mdot
.684 .40586 Mdot
.684 .40615 Mdot
.684 .40618 Mdot
.684 .40632 Mdot
.684 .40641 Mdot
.684 .40661 Mdot
.684 .40675 Mdot
.684 .40692 Mdot
.684 .40702 Mdot
.684 .40704 Mdot
.684 .40711 Mdot
.684 .4073 Mdot
.684 .40741 Mdot
.684 .40757 Mdot
.684 .40764 Mdot
.684 .40768 Mdot
.684 .40778 Mdot
.684 .40786 Mdot
.684 .40803 Mdot
.684 .40811 Mdot
.684 .40841 Mdot
.684 .40848 Mdot
.684 .40855 Mdot
.684 .4086 Mdot
.684 .40863 Mdot
.684 .40882 Mdot
.684 .40897 Mdot
.684 .40908 Mdot
.684 .40917 Mdot
.684 .40919 Mdot
.684 .40922 Mdot
.684 .40923 Mdot
.684 .40932 Mdot
.684 .40957 Mdot
.684 .40965 Mdot
.684 .40967 Mdot
.684 .40971 Mdot
.684 .40979 Mdot
.684 .4098 Mdot
.684 .40987 Mdot
.684 .40997 Mdot
.684 .41004 Mdot
.684 .41015 Mdot
.684 .41016 Mdot
.684 .41023 Mdot
.684 .4103 Mdot
.684 .41036 Mdot
.684 .41041 Mdot
.684 .41053 Mdot
.684 .41067 Mdot
.684 .4107 Mdot
.684 .4108 Mdot
.684 .4109 Mdot
.684 .41121 Mdot
.684 .41128 Mdot
.684 .4114 Mdot
.684 .41144 Mdot
.684 .41151 Mdot
.684 .41155 Mdot
.684 .41161 Mdot
.684 .41193 Mdot
.684 .41209 Mdot
.684 .41237 Mdot
.684 .4124 Mdot
.684 .41242 Mdot
.684 .41256 Mdot
.684 .41269 Mdot
.684 .41289 Mdot
.684 .4129 Mdot
.684 .41293 Mdot
.684 .41301 Mdot
.684 .41312 Mdot
.684 .41321 Mdot
.684 .4134 Mdot
.684 .41355 Mdot
.684 .4136 Mdot
.684 .41376 Mdot
.684 .41401 Mdot
.684 .41414 Mdot
.684 .41421 Mdot
.684 .41423 Mdot
.684 .41424 Mdot
.684 .41437 Mdot
.684 .41449 Mdot
.684 .4146 Mdot
.684 .41472 Mdot
.684 .41488 Mdot
.684 .41492 Mdot
.684 .41492 Mdot
.684 .41499 Mdot
.684 .41527 Mdot
.684 .41531 Mdot
.684 .41544 Mdot
.684 .41546 Mdot
.684 .41554 Mdot
.684 .41558 Mdot
.684 .41588 Mdot
.684 .41608 Mdot
.684 .41609 Mdot
.684 .41626 Mdot
.684 .41631 Mdot
.684 .41646 Mdot
.684 .4167 Mdot
.684 .41683 Mdot
.684 .41687 Mdot
.684 .41701 Mdot
.684 .41708 Mdot
.684 .41712 Mdot
.684 .4172 Mdot
.684 .41738 Mdot
.684 .41739 Mdot
.684 .41742 Mdot
.684 .41744 Mdot
.684 .41752 Mdot
.684 .41753 Mdot
.684 .41762 Mdot
.684 .41764 Mdot
.684 .41778 Mdot
.684 .41783 Mdot
.684 .41792 Mdot
.684 .418 Mdot
.684 .41805 Mdot
.684 .41809 Mdot
.684 .41814 Mdot
.684 .41814 Mdot
.686 .26918 Mdot
.686 .2696 Mdot
.686 .26964 Mdot
.686 .26969 Mdot
.686 .26979 Mdot
.686 .26979 Mdot
.686 .26987 Mdot
.686 .26987 Mdot
.686 .27015 Mdot
.686 .2703 Mdot
.686 .27047 Mdot
.686 .27055 Mdot
.686 .27075 Mdot
.686 .27076 Mdot
.686 .27079 Mdot
.686 .2708 Mdot
.686 .27081 Mdot
.686 .27085 Mdot
.686 .27118 Mdot
.686 .27127 Mdot
.686 .27136 Mdot
.686 .27149 Mdot
.686 .27165 Mdot
.686 .2717 Mdot
.686 .2717 Mdot
.686 .27215 Mdot
.686 .27217 Mdot
.686 .27256 Mdot
.686 .27293 Mdot
.686 .27297 Mdot
.686 .27354 Mdot
.686 .27359 Mdot
.686 .27366 Mdot
.686 .27373 Mdot
.686 .27402 Mdot
.686 .27402 Mdot
.686 .27403 Mdot
.686 .27413 Mdot
.686 .27433 Mdot
.686 .27442 Mdot
.686 .27445 Mdot
.686 .27455 Mdot
.686 .27466 Mdot
.686 .27469 Mdot
.686 .27494 Mdot
.686 .27495 Mdot
.686 .27511 Mdot
.686 .27517 Mdot
.686 .27518 Mdot
.686 .27518 Mdot
.686 .27549 Mdot
.686 .27554 Mdot
.686 .27572 Mdot
.686 .27579 Mdot
.686 .276 Mdot
.686 .27613 Mdot
.686 .27619 Mdot
.686 .2762 Mdot
.686 .27621 Mdot
.686 .27634 Mdot
.686 .27654 Mdot
.686 .27661 Mdot
.686 .27688 Mdot
.686 .27726 Mdot
.686 .27736 Mdot
.686 .27742 Mdot
.686 .27748 Mdot
.686 .27756 Mdot
.686 .27759 Mdot
.686 .27761 Mdot
.686 .27765 Mdot
.686 .27769 Mdot
.686 .27775 Mdot
.686 .27779 Mdot
.686 .27803 Mdot
.686 .27811 Mdot
.686 .27821 Mdot
.686 .27825 Mdot
.686 .27839 Mdot
.686 .27847 Mdot
.686 .27851 Mdot
.686 .27879 Mdot
.686 .27887 Mdot
.686 .27905 Mdot
.686 .27911 Mdot
.686 .27912 Mdot
.686 .27916 Mdot
.686 .27924 Mdot
.686 .27928 Mdot
.686 .27929 Mdot
.686 .27965 Mdot
.686 .27974 Mdot
.686 .28023 Mdot
.686 .28024 Mdot
.686 .28034 Mdot
.686 .28042 Mdot
.686 .28059 Mdot
.686 .28064 Mdot
.686 .28086 Mdot
.686 .28089 Mdot
.686 .28115 Mdot
.686 .2813 Mdot
.686 .28152 Mdot
.686 .28178 Mdot
.686 .2818 Mdot
.686 .28206 Mdot
.686 .28228 Mdot
.686 .28232 Mdot
.686 .28248 Mdot
.686 .2825 Mdot
.686 .28255 Mdot
.686 .28268 Mdot
.686 .28276 Mdot
.686 .28293 Mdot
.686 .28332 Mdot
.686 .28354 Mdot
.686 .28364 Mdot
.686 .28384 Mdot
.686 .28409 Mdot
.686 .28417 Mdot
.686 .28423 Mdot
.686 .28437 Mdot
.686 .28463 Mdot
.686 .2847 Mdot
.686 .28475 Mdot
.686 .28495 Mdot
.686 .28519 Mdot
.686 .2853 Mdot
.686 .28533 Mdot
.686 .28536 Mdot
.686 .28538 Mdot
.686 .28551 Mdot
.686 .28553 Mdot
.686 .28558 Mdot
.686 .28595 Mdot
.686 .28638 Mdot
.686 .28645 Mdot
.686 .28668 Mdot
.686 .28687 Mdot
.686 .28721 Mdot
.686 .28723 Mdot
.686 .28731 Mdot
.686 .28746 Mdot
.686 .28747 Mdot
.686 .28756 Mdot
.686 .28773 Mdot
.686 .28775 Mdot
.686 .28822 Mdot
.686 .28823 Mdot
.686 .28841 Mdot
.686 .28848 Mdot
.686 .28854 Mdot
.686 .28894 Mdot
.686 .28905 Mdot
.686 .28917 Mdot
.686 .28946 Mdot
.686 .28961 Mdot
.686 .28972 Mdot
.686 .28994 Mdot
.686 .28996 Mdot
.686 .29017 Mdot
.686 .29042 Mdot
.686 .29053 Mdot
.686 .29081 Mdot
.686 .2909 Mdot
.686 .29095 Mdot
.686 .29095 Mdot
.686 .29122 Mdot
.686 .29147 Mdot
.686 .29187 Mdot
.686 .29215 Mdot
.686 .29233 Mdot
.686 .29261 Mdot
.686 .29267 Mdot
.686 .29319 Mdot
.686 .29367 Mdot
.686 .29382 Mdot
.686 .29386 Mdot
.686 .29389 Mdot
.686 .29402 Mdot
.686 .29409 Mdot
.686 .2942 Mdot
.686 .29424 Mdot
.686 .29458 Mdot
.686 .29501 Mdot
.686 .29507 Mdot
.686 .29511 Mdot
.686 .29517 Mdot
.686 .29578 Mdot
.686 .29604 Mdot
.686 .29622 Mdot
.686 .29634 Mdot
.686 .29641 Mdot
.686 .29642 Mdot
.686 .29644 Mdot
.686 .29652 Mdot
.686 .29733 Mdot
.686 .29769 Mdot
.686 .29783 Mdot
.686 .29797 Mdot
.686 .29804 Mdot
.686 .29819 Mdot
.686 .29825 Mdot
.686 .29838 Mdot
.686 .29851 Mdot
.686 .29862 Mdot
.686 .29868 Mdot
.686 .29876 Mdot
.686 .29904 Mdot
.686 .29977 Mdot
.686 .29982 Mdot
.686 .29995 Mdot
.686 .29995 Mdot
.686 .30024 Mdot
.686 .30036 Mdot
.686 .3004 Mdot
.686 .30063 Mdot
.686 .30082 Mdot
.686 .30085 Mdot
.686 .30093 Mdot
.686 .30103 Mdot
.686 .30116 Mdot
.686 .30126 Mdot
.686 .30154 Mdot
.686 .30157 Mdot
.686 .3019 Mdot
.686 .30223 Mdot
.686 .30243 Mdot
.686 .30256 Mdot
.686 .30269 Mdot
.686 .30298 Mdot
.686 .3031 Mdot
.686 .30318 Mdot
.686 .30345 Mdot
.686 .3036 Mdot
.686 .30366 Mdot
.686 .30366 Mdot
.686 .30397 Mdot
.686 .30416 Mdot
.686 .30417 Mdot
.686 .30425 Mdot
.686 .30426 Mdot
.686 .30429 Mdot
.686 .30443 Mdot
.686 .30496 Mdot
.686 .30508 Mdot
.686 .30515 Mdot
.686 .30524 Mdot
.686 .30544 Mdot
.686 .30559 Mdot
.686 .30563 Mdot
.686 .30573 Mdot
.686 .3058 Mdot
.686 .30591 Mdot
.686 .30602 Mdot
.686 .30606 Mdot
.686 .30618 Mdot
.686 .30639 Mdot
.686 .30647 Mdot
.686 .30648 Mdot
.686 .30661 Mdot
.686 .30668 Mdot
.686 .30674 Mdot
.686 .3068 Mdot
.686 .30691 Mdot
.686 .30696 Mdot
.686 .30696 Mdot
.686 .30712 Mdot
.686 .30715 Mdot
.686 .30752 Mdot
.686 .30774 Mdot
.686 .30795 Mdot
.686 .30831 Mdot
.686 .30847 Mdot
.686 .3087 Mdot
.686 .3088 Mdot
.686 .30894 Mdot
.686 .30902 Mdot
.686 .30926 Mdot
.686 .30929 Mdot
.686 .30931 Mdot
.686 .30954 Mdot
.686 .31018 Mdot
.686 .31018 Mdot
.686 .31022 Mdot
.686 .31022 Mdot
.686 .31054 Mdot
.686 .3107 Mdot
.686 .31071 Mdot
.686 .31072 Mdot
.686 .31073 Mdot
.686 .31075 Mdot
.686 .31097 Mdot
.686 .31102 Mdot
.686 .31117 Mdot
.686 .3112 Mdot
.686 .3112 Mdot
.686 .31144 Mdot
.686 .31185 Mdot
.686 .31218 Mdot
.686 .3122 Mdot
.686 .31243 Mdot
.686 .31264 Mdot
.686 .31277 Mdot
.686 .31304 Mdot
.686 .31305 Mdot
.686 .31305 Mdot
.686 .31324 Mdot
.686 .31355 Mdot
.686 .31358 Mdot
.686 .31359 Mdot
.686 .3142 Mdot
.686 .31427 Mdot
.686 .31433 Mdot
.686 .31434 Mdot
.686 .31436 Mdot
.686 .31438 Mdot
.686 .31441 Mdot
.686 .31456 Mdot
.686 .3146 Mdot
.686 .31466 Mdot
.686 .31468 Mdot
.686 .31475 Mdot
.686 .31479 Mdot
.686 .31481 Mdot
.686 .31501 Mdot
.686 .31516 Mdot
.686 .3152 Mdot
.686 .31547 Mdot
.686 .31583 Mdot
.686 .31592 Mdot
.686 .31606 Mdot
.686 .31608 Mdot
.686 .31619 Mdot
.686 .31655 Mdot
.686 .31656 Mdot
.686 .31682 Mdot
.686 .31692 Mdot
.686 .31693 Mdot
.686 .31703 Mdot
.686 .31707 Mdot
.686 .31737 Mdot
.686 .31754 Mdot
.686 .31765 Mdot
.686 .31778 Mdot
.686 .31793 Mdot
.686 .31806 Mdot
.686 .31811 Mdot
.686 .31842 Mdot
.686 .31844 Mdot
.686 .31846 Mdot
.686 .31853 Mdot
.686 .31925 Mdot
.686 .31949 Mdot
.686 .31957 Mdot
.686 .31971 Mdot
.686 .31972 Mdot
.686 .31997 Mdot
.686 .31998 Mdot
.686 .32007 Mdot
.686 .32011 Mdot
.686 .32014 Mdot
.686 .32041 Mdot
.686 .32048 Mdot
.686 .3209 Mdot
.686 .3214 Mdot
.686 .32142 Mdot
.686 .32191 Mdot
.686 .32216 Mdot
.686 .32231 Mdot
.686 .32234 Mdot
.686 .32261 Mdot
.686 .32309 Mdot
.686 .32315 Mdot
.686 .32358 Mdot
.686 .32363 Mdot
.686 .32366 Mdot
.686 .32399 Mdot
.686 .32413 Mdot
.686 .32433 Mdot
.686 .32434 Mdot
.686 .325 Mdot
.686 .32508 Mdot
.686 .32527 Mdot
.686 .32544 Mdot
.686 .32611 Mdot
.686 .32614 Mdot
.686 .32621 Mdot
.686 .32636 Mdot
.686 .32642 Mdot
.686 .32644 Mdot
.686 .32656 Mdot
.686 .32667 Mdot
.686 .32668 Mdot
.686 .32685 Mdot
.686 .3269 Mdot
.686 .32705 Mdot
.686 .32741 Mdot
.686 .32759 Mdot
.686 .32766 Mdot
.686 .32781 Mdot
.686 .32788 Mdot
.686 .32806 Mdot
.686 .32815 Mdot
.686 .32818 Mdot
.686 .32834 Mdot
.686 .32849 Mdot
.686 .32851 Mdot
.686 .32893 Mdot
.686 .32902 Mdot
.686 .32912 Mdot
.686 .3292 Mdot
.686 .32928 Mdot
.686 .32931 Mdot
.686 .32937 Mdot
.686 .32952 Mdot
.686 .32962 Mdot
.686 .32967 Mdot
.686 .32974 Mdot
.686 .32981 Mdot
.686 .32984 Mdot
.686 .3299 Mdot
.686 .32993 Mdot
.686 .33001 Mdot
.686 .33003 Mdot
.686 .33064 Mdot
.686 .33073 Mdot
.686 .33102 Mdot
.686 .33115 Mdot
.686 .3313 Mdot
.686 .33164 Mdot
.686 .33166 Mdot
.686 .33191 Mdot
.686 .33192 Mdot
.686 .33194 Mdot
.686 .33206 Mdot
.686 .33218 Mdot
.686 .33231 Mdot
.686 .3327 Mdot
.686 .33284 Mdot
.686 .33316 Mdot
.686 .33316 Mdot
.686 .33316 Mdot
.686 .33326 Mdot
.686 .33343 Mdot
.686 .33345 Mdot
.686 .33378 Mdot
.686 .33384 Mdot
.686 .33385 Mdot
.686 .33387 Mdot
.686 .33396 Mdot
.686 .33399 Mdot
.686 .3341 Mdot
.686 .33428 Mdot
.686 .33431 Mdot
.686 .33477 Mdot
.686 .33483 Mdot
.686 .33503 Mdot
.686 .33523 Mdot
.686 .33528 Mdot
.686 .33546 Mdot
.686 .33561 Mdot
.686 .33583 Mdot
.686 .33602 Mdot
.686 .33602 Mdot
.686 .33604 Mdot
.686 .33658 Mdot
.686 .3367 Mdot
.686 .33684 Mdot
.686 .33693 Mdot
.686 .338 Mdot
.686 .33808 Mdot
.686 .33879 Mdot
.686 .33951 Mdot
.686 .33955 Mdot
.686 .3404 Mdot
.686 .3404 Mdot
.686 .34049 Mdot
.686 .34079 Mdot
.686 .34104 Mdot
.686 .3412 Mdot
.686 .34138 Mdot
.686 .34199 Mdot
.686 .34207 Mdot
.686 .34209 Mdot
.686 .34211 Mdot
.686 .34218 Mdot
.686 .34218 Mdot
.686 .34256 Mdot
.686 .34271 Mdot
.686 .34304 Mdot
.686 .34333 Mdot
.686 .34385 Mdot
.686 .34385 Mdot
.686 .34399 Mdot
.686 .344 Mdot
.686 .34417 Mdot
.686 .34427 Mdot
.686 .34435 Mdot
.686 .34515 Mdot
.686 .36384 Mdot
.686 .36442 Mdot
.686 .36447 Mdot
.686 .36455 Mdot
.686 .36467 Mdot
.686 .36468 Mdot
.686 .36479 Mdot
.686 .36479 Mdot
.686 .36517 Mdot
.686 .36537 Mdot
.686 .36561 Mdot
.686 .36573 Mdot
.686 .366 Mdot
.686 .366 Mdot
.686 .36605 Mdot
.686 .36607 Mdot
.686 .36608 Mdot
.686 .36614 Mdot
.686 .36659 Mdot
.686 .36672 Mdot
.686 .36683 Mdot
.686 .36701 Mdot
.686 .36723 Mdot
.686 .36729 Mdot
.686 .3673 Mdot
.686 .36792 Mdot
.686 .36794 Mdot
.686 .36848 Mdot
.686 .36899 Mdot
.686 .36905 Mdot
.686 .36983 Mdot
.686 .36989 Mdot
.686 .36999 Mdot
.686 .37008 Mdot
.686 .37048 Mdot
.686 .37049 Mdot
.686 .37049 Mdot
.686 .37063 Mdot
.686 .37079 Mdot
.686 .3709 Mdot
.686 .37103 Mdot
.686 .37107 Mdot
.686 .37121 Mdot
.686 .37136 Mdot
.686 .3714 Mdot
.686 .37174 Mdot
.686 .37176 Mdot
.686 .37189 Mdot
.686 .37197 Mdot
.686 .37199 Mdot
.686 .37206 Mdot
.686 .37207 Mdot
.686 .37208 Mdot
.686 .37213 Mdot
.686 .37236 Mdot
.686 .37238 Mdot
.686 .3725 Mdot
.686 .37257 Mdot
.686 .37257 Mdot
.686 .37258 Mdot
.686 .37281 Mdot
.686 .37291 Mdot
.686 .3732 Mdot
.686 .37329 Mdot
.686 .37338 Mdot
.686 .37346 Mdot
.686 .37348 Mdot
.686 .37348 Mdot
.686 .37367 Mdot
.686 .37368 Mdot
.686 .37393 Mdot
.686 .37404 Mdot
.686 .37413 Mdot
.686 .37435 Mdot
.686 .37441 Mdot
.686 .37486 Mdot
.686 .37487 Mdot
.686 .37493 Mdot
.686 .37495 Mdot
.686 .37499 Mdot
.686 .37502 Mdot
.686 .37507 Mdot
.686 .37512 Mdot
.686 .37515 Mdot
.686 .37523 Mdot
.686 .37534 Mdot
.686 .37538 Mdot
.686 .37541 Mdot
.686 .37546 Mdot
.686 .37552 Mdot
.686 .3756 Mdot
.686 .37566 Mdot
.686 .37596 Mdot
.686 .37598 Mdot
.686 .37609 Mdot
.686 .37621 Mdot
.686 .37623 Mdot
.686 .37629 Mdot
.686 .37643 Mdot
.686 .37647 Mdot
.686 .37658 Mdot
.686 .37664 Mdot
.686 .37676 Mdot
.686 .37703 Mdot
.686 .37714 Mdot
.686 .37718 Mdot
.686 .3773 Mdot
.686 .37731 Mdot
.686 .37738 Mdot
.686 .37747 Mdot
.686 .37749 Mdot
.686 .37753 Mdot
.686 .37764 Mdot
.686 .3777 Mdot
.686 .37771 Mdot
.686 .3782 Mdot
.686 .37832 Mdot
.686 .37847 Mdot
.686 .37852 Mdot
.686 .379 Mdot
.686 .37901 Mdot
.686 .37916 Mdot
.686 .37926 Mdot
.686 .3795 Mdot
.686 .37952 Mdot
.686 .37956 Mdot
.686 .37987 Mdot
.686 .37991 Mdot
.686 .38026 Mdot
.686 .38046 Mdot
.686 .38048 Mdot
.686 .3806 Mdot
.686 .38077 Mdot
.686 .38113 Mdot
.686 .38115 Mdot
.686 .38151 Mdot
.686 .38182 Mdot
.686 .38187 Mdot
.686 .38206 Mdot
.686 .38208 Mdot
.686 .38211 Mdot
.686 .38218 Mdot
.686 .38219 Mdot
.686 .38237 Mdot
.686 .38238 Mdot
.686 .38248 Mdot
.686 .38254 Mdot
.686 .38271 Mdot
.686 .38324 Mdot
.686 .38329 Mdot
.686 .38331 Mdot
.686 .38332 Mdot
.686 .38355 Mdot
.686 .38358 Mdot
.686 .38368 Mdot
.686 .38379 Mdot
.686 .38388 Mdot
.686 .38396 Mdot
.686 .38409 Mdot
.686 .3843 Mdot
.686 .38433 Mdot
.686 .3844 Mdot
.686 .38441 Mdot
.686 .38449 Mdot
.686 .38467 Mdot
.686 .38468 Mdot
.686 .38494 Mdot
.686 .38502 Mdot
.686 .38504 Mdot
.686 .38514 Mdot
.686 .38521 Mdot
.686 .38547 Mdot
.686 .38566 Mdot
.686 .38569 Mdot
.686 .38581 Mdot
.686 .38595 Mdot
.686 .38596 Mdot
.686 .38599 Mdot
.686 .38605 Mdot
.686 .38606 Mdot
.686 .3861 Mdot
.686 .38613 Mdot
.686 .38624 Mdot
.686 .38626 Mdot
.686 .38628 Mdot
.686 .38629 Mdot
.686 .3863 Mdot
.686 .38634 Mdot
.686 .38639 Mdot
.686 .38684 Mdot
.686 .38684 Mdot
.686 .38687 Mdot
.686 .38709 Mdot
.686 .38723 Mdot
.686 .38724 Mdot
.686 .38724 Mdot
.686 .38744 Mdot
.686 .38753 Mdot
.686 .38768 Mdot
.686 .38785 Mdot
.686 .38787 Mdot
.686 .38811 Mdot
.686 .38841 Mdot
.686 .38858 Mdot
.686 .38858 Mdot
.686 .3886 Mdot
.686 .38872 Mdot
.686 .38875 Mdot
.686 .38891 Mdot
.686 .38893 Mdot
.686 .38893 Mdot
.686 .38894 Mdot
.686 .38895 Mdot
.686 .38906 Mdot
.686 .38929 Mdot
.686 .38929 Mdot
.686 .38932 Mdot
.686 .38932 Mdot
.686 .38979 Mdot
.686 .38996 Mdot
.686 .38997 Mdot
.686 .38999 Mdot
.686 .39017 Mdot
.686 .39023 Mdot
.686 .39033 Mdot
.686 .3904 Mdot
.686 .39057 Mdot
.686 .39069 Mdot
.686 .39095 Mdot
.686 .3911 Mdot
.686 .39126 Mdot
.686 .39153 Mdot
.686 .39156 Mdot
.686 .39167 Mdot
.686 .39167 Mdot
.686 .39171 Mdot
.686 .39179 Mdot
.686 .39183 Mdot
.686 .39188 Mdot
.686 .39193 Mdot
.686 .39202 Mdot
.686 .39203 Mdot
.686 .39209 Mdot
.686 .39224 Mdot
.686 .39233 Mdot
.686 .39235 Mdot
.686 .39244 Mdot
.686 .39251 Mdot
.686 .39257 Mdot
.686 .39264 Mdot
.686 .39267 Mdot
.686 .39278 Mdot
.686 .39292 Mdot
.686 .39299 Mdot
.686 .39304 Mdot
.686 .39313 Mdot
.686 .39352 Mdot
.686 .39362 Mdot
.686 .39364 Mdot
.686 .39365 Mdot
.686 .3937 Mdot
.686 .39371 Mdot
.686 .39385 Mdot
.686 .39407 Mdot
.686 .39408 Mdot
.686 .39412 Mdot
.686 .39423 Mdot
.686 .39443 Mdot
.686 .39449 Mdot
.686 .39457 Mdot
.686 .39478 Mdot
.686 .39488 Mdot
.686 .39497 Mdot
.686 .39512 Mdot
.686 .39536 Mdot
.686 .3956 Mdot
.686 .39562 Mdot
.686 .39582 Mdot
.686 .3959 Mdot
.686 .39599 Mdot
.686 .39607 Mdot
.686 .39613 Mdot
.686 .39615 Mdot
.686 .39629 Mdot
.686 .39645 Mdot
.686 .39648 Mdot
.686 .39657 Mdot
.686 .39678 Mdot
.686 .39678 Mdot
.686 .39688 Mdot
.686 .39691 Mdot
.686 .39745 Mdot
.686 .39765 Mdot
.686 .39771 Mdot
.686 .39775 Mdot
.686 .39783 Mdot
.686 .39792 Mdot
.686 .39802 Mdot
.686 .39806 Mdot
.686 .39817 Mdot
.686 .39822 Mdot
.686 .39833 Mdot
.686 .39843 Mdot
.686 .39869 Mdot
.686 .39928 Mdot
.686 .39934 Mdot
.686 .39935 Mdot
.686 .39936 Mdot
.686 .39941 Mdot
.686 .3995 Mdot
.686 .39963 Mdot
.686 .39982 Mdot
.686 .40027 Mdot
.686 .40031 Mdot
.686 .40034 Mdot
.686 .40038 Mdot
.686 .4007 Mdot
.686 .40094 Mdot
.686 .40097 Mdot
.686 .40105 Mdot
.686 .4011 Mdot
.686 .40119 Mdot
.686 .40122 Mdot
.686 .40125 Mdot
.686 .40136 Mdot
.686 .40171 Mdot
.686 .40209 Mdot
.686 .40213 Mdot
.686 .40234 Mdot
.686 .40247 Mdot
.686 .40267 Mdot
.686 .40296 Mdot
.686 .40315 Mdot
.686 .40334 Mdot
.686 .40334 Mdot
.686 .40338 Mdot
.686 .40344 Mdot
.686 .40365 Mdot
.686 .40372 Mdot
.686 .40391 Mdot
.686 .40406 Mdot
.686 .40408 Mdot
.686 .40424 Mdot
.686 .40431 Mdot
.686 .40442 Mdot
.686 .40464 Mdot
.686 .40473 Mdot
.686 .4048 Mdot
.686 .4051 Mdot
.686 .40514 Mdot
.686 .40519 Mdot
.686 .40533 Mdot
.686 .40533 Mdot
.686 .40567 Mdot
.686 .40569 Mdot
.686 .40581 Mdot
.686 .40588 Mdot
.686 .40588 Mdot
.686 .40599 Mdot
.686 .40605 Mdot
.686 .40606 Mdot
.686 .40632 Mdot
.686 .40645 Mdot
.686 .40662 Mdot
.686 .40667 Mdot
.686 .40699 Mdot
.686 .40725 Mdot
.686 .40729 Mdot
.686 .40731 Mdot
.686 .4074 Mdot
.686 .40741 Mdot
.686 .40744 Mdot
.686 .40746 Mdot
.686 .40754 Mdot
.686 .40772 Mdot
.686 .40786 Mdot
.686 .40789 Mdot
.686 .40795 Mdot
.686 .40814 Mdot
.686 .40824 Mdot
.686 .40828 Mdot
.686 .40834 Mdot
.686 .40852 Mdot
.686 .40867 Mdot
.686 .40874 Mdot
.686 .4089 Mdot
.686 .40918 Mdot
.686 .40931 Mdot
.686 .40937 Mdot
.686 .40946 Mdot
.686 .4095 Mdot
.686 .40952 Mdot
.686 .40963 Mdot
.686 .40966 Mdot
.686 .40982 Mdot
.686 .41001 Mdot
.686 .41002 Mdot
.686 .41021 Mdot
.686 .41038 Mdot
.686 .41048 Mdot
.686 .41052 Mdot
.686 .41067 Mdot
.686 .41069 Mdot
.686 .41086 Mdot
.686 .41089 Mdot
.686 .41102 Mdot
.686 .41107 Mdot
.686 .41115 Mdot
.686 .41115 Mdot
.686 .41151 Mdot
.686 .41158 Mdot
.686 .41184 Mdot
.686 .41185 Mdot
.686 .41188 Mdot
.686 .41193 Mdot
.686 .41196 Mdot
.686 .41197 Mdot
.686 .41201 Mdot
.686 .41214 Mdot
.686 .4122 Mdot
.686 .41241 Mdot
.686 .41244 Mdot
.686 .4125 Mdot
.686 .41259 Mdot
.686 .41263 Mdot
.686 .4127 Mdot
.686 .41276 Mdot
.686 .41293 Mdot
.686 .41296 Mdot
.686 .413 Mdot
.686 .41303 Mdot
.686 .41306 Mdot
.686 .41308 Mdot
.686 .4131 Mdot
.686 .41316 Mdot
.686 .4132 Mdot
.686 .41324 Mdot
.686 .41332 Mdot
.686 .41359 Mdot
.686 .41379 Mdot
.686 .41385 Mdot
.686 .41399 Mdot
.686 .41408 Mdot
.686 .41409 Mdot
.686 .4141 Mdot
.686 .41414 Mdot
.686 .41424 Mdot
.686 .41439 Mdot
.686 .41444 Mdot
.686 .41457 Mdot
.686 .41461 Mdot
.686 .41483 Mdot
.686 .41483 Mdot
.686 .41484 Mdot
.686 .41489 Mdot
.686 .415 Mdot
.686 .41501 Mdot
.686 .41519 Mdot
.686 .41522 Mdot
.686 .41529 Mdot
.686 .41537 Mdot
.686 .41539 Mdot
.686 .41546 Mdot
.686 .4156 Mdot
.686 .41567 Mdot
.686 .41568 Mdot
.686 .41568 Mdot
.686 .41589 Mdot
.686 .41594 Mdot
.686 .41599 Mdot
.686 .41603 Mdot
.686 .41644 Mdot
.686 .41647 Mdot
.686 .41675 Mdot
.686 .41703 Mdot
.686 .41704 Mdot
.686 .41737 Mdot
.686 .41737 Mdot
.686 .41741 Mdot
.686 .41752 Mdot
.686 .41762 Mdot
.686 .41768 Mdot
.686 .41775 Mdot
.686 .41799 Mdot
.686 .41802 Mdot
.686 .41802 Mdot
.686 .41804 Mdot
.686 .41806 Mdot
.686 .41806 Mdot
.686 .41821 Mdot
.686 .41827 Mdot
.686 .41839 Mdot
.686 .4185 Mdot
.686 .41871 Mdot
.686 .41871 Mdot
.686 .41876 Mdot
.686 .41877 Mdot
.686 .41883 Mdot
.686 .41887 Mdot
.686 .4189 Mdot
.686 .41921 Mdot
.688 .26816 Mdot
.688 .26824 Mdot
.688 .26846 Mdot
.688 .26858 Mdot
.688 .26871 Mdot
.688 .2688 Mdot
.688 .26886 Mdot
.688 .26891 Mdot
.688 .26911 Mdot
.688 .26923 Mdot
.688 .26936 Mdot
.688 .26955 Mdot
.688 .2696 Mdot
.688 .26987 Mdot
.688 .26999 Mdot
.688 .27008 Mdot
.688 .27037 Mdot
.688 .27061 Mdot
.688 .2708 Mdot
.688 .27091 Mdot
.688 .27094 Mdot
.688 .27108 Mdot
.688 .27136 Mdot
.688 .27177 Mdot
.688 .2718 Mdot
.688 .27181 Mdot
.688 .27186 Mdot
.688 .27196 Mdot
.688 .27201 Mdot
.688 .27238 Mdot
.688 .27245 Mdot
.688 .27268 Mdot
.688 .2727 Mdot
.688 .27281 Mdot
.688 .27306 Mdot
.688 .27361 Mdot
.688 .27376 Mdot
.688 .27376 Mdot
.688 .27384 Mdot
.688 .27409 Mdot
.688 .27419 Mdot
.688 .27432 Mdot
.688 .27432 Mdot
.688 .27477 Mdot
.688 .27486 Mdot
.688 .27519 Mdot
.688 .27521 Mdot
.688 .27547 Mdot
.688 .27562 Mdot
.688 .27591 Mdot
.688 .27593 Mdot
.688 .27597 Mdot
.688 .27612 Mdot
.688 .2762 Mdot
.688 .27627 Mdot
.688 .27647 Mdot
.688 .27659 Mdot
.688 .27663 Mdot
.688 .27675 Mdot
.688 .27695 Mdot
.688 .2771 Mdot
.688 .27721 Mdot
.688 .27724 Mdot
.688 .27726 Mdot
.688 .27738 Mdot
.688 .27765 Mdot
.688 .27801 Mdot
.688 .27805 Mdot
.688 .27811 Mdot
.688 .27847 Mdot
.688 .27848 Mdot
.688 .27863 Mdot
.688 .27878 Mdot
.688 .27887 Mdot
.688 .27893 Mdot
.688 .27893 Mdot
.688 .27897 Mdot
.688 .27907 Mdot
.688 .27914 Mdot
.688 .27929 Mdot
.688 .27945 Mdot
.688 .27945 Mdot
.688 .27962 Mdot
.688 .27964 Mdot
.688 .27966 Mdot
.688 .28025 Mdot
.688 .2804 Mdot
.688 .28042 Mdot
.688 .28046 Mdot
.688 .28053 Mdot
.688 .28058 Mdot
.688 .2807 Mdot
.688 .28105 Mdot
.688 .28121 Mdot
.688 .28123 Mdot
.688 .28135 Mdot
.688 .28139 Mdot
.688 .28145 Mdot
.688 .28165 Mdot
.688 .28203 Mdot
.688 .28208 Mdot
.688 .28239 Mdot
.688 .28253 Mdot
.688 .28267 Mdot
.688 .28293 Mdot
.688 .28303 Mdot
.688 .28303 Mdot
.688 .28317 Mdot
.688 .2833 Mdot
.688 .28348 Mdot
.688 .28348 Mdot
.688 .28366 Mdot
.688 .28392 Mdot
.688 .28413 Mdot
.688 .28448 Mdot
.688 .28452 Mdot
.688 .28458 Mdot
.688 .28461 Mdot
.688 .28462 Mdot
.688 .28464 Mdot
.688 .28475 Mdot
.688 .28488 Mdot
.688 .28498 Mdot
.688 .28509 Mdot
.688 .28523 Mdot
.688 .28538 Mdot
.688 .28554 Mdot
.688 .28559 Mdot
.688 .28566 Mdot
.688 .2859 Mdot
.688 .28591 Mdot
.688 .28636 Mdot
.688 .28636 Mdot
.688 .28643 Mdot
.688 .28656 Mdot
.688 .2866 Mdot
.688 .28686 Mdot
.688 .28694 Mdot
.688 .28709 Mdot
.688 .28722 Mdot
.688 .28762 Mdot
.688 .28765 Mdot
.688 .2879 Mdot
.688 .28793 Mdot
.688 .28805 Mdot
.688 .2882 Mdot
.688 .28823 Mdot
.688 .28853 Mdot
.688 .28861 Mdot
.688 .28908 Mdot
.688 .28928 Mdot
.688 .2893 Mdot
.688 .28956 Mdot
.688 .28988 Mdot
.688 .29008 Mdot
.688 .29017 Mdot
.688 .29024 Mdot
.688 .29029 Mdot
.688 .29049 Mdot
.688 .2906 Mdot
.688 .29064 Mdot
.688 .29068 Mdot
.688 .29078 Mdot
.688 .29087 Mdot
.688 .29109 Mdot
.688 .29113 Mdot
.688 .29114 Mdot
.688 .29115 Mdot
.688 .29173 Mdot
.688 .29177 Mdot
.688 .29211 Mdot
.688 .29231 Mdot
.688 .29234 Mdot
.688 .29244 Mdot
.688 .29248 Mdot
.688 .29252 Mdot
.688 .29257 Mdot
.688 .2926 Mdot
.688 .29267 Mdot
.688 .29279 Mdot
.688 .29285 Mdot
.688 .293 Mdot
.688 .29322 Mdot
.688 .2934 Mdot
.688 .29361 Mdot
.688 .29386 Mdot
.688 .29398 Mdot
.688 .29405 Mdot
.688 .2945 Mdot
.688 .29453 Mdot
.688 .29459 Mdot
.688 .29506 Mdot
.688 .29522 Mdot
.688 .29532 Mdot
.688 .2954 Mdot
.688 .29568 Mdot
.688 .2957 Mdot
.688 .29637 Mdot
.688 .2966 Mdot
.688 .29666 Mdot
.688 .2967 Mdot
.688 .29672 Mdot
.688 .29674 Mdot
.688 .29676 Mdot
.688 .29678 Mdot
.688 .29686 Mdot
.688 .29696 Mdot
.688 .29714 Mdot
.688 .29747 Mdot
.688 .29748 Mdot
.688 .29762 Mdot
.688 .29776 Mdot
.688 .29798 Mdot
.688 .29803 Mdot
.688 .29845 Mdot
.688 .29856 Mdot
.688 .29881 Mdot
.688 .29885 Mdot
.688 .29917 Mdot
.688 .29918 Mdot
.688 .29931 Mdot
.688 .29933 Mdot
.688 .29954 Mdot
.688 .29961 Mdot
.688 .29973 Mdot
.688 .29987 Mdot
.688 .29989 Mdot
.688 .3 Mdot
.688 .30024 Mdot
.688 .30036 Mdot
.688 .3004 Mdot
.688 .30043 Mdot
.688 .30051 Mdot
.688 .30059 Mdot
.688 .30067 Mdot
.688 .30085 Mdot
.688 .30092 Mdot
.688 .30094 Mdot
.688 .30097 Mdot
.688 .30129 Mdot
.688 .30161 Mdot
.688 .30194 Mdot
.688 .30202 Mdot
.688 .30226 Mdot
.688 .30248 Mdot
.688 .30262 Mdot
.688 .30264 Mdot
.688 .3028 Mdot
.688 .30311 Mdot
.688 .30313 Mdot
.688 .30314 Mdot
.688 .30322 Mdot
.688 .30353 Mdot
.688 .30365 Mdot
.688 .30381 Mdot
.688 .30392 Mdot
.688 .304 Mdot
.688 .30408 Mdot
.688 .30416 Mdot
.688 .30435 Mdot
.688 .30474 Mdot
.688 .3048 Mdot
.688 .30483 Mdot
.688 .30489 Mdot
.688 .30497 Mdot
.688 .30514 Mdot
.688 .30533 Mdot
.688 .3054 Mdot
.688 .3055 Mdot
.688 .30552 Mdot
.688 .30588 Mdot
.688 .30612 Mdot
.688 .30642 Mdot
.688 .30648 Mdot
.688 .30661 Mdot
.688 .30665 Mdot
.688 .30702 Mdot
.688 .30715 Mdot
.688 .30757 Mdot
.688 .3077 Mdot
.688 .30792 Mdot
.688 .30806 Mdot
.688 .30814 Mdot
.688 .30844 Mdot
.688 .30864 Mdot
.688 .3087 Mdot
.688 .30887 Mdot
.688 .30898 Mdot
.688 .30904 Mdot
.688 .30911 Mdot
.688 .30921 Mdot
.688 .30927 Mdot
.688 .30939 Mdot
.688 .30979 Mdot
.688 .30982 Mdot
.688 .30995 Mdot
.688 .31008 Mdot
.688 .31016 Mdot
.688 .31054 Mdot
.688 .3108 Mdot
.688 .31108 Mdot
.688 .31118 Mdot
.688 .31124 Mdot
.688 .31171 Mdot
.688 .31171 Mdot
.688 .31174 Mdot
.688 .31179 Mdot
.688 .31201 Mdot
.688 .31205 Mdot
.688 .31217 Mdot
.688 .31218 Mdot
.688 .31266 Mdot
.688 .31274 Mdot
.688 .31304 Mdot
.688 .31304 Mdot
.688 .31332 Mdot
.688 .3135 Mdot
.688 .31364 Mdot
.688 .31373 Mdot
.688 .31391 Mdot
.688 .31403 Mdot
.688 .31417 Mdot
.688 .31424 Mdot
.688 .31432 Mdot
.688 .31458 Mdot
.688 .3148 Mdot
.688 .31498 Mdot
.688 .31501 Mdot
.688 .31523 Mdot
.688 .31544 Mdot
.688 .31547 Mdot
.688 .3155 Mdot
.688 .31555 Mdot
.688 .31566 Mdot
.688 .31575 Mdot
.688 .31584 Mdot
.688 .31585 Mdot
.688 .31632 Mdot
.688 .31635 Mdot
.688 .31641 Mdot
.688 .31668 Mdot
.688 .31669 Mdot
.688 .3168 Mdot
.688 .31711 Mdot
.688 .3173 Mdot
.688 .31759 Mdot
.688 .31764 Mdot
.688 .31764 Mdot
.688 .31771 Mdot
.688 .31787 Mdot
.688 .31787 Mdot
.688 .31797 Mdot
.688 .31822 Mdot
.688 .3184 Mdot
.688 .31848 Mdot
.688 .31849 Mdot
.688 .31861 Mdot
.688 .31867 Mdot
.688 .31916 Mdot
.688 .3194 Mdot
.688 .31943 Mdot
.688 .3197 Mdot
.688 .32029 Mdot
.688 .32037 Mdot
.688 .32038 Mdot
.688 .32095 Mdot
.688 .32109 Mdot
.688 .32126 Mdot
.688 .32145 Mdot
.688 .32147 Mdot
.688 .32158 Mdot
.688 .32166 Mdot
.688 .32168 Mdot
.688 .32173 Mdot
.688 .3219 Mdot
.688 .32193 Mdot
.688 .32223 Mdot
.688 .32256 Mdot
.688 .32283 Mdot
.688 .3229 Mdot
.688 .32312 Mdot
.688 .32323 Mdot
.688 .32336 Mdot
.688 .32342 Mdot
.688 .32346 Mdot
.688 .32374 Mdot
.688 .32413 Mdot
.688 .32432 Mdot
.688 .32468 Mdot
.688 .32484 Mdot
.688 .32486 Mdot
.688 .32488 Mdot
.688 .3249 Mdot
.688 .32494 Mdot
.688 .32499 Mdot
.688 .32527 Mdot
.688 .32527 Mdot
.688 .32556 Mdot
.688 .32584 Mdot
.688 .32597 Mdot
.688 .32616 Mdot
.688 .32624 Mdot
.688 .32625 Mdot
.688 .32636 Mdot
.688 .32646 Mdot
.688 .32653 Mdot
.688 .32681 Mdot
.688 .3271 Mdot
.688 .32711 Mdot
.688 .32745 Mdot
.688 .32779 Mdot
.688 .32791 Mdot
.688 .32798 Mdot
.688 .328 Mdot
.688 .32808 Mdot
.688 .32847 Mdot
.688 .32867 Mdot
.688 .32914 Mdot
.688 .32918 Mdot
.688 .32941 Mdot
.688 .32945 Mdot
.688 .32951 Mdot
.688 .32971 Mdot
.688 .32999 Mdot
.688 .33002 Mdot
.688 .33038 Mdot
.688 .3306 Mdot
.688 .33067 Mdot
.688 .3309 Mdot
.688 .33106 Mdot
.688 .33129 Mdot
.688 .33138 Mdot
.688 .33141 Mdot
.688 .33156 Mdot
.688 .33179 Mdot
.688 .33185 Mdot
.688 .33192 Mdot
.688 .33197 Mdot
.688 .33251 Mdot
.688 .33278 Mdot
.688 .3328 Mdot
.688 .33294 Mdot
.688 .33329 Mdot
.688 .33333 Mdot
.688 .33364 Mdot
.688 .33395 Mdot
.688 .33409 Mdot
.688 .33412 Mdot
.688 .33453 Mdot
.688 .33497 Mdot
.688 .33497 Mdot
.688 .33522 Mdot
.688 .33523 Mdot
.688 .33541 Mdot
.688 .33541 Mdot
.688 .33564 Mdot
.688 .33589 Mdot
.688 .33596 Mdot
.688 .33604 Mdot
.688 .33604 Mdot
.688 .33632 Mdot
.688 .33643 Mdot
.688 .33685 Mdot
.688 .33736 Mdot
.688 .33767 Mdot
.688 .33783 Mdot
.688 .33793 Mdot
.688 .33805 Mdot
.688 .33808 Mdot
.688 .33852 Mdot
.688 .33866 Mdot
.688 .33934 Mdot
.688 .33945 Mdot
.688 .33964 Mdot
.688 .33972 Mdot
.688 .33974 Mdot
.688 .3398 Mdot
.688 .34058 Mdot
.688 .3411 Mdot
.688 .34138 Mdot
.688 .34143 Mdot
.688 .34164 Mdot
.688 .34199 Mdot
.688 .34246 Mdot
.688 .34301 Mdot
.688 .34317 Mdot
.688 .34339 Mdot
.688 .34392 Mdot
.688 .344 Mdot
.688 .34437 Mdot
.688 .3446 Mdot
.688 .34484 Mdot
.688 .34521 Mdot
.688 .34531 Mdot
.688 .34542 Mdot
.688 .34559 Mdot
.688 .34584 Mdot
.688 .34606 Mdot
.688 .34649 Mdot
.688 .34663 Mdot
.688 .36346 Mdot
.688 .36356 Mdot
.688 .36387 Mdot
.688 .36403 Mdot
.688 .36422 Mdot
.688 .36434 Mdot
.688 .36442 Mdot
.688 .36449 Mdot
.688 .36476 Mdot
.688 .36493 Mdot
.688 .3651 Mdot
.688 .36537 Mdot
.688 .36543 Mdot
.688 .36581 Mdot
.688 .36597 Mdot
.688 .36609 Mdot
.688 .36649 Mdot
.688 .36683 Mdot
.688 .36709 Mdot
.688 .36724 Mdot
.688 .36728 Mdot
.688 .36748 Mdot
.688 .36786 Mdot
.688 .36842 Mdot
.688 .36847 Mdot
.688 .36848 Mdot
.688 .36854 Mdot
.688 .36868 Mdot
.688 .36876 Mdot
.688 .36926 Mdot
.688 .36936 Mdot
.688 .36967 Mdot
.688 .3697 Mdot
.688 .36978 Mdot
.688 .36986 Mdot
.688 .36998 Mdot
.688 .3702 Mdot
.688 .37057 Mdot
.688 .37087 Mdot
.688 .37095 Mdot
.688 .37116 Mdot
.688 .37116 Mdot
.688 .37122 Mdot
.688 .37127 Mdot
.688 .37145 Mdot
.688 .37161 Mdot
.688 .37161 Mdot
.688 .37174 Mdot
.688 .37175 Mdot
.688 .37193 Mdot
.688 .37194 Mdot
.688 .37226 Mdot
.688 .37255 Mdot
.688 .37258 Mdot
.688 .37268 Mdot
.688 .3729 Mdot
.688 .37313 Mdot
.688 .37316 Mdot
.688 .37341 Mdot
.688 .37351 Mdot
.688 .37352 Mdot
.688 .37373 Mdot
.688 .37412 Mdot
.688 .37415 Mdot
.688 .3742 Mdot
.688 .37425 Mdot
.688 .37441 Mdot
.688 .37452 Mdot
.688 .37455 Mdot
.688 .37461 Mdot
.688 .37478 Mdot
.688 .37489 Mdot
.688 .37506 Mdot
.688 .37511 Mdot
.688 .37527 Mdot
.688 .37553 Mdot
.688 .37555 Mdot
.688 .37576 Mdot
.688 .3759 Mdot
.688 .37594 Mdot
.688 .37597 Mdot
.688 .37614 Mdot
.688 .37617 Mdot
.688 .37651 Mdot
.688 .37666 Mdot
.688 .37694 Mdot
.688 .377 Mdot
.688 .37701 Mdot
.688 .37706 Mdot
.688 .37715 Mdot
.688 .3774 Mdot
.688 .37764 Mdot
.688 .37766 Mdot
.688 .37786 Mdot
.688 .37807 Mdot
.688 .37812 Mdot
.688 .37819 Mdot
.688 .37827 Mdot
.688 .37828 Mdot
.688 .37834 Mdot
.688 .37847 Mdot
.688 .37857 Mdot
.688 .37877 Mdot
.688 .37899 Mdot
.688 .37899 Mdot
.688 .37918 Mdot
.688 .37922 Mdot
.688 .37925 Mdot
.688 .37927 Mdot
.688 .37928 Mdot
.688 .3793 Mdot
.688 .37941 Mdot
.688 .37967 Mdot
.688 .37981 Mdot
.688 .38009 Mdot
.688 .3803 Mdot
.688 .38033 Mdot
.688 .38037 Mdot
.688 .38047 Mdot
.688 .38055 Mdot
.688 .3807 Mdot
.688 .38076 Mdot
.688 .38096 Mdot
.688 .38119 Mdot
.688 .38141 Mdot
.688 .38144 Mdot
.688 .38155 Mdot
.688 .38159 Mdot
.688 .38161 Mdot
.688 .38167 Mdot
.688 .38174 Mdot
.688 .38176 Mdot
.688 .3819 Mdot
.688 .38202 Mdot
.688 .38212 Mdot
.688 .38254 Mdot
.688 .38255 Mdot
.688 .3826 Mdot
.688 .38303 Mdot
.688 .38323 Mdot
.688 .38325 Mdot
.688 .38343 Mdot
.688 .38378 Mdot
.688 .38382 Mdot
.688 .38391 Mdot
.688 .38392 Mdot
.688 .38398 Mdot
.688 .38411 Mdot
.688 .38429 Mdot
.688 .38436 Mdot
.688 .38436 Mdot
.688 .38448 Mdot
.688 .38453 Mdot
.688 .38453 Mdot
.688 .38457 Mdot
.688 .38478 Mdot
.688 .38492 Mdot
.688 .38514 Mdot
.688 .38522 Mdot
.688 .38523 Mdot
.688 .38543 Mdot
.688 .38547 Mdot
.688 .38549 Mdot
.688 .38583 Mdot
.688 .38584 Mdot
.688 .38591 Mdot
.688 .38597 Mdot
.688 .38605 Mdot
.688 .38609 Mdot
.688 .3861 Mdot
.688 .38613 Mdot
.688 .38628 Mdot
.688 .38644 Mdot
.688 .38646 Mdot
.688 .3866 Mdot
.688 .38675 Mdot
.688 .38694 Mdot
.688 .387 Mdot
.688 .38705 Mdot
.688 .38715 Mdot
.688 .38724 Mdot
.688 .38737 Mdot
.688 .38743 Mdot
.688 .38754 Mdot
.688 .38767 Mdot
.688 .38787 Mdot
.688 .38787 Mdot
.688 .38809 Mdot
.688 .38815 Mdot
.688 .3885 Mdot
.688 .3885 Mdot
.688 .38859 Mdot
.688 .38862 Mdot
.688 .38878 Mdot
.688 .38882 Mdot
.688 .38884 Mdot
.688 .38884 Mdot
.688 .38918 Mdot
.688 .38922 Mdot
.688 .3893 Mdot
.688 .3895 Mdot
.688 .38969 Mdot
.688 .38997 Mdot
.688 .39003 Mdot
.688 .39012 Mdot
.688 .39021 Mdot
.688 .39024 Mdot
.688 .39028 Mdot
.688 .39053 Mdot
.688 .39061 Mdot
.688 .39066 Mdot
.688 .39073 Mdot
.688 .39078 Mdot
.688 .39083 Mdot
.688 .3909 Mdot
.688 .39102 Mdot
.688 .39107 Mdot
.688 .39121 Mdot
.688 .39143 Mdot
.688 .39149 Mdot
.688 .39159 Mdot
.688 .39175 Mdot
.688 .39184 Mdot
.688 .39215 Mdot
.688 .39225 Mdot
.688 .39251 Mdot
.688 .39254 Mdot
.688 .39264 Mdot
.688 .39268 Mdot
.688 .3929 Mdot
.688 .39307 Mdot
.688 .39334 Mdot
.688 .39335 Mdot
.688 .39342 Mdot
.688 .39348 Mdot
.688 .39362 Mdot
.688 .39374 Mdot
.688 .3938 Mdot
.688 .39384 Mdot
.688 .39386 Mdot
.688 .3939 Mdot
.688 .39419 Mdot
.688 .39433 Mdot
.688 .39438 Mdot
.688 .39444 Mdot
.688 .3945 Mdot
.688 .39458 Mdot
.688 .3947 Mdot
.688 .39478 Mdot
.688 .39501 Mdot
.688 .39506 Mdot
.688 .39507 Mdot
.688 .39509 Mdot
.688 .39531 Mdot
.688 .39543 Mdot
.688 .39545 Mdot
.688 .39555 Mdot
.688 .39571 Mdot
.688 .39588 Mdot
.688 .39594 Mdot
.688 .39618 Mdot
.688 .39641 Mdot
.688 .39664 Mdot
.688 .39667 Mdot
.688 .39668 Mdot
.688 .39673 Mdot
.688 .39687 Mdot
.688 .39692 Mdot
.688 .39698 Mdot
.688 .39704 Mdot
.688 .39705 Mdot
.688 .39708 Mdot
.688 .39718 Mdot
.688 .39735 Mdot
.688 .39743 Mdot
.688 .39745 Mdot
.688 .39754 Mdot
.688 .39763 Mdot
.688 .39768 Mdot
.688 .39784 Mdot
.688 .39785 Mdot
.688 .39794 Mdot
.688 .39795 Mdot
.688 .39819 Mdot
.688 .39822 Mdot
.688 .3984 Mdot
.688 .39847 Mdot
.688 .39878 Mdot
.688 .39881 Mdot
.688 .39898 Mdot
.688 .39908 Mdot
.688 .39918 Mdot
.688 .39919 Mdot
.688 .39943 Mdot
.688 .39956 Mdot
.688 .39963 Mdot
.688 .39969 Mdot
.688 .3997 Mdot
.688 .39972 Mdot
.688 .39973 Mdot
.688 .39975 Mdot
.688 .39977 Mdot
.688 .39982 Mdot
.688 .39999 Mdot
.688 .40048 Mdot
.688 .40049 Mdot
.688 .40069 Mdot
.688 .40075 Mdot
.688 .40082 Mdot
.688 .40094 Mdot
.688 .40128 Mdot
.688 .40133 Mdot
.688 .40135 Mdot
.688 .40167 Mdot
.688 .40173 Mdot
.688 .40181 Mdot
.688 .40199 Mdot
.688 .40215 Mdot
.688 .40227 Mdot
.688 .40244 Mdot
.688 .40254 Mdot
.688 .40259 Mdot
.688 .40268 Mdot
.688 .40273 Mdot
.688 .40275 Mdot
.688 .40278 Mdot
.688 .40281 Mdot
.688 .40284 Mdot
.688 .40291 Mdot
.688 .40294 Mdot
.688 .40308 Mdot
.688 .40333 Mdot
.688 .40336 Mdot
.688 .40378 Mdot
.688 .40379 Mdot
.688 .40379 Mdot
.688 .40382 Mdot
.688 .40399 Mdot
.688 .40405 Mdot
.688 .40412 Mdot
.688 .40415 Mdot
.688 .40418 Mdot
.688 .40426 Mdot
.688 .40441 Mdot
.688 .40444 Mdot
.688 .40449 Mdot
.688 .40456 Mdot
.688 .4047 Mdot
.688 .40494 Mdot
.688 .40512 Mdot
.688 .40514 Mdot
.688 .40528 Mdot
.688 .40563 Mdot
.688 .40568 Mdot
.688 .4059 Mdot
.688 .40593 Mdot
.688 .40603 Mdot
.688 .40612 Mdot
.688 .40615 Mdot
.688 .40632 Mdot
.688 .40634 Mdot
.688 .40663 Mdot
.688 .40673 Mdot
.688 .40684 Mdot
.688 .4069 Mdot
.688 .40708 Mdot
.688 .40711 Mdot
.688 .40721 Mdot
.688 .40726 Mdot
.688 .40726 Mdot
.688 .40759 Mdot
.688 .40759 Mdot
.688 .40777 Mdot
.688 .40782 Mdot
.688 .40786 Mdot
.688 .40797 Mdot
.688 .40808 Mdot
.688 .40818 Mdot
.688 .40827 Mdot
.688 .40834 Mdot
.688 .40843 Mdot
.688 .40851 Mdot
.688 .40853 Mdot
.688 .40854 Mdot
.688 .40856 Mdot
.688 .4086 Mdot
.688 .40863 Mdot
.688 .40888 Mdot
.688 .40904 Mdot
.688 .40923 Mdot
.688 .40936 Mdot
.688 .40936 Mdot
.688 .40948 Mdot
.688 .40958 Mdot
.688 .40968 Mdot
.688 .40968 Mdot
.688 .40975 Mdot
.688 .40994 Mdot
.688 .41005 Mdot
.688 .41015 Mdot
.688 .41038 Mdot
.688 .41041 Mdot
.688 .41068 Mdot
.688 .41083 Mdot
.688 .41087 Mdot
.688 .4109 Mdot
.688 .41099 Mdot
.688 .411 Mdot
.688 .41112 Mdot
.688 .41138 Mdot
.688 .41146 Mdot
.688 .4115 Mdot
.688 .41155 Mdot
.688 .41158 Mdot
.688 .41159 Mdot
.688 .4117 Mdot
.688 .41213 Mdot
.688 .41215 Mdot
.688 .41216 Mdot
.688 .41229 Mdot
.688 .41229 Mdot
.688 .4124 Mdot
.688 .41251 Mdot
.688 .41256 Mdot
.688 .41263 Mdot
.688 .41266 Mdot
.688 .41266 Mdot
.688 .4127 Mdot
.688 .41277 Mdot
.688 .41288 Mdot
.688 .41299 Mdot
.688 .41299 Mdot
.688 .41326 Mdot
.688 .4133 Mdot
.688 .41333 Mdot
.688 .41359 Mdot
.688 .41379 Mdot
.688 .41388 Mdot
.688 .41389 Mdot
.688 .41391 Mdot
.688 .41399 Mdot
.688 .4141 Mdot
.688 .41425 Mdot
.688 .41433 Mdot
.688 .41436 Mdot
.688 .41445 Mdot
.688 .4146 Mdot
.688 .41464 Mdot
.688 .4147 Mdot
.688 .41481 Mdot
.688 .41484 Mdot
.688 .41486 Mdot
.688 .41506 Mdot
.688 .41518 Mdot
.688 .41536 Mdot
.688 .41538 Mdot
.688 .41562 Mdot
.688 .41568 Mdot
.688 .41601 Mdot
.688 .41601 Mdot
.688 .41611 Mdot
.688 .41618 Mdot
.688 .41636 Mdot
.688 .41642 Mdot
.688 .41642 Mdot
.688 .41653 Mdot
.688 .41693 Mdot
.688 .41711 Mdot
.688 .41719 Mdot
.688 .4172 Mdot
.688 .41737 Mdot
.688 .41742 Mdot
.688 .41769 Mdot
.688 .41773 Mdot
.688 .4178 Mdot
.688 .41783 Mdot
.688 .41784 Mdot
.688 .41786 Mdot
.688 .41816 Mdot
.688 .41836 Mdot
.688 .41847 Mdot
.688 .41849 Mdot
.688 .41857 Mdot
.688 .4187 Mdot
.688 .41888 Mdot
.688 .41909 Mdot
.688 .41916 Mdot
.688 .41924 Mdot
.688 .41944 Mdot
.688 .41948 Mdot
.688 .41962 Mdot
.688 .41971 Mdot
.688 .4198 Mdot
.688 .41994 Mdot
.688 .41998 Mdot
.688 .42002 Mdot
.688 .42009 Mdot
.688 .42018 Mdot
.688 .42027 Mdot
.688 .42043 Mdot
.688 .42049 Mdot
.69 .26711 Mdot
.69 .26725 Mdot
.69 .26732 Mdot
.69 .268 Mdot
.69 .26818 Mdot
.69 .26841 Mdot
.69 .26842 Mdot
.69 .26849 Mdot
.69 .2685 Mdot
.69 .26862 Mdot
.69 .26867 Mdot
.69 .26867 Mdot
.69 .26879 Mdot
.69 .26886 Mdot
.69 .26892 Mdot
.69 .26901 Mdot
.69 .2691 Mdot
.69 .26942 Mdot
.69 .26999 Mdot
.69 .27005 Mdot
.69 .27016 Mdot
.69 .27026 Mdot
.69 .27037 Mdot
.69 .27063 Mdot
.69 .27093 Mdot
.69 .27099 Mdot
.69 .27125 Mdot
.69 .27128 Mdot
.69 .27176 Mdot
.69 .27222 Mdot
.69 .27243 Mdot
.69 .27245 Mdot
.69 .27259 Mdot
.69 .27274 Mdot
.69 .27275 Mdot
.69 .27307 Mdot
.69 .27313 Mdot
.69 .27326 Mdot
.69 .27337 Mdot
.69 .27368 Mdot
.69 .27368 Mdot
.69 .27379 Mdot
.69 .2739 Mdot
.69 .27429 Mdot
.69 .27442 Mdot
.69 .27444 Mdot
.69 .2746 Mdot
.69 .27477 Mdot
.69 .27498 Mdot
.69 .27517 Mdot
.69 .27536 Mdot
.69 .27538 Mdot
.69 .27538 Mdot
.69 .2754 Mdot
.69 .27562 Mdot
.69 .27583 Mdot
.69 .27601 Mdot
.69 .27606 Mdot
.69 .27615 Mdot
.69 .27636 Mdot
.69 .27638 Mdot
.69 .27682 Mdot
.69 .27689 Mdot
.69 .27692 Mdot
.69 .27693 Mdot
.69 .27704 Mdot
.69 .27714 Mdot
.69 .27737 Mdot
.69 .27756 Mdot
.69 .27786 Mdot
.69 .27791 Mdot
.69 .27806 Mdot
.69 .27806 Mdot
.69 .27813 Mdot
.69 .27837 Mdot
.69 .27855 Mdot
.69 .27857 Mdot
.69 .27875 Mdot
.69 .27891 Mdot
.69 .279 Mdot
.69 .27918 Mdot
.69 .2792 Mdot
.69 .2793 Mdot
.69 .27932 Mdot
.69 .27942 Mdot
.69 .27949 Mdot
.69 .27965 Mdot
.69 .28006 Mdot
.69 .28012 Mdot
.69 .28013 Mdot
.69 .28017 Mdot
.69 .28025 Mdot
.69 .28028 Mdot
.69 .28028 Mdot
.69 .2804 Mdot
.69 .28055 Mdot
.69 .28076 Mdot
.69 .28083 Mdot
.69 .28092 Mdot
.69 .2812 Mdot
.69 .28223 Mdot
.69 .28225 Mdot
.69 .28226 Mdot
.69 .28233 Mdot
.69 .28238 Mdot
.69 .28274 Mdot
.69 .28277 Mdot
.69 .2828 Mdot
.69 .2829 Mdot
.69 .28295 Mdot
.69 .28297 Mdot
.69 .28309 Mdot
.69 .28313 Mdot
.69 .28315 Mdot
.69 .28316 Mdot
.69 .28344 Mdot
.69 .28354 Mdot
.69 .28362 Mdot
.69 .2837 Mdot
.69 .28374 Mdot
.69 .28405 Mdot
.69 .28417 Mdot
.69 .28417 Mdot
.69 .28422 Mdot
.69 .2845 Mdot
.69 .28465 Mdot
.69 .28492 Mdot
.69 .28505 Mdot
.69 .28522 Mdot
.69 .28549 Mdot
.69 .28552 Mdot
.69 .2856 Mdot
.69 .28568 Mdot
.69 .28636 Mdot
.69 .28646 Mdot
.69 .28648 Mdot
.69 .28669 Mdot
.69 .28678 Mdot
.69 .2869 Mdot
.69 .28691 Mdot
.69 .28703 Mdot
.69 .28737 Mdot
.69 .28758 Mdot
.69 .28769 Mdot
.69 .28781 Mdot
.69 .28783 Mdot
.69 .28786 Mdot
.69 .28839 Mdot
.69 .28861 Mdot
.69 .28874 Mdot
.69 .28888 Mdot
.69 .28899 Mdot
.69 .28931 Mdot
.69 .28935 Mdot
.69 .28961 Mdot
.69 .2898 Mdot
.69 .29007 Mdot
.69 .29031 Mdot
.69 .29035 Mdot
.69 .29035 Mdot
.69 .29059 Mdot
.69 .29066 Mdot
.69 .29069 Mdot
.69 .2909 Mdot
.69 .29092 Mdot
.69 .29114 Mdot
.69 .29151 Mdot
.69 .29164 Mdot
.69 .29165 Mdot
.69 .2917 Mdot
.69 .29191 Mdot
.69 .29205 Mdot
.69 .29224 Mdot
.69 .29267 Mdot
.69 .29267 Mdot
.69 .29279 Mdot
.69 .29279 Mdot
.69 .29292 Mdot
.69 .29305 Mdot
.69 .2932 Mdot
.69 .29326 Mdot
.69 .29345 Mdot
.69 .29354 Mdot
.69 .29359 Mdot
.69 .29381 Mdot
.69 .29389 Mdot
.69 .29406 Mdot
.69 .2941 Mdot
.69 .29472 Mdot
.69 .29476 Mdot
.69 .29496 Mdot
.69 .29517 Mdot
.69 .29552 Mdot
.69 .29554 Mdot
.69 .29563 Mdot
.69 .29567 Mdot
.69 .29579 Mdot
.69 .29614 Mdot
.69 .29621 Mdot
.69 .2966 Mdot
.69 .29667 Mdot
.69 .29681 Mdot
.69 .29681 Mdot
.69 .29688 Mdot
.69 .29707 Mdot
.69 .2972 Mdot
.69 .29731 Mdot
.69 .29736 Mdot
.69 .29749 Mdot
.69 .29764 Mdot
.69 .29778 Mdot
.69 .29788 Mdot
.69 .29803 Mdot
.69 .2982 Mdot
.69 .2984 Mdot
.69 .29852 Mdot
.69 .2988 Mdot
.69 .29881 Mdot
.69 .29888 Mdot
.69 .29894 Mdot
.69 .29905 Mdot
.69 .29923 Mdot
.69 .29929 Mdot
.69 .2993 Mdot
.69 .29952 Mdot
.69 .29953 Mdot
.69 .29959 Mdot
.69 .30034 Mdot
.69 .30048 Mdot
.69 .30071 Mdot
.69 .30073 Mdot
.69 .30073 Mdot
.69 .30098 Mdot
.69 .30128 Mdot
.69 .3013 Mdot
.69 .30137 Mdot
.69 .30146 Mdot
.69 .30147 Mdot
.69 .30148 Mdot
.69 .30174 Mdot
.69 .30244 Mdot
.69 .30252 Mdot
.69 .30286 Mdot
.69 .30289 Mdot
.69 .30311 Mdot
.69 .30323 Mdot
.69 .30329 Mdot
.69 .30336 Mdot
.69 .3035 Mdot
.69 .30391 Mdot
.69 .30394 Mdot
.69 .30394 Mdot
.69 .30402 Mdot
.69 .30405 Mdot
.69 .30442 Mdot
.69 .30448 Mdot
.69 .30454 Mdot
.69 .30482 Mdot
.69 .30484 Mdot
.69 .30495 Mdot
.69 .30499 Mdot
.69 .30523 Mdot
.69 .30534 Mdot
.69 .30535 Mdot
.69 .30576 Mdot
.69 .30585 Mdot
.69 .30592 Mdot
.69 .30653 Mdot
.69 .30674 Mdot
.69 .30682 Mdot
.69 .3069 Mdot
.69 .30701 Mdot
.69 .30725 Mdot
.69 .30765 Mdot
.69 .30768 Mdot
.69 .30798 Mdot
.69 .30815 Mdot
.69 .30869 Mdot
.69 .30874 Mdot
.69 .30877 Mdot
.69 .30881 Mdot
.69 .309 Mdot
.69 .30922 Mdot
.69 .30958 Mdot
.69 .30962 Mdot
.69 .30969 Mdot
.69 .31026 Mdot
.69 .31038 Mdot
.69 .31042 Mdot
.69 .31043 Mdot
.69 .3105 Mdot
.69 .31052 Mdot
.69 .31052 Mdot
.69 .31075 Mdot
.69 .31091 Mdot
.69 .31121 Mdot
.69 .31131 Mdot
.69 .31135 Mdot
.69 .31155 Mdot
.69 .31187 Mdot
.69 .31189 Mdot
.69 .31251 Mdot
.69 .31266 Mdot
.69 .31283 Mdot
.69 .31293 Mdot
.69 .31299 Mdot
.69 .31315 Mdot
.69 .31315 Mdot
.69 .31321 Mdot
.69 .31327 Mdot
.69 .31355 Mdot
.69 .31372 Mdot
.69 .31383 Mdot
.69 .31393 Mdot
.69 .31403 Mdot
.69 .31405 Mdot
.69 .31428 Mdot
.69 .31438 Mdot
.69 .3148 Mdot
.69 .31484 Mdot
.69 .31485 Mdot
.69 .31509 Mdot
.69 .31519 Mdot
.69 .31562 Mdot
.69 .31571 Mdot
.69 .31572 Mdot
.69 .31582 Mdot
.69 .31594 Mdot
.69 .31605 Mdot
.69 .31611 Mdot
.69 .3162 Mdot
.69 .31654 Mdot
.69 .31656 Mdot
.69 .3166 Mdot
.69 .31662 Mdot
.69 .31662 Mdot
.69 .31668 Mdot
.69 .31676 Mdot
.69 .31691 Mdot
.69 .3171 Mdot
.69 .31764 Mdot
.69 .31765 Mdot
.69 .3177 Mdot
.69 .31772 Mdot
.69 .31776 Mdot
.69 .31799 Mdot
.69 .31803 Mdot
.69 .31812 Mdot
.69 .31813 Mdot
.69 .31828 Mdot
.69 .31833 Mdot
.69 .31837 Mdot
.69 .31843 Mdot
.69 .3186 Mdot
.69 .31883 Mdot
.69 .31912 Mdot
.69 .31921 Mdot
.69 .31935 Mdot
.69 .31937 Mdot
.69 .31941 Mdot
.69 .31945 Mdot
.69 .31998 Mdot
.69 .32003 Mdot
.69 .32057 Mdot
.69 .32106 Mdot
.69 .32113 Mdot
.69 .32138 Mdot
.69 .32188 Mdot
.69 .3219 Mdot
.69 .32207 Mdot
.69 .3222 Mdot
.69 .32261 Mdot
.69 .3229 Mdot
.69 .32312 Mdot
.69 .32312 Mdot
.69 .32318 Mdot
.69 .32332 Mdot
.69 .3234 Mdot
.69 .32343 Mdot
.69 .32353 Mdot
.69 .32358 Mdot
.69 .3242 Mdot
.69 .32432 Mdot
.69 .32462 Mdot
.69 .3247 Mdot
.69 .32476 Mdot
.69 .32494 Mdot
.69 .32498 Mdot
.69 .32518 Mdot
.69 .32522 Mdot
.69 .32529 Mdot
.69 .32544 Mdot
.69 .32556 Mdot
.69 .32565 Mdot
.69 .32573 Mdot
.69 .32603 Mdot
.69 .32635 Mdot
.69 .32639 Mdot
.69 .32642 Mdot
.69 .32657 Mdot
.69 .32675 Mdot
.69 .32722 Mdot
.69 .32736 Mdot
.69 .32736 Mdot
.69 .32764 Mdot
.69 .32765 Mdot
.69 .32774 Mdot
.69 .3283 Mdot
.69 .3286 Mdot
.69 .32867 Mdot
.69 .32902 Mdot
.69 .3291 Mdot
.69 .32929 Mdot
.69 .32935 Mdot
.69 .32951 Mdot
.69 .32951 Mdot
.69 .32957 Mdot
.69 .32972 Mdot
.69 .32978 Mdot
.69 .33 Mdot
.69 .33055 Mdot
.69 .33059 Mdot
.69 .33099 Mdot
.69 .33116 Mdot
.69 .33125 Mdot
.69 .3316 Mdot
.69 .332 Mdot
.69 .33206 Mdot
.69 .33242 Mdot
.69 .33245 Mdot
.69 .33245 Mdot
.69 .3325 Mdot
.69 .33286 Mdot
.69 .33321 Mdot
.69 .33322 Mdot
.69 .33354 Mdot
.69 .33362 Mdot
.69 .33376 Mdot
.69 .33388 Mdot
.69 .33394 Mdot
.69 .33409 Mdot
.69 .33424 Mdot
.69 .33429 Mdot
.69 .33435 Mdot
.69 .33452 Mdot
.69 .33476 Mdot
.69 .33477 Mdot
.69 .33495 Mdot
.69 .33528 Mdot
.69 .3354 Mdot
.69 .33543 Mdot
.69 .33548 Mdot
.69 .33567 Mdot
.69 .3357 Mdot
.69 .3357 Mdot
.69 .33573 Mdot
.69 .33628 Mdot
.69 .33649 Mdot
.69 .33657 Mdot
.69 .33674 Mdot
.69 .33686 Mdot
.69 .33719 Mdot
.69 .33746 Mdot
.69 .33749 Mdot
.69 .33777 Mdot
.69 .33803 Mdot
.69 .33807 Mdot
.69 .33846 Mdot
.69 .33935 Mdot
.69 .33968 Mdot
.69 .33994 Mdot
.69 .34025 Mdot
.69 .34033 Mdot
.69 .34044 Mdot
.69 .34081 Mdot
.69 .34092 Mdot
.69 .34149 Mdot
.69 .34199 Mdot
.69 .34221 Mdot
.69 .34239 Mdot
.69 .34261 Mdot
.69 .34272 Mdot
.69 .34381 Mdot
.69 .34441 Mdot
.69 .34458 Mdot
.69 .34476 Mdot
.69 .34487 Mdot
.69 .34501 Mdot
.69 .34523 Mdot
.69 .34523 Mdot
.69 .34532 Mdot
.69 .34556 Mdot
.69 .34558 Mdot
.69 .3457 Mdot
.69 .34573 Mdot
.69 .34617 Mdot
.69 .3465 Mdot
.69 .34781 Mdot
.69 .34794 Mdot
.69 .34821 Mdot
.69 .36302 Mdot
.69 .36321 Mdot
.69 .36331 Mdot
.69 .36425 Mdot
.69 .36449 Mdot
.69 .36481 Mdot
.69 .36483 Mdot
.69 .36492 Mdot
.69 .36494 Mdot
.69 .36511 Mdot
.69 .36517 Mdot
.69 .36518 Mdot
.69 .36534 Mdot
.69 .36543 Mdot
.69 .36551 Mdot
.69 .36564 Mdot
.69 .36577 Mdot
.69 .36621 Mdot
.69 .36699 Mdot
.69 .36707 Mdot
.69 .36724 Mdot
.69 .36736 Mdot
.69 .36752 Mdot
.69 .36788 Mdot
.69 .3683 Mdot
.69 .36838 Mdot
.69 .36864 Mdot
.69 .36873 Mdot
.69 .36878 Mdot
.69 .36901 Mdot
.69 .3692 Mdot
.69 .36943 Mdot
.69 .37008 Mdot
.69 .37036 Mdot
.69 .37039 Mdot
.69 .37058 Mdot
.69 .37078 Mdot
.69 .3708 Mdot
.69 .371 Mdot
.69 .37124 Mdot
.69 .37133 Mdot
.69 .37145 Mdot
.69 .37151 Mdot
.69 .37166 Mdot
.69 .37206 Mdot
.69 .37208 Mdot
.69 .37208 Mdot
.69 .3721 Mdot
.69 .37224 Mdot
.69 .37227 Mdot
.69 .3723 Mdot
.69 .37239 Mdot
.69 .37263 Mdot
.69 .37275 Mdot
.69 .37276 Mdot
.69 .37294 Mdot
.69 .37306 Mdot
.69 .3731 Mdot
.69 .37314 Mdot
.69 .37325 Mdot
.69 .37336 Mdot
.69 .3734 Mdot
.69 .37348 Mdot
.69 .37359 Mdot
.69 .37365 Mdot
.69 .37388 Mdot
.69 .37389 Mdot
.69 .37414 Mdot
.69 .3744 Mdot
.69 .37444 Mdot
.69 .37444 Mdot
.69 .37445 Mdot
.69 .37472 Mdot
.69 .37476 Mdot
.69 .37505 Mdot
.69 .3753 Mdot
.69 .37537 Mdot
.69 .37549 Mdot
.69 .37578 Mdot
.69 .37581 Mdot
.69 .37621 Mdot
.69 .37637 Mdot
.69 .37642 Mdot
.69 .37652 Mdot
.69 .37656 Mdot
.69 .37657 Mdot
.69 .37668 Mdot
.69 .37672 Mdot
.69 .37686 Mdot
.69 .37692 Mdot
.69 .37718 Mdot
.69 .37722 Mdot
.69 .37744 Mdot
.69 .37785 Mdot
.69 .37791 Mdot
.69 .37792 Mdot
.69 .37813 Mdot
.69 .37813 Mdot
.69 .37822 Mdot
.69 .37856 Mdot
.69 .3787 Mdot
.69 .37881 Mdot
.69 .37883 Mdot
.69 .37886 Mdot
.69 .37909 Mdot
.69 .3793 Mdot
.69 .37936 Mdot
.69 .37943 Mdot
.69 .37952 Mdot
.69 .37962 Mdot
.69 .37967 Mdot
.69 .3797 Mdot
.69 .37985 Mdot
.69 .37987 Mdot
.69 .38001 Mdot
.69 .38005 Mdot
.69 .38011 Mdot
.69 .38032 Mdot
.69 .38042 Mdot
.69 .38086 Mdot
.69 .3809 Mdot
.69 .38097 Mdot
.69 .38099 Mdot
.69 .38105 Mdot
.69 .38115 Mdot
.69 .38119 Mdot
.69 .3812 Mdot
.69 .38136 Mdot
.69 .38156 Mdot
.69 .38186 Mdot
.69 .38196 Mdot
.69 .38208 Mdot
.69 .38209 Mdot
.69 .38246 Mdot
.69 .38263 Mdot
.69 .38269 Mdot
.69 .38304 Mdot
.69 .38344 Mdot
.69 .38347 Mdot
.69 .38385 Mdot
.69 .38388 Mdot
.69 .38392 Mdot
.69 .38393 Mdot
.69 .38403 Mdot
.69 .38409 Mdot
.69 .3843 Mdot
.69 .38447 Mdot
.69 .38459 Mdot
.69 .38464 Mdot
.69 .38467 Mdot
.69 .3847 Mdot
.69 .38481 Mdot
.69 .38482 Mdot
.69 .38488 Mdot
.69 .38491 Mdot
.69 .38508 Mdot
.69 .38511 Mdot
.69 .38513 Mdot
.69 .38516 Mdot
.69 .38517 Mdot
.69 .38556 Mdot
.69 .3857 Mdot
.69 .38581 Mdot
.69 .38586 Mdot
.69 .38591 Mdot
.69 .38591 Mdot
.69 .38592 Mdot
.69 .38595 Mdot
.69 .38596 Mdot
.69 .38621 Mdot
.69 .38627 Mdot
.69 .38632 Mdot
.69 .3864 Mdot
.69 .38649 Mdot
.69 .38656 Mdot
.69 .38657 Mdot
.69 .38663 Mdot
.69 .38694 Mdot
.69 .38702 Mdot
.69 .38719 Mdot
.69 .3872 Mdot
.69 .38723 Mdot
.69 .38753 Mdot
.69 .3876 Mdot
.69 .38777 Mdot
.69 .38778 Mdot
.69 .38785 Mdot
.69 .38793 Mdot
.69 .38801 Mdot
.69 .38813 Mdot
.69 .38834 Mdot
.69 .38838 Mdot
.69 .38842 Mdot
.69 .38842 Mdot
.69 .38854 Mdot
.69 .38858 Mdot
.69 .38865 Mdot
.69 .38877 Mdot
.69 .38889 Mdot
.69 .38933 Mdot
.69 .38935 Mdot
.69 .38958 Mdot
.69 .38972 Mdot
.69 .38976 Mdot
.69 .38982 Mdot
.69 .39004 Mdot
.69 .39016 Mdot
.69 .39033 Mdot
.69 .39033 Mdot
.69 .39034 Mdot
.69 .39039 Mdot
.69 .3904 Mdot
.69 .39043 Mdot
.69 .39051 Mdot
.69 .39093 Mdot
.69 .39098 Mdot
.69 .39101 Mdot
.69 .39127 Mdot
.69 .39143 Mdot
.69 .39157 Mdot
.69 .39159 Mdot
.69 .39161 Mdot
.69 .39165 Mdot
.69 .39204 Mdot
.69 .39217 Mdot
.69 .39238 Mdot
.69 .3924 Mdot
.69 .39269 Mdot
.69 .39287 Mdot
.69 .39295 Mdot
.69 .39301 Mdot
.69 .39307 Mdot
.69 .39322 Mdot
.69 .39366 Mdot
.69 .39371 Mdot
.69 .39378 Mdot
.69 .39407 Mdot
.69 .39408 Mdot
.69 .39416 Mdot
.69 .39433 Mdot
.69 .39437 Mdot
.69 .39444 Mdot
.69 .39445 Mdot
.69 .39466 Mdot
.69 .3947 Mdot
.69 .39474 Mdot
.69 .39502 Mdot
.69 .39503 Mdot
.69 .39509 Mdot
.69 .39509 Mdot
.69 .39512 Mdot
.69 .39542 Mdot
.69 .39552 Mdot
.69 .39557 Mdot
.69 .39561 Mdot
.69 .3957 Mdot
.69 .39586 Mdot
.69 .39588 Mdot
.69 .39612 Mdot
.69 .39618 Mdot
.69 .39669 Mdot
.69 .39687 Mdot
.69 .39689 Mdot
.69 .3969 Mdot
.69 .39696 Mdot
.69 .39701 Mdot
.69 .39702 Mdot
.69 .39724 Mdot
.69 .39742 Mdot
.69 .39742 Mdot
.69 .39744 Mdot
.69 .3976 Mdot
.69 .3977 Mdot
.69 .39825 Mdot
.69 .39829 Mdot
.69 .3983 Mdot
.69 .39846 Mdot
.69 .39846 Mdot
.69 .39851 Mdot
.69 .39864 Mdot
.69 .39872 Mdot
.69 .39876 Mdot
.69 .39881 Mdot
.69 .39882 Mdot
.69 .39902 Mdot
.69 .39911 Mdot
.69 .39925 Mdot
.69 .39938 Mdot
.69 .39949 Mdot
.69 .39956 Mdot
.69 .39966 Mdot
.69 .39977 Mdot
.69 .39986 Mdot
.69 .3999 Mdot
.69 .39998 Mdot
.69 .40007 Mdot
.69 .40021 Mdot
.69 .40026 Mdot
.69 .40026 Mdot
.69 .40036 Mdot
.69 .40042 Mdot
.69 .4007 Mdot
.69 .40075 Mdot
.69 .401 Mdot
.69 .40108 Mdot
.69 .40112 Mdot
.69 .40118 Mdot
.69 .4012 Mdot
.69 .40145 Mdot
.69 .4016 Mdot
.69 .40174 Mdot
.69 .40178 Mdot
.69 .40223 Mdot
.69 .40225 Mdot
.69 .40238 Mdot
.69 .40244 Mdot
.69 .4026 Mdot
.69 .40263 Mdot
.69 .40269 Mdot
.69 .40283 Mdot
.69 .40288 Mdot
.69 .40298 Mdot
.69 .40308 Mdot
.69 .40317 Mdot
.69 .40318 Mdot
.69 .40326 Mdot
.69 .40326 Mdot
.69 .40357 Mdot
.69 .40371 Mdot
.69 .40381 Mdot
.69 .40396 Mdot
.69 .404 Mdot
.69 .40401 Mdot
.69 .4041 Mdot
.69 .40437 Mdot
.69 .40453 Mdot
.69 .40454 Mdot
.69 .40469 Mdot
.69 .40472 Mdot
.69 .40477 Mdot
.69 .40494 Mdot
.69 .40494 Mdot
.69 .40497 Mdot
.69 .40515 Mdot
.69 .40534 Mdot
.69 .40548 Mdot
.69 .40567 Mdot
.69 .40569 Mdot
.69 .40593 Mdot
.69 .40601 Mdot
.69 .40611 Mdot
.69 .4062 Mdot
.69 .40637 Mdot
.69 .40675 Mdot
.69 .40677 Mdot
.69 .40678 Mdot
.69 .40687 Mdot
.69 .40695 Mdot
.69 .4071 Mdot
.69 .40735 Mdot
.69 .40743 Mdot
.69 .40744 Mdot
.69 .40753 Mdot
.69 .40759 Mdot
.69 .40774 Mdot
.69 .40776 Mdot
.69 .40784 Mdot
.69 .40832 Mdot
.69 .40838 Mdot
.69 .40844 Mdot
.69 .40847 Mdot
.69 .40866 Mdot
.69 .40878 Mdot
.69 .40887 Mdot
.69 .40907 Mdot
.69 .40918 Mdot
.69 .40938 Mdot
.69 .40942 Mdot
.69 .40942 Mdot
.69 .40951 Mdot
.69 .40973 Mdot
.69 .40976 Mdot
.69 .40982 Mdot
.69 .40987 Mdot
.69 .40995 Mdot
.69 .41015 Mdot
.69 .41016 Mdot
.69 .41017 Mdot
.69 .4102 Mdot
.69 .41029 Mdot
.69 .4103 Mdot
.69 .41034 Mdot
.69 .41042 Mdot
.69 .41043 Mdot
.69 .41045 Mdot
.69 .41066 Mdot
.69 .41072 Mdot
.69 .41075 Mdot
.69 .4108 Mdot
.69 .41081 Mdot
.69 .41083 Mdot
.69 .41158 Mdot
.69 .41178 Mdot
.69 .41184 Mdot
.69 .41189 Mdot
.69 .41205 Mdot
.69 .41215 Mdot
.69 .41224 Mdot
.69 .41224 Mdot
.69 .41226 Mdot
.69 .41232 Mdot
.69 .41235 Mdot
.69 .41236 Mdot
.69 .4124 Mdot
.69 .4127 Mdot
.69 .41281 Mdot
.69 .41286 Mdot
.69 .41293 Mdot
.69 .41295 Mdot
.69 .41302 Mdot
.69 .41304 Mdot
.69 .41317 Mdot
.69 .41323 Mdot
.69 .41334 Mdot
.69 .41348 Mdot
.69 .41349 Mdot
.69 .41362 Mdot
.69 .4138 Mdot
.69 .41385 Mdot
.69 .41385 Mdot
.69 .41396 Mdot
.69 .414 Mdot
.69 .41421 Mdot
.69 .41435 Mdot
.69 .41451 Mdot
.69 .41459 Mdot
.69 .41467 Mdot
.69 .41467 Mdot
.69 .41469 Mdot
.69 .41475 Mdot
.69 .41507 Mdot
.69 .41508 Mdot
.69 .41523 Mdot
.69 .4153 Mdot
.69 .41533 Mdot
.69 .41546 Mdot
.69 .41562 Mdot
.69 .41578 Mdot
.69 .41579 Mdot
.69 .41579 Mdot
.69 .41581 Mdot
.69 .41594 Mdot
.69 .41608 Mdot
.69 .41623 Mdot
.69 .41635 Mdot
.69 .41647 Mdot
.69 .41649 Mdot
.69 .41658 Mdot
.69 .41686 Mdot
.69 .41694 Mdot
.69 .41702 Mdot
.69 .41702 Mdot
.69 .41724 Mdot
.69 .41733 Mdot
.69 .41742 Mdot
.69 .41747 Mdot
.69 .4177 Mdot
.69 .41771 Mdot
.69 .41781 Mdot
.69 .41791 Mdot
.69 .41793 Mdot
.69 .41808 Mdot
.69 .41842 Mdot
.69 .41876 Mdot
.69 .41879 Mdot
.69 .41897 Mdot
.69 .41901 Mdot
.69 .41923 Mdot
.69 .41942 Mdot
.69 .4195 Mdot
.69 .41957 Mdot
.69 .41965 Mdot
.69 .4197 Mdot
.69 .42011 Mdot
.69 .42034 Mdot
.69 .42041 Mdot
.69 .42047 Mdot
.69 .42052 Mdot
.69 .42057 Mdot
.69 .42065 Mdot
.69 .42065 Mdot
.69 .42069 Mdot
.69 .42078 Mdot
.69 .42078 Mdot
.69 .42083 Mdot
.69 .42084 Mdot
.69 .42101 Mdot
.69 .42113 Mdot
.69 .42163 Mdot
.69 .42168 Mdot
.69 .42178 Mdot
.692 .26624 Mdot
.692 .26663 Mdot
.692 .26691 Mdot
.692 .26691 Mdot
.692 .26696 Mdot
.692 .26698 Mdot
.692 .26723 Mdot
.692 .26723 Mdot
.692 .26737 Mdot
.692 .26743 Mdot
.692 .2675 Mdot
.692 .26751 Mdot
.692 .26754 Mdot
.692 .26757 Mdot
.692 .26764 Mdot
.692 .26792 Mdot
.692 .26793 Mdot
.692 .26794 Mdot
.692 .26814 Mdot
.692 .26823 Mdot
.692 .26829 Mdot
.692 .26862 Mdot
.692 .26934 Mdot
.692 .26946 Mdot
.692 .27 Mdot
.692 .27019 Mdot
.692 .27035 Mdot
.692 .27049 Mdot
.692 .27061 Mdot
.692 .27067 Mdot
.692 .27079 Mdot
.692 .2708 Mdot
.692 .27088 Mdot
.692 .27103 Mdot
.692 .27103 Mdot
.692 .27121 Mdot
.692 .2713 Mdot
.692 .27139 Mdot
.692 .27154 Mdot
.692 .27176 Mdot
.692 .27179 Mdot
.692 .2719 Mdot
.692 .272 Mdot
.692 .27208 Mdot
.692 .27215 Mdot
.692 .27221 Mdot
.692 .27236 Mdot
.692 .27281 Mdot
.692 .27292 Mdot
.692 .27311 Mdot
.692 .27318 Mdot
.692 .27328 Mdot
.692 .2733 Mdot
.692 .27333 Mdot
.692 .27344 Mdot
.692 .27445 Mdot
.692 .27452 Mdot
.692 .27459 Mdot
.692 .27484 Mdot
.692 .27496 Mdot
.692 .27503 Mdot
.692 .27528 Mdot
.692 .27585 Mdot
.692 .27587 Mdot
.692 .27615 Mdot
.692 .27616 Mdot
.692 .27651 Mdot
.692 .27697 Mdot
.692 .27701 Mdot
.692 .27806 Mdot
.692 .27812 Mdot
.692 .27816 Mdot
.692 .27828 Mdot
.692 .27841 Mdot
.692 .27888 Mdot
.692 .2791 Mdot
.692 .27911 Mdot
.692 .27922 Mdot
.692 .27941 Mdot
.692 .27969 Mdot
.692 .27981 Mdot
.692 .27986 Mdot
.692 .27987 Mdot
.692 .2799 Mdot
.692 .27996 Mdot
.692 .28041 Mdot
.692 .28044 Mdot
.692 .28083 Mdot
.692 .2809 Mdot
.692 .28099 Mdot
.692 .28117 Mdot
.692 .28156 Mdot
.692 .28176 Mdot
.692 .28182 Mdot
.692 .28241 Mdot
.692 .28248 Mdot
.692 .28253 Mdot
.692 .28254 Mdot
.692 .28255 Mdot
.692 .28257 Mdot
.692 .28273 Mdot
.692 .28298 Mdot
.692 .283 Mdot
.692 .28373 Mdot
.692 .28427 Mdot
.692 .28451 Mdot
.692 .28463 Mdot
.692 .28506 Mdot
.692 .2851 Mdot
.692 .28516 Mdot
.692 .28531 Mdot
.692 .28537 Mdot
.692 .28539 Mdot
.692 .28546 Mdot
.692 .28547 Mdot
.692 .2856 Mdot
.692 .28571 Mdot
.692 .28573 Mdot
.692 .2859 Mdot
.692 .2861 Mdot
.692 .28646 Mdot
.692 .28652 Mdot
.692 .28661 Mdot
.692 .28662 Mdot
.692 .28663 Mdot
.692 .28671 Mdot
.692 .28678 Mdot
.692 .28698 Mdot
.692 .2871 Mdot
.692 .28718 Mdot
.692 .2872 Mdot
.692 .28731 Mdot
.692 .28735 Mdot
.692 .28738 Mdot
.692 .28746 Mdot
.692 .28746 Mdot
.692 .28756 Mdot
.692 .28765 Mdot
.692 .28784 Mdot
.692 .28812 Mdot
.692 .28821 Mdot
.692 .28824 Mdot
.692 .2883 Mdot
.692 .28854 Mdot
.692 .28857 Mdot
.692 .28863 Mdot
.692 .28879 Mdot
.692 .28892 Mdot
.692 .28924 Mdot
.692 .28926 Mdot
.692 .28928 Mdot
.692 .2894 Mdot
.692 .2897 Mdot
.692 .2898 Mdot
.692 .28994 Mdot
.692 .29022 Mdot
.692 .29025 Mdot
.692 .29028 Mdot
.692 .29032 Mdot
.692 .29071 Mdot
.692 .29102 Mdot
.692 .29107 Mdot
.692 .29118 Mdot
.692 .29144 Mdot
.692 .29191 Mdot
.692 .29198 Mdot
.692 .2922 Mdot
.692 .29221 Mdot
.692 .29224 Mdot
.692 .29231 Mdot
.692 .29236 Mdot
.692 .29251 Mdot
.692 .29253 Mdot
.692 .29255 Mdot
.692 .29255 Mdot
.692 .29269 Mdot
.692 .29276 Mdot
.692 .29278 Mdot
.692 .29289 Mdot
.692 .29296 Mdot
.692 .2931 Mdot
.692 .29354 Mdot
.692 .29355 Mdot
.692 .29367 Mdot
.692 .29375 Mdot
.692 .294 Mdot
.692 .29408 Mdot
.692 .29416 Mdot
.692 .29423 Mdot
.692 .29423 Mdot
.692 .29448 Mdot
.692 .29469 Mdot
.692 .29493 Mdot
.692 .29506 Mdot
.692 .29506 Mdot
.692 .2951 Mdot
.692 .29514 Mdot
.692 .29536 Mdot
.692 .29582 Mdot
.692 .29583 Mdot
.692 .29594 Mdot
.692 .29595 Mdot
.692 .2961 Mdot
.692 .29612 Mdot
.692 .29627 Mdot
.692 .29666 Mdot
.692 .29671 Mdot
.692 .29674 Mdot
.692 .2969 Mdot
.692 .29712 Mdot
.692 .29714 Mdot
.692 .29738 Mdot
.692 .29759 Mdot
.692 .29766 Mdot
.692 .29799 Mdot
.692 .29802 Mdot
.692 .29816 Mdot
.692 .29825 Mdot
.692 .2984 Mdot
.692 .2986 Mdot
.692 .2986 Mdot
.692 .29864 Mdot
.692 .29868 Mdot
.692 .29874 Mdot
.692 .29878 Mdot
.692 .29885 Mdot
.692 .29895 Mdot
.692 .29903 Mdot
.692 .29904 Mdot
.692 .29909 Mdot
.692 .29912 Mdot
.692 .29941 Mdot
.692 .2995 Mdot
.692 .29963 Mdot
.692 .29969 Mdot
.692 .29972 Mdot
.692 .29983 Mdot
.692 .30014 Mdot
.692 .30026 Mdot
.692 .30093 Mdot
.692 .30117 Mdot
.692 .30167 Mdot
.692 .30188 Mdot
.692 .30197 Mdot
.692 .30226 Mdot
.692 .30256 Mdot
.692 .30257 Mdot
.692 .3028 Mdot
.692 .30296 Mdot
.692 .30332 Mdot
.692 .30339 Mdot
.692 .3035 Mdot
.692 .30405 Mdot
.692 .30432 Mdot
.692 .3045 Mdot
.692 .30466 Mdot
.692 .30509 Mdot
.692 .30532 Mdot
.692 .30535 Mdot
.692 .30539 Mdot
.692 .30592 Mdot
.692 .30597 Mdot
.692 .30599 Mdot
.692 .30605 Mdot
.692 .30625 Mdot
.692 .30656 Mdot
.692 .30667 Mdot
.692 .30672 Mdot
.692 .30691 Mdot
.692 .30699 Mdot
.692 .30708 Mdot
.692 .30718 Mdot
.692 .3073 Mdot
.692 .30736 Mdot
.692 .30753 Mdot
.692 .30806 Mdot
.692 .30843 Mdot
.692 .3086 Mdot
.692 .30879 Mdot
.692 .3088 Mdot
.692 .30894 Mdot
.692 .30901 Mdot
.692 .30908 Mdot
.692 .30916 Mdot
.692 .3093 Mdot
.692 .30932 Mdot
.692 .30947 Mdot
.692 .30972 Mdot
.692 .31007 Mdot
.692 .3101 Mdot
.692 .31023 Mdot
.692 .31034 Mdot
.692 .31038 Mdot
.692 .3104 Mdot
.692 .31041 Mdot
.692 .3106 Mdot
.692 .31071 Mdot
.692 .31075 Mdot
.692 .3114 Mdot
.692 .31168 Mdot
.692 .31178 Mdot
.692 .31193 Mdot
.692 .312 Mdot
.692 .3121 Mdot
.692 .31214 Mdot
.692 .31222 Mdot
.692 .31236 Mdot
.692 .3126 Mdot
.692 .31261 Mdot
.692 .31277 Mdot
.692 .3128 Mdot
.692 .31291 Mdot
.692 .3132 Mdot
.692 .3133 Mdot
.692 .31339 Mdot
.692 .31421 Mdot
.692 .31427 Mdot
.692 .31444 Mdot
.692 .31475 Mdot
.692 .3149 Mdot
.692 .31532 Mdot
.692 .31592 Mdot
.692 .31594 Mdot
.692 .31632 Mdot
.692 .31643 Mdot
.692 .31649 Mdot
.692 .31674 Mdot
.692 .3168 Mdot
.692 .31685 Mdot
.692 .31688 Mdot
.692 .31712 Mdot
.692 .31734 Mdot
.692 .31737 Mdot
.692 .31782 Mdot
.692 .31785 Mdot
.692 .31816 Mdot
.692 .3182 Mdot
.692 .31822 Mdot
.692 .31823 Mdot
.692 .31824 Mdot
.692 .31833 Mdot
.692 .31846 Mdot
.692 .31885 Mdot
.692 .31932 Mdot
.692 .31954 Mdot
.692 .31959 Mdot
.692 .31971 Mdot
.692 .31975 Mdot
.692 .31982 Mdot
.692 .31988 Mdot
.692 .32009 Mdot
.692 .32036 Mdot
.692 .3204 Mdot
.692 .32065 Mdot
.692 .32074 Mdot
.692 .32085 Mdot
.692 .32089 Mdot
.692 .32119 Mdot
.692 .3212 Mdot
.692 .32136 Mdot
.692 .32149 Mdot
.692 .32156 Mdot
.692 .32172 Mdot
.692 .32174 Mdot
.692 .32196 Mdot
.692 .32209 Mdot
.692 .32224 Mdot
.692 .32229 Mdot
.692 .32287 Mdot
.692 .32316 Mdot
.692 .32327 Mdot
.692 .32333 Mdot
.692 .32335 Mdot
.692 .32343 Mdot
.692 .32346 Mdot
.692 .32352 Mdot
.692 .32363 Mdot
.692 .32367 Mdot
.692 .32374 Mdot
.692 .32397 Mdot
.692 .32398 Mdot
.692 .32408 Mdot
.692 .32421 Mdot
.692 .32457 Mdot
.692 .32476 Mdot
.692 .32477 Mdot
.692 .32478 Mdot
.692 .32481 Mdot
.692 .32522 Mdot
.692 .32531 Mdot
.692 .3256 Mdot
.692 .32563 Mdot
.692 .32597 Mdot
.692 .32608 Mdot
.692 .32612 Mdot
.692 .32631 Mdot
.692 .32638 Mdot
.692 .32661 Mdot
.692 .32665 Mdot
.692 .32668 Mdot
.692 .32674 Mdot
.692 .3268 Mdot
.692 .32725 Mdot
.692 .32783 Mdot
.692 .32852 Mdot
.692 .32868 Mdot
.692 .3288 Mdot
.692 .32889 Mdot
.692 .32978 Mdot
.692 .33043 Mdot
.692 .33046 Mdot
.692 .3305 Mdot
.692 .33095 Mdot
.692 .33099 Mdot
.692 .33104 Mdot
.692 .33212 Mdot
.692 .3326 Mdot
.692 .33274 Mdot
.692 .33296 Mdot
.692 .33344 Mdot
.692 .33357 Mdot
.692 .33361 Mdot
.692 .33372 Mdot
.692 .33479 Mdot
.692 .33504 Mdot
.692 .33534 Mdot
.692 .33565 Mdot
.692 .33586 Mdot
.692 .33592 Mdot
.692 .33595 Mdot
.692 .33608 Mdot
.692 .33611 Mdot
.692 .33614 Mdot
.692 .33616 Mdot
.692 .33628 Mdot
.692 .33665 Mdot
.692 .33686 Mdot
.692 .33718 Mdot
.692 .33743 Mdot
.692 .33754 Mdot
.692 .33766 Mdot
.692 .33769 Mdot
.692 .33772 Mdot
.692 .33797 Mdot
.692 .33799 Mdot
.692 .33812 Mdot
.692 .33817 Mdot
.692 .33825 Mdot
.692 .33841 Mdot
.692 .3386 Mdot
.692 .33868 Mdot
.692 .33869 Mdot
.692 .33881 Mdot
.692 .33887 Mdot
.692 .33928 Mdot
.692 .33958 Mdot
.692 .33962 Mdot
.692 .33968 Mdot
.692 .33974 Mdot
.692 .33986 Mdot
.692 .33986 Mdot
.692 .33991 Mdot
.692 .34027 Mdot
.692 .34027 Mdot
.692 .34055 Mdot
.692 .34071 Mdot
.692 .34072 Mdot
.692 .3409 Mdot
.692 .34096 Mdot
.692 .34108 Mdot
.692 .34126 Mdot
.692 .3413 Mdot
.692 .34157 Mdot
.692 .34187 Mdot
.692 .34223 Mdot
.692 .34231 Mdot
.692 .34327 Mdot
.692 .3435 Mdot
.692 .34489 Mdot
.692 .34551 Mdot
.692 .34564 Mdot
.692 .34579 Mdot
.692 .34618 Mdot
.692 .3462 Mdot
.692 .34622 Mdot
.692 .34675 Mdot
.692 .34688 Mdot
.692 .34694 Mdot
.692 .347 Mdot
.692 .34702 Mdot
.692 .34717 Mdot
.692 .34727 Mdot
.692 .34754 Mdot
.692 .34754 Mdot
.692 .34803 Mdot
.692 .34806 Mdot
.692 .34815 Mdot
.692 .34815 Mdot
.692 .3487 Mdot
.692 .34943 Mdot
.692 .36283 Mdot
.692 .36336 Mdot
.692 .36376 Mdot
.692 .36376 Mdot
.692 .36382 Mdot
.692 .36384 Mdot
.692 .36419 Mdot
.692 .3642 Mdot
.692 .36439 Mdot
.692 .36447 Mdot
.692 .36457 Mdot
.692 .36459 Mdot
.692 .36463 Mdot
.692 .36467 Mdot
.692 .36477 Mdot
.692 .36515 Mdot
.692 .36517 Mdot
.692 .36518 Mdot
.692 .36546 Mdot
.692 .36557 Mdot
.692 .36567 Mdot
.692 .36611 Mdot
.692 .36712 Mdot
.692 .36729 Mdot
.692 .36797 Mdot
.692 .36803 Mdot
.692 .36829 Mdot
.692 .36851 Mdot
.692 .3687 Mdot
.692 .36874 Mdot
.692 .36887 Mdot
.692 .36895 Mdot
.692 .36899 Mdot
.692 .36912 Mdot
.692 .36914 Mdot
.692 .36924 Mdot
.692 .36945 Mdot
.692 .36945 Mdot
.692 .36971 Mdot
.692 .36975 Mdot
.692 .36975 Mdot
.692 .36984 Mdot
.692 .36988 Mdot
.692 .36992 Mdot
.692 .36995 Mdot
.692 .37016 Mdot
.692 .37046 Mdot
.692 .37051 Mdot
.692 .37059 Mdot
.692 .3706 Mdot
.692 .37066 Mdot
.692 .37079 Mdot
.692 .37091 Mdot
.692 .37097 Mdot
.692 .371 Mdot
.692 .37109 Mdot
.692 .37111 Mdot
.692 .37129 Mdot
.692 .37131 Mdot
.692 .37134 Mdot
.692 .37142 Mdot
.692 .3715 Mdot
.692 .37168 Mdot
.692 .37191 Mdot
.692 .37207 Mdot
.692 .37233 Mdot
.692 .37242 Mdot
.692 .37243 Mdot
.692 .37245 Mdot
.692 .37248 Mdot
.692 .37257 Mdot
.692 .37259 Mdot
.692 .37264 Mdot
.692 .37279 Mdot
.692 .37301 Mdot
.692 .37323 Mdot
.692 .37341 Mdot
.692 .37418 Mdot
.692 .37427 Mdot
.692 .37429 Mdot
.692 .37438 Mdot
.692 .37473 Mdot
.692 .37489 Mdot
.692 .37499 Mdot
.692 .37534 Mdot
.692 .37612 Mdot
.692 .37616 Mdot
.692 .37619 Mdot
.692 .37651 Mdot
.692 .37654 Mdot
.692 .37656 Mdot
.692 .37703 Mdot
.692 .37768 Mdot
.692 .37774 Mdot
.692 .37783 Mdot
.692 .37794 Mdot
.692 .37844 Mdot
.692 .37886 Mdot
.692 .37919 Mdot
.692 .37922 Mdot
.692 .37927 Mdot
.692 .37929 Mdot
.692 .37932 Mdot
.692 .37949 Mdot
.692 .37954 Mdot
.692 .37967 Mdot
.692 .3797 Mdot
.692 .37978 Mdot
.692 .38003 Mdot
.692 .38005 Mdot
.692 .38026 Mdot
.692 .38032 Mdot
.692 .38062 Mdot
.692 .38064 Mdot
.692 .38065 Mdot
.692 .38065 Mdot
.692 .38079 Mdot
.692 .38106 Mdot
.692 .38115 Mdot
.692 .38122 Mdot
.692 .38123 Mdot
.692 .38139 Mdot
.692 .38145 Mdot
.692 .38147 Mdot
.692 .38155 Mdot
.692 .3816 Mdot
.692 .38162 Mdot
.692 .38167 Mdot
.692 .38169 Mdot
.692 .38173 Mdot
.692 .38182 Mdot
.692 .38202 Mdot
.692 .38244 Mdot
.692 .38248 Mdot
.692 .38259 Mdot
.692 .38268 Mdot
.692 .38284 Mdot
.692 .38285 Mdot
.692 .38297 Mdot
.692 .38302 Mdot
.692 .38311 Mdot
.692 .38323 Mdot
.692 .38324 Mdot
.692 .38345 Mdot
.692 .38348 Mdot
.692 .38356 Mdot
.692 .38363 Mdot
.692 .38381 Mdot
.692 .38383 Mdot
.692 .38403 Mdot
.692 .38418 Mdot
.692 .38422 Mdot
.692 .38427 Mdot
.692 .3843 Mdot
.692 .38439 Mdot
.692 .38443 Mdot
.692 .38459 Mdot
.692 .38493 Mdot
.692 .38521 Mdot
.692 .38531 Mdot
.692 .38537 Mdot
.692 .38537 Mdot
.692 .38538 Mdot
.692 .3854 Mdot
.692 .38542 Mdot
.692 .38565 Mdot
.692 .38567 Mdot
.692 .386 Mdot
.692 .38602 Mdot
.692 .38618 Mdot
.692 .38635 Mdot
.692 .38637 Mdot
.692 .38641 Mdot
.692 .38645 Mdot
.692 .38663 Mdot
.692 .38667 Mdot
.692 .38676 Mdot
.692 .38703 Mdot
.692 .38704 Mdot
.692 .38748 Mdot
.692 .38778 Mdot
.692 .38789 Mdot
.692 .38812 Mdot
.692 .38824 Mdot
.692 .38828 Mdot
.692 .38887 Mdot
.692 .38893 Mdot
.692 .38901 Mdot
.692 .38922 Mdot
.692 .3893 Mdot
.692 .38932 Mdot
.692 .38943 Mdot
.692 .38945 Mdot
.692 .38962 Mdot
.692 .38972 Mdot
.692 .38978 Mdot
.692 .38981 Mdot
.692 .38988 Mdot
.692 .38992 Mdot
.692 .39004 Mdot
.692 .39011 Mdot
.692 .39031 Mdot
.692 .39078 Mdot
.692 .39081 Mdot
.692 .39089 Mdot
.692 .39102 Mdot
.692 .39103 Mdot
.692 .39105 Mdot
.692 .39108 Mdot
.692 .39115 Mdot
.692 .39125 Mdot
.692 .39127 Mdot
.692 .39152 Mdot
.692 .3917 Mdot
.692 .39181 Mdot
.692 .39183 Mdot
.692 .39193 Mdot
.692 .39198 Mdot
.692 .39204 Mdot
.692 .39208 Mdot
.692 .39219 Mdot
.692 .3922 Mdot
.692 .39233 Mdot
.692 .39245 Mdot
.692 .39273 Mdot
.692 .39311 Mdot
.692 .39323 Mdot
.692 .39327 Mdot
.692 .39336 Mdot
.692 .39343 Mdot
.692 .3935 Mdot
.692 .39356 Mdot
.692 .39369 Mdot
.692 .39373 Mdot
.692 .39381 Mdot
.692 .39403 Mdot
.692 .39418 Mdot
.692 .39422 Mdot
.692 .39423 Mdot
.692 .39427 Mdot
.692 .39465 Mdot
.692 .39468 Mdot
.692 .39471 Mdot
.692 .39487 Mdot
.692 .39518 Mdot
.692 .39529 Mdot
.692 .39543 Mdot
.692 .39562 Mdot
.692 .39602 Mdot
.692 .39605 Mdot
.692 .3961 Mdot
.692 .39615 Mdot
.692 .39641 Mdot
.692 .39652 Mdot
.692 .39669 Mdot
.692 .3967 Mdot
.692 .39691 Mdot
.692 .39712 Mdot
.692 .39719 Mdot
.692 .39734 Mdot
.692 .3977 Mdot
.692 .39788 Mdot
.692 .39836 Mdot
.692 .39845 Mdot
.692 .39867 Mdot
.692 .39875 Mdot
.692 .39877 Mdot
.692 .39881 Mdot
.692 .39891 Mdot
.692 .39897 Mdot
.692 .39918 Mdot
.692 .3992 Mdot
.692 .39924 Mdot
.692 .39924 Mdot
.692 .3993 Mdot
.692 .39938 Mdot
.692 .39943 Mdot
.692 .39946 Mdot
.692 .3995 Mdot
.692 .39953 Mdot
.692 .39956 Mdot
.692 .39956 Mdot
.692 .39971 Mdot
.692 .39981 Mdot
.692 .39988 Mdot
.692 .39998 Mdot
.692 .4 Mdot
.692 .40024 Mdot
.692 .40029 Mdot
.692 .40044 Mdot
.692 .40061 Mdot
.692 .40062 Mdot
.692 .40079 Mdot
.692 .4009 Mdot
.692 .40092 Mdot
.692 .40096 Mdot
.692 .40124 Mdot
.692 .40135 Mdot
.692 .40136 Mdot
.692 .40147 Mdot
.692 .40148 Mdot
.692 .40156 Mdot
.692 .40157 Mdot
.692 .4019 Mdot
.692 .40206 Mdot
.692 .40209 Mdot
.692 .40211 Mdot
.692 .40212 Mdot
.692 .40221 Mdot
.692 .40238 Mdot
.692 .40254 Mdot
.692 .40271 Mdot
.692 .40272 Mdot
.692 .40276 Mdot
.692 .40283 Mdot
.692 .40288 Mdot
.692 .40306 Mdot
.692 .40312 Mdot
.692 .40321 Mdot
.692 .40321 Mdot
.692 .40353 Mdot
.692 .40363 Mdot
.692 .40369 Mdot
.692 .40376 Mdot
.692 .40378 Mdot
.692 .40383 Mdot
.692 .40393 Mdot
.692 .40393 Mdot
.692 .40395 Mdot
.692 .40396 Mdot
.692 .40407 Mdot
.692 .4041 Mdot
.692 .40415 Mdot
.692 .40417 Mdot
.692 .40419 Mdot
.692 .40434 Mdot
.692 .40439 Mdot
.692 .40473 Mdot
.692 .40492 Mdot
.692 .405 Mdot
.692 .40504 Mdot
.692 .40526 Mdot
.692 .40554 Mdot
.692 .40557 Mdot
.692 .40559 Mdot
.692 .40561 Mdot
.692 .40582 Mdot
.692 .40592 Mdot
.692 .40599 Mdot
.692 .40621 Mdot
.692 .4063 Mdot
.692 .40631 Mdot
.692 .40632 Mdot
.692 .40655 Mdot
.692 .40665 Mdot
.692 .40676 Mdot
.692 .40681 Mdot
.692 .40683 Mdot
.692 .407 Mdot
.692 .40704 Mdot
.692 .40707 Mdot
.692 .40713 Mdot
.692 .40733 Mdot
.692 .40747 Mdot
.692 .40754 Mdot
.692 .40761 Mdot
.692 .40761 Mdot
.692 .40766 Mdot
.692 .40769 Mdot
.692 .40772 Mdot
.692 .4078 Mdot
.692 .40781 Mdot
.692 .40786 Mdot
.692 .40796 Mdot
.692 .4081 Mdot
.692 .40815 Mdot
.692 .40821 Mdot
.692 .40821 Mdot
.692 .40822 Mdot
.692 .40829 Mdot
.692 .40833 Mdot
.692 .40859 Mdot
.692 .40873 Mdot
.692 .40885 Mdot
.692 .40887 Mdot
.692 .40895 Mdot
.692 .40904 Mdot
.692 .40905 Mdot
.692 .40911 Mdot
.692 .40912 Mdot
.692 .40916 Mdot
.692 .40927 Mdot
.692 .40931 Mdot
.692 .40934 Mdot
.692 .40965 Mdot
.692 .40974 Mdot
.692 .40991 Mdot
.692 .4103 Mdot
.692 .41083 Mdot
.692 .41084 Mdot
.692 .41103 Mdot
.692 .41114 Mdot
.692 .41116 Mdot
.692 .41116 Mdot
.692 .41117 Mdot
.692 .4112 Mdot
.692 .41125 Mdot
.692 .41168 Mdot
.692 .41173 Mdot
.692 .41187 Mdot
.692 .41216 Mdot
.692 .41228 Mdot
.692 .41235 Mdot
.692 .4124 Mdot
.692 .41268 Mdot
.692 .4127 Mdot
.692 .41303 Mdot
.692 .41307 Mdot
.692 .41309 Mdot
.692 .4131 Mdot
.692 .41314 Mdot
.692 .41322 Mdot
.692 .41342 Mdot
.692 .41356 Mdot
.692 .41364 Mdot
.692 .41365 Mdot
.692 .41381 Mdot
.692 .41414 Mdot
.692 .41424 Mdot
.692 .41433 Mdot
.692 .41436 Mdot
.692 .4144 Mdot
.692 .41516 Mdot
.692 .41519 Mdot
.692 .41552 Mdot
.692 .41577 Mdot
.692 .41578 Mdot
.692 .41598 Mdot
.692 .416 Mdot
.692 .41641 Mdot
.692 .41659 Mdot
.692 .41664 Mdot
.692 .41672 Mdot
.692 .41691 Mdot
.692 .41696 Mdot
.692 .41701 Mdot
.692 .41774 Mdot
.692 .41782 Mdot
.692 .41784 Mdot
.692 .41785 Mdot
.692 .41792 Mdot
.692 .41798 Mdot
.692 .41811 Mdot
.692 .4182 Mdot
.692 .41852 Mdot
.692 .41862 Mdot
.692 .41867 Mdot
.692 .41872 Mdot
.692 .41878 Mdot
.692 .41885 Mdot
.692 .41893 Mdot
.692 .41896 Mdot
.692 .41911 Mdot
.692 .41922 Mdot
.692 .41928 Mdot
.692 .41935 Mdot
.692 .41948 Mdot
.692 .41948 Mdot
.692 .41959 Mdot
.692 .41965 Mdot
.692 .41965 Mdot
.692 .41974 Mdot
.692 .41979 Mdot
.692 .41987 Mdot
.692 .41997 Mdot
.692 .42008 Mdot
.692 .42022 Mdot
.692 .42061 Mdot
.692 .4207 Mdot
.692 .42122 Mdot
.692 .42146 Mdot
.692 .42151 Mdot
.692 .42156 Mdot
.692 .42171 Mdot
.692 .42172 Mdot
.692 .42173 Mdot
.692 .42193 Mdot
.692 .42198 Mdot
.692 .422 Mdot
.692 .42202 Mdot
.692 .42203 Mdot
.692 .42208 Mdot
.692 .42212 Mdot
.692 .42222 Mdot
.692 .42223 Mdot
.692 .42241 Mdot
.692 .42242 Mdot
.692 .42245 Mdot
.692 .42245 Mdot
.692 .42266 Mdot
.692 .42294 Mdot
.694 .26545 Mdot
.694 .2655 Mdot
.694 .26566 Mdot
.694 .26575 Mdot
.694 .26585 Mdot
.694 .26586 Mdot
.694 .26587 Mdot
.694 .26605 Mdot
.694 .26611 Mdot
.694 .26629 Mdot
.694 .26669 Mdot
.694 .26693 Mdot
.694 .26711 Mdot
.694 .26742 Mdot
.694 .26747 Mdot
.694 .26748 Mdot
.694 .26756 Mdot
.694 .26774 Mdot
.694 .26787 Mdot
.694 .26832 Mdot
.694 .26922 Mdot
.694 .26936 Mdot
.694 .26943 Mdot
.694 .26946 Mdot
.694 .26965 Mdot
.694 .27012 Mdot
.694 .27028 Mdot
.694 .27048 Mdot
.694 .27065 Mdot
.694 .27072 Mdot
.694 .27079 Mdot
.694 .2709 Mdot
.694 .27106 Mdot
.694 .27113 Mdot
.694 .27142 Mdot
.694 .27164 Mdot
.694 .27166 Mdot
.694 .27193 Mdot
.694 .27194 Mdot
.694 .27214 Mdot
.694 .2722 Mdot
.694 .2722 Mdot
.694 .27246 Mdot
.694 .27268 Mdot
.694 .27281 Mdot
.694 .27316 Mdot
.694 .27335 Mdot
.694 .27338 Mdot
.694 .27355 Mdot
.694 .27355 Mdot
.694 .27363 Mdot
.694 .27372 Mdot
.694 .27386 Mdot
.694 .27407 Mdot
.694 .27436 Mdot
.694 .2746 Mdot
.694 .27462 Mdot
.694 .27466 Mdot
.694 .27479 Mdot
.694 .27482 Mdot
.694 .27491 Mdot
.694 .2751 Mdot
.694 .27526 Mdot
.694 .27536 Mdot
.694 .27538 Mdot
.694 .27557 Mdot
.694 .27572 Mdot
.694 .27591 Mdot
.694 .27605 Mdot
.694 .27609 Mdot
.694 .27614 Mdot
.694 .27619 Mdot
.694 .27699 Mdot
.694 .2771 Mdot
.694 .27757 Mdot
.694 .2776 Mdot
.694 .27776 Mdot
.694 .27782 Mdot
.694 .27782 Mdot
.694 .27788 Mdot
.694 .27853 Mdot
.694 .27857 Mdot
.694 .27865 Mdot
.694 .27867 Mdot
.694 .27869 Mdot
.694 .27872 Mdot
.694 .27876 Mdot
.694 .27885 Mdot
.694 .27897 Mdot
.694 .27908 Mdot
.694 .27938 Mdot
.694 .27959 Mdot
.694 .2798 Mdot
.694 .28019 Mdot
.694 .28022 Mdot
.694 .28027 Mdot
.694 .28039 Mdot
.694 .28045 Mdot
.694 .28073 Mdot
.694 .28118 Mdot
.694 .28129 Mdot
.694 .28155 Mdot
.694 .28168 Mdot
.694 .2818 Mdot
.694 .2818 Mdot
.694 .28198 Mdot
.694 .28256 Mdot
.694 .28261 Mdot
.694 .28262 Mdot
.694 .28304 Mdot
.694 .28305 Mdot
.694 .28327 Mdot
.694 .28327 Mdot
.694 .28329 Mdot
.694 .28346 Mdot
.694 .28374 Mdot
.694 .28408 Mdot
.694 .2842 Mdot
.694 .28442 Mdot
.694 .28442 Mdot
.694 .28486 Mdot
.694 .28493 Mdot
.694 .28518 Mdot
.694 .28559 Mdot
.694 .28595 Mdot
.694 .28606 Mdot
.694 .28616 Mdot
.694 .28649 Mdot
.694 .28649 Mdot
.694 .2867 Mdot
.694 .28675 Mdot
.694 .28687 Mdot
.694 .28702 Mdot
.694 .28723 Mdot
.694 .28731 Mdot
.694 .28774 Mdot
.694 .28776 Mdot
.694 .28804 Mdot
.694 .28809 Mdot
.694 .28816 Mdot
.694 .2882 Mdot
.694 .2883 Mdot
.694 .28851 Mdot
.694 .28851 Mdot
.694 .28858 Mdot
.694 .28877 Mdot
.694 .28892 Mdot
.694 .28896 Mdot
.694 .28915 Mdot
.694 .28917 Mdot
.694 .28924 Mdot
.694 .28933 Mdot
.694 .28951 Mdot
.694 .2898 Mdot
.694 .28996 Mdot
.694 .29021 Mdot
.694 .29027 Mdot
.694 .29044 Mdot
.694 .29066 Mdot
.694 .29071 Mdot
.694 .29114 Mdot
.694 .29132 Mdot
.694 .29149 Mdot
.694 .2918 Mdot
.694 .2918 Mdot
.694 .29224 Mdot
.694 .29236 Mdot
.694 .29243 Mdot
.694 .29279 Mdot
.694 .2929 Mdot
.694 .29297 Mdot
.694 .29301 Mdot
.694 .29308 Mdot
.694 .29312 Mdot
.694 .29317 Mdot
.694 .29329 Mdot
.694 .29336 Mdot
.694 .29342 Mdot
.694 .29361 Mdot
.694 .29366 Mdot
.694 .29379 Mdot
.694 .29379 Mdot
.694 .29396 Mdot
.694 .29412 Mdot
.694 .29416 Mdot
.694 .29419 Mdot
.694 .29423 Mdot
.694 .29442 Mdot
.694 .29457 Mdot
.694 .29469 Mdot
.694 .29471 Mdot
.694 .29482 Mdot
.694 .2949 Mdot
.694 .29497 Mdot
.694 .29509 Mdot
.694 .29516 Mdot
.694 .29522 Mdot
.694 .29527 Mdot
.694 .29531 Mdot
.694 .29533 Mdot
.694 .29536 Mdot
.694 .29542 Mdot
.694 .29561 Mdot
.694 .29594 Mdot
.694 .29594 Mdot
.694 .29619 Mdot
.694 .29628 Mdot
.694 .29664 Mdot
.694 .29673 Mdot
.694 .29676 Mdot
.694 .29689 Mdot
.694 .29713 Mdot
.694 .29722 Mdot
.694 .2973 Mdot
.694 .29743 Mdot
.694 .29751 Mdot
.694 .29764 Mdot
.694 .2978 Mdot
.694 .29783 Mdot
.694 .29786 Mdot
.694 .29788 Mdot
.694 .29803 Mdot
.694 .29804 Mdot
.694 .29827 Mdot
.694 .29856 Mdot
.694 .29858 Mdot
.694 .29869 Mdot
.694 .29886 Mdot
.694 .29892 Mdot
.694 .29897 Mdot
.694 .29977 Mdot
.694 .29977 Mdot
.694 .30036 Mdot
.694 .3007 Mdot
.694 .30073 Mdot
.694 .30103 Mdot
.694 .30113 Mdot
.694 .30113 Mdot
.694 .30119 Mdot
.694 .30126 Mdot
.694 .30139 Mdot
.694 .30168 Mdot
.694 .30186 Mdot
.694 .30196 Mdot
.694 .30238 Mdot
.694 .30266 Mdot
.694 .30271 Mdot
.694 .30272 Mdot
.694 .3028 Mdot
.694 .30282 Mdot
.694 .30331 Mdot
.694 .30332 Mdot
.694 .30362 Mdot
.694 .30404 Mdot
.694 .30411 Mdot
.694 .30418 Mdot
.694 .30428 Mdot
.694 .30436 Mdot
.694 .30447 Mdot
.694 .30452 Mdot
.694 .3046 Mdot
.694 .3047 Mdot
.694 .30483 Mdot
.694 .30486 Mdot
.694 .30514 Mdot
.694 .30525 Mdot
.694 .30532 Mdot
.694 .30561 Mdot
.694 .30586 Mdot
.694 .30597 Mdot
.694 .30611 Mdot
.694 .30611 Mdot
.694 .30624 Mdot
.694 .3064 Mdot
.694 .30651 Mdot
.694 .3067 Mdot
.694 .30679 Mdot
.694 .30684 Mdot
.694 .30691 Mdot
.694 .307 Mdot
.694 .3071 Mdot
.694 .30719 Mdot
.694 .30753 Mdot
.694 .30754 Mdot
.694 .30758 Mdot
.694 .30812 Mdot
.694 .30842 Mdot
.694 .30856 Mdot
.694 .30884 Mdot
.694 .30897 Mdot
.694 .30918 Mdot
.694 .30927 Mdot
.694 .3093 Mdot
.694 .3095 Mdot
.694 .30959 Mdot
.694 .30978 Mdot
.694 .30994 Mdot
.694 .30999 Mdot
.694 .31 Mdot
.694 .31 Mdot
.694 .31064 Mdot
.694 .3108 Mdot
.694 .31083 Mdot
.694 .31087 Mdot
.694 .31103 Mdot
.694 .31174 Mdot
.694 .31196 Mdot
.694 .31252 Mdot
.694 .31273 Mdot
.694 .31301 Mdot
.694 .31315 Mdot
.694 .31325 Mdot
.694 .3136 Mdot
.694 .31388 Mdot
.694 .31389 Mdot
.694 .31398 Mdot
.694 .31399 Mdot
.694 .31403 Mdot
.694 .31441 Mdot
.694 .31454 Mdot
.694 .31463 Mdot
.694 .31464 Mdot
.694 .31493 Mdot
.694 .3153 Mdot
.694 .31533 Mdot
.694 .31583 Mdot
.694 .31617 Mdot
.694 .3162 Mdot
.694 .3162 Mdot
.694 .31623 Mdot
.694 .31663 Mdot
.694 .31664 Mdot
.694 .31665 Mdot
.694 .3168 Mdot
.694 .31686 Mdot
.694 .31712 Mdot
.694 .31723 Mdot
.694 .31744 Mdot
.694 .31747 Mdot
.694 .31756 Mdot
.694 .31794 Mdot
.694 .31869 Mdot
.694 .31891 Mdot
.694 .31891 Mdot
.694 .31903 Mdot
.694 .31904 Mdot
.694 .31913 Mdot
.694 .31927 Mdot
.694 .31945 Mdot
.694 .31951 Mdot
.694 .31985 Mdot
.694 .31989 Mdot
.694 .32002 Mdot
.694 .32023 Mdot
.694 .3207 Mdot
.694 .3209 Mdot
.694 .32098 Mdot
.694 .32109 Mdot
.694 .32164 Mdot
.694 .32175 Mdot
.694 .32179 Mdot
.694 .32198 Mdot
.694 .32208 Mdot
.694 .32213 Mdot
.694 .32242 Mdot
.694 .32287 Mdot
.694 .32289 Mdot
.694 .3233 Mdot
.694 .32369 Mdot
.694 .32375 Mdot
.694 .32414 Mdot
.694 .32427 Mdot
.694 .3244 Mdot
.694 .32449 Mdot
.694 .32466 Mdot
.694 .32472 Mdot
.694 .3249 Mdot
.694 .32496 Mdot
.694 .32502 Mdot
.694 .32507 Mdot
.694 .3251 Mdot
.694 .32526 Mdot
.694 .32529 Mdot
.694 .32531 Mdot
.694 .32534 Mdot
.694 .32602 Mdot
.694 .32657 Mdot
.694 .32659 Mdot
.694 .32662 Mdot
.694 .32669 Mdot
.694 .3267 Mdot
.694 .32681 Mdot
.694 .32698 Mdot
.694 .32712 Mdot
.694 .32718 Mdot
.694 .32809 Mdot
.694 .3283 Mdot
.694 .3283 Mdot
.694 .32833 Mdot
.694 .32837 Mdot
.694 .32844 Mdot
.694 .32909 Mdot
.694 .32913 Mdot
.694 .32917 Mdot
.694 .32943 Mdot
.694 .32981 Mdot
.694 .32985 Mdot
.694 .32994 Mdot
.694 .32998 Mdot
.694 .33003 Mdot
.694 .3301 Mdot
.694 .33038 Mdot
.694 .33075 Mdot
.694 .33095 Mdot
.694 .33104 Mdot
.694 .33127 Mdot
.694 .3314 Mdot
.694 .33144 Mdot
.694 .33162 Mdot
.694 .33193 Mdot
.694 .3323 Mdot
.694 .33248 Mdot
.694 .33254 Mdot
.694 .33279 Mdot
.694 .33287 Mdot
.694 .3329 Mdot
.694 .33332 Mdot
.694 .33336 Mdot
.694 .33392 Mdot
.694 .33432 Mdot
.694 .33459 Mdot
.694 .33477 Mdot
.694 .33492 Mdot
.694 .33493 Mdot
.694 .33499 Mdot
.694 .33526 Mdot
.694 .33531 Mdot
.694 .33547 Mdot
.694 .33567 Mdot
.694 .33614 Mdot
.694 .33635 Mdot
.694 .33643 Mdot
.694 .33646 Mdot
.694 .3366 Mdot
.694 .33666 Mdot
.694 .33703 Mdot
.694 .33753 Mdot
.694 .33753 Mdot
.694 .33764 Mdot
.694 .33781 Mdot
.694 .33802 Mdot
.694 .33804 Mdot
.694 .33846 Mdot
.694 .33856 Mdot
.694 .3386 Mdot
.694 .33902 Mdot
.694 .33935 Mdot
.694 .33958 Mdot
.694 .34004 Mdot
.694 .34025 Mdot
.694 .34038 Mdot
.694 .34051 Mdot
.694 .34084 Mdot
.694 .34085 Mdot
.694 .34122 Mdot
.694 .34151 Mdot
.694 .34153 Mdot
.694 .34172 Mdot
.694 .3424 Mdot
.694 .34242 Mdot
.694 .34244 Mdot
.694 .34247 Mdot
.694 .34282 Mdot
.694 .34283 Mdot
.694 .34285 Mdot
.694 .34299 Mdot
.694 .34319 Mdot
.694 .34327 Mdot
.694 .34378 Mdot
.694 .34394 Mdot
.694 .34501 Mdot
.694 .34588 Mdot
.694 .34612 Mdot
.694 .34647 Mdot
.694 .34662 Mdot
.694 .34664 Mdot
.694 .34674 Mdot
.694 .34734 Mdot
.694 .34768 Mdot
.694 .34814 Mdot
.694 .34892 Mdot
.694 .34926 Mdot
.694 .34937 Mdot
.694 .34972 Mdot
.694 .34973 Mdot
.694 .34976 Mdot
.694 .34995 Mdot
.694 .35013 Mdot
.694 .35044 Mdot
.694 .35052 Mdot
.694 .36274 Mdot
.694 .3628 Mdot
.694 .36302 Mdot
.694 .36316 Mdot
.694 .36329 Mdot
.694 .36331 Mdot
.694 .36332 Mdot
.694 .36357 Mdot
.694 .36365 Mdot
.694 .3639 Mdot
.694 .36446 Mdot
.694 .36479 Mdot
.694 .36504 Mdot
.694 .36547 Mdot
.694 .36554 Mdot
.694 .36555 Mdot
.694 .36566 Mdot
.694 .36591 Mdot
.694 .36609 Mdot
.694 .36671 Mdot
.694 .36748 Mdot
.694 .3676 Mdot
.694 .36796 Mdot
.694 .36803 Mdot
.694 .36817 Mdot
.694 .36827 Mdot
.694 .36828 Mdot
.694 .36829 Mdot
.694 .36854 Mdot
.694 .36857 Mdot
.694 .36858 Mdot
.694 .36859 Mdot
.694 .36909 Mdot
.694 .36922 Mdot
.694 .36924 Mdot
.694 .36945 Mdot
.694 .36971 Mdot
.694 .36972 Mdot
.694 .36995 Mdot
.694 .37005 Mdot
.694 .37015 Mdot
.694 .37029 Mdot
.694 .37052 Mdot
.694 .37062 Mdot
.694 .37079 Mdot
.694 .37103 Mdot
.694 .37133 Mdot
.694 .37136 Mdot
.694 .37143 Mdot
.694 .37174 Mdot
.694 .37175 Mdot
.694 .3719 Mdot
.694 .37202 Mdot
.694 .3721 Mdot
.694 .3721 Mdot
.694 .37246 Mdot
.694 .37273 Mdot
.694 .37277 Mdot
.694 .37287 Mdot
.694 .37289 Mdot
.694 .37295 Mdot
.694 .3731 Mdot
.694 .37344 Mdot
.694 .37359 Mdot
.694 .3737 Mdot
.694 .37374 Mdot
.694 .37393 Mdot
.694 .37398 Mdot
.694 .37398 Mdot
.694 .37409 Mdot
.694 .37422 Mdot
.694 .37441 Mdot
.694 .3747 Mdot
.694 .37511 Mdot
.694 .37513 Mdot
.694 .37544 Mdot
.694 .37546 Mdot
.694 .37552 Mdot
.694 .3757 Mdot
.694 .37574 Mdot
.694 .37587 Mdot
.694 .37614 Mdot
.694 .37636 Mdot
.694 .37649 Mdot
.694 .37652 Mdot
.694 .37662 Mdot
.694 .37678 Mdot
.694 .37684 Mdot
.694 .37698 Mdot
.694 .37725 Mdot
.694 .37745 Mdot
.694 .3775 Mdot
.694 .37754 Mdot
.694 .37757 Mdot
.694 .37764 Mdot
.694 .37766 Mdot
.694 .37794 Mdot
.694 .37813 Mdot
.694 .37816 Mdot
.694 .37818 Mdot
.694 .37865 Mdot
.694 .3787 Mdot
.694 .37873 Mdot
.694 .37875 Mdot
.694 .37875 Mdot
.694 .3789 Mdot
.694 .37956 Mdot
.694 .3796 Mdot
.694 .3797 Mdot
.694 .37982 Mdot
.694 .37991 Mdot
.694 .37991 Mdot
.694 .37997 Mdot
.694 .37999 Mdot
.694 .38 Mdot
.694 .3804 Mdot
.694 .38089 Mdot
.694 .38091 Mdot
.694 .38092 Mdot
.694 .38094 Mdot
.694 .38106 Mdot
.694 .38108 Mdot
.694 .38111 Mdot
.694 .38116 Mdot
.694 .3812 Mdot
.694 .38133 Mdot
.694 .38137 Mdot
.694 .3815 Mdot
.694 .38156 Mdot
.694 .38166 Mdot
.694 .38175 Mdot
.694 .38203 Mdot
.694 .38208 Mdot
.694 .38236 Mdot
.694 .38265 Mdot
.694 .38267 Mdot
.694 .38299 Mdot
.694 .3832 Mdot
.694 .38323 Mdot
.694 .3833 Mdot
.694 .38345 Mdot
.694 .38347 Mdot
.694 .38355 Mdot
.694 .38395 Mdot
.694 .38403 Mdot
.694 .38409 Mdot
.694 .38423 Mdot
.694 .38456 Mdot
.694 .38472 Mdot
.694 .38481 Mdot
.694 .38484 Mdot
.694 .38508 Mdot
.694 .38513 Mdot
.694 .38526 Mdot
.694 .38536 Mdot
.694 .38542 Mdot
.694 .38543 Mdot
.694 .38551 Mdot
.694 .38552 Mdot
.694 .38568 Mdot
.694 .38621 Mdot
.694 .38649 Mdot
.694 .38655 Mdot
.694 .38657 Mdot
.694 .38673 Mdot
.694 .38681 Mdot
.694 .387 Mdot
.694 .38704 Mdot
.694 .38714 Mdot
.694 .38715 Mdot
.694 .38716 Mdot
.694 .38745 Mdot
.694 .38747 Mdot
.694 .38747 Mdot
.694 .38749 Mdot
.694 .38774 Mdot
.694 .3881 Mdot
.694 .38812 Mdot
.694 .38838 Mdot
.694 .38859 Mdot
.694 .3886 Mdot
.694 .38867 Mdot
.694 .38876 Mdot
.694 .38904 Mdot
.694 .38906 Mdot
.694 .38907 Mdot
.694 .38913 Mdot
.694 .38914 Mdot
.694 .38934 Mdot
.694 .38959 Mdot
.694 .38967 Mdot
.694 .38977 Mdot
.694 .38997 Mdot
.694 .39012 Mdot
.694 .39052 Mdot
.694 .39069 Mdot
.694 .39119 Mdot
.694 .39131 Mdot
.694 .39134 Mdot
.694 .39136 Mdot
.694 .39148 Mdot
.694 .39194 Mdot
.694 .39194 Mdot
.694 .39195 Mdot
.694 .39198 Mdot
.694 .39209 Mdot
.694 .39223 Mdot
.694 .39229 Mdot
.694 .39244 Mdot
.694 .39246 Mdot
.694 .39253 Mdot
.694 .39268 Mdot
.694 .39277 Mdot
.694 .39297 Mdot
.694 .39307 Mdot
.694 .39329 Mdot
.694 .39368 Mdot
.694 .39371 Mdot
.694 .39371 Mdot
.694 .39396 Mdot
.694 .39402 Mdot
.694 .3941 Mdot
.694 .39416 Mdot
.694 .39421 Mdot
.694 .39425 Mdot
.694 .39431 Mdot
.694 .39445 Mdot
.694 .39453 Mdot
.694 .39464 Mdot
.694 .39474 Mdot
.694 .39474 Mdot
.694 .39484 Mdot
.694 .39492 Mdot
.694 .3951 Mdot
.694 .39531 Mdot
.694 .39536 Mdot
.694 .39544 Mdot
.694 .39564 Mdot
.694 .39566 Mdot
.694 .39575 Mdot
.694 .39583 Mdot
.694 .39589 Mdot
.694 .39592 Mdot
.694 .396 Mdot
.694 .39605 Mdot
.694 .39613 Mdot
.694 .39618 Mdot
.694 .39623 Mdot
.694 .39653 Mdot
.694 .39675 Mdot
.694 .39676 Mdot
.694 .39711 Mdot
.694 .39712 Mdot
.694 .39718 Mdot
.694 .39719 Mdot
.694 .39723 Mdot
.694 .39743 Mdot
.694 .39773 Mdot
.694 .3978 Mdot
.694 .39793 Mdot
.694 .39814 Mdot
.694 .39824 Mdot
.694 .39828 Mdot
.694 .39833 Mdot
.694 .39833 Mdot
.694 .3984 Mdot
.694 .39861 Mdot
.694 .39864 Mdot
.694 .39888 Mdot
.694 .39931 Mdot
.694 .39931 Mdot
.694 .39988 Mdot
.694 .39992 Mdot
.694 .39996 Mdot
.694 .40009 Mdot
.694 .40016 Mdot
.694 .40018 Mdot
.694 .40039 Mdot
.694 .40055 Mdot
.694 .40056 Mdot
.694 .40067 Mdot
.694 .40068 Mdot
.694 .40071 Mdot
.694 .40072 Mdot
.694 .40084 Mdot
.694 .40094 Mdot
.694 .40099 Mdot
.694 .40109 Mdot
.694 .40115 Mdot
.694 .40121 Mdot
.694 .40138 Mdot
.694 .40148 Mdot
.694 .4015 Mdot
.694 .40156 Mdot
.694 .40182 Mdot
.694 .40189 Mdot
.694 .40207 Mdot
.694 .40207 Mdot
.694 .4023 Mdot
.694 .40244 Mdot
.694 .40248 Mdot
.694 .40251 Mdot
.694 .40252 Mdot
.694 .40255 Mdot
.694 .40258 Mdot
.694 .40263 Mdot
.694 .40268 Mdot
.694 .40276 Mdot
.694 .40281 Mdot
.694 .40288 Mdot
.694 .40295 Mdot
.694 .40296 Mdot
.694 .40305 Mdot
.694 .40316 Mdot
.694 .4033 Mdot
.694 .40333 Mdot
.694 .40335 Mdot
.694 .40338 Mdot
.694 .40349 Mdot
.694 .40362 Mdot
.694 .40362 Mdot
.694 .40371 Mdot
.694 .40374 Mdot
.694 .40388 Mdot
.694 .40392 Mdot
.694 .40397 Mdot
.694 .40406 Mdot
.694 .40409 Mdot
.694 .40413 Mdot
.694 .40418 Mdot
.694 .4042 Mdot
.694 .40426 Mdot
.694 .40434 Mdot
.694 .4046 Mdot
.694 .40465 Mdot
.694 .40473 Mdot
.694 .40505 Mdot
.694 .40505 Mdot
.694 .40527 Mdot
.694 .4054 Mdot
.694 .40552 Mdot
.694 .40583 Mdot
.694 .40587 Mdot
.694 .40603 Mdot
.694 .40615 Mdot
.694 .40619 Mdot
.694 .40638 Mdot
.694 .40649 Mdot
.694 .4067 Mdot
.694 .40683 Mdot
.694 .40689 Mdot
.694 .40694 Mdot
.694 .40695 Mdot
.694 .4071 Mdot
.694 .40712 Mdot
.694 .40723 Mdot
.694 .40737 Mdot
.694 .40742 Mdot
.694 .40742 Mdot
.694 .40757 Mdot
.694 .40764 Mdot
.694 .40767 Mdot
.694 .40772 Mdot
.694 .40775 Mdot
.694 .40796 Mdot
.694 .40797 Mdot
.694 .40829 Mdot
.694 .40834 Mdot
.694 .40849 Mdot
.694 .4086 Mdot
.694 .40869 Mdot
.694 .40872 Mdot
.694 .40887 Mdot
.694 .40887 Mdot
.694 .40912 Mdot
.694 .40919 Mdot
.694 .40926 Mdot
.694 .40952 Mdot
.694 .40982 Mdot
.694 .41 Mdot
.694 .41005 Mdot
.694 .41037 Mdot
.694 .41037 Mdot
.694 .41052 Mdot
.694 .41061 Mdot
.694 .41086 Mdot
.694 .41105 Mdot
.694 .41118 Mdot
.694 .41119 Mdot
.694 .4112 Mdot
.694 .41136 Mdot
.694 .41136 Mdot
.694 .41166 Mdot
.694 .41167 Mdot
.694 .4117 Mdot
.694 .41212 Mdot
.694 .41225 Mdot
.694 .41226 Mdot
.694 .41234 Mdot
.694 .41243 Mdot
.694 .41262 Mdot
.694 .4127 Mdot
.694 .41302 Mdot
.694 .41323 Mdot
.694 .41327 Mdot
.694 .41336 Mdot
.694 .41339 Mdot
.694 .41341 Mdot
.694 .4137 Mdot
.694 .41385 Mdot
.694 .41399 Mdot
.694 .41421 Mdot
.694 .41429 Mdot
.694 .41438 Mdot
.694 .41445 Mdot
.694 .41447 Mdot
.694 .41449 Mdot
.694 .41451 Mdot
.694 .41452 Mdot
.694 .41458 Mdot
.694 .41461 Mdot
.694 .41508 Mdot
.694 .41512 Mdot
.694 .41512 Mdot
.694 .41516 Mdot
.694 .41528 Mdot
.694 .4153 Mdot
.694 .41564 Mdot
.694 .41572 Mdot
.694 .4163 Mdot
.694 .41633 Mdot
.694 .41637 Mdot
.694 .41639 Mdot
.694 .4165 Mdot
.694 .41664 Mdot
.694 .41674 Mdot
.694 .41688 Mdot
.694 .4169 Mdot
.694 .41696 Mdot
.694 .41708 Mdot
.694 .41722 Mdot
.694 .41728 Mdot
.694 .41731 Mdot
.694 .4174 Mdot
.694 .41743 Mdot
.694 .41744 Mdot
.694 .41761 Mdot
.694 .41782 Mdot
.694 .41797 Mdot
.694 .41807 Mdot
.694 .41814 Mdot
.694 .41819 Mdot
.694 .4182 Mdot
.694 .41832 Mdot
.694 .41834 Mdot
.694 .41848 Mdot
.694 .41873 Mdot
.694 .41882 Mdot
.694 .41898 Mdot
.694 .41917 Mdot
.694 .41917 Mdot
.694 .41921 Mdot
.694 .41935 Mdot
.694 .41936 Mdot
.694 .41956 Mdot
.694 .41957 Mdot
.694 .41973 Mdot
.694 .41994 Mdot
.694 .41999 Mdot
.694 .42011 Mdot
.694 .42019 Mdot
.694 .42024 Mdot
.694 .42029 Mdot
.694 .42041 Mdot
.694 .42055 Mdot
.694 .42067 Mdot
.694 .42101 Mdot
.694 .42115 Mdot
.694 .42116 Mdot
.694 .42121 Mdot
.694 .42132 Mdot
.694 .42197 Mdot
.694 .42229 Mdot
.694 .42238 Mdot
.694 .42252 Mdot
.694 .42257 Mdot
.694 .42258 Mdot
.694 .42262 Mdot
.694 .42284 Mdot
.694 .42297 Mdot
.694 .42314 Mdot
.694 .42343 Mdot
.694 .42356 Mdot
.694 .4236 Mdot
.694 .42373 Mdot
.694 .42373 Mdot
.694 .42374 Mdot
.694 .42381 Mdot
.694 .42388 Mdot
.694 .424 Mdot
.694 .42403 Mdot
.696 .26441 Mdot
.696 .26455 Mdot
.696 .26461 Mdot
.696 .26507 Mdot
.696 .2652 Mdot
.696 .26549 Mdot
.696 .2655 Mdot
.696 .26562 Mdot
.696 .26568 Mdot
.696 .26577 Mdot
.696 .26613 Mdot
.696 .26628 Mdot
.696 .26629 Mdot
.696 .26632 Mdot
.696 .26647 Mdot
.696 .26658 Mdot
.696 .26659 Mdot
.696 .26679 Mdot
.696 .2669 Mdot
.696 .26715 Mdot
.696 .26719 Mdot
.696 .2674 Mdot
.696 .26742 Mdot
.696 .26746 Mdot
.696 .26749 Mdot
.696 .26752 Mdot
.696 .26754 Mdot
.696 .26768 Mdot
.696 .26792 Mdot
.696 .26798 Mdot
.696 .26813 Mdot
.696 .26889 Mdot
.696 .26902 Mdot
.696 .26909 Mdot
.696 .2691 Mdot
.696 .26927 Mdot
.696 .26963 Mdot
.696 .27038 Mdot
.696 .27067 Mdot
.696 .27068 Mdot
.696 .27071 Mdot
.696 .2709 Mdot
.696 .2711 Mdot
.696 .2711 Mdot
.696 .27149 Mdot
.696 .27153 Mdot
.696 .27169 Mdot
.696 .27184 Mdot
.696 .272 Mdot
.696 .27205 Mdot
.696 .27229 Mdot
.696 .27229 Mdot
.696 .2723 Mdot
.696 .27237 Mdot
.696 .27257 Mdot
.696 .27257 Mdot
.696 .27266 Mdot
.696 .27274 Mdot
.696 .27282 Mdot
.696 .27282 Mdot
.696 .27289 Mdot
.696 .27291 Mdot
.696 .27308 Mdot
.696 .27314 Mdot
.696 .27393 Mdot
.696 .27396 Mdot
.696 .27407 Mdot
.696 .27412 Mdot
.696 .27413 Mdot
.696 .27458 Mdot
.696 .27461 Mdot
.696 .27462 Mdot
.696 .27487 Mdot
.696 .27506 Mdot
.696 .2751 Mdot
.696 .27521 Mdot
.696 .27532 Mdot
.696 .27536 Mdot
.696 .27557 Mdot
.696 .27567 Mdot
.696 .27571 Mdot
.696 .27574 Mdot
.696 .27577 Mdot
.696 .27578 Mdot
.696 .2758 Mdot
.696 .27641 Mdot
.696 .27642 Mdot
.696 .27647 Mdot
.696 .27685 Mdot
.696 .2772 Mdot
.696 .27736 Mdot
.696 .27738 Mdot
.696 .27789 Mdot
.696 .27827 Mdot
.696 .27843 Mdot
.696 .2785 Mdot
.696 .27852 Mdot
.696 .27881 Mdot
.696 .27902 Mdot
.696 .27931 Mdot
.696 .27932 Mdot
.696 .27968 Mdot
.696 .27984 Mdot
.696 .27987 Mdot
.696 .28021 Mdot
.696 .28023 Mdot
.696 .2803 Mdot
.696 .28036 Mdot
.696 .28047 Mdot
.696 .2806 Mdot
.696 .2806 Mdot
.696 .28068 Mdot
.696 .2808 Mdot
.696 .28137 Mdot
.696 .28138 Mdot
.696 .28177 Mdot
.696 .28204 Mdot
.696 .28232 Mdot
.696 .28284 Mdot
.696 .28284 Mdot
.696 .28289 Mdot
.696 .28346 Mdot
.696 .28376 Mdot
.696 .28398 Mdot
.696 .28405 Mdot
.696 .28426 Mdot
.696 .28431 Mdot
.696 .28435 Mdot
.696 .28463 Mdot
.696 .2849 Mdot
.696 .28504 Mdot
.696 .28547 Mdot
.696 .28566 Mdot
.696 .28579 Mdot
.696 .28579 Mdot
.696 .28595 Mdot
.696 .28597 Mdot
.696 .28625 Mdot
.696 .28668 Mdot
.696 .28686 Mdot
.696 .28689 Mdot
.696 .28711 Mdot
.696 .28712 Mdot
.696 .28713 Mdot
.696 .28714 Mdot
.696 .28715 Mdot
.696 .28719 Mdot
.696 .28725 Mdot
.696 .28727 Mdot
.696 .2873 Mdot
.696 .28761 Mdot
.696 .2881 Mdot
.696 .28843 Mdot
.696 .28851 Mdot
.696 .28855 Mdot
.696 .28858 Mdot
.696 .28864 Mdot
.696 .28889 Mdot
.696 .28923 Mdot
.696 .28932 Mdot
.696 .29001 Mdot
.696 .29021 Mdot
.696 .29029 Mdot
.696 .29059 Mdot
.696 .29063 Mdot
.696 .29068 Mdot
.696 .29101 Mdot
.696 .29126 Mdot
.696 .2917 Mdot
.696 .29177 Mdot
.696 .29197 Mdot
.696 .29229 Mdot
.696 .29236 Mdot
.696 .29249 Mdot
.696 .29295 Mdot
.696 .2936 Mdot
.696 .29366 Mdot
.696 .29374 Mdot
.696 .29392 Mdot
.696 .29454 Mdot
.696 .29495 Mdot
.696 .29528 Mdot
.696 .29545 Mdot
.696 .29555 Mdot
.696 .29582 Mdot
.696 .29595 Mdot
.696 .29682 Mdot
.696 .29704 Mdot
.696 .2977 Mdot
.696 .29786 Mdot
.696 .29788 Mdot
.696 .29794 Mdot
.696 .29794 Mdot
.696 .29796 Mdot
.696 .29809 Mdot
.696 .29856 Mdot
.696 .29871 Mdot
.696 .2991 Mdot
.696 .29924 Mdot
.696 .29954 Mdot
.696 .29969 Mdot
.696 .29985 Mdot
.696 .30043 Mdot
.696 .30057 Mdot
.696 .30122 Mdot
.696 .30128 Mdot
.696 .30132 Mdot
.696 .30138 Mdot
.696 .30147 Mdot
.696 .30152 Mdot
.696 .30171 Mdot
.696 .30179 Mdot
.696 .30198 Mdot
.696 .30213 Mdot
.696 .30224 Mdot
.696 .30252 Mdot
.696 .30325 Mdot
.696 .3038 Mdot
.696 .3038 Mdot
.696 .30385 Mdot
.696 .30386 Mdot
.696 .30392 Mdot
.696 .30402 Mdot
.696 .30405 Mdot
.696 .30416 Mdot
.696 .30428 Mdot
.696 .30467 Mdot
.696 .30469 Mdot
.696 .30517 Mdot
.696 .30529 Mdot
.696 .30533 Mdot
.696 .30542 Mdot
.696 .30546 Mdot
.696 .30557 Mdot
.696 .30561 Mdot
.696 .30561 Mdot
.696 .30602 Mdot
.696 .30622 Mdot
.696 .30644 Mdot
.696 .30659 Mdot
.696 .30716 Mdot
.696 .30729 Mdot
.696 .30776 Mdot
.696 .30783 Mdot
.696 .30786 Mdot
.696 .30799 Mdot
.696 .30806 Mdot
.696 .30807 Mdot
.696 .3081 Mdot
.696 .30812 Mdot
.696 .30813 Mdot
.696 .30824 Mdot
.696 .30826 Mdot
.696 .30839 Mdot
.696 .30855 Mdot
.696 .30861 Mdot
.696 .30879 Mdot
.696 .30897 Mdot
.696 .30967 Mdot
.696 .30979 Mdot
.696 .30982 Mdot
.696 .31006 Mdot
.696 .31013 Mdot
.696 .31028 Mdot
.696 .31028 Mdot
.696 .31034 Mdot
.696 .31037 Mdot
.696 .31069 Mdot
.696 .31069 Mdot
.696 .3107 Mdot
.696 .31084 Mdot
.696 .31095 Mdot
.696 .31131 Mdot
.696 .31203 Mdot
.696 .31213 Mdot
.696 .31214 Mdot
.696 .31241 Mdot
.696 .31295 Mdot
.696 .31297 Mdot
.696 .31307 Mdot
.696 .31317 Mdot
.696 .31339 Mdot
.696 .31348 Mdot
.696 .31355 Mdot
.696 .31363 Mdot
.696 .31366 Mdot
.696 .31379 Mdot
.696 .31393 Mdot
.696 .31402 Mdot
.696 .31406 Mdot
.696 .31409 Mdot
.696 .31419 Mdot
.696 .31463 Mdot
.696 .31465 Mdot
.696 .31474 Mdot
.696 .31497 Mdot
.696 .31498 Mdot
.696 .31499 Mdot
.696 .31521 Mdot
.696 .31529 Mdot
.696 .31556 Mdot
.696 .31558 Mdot
.696 .31591 Mdot
.696 .31592 Mdot
.696 .31594 Mdot
.696 .31632 Mdot
.696 .3164 Mdot
.696 .31641 Mdot
.696 .31668 Mdot
.696 .31696 Mdot
.696 .31699 Mdot
.696 .317 Mdot
.696 .31741 Mdot
.696 .3177 Mdot
.696 .31788 Mdot
.696 .31795 Mdot
.696 .31807 Mdot
.696 .31847 Mdot
.696 .31848 Mdot
.696 .31868 Mdot
.696 .31923 Mdot
.696 .31923 Mdot
.696 .31925 Mdot
.696 .31982 Mdot
.696 .31996 Mdot
.696 .31999 Mdot
.696 .32001 Mdot
.696 .32037 Mdot
.696 .32059 Mdot
.696 .32075 Mdot
.696 .32075 Mdot
.696 .32084 Mdot
.696 .32099 Mdot
.696 .32121 Mdot
.696 .32132 Mdot
.696 .32144 Mdot
.696 .32144 Mdot
.696 .32147 Mdot
.696 .3215 Mdot
.696 .32194 Mdot
.696 .32212 Mdot
.696 .32216 Mdot
.696 .32218 Mdot
.696 .32219 Mdot
.696 .32222 Mdot
.696 .32253 Mdot
.696 .32293 Mdot
.696 .32303 Mdot
.696 .32307 Mdot
.696 .32323 Mdot
.696 .32325 Mdot
.696 .32327 Mdot
.696 .3238 Mdot
.696 .32414 Mdot
.696 .32421 Mdot
.696 .32478 Mdot
.696 .32481 Mdot
.696 .32495 Mdot
.696 .32527 Mdot
.696 .32593 Mdot
.696 .32599 Mdot
.696 .32656 Mdot
.696 .32698 Mdot
.696 .32699 Mdot
.696 .32702 Mdot
.696 .32702 Mdot
.696 .32734 Mdot
.696 .32785 Mdot
.696 .32793 Mdot
.696 .32801 Mdot
.696 .32831 Mdot
.696 .32874 Mdot
.696 .32885 Mdot
.696 .32887 Mdot
.696 .32897 Mdot
.696 .32901 Mdot
.696 .32924 Mdot
.696 .32976 Mdot
.696 .33004 Mdot
.696 .33005 Mdot
.696 .33008 Mdot
.696 .33011 Mdot
.696 .33017 Mdot
.696 .33023 Mdot
.696 .33029 Mdot
.696 .33049 Mdot
.696 .3309 Mdot
.696 .33098 Mdot
.696 .33098 Mdot
.696 .33119 Mdot
.696 .33141 Mdot
.696 .33149 Mdot
.696 .33185 Mdot
.696 .33234 Mdot
.696 .33235 Mdot
.696 .33242 Mdot
.696 .33262 Mdot
.696 .33308 Mdot
.696 .33315 Mdot
.696 .33328 Mdot
.696 .33331 Mdot
.696 .33339 Mdot
.696 .33339 Mdot
.696 .33361 Mdot
.696 .33368 Mdot
.696 .33429 Mdot
.696 .33435 Mdot
.696 .33478 Mdot
.696 .33483 Mdot
.696 .33488 Mdot
.696 .335 Mdot
.696 .33512 Mdot
.696 .3352 Mdot
.696 .33527 Mdot
.696 .33532 Mdot
.696 .33536 Mdot
.696 .33564 Mdot
.696 .33569 Mdot
.696 .33581 Mdot
.696 .33582 Mdot
.696 .33582 Mdot
.696 .33598 Mdot
.696 .33612 Mdot
.696 .33613 Mdot
.696 .3363 Mdot
.696 .3363 Mdot
.696 .33631 Mdot
.696 .33669 Mdot
.696 .33684 Mdot
.696 .33685 Mdot
.696 .33686 Mdot
.696 .33722 Mdot
.696 .33731 Mdot
.696 .33741 Mdot
.696 .33762 Mdot
.696 .33772 Mdot
.696 .33801 Mdot
.696 .33831 Mdot
.696 .33839 Mdot
.696 .3384 Mdot
.696 .33841 Mdot
.696 .33884 Mdot
.696 .33915 Mdot
.696 .33915 Mdot
.696 .33941 Mdot
.696 .3395 Mdot
.696 .33953 Mdot
.696 .33954 Mdot
.696 .33992 Mdot
.696 .33997 Mdot
.696 .33999 Mdot
.696 .3401 Mdot
.696 .34055 Mdot
.696 .34147 Mdot
.696 .34179 Mdot
.696 .34201 Mdot
.696 .34203 Mdot
.696 .34246 Mdot
.696 .3425 Mdot
.696 .34269 Mdot
.696 .34304 Mdot
.696 .34306 Mdot
.696 .34318 Mdot
.696 .34345 Mdot
.696 .34359 Mdot
.696 .34407 Mdot
.696 .34492 Mdot
.696 .3452 Mdot
.696 .34532 Mdot
.696 .34578 Mdot
.696 .34581 Mdot
.696 .34603 Mdot
.696 .34606 Mdot
.696 .34609 Mdot
.696 .34615 Mdot
.696 .34621 Mdot
.696 .34629 Mdot
.696 .34633 Mdot
.696 .34657 Mdot
.696 .34672 Mdot
.696 .34682 Mdot
.696 .34729 Mdot
.696 .3475 Mdot
.696 .3479 Mdot
.696 .34791 Mdot
.696 .34813 Mdot
.696 .34842 Mdot
.696 .34847 Mdot
.696 .34849 Mdot
.696 .34878 Mdot
.696 .34949 Mdot
.696 .34965 Mdot
.696 .34978 Mdot
.696 .35 Mdot
.696 .35002 Mdot
.696 .35058 Mdot
.696 .35083 Mdot
.696 .35173 Mdot
.696 .35184 Mdot
.696 .35212 Mdot
.696 .36229 Mdot
.696 .36249 Mdot
.696 .36257 Mdot
.696 .36322 Mdot
.696 .36339 Mdot
.696 .3638 Mdot
.696 .36381 Mdot
.696 .36397 Mdot
.696 .36406 Mdot
.696 .36418 Mdot
.696 .36469 Mdot
.696 .3649 Mdot
.696 .36491 Mdot
.696 .36494 Mdot
.696 .36515 Mdot
.696 .36531 Mdot
.696 .36532 Mdot
.696 .36561 Mdot
.696 .36576 Mdot
.696 .3661 Mdot
.696 .36616 Mdot
.696 .36628 Mdot
.696 .36645 Mdot
.696 .36648 Mdot
.696 .36653 Mdot
.696 .36658 Mdot
.696 .36662 Mdot
.696 .36664 Mdot
.696 .36666 Mdot
.696 .36682 Mdot
.696 .36684 Mdot
.696 .36718 Mdot
.696 .36726 Mdot
.696 .36746 Mdot
.696 .36807 Mdot
.696 .36842 Mdot
.696 .36852 Mdot
.696 .36871 Mdot
.696 .3688 Mdot
.696 .36882 Mdot
.696 .36906 Mdot
.696 .3692 Mdot
.696 .36923 Mdot
.696 .36954 Mdot
.696 .36955 Mdot
.696 .36971 Mdot
.696 .36994 Mdot
.696 .3706 Mdot
.696 .37093 Mdot
.696 .371 Mdot
.696 .37102 Mdot
.696 .37106 Mdot
.696 .37133 Mdot
.696 .37133 Mdot
.696 .37136 Mdot
.696 .37142 Mdot
.696 .37161 Mdot
.696 .37161 Mdot
.696 .37183 Mdot
.696 .37214 Mdot
.696 .37214 Mdot
.696 .37216 Mdot
.696 .37221 Mdot
.696 .37243 Mdot
.696 .37263 Mdot
.696 .37271 Mdot
.696 .37286 Mdot
.696 .37293 Mdot
.696 .37299 Mdot
.696 .37325 Mdot
.696 .37326 Mdot
.696 .37327 Mdot
.696 .37337 Mdot
.696 .37364 Mdot
.696 .37365 Mdot
.696 .37366 Mdot
.696 .37378 Mdot
.696 .37379 Mdot
.696 .37389 Mdot
.696 .374 Mdot
.696 .374 Mdot
.696 .37401 Mdot
.696 .37409 Mdot
.696 .37412 Mdot
.696 .37433 Mdot
.696 .37436 Mdot
.696 .37439 Mdot
.696 .37444 Mdot
.696 .3745 Mdot
.696 .37459 Mdot
.696 .37467 Mdot
.696 .37471 Mdot
.696 .37475 Mdot
.696 .37506 Mdot
.696 .3751 Mdot
.696 .37554 Mdot
.696 .37559 Mdot
.696 .37574 Mdot
.696 .37575 Mdot
.696 .3758 Mdot
.696 .37583 Mdot
.696 .37591 Mdot
.696 .37597 Mdot
.696 .3763 Mdot
.696 .37644 Mdot
.696 .37649 Mdot
.696 .3765 Mdot
.696 .37685 Mdot
.696 .37711 Mdot
.696 .37717 Mdot
.696 .37732 Mdot
.696 .37748 Mdot
.696 .37748 Mdot
.696 .37753 Mdot
.696 .37783 Mdot
.696 .37797 Mdot
.696 .37801 Mdot
.696 .37806 Mdot
.696 .3781 Mdot
.696 .37812 Mdot
.696 .37814 Mdot
.696 .37815 Mdot
.696 .37835 Mdot
.696 .37872 Mdot
.696 .37889 Mdot
.696 .37892 Mdot
.696 .37899 Mdot
.696 .37901 Mdot
.696 .37908 Mdot
.696 .3794 Mdot
.696 .37961 Mdot
.696 .37967 Mdot
.696 .37973 Mdot
.696 .38009 Mdot
.696 .38032 Mdot
.696 .38032 Mdot
.696 .38034 Mdot
.696 .38035 Mdot
.696 .38065 Mdot
.696 .38106 Mdot
.696 .38111 Mdot
.696 .38158 Mdot
.696 .38181 Mdot
.696 .38191 Mdot
.696 .38193 Mdot
.696 .38234 Mdot
.696 .38239 Mdot
.696 .38263 Mdot
.696 .38301 Mdot
.696 .38303 Mdot
.696 .38304 Mdot
.696 .38316 Mdot
.696 .38319 Mdot
.696 .38326 Mdot
.696 .38355 Mdot
.696 .38377 Mdot
.696 .38379 Mdot
.696 .3838 Mdot
.696 .38381 Mdot
.696 .38384 Mdot
.696 .38397 Mdot
.696 .38428 Mdot
.696 .38431 Mdot
.696 .38433 Mdot
.696 .38433 Mdot
.696 .38441 Mdot
.696 .3845 Mdot
.696 .38465 Mdot
.696 .38476 Mdot
.696 .38482 Mdot
.696 .38482 Mdot
.696 .38494 Mdot
.696 .3851 Mdot
.696 .38536 Mdot
.696 .38537 Mdot
.696 .38539 Mdot
.696 .38549 Mdot
.696 .3859 Mdot
.696 .38592 Mdot
.696 .38592 Mdot
.696 .38631 Mdot
.696 .38646 Mdot
.696 .38646 Mdot
.696 .38675 Mdot
.696 .38684 Mdot
.696 .38689 Mdot
.696 .38702 Mdot
.696 .38723 Mdot
.696 .38752 Mdot
.696 .38753 Mdot
.696 .38755 Mdot
.696 .38775 Mdot
.696 .38794 Mdot
.696 .38795 Mdot
.696 .38801 Mdot
.696 .38828 Mdot
.696 .3883 Mdot
.696 .3883 Mdot
.696 .38854 Mdot
.696 .38855 Mdot
.696 .38875 Mdot
.696 .3888 Mdot
.696 .38897 Mdot
.696 .38897 Mdot
.696 .38898 Mdot
.696 .38915 Mdot
.696 .38921 Mdot
.696 .38922 Mdot
.696 .38954 Mdot
.696 .38961 Mdot
.696 .38963 Mdot
.696 .38966 Mdot
.696 .38973 Mdot
.696 .38983 Mdot
.696 .38992 Mdot
.696 .38994 Mdot
.696 .39 Mdot
.696 .39005 Mdot
.696 .39011 Mdot
.696 .39027 Mdot
.696 .39034 Mdot
.696 .39042 Mdot
.696 .39043 Mdot
.696 .39082 Mdot
.696 .39101 Mdot
.696 .39102 Mdot
.696 .39109 Mdot
.696 .39161 Mdot
.696 .39187 Mdot
.696 .39195 Mdot
.696 .39204 Mdot
.696 .39205 Mdot
.696 .39206 Mdot
.696 .39228 Mdot
.696 .3923 Mdot
.696 .39234 Mdot
.696 .39235 Mdot
.696 .39246 Mdot
.696 .3925 Mdot
.696 .39268 Mdot
.696 .3927 Mdot
.696 .39278 Mdot
.696 .39329 Mdot
.696 .39342 Mdot
.696 .39354 Mdot
.696 .39359 Mdot
.696 .3937 Mdot
.696 .3938 Mdot
.696 .39381 Mdot
.696 .39389 Mdot
.696 .3939 Mdot
.696 .39391 Mdot
.696 .39394 Mdot
.696 .39394 Mdot
.696 .39399 Mdot
.696 .39408 Mdot
.696 .39411 Mdot
.696 .39416 Mdot
.696 .39449 Mdot
.696 .39458 Mdot
.696 .395 Mdot
.696 .39511 Mdot
.696 .39526 Mdot
.696 .39541 Mdot
.696 .3957 Mdot
.696 .3957 Mdot
.696 .39573 Mdot
.696 .39581 Mdot
.696 .39584 Mdot
.696 .3959 Mdot
.696 .39593 Mdot
.696 .39602 Mdot
.696 .39636 Mdot
.696 .39638 Mdot
.696 .39666 Mdot
.696 .39674 Mdot
.696 .39683 Mdot
.696 .39684 Mdot
.696 .39692 Mdot
.696 .39696 Mdot
.696 .39697 Mdot
.696 .397 Mdot
.696 .397 Mdot
.696 .3974 Mdot
.696 .39792 Mdot
.696 .39812 Mdot
.696 .3982 Mdot
.696 .39831 Mdot
.696 .39844 Mdot
.696 .3985 Mdot
.696 .39864 Mdot
.696 .39867 Mdot
.696 .39874 Mdot
.696 .39878 Mdot
.696 .39881 Mdot
.696 .39886 Mdot
.696 .39932 Mdot
.696 .39942 Mdot
.696 .39966 Mdot
.696 .39984 Mdot
.696 .39995 Mdot
.696 .40006 Mdot
.696 .40028 Mdot
.696 .40038 Mdot
.696 .40066 Mdot
.696 .40077 Mdot
.696 .40111 Mdot
.696 .4012 Mdot
.696 .40121 Mdot
.696 .40121 Mdot
.696 .40126 Mdot
.696 .40127 Mdot
.696 .40138 Mdot
.696 .40186 Mdot
.696 .40202 Mdot
.696 .40264 Mdot
.696 .40274 Mdot
.696 .40293 Mdot
.696 .403 Mdot
.696 .40312 Mdot
.696 .40336 Mdot
.696 .40366 Mdot
.696 .4041 Mdot
.696 .40423 Mdot
.696 .40429 Mdot
.696 .40433 Mdot
.696 .4048 Mdot
.696 .40512 Mdot
.696 .40522 Mdot
.696 .40527 Mdot
.696 .4055 Mdot
.696 .40564 Mdot
.696 .4057 Mdot
.696 .40601 Mdot
.696 .40619 Mdot
.696 .40643 Mdot
.696 .40647 Mdot
.696 .40649 Mdot
.696 .40671 Mdot
.696 .40677 Mdot
.696 .40691 Mdot
.696 .4074 Mdot
.696 .40747 Mdot
.696 .40771 Mdot
.696 .40789 Mdot
.696 .40794 Mdot
.696 .40795 Mdot
.696 .40798 Mdot
.696 .40804 Mdot
.696 .40828 Mdot
.696 .40863 Mdot
.696 .40885 Mdot
.696 .40888 Mdot
.696 .40889 Mdot
.696 .40894 Mdot
.696 .40897 Mdot
.696 .40897 Mdot
.696 .40898 Mdot
.696 .40899 Mdot
.696 .40899 Mdot
.696 .40915 Mdot
.696 .40917 Mdot
.696 .4093 Mdot
.696 .40961 Mdot
.696 .40981 Mdot
.696 .40982 Mdot
.696 .40994 Mdot
.696 .40994 Mdot
.696 .41004 Mdot
.696 .41017 Mdot
.696 .41048 Mdot
.696 .41058 Mdot
.696 .41078 Mdot
.696 .41097 Mdot
.696 .411 Mdot
.696 .41104 Mdot
.696 .41119 Mdot
.696 .41124 Mdot
.696 .4114 Mdot
.696 .41162 Mdot
.696 .41203 Mdot
.696 .41206 Mdot
.696 .41206 Mdot
.696 .41243 Mdot
.696 .41263 Mdot
.696 .41283 Mdot
.696 .41311 Mdot
.696 .41311 Mdot
.696 .41353 Mdot
.696 .41361 Mdot
.696 .41367 Mdot
.696 .41367 Mdot
.696 .41376 Mdot
.696 .41384 Mdot
.696 .41388 Mdot
.696 .41394 Mdot
.696 .41395 Mdot
.696 .41419 Mdot
.696 .41422 Mdot
.696 .41433 Mdot
.696 .41459 Mdot
.696 .4146 Mdot
.696 .4148 Mdot
.696 .41495 Mdot
.696 .41516 Mdot
.696 .41518 Mdot
.696 .41522 Mdot
.696 .41534 Mdot
.696 .41561 Mdot
.696 .41598 Mdot
.696 .416 Mdot
.696 .41611 Mdot
.696 .41636 Mdot
.696 .41663 Mdot
.696 .41667 Mdot
.696 .41668 Mdot
.696 .41712 Mdot
.696 .41713 Mdot
.696 .41714 Mdot
.696 .41716 Mdot
.696 .41718 Mdot
.696 .41721 Mdot
.696 .41728 Mdot
.696 .41743 Mdot
.696 .41746 Mdot
.696 .41754 Mdot
.696 .41762 Mdot
.696 .41765 Mdot
.696 .41778 Mdot
.696 .41797 Mdot
.696 .41797 Mdot
.696 .41799 Mdot
.696 .41831 Mdot
.696 .41833 Mdot
.696 .41836 Mdot
.696 .41844 Mdot
.696 .41846 Mdot
.696 .41903 Mdot
.696 .41907 Mdot
.696 .41919 Mdot
.696 .41921 Mdot
.696 .41926 Mdot
.696 .41926 Mdot
.696 .41931 Mdot
.696 .41937 Mdot
.696 .41943 Mdot
.696 .41944 Mdot
.696 .41958 Mdot
.696 .41963 Mdot
.696 .41964 Mdot
.696 .41964 Mdot
.696 .41981 Mdot
.696 .41985 Mdot
.696 .41996 Mdot
.696 .42007 Mdot
.696 .42018 Mdot
.696 .42021 Mdot
.696 .42049 Mdot
.696 .42049 Mdot
.696 .42064 Mdot
.696 .42078 Mdot
.696 .4208 Mdot
.696 .4208 Mdot
.696 .42101 Mdot
.696 .42155 Mdot
.696 .42181 Mdot
.696 .42193 Mdot
.696 .42194 Mdot
.696 .42198 Mdot
.696 .42208 Mdot
.696 .42263 Mdot
.696 .42273 Mdot
.696 .42278 Mdot
.696 .42295 Mdot
.696 .42305 Mdot
.696 .42306 Mdot
.696 .42309 Mdot
.696 .42311 Mdot
.696 .42314 Mdot
.696 .42315 Mdot
.696 .4233 Mdot
.696 .42333 Mdot
.696 .42351 Mdot
.696 .42359 Mdot
.696 .42373 Mdot
.696 .42374 Mdot
.696 .42382 Mdot
.696 .42393 Mdot
.696 .42395 Mdot
.696 .42395 Mdot
.696 .42406 Mdot
.696 .42432 Mdot
.696 .42439 Mdot
.696 .42443 Mdot
.696 .42451 Mdot
.696 .42452 Mdot
.696 .42473 Mdot
.696 .42482 Mdot
.696 .42515 Mdot
.696 .4252 Mdot
.696 .4253 Mdot
.698 .26382 Mdot
.698 .26384 Mdot
.698 .26386 Mdot
.698 .26405 Mdot
.698 .26425 Mdot
.698 .26437 Mdot
.698 .26455 Mdot
.698 .26467 Mdot
.698 .26472 Mdot
.698 .26479 Mdot
.698 .26559 Mdot
.698 .26559 Mdot
.698 .26565 Mdot
.698 .26651 Mdot
.698 .26651 Mdot
.698 .26651 Mdot
.698 .26655 Mdot
.698 .26668 Mdot
.698 .26676 Mdot
.698 .26684 Mdot
.698 .26697 Mdot
.698 .26705 Mdot
.698 .26713 Mdot
.698 .26785 Mdot
.698 .26797 Mdot
.698 .26804 Mdot
.698 .26851 Mdot
.698 .26867 Mdot
.698 .26881 Mdot
.698 .26902 Mdot
.698 .26908 Mdot
.698 .26913 Mdot
.698 .26919 Mdot
.698 .26936 Mdot
.698 .26954 Mdot
.698 .26969 Mdot
.698 .26975 Mdot
.698 .26977 Mdot
.698 .26993 Mdot
.698 .2702 Mdot
.698 .27042 Mdot
.698 .27054 Mdot
.698 .27062 Mdot
.698 .27072 Mdot
.698 .27097 Mdot
.698 .27103 Mdot
.698 .27134 Mdot
.698 .27153 Mdot
.698 .27162 Mdot
.698 .27164 Mdot
.698 .27168 Mdot
.698 .27187 Mdot
.698 .27194 Mdot
.698 .27236 Mdot
.698 .27249 Mdot
.698 .27282 Mdot
.698 .27293 Mdot
.698 .27298 Mdot
.698 .2733 Mdot
.698 .27336 Mdot
.698 .27372 Mdot
.698 .27373 Mdot
.698 .27389 Mdot
.698 .27395 Mdot
.698 .27424 Mdot
.698 .27453 Mdot
.698 .27455 Mdot
.698 .27475 Mdot
.698 .27492 Mdot
.698 .27517 Mdot
.698 .27537 Mdot
.698 .27566 Mdot
.698 .27574 Mdot
.698 .27636 Mdot
.698 .27641 Mdot
.698 .27649 Mdot
.698 .27652 Mdot
.698 .27704 Mdot
.698 .27716 Mdot
.698 .27733 Mdot
.698 .27755 Mdot
.698 .27758 Mdot
.698 .27758 Mdot
.698 .27759 Mdot
.698 .27764 Mdot
.698 .27765 Mdot
.698 .27792 Mdot
.698 .27811 Mdot
.698 .27811 Mdot
.698 .27818 Mdot
.698 .27838 Mdot
.698 .27853 Mdot
.698 .27866 Mdot
.698 .2788 Mdot
.698 .27896 Mdot
.698 .27904 Mdot
.698 .27925 Mdot
.698 .2794 Mdot
.698 .27981 Mdot
.698 .28009 Mdot
.698 .28024 Mdot
.698 .28075 Mdot
.698 .28088 Mdot
.698 .28114 Mdot
.698 .28154 Mdot
.698 .28173 Mdot
.698 .28195 Mdot
.698 .28252 Mdot
.698 .28272 Mdot
.698 .28282 Mdot
.698 .28294 Mdot
.698 .28312 Mdot
.698 .28321 Mdot
.698 .28325 Mdot
.698 .28349 Mdot
.698 .28372 Mdot
.698 .28379 Mdot
.698 .2838 Mdot
.698 .28388 Mdot
.698 .28398 Mdot
.698 .28418 Mdot
.698 .28425 Mdot
.698 .28477 Mdot
.698 .2848 Mdot
.698 .28499 Mdot
.698 .28501 Mdot
.698 .28509 Mdot
.698 .28515 Mdot
.698 .28562 Mdot
.698 .28571 Mdot
.698 .2858 Mdot
.698 .28606 Mdot
.698 .28625 Mdot
.698 .28653 Mdot
.698 .28654 Mdot
.698 .28677 Mdot
.698 .28678 Mdot
.698 .28681 Mdot
.698 .2873 Mdot
.698 .28734 Mdot
.698 .28738 Mdot
.698 .28745 Mdot
.698 .28757 Mdot
.698 .28812 Mdot
.698 .28831 Mdot
.698 .28834 Mdot
.698 .28846 Mdot
.698 .28894 Mdot
.698 .28938 Mdot
.698 .28969 Mdot
.698 .2897 Mdot
.698 .28989 Mdot
.698 .28993 Mdot
.698 .29001 Mdot
.698 .29007 Mdot
.698 .29052 Mdot
.698 .29055 Mdot
.698 .29062 Mdot
.698 .29106 Mdot
.698 .29114 Mdot
.698 .29118 Mdot
.698 .29132 Mdot
.698 .29134 Mdot
.698 .29137 Mdot
.698 .29142 Mdot
.698 .29158 Mdot
.698 .29158 Mdot
.698 .29164 Mdot
.698 .29166 Mdot
.698 .2918 Mdot
.698 .29197 Mdot
.698 .29204 Mdot
.698 .2921 Mdot
.698 .29224 Mdot
.698 .29246 Mdot
.698 .29279 Mdot
.698 .29297 Mdot
.698 .29309 Mdot
.698 .29323 Mdot
.698 .29325 Mdot
.698 .2933 Mdot
.698 .29343 Mdot
.698 .29369 Mdot
.698 .29386 Mdot
.698 .29397 Mdot
.698 .29409 Mdot
.698 .29431 Mdot
.698 .29464 Mdot
.698 .29481 Mdot
.698 .29499 Mdot
.698 .29502 Mdot
.698 .29514 Mdot
.698 .29522 Mdot
.698 .29525 Mdot
.698 .29526 Mdot
.698 .29538 Mdot
.698 .29539 Mdot
.698 .29548 Mdot
.698 .29552 Mdot
.698 .2958 Mdot
.698 .29603 Mdot
.698 .29612 Mdot
.698 .29623 Mdot
.698 .29639 Mdot
.698 .29686 Mdot
.698 .29703 Mdot
.698 .29732 Mdot
.698 .29743 Mdot
.698 .29745 Mdot
.698 .29772 Mdot
.698 .29784 Mdot
.698 .29785 Mdot
.698 .29799 Mdot
.698 .29822 Mdot
.698 .29831 Mdot
.698 .29859 Mdot
.698 .29863 Mdot
.698 .29864 Mdot
.698 .29874 Mdot
.698 .29875 Mdot
.698 .29905 Mdot
.698 .29916 Mdot
.698 .29921 Mdot
.698 .29925 Mdot
.698 .29929 Mdot
.698 .29941 Mdot
.698 .29953 Mdot
.698 .2996 Mdot
.698 .29969 Mdot
.698 .29975 Mdot
.698 .29991 Mdot
.698 .3002 Mdot
.698 .30061 Mdot
.698 .30075 Mdot
.698 .30081 Mdot
.698 .30129 Mdot
.698 .30169 Mdot
.698 .30181 Mdot
.698 .30195 Mdot
.698 .30203 Mdot
.698 .30226 Mdot
.698 .3024 Mdot
.698 .30243 Mdot
.698 .30244 Mdot
.698 .30257 Mdot
.698 .303 Mdot
.698 .30304 Mdot
.698 .30368 Mdot
.698 .30389 Mdot
.698 .304 Mdot
.698 .30442 Mdot
.698 .30463 Mdot
.698 .30483 Mdot
.698 .30505 Mdot
.698 .30512 Mdot
.698 .30537 Mdot
.698 .3055 Mdot
.698 .30596 Mdot
.698 .30601 Mdot
.698 .30645 Mdot
.698 .30649 Mdot
.698 .30656 Mdot
.698 .30678 Mdot
.698 .3068 Mdot
.698 .30683 Mdot
.698 .30694 Mdot
.698 .30701 Mdot
.698 .30709 Mdot
.698 .30734 Mdot
.698 .30795 Mdot
.698 .30803 Mdot
.698 .3081 Mdot
.698 .30812 Mdot
.698 .30856 Mdot
.698 .30859 Mdot
.698 .309 Mdot
.698 .30906 Mdot
.698 .30913 Mdot
.698 .30928 Mdot
.698 .30949 Mdot
.698 .30989 Mdot
.698 .30991 Mdot
.698 .31001 Mdot
.698 .31018 Mdot
.698 .31035 Mdot
.698 .3108 Mdot
.698 .31127 Mdot
.698 .31127 Mdot
.698 .3114 Mdot
.698 .31151 Mdot
.698 .31155 Mdot
.698 .31159 Mdot
.698 .31196 Mdot
.698 .31202 Mdot
.698 .31265 Mdot
.698 .31274 Mdot
.698 .31293 Mdot
.698 .31303 Mdot
.698 .31317 Mdot
.698 .31328 Mdot
.698 .31334 Mdot
.698 .31356 Mdot
.698 .31359 Mdot
.698 .31375 Mdot
.698 .31385 Mdot
.698 .31391 Mdot
.698 .31393 Mdot
.698 .31406 Mdot
.698 .31451 Mdot
.698 .31459 Mdot
.698 .31479 Mdot
.698 .31498 Mdot
.698 .31506 Mdot
.698 .31509 Mdot
.698 .31524 Mdot
.698 .31539 Mdot
.698 .31559 Mdot
.698 .31582 Mdot
.698 .31597 Mdot
.698 .31601 Mdot
.698 .31633 Mdot
.698 .31641 Mdot
.698 .31668 Mdot
.698 .31674 Mdot
.698 .31694 Mdot
.698 .31695 Mdot
.698 .31699 Mdot
.698 .31722 Mdot
.698 .31723 Mdot
.698 .31726 Mdot
.698 .31751 Mdot
.698 .31766 Mdot
.698 .31781 Mdot
.698 .31789 Mdot
.698 .31824 Mdot
.698 .31832 Mdot
.698 .31898 Mdot
.698 .31908 Mdot
.698 .31959 Mdot
.698 .31984 Mdot
.698 .32014 Mdot
.698 .32038 Mdot
.698 .32084 Mdot
.698 .32113 Mdot
.698 .32131 Mdot
.698 .32167 Mdot
.698 .32169 Mdot
.698 .32202 Mdot
.698 .32246 Mdot
.698 .32248 Mdot
.698 .32278 Mdot
.698 .32317 Mdot
.698 .32329 Mdot
.698 .32333 Mdot
.698 .32361 Mdot
.698 .32364 Mdot
.698 .32393 Mdot
.698 .32403 Mdot
.698 .32406 Mdot
.698 .32417 Mdot
.698 .32434 Mdot
.698 .32448 Mdot
.698 .32485 Mdot
.698 .32491 Mdot
.698 .32499 Mdot
.698 .325 Mdot
.698 .32502 Mdot
.698 .32522 Mdot
.698 .32536 Mdot
.698 .32579 Mdot
.698 .32589 Mdot
.698 .3259 Mdot
.698 .326 Mdot
.698 .32602 Mdot
.698 .32602 Mdot
.698 .32609 Mdot
.698 .32647 Mdot
.698 .32652 Mdot
.698 .32684 Mdot
.698 .32708 Mdot
.698 .32714 Mdot
.698 .32735 Mdot
.698 .32755 Mdot
.698 .32776 Mdot
.698 .32809 Mdot
.698 .32815 Mdot
.698 .3283 Mdot
.698 .32841 Mdot
.698 .32856 Mdot
.698 .32912 Mdot
.698 .32962 Mdot
.698 .32971 Mdot
.698 .32978 Mdot
.698 .33 Mdot
.698 .33034 Mdot
.698 .33051 Mdot
.698 .33072 Mdot
.698 .33084 Mdot
.698 .33121 Mdot
.698 .33151 Mdot
.698 .33154 Mdot
.698 .33176 Mdot
.698 .33179 Mdot
.698 .33193 Mdot
.698 .33196 Mdot
.698 .33222 Mdot
.698 .33254 Mdot
.698 .33308 Mdot
.698 .33311 Mdot
.698 .33322 Mdot
.698 .33353 Mdot
.698 .33354 Mdot
.698 .334 Mdot
.698 .33424 Mdot
.698 .33436 Mdot
.698 .33495 Mdot
.698 .33499 Mdot
.698 .33509 Mdot
.698 .33527 Mdot
.698 .3353 Mdot
.698 .33543 Mdot
.698 .33556 Mdot
.698 .33594 Mdot
.698 .33605 Mdot
.698 .3362 Mdot
.698 .33635 Mdot
.698 .33665 Mdot
.698 .33683 Mdot
.698 .33701 Mdot
.698 .33705 Mdot
.698 .33715 Mdot
.698 .33716 Mdot
.698 .33717 Mdot
.698 .3373 Mdot
.698 .3373 Mdot
.698 .33732 Mdot
.698 .33752 Mdot
.698 .33759 Mdot
.698 .33764 Mdot
.698 .33782 Mdot
.698 .3382 Mdot
.698 .33879 Mdot
.698 .33891 Mdot
.698 .33939 Mdot
.698 .33959 Mdot
.698 .33975 Mdot
.698 .33998 Mdot
.698 .34041 Mdot
.698 .34057 Mdot
.698 .34079 Mdot
.698 .3408 Mdot
.698 .34094 Mdot
.698 .34124 Mdot
.698 .3413 Mdot
.698 .3414 Mdot
.698 .34169 Mdot
.698 .34204 Mdot
.698 .34238 Mdot
.698 .34249 Mdot
.698 .34259 Mdot
.698 .3427 Mdot
.698 .34311 Mdot
.698 .3434 Mdot
.698 .3437 Mdot
.698 .34385 Mdot
.698 .34411 Mdot
.698 .34428 Mdot
.698 .34463 Mdot
.698 .34476 Mdot
.698 .34477 Mdot
.698 .34499 Mdot
.698 .34543 Mdot
.698 .3459 Mdot
.698 .34639 Mdot
.698 .34656 Mdot
.698 .34664 Mdot
.698 .34671 Mdot
.698 .34695 Mdot
.698 .34711 Mdot
.698 .34726 Mdot
.698 .34736 Mdot
.698 .34747 Mdot
.698 .34752 Mdot
.698 .34753 Mdot
.698 .34759 Mdot
.698 .3476 Mdot
.698 .3476 Mdot
.698 .34928 Mdot
.698 .34939 Mdot
.698 .34939 Mdot
.698 .35096 Mdot
.698 .35109 Mdot
.698 .35118 Mdot
.698 .35143 Mdot
.698 .35177 Mdot
.698 .35201 Mdot
.698 .35239 Mdot
.698 .35276 Mdot
.698 .35281 Mdot
.698 .35285 Mdot
.698 .36246 Mdot
.698 .36249 Mdot
.698 .36253 Mdot
.698 .36279 Mdot
.698 .36306 Mdot
.698 .36324 Mdot
.698 .36348 Mdot
.698 .36366 Mdot
.698 .36372 Mdot
.698 .36382 Mdot
.698 .36494 Mdot
.698 .36494 Mdot
.698 .36502 Mdot
.698 .36622 Mdot
.698 .36622 Mdot
.698 .36623 Mdot
.698 .36627 Mdot
.698 .36628 Mdot
.698 .36632 Mdot
.698 .36639 Mdot
.698 .36646 Mdot
.698 .36657 Mdot
.698 .36668 Mdot
.698 .36686 Mdot
.698 .36691 Mdot
.698 .36697 Mdot
.698 .36709 Mdot
.698 .36744 Mdot
.698 .36778 Mdot
.698 .36809 Mdot
.698 .36825 Mdot
.698 .36826 Mdot
.698 .36835 Mdot
.698 .3686 Mdot
.698 .36872 Mdot
.698 .36891 Mdot
.698 .36901 Mdot
.698 .36923 Mdot
.698 .36944 Mdot
.698 .36973 Mdot
.698 .36981 Mdot
.698 .36988 Mdot
.698 .36996 Mdot
.698 .37021 Mdot
.698 .37045 Mdot
.698 .37066 Mdot
.698 .37074 Mdot
.698 .37078 Mdot
.698 .37099 Mdot
.698 .37109 Mdot
.698 .3711 Mdot
.698 .37126 Mdot
.698 .37137 Mdot
.698 .37168 Mdot
.698 .37184 Mdot
.698 .37196 Mdot
.698 .3721 Mdot
.698 .37244 Mdot
.698 .37253 Mdot
.698 .37296 Mdot
.698 .37323 Mdot
.698 .37336 Mdot
.698 .37339 Mdot
.698 .37344 Mdot
.698 .37359 Mdot
.698 .3736 Mdot
.698 .3736 Mdot
.698 .37369 Mdot
.698 .3737 Mdot
.698 .37371 Mdot
.698 .37378 Mdot
.698 .3738 Mdot
.698 .37393 Mdot
.698 .37407 Mdot
.698 .37428 Mdot
.698 .37439 Mdot
.698 .3745 Mdot
.698 .37457 Mdot
.698 .37484 Mdot
.698 .37494 Mdot
.698 .37503 Mdot
.698 .37505 Mdot
.698 .37518 Mdot
.698 .37525 Mdot
.698 .37529 Mdot
.698 .3757 Mdot
.698 .37579 Mdot
.698 .37596 Mdot
.698 .37629 Mdot
.698 .3763 Mdot
.698 .37652 Mdot
.698 .3766 Mdot
.698 .37662 Mdot
.698 .37701 Mdot
.698 .37724 Mdot
.698 .37742 Mdot
.698 .37744 Mdot
.698 .37755 Mdot
.698 .37756 Mdot
.698 .37772 Mdot
.698 .37774 Mdot
.698 .37796 Mdot
.698 .37823 Mdot
.698 .37831 Mdot
.698 .37847 Mdot
.698 .37858 Mdot
.698 .37883 Mdot
.698 .37899 Mdot
.698 .37904 Mdot
.698 .3791 Mdot
.698 .37946 Mdot
.698 .37986 Mdot
.698 .37997 Mdot
.698 .38005 Mdot
.698 .38015 Mdot
.698 .3802 Mdot
.698 .38043 Mdot
.698 .38059 Mdot
.698 .38072 Mdot
.698 .38088 Mdot
.698 .38092 Mdot
.698 .38109 Mdot
.698 .38132 Mdot
.698 .38136 Mdot
.698 .38163 Mdot
.698 .38168 Mdot
.698 .38168 Mdot
.698 .38169 Mdot
.698 .38177 Mdot
.698 .38178 Mdot
.698 .38184 Mdot
.698 .38215 Mdot
.698 .38225 Mdot
.698 .3824 Mdot
.698 .38241 Mdot
.698 .38242 Mdot
.698 .38247 Mdot
.698 .38252 Mdot
.698 .38279 Mdot
.698 .38289 Mdot
.698 .38301 Mdot
.698 .38309 Mdot
.698 .38311 Mdot
.698 .38318 Mdot
.698 .38338 Mdot
.698 .38341 Mdot
.698 .38361 Mdot
.698 .38363 Mdot
.698 .38372 Mdot
.698 .384 Mdot
.698 .38422 Mdot
.698 .38423 Mdot
.698 .38455 Mdot
.698 .38478 Mdot
.698 .38479 Mdot
.698 .38506 Mdot
.698 .38519 Mdot
.698 .38539 Mdot
.698 .38572 Mdot
.698 .38589 Mdot
.698 .38611 Mdot
.698 .38629 Mdot
.698 .38665 Mdot
.698 .38672 Mdot
.698 .3872 Mdot
.698 .38725 Mdot
.698 .38747 Mdot
.698 .38751 Mdot
.698 .38756 Mdot
.698 .38767 Mdot
.698 .38778 Mdot
.698 .38795 Mdot
.698 .38798 Mdot
.698 .38798 Mdot
.698 .38815 Mdot
.698 .38817 Mdot
.698 .38819 Mdot
.698 .38833 Mdot
.698 .38837 Mdot
.698 .38856 Mdot
.698 .38862 Mdot
.698 .38885 Mdot
.698 .38888 Mdot
.698 .38899 Mdot
.698 .38915 Mdot
.698 .38929 Mdot
.698 .3894 Mdot
.698 .38951 Mdot
.698 .38953 Mdot
.698 .38959 Mdot
.698 .38972 Mdot
.698 .38987 Mdot
.698 .38992 Mdot
.698 .39025 Mdot
.698 .39034 Mdot
.698 .39036 Mdot
.698 .3904 Mdot
.698 .39047 Mdot
.698 .39058 Mdot
.698 .39061 Mdot
.698 .39076 Mdot
.698 .39081 Mdot
.698 .39089 Mdot
.698 .39099 Mdot
.698 .39105 Mdot
.698 .39119 Mdot
.698 .39126 Mdot
.698 .39171 Mdot
.698 .39175 Mdot
.698 .39202 Mdot
.698 .39205 Mdot
.698 .39208 Mdot
.698 .39215 Mdot
.698 .39224 Mdot
.698 .39224 Mdot
.698 .39258 Mdot
.698 .3929 Mdot
.698 .39303 Mdot
.698 .39315 Mdot
.698 .39322 Mdot
.698 .39323 Mdot
.698 .39352 Mdot
.698 .39367 Mdot
.698 .39378 Mdot
.698 .39383 Mdot
.698 .39387 Mdot
.698 .39416 Mdot
.698 .39419 Mdot
.698 .3945 Mdot
.698 .39452 Mdot
.698 .39457 Mdot
.698 .39462 Mdot
.698 .39506 Mdot
.698 .39524 Mdot
.698 .39529 Mdot
.698 .39535 Mdot
.698 .39543 Mdot
.698 .39545 Mdot
.698 .39547 Mdot
.698 .39562 Mdot
.698 .39567 Mdot
.698 .3957 Mdot
.698 .39601 Mdot
.698 .39605 Mdot
.698 .39638 Mdot
.698 .39647 Mdot
.698 .39665 Mdot
.698 .3967 Mdot
.698 .39686 Mdot
.698 .397 Mdot
.698 .39715 Mdot
.698 .39746 Mdot
.698 .39753 Mdot
.698 .39769 Mdot
.698 .39814 Mdot
.698 .39817 Mdot
.698 .39848 Mdot
.698 .39857 Mdot
.698 .39858 Mdot
.698 .3986 Mdot
.698 .3987 Mdot
.698 .39886 Mdot
.698 .39892 Mdot
.698 .39902 Mdot
.698 .39911 Mdot
.698 .39939 Mdot
.698 .39974 Mdot
.698 .39979 Mdot
.698 .39988 Mdot
.698 .40018 Mdot
.698 .40039 Mdot
.698 .4005 Mdot
.698 .40054 Mdot
.698 .40061 Mdot
.698 .40066 Mdot
.698 .40074 Mdot
.698 .40083 Mdot
.698 .40085 Mdot
.698 .40089 Mdot
.698 .40092 Mdot
.698 .401 Mdot
.698 .40121 Mdot
.698 .40122 Mdot
.698 .40129 Mdot
.698 .4013 Mdot
.698 .40133 Mdot
.698 .40153 Mdot
.698 .40159 Mdot
.698 .40176 Mdot
.698 .40186 Mdot
.698 .40187 Mdot
.698 .40195 Mdot
.698 .40214 Mdot
.698 .40216 Mdot
.698 .40224 Mdot
.698 .40244 Mdot
.698 .40257 Mdot
.698 .40291 Mdot
.698 .40302 Mdot
.698 .4031 Mdot
.698 .40316 Mdot
.698 .40333 Mdot
.698 .40353 Mdot
.698 .40356 Mdot
.698 .40362 Mdot
.698 .40363 Mdot
.698 .40372 Mdot
.698 .40372 Mdot
.698 .40375 Mdot
.698 .4038 Mdot
.698 .40389 Mdot
.698 .40391 Mdot
.698 .40404 Mdot
.698 .40416 Mdot
.698 .4044 Mdot
.698 .40455 Mdot
.698 .40464 Mdot
.698 .40472 Mdot
.698 .40484 Mdot
.698 .40503 Mdot
.698 .40512 Mdot
.698 .40515 Mdot
.698 .40517 Mdot
.698 .40527 Mdot
.698 .40535 Mdot
.698 .40548 Mdot
.698 .40572 Mdot
.698 .40588 Mdot
.698 .40598 Mdot
.698 .40602 Mdot
.698 .40607 Mdot
.698 .40619 Mdot
.698 .40629 Mdot
.698 .40631 Mdot
.698 .40635 Mdot
.698 .40635 Mdot
.698 .40646 Mdot
.698 .4065 Mdot
.698 .40652 Mdot
.698 .40654 Mdot
.698 .40664 Mdot
.698 .40666 Mdot
.698 .40672 Mdot
.698 .40704 Mdot
.698 .40709 Mdot
.698 .40711 Mdot
.698 .40743 Mdot
.698 .40748 Mdot
.698 .40753 Mdot
.698 .40756 Mdot
.698 .4077 Mdot
.698 .40771 Mdot
.698 .40793 Mdot
.698 .40824 Mdot
.698 .40859 Mdot
.698 .40867 Mdot
.698 .40869 Mdot
.698 .40883 Mdot
.698 .40923 Mdot
.698 .40931 Mdot
.698 .40936 Mdot
.698 .40939 Mdot
.698 .40942 Mdot
.698 .40976 Mdot
.698 .40979 Mdot
.698 .4098 Mdot
.698 .40996 Mdot
.698 .40997 Mdot
.698 .41017 Mdot
.698 .4103 Mdot
.698 .41049 Mdot
.698 .41055 Mdot
.698 .41062 Mdot
.698 .41096 Mdot
.698 .411 Mdot
.698 .41106 Mdot
.698 .41107 Mdot
.698 .41121 Mdot
.698 .41123 Mdot
.698 .4116 Mdot
.698 .41165 Mdot
.698 .4118 Mdot
.698 .41187 Mdot
.698 .41192 Mdot
.698 .41193 Mdot
.698 .41198 Mdot
.698 .41215 Mdot
.698 .41232 Mdot
.698 .41235 Mdot
.698 .41241 Mdot
.698 .41254 Mdot
.698 .41263 Mdot
.698 .4127 Mdot
.698 .41284 Mdot
.698 .41325 Mdot
.698 .4134 Mdot
.698 .41355 Mdot
.698 .41383 Mdot
.698 .41401 Mdot
.698 .41411 Mdot
.698 .41447 Mdot
.698 .41458 Mdot
.698 .41478 Mdot
.698 .41507 Mdot
.698 .41519 Mdot
.698 .41533 Mdot
.698 .41539 Mdot
.698 .4155 Mdot
.698 .41561 Mdot
.698 .4157 Mdot
.698 .41581 Mdot
.698 .41595 Mdot
.698 .416 Mdot
.698 .416 Mdot
.698 .41613 Mdot
.698 .41633 Mdot
.698 .41633 Mdot
.698 .41637 Mdot
.698 .41638 Mdot
.698 .41638 Mdot
.698 .4164 Mdot
.698 .41656 Mdot
.698 .41668 Mdot
.698 .41677 Mdot
.698 .41714 Mdot
.698 .41716 Mdot
.698 .41721 Mdot
.698 .41725 Mdot
.698 .4177 Mdot
.698 .41776 Mdot
.698 .41797 Mdot
.698 .41811 Mdot
.698 .41828 Mdot
.698 .41841 Mdot
.698 .41855 Mdot
.698 .41856 Mdot
.698 .41877 Mdot
.698 .41898 Mdot
.698 .41902 Mdot
.698 .41914 Mdot
.698 .41914 Mdot
.698 .4194 Mdot
.698 .41944 Mdot
.698 .41967 Mdot
.698 .41971 Mdot
.698 .41979 Mdot
.698 .42002 Mdot
.698 .42012 Mdot
.698 .42042 Mdot
.698 .42047 Mdot
.698 .4206 Mdot
.698 .42063 Mdot
.698 .42065 Mdot
.698 .42071 Mdot
.698 .42085 Mdot
.698 .42107 Mdot
.698 .42112 Mdot
.698 .42129 Mdot
.698 .42136 Mdot
.698 .42142 Mdot
.698 .42151 Mdot
.698 .42167 Mdot
.698 .42186 Mdot
.698 .42197 Mdot
.698 .42199 Mdot
.698 .42203 Mdot
.698 .42214 Mdot
.698 .42226 Mdot
.698 .42239 Mdot
.698 .42243 Mdot
.698 .42247 Mdot
.698 .42251 Mdot
.698 .42266 Mdot
.698 .42276 Mdot
.698 .42288 Mdot
.698 .42322 Mdot
.698 .42326 Mdot
.698 .42335 Mdot
.698 .42386 Mdot
.698 .42392 Mdot
.698 .42398 Mdot
.698 .42407 Mdot
.698 .42413 Mdot
.698 .42418 Mdot
.698 .42428 Mdot
.698 .42431 Mdot
.698 .42431 Mdot
.698 .42431 Mdot
.698 .42492 Mdot
.698 .42497 Mdot
.698 .42497 Mdot
.698 .42554 Mdot
.698 .42559 Mdot
.698 .42562 Mdot
.698 .42572 Mdot
.698 .42584 Mdot
.698 .42593 Mdot
.698 .42607 Mdot
.698 .4262 Mdot
.698 .42623 Mdot
.698 .42624 Mdot
.7 .2627 Mdot
.7 .26274 Mdot
.7 .26331 Mdot
.7 .26395 Mdot
.7 .26411 Mdot
.7 .26417 Mdot
.7 .26427 Mdot
.7 .26442 Mdot
.7 .26447 Mdot
.7 .26472 Mdot
.7 .26476 Mdot
.7 .26486 Mdot
.7 .2649 Mdot
.7 .26497 Mdot
.7 .26505 Mdot
.7 .26506 Mdot
.7 .26553 Mdot
.7 .2656 Mdot
.7 .26567 Mdot
.7 .26591 Mdot
.7 .26603 Mdot
.7 .2667 Mdot
.7 .26671 Mdot
.7 .26708 Mdot
.7 .26722 Mdot
.7 .26728 Mdot
.7 .26755 Mdot
.7 .26763 Mdot
.7 .26785 Mdot
.7 .26812 Mdot
.7 .26833 Mdot
.7 .26851 Mdot
.7 .26854 Mdot
.7 .26863 Mdot
.7 .26876 Mdot
.7 .26886 Mdot
.7 .26893 Mdot
.7 .26931 Mdot
.7 .26956 Mdot
.7 .26962 Mdot
.7 .26964 Mdot
.7 .26987 Mdot
.7 .26993 Mdot
.7 .2701 Mdot
.7 .27038 Mdot
.7 .27052 Mdot
.7 .27066 Mdot
.7 .27068 Mdot
.7 .27082 Mdot
.7 .27129 Mdot
.7 .27135 Mdot
.7 .27135 Mdot
.7 .27148 Mdot
.7 .27168 Mdot
.7 .27186 Mdot
.7 .27202 Mdot
.7 .27216 Mdot
.7 .27227 Mdot
.7 .27238 Mdot
.7 .27252 Mdot
.7 .27292 Mdot
.7 .27299 Mdot
.7 .27312 Mdot
.7 .27359 Mdot
.7 .27359 Mdot
.7 .27363 Mdot
.7 .27373 Mdot
.7 .2738 Mdot
.7 .27408 Mdot
.7 .27413 Mdot
.7 .27416 Mdot
.7 .27418 Mdot
.7 .27452 Mdot
.7 .27471 Mdot
.7 .27493 Mdot
.7 .27514 Mdot
.7 .27538 Mdot
.7 .27602 Mdot
.7 .27609 Mdot
.7 .27646 Mdot
.7 .27667 Mdot
.7 .27712 Mdot
.7 .2774 Mdot
.7 .27743 Mdot
.7 .27746 Mdot
.7 .27758 Mdot
.7 .27777 Mdot
.7 .27789 Mdot
.7 .27796 Mdot
.7 .27808 Mdot
.7 .27842 Mdot
.7 .27858 Mdot
.7 .27864 Mdot
.7 .27874 Mdot
.7 .27944 Mdot
.7 .27944 Mdot
.7 .27954 Mdot
.7 .2797 Mdot
.7 .27988 Mdot
.7 .27994 Mdot
.7 .28035 Mdot
.7 .2807 Mdot
.7 .28088 Mdot
.7 .28118 Mdot
.7 .28139 Mdot
.7 .28142 Mdot
.7 .28244 Mdot
.7 .28259 Mdot
.7 .28267 Mdot
.7 .28272 Mdot
.7 .28273 Mdot
.7 .2831 Mdot
.7 .28318 Mdot
.7 .28323 Mdot
.7 .28331 Mdot
.7 .28349 Mdot
.7 .2837 Mdot
.7 .28384 Mdot
.7 .28405 Mdot
.7 .2843 Mdot
.7 .28437 Mdot
.7 .28439 Mdot
.7 .28452 Mdot
.7 .28452 Mdot
.7 .28473 Mdot
.7 .28495 Mdot
.7 .28518 Mdot
.7 .28524 Mdot
.7 .28567 Mdot
.7 .28583 Mdot
.7 .28608 Mdot
.7 .28623 Mdot
.7 .28624 Mdot
.7 .28681 Mdot
.7 .28713 Mdot
.7 .28727 Mdot
.7 .28755 Mdot
.7 .2876 Mdot
.7 .28767 Mdot
.7 .28775 Mdot
.7 .28809 Mdot
.7 .28816 Mdot
.7 .28822 Mdot
.7 .28835 Mdot
.7 .28838 Mdot
.7 .28854 Mdot
.7 .28863 Mdot
.7 .28891 Mdot
.7 .28897 Mdot
.7 .28914 Mdot
.7 .28931 Mdot
.7 .28942 Mdot
.7 .28951 Mdot
.7 .28954 Mdot
.7 .29003 Mdot
.7 .29009 Mdot
.7 .29016 Mdot
.7 .29026 Mdot
.7 .2904 Mdot
.7 .29087 Mdot
.7 .291 Mdot
.7 .29101 Mdot
.7 .29108 Mdot
.7 .29131 Mdot
.7 .29135 Mdot
.7 .29146 Mdot
.7 .29191 Mdot
.7 .29203 Mdot
.7 .29214 Mdot
.7 .29219 Mdot
.7 .2923 Mdot
.7 .29231 Mdot
.7 .29235 Mdot
.7 .29242 Mdot
.7 .29262 Mdot
.7 .29278 Mdot
.7 .29306 Mdot
.7 .29312 Mdot
.7 .29337 Mdot
.7 .29338 Mdot
.7 .29339 Mdot
.7 .29357 Mdot
.7 .29384 Mdot
.7 .29394 Mdot
.7 .29408 Mdot
.7 .29411 Mdot
.7 .29443 Mdot
.7 .29446 Mdot
.7 .29449 Mdot
.7 .29449 Mdot
.7 .29498 Mdot
.7 .29499 Mdot
.7 .29511 Mdot
.7 .29515 Mdot
.7 .29516 Mdot
.7 .29562 Mdot
.7 .29565 Mdot
.7 .29596 Mdot
.7 .29611 Mdot
.7 .29619 Mdot
.7 .29636 Mdot
.7 .29649 Mdot
.7 .29651 Mdot
.7 .29657 Mdot
.7 .29661 Mdot
.7 .29682 Mdot
.7 .29686 Mdot
.7 .29689 Mdot
.7 .29692 Mdot
.7 .29706 Mdot
.7 .29713 Mdot
.7 .29767 Mdot
.7 .29788 Mdot
.7 .29824 Mdot
.7 .29846 Mdot
.7 .29853 Mdot
.7 .29854 Mdot
.7 .29881 Mdot
.7 .29899 Mdot
.7 .29908 Mdot
.7 .29912 Mdot
.7 .29914 Mdot
.7 .29937 Mdot
.7 .2994 Mdot
.7 .30017 Mdot
.7 .30032 Mdot
.7 .30059 Mdot
.7 .3008 Mdot
.7 .30083 Mdot
.7 .30092 Mdot
.7 .30106 Mdot
.7 .30149 Mdot
.7 .30175 Mdot
.7 .30181 Mdot
.7 .302 Mdot
.7 .30206 Mdot
.7 .30224 Mdot
.7 .30246 Mdot
.7 .30276 Mdot
.7 .3028 Mdot
.7 .30312 Mdot
.7 .30325 Mdot
.7 .30356 Mdot
.7 .30373 Mdot
.7 .30375 Mdot
.7 .30379 Mdot
.7 .30397 Mdot
.7 .30428 Mdot
.7 .30434 Mdot
.7 .30438 Mdot
.7 .30459 Mdot
.7 .30471 Mdot
.7 .30484 Mdot
.7 .30512 Mdot
.7 .30521 Mdot
.7 .30545 Mdot
.7 .30552 Mdot
.7 .30568 Mdot
.7 .30582 Mdot
.7 .3059 Mdot
.7 .30605 Mdot
.7 .30609 Mdot
.7 .30641 Mdot
.7 .30645 Mdot
.7 .3065 Mdot
.7 .30661 Mdot
.7 .30672 Mdot
.7 .30683 Mdot
.7 .30736 Mdot
.7 .3079 Mdot
.7 .30808 Mdot
.7 .30815 Mdot
.7 .30844 Mdot
.7 .30847 Mdot
.7 .30849 Mdot
.7 .30854 Mdot
.7 .30856 Mdot
.7 .30869 Mdot
.7 .30872 Mdot
.7 .30879 Mdot
.7 .30928 Mdot
.7 .30958 Mdot
.7 .30959 Mdot
.7 .31044 Mdot
.7 .31052 Mdot
.7 .31055 Mdot
.7 .311 Mdot
.7 .311 Mdot
.7 .31128 Mdot
.7 .31144 Mdot
.7 .31184 Mdot
.7 .31185 Mdot
.7 .3121 Mdot
.7 .31213 Mdot
.7 .31227 Mdot
.7 .31231 Mdot
.7 .31243 Mdot
.7 .31276 Mdot
.7 .31283 Mdot
.7 .31317 Mdot
.7 .31333 Mdot
.7 .31346 Mdot
.7 .31379 Mdot
.7 .31386 Mdot
.7 .31421 Mdot
.7 .31421 Mdot
.7 .31438 Mdot
.7 .31447 Mdot
.7 .31462 Mdot
.7 .31474 Mdot
.7 .31535 Mdot
.7 .31536 Mdot
.7 .31537 Mdot
.7 .31546 Mdot
.7 .31563 Mdot
.7 .31593 Mdot
.7 .31604 Mdot
.7 .31682 Mdot
.7 .3173 Mdot
.7 .31732 Mdot
.7 .31749 Mdot
.7 .31755 Mdot
.7 .31782 Mdot
.7 .31793 Mdot
.7 .31798 Mdot
.7 .31834 Mdot
.7 .31839 Mdot
.7 .31898 Mdot
.7 .31933 Mdot
.7 .31935 Mdot
.7 .31987 Mdot
.7 .31995 Mdot
.7 .32001 Mdot
.7 .32021 Mdot
.7 .32051 Mdot
.7 .32069 Mdot
.7 .32082 Mdot
.7 .32093 Mdot
.7 .32104 Mdot
.7 .32127 Mdot
.7 .3213 Mdot
.7 .3216 Mdot
.7 .3218 Mdot
.7 .32181 Mdot
.7 .3221 Mdot
.7 .32275 Mdot
.7 .32298 Mdot
.7 .32317 Mdot
.7 .32337 Mdot
.7 .32349 Mdot
.7 .32381 Mdot
.7 .32386 Mdot
.7 .32393 Mdot
.7 .32417 Mdot
.7 .32447 Mdot
.7 .3247 Mdot
.7 .32476 Mdot
.7 .32482 Mdot
.7 .32484 Mdot
.7 .32507 Mdot
.7 .32515 Mdot
.7 .32545 Mdot
.7 .32545 Mdot
.7 .32569 Mdot
.7 .32574 Mdot
.7 .32581 Mdot
.7 .32599 Mdot
.7 .32627 Mdot
.7 .32635 Mdot
.7 .32636 Mdot
.7 .32659 Mdot
.7 .32684 Mdot
.7 .32689 Mdot
.7 .32705 Mdot
.7 .32723 Mdot
.7 .32724 Mdot
.7 .32733 Mdot
.7 .32764 Mdot
.7 .32775 Mdot
.7 .32808 Mdot
.7 .32822 Mdot
.7 .32836 Mdot
.7 .32851 Mdot
.7 .32891 Mdot
.7 .32925 Mdot
.7 .32959 Mdot
.7 .32972 Mdot
.7 .32975 Mdot
.7 .33024 Mdot
.7 .33065 Mdot
.7 .33073 Mdot
.7 .33074 Mdot
.7 .33106 Mdot
.7 .33144 Mdot
.7 .33149 Mdot
.7 .33161 Mdot
.7 .33192 Mdot
.7 .33194 Mdot
.7 .3321 Mdot
.7 .33215 Mdot
.7 .3322 Mdot
.7 .33231 Mdot
.7 .33286 Mdot
.7 .33295 Mdot
.7 .33299 Mdot
.7 .33313 Mdot
.7 .33319 Mdot
.7 .3332 Mdot
.7 .33326 Mdot
.7 .33328 Mdot
.7 .33372 Mdot
.7 .3342 Mdot
.7 .33444 Mdot
.7 .33458 Mdot
.7 .33511 Mdot
.7 .33517 Mdot
.7 .33537 Mdot
.7 .33563 Mdot
.7 .33586 Mdot
.7 .33608 Mdot
.7 .33635 Mdot
.7 .33666 Mdot
.7 .33701 Mdot
.7 .33741 Mdot
.7 .33765 Mdot
.7 .33766 Mdot
.7 .33775 Mdot
.7 .33778 Mdot
.7 .33792 Mdot
.7 .33819 Mdot
.7 .3387 Mdot
.7 .33897 Mdot
.7 .33901 Mdot
.7 .33914 Mdot
.7 .33929 Mdot
.7 .33939 Mdot
.7 .33956 Mdot
.7 .33968 Mdot
.7 .3401 Mdot
.7 .34044 Mdot
.7 .34056 Mdot
.7 .341 Mdot
.7 .34104 Mdot
.7 .34116 Mdot
.7 .34146 Mdot
.7 .34149 Mdot
.7 .34166 Mdot
.7 .34181 Mdot
.7 .34209 Mdot
.7 .34223 Mdot
.7 .34228 Mdot
.7 .3424 Mdot
.7 .34252 Mdot
.7 .34255 Mdot
.7 .34263 Mdot
.7 .34273 Mdot
.7 .34277 Mdot
.7 .34299 Mdot
.7 .34316 Mdot
.7 .34323 Mdot
.7 .34358 Mdot
.7 .34375 Mdot
.7 .34393 Mdot
.7 .34399 Mdot
.7 .34451 Mdot
.7 .34451 Mdot
.7 .3449 Mdot
.7 .34496 Mdot
.7 .34511 Mdot
.7 .34512 Mdot
.7 .34564 Mdot
.7 .34573 Mdot
.7 .34576 Mdot
.7 .34603 Mdot
.7 .34674 Mdot
.7 .34677 Mdot
.7 .34809 Mdot
.7 .34818 Mdot
.7 .34831 Mdot
.7 .3488 Mdot
.7 .34892 Mdot
.7 .34907 Mdot
.7 .34998 Mdot
.7 .35 Mdot
.7 .35016 Mdot
.7 .3503 Mdot
.7 .35038 Mdot
.7 .3504 Mdot
.7 .35053 Mdot
.7 .35058 Mdot
.7 .35065 Mdot
.7 .35115 Mdot
.7 .35124 Mdot
.7 .35154 Mdot
.7 .35174 Mdot
.7 .35185 Mdot
.7 .35216 Mdot
.7 .35341 Mdot
.7 .35454 Mdot
.7 .35461 Mdot
.7 .3619 Mdot
.7 .36194 Mdot
.7 .36275 Mdot
.7 .36364 Mdot
.7 .36387 Mdot
.7 .36395 Mdot
.7 .36409 Mdot
.7 .3643 Mdot
.7 .36437 Mdot
.7 .36472 Mdot
.7 .36477 Mdot
.7 .36481 Mdot
.7 .3649 Mdot
.7 .36492 Mdot
.7 .36497 Mdot
.7 .36507 Mdot
.7 .36519 Mdot
.7 .3652 Mdot
.7 .36585 Mdot
.7 .36596 Mdot
.7 .36605 Mdot
.7 .36639 Mdot
.7 .36649 Mdot
.7 .36655 Mdot
.7 .36749 Mdot
.7 .36751 Mdot
.7 .36802 Mdot
.7 .36822 Mdot
.7 .36824 Mdot
.7 .3683 Mdot
.7 .36867 Mdot
.7 .36868 Mdot
.7 .36879 Mdot
.7 .36883 Mdot
.7 .36911 Mdot
.7 .36911 Mdot
.7 .36948 Mdot
.7 .36953 Mdot
.7 .36965 Mdot
.7 .36977 Mdot
.7 .37003 Mdot
.7 .37008 Mdot
.7 .3702 Mdot
.7 .37035 Mdot
.7 .37038 Mdot
.7 .37045 Mdot
.7 .37051 Mdot
.7 .37053 Mdot
.7 .37062 Mdot
.7 .3707 Mdot
.7 .37074 Mdot
.7 .37084 Mdot
.7 .37104 Mdot
.7 .37115 Mdot
.7 .37127 Mdot
.7 .37129 Mdot
.7 .3715 Mdot
.7 .37159 Mdot
.7 .37161 Mdot
.7 .37193 Mdot
.7 .37202 Mdot
.7 .37226 Mdot
.7 .37256 Mdot
.7 .37264 Mdot
.7 .37277 Mdot
.7 .37284 Mdot
.7 .37295 Mdot
.7 .37304 Mdot
.7 .37307 Mdot
.7 .37326 Mdot
.7 .37363 Mdot
.7 .37382 Mdot
.7 .37392 Mdot
.7 .37394 Mdot
.7 .374 Mdot
.7 .37401 Mdot
.7 .37418 Mdot
.7 .37447 Mdot
.7 .37471 Mdot
.7 .37494 Mdot
.7 .37513 Mdot
.7 .37529 Mdot
.7 .37545 Mdot
.7 .37564 Mdot
.7 .37578 Mdot
.7 .37582 Mdot
.7 .3762 Mdot
.7 .3763 Mdot
.7 .37648 Mdot
.7 .37682 Mdot
.7 .37713 Mdot
.7 .37714 Mdot
.7 .37719 Mdot
.7 .3772 Mdot
.7 .37724 Mdot
.7 .37734 Mdot
.7 .37737 Mdot
.7 .37743 Mdot
.7 .37782 Mdot
.7 .3779 Mdot
.7 .37794 Mdot
.7 .37797 Mdot
.7 .37809 Mdot
.7 .37811 Mdot
.7 .37832 Mdot
.7 .37841 Mdot
.7 .37845 Mdot
.7 .37871 Mdot
.7 .37895 Mdot
.7 .37895 Mdot
.7 .37901 Mdot
.7 .3793 Mdot
.7 .37965 Mdot
.7 .37967 Mdot
.7 .37977 Mdot
.7 .38001 Mdot
.7 .38025 Mdot
.7 .38054 Mdot
.7 .38065 Mdot
.7 .38075 Mdot
.7 .38084 Mdot
.7 .38108 Mdot
.7 .38116 Mdot
.7 .38138 Mdot
.7 .38144 Mdot
.7 .38146 Mdot
.7 .38158 Mdot
.7 .3817 Mdot
.7 .38173 Mdot
.7 .38191 Mdot
.7 .38208 Mdot
.7 .38208 Mdot
.7 .38214 Mdot
.7 .38234 Mdot
.7 .38247 Mdot
.7 .38252 Mdot
.7 .38255 Mdot
.7 .38272 Mdot
.7 .38273 Mdot
.7 .38294 Mdot
.7 .383 Mdot
.7 .38316 Mdot
.7 .38318 Mdot
.7 .38322 Mdot
.7 .38326 Mdot
.7 .38342 Mdot
.7 .38364 Mdot
.7 .38381 Mdot
.7 .38386 Mdot
.7 .3839 Mdot
.7 .38412 Mdot
.7 .38421 Mdot
.7 .38435 Mdot
.7 .38449 Mdot
.7 .38465 Mdot
.7 .38512 Mdot
.7 .38532 Mdot
.7 .38533 Mdot
.7 .38548 Mdot
.7 .38569 Mdot
.7 .38571 Mdot
.7 .38588 Mdot
.7 .38595 Mdot
.7 .38603 Mdot
.7 .38612 Mdot
.7 .38625 Mdot
.7 .38647 Mdot
.7 .38661 Mdot
.7 .38666 Mdot
.7 .38671 Mdot
.7 .38708 Mdot
.7 .38709 Mdot
.7 .38734 Mdot
.7 .38777 Mdot
.7 .3878 Mdot
.7 .38806 Mdot
.7 .3881 Mdot
.7 .38818 Mdot
.7 .38837 Mdot
.7 .38841 Mdot
.7 .38853 Mdot
.7 .38855 Mdot
.7 .38889 Mdot
.7 .38945 Mdot
.7 .38953 Mdot
.7 .38974 Mdot
.7 .38986 Mdot
.7 .38992 Mdot
.7 .38993 Mdot
.7 .38994 Mdot
.7 .39037 Mdot
.7 .39046 Mdot
.7 .39057 Mdot
.7 .39063 Mdot
.7 .39075 Mdot
.7 .39075 Mdot
.7 .391 Mdot
.7 .39106 Mdot
.7 .39129 Mdot
.7 .39138 Mdot
.7 .3915 Mdot
.7 .39174 Mdot
.7 .39179 Mdot
.7 .39203 Mdot
.7 .39211 Mdot
.7 .39214 Mdot
.7 .39224 Mdot
.7 .39226 Mdot
.7 .39244 Mdot
.7 .39245 Mdot
.7 .39273 Mdot
.7 .39285 Mdot
.7 .39304 Mdot
.7 .39305 Mdot
.7 .39337 Mdot
.7 .39339 Mdot
.7 .39345 Mdot
.7 .39405 Mdot
.7 .39406 Mdot
.7 .39427 Mdot
.7 .39462 Mdot
.7 .39468 Mdot
.7 .39469 Mdot
.7 .39479 Mdot
.7 .3948 Mdot
.7 .39484 Mdot
.7 .39485 Mdot
.7 .39488 Mdot
.7 .39508 Mdot
.7 .39513 Mdot
.7 .39526 Mdot
.7 .39565 Mdot
.7 .39602 Mdot
.7 .3961 Mdot
.7 .39618 Mdot
.7 .39626 Mdot
.7 .39629 Mdot
.7 .39632 Mdot
.7 .39655 Mdot
.7 .39658 Mdot
.7 .39669 Mdot
.7 .39675 Mdot
.7 .39685 Mdot
.7 .39696 Mdot
.7 .39701 Mdot
.7 .39718 Mdot
.7 .39725 Mdot
.7 .39745 Mdot
.7 .39754 Mdot
.7 .39763 Mdot
.7 .39777 Mdot
.7 .3978 Mdot
.7 .39785 Mdot
.7 .39807 Mdot
.7 .3982 Mdot
.7 .39823 Mdot
.7 .39824 Mdot
.7 .39836 Mdot
.7 .39858 Mdot
.7 .39867 Mdot
.7 .3989 Mdot
.7 .39893 Mdot
.7 .39914 Mdot
.7 .3993 Mdot
.7 .39943 Mdot
.7 .39947 Mdot
.7 .39961 Mdot
.7 .39965 Mdot
.7 .39984 Mdot
.7 .40015 Mdot
.7 .40024 Mdot
.7 .40031 Mdot
.7 .40033 Mdot
.7 .40048 Mdot
.7 .40067 Mdot
.7 .40078 Mdot
.7 .40133 Mdot
.7 .40135 Mdot
.7 .40151 Mdot
.7 .40153 Mdot
.7 .40156 Mdot
.7 .40163 Mdot
.7 .40176 Mdot
.7 .40195 Mdot
.7 .40195 Mdot
.7 .402 Mdot
.7 .40216 Mdot
.7 .40242 Mdot
.7 .40257 Mdot
.7 .40278 Mdot
.7 .40295 Mdot
.7 .403 Mdot
.7 .40311 Mdot
.7 .40312 Mdot
.7 .40315 Mdot
.7 .40318 Mdot
.7 .40333 Mdot
.7 .40335 Mdot
.7 .4034 Mdot
.7 .40341 Mdot
.7 .4035 Mdot
.7 .40362 Mdot
.7 .40368 Mdot
.7 .40379 Mdot
.7 .40401 Mdot
.7 .40403 Mdot
.7 .40436 Mdot
.7 .40437 Mdot
.7 .40439 Mdot
.7 .40448 Mdot
.7 .40449 Mdot
.7 .40484 Mdot
.7 .40484 Mdot
.7 .40486 Mdot
.7 .40488 Mdot
.7 .40511 Mdot
.7 .40513 Mdot
.7 .40523 Mdot
.7 .4053 Mdot
.7 .4055 Mdot
.7 .40563 Mdot
.7 .40563 Mdot
.7 .40564 Mdot
.7 .40582 Mdot
.7 .40586 Mdot
.7 .40606 Mdot
.7 .40617 Mdot
.7 .40632 Mdot
.7 .40636 Mdot
.7 .40639 Mdot
.7 .40641 Mdot
.7 .40648 Mdot
.7 .40652 Mdot
.7 .4066 Mdot
.7 .40668 Mdot
.7 .407 Mdot
.7 .40708 Mdot
.7 .40711 Mdot
.7 .40727 Mdot
.7 .40732 Mdot
.7 .40733 Mdot
.7 .40743 Mdot
.7 .40776 Mdot
.7 .40786 Mdot
.7 .40793 Mdot
.7 .40798 Mdot
.7 .40803 Mdot
.7 .40837 Mdot
.7 .4084 Mdot
.7 .40846 Mdot
.7 .40854 Mdot
.7 .40866 Mdot
.7 .40878 Mdot
.7 .40883 Mdot
.7 .40902 Mdot
.7 .40909 Mdot
.7 .4092 Mdot
.7 .40923 Mdot
.7 .40931 Mdot
.7 .40936 Mdot
.7 .40941 Mdot
.7 .40966 Mdot
.7 .40971 Mdot
.7 .40976 Mdot
.7 .4098 Mdot
.7 .41 Mdot
.7 .41009 Mdot
.7 .41033 Mdot
.7 .41073 Mdot
.7 .41074 Mdot
.7 .41085 Mdot
.7 .41103 Mdot
.7 .41114 Mdot
.7 .41145 Mdot
.7 .41149 Mdot
.7 .41165 Mdot
.7 .41181 Mdot
.7 .41196 Mdot
.7 .41196 Mdot
.7 .41205 Mdot
.7 .41207 Mdot
.7 .41212 Mdot
.7 .41229 Mdot
.7 .41244 Mdot
.7 .41255 Mdot
.7 .41269 Mdot
.7 .41282 Mdot
.7 .41288 Mdot
.7 .41292 Mdot
.7 .41297 Mdot
.7 .41324 Mdot
.7 .41325 Mdot
.7 .41328 Mdot
.7 .41334 Mdot
.7 .41345 Mdot
.7 .41418 Mdot
.7 .4142 Mdot
.7 .41435 Mdot
.7 .41456 Mdot
.7 .41469 Mdot
.7 .41494 Mdot
.7 .41523 Mdot
.7 .41527 Mdot
.7 .4154 Mdot
.7 .41551 Mdot
.7 .41559 Mdot
.7 .41559 Mdot
.7 .41609 Mdot
.7 .41616 Mdot
.7 .41621 Mdot
.7 .41632 Mdot
.7 .41656 Mdot
.7 .41664 Mdot
.7 .4167 Mdot
.7 .41678 Mdot
.7 .41692 Mdot
.7 .417 Mdot
.7 .41702 Mdot
.7 .41705 Mdot
.7 .41725 Mdot
.7 .41756 Mdot
.7 .41772 Mdot
.7 .41798 Mdot
.7 .41803 Mdot
.7 .41849 Mdot
.7 .41866 Mdot
.7 .41881 Mdot
.7 .41896 Mdot
.7 .4191 Mdot
.7 .41934 Mdot
.7 .41936 Mdot
.7 .41938 Mdot
.7 .41942 Mdot
.7 .41962 Mdot
.7 .41967 Mdot
.7 .41974 Mdot
.7 .41977 Mdot
.7 .41977 Mdot
.7 .42011 Mdot
.7 .4202 Mdot
.7 .42025 Mdot
.7 .42053 Mdot
.7 .42063 Mdot
.7 .42071 Mdot
.7 .42079 Mdot
.7 .42089 Mdot
.7 .421 Mdot
.7 .42113 Mdot
.7 .42128 Mdot
.7 .42137 Mdot
.7 .42137 Mdot
.7 .42141 Mdot
.7 .42175 Mdot
.7 .42184 Mdot
.7 .42186 Mdot
.7 .42196 Mdot
.7 .42206 Mdot
.7 .42226 Mdot
.7 .42238 Mdot
.7 .42242 Mdot
.7 .42259 Mdot
.7 .4226 Mdot
.7 .42264 Mdot
.7 .42283 Mdot
.7 .42309 Mdot
.7 .42315 Mdot
.7 .42322 Mdot
.7 .42331 Mdot
.7 .42337 Mdot
.7 .4234 Mdot
.7 .42353 Mdot
.7 .42368 Mdot
.7 .42386 Mdot
.7 .42403 Mdot
.7 .42408 Mdot
.7 .42428 Mdot
.7 .42432 Mdot
.7 .42442 Mdot
.7 .42468 Mdot
.7 .42469 Mdot
.7 .42517 Mdot
.7 .42525 Mdot
.7 .42543 Mdot
.7 .42547 Mdot
.7 .42553 Mdot
.7 .42586 Mdot
.7 .42586 Mdot
.7 .42592 Mdot
.7 .42598 Mdot
.7 .426 Mdot
.7 .42608 Mdot
.7 .4261 Mdot
.7 .42628 Mdot
.7 .42632 Mdot
.7 .42643 Mdot
.7 .4265 Mdot
.7 .42654 Mdot
.7 .42665 Mdot
.7 .42711 Mdot
.7 .42752 Mdot
.7 .42754 Mdot
.702 .26168 Mdot
.702 .26203 Mdot
.702 .26205 Mdot
.702 .2621 Mdot
.702 .26226 Mdot
.702 .26252 Mdot
.702 .26262 Mdot
.702 .26264 Mdot
.702 .26267 Mdot
.702 .26279 Mdot
.702 .26281 Mdot
.702 .26293 Mdot
.702 .26351 Mdot
.702 .2637 Mdot
.702 .26382 Mdot
.702 .26389 Mdot
.702 .26401 Mdot
.702 .26421 Mdot
.702 .2643 Mdot
.702 .26432 Mdot
.702 .26454 Mdot
.702 .26466 Mdot
.702 .26471 Mdot
.702 .26507 Mdot
.702 .26508 Mdot
.702 .2651 Mdot
.702 .26536 Mdot
.702 .26551 Mdot
.702 .2657 Mdot
.702 .26585 Mdot
.702 .26587 Mdot
.702 .26667 Mdot
.702 .2671 Mdot
.702 .26791 Mdot
.702 .26801 Mdot
.702 .26823 Mdot
.702 .26831 Mdot
.702 .26841 Mdot
.702 .26846 Mdot
.702 .26854 Mdot
.702 .26855 Mdot
.702 .26883 Mdot
.702 .26917 Mdot
.702 .26919 Mdot
.702 .26945 Mdot
.702 .26965 Mdot
.702 .26979 Mdot
.702 .2698 Mdot
.702 .26986 Mdot
.702 .2699 Mdot
.702 .2702 Mdot
.702 .27059 Mdot
.702 .27062 Mdot
.702 .27103 Mdot
.702 .27146 Mdot
.702 .27198 Mdot
.702 .27242 Mdot
.702 .27259 Mdot
.702 .27263 Mdot
.702 .27282 Mdot
.702 .2732 Mdot
.702 .27371 Mdot
.702 .27383 Mdot
.702 .27496 Mdot
.702 .27505 Mdot
.702 .27574 Mdot
.702 .27575 Mdot
.702 .27581 Mdot
.702 .27585 Mdot
.702 .276 Mdot
.702 .27602 Mdot
.702 .27671 Mdot
.702 .27678 Mdot
.702 .2769 Mdot
.702 .27692 Mdot
.702 .27696 Mdot
.702 .27707 Mdot
.702 .27734 Mdot
.702 .27746 Mdot
.702 .27792 Mdot
.702 .27812 Mdot
.702 .27816 Mdot
.702 .27857 Mdot
.702 .27888 Mdot
.702 .27896 Mdot
.702 .27908 Mdot
.702 .27924 Mdot
.702 .27925 Mdot
.702 .27934 Mdot
.702 .27935 Mdot
.702 .27961 Mdot
.702 .27963 Mdot
.702 .27971 Mdot
.702 .27979 Mdot
.702 .2802 Mdot
.702 .28027 Mdot
.702 .28034 Mdot
.702 .28036 Mdot
.702 .28062 Mdot
.702 .28072 Mdot
.702 .281 Mdot
.702 .28128 Mdot
.702 .28132 Mdot
.702 .28211 Mdot
.702 .28283 Mdot
.702 .28294 Mdot
.702 .28312 Mdot
.702 .28313 Mdot
.702 .28315 Mdot
.702 .28324 Mdot
.702 .28331 Mdot
.702 .28347 Mdot
.702 .28347 Mdot
.702 .28351 Mdot
.702 .28353 Mdot
.702 .28355 Mdot
.702 .28384 Mdot
.702 .28396 Mdot
.702 .28417 Mdot
.702 .28425 Mdot
.702 .28436 Mdot
.702 .28437 Mdot
.702 .2845 Mdot
.702 .28456 Mdot
.702 .28456 Mdot
.702 .28459 Mdot
.702 .28467 Mdot
.702 .28492 Mdot
.702 .28495 Mdot
.702 .28498 Mdot
.702 .28513 Mdot
.702 .28524 Mdot
.702 .2854 Mdot
.702 .28545 Mdot
.702 .28552 Mdot
.702 .28555 Mdot
.702 .28559 Mdot
.702 .28582 Mdot
.702 .28607 Mdot
.702 .28625 Mdot
.702 .28634 Mdot
.702 .28638 Mdot
.702 .28736 Mdot
.702 .28739 Mdot
.702 .2876 Mdot
.702 .28782 Mdot
.702 .28796 Mdot
.702 .28812 Mdot
.702 .28827 Mdot
.702 .28872 Mdot
.702 .28899 Mdot
.702 .28899 Mdot
.702 .28917 Mdot
.702 .28919 Mdot
.702 .28923 Mdot
.702 .28933 Mdot
.702 .28965 Mdot
.702 .28975 Mdot
.702 .28982 Mdot
.702 .28985 Mdot
.702 .28995 Mdot
.702 .29009 Mdot
.702 .29011 Mdot
.702 .29011 Mdot
.702 .29082 Mdot
.702 .29083 Mdot
.702 .29085 Mdot
.702 .29087 Mdot
.702 .29101 Mdot
.702 .29142 Mdot
.702 .29191 Mdot
.702 .29215 Mdot
.702 .29233 Mdot
.702 .29238 Mdot
.702 .2925 Mdot
.702 .29256 Mdot
.702 .29262 Mdot
.702 .29281 Mdot
.702 .29315 Mdot
.702 .2934 Mdot
.702 .29367 Mdot
.702 .29384 Mdot
.702 .29399 Mdot
.702 .29408 Mdot
.702 .29417 Mdot
.702 .29454 Mdot
.702 .29475 Mdot
.702 .29482 Mdot
.702 .29483 Mdot
.702 .29484 Mdot
.702 .29521 Mdot
.702 .29534 Mdot
.702 .29539 Mdot
.702 .29544 Mdot
.702 .29566 Mdot
.702 .29568 Mdot
.702 .29577 Mdot
.702 .29578 Mdot
.702 .29591 Mdot
.702 .29614 Mdot
.702 .29622 Mdot
.702 .29659 Mdot
.702 .29661 Mdot
.702 .29717 Mdot
.702 .29752 Mdot
.702 .29754 Mdot
.702 .29757 Mdot
.702 .2976 Mdot
.702 .29818 Mdot
.702 .29833 Mdot
.702 .29839 Mdot
.702 .29854 Mdot
.702 .29857 Mdot
.702 .29866 Mdot
.702 .29869 Mdot
.702 .29875 Mdot
.702 .29875 Mdot
.702 .29885 Mdot
.702 .29967 Mdot
.702 .30015 Mdot
.702 .30016 Mdot
.702 .3002 Mdot
.702 .30048 Mdot
.702 .30054 Mdot
.702 .30067 Mdot
.702 .30072 Mdot
.702 .30086 Mdot
.702 .30106 Mdot
.702 .30129 Mdot
.702 .30163 Mdot
.702 .30169 Mdot
.702 .30188 Mdot
.702 .3019 Mdot
.702 .30197 Mdot
.702 .30201 Mdot
.702 .30236 Mdot
.702 .30237 Mdot
.702 .30246 Mdot
.702 .3025 Mdot
.702 .30289 Mdot
.702 .30353 Mdot
.702 .30379 Mdot
.702 .30408 Mdot
.702 .30441 Mdot
.702 .30467 Mdot
.702 .30511 Mdot
.702 .30531 Mdot
.702 .30552 Mdot
.702 .30559 Mdot
.702 .30582 Mdot
.702 .306 Mdot
.702 .30647 Mdot
.702 .30751 Mdot
.702 .30759 Mdot
.702 .30776 Mdot
.702 .3081 Mdot
.702 .30812 Mdot
.702 .30845 Mdot
.702 .30861 Mdot
.702 .30907 Mdot
.702 .30914 Mdot
.702 .30915 Mdot
.702 .3092 Mdot
.702 .30934 Mdot
.702 .30944 Mdot
.702 .30976 Mdot
.702 .30994 Mdot
.702 .30997 Mdot
.702 .31026 Mdot
.702 .31033 Mdot
.702 .31039 Mdot
.702 .31069 Mdot
.702 .31085 Mdot
.702 .31088 Mdot
.702 .31105 Mdot
.702 .31109 Mdot
.702 .3111 Mdot
.702 .31121 Mdot
.702 .31148 Mdot
.702 .31148 Mdot
.702 .3115 Mdot
.702 .31171 Mdot
.702 .31188 Mdot
.702 .31229 Mdot
.702 .31251 Mdot
.702 .31297 Mdot
.702 .31309 Mdot
.702 .31312 Mdot
.702 .31318 Mdot
.702 .3132 Mdot
.702 .31324 Mdot
.702 .31325 Mdot
.702 .31356 Mdot
.702 .3137 Mdot
.702 .31388 Mdot
.702 .31391 Mdot
.702 .31393 Mdot
.702 .3143 Mdot
.702 .3145 Mdot
.702 .31521 Mdot
.702 .31529 Mdot
.702 .31541 Mdot
.702 .31593 Mdot
.702 .31654 Mdot
.702 .3169 Mdot
.702 .31695 Mdot
.702 .31748 Mdot
.702 .31757 Mdot
.702 .318 Mdot
.702 .31812 Mdot
.702 .31849 Mdot
.702 .31859 Mdot
.702 .31868 Mdot
.702 .31873 Mdot
.702 .31887 Mdot
.702 .31895 Mdot
.702 .31915 Mdot
.702 .31937 Mdot
.702 .31942 Mdot
.702 .31956 Mdot
.702 .3197 Mdot
.702 .32013 Mdot
.702 .32049 Mdot
.702 .32065 Mdot
.702 .32082 Mdot
.702 .32083 Mdot
.702 .32086 Mdot
.702 .32117 Mdot
.702 .32127 Mdot
.702 .32127 Mdot
.702 .32134 Mdot
.702 .32137 Mdot
.702 .32137 Mdot
.702 .32138 Mdot
.702 .32143 Mdot
.702 .32155 Mdot
.702 .32157 Mdot
.702 .32158 Mdot
.702 .32166 Mdot
.702 .32171 Mdot
.702 .32189 Mdot
.702 .32214 Mdot
.702 .32227 Mdot
.702 .32229 Mdot
.702 .32291 Mdot
.702 .32302 Mdot
.702 .32309 Mdot
.702 .32372 Mdot
.702 .32379 Mdot
.702 .32404 Mdot
.702 .3241 Mdot
.702 .32417 Mdot
.702 .32419 Mdot
.702 .32455 Mdot
.702 .3251 Mdot
.702 .32534 Mdot
.702 .32543 Mdot
.702 .32546 Mdot
.702 .32586 Mdot
.702 .32608 Mdot
.702 .32615 Mdot
.702 .3262 Mdot
.702 .32643 Mdot
.702 .32654 Mdot
.702 .32657 Mdot
.702 .32658 Mdot
.702 .32686 Mdot
.702 .327 Mdot
.702 .32706 Mdot
.702 .32713 Mdot
.702 .32728 Mdot
.702 .32747 Mdot
.702 .32776 Mdot
.702 .32794 Mdot
.702 .32795 Mdot
.702 .32798 Mdot
.702 .32828 Mdot
.702 .32835 Mdot
.702 .32846 Mdot
.702 .32848 Mdot
.702 .32862 Mdot
.702 .32903 Mdot
.702 .32947 Mdot
.702 .32986 Mdot
.702 .33003 Mdot
.702 .33015 Mdot
.702 .33045 Mdot
.702 .33047 Mdot
.702 .33099 Mdot
.702 .3319 Mdot
.702 .33215 Mdot
.702 .33225 Mdot
.702 .33249 Mdot
.702 .33331 Mdot
.702 .33349 Mdot
.702 .33385 Mdot
.702 .33424 Mdot
.702 .33463 Mdot
.702 .3347 Mdot
.702 .33503 Mdot
.702 .33578 Mdot
.702 .3359 Mdot
.702 .33692 Mdot
.702 .33696 Mdot
.702 .33702 Mdot
.702 .33759 Mdot
.702 .33778 Mdot
.702 .3378 Mdot
.702 .33833 Mdot
.702 .33858 Mdot
.702 .33863 Mdot
.702 .3387 Mdot
.702 .33882 Mdot
.702 .33892 Mdot
.702 .33941 Mdot
.702 .33977 Mdot
.702 .33994 Mdot
.702 .33999 Mdot
.702 .33999 Mdot
.702 .34003 Mdot
.702 .34004 Mdot
.702 .34007 Mdot
.702 .34013 Mdot
.702 .34019 Mdot
.702 .34022 Mdot
.702 .3405 Mdot
.702 .34088 Mdot
.702 .34092 Mdot
.702 .3414 Mdot
.702 .34143 Mdot
.702 .34147 Mdot
.702 .34165 Mdot
.702 .3421 Mdot
.702 .34212 Mdot
.702 .34267 Mdot
.702 .34268 Mdot
.702 .34283 Mdot
.702 .3429 Mdot
.702 .34293 Mdot
.702 .34296 Mdot
.702 .34304 Mdot
.702 .34314 Mdot
.702 .34329 Mdot
.702 .34338 Mdot
.702 .34372 Mdot
.702 .34393 Mdot
.702 .34415 Mdot
.702 .34419 Mdot
.702 .3445 Mdot
.702 .34465 Mdot
.702 .34466 Mdot
.702 .34492 Mdot
.702 .34538 Mdot
.702 .34551 Mdot
.702 .3461 Mdot
.702 .34637 Mdot
.702 .34735 Mdot
.702 .34795 Mdot
.702 .34798 Mdot
.702 .34827 Mdot
.702 .34838 Mdot
.702 .34865 Mdot
.702 .34884 Mdot
.702 .34889 Mdot
.702 .34895 Mdot
.702 .34938 Mdot
.702 .34946 Mdot
.702 .34949 Mdot
.702 .34951 Mdot
.702 .34952 Mdot
.702 .34956 Mdot
.702 .34996 Mdot
.702 .35024 Mdot
.702 .35033 Mdot
.702 .35057 Mdot
.702 .35096 Mdot
.702 .351 Mdot
.702 .35104 Mdot
.702 .35121 Mdot
.702 .3516 Mdot
.702 .35162 Mdot
.702 .35178 Mdot
.702 .35185 Mdot
.702 .35186 Mdot
.702 .35199 Mdot
.702 .35222 Mdot
.702 .35259 Mdot
.702 .35322 Mdot
.702 .35374 Mdot
.702 .35398 Mdot
.702 .35401 Mdot
.702 .35425 Mdot
.702 .35431 Mdot
.702 .35434 Mdot
.702 .35455 Mdot
.702 .35506 Mdot
.702 .35538 Mdot
.702 .35547 Mdot
.702 .35551 Mdot
.702 .3562 Mdot
.702 .36145 Mdot
.702 .36195 Mdot
.702 .36198 Mdot
.702 .36204 Mdot
.702 .36227 Mdot
.702 .36263 Mdot
.702 .36278 Mdot
.702 .3628 Mdot
.702 .36284 Mdot
.702 .36302 Mdot
.702 .36304 Mdot
.702 .3632 Mdot
.702 .36357 Mdot
.702 .36403 Mdot
.702 .36429 Mdot
.702 .36445 Mdot
.702 .36455 Mdot
.702 .36455 Mdot
.702 .36461 Mdot
.702 .36472 Mdot
.702 .36473 Mdot
.702 .36501 Mdot
.702 .36513 Mdot
.702 .36516 Mdot
.702 .36518 Mdot
.702 .36547 Mdot
.702 .36563 Mdot
.702 .3657 Mdot
.702 .3659 Mdot
.702 .36618 Mdot
.702 .36622 Mdot
.702 .36622 Mdot
.702 .36623 Mdot
.702 .36625 Mdot
.702 .36631 Mdot
.702 .36662 Mdot
.702 .36666 Mdot
.702 .3667 Mdot
.702 .36683 Mdot
.702 .36703 Mdot
.702 .3671 Mdot
.702 .36731 Mdot
.702 .36733 Mdot
.702 .36775 Mdot
.702 .36846 Mdot
.702 .36865 Mdot
.702 .36907 Mdot
.702 .36916 Mdot
.702 .36949 Mdot
.702 .36968 Mdot
.702 .36968 Mdot
.702 .36979 Mdot
.702 .37001 Mdot
.702 .37003 Mdot
.702 .37019 Mdot
.702 .37034 Mdot
.702 .37058 Mdot
.702 .37065 Mdot
.702 .37076 Mdot
.702 .37083 Mdot
.702 .37088 Mdot
.702 .37091 Mdot
.702 .37093 Mdot
.702 .37098 Mdot
.702 .37108 Mdot
.702 .3711 Mdot
.702 .37149 Mdot
.702 .3715 Mdot
.702 .37182 Mdot
.702 .37195 Mdot
.702 .37198 Mdot
.702 .372 Mdot
.702 .37234 Mdot
.702 .37237 Mdot
.702 .37264 Mdot
.702 .37284 Mdot
.702 .37286 Mdot
.702 .3729 Mdot
.702 .37294 Mdot
.702 .37296 Mdot
.702 .37297 Mdot
.702 .373 Mdot
.702 .373 Mdot
.702 .37304 Mdot
.702 .37316 Mdot
.702 .37341 Mdot
.702 .37376 Mdot
.702 .37384 Mdot
.702 .37392 Mdot
.702 .37397 Mdot
.702 .374 Mdot
.702 .37418 Mdot
.702 .37456 Mdot
.702 .37458 Mdot
.702 .37471 Mdot
.702 .37512 Mdot
.702 .37516 Mdot
.702 .37519 Mdot
.702 .37591 Mdot
.702 .376 Mdot
.702 .37653 Mdot
.702 .37677 Mdot
.702 .37682 Mdot
.702 .37709 Mdot
.702 .37738 Mdot
.702 .37763 Mdot
.702 .37776 Mdot
.702 .37835 Mdot
.702 .37852 Mdot
.702 .37858 Mdot
.702 .37877 Mdot
.702 .37941 Mdot
.702 .37978 Mdot
.702 .37979 Mdot
.702 .38001 Mdot
.702 .3801 Mdot
.702 .38022 Mdot
.702 .38045 Mdot
.702 .38049 Mdot
.702 .3808 Mdot
.702 .3811 Mdot
.702 .3812 Mdot
.702 .38121 Mdot
.702 .38129 Mdot
.702 .38134 Mdot
.702 .38155 Mdot
.702 .38157 Mdot
.702 .38158 Mdot
.702 .38171 Mdot
.702 .38192 Mdot
.702 .38205 Mdot
.702 .38216 Mdot
.702 .38221 Mdot
.702 .38225 Mdot
.702 .38235 Mdot
.702 .38255 Mdot
.702 .38256 Mdot
.702 .38258 Mdot
.702 .38266 Mdot
.702 .38282 Mdot
.702 .38285 Mdot
.702 .38291 Mdot
.702 .38307 Mdot
.702 .38335 Mdot
.702 .38337 Mdot
.702 .38344 Mdot
.702 .38361 Mdot
.702 .384 Mdot
.702 .38426 Mdot
.702 .38427 Mdot
.702 .38432 Mdot
.702 .38436 Mdot
.702 .38454 Mdot
.702 .38459 Mdot
.702 .38504 Mdot
.702 .38508 Mdot
.702 .38517 Mdot
.702 .3856 Mdot
.702 .38562 Mdot
.702 .38572 Mdot
.702 .38589 Mdot
.702 .38602 Mdot
.702 .38606 Mdot
.702 .38611 Mdot
.702 .38612 Mdot
.702 .38613 Mdot
.702 .38622 Mdot
.702 .38625 Mdot
.702 .38626 Mdot
.702 .38626 Mdot
.702 .38628 Mdot
.702 .38633 Mdot
.702 .38633 Mdot
.702 .38641 Mdot
.702 .38663 Mdot
.702 .38664 Mdot
.702 .38666 Mdot
.702 .38677 Mdot
.702 .38689 Mdot
.702 .38715 Mdot
.702 .38745 Mdot
.702 .38755 Mdot
.702 .38765 Mdot
.702 .38769 Mdot
.702 .38784 Mdot
.702 .38799 Mdot
.702 .38804 Mdot
.702 .38815 Mdot
.702 .38818 Mdot
.702 .38824 Mdot
.702 .38832 Mdot
.702 .38858 Mdot
.702 .38866 Mdot
.702 .38897 Mdot
.702 .38903 Mdot
.702 .38941 Mdot
.702 .38945 Mdot
.702 .3897 Mdot
.702 .39014 Mdot
.702 .39051 Mdot
.702 .39059 Mdot
.702 .39065 Mdot
.702 .39115 Mdot
.702 .3913 Mdot
.702 .39156 Mdot
.702 .39157 Mdot
.702 .3916 Mdot
.702 .39172 Mdot
.702 .39182 Mdot
.702 .39205 Mdot
.702 .39205 Mdot
.702 .39208 Mdot
.702 .3921 Mdot
.702 .39214 Mdot
.702 .39216 Mdot
.702 .39224 Mdot
.702 .39257 Mdot
.702 .39273 Mdot
.702 .39302 Mdot
.702 .39315 Mdot
.702 .3933 Mdot
.702 .3933 Mdot
.702 .3933 Mdot
.702 .3935 Mdot
.702 .39358 Mdot
.702 .39358 Mdot
.702 .39362 Mdot
.702 .39373 Mdot
.702 .39376 Mdot
.702 .39387 Mdot
.702 .39408 Mdot
.702 .39412 Mdot
.702 .39417 Mdot
.702 .39438 Mdot
.702 .3944 Mdot
.702 .39453 Mdot
.702 .39476 Mdot
.702 .39483 Mdot
.702 .39493 Mdot
.702 .39496 Mdot
.702 .39497 Mdot
.702 .39503 Mdot
.702 .39535 Mdot
.702 .39546 Mdot
.702 .3957 Mdot
.702 .39572 Mdot
.702 .39595 Mdot
.702 .39608 Mdot
.702 .39614 Mdot
.702 .39687 Mdot
.702 .39721 Mdot
.702 .39734 Mdot
.702 .3975 Mdot
.702 .39755 Mdot
.702 .3977 Mdot
.702 .39784 Mdot
.702 .39816 Mdot
.702 .39835 Mdot
.702 .39858 Mdot
.702 .39879 Mdot
.702 .39897 Mdot
.702 .39942 Mdot
.702 .39971 Mdot
.702 .39973 Mdot
.702 .3998 Mdot
.702 .3998 Mdot
.702 .40005 Mdot
.702 .40008 Mdot
.702 .40013 Mdot
.702 .40015 Mdot
.702 .40028 Mdot
.702 .40032 Mdot
.702 .40056 Mdot
.702 .40073 Mdot
.702 .40087 Mdot
.702 .40097 Mdot
.702 .40101 Mdot
.702 .4011 Mdot
.702 .40114 Mdot
.702 .40134 Mdot
.702 .40137 Mdot
.702 .40138 Mdot
.702 .40172 Mdot
.702 .40231 Mdot
.702 .40237 Mdot
.702 .40238 Mdot
.702 .40241 Mdot
.702 .40244 Mdot
.702 .4025 Mdot
.702 .40252 Mdot
.702 .40263 Mdot
.702 .40267 Mdot
.702 .40278 Mdot
.702 .40319 Mdot
.702 .40321 Mdot
.702 .40324 Mdot
.702 .40325 Mdot
.702 .4035 Mdot
.702 .4039 Mdot
.702 .40391 Mdot
.702 .40418 Mdot
.702 .40423 Mdot
.702 .40439 Mdot
.702 .40449 Mdot
.702 .40449 Mdot
.702 .40456 Mdot
.702 .40458 Mdot
.702 .40473 Mdot
.702 .40477 Mdot
.702 .4048 Mdot
.702 .4049 Mdot
.702 .40516 Mdot
.702 .40516 Mdot
.702 .40517 Mdot
.702 .40522 Mdot
.702 .40537 Mdot
.702 .40563 Mdot
.702 .4057 Mdot
.702 .40576 Mdot
.702 .40587 Mdot
.702 .40599 Mdot
.702 .40618 Mdot
.702 .40636 Mdot
.702 .40661 Mdot
.702 .40674 Mdot
.702 .40679 Mdot
.702 .40682 Mdot
.702 .40691 Mdot
.702 .40694 Mdot
.702 .40708 Mdot
.702 .40724 Mdot
.702 .40759 Mdot
.702 .40789 Mdot
.702 .40798 Mdot
.702 .408 Mdot
.702 .40802 Mdot
.702 .40802 Mdot
.702 .40852 Mdot
.702 .40853 Mdot
.702 .40854 Mdot
.702 .40864 Mdot
.702 .40871 Mdot
.702 .40873 Mdot
.702 .40878 Mdot
.702 .40885 Mdot
.702 .40908 Mdot
.702 .40916 Mdot
.702 .40918 Mdot
.702 .4092 Mdot
.702 .40932 Mdot
.702 .40933 Mdot
.702 .40952 Mdot
.702 .40984 Mdot
.702 .40994 Mdot
.702 .41006 Mdot
.702 .41016 Mdot
.702 .41032 Mdot
.702 .41046 Mdot
.702 .41049 Mdot
.702 .41118 Mdot
.702 .41121 Mdot
.702 .41127 Mdot
.702 .4114 Mdot
.702 .41158 Mdot
.702 .41175 Mdot
.702 .41177 Mdot
.702 .4118 Mdot
.702 .41184 Mdot
.702 .41188 Mdot
.702 .412 Mdot
.702 .41207 Mdot
.702 .41218 Mdot
.702 .4122 Mdot
.702 .41223 Mdot
.702 .4124 Mdot
.702 .41246 Mdot
.702 .41248 Mdot
.702 .41248 Mdot
.702 .41252 Mdot
.702 .41262 Mdot
.702 .41262 Mdot
.702 .4127 Mdot
.702 .41276 Mdot
.702 .41291 Mdot
.702 .41299 Mdot
.702 .4132 Mdot
.702 .41321 Mdot
.702 .41323 Mdot
.702 .41325 Mdot
.702 .41326 Mdot
.702 .41337 Mdot
.702 .41342 Mdot
.702 .41349 Mdot
.702 .4135 Mdot
.702 .4135 Mdot
.702 .41364 Mdot
.702 .41371 Mdot
.702 .41422 Mdot
.702 .41479 Mdot
.702 .41482 Mdot
.702 .41502 Mdot
.702 .41522 Mdot
.702 .41529 Mdot
.702 .41547 Mdot
.702 .41549 Mdot
.702 .41554 Mdot
.702 .41559 Mdot
.702 .41587 Mdot
.702 .41593 Mdot
.702 .41599 Mdot
.702 .41601 Mdot
.702 .41619 Mdot
.702 .4162 Mdot
.702 .41626 Mdot
.702 .41627 Mdot
.702 .41638 Mdot
.702 .41647 Mdot
.702 .41653 Mdot
.702 .41675 Mdot
.702 .41704 Mdot
.702 .41707 Mdot
.702 .41721 Mdot
.702 .41754 Mdot
.702 .41762 Mdot
.702 .41781 Mdot
.702 .41789 Mdot
.702 .41792 Mdot
.702 .41794 Mdot
.702 .41802 Mdot
.702 .41807 Mdot
.702 .41857 Mdot
.702 .41858 Mdot
.702 .41869 Mdot
.702 .41872 Mdot
.702 .41875 Mdot
.702 .41876 Mdot
.702 .41926 Mdot
.702 .41932 Mdot
.702 .42012 Mdot
.702 .42021 Mdot
.702 .42057 Mdot
.702 .42084 Mdot
.702 .42098 Mdot
.702 .42101 Mdot
.702 .42113 Mdot
.702 .42144 Mdot
.702 .42181 Mdot
.702 .42212 Mdot
.702 .42241 Mdot
.702 .42243 Mdot
.702 .42271 Mdot
.702 .42292 Mdot
.702 .42295 Mdot
.702 .42299 Mdot
.702 .423 Mdot
.702 .4231 Mdot
.702 .42324 Mdot
.702 .42343 Mdot
.702 .42344 Mdot
.702 .42368 Mdot
.702 .42389 Mdot
.702 .42389 Mdot
.702 .42395 Mdot
.702 .42398 Mdot
.702 .42406 Mdot
.702 .42411 Mdot
.702 .42427 Mdot
.702 .42434 Mdot
.702 .42492 Mdot
.702 .42522 Mdot
.702 .4258 Mdot
.702 .42581 Mdot
.702 .42591 Mdot
.702 .42605 Mdot
.702 .42616 Mdot
.702 .42634 Mdot
.702 .42636 Mdot
.702 .42636 Mdot
.702 .42662 Mdot
.702 .42666 Mdot
.702 .42674 Mdot
.702 .4269 Mdot
.702 .42691 Mdot
.702 .42697 Mdot
.702 .42712 Mdot
.702 .42721 Mdot
.702 .42726 Mdot
.702 .42734 Mdot
.702 .42747 Mdot
.702 .42789 Mdot
.702 .42797 Mdot
.702 .42798 Mdot
.702 .42807 Mdot
.702 .42809 Mdot
.702 .42811 Mdot
.702 .42818 Mdot
.702 .42836 Mdot
.702 .42848 Mdot
.702 .42851 Mdot
.702 .42853 Mdot
.702 .42878 Mdot
.704 .26092 Mdot
.704 .26125 Mdot
.704 .26142 Mdot
.704 .26178 Mdot
.704 .26178 Mdot
.704 .26181 Mdot
.704 .26199 Mdot
.704 .2627 Mdot
.704 .26319 Mdot
.704 .26413 Mdot
.704 .26424 Mdot
.704 .26462 Mdot
.704 .26478 Mdot
.704 .26512 Mdot
.704 .26527 Mdot
.704 .26532 Mdot
.704 .26532 Mdot
.704 .26533 Mdot
.704 .26542 Mdot
.704 .26553 Mdot
.704 .26618 Mdot
.704 .26639 Mdot
.704 .26661 Mdot
.704 .26672 Mdot
.704 .26681 Mdot
.704 .26686 Mdot
.704 .26693 Mdot
.704 .26697 Mdot
.704 .26729 Mdot
.704 .26761 Mdot
.704 .26761 Mdot
.704 .26778 Mdot
.704 .26784 Mdot
.704 .26791 Mdot
.704 .26797 Mdot
.704 .26801 Mdot
.704 .26807 Mdot
.704 .26827 Mdot
.704 .2683 Mdot
.704 .26835 Mdot
.704 .26865 Mdot
.704 .26866 Mdot
.704 .26883 Mdot
.704 .26901 Mdot
.704 .26909 Mdot
.704 .26927 Mdot
.704 .26933 Mdot
.704 .26938 Mdot
.704 .26964 Mdot
.704 .26965 Mdot
.704 .26986 Mdot
.704 .27002 Mdot
.704 .27005 Mdot
.704 .27039 Mdot
.704 .27056 Mdot
.704 .27074 Mdot
.704 .27076 Mdot
.704 .27077 Mdot
.704 .27107 Mdot
.704 .27113 Mdot
.704 .27122 Mdot
.704 .27131 Mdot
.704 .2714 Mdot
.704 .27148 Mdot
.704 .27151 Mdot
.704 .2718 Mdot
.704 .27261 Mdot
.704 .27289 Mdot
.704 .27304 Mdot
.704 .27304 Mdot
.704 .27315 Mdot
.704 .27318 Mdot
.704 .27325 Mdot
.704 .27351 Mdot
.704 .27355 Mdot
.704 .27364 Mdot
.704 .27381 Mdot
.704 .27383 Mdot
.704 .27403 Mdot
.704 .27442 Mdot
.704 .27503 Mdot
.704 .27516 Mdot
.704 .27522 Mdot
.704 .2756 Mdot
.704 .27584 Mdot
.704 .27605 Mdot
.704 .27622 Mdot
.704 .27626 Mdot
.704 .27639 Mdot
.704 .2764 Mdot
.704 .27642 Mdot
.704 .2765 Mdot
.704 .27668 Mdot
.704 .27732 Mdot
.704 .27809 Mdot
.704 .27846 Mdot
.704 .27871 Mdot
.704 .27881 Mdot
.704 .2789 Mdot
.704 .27919 Mdot
.704 .2792 Mdot
.704 .2794 Mdot
.704 .27971 Mdot
.704 .28032 Mdot
.704 .28048 Mdot
.704 .28067 Mdot
.704 .28083 Mdot
.704 .2809 Mdot
.704 .28091 Mdot
.704 .28094 Mdot
.704 .28111 Mdot
.704 .28125 Mdot
.704 .28151 Mdot
.704 .28187 Mdot
.704 .28218 Mdot
.704 .28226 Mdot
.704 .28232 Mdot
.704 .28234 Mdot
.704 .28235 Mdot
.704 .28243 Mdot
.704 .28276 Mdot
.704 .28308 Mdot
.704 .28314 Mdot
.704 .28337 Mdot
.704 .2834 Mdot
.704 .284 Mdot
.704 .28427 Mdot
.704 .28439 Mdot
.704 .28462 Mdot
.704 .28476 Mdot
.704 .28501 Mdot
.704 .28523 Mdot
.704 .28524 Mdot
.704 .28599 Mdot
.704 .28612 Mdot
.704 .28613 Mdot
.704 .28616 Mdot
.704 .28651 Mdot
.704 .28663 Mdot
.704 .28671 Mdot
.704 .28683 Mdot
.704 .28688 Mdot
.704 .28689 Mdot
.704 .28698 Mdot
.704 .28702 Mdot
.704 .28715 Mdot
.704 .28723 Mdot
.704 .28746 Mdot
.704 .28815 Mdot
.704 .28845 Mdot
.704 .28863 Mdot
.704 .28881 Mdot
.704 .28895 Mdot
.704 .28956 Mdot
.704 .28959 Mdot
.704 .28966 Mdot
.704 .28979 Mdot
.704 .28995 Mdot
.704 .28999 Mdot
.704 .29009 Mdot
.704 .2901 Mdot
.704 .2901 Mdot
.704 .29018 Mdot
.704 .29042 Mdot
.704 .29048 Mdot
.704 .29057 Mdot
.704 .29142 Mdot
.704 .29143 Mdot
.704 .29152 Mdot
.704 .29162 Mdot
.704 .29162 Mdot
.704 .2923 Mdot
.704 .2923 Mdot
.704 .2924 Mdot
.704 .29243 Mdot
.704 .29282 Mdot
.704 .29299 Mdot
.704 .29302 Mdot
.704 .29365 Mdot
.704 .2937 Mdot
.704 .2937 Mdot
.704 .29405 Mdot
.704 .29405 Mdot
.704 .2941 Mdot
.704 .29415 Mdot
.704 .29458 Mdot
.704 .29465 Mdot
.704 .29481 Mdot
.704 .29481 Mdot
.704 .29489 Mdot
.704 .29503 Mdot
.704 .29507 Mdot
.704 .29508 Mdot
.704 .29539 Mdot
.704 .29546 Mdot
.704 .29565 Mdot
.704 .2958 Mdot
.704 .2963 Mdot
.704 .29636 Mdot
.704 .29639 Mdot
.704 .29643 Mdot
.704 .29644 Mdot
.704 .29646 Mdot
.704 .29662 Mdot
.704 .2968 Mdot
.704 .29681 Mdot
.704 .29682 Mdot
.704 .29727 Mdot
.704 .29819 Mdot
.704 .29821 Mdot
.704 .29851 Mdot
.704 .29868 Mdot
.704 .29873 Mdot
.704 .29881 Mdot
.704 .29896 Mdot
.704 .29927 Mdot
.704 .29943 Mdot
.704 .29945 Mdot
.704 .29945 Mdot
.704 .29949 Mdot
.704 .29967 Mdot
.704 .29975 Mdot
.704 .30005 Mdot
.704 .30031 Mdot
.704 .30046 Mdot
.704 .30051 Mdot
.704 .30068 Mdot
.704 .30172 Mdot
.704 .3019 Mdot
.704 .302 Mdot
.704 .30235 Mdot
.704 .30272 Mdot
.704 .30316 Mdot
.704 .30331 Mdot
.704 .30342 Mdot
.704 .30349 Mdot
.704 .30404 Mdot
.704 .3042 Mdot
.704 .30429 Mdot
.704 .30438 Mdot
.704 .30467 Mdot
.704 .30494 Mdot
.704 .30513 Mdot
.704 .30513 Mdot
.704 .30529 Mdot
.704 .30532 Mdot
.704 .30545 Mdot
.704 .30554 Mdot
.704 .30563 Mdot
.704 .30581 Mdot
.704 .30582 Mdot
.704 .30592 Mdot
.704 .30598 Mdot
.704 .306 Mdot
.704 .30616 Mdot
.704 .30632 Mdot
.704 .30648 Mdot
.704 .30656 Mdot
.704 .30677 Mdot
.704 .30688 Mdot
.704 .30726 Mdot
.704 .30731 Mdot
.704 .30731 Mdot
.704 .30731 Mdot
.704 .30734 Mdot
.704 .30741 Mdot
.704 .30759 Mdot
.704 .30767 Mdot
.704 .30791 Mdot
.704 .30899 Mdot
.704 .30908 Mdot
.704 .3091 Mdot
.704 .30928 Mdot
.704 .30953 Mdot
.704 .31003 Mdot
.704 .3103 Mdot
.704 .31076 Mdot
.704 .31101 Mdot
.704 .31154 Mdot
.704 .31219 Mdot
.704 .31273 Mdot
.704 .31279 Mdot
.704 .31286 Mdot
.704 .31323 Mdot
.704 .31332 Mdot
.704 .31335 Mdot
.704 .31344 Mdot
.704 .31361 Mdot
.704 .31377 Mdot
.704 .31398 Mdot
.704 .31413 Mdot
.704 .31437 Mdot
.704 .31447 Mdot
.704 .31464 Mdot
.704 .31481 Mdot
.704 .31482 Mdot
.704 .31483 Mdot
.704 .31486 Mdot
.704 .31498 Mdot
.704 .31506 Mdot
.704 .31515 Mdot
.704 .3152 Mdot
.704 .31576 Mdot
.704 .31597 Mdot
.704 .31603 Mdot
.704 .31604 Mdot
.704 .31621 Mdot
.704 .31628 Mdot
.704 .31636 Mdot
.704 .31637 Mdot
.704 .31648 Mdot
.704 .31698 Mdot
.704 .31708 Mdot
.704 .31726 Mdot
.704 .31758 Mdot
.704 .3176 Mdot
.704 .31767 Mdot
.704 .31768 Mdot
.704 .31772 Mdot
.704 .31781 Mdot
.704 .31813 Mdot
.704 .31852 Mdot
.704 .31884 Mdot
.704 .31908 Mdot
.704 .31918 Mdot
.704 .31982 Mdot
.704 .32005 Mdot
.704 .32025 Mdot
.704 .32063 Mdot
.704 .32066 Mdot
.704 .32067 Mdot
.704 .32104 Mdot
.704 .32107 Mdot
.704 .3215 Mdot
.704 .32164 Mdot
.704 .3217 Mdot
.704 .32182 Mdot
.704 .32189 Mdot
.704 .32201 Mdot
.704 .32212 Mdot
.704 .32251 Mdot
.704 .32283 Mdot
.704 .32287 Mdot
.704 .32313 Mdot
.704 .32325 Mdot
.704 .32384 Mdot
.704 .32442 Mdot
.704 .32452 Mdot
.704 .32458 Mdot
.704 .32462 Mdot
.704 .32477 Mdot
.704 .32525 Mdot
.704 .32576 Mdot
.704 .32595 Mdot
.704 .32604 Mdot
.704 .32605 Mdot
.704 .3264 Mdot
.704 .32657 Mdot
.704 .3266 Mdot
.704 .32662 Mdot
.704 .32684 Mdot
.704 .32688 Mdot
.704 .32696 Mdot
.704 .32707 Mdot
.704 .32725 Mdot
.704 .32729 Mdot
.704 .32738 Mdot
.704 .32745 Mdot
.704 .32771 Mdot
.704 .32774 Mdot
.704 .32775 Mdot
.704 .32779 Mdot
.704 .32797 Mdot
.704 .3282 Mdot
.704 .32866 Mdot
.704 .32867 Mdot
.704 .32893 Mdot
.704 .32905 Mdot
.704 .32932 Mdot
.704 .32992 Mdot
.704 .33053 Mdot
.704 .33117 Mdot
.704 .3313 Mdot
.704 .33134 Mdot
.704 .33161 Mdot
.704 .3317 Mdot
.704 .33174 Mdot
.704 .33179 Mdot
.704 .33207 Mdot
.704 .33216 Mdot
.704 .33226 Mdot
.704 .33232 Mdot
.704 .33259 Mdot
.704 .3326 Mdot
.704 .33284 Mdot
.704 .33299 Mdot
.704 .33304 Mdot
.704 .33326 Mdot
.704 .33326 Mdot
.704 .33331 Mdot
.704 .33344 Mdot
.704 .33356 Mdot
.704 .33411 Mdot
.704 .33425 Mdot
.704 .33572 Mdot
.704 .33606 Mdot
.704 .3363 Mdot
.704 .33635 Mdot
.704 .33644 Mdot
.704 .33652 Mdot
.704 .3367 Mdot
.704 .33682 Mdot
.704 .33687 Mdot
.704 .33706 Mdot
.704 .33717 Mdot
.704 .33724 Mdot
.704 .33763 Mdot
.704 .33766 Mdot
.704 .33767 Mdot
.704 .33775 Mdot
.704 .33779 Mdot
.704 .33783 Mdot
.704 .33783 Mdot
.704 .33819 Mdot
.704 .33844 Mdot
.704 .33851 Mdot
.704 .3392 Mdot
.704 .33925 Mdot
.704 .33957 Mdot
.704 .33979 Mdot
.704 .33998 Mdot
.704 .34 Mdot
.704 .34042 Mdot
.704 .34052 Mdot
.704 .34062 Mdot
.704 .34073 Mdot
.704 .34109 Mdot
.704 .34111 Mdot
.704 .34124 Mdot
.704 .3416 Mdot
.704 .34189 Mdot
.704 .34194 Mdot
.704 .34197 Mdot
.704 .34199 Mdot
.704 .34231 Mdot
.704 .34257 Mdot
.704 .34267 Mdot
.704 .34271 Mdot
.704 .34311 Mdot
.704 .34323 Mdot
.704 .34332 Mdot
.704 .34338 Mdot
.704 .34342 Mdot
.704 .34357 Mdot
.704 .34357 Mdot
.704 .34359 Mdot
.704 .34368 Mdot
.704 .34403 Mdot
.704 .34404 Mdot
.704 .34467 Mdot
.704 .3453 Mdot
.704 .34538 Mdot
.704 .34552 Mdot
.704 .34561 Mdot
.704 .3458 Mdot
.704 .34601 Mdot
.704 .34602 Mdot
.704 .34638 Mdot
.704 .34644 Mdot
.704 .34685 Mdot
.704 .34776 Mdot
.704 .34795 Mdot
.704 .34815 Mdot
.704 .34836 Mdot
.704 .34856 Mdot
.704 .34857 Mdot
.704 .34857 Mdot
.704 .34866 Mdot
.704 .34897 Mdot
.704 .34964 Mdot
.704 .34996 Mdot
.704 .35031 Mdot
.704 .35071 Mdot
.704 .35076 Mdot
.704 .35092 Mdot
.704 .35146 Mdot
.704 .35155 Mdot
.704 .35156 Mdot
.704 .35278 Mdot
.704 .35297 Mdot
.704 .35367 Mdot
.704 .35376 Mdot
.704 .35495 Mdot
.704 .35518 Mdot
.704 .35553 Mdot
.704 .35558 Mdot
.704 .35558 Mdot
.704 .35629 Mdot
.704 .35665 Mdot
.704 .35729 Mdot
.704 .36137 Mdot
.704 .36183 Mdot
.704 .36208 Mdot
.704 .36258 Mdot
.704 .36259 Mdot
.704 .36262 Mdot
.704 .36287 Mdot
.704 .36303 Mdot
.704 .36388 Mdot
.704 .36394 Mdot
.704 .36444 Mdot
.704 .36457 Mdot
.704 .36544 Mdot
.704 .36545 Mdot
.704 .36551 Mdot
.704 .3659 Mdot
.704 .36601 Mdot
.704 .36605 Mdot
.704 .36633 Mdot
.704 .36658 Mdot
.704 .3668 Mdot
.704 .36728 Mdot
.704 .3675 Mdot
.704 .36756 Mdot
.704 .36756 Mdot
.704 .36757 Mdot
.704 .36771 Mdot
.704 .36786 Mdot
.704 .368 Mdot
.704 .36814 Mdot
.704 .36878 Mdot
.704 .36908 Mdot
.704 .36912 Mdot
.704 .36938 Mdot
.704 .36938 Mdot
.704 .36953 Mdot
.704 .36967 Mdot
.704 .36973 Mdot
.704 .36983 Mdot
.704 .36989 Mdot
.704 .37034 Mdot
.704 .37078 Mdot
.704 .37079 Mdot
.704 .37104 Mdot
.704 .3711 Mdot
.704 .37111 Mdot
.704 .37112 Mdot
.704 .37122 Mdot
.704 .37125 Mdot
.704 .37129 Mdot
.704 .37136 Mdot
.704 .37144 Mdot
.704 .37173 Mdot
.704 .37176 Mdot
.704 .37183 Mdot
.704 .37201 Mdot
.704 .37223 Mdot
.704 .37225 Mdot
.704 .37227 Mdot
.704 .37231 Mdot
.704 .37251 Mdot
.704 .37277 Mdot
.704 .37286 Mdot
.704 .37288 Mdot
.704 .37313 Mdot
.704 .37321 Mdot
.704 .37328 Mdot
.704 .37335 Mdot
.704 .37365 Mdot
.704 .37367 Mdot
.704 .3738 Mdot
.704 .37395 Mdot
.704 .37418 Mdot
.704 .37422 Mdot
.704 .37471 Mdot
.704 .37476 Mdot
.704 .37494 Mdot
.704 .37519 Mdot
.704 .37519 Mdot
.704 .37522 Mdot
.704 .37525 Mdot
.704 .37531 Mdot
.704 .37531 Mdot
.704 .37533 Mdot
.704 .37561 Mdot
.704 .37566 Mdot
.704 .37574 Mdot
.704 .37587 Mdot
.704 .37591 Mdot
.704 .37599 Mdot
.704 .37612 Mdot
.704 .37618 Mdot
.704 .37624 Mdot
.704 .37628 Mdot
.704 .37645 Mdot
.704 .37669 Mdot
.704 .37773 Mdot
.704 .37783 Mdot
.704 .37822 Mdot
.704 .37831 Mdot
.704 .3784 Mdot
.704 .37844 Mdot
.704 .37844 Mdot
.704 .37859 Mdot
.704 .37863 Mdot
.704 .37873 Mdot
.704 .37891 Mdot
.704 .37891 Mdot
.704 .3791 Mdot
.704 .37915 Mdot
.704 .37922 Mdot
.704 .37929 Mdot
.704 .37949 Mdot
.704 .37952 Mdot
.704 .37955 Mdot
.704 .37961 Mdot
.704 .3798 Mdot
.704 .37983 Mdot
.704 .37992 Mdot
.704 .38038 Mdot
.704 .38081 Mdot
.704 .38124 Mdot
.704 .38143 Mdot
.704 .38151 Mdot
.704 .3817 Mdot
.704 .3817 Mdot
.704 .38204 Mdot
.704 .3822 Mdot
.704 .38232 Mdot
.704 .38235 Mdot
.704 .38236 Mdot
.704 .38238 Mdot
.704 .38256 Mdot
.704 .38262 Mdot
.704 .38268 Mdot
.704 .38271 Mdot
.704 .38284 Mdot
.704 .38291 Mdot
.704 .38297 Mdot
.704 .383 Mdot
.704 .38315 Mdot
.704 .38317 Mdot
.704 .38319 Mdot
.704 .38331 Mdot
.704 .38356 Mdot
.704 .38357 Mdot
.704 .38363 Mdot
.704 .38377 Mdot
.704 .38413 Mdot
.704 .38446 Mdot
.704 .38457 Mdot
.704 .3846 Mdot
.704 .38464 Mdot
.704 .38471 Mdot
.704 .38513 Mdot
.704 .38555 Mdot
.704 .38563 Mdot
.704 .38582 Mdot
.704 .38585 Mdot
.704 .38607 Mdot
.704 .38635 Mdot
.704 .38643 Mdot
.704 .38652 Mdot
.704 .38656 Mdot
.704 .38665 Mdot
.704 .38669 Mdot
.704 .38679 Mdot
.704 .3871 Mdot
.704 .38712 Mdot
.704 .38738 Mdot
.704 .38739 Mdot
.704 .38741 Mdot
.704 .38768 Mdot
.704 .38782 Mdot
.704 .38798 Mdot
.704 .38844 Mdot
.704 .38851 Mdot
.704 .38868 Mdot
.704 .38891 Mdot
.704 .38918 Mdot
.704 .38941 Mdot
.704 .38947 Mdot
.704 .38951 Mdot
.704 .38951 Mdot
.704 .38956 Mdot
.704 .38958 Mdot
.704 .3898 Mdot
.704 .38993 Mdot
.704 .39 Mdot
.704 .39036 Mdot
.704 .39043 Mdot
.704 .39044 Mdot
.704 .3905 Mdot
.704 .39054 Mdot
.704 .39067 Mdot
.704 .39067 Mdot
.704 .39071 Mdot
.704 .39087 Mdot
.704 .39126 Mdot
.704 .3913 Mdot
.704 .39137 Mdot
.704 .39142 Mdot
.704 .3915 Mdot
.704 .39153 Mdot
.704 .39153 Mdot
.704 .39154 Mdot
.704 .39166 Mdot
.704 .39179 Mdot
.704 .39186 Mdot
.704 .39203 Mdot
.704 .39213 Mdot
.704 .39228 Mdot
.704 .3924 Mdot
.704 .39252 Mdot
.704 .39258 Mdot
.704 .3926 Mdot
.704 .39266 Mdot
.704 .39293 Mdot
.704 .39298 Mdot
.704 .39302 Mdot
.704 .3934 Mdot
.704 .39387 Mdot
.704 .39424 Mdot
.704 .39442 Mdot
.704 .39475 Mdot
.704 .39494 Mdot
.704 .39529 Mdot
.704 .39547 Mdot
.704 .3956 Mdot
.704 .39561 Mdot
.704 .39567 Mdot
.704 .39644 Mdot
.704 .39662 Mdot
.704 .39667 Mdot
.704 .3968 Mdot
.704 .39685 Mdot
.704 .39687 Mdot
.704 .39687 Mdot
.704 .39687 Mdot
.704 .3969 Mdot
.704 .39718 Mdot
.704 .39725 Mdot
.704 .3974 Mdot
.704 .39746 Mdot
.704 .39757 Mdot
.704 .39769 Mdot
.704 .3978 Mdot
.704 .39782 Mdot
.704 .39785 Mdot
.704 .39793 Mdot
.704 .39793 Mdot
.704 .39806 Mdot
.704 .39813 Mdot
.704 .39819 Mdot
.704 .39828 Mdot
.704 .3983 Mdot
.704 .39842 Mdot
.704 .39842 Mdot
.704 .39855 Mdot
.704 .39874 Mdot
.704 .39895 Mdot
.704 .39901 Mdot
.704 .39907 Mdot
.704 .39919 Mdot
.704 .39958 Mdot
.704 .39963 Mdot
.704 .39971 Mdot
.704 .39982 Mdot
.704 .40013 Mdot
.704 .40039 Mdot
.704 .40064 Mdot
.704 .40071 Mdot
.704 .40084 Mdot
.704 .40158 Mdot
.704 .4017 Mdot
.704 .40173 Mdot
.704 .40184 Mdot
.704 .40202 Mdot
.704 .40224 Mdot
.704 .4023 Mdot
.704 .40243 Mdot
.704 .40245 Mdot
.704 .40245 Mdot
.704 .40246 Mdot
.704 .40258 Mdot
.704 .4028 Mdot
.704 .40291 Mdot
.704 .40297 Mdot
.704 .403 Mdot
.704 .40312 Mdot
.704 .40333 Mdot
.704 .40334 Mdot
.704 .404 Mdot
.704 .40432 Mdot
.704 .40432 Mdot
.704 .40433 Mdot
.704 .40446 Mdot
.704 .40457 Mdot
.704 .40459 Mdot
.704 .40459 Mdot
.704 .40463 Mdot
.704 .40464 Mdot
.704 .40469 Mdot
.704 .40505 Mdot
.704 .40515 Mdot
.704 .40528 Mdot
.704 .40533 Mdot
.704 .40555 Mdot
.704 .40556 Mdot
.704 .40559 Mdot
.704 .40569 Mdot
.704 .40574 Mdot
.704 .40574 Mdot
.704 .40586 Mdot
.704 .40591 Mdot
.704 .40622 Mdot
.704 .40625 Mdot
.704 .40629 Mdot
.704 .40629 Mdot
.704 .40653 Mdot
.704 .40653 Mdot
.704 .40657 Mdot
.704 .40702 Mdot
.704 .40704 Mdot
.704 .40716 Mdot
.704 .40743 Mdot
.704 .40746 Mdot
.704 .40753 Mdot
.704 .40753 Mdot
.704 .40801 Mdot
.704 .40801 Mdot
.704 .40808 Mdot
.704 .40815 Mdot
.704 .40815 Mdot
.704 .40876 Mdot
.704 .40882 Mdot
.704 .40886 Mdot
.704 .40903 Mdot
.704 .40909 Mdot
.704 .40909 Mdot
.704 .4091 Mdot
.704 .40917 Mdot
.704 .4092 Mdot
.704 .40931 Mdot
.704 .4094 Mdot
.704 .40946 Mdot
.704 .40947 Mdot
.704 .40991 Mdot
.704 .41001 Mdot
.704 .41013 Mdot
.704 .41027 Mdot
.704 .41048 Mdot
.704 .41097 Mdot
.704 .41113 Mdot
.704 .41119 Mdot
.704 .41128 Mdot
.704 .41131 Mdot
.704 .41137 Mdot
.704 .41138 Mdot
.704 .41141 Mdot
.704 .4115 Mdot
.704 .41156 Mdot
.704 .41164 Mdot
.704 .41189 Mdot
.704 .41191 Mdot
.704 .41192 Mdot
.704 .41201 Mdot
.704 .41255 Mdot
.704 .41255 Mdot
.704 .41271 Mdot
.704 .41288 Mdot
.704 .41298 Mdot
.704 .41315 Mdot
.704 .41324 Mdot
.704 .41342 Mdot
.704 .41385 Mdot
.704 .41387 Mdot
.704 .41403 Mdot
.704 .41408 Mdot
.704 .4143 Mdot
.704 .41454 Mdot
.704 .4146 Mdot
.704 .4146 Mdot
.704 .41462 Mdot
.704 .41466 Mdot
.704 .41472 Mdot
.704 .41494 Mdot
.704 .41519 Mdot
.704 .41537 Mdot
.704 .41548 Mdot
.704 .4156 Mdot
.704 .41562 Mdot
.704 .41562 Mdot
.704 .41567 Mdot
.704 .41579 Mdot
.704 .41593 Mdot
.704 .41604 Mdot
.704 .41647 Mdot
.704 .41669 Mdot
.704 .41683 Mdot
.704 .41684 Mdot
.704 .41704 Mdot
.704 .41711 Mdot
.704 .41718 Mdot
.704 .41736 Mdot
.704 .41762 Mdot
.704 .41817 Mdot
.704 .41863 Mdot
.704 .41875 Mdot
.704 .41881 Mdot
.704 .41882 Mdot
.704 .41883 Mdot
.704 .41892 Mdot
.704 .41895 Mdot
.704 .41907 Mdot
.704 .41922 Mdot
.704 .41939 Mdot
.704 .41966 Mdot
.704 .4197 Mdot
.704 .41979 Mdot
.704 .42023 Mdot
.704 .4205 Mdot
.704 .42065 Mdot
.704 .42066 Mdot
.704 .42078 Mdot
.704 .42085 Mdot
.704 .42087 Mdot
.704 .42106 Mdot
.704 .42111 Mdot
.704 .42113 Mdot
.704 .42121 Mdot
.704 .42121 Mdot
.704 .42132 Mdot
.704 .42151 Mdot
.704 .42209 Mdot
.704 .42229 Mdot
.704 .42232 Mdot
.704 .42237 Mdot
.704 .42244 Mdot
.704 .4225 Mdot
.704 .42257 Mdot
.704 .42261 Mdot
.704 .42277 Mdot
.704 .42282 Mdot
.704 .42283 Mdot
.704 .42284 Mdot
.704 .42297 Mdot
.704 .42309 Mdot
.704 .42333 Mdot
.704 .42335 Mdot
.704 .42347 Mdot
.704 .42361 Mdot
.704 .42362 Mdot
.704 .42381 Mdot
.704 .42384 Mdot
.704 .42389 Mdot
.704 .42401 Mdot
.704 .42407 Mdot
.704 .4242 Mdot
.704 .42432 Mdot
.704 .42433 Mdot
.704 .42454 Mdot
.704 .42458 Mdot
.704 .42459 Mdot
.704 .42474 Mdot
.704 .42478 Mdot
.704 .42481 Mdot
.704 .42485 Mdot
.704 .4249 Mdot
.704 .42494 Mdot
.704 .42507 Mdot
.704 .42507 Mdot
.704 .42529 Mdot
.704 .42552 Mdot
.704 .42555 Mdot
.704 .4256 Mdot
.704 .42563 Mdot
.704 .4257 Mdot
.704 .42578 Mdot
.704 .42593 Mdot
.704 .42608 Mdot
.704 .42654 Mdot
.704 .42662 Mdot
.704 .42669 Mdot
.704 .42669 Mdot
.704 .42669 Mdot
.704 .42672 Mdot
.704 .42683 Mdot
.704 .42708 Mdot
.704 .42719 Mdot
.704 .42746 Mdot
.704 .42753 Mdot
.704 .4282 Mdot
.704 .42855 Mdot
.704 .42906 Mdot
.704 .42919 Mdot
.704 .4292 Mdot
.704 .42921 Mdot
.704 .42946 Mdot
.704 .42959 Mdot
.704 .42982 Mdot
.706 .25989 Mdot
.706 .26002 Mdot
.706 .26065 Mdot
.706 .26072 Mdot
.706 .26074 Mdot
.706 .26093 Mdot
.706 .261 Mdot
.706 .26124 Mdot
.706 .26181 Mdot
.706 .26183 Mdot
.706 .26185 Mdot
.706 .26186 Mdot
.706 .26191 Mdot
.706 .26214 Mdot
.706 .26223 Mdot
.706 .26224 Mdot
.706 .26298 Mdot
.706 .26302 Mdot
.706 .26304 Mdot
.706 .26312 Mdot
.706 .26312 Mdot
.706 .26344 Mdot
.706 .2638 Mdot
.706 .26407 Mdot
.706 .26419 Mdot
.706 .2644 Mdot
.706 .26473 Mdot
.706 .26493 Mdot
.706 .26499 Mdot
.706 .26527 Mdot
.706 .26528 Mdot
.706 .26533 Mdot
.706 .26534 Mdot
.706 .26583 Mdot
.706 .26588 Mdot
.706 .26611 Mdot
.706 .26656 Mdot
.706 .26659 Mdot
.706 .2671 Mdot
.706 .26719 Mdot
.706 .2674 Mdot
.706 .26761 Mdot
.706 .26766 Mdot
.706 .26785 Mdot
.706 .26807 Mdot
.706 .26837 Mdot
.706 .26858 Mdot
.706 .26875 Mdot
.706 .26917 Mdot
.706 .26952 Mdot
.706 .26963 Mdot
.706 .26988 Mdot
.706 .27021 Mdot
.706 .27034 Mdot
.706 .2704 Mdot
.706 .27057 Mdot
.706 .27083 Mdot
.706 .27097 Mdot
.706 .271 Mdot
.706 .27104 Mdot
.706 .27126 Mdot
.706 .27127 Mdot
.706 .27132 Mdot
.706 .27194 Mdot
.706 .27219 Mdot
.706 .27243 Mdot
.706 .27256 Mdot
.706 .2727 Mdot
.706 .27309 Mdot
.706 .27323 Mdot
.706 .27325 Mdot
.706 .27342 Mdot
.706 .2736 Mdot
.706 .27368 Mdot
.706 .2737 Mdot
.706 .2737 Mdot
.706 .27376 Mdot
.706 .27415 Mdot
.706 .27429 Mdot
.706 .27438 Mdot
.706 .27443 Mdot
.706 .27469 Mdot
.706 .27498 Mdot
.706 .27517 Mdot
.706 .27591 Mdot
.706 .2761 Mdot
.706 .27615 Mdot
.706 .27632 Mdot
.706 .27647 Mdot
.706 .2766 Mdot
.706 .27669 Mdot
.706 .27674 Mdot
.706 .27722 Mdot
.706 .27786 Mdot
.706 .27802 Mdot
.706 .27816 Mdot
.706 .27829 Mdot
.706 .27837 Mdot
.706 .27844 Mdot
.706 .27857 Mdot
.706 .27902 Mdot
.706 .27904 Mdot
.706 .27918 Mdot
.706 .27919 Mdot
.706 .27929 Mdot
.706 .27966 Mdot
.706 .27987 Mdot
.706 .28015 Mdot
.706 .28035 Mdot
.706 .28067 Mdot
.706 .28072 Mdot
.706 .28086 Mdot
.706 .28105 Mdot
.706 .28107 Mdot
.706 .28111 Mdot
.706 .28133 Mdot
.706 .28164 Mdot
.706 .28172 Mdot
.706 .28192 Mdot
.706 .28233 Mdot
.706 .2825 Mdot
.706 .28295 Mdot
.706 .28338 Mdot
.706 .28353 Mdot
.706 .2837 Mdot
.706 .28373 Mdot
.706 .28374 Mdot
.706 .28392 Mdot
.706 .28402 Mdot
.706 .28402 Mdot
.706 .28426 Mdot
.706 .28431 Mdot
.706 .28465 Mdot
.706 .28486 Mdot
.706 .28493 Mdot
.706 .28513 Mdot
.706 .28514 Mdot
.706 .28516 Mdot
.706 .28524 Mdot
.706 .28554 Mdot
.706 .2857 Mdot
.706 .28633 Mdot
.706 .28649 Mdot
.706 .28659 Mdot
.706 .28698 Mdot
.706 .28716 Mdot
.706 .28768 Mdot
.706 .28827 Mdot
.706 .28868 Mdot
.706 .28887 Mdot
.706 .28921 Mdot
.706 .28932 Mdot
.706 .28992 Mdot
.706 .29034 Mdot
.706 .29064 Mdot
.706 .29065 Mdot
.706 .2907 Mdot
.706 .29072 Mdot
.706 .29078 Mdot
.706 .291 Mdot
.706 .29101 Mdot
.706 .2911 Mdot
.706 .29134 Mdot
.706 .29164 Mdot
.706 .29189 Mdot
.706 .2922 Mdot
.706 .2924 Mdot
.706 .29247 Mdot
.706 .29264 Mdot
.706 .29314 Mdot
.706 .29336 Mdot
.706 .29364 Mdot
.706 .29391 Mdot
.706 .29396 Mdot
.706 .2941 Mdot
.706 .29411 Mdot
.706 .29414 Mdot
.706 .29429 Mdot
.706 .2945 Mdot
.706 .2948 Mdot
.706 .29512 Mdot
.706 .29563 Mdot
.706 .29597 Mdot
.706 .29622 Mdot
.706 .2967 Mdot
.706 .29689 Mdot
.706 .2969 Mdot
.706 .29704 Mdot
.706 .29734 Mdot
.706 .29746 Mdot
.706 .29751 Mdot
.706 .2976 Mdot
.706 .29761 Mdot
.706 .29762 Mdot
.706 .29778 Mdot
.706 .29822 Mdot
.706 .29831 Mdot
.706 .29895 Mdot
.706 .29905 Mdot
.706 .2993 Mdot
.706 .29983 Mdot
.706 .29996 Mdot
.706 .29997 Mdot
.706 .3002 Mdot
.706 .30026 Mdot
.706 .30047 Mdot
.706 .30055 Mdot
.706 .30111 Mdot
.706 .30114 Mdot
.706 .30118 Mdot
.706 .30143 Mdot
.706 .30153 Mdot
.706 .30214 Mdot
.706 .30234 Mdot
.706 .30241 Mdot
.706 .30261 Mdot
.706 .30264 Mdot
.706 .30286 Mdot
.706 .30287 Mdot
.706 .30294 Mdot
.706 .30328 Mdot
.706 .30352 Mdot
.706 .30401 Mdot
.706 .30455 Mdot
.706 .30468 Mdot
.706 .30473 Mdot
.706 .30491 Mdot
.706 .30531 Mdot
.706 .30569 Mdot
.706 .3059 Mdot
.706 .3062 Mdot
.706 .30622 Mdot
.706 .30684 Mdot
.706 .30686 Mdot
.706 .30741 Mdot
.706 .30747 Mdot
.706 .30778 Mdot
.706 .30794 Mdot
.706 .30798 Mdot
.706 .30839 Mdot
.706 .30844 Mdot
.706 .30855 Mdot
.706 .30859 Mdot
.706 .3086 Mdot
.706 .30889 Mdot
.706 .30901 Mdot
.706 .30914 Mdot
.706 .30918 Mdot
.706 .30956 Mdot
.706 .3099 Mdot
.706 .31025 Mdot
.706 .31035 Mdot
.706 .31081 Mdot
.706 .31082 Mdot
.706 .31101 Mdot
.706 .31138 Mdot
.706 .3114 Mdot
.706 .31145 Mdot
.706 .31179 Mdot
.706 .31209 Mdot
.706 .31226 Mdot
.706 .31236 Mdot
.706 .31239 Mdot
.706 .31253 Mdot
.706 .31257 Mdot
.706 .31281 Mdot
.706 .31284 Mdot
.706 .31295 Mdot
.706 .31345 Mdot
.706 .3136 Mdot
.706 .31373 Mdot
.706 .31382 Mdot
.706 .31393 Mdot
.706 .31419 Mdot
.706 .31428 Mdot
.706 .31501 Mdot
.706 .31507 Mdot
.706 .3151 Mdot
.706 .31519 Mdot
.706 .31532 Mdot
.706 .3154 Mdot
.706 .31542 Mdot
.706 .31553 Mdot
.706 .31554 Mdot
.706 .31556 Mdot
.706 .316 Mdot
.706 .31619 Mdot
.706 .31625 Mdot
.706 .31661 Mdot
.706 .31671 Mdot
.706 .31675 Mdot
.706 .31676 Mdot
.706 .31709 Mdot
.706 .31712 Mdot
.706 .3174 Mdot
.706 .31749 Mdot
.706 .31799 Mdot
.706 .31807 Mdot
.706 .31814 Mdot
.706 .31852 Mdot
.706 .319 Mdot
.706 .31906 Mdot
.706 .3191 Mdot
.706 .3195 Mdot
.706 .31951 Mdot
.706 .31975 Mdot
.706 .31985 Mdot
.706 .31999 Mdot
.706 .32025 Mdot
.706 .32028 Mdot
.706 .32045 Mdot
.706 .32047 Mdot
.706 .32058 Mdot
.706 .32074 Mdot
.706 .32078 Mdot
.706 .32088 Mdot
.706 .3214 Mdot
.706 .32169 Mdot
.706 .32193 Mdot
.706 .32208 Mdot
.706 .32225 Mdot
.706 .32239 Mdot
.706 .32249 Mdot
.706 .32254 Mdot
.706 .32277 Mdot
.706 .32309 Mdot
.706 .32322 Mdot
.706 .32351 Mdot
.706 .32406 Mdot
.706 .32437 Mdot
.706 .32454 Mdot
.706 .32525 Mdot
.706 .32532 Mdot
.706 .32544 Mdot
.706 .3256 Mdot
.706 .32588 Mdot
.706 .32614 Mdot
.706 .32617 Mdot
.706 .32651 Mdot
.706 .32661 Mdot
.706 .32689 Mdot
.706 .32699 Mdot
.706 .32708 Mdot
.706 .32734 Mdot
.706 .32793 Mdot
.706 .32846 Mdot
.706 .32874 Mdot
.706 .32883 Mdot
.706 .3291 Mdot
.706 .32942 Mdot
.706 .3296 Mdot
.706 .32986 Mdot
.706 .32993 Mdot
.706 .32993 Mdot
.706 .33005 Mdot
.706 .33022 Mdot
.706 .3305 Mdot
.706 .33054 Mdot
.706 .33067 Mdot
.706 .33102 Mdot
.706 .33116 Mdot
.706 .33125 Mdot
.706 .33127 Mdot
.706 .33138 Mdot
.706 .33139 Mdot
.706 .33142 Mdot
.706 .33159 Mdot
.706 .33196 Mdot
.706 .33229 Mdot
.706 .33232 Mdot
.706 .33261 Mdot
.706 .33306 Mdot
.706 .33338 Mdot
.706 .33339 Mdot
.706 .33366 Mdot
.706 .33393 Mdot
.706 .33395 Mdot
.706 .33418 Mdot
.706 .3344 Mdot
.706 .33455 Mdot
.706 .33491 Mdot
.706 .3361 Mdot
.706 .33615 Mdot
.706 .33616 Mdot
.706 .33623 Mdot
.706 .33625 Mdot
.706 .33637 Mdot
.706 .33639 Mdot
.706 .33669 Mdot
.706 .33677 Mdot
.706 .33683 Mdot
.706 .33688 Mdot
.706 .33694 Mdot
.706 .33711 Mdot
.706 .33751 Mdot
.706 .33752 Mdot
.706 .33756 Mdot
.706 .33763 Mdot
.706 .33768 Mdot
.706 .33774 Mdot
.706 .33774 Mdot
.706 .33797 Mdot
.706 .3381 Mdot
.706 .33835 Mdot
.706 .33852 Mdot
.706 .33897 Mdot
.706 .33901 Mdot
.706 .33947 Mdot
.706 .33951 Mdot
.706 .33973 Mdot
.706 .33985 Mdot
.706 .3399 Mdot
.706 .33998 Mdot
.706 .34012 Mdot
.706 .34027 Mdot
.706 .34042 Mdot
.706 .34068 Mdot
.706 .34118 Mdot
.706 .34125 Mdot
.706 .34159 Mdot
.706 .34174 Mdot
.706 .34202 Mdot
.706 .34225 Mdot
.706 .34261 Mdot
.706 .34306 Mdot
.706 .34344 Mdot
.706 .34353 Mdot
.706 .34366 Mdot
.706 .34396 Mdot
.706 .34436 Mdot
.706 .34454 Mdot
.706 .34479 Mdot
.706 .34493 Mdot
.706 .34496 Mdot
.706 .34526 Mdot
.706 .34533 Mdot
.706 .34551 Mdot
.706 .34557 Mdot
.706 .34562 Mdot
.706 .34653 Mdot
.706 .34669 Mdot
.706 .34698 Mdot
.706 .34709 Mdot
.706 .34728 Mdot
.706 .34805 Mdot
.706 .34808 Mdot
.706 .34819 Mdot
.706 .3482 Mdot
.706 .34844 Mdot
.706 .34847 Mdot
.706 .34876 Mdot
.706 .34877 Mdot
.706 .34879 Mdot
.706 .34885 Mdot
.706 .34888 Mdot
.706 .34888 Mdot
.706 .34927 Mdot
.706 .34949 Mdot
.706 .34975 Mdot
.706 .34994 Mdot
.706 .34996 Mdot
.706 .35 Mdot
.706 .35007 Mdot
.706 .35015 Mdot
.706 .35035 Mdot
.706 .3506 Mdot
.706 .35088 Mdot
.706 .35114 Mdot
.706 .35185 Mdot
.706 .35241 Mdot
.706 .35248 Mdot
.706 .3525 Mdot
.706 .35265 Mdot
.706 .35268 Mdot
.706 .35277 Mdot
.706 .35336 Mdot
.706 .35366 Mdot
.706 .35425 Mdot
.706 .35426 Mdot
.706 .35441 Mdot
.706 .35442 Mdot
.706 .35445 Mdot
.706 .35446 Mdot
.706 .35477 Mdot
.706 .3549 Mdot
.706 .35501 Mdot
.706 .35502 Mdot
.706 .35506 Mdot
.706 .3551 Mdot
.706 .35547 Mdot
.706 .35624 Mdot
.706 .35671 Mdot
.706 .35686 Mdot
.706 .35724 Mdot
.706 .35724 Mdot
.706 .35726 Mdot
.706 .35742 Mdot
.706 .35777 Mdot
.706 .35866 Mdot
.706 .35892 Mdot
.706 .36091 Mdot
.706 .36109 Mdot
.706 .36172 Mdot
.706 .36197 Mdot
.706 .36208 Mdot
.706 .3621 Mdot
.706 .3621 Mdot
.706 .36236 Mdot
.706 .36247 Mdot
.706 .36281 Mdot
.706 .36335 Mdot
.706 .36361 Mdot
.706 .36364 Mdot
.706 .36367 Mdot
.706 .36368 Mdot
.706 .36375 Mdot
.706 .36384 Mdot
.706 .36406 Mdot
.706 .36407 Mdot
.706 .3641 Mdot
.706 .3641 Mdot
.706 .36421 Mdot
.706 .36422 Mdot
.706 .36463 Mdot
.706 .36484 Mdot
.706 .36526 Mdot
.706 .36532 Mdot
.706 .36535 Mdot
.706 .36546 Mdot
.706 .36547 Mdot
.706 .36551 Mdot
.706 .36592 Mdot
.706 .36642 Mdot
.706 .3666 Mdot
.706 .3668 Mdot
.706 .36698 Mdot
.706 .36712 Mdot
.706 .36718 Mdot
.706 .36723 Mdot
.706 .36725 Mdot
.706 .36727 Mdot
.706 .3674 Mdot
.706 .36758 Mdot
.706 .36774 Mdot
.706 .36802 Mdot
.706 .36802 Mdot
.706 .36804 Mdot
.706 .36808 Mdot
.706 .3681 Mdot
.706 .3681 Mdot
.706 .36831 Mdot
.706 .36833 Mdot
.706 .3685 Mdot
.706 .36851 Mdot
.706 .36858 Mdot
.706 .3686 Mdot
.706 .36915 Mdot
.706 .36928 Mdot
.706 .36937 Mdot
.706 .36957 Mdot
.706 .36968 Mdot
.706 .37032 Mdot
.706 .37036 Mdot
.706 .37041 Mdot
.706 .37053 Mdot
.706 .37058 Mdot
.706 .3708 Mdot
.706 .37082 Mdot
.706 .37091 Mdot
.706 .37109 Mdot
.706 .37122 Mdot
.706 .37151 Mdot
.706 .37171 Mdot
.706 .3718 Mdot
.706 .37187 Mdot
.706 .37214 Mdot
.706 .37246 Mdot
.706 .37271 Mdot
.706 .37288 Mdot
.706 .37308 Mdot
.706 .37318 Mdot
.706 .37342 Mdot
.706 .37347 Mdot
.706 .37383 Mdot
.706 .37401 Mdot
.706 .37411 Mdot
.706 .37422 Mdot
.706 .37432 Mdot
.706 .37438 Mdot
.706 .37441 Mdot
.706 .3745 Mdot
.706 .37466 Mdot
.706 .37468 Mdot
.706 .37501 Mdot
.706 .37504 Mdot
.706 .37535 Mdot
.706 .37547 Mdot
.706 .37565 Mdot
.706 .37574 Mdot
.706 .37591 Mdot
.706 .37591 Mdot
.706 .37595 Mdot
.706 .37598 Mdot
.706 .37603 Mdot
.706 .37606 Mdot
.706 .37607 Mdot
.706 .37635 Mdot
.706 .37648 Mdot
.706 .37652 Mdot
.706 .37655 Mdot
.706 .3766 Mdot
.706 .37665 Mdot
.706 .37687 Mdot
.706 .37688 Mdot
.706 .37696 Mdot
.706 .37698 Mdot
.706 .37703 Mdot
.706 .37704 Mdot
.706 .37707 Mdot
.706 .37791 Mdot
.706 .37816 Mdot
.706 .37827 Mdot
.706 .37843 Mdot
.706 .37859 Mdot
.706 .3786 Mdot
.706 .37879 Mdot
.706 .37899 Mdot
.706 .379 Mdot
.706 .37922 Mdot
.706 .37954 Mdot
.706 .37974 Mdot
.706 .37976 Mdot
.706 .38 Mdot
.706 .38026 Mdot
.706 .38038 Mdot
.706 .38041 Mdot
.706 .38041 Mdot
.706 .38049 Mdot
.706 .3805 Mdot
.706 .38057 Mdot
.706 .38067 Mdot
.706 .38092 Mdot
.706 .38101 Mdot
.706 .38103 Mdot
.706 .38123 Mdot
.706 .38136 Mdot
.706 .38144 Mdot
.706 .38144 Mdot
.706 .38148 Mdot
.706 .38167 Mdot
.706 .3818 Mdot
.706 .38203 Mdot
.706 .38221 Mdot
.706 .38228 Mdot
.706 .38248 Mdot
.706 .38286 Mdot
.706 .38327 Mdot
.706 .38345 Mdot
.706 .38352 Mdot
.706 .38359 Mdot
.706 .38379 Mdot
.706 .38386 Mdot
.706 .3841 Mdot
.706 .38412 Mdot
.706 .38431 Mdot
.706 .3845 Mdot
.706 .38462 Mdot
.706 .3847 Mdot
.706 .38475 Mdot
.706 .38526 Mdot
.706 .38538 Mdot
.706 .38559 Mdot
.706 .38599 Mdot
.706 .38619 Mdot
.706 .38628 Mdot
.706 .38651 Mdot
.706 .38667 Mdot
.706 .38671 Mdot
.706 .38678 Mdot
.706 .38688 Mdot
.706 .387 Mdot
.706 .3871 Mdot
.706 .38727 Mdot
.706 .38748 Mdot
.706 .38785 Mdot
.706 .38792 Mdot
.706 .38795 Mdot
.706 .38806 Mdot
.706 .38813 Mdot
.706 .38815 Mdot
.706 .38827 Mdot
.706 .38829 Mdot
.706 .38847 Mdot
.706 .38858 Mdot
.706 .38865 Mdot
.706 .38882 Mdot
.706 .38882 Mdot
.706 .38911 Mdot
.706 .38914 Mdot
.706 .38918 Mdot
.706 .38952 Mdot
.706 .38979 Mdot
.706 .38984 Mdot
.706 .3899 Mdot
.706 .39025 Mdot
.706 .39031 Mdot
.706 .39051 Mdot
.706 .39053 Mdot
.706 .39077 Mdot
.706 .39077 Mdot
.706 .3908 Mdot
.706 .39087 Mdot
.706 .39112 Mdot
.706 .39117 Mdot
.706 .3913 Mdot
.706 .39161 Mdot
.706 .39163 Mdot
.706 .39163 Mdot
.706 .39171 Mdot
.706 .39173 Mdot
.706 .39179 Mdot
.706 .39188 Mdot
.706 .39194 Mdot
.706 .39196 Mdot
.706 .39201 Mdot
.706 .39252 Mdot
.706 .39259 Mdot
.706 .39277 Mdot
.706 .39283 Mdot
.706 .39285 Mdot
.706 .39291 Mdot
.706 .39301 Mdot
.706 .39311 Mdot
.706 .39346 Mdot
.706 .39354 Mdot
.706 .39356 Mdot
.706 .39374 Mdot
.706 .39376 Mdot
.706 .39386 Mdot
.706 .39388 Mdot
.706 .39395 Mdot
.706 .39407 Mdot
.706 .39429 Mdot
.706 .39453 Mdot
.706 .39456 Mdot
.706 .39458 Mdot
.706 .39484 Mdot
.706 .39497 Mdot
.706 .39498 Mdot
.706 .39531 Mdot
.706 .39538 Mdot
.706 .39563 Mdot
.706 .39586 Mdot
.706 .39613 Mdot
.706 .39616 Mdot
.706 .39626 Mdot
.706 .39634 Mdot
.706 .39654 Mdot
.706 .39655 Mdot
.706 .39658 Mdot
.706 .39666 Mdot
.706 .39669 Mdot
.706 .39698 Mdot
.706 .39701 Mdot
.706 .39712 Mdot
.706 .39735 Mdot
.706 .39739 Mdot
.706 .39777 Mdot
.706 .39779 Mdot
.706 .39823 Mdot
.706 .39824 Mdot
.706 .39846 Mdot
.706 .3986 Mdot
.706 .39887 Mdot
.706 .39916 Mdot
.706 .39928 Mdot
.706 .39932 Mdot
.706 .39941 Mdot
.706 .3998 Mdot
.706 .40014 Mdot
.706 .40031 Mdot
.706 .40055 Mdot
.706 .4006 Mdot
.706 .40061 Mdot
.706 .40077 Mdot
.706 .40079 Mdot
.706 .40093 Mdot
.706 .40098 Mdot
.706 .40112 Mdot
.706 .40155 Mdot
.706 .40162 Mdot
.706 .4018 Mdot
.706 .40183 Mdot
.706 .40185 Mdot
.706 .40225 Mdot
.706 .4023 Mdot
.706 .40245 Mdot
.706 .4025 Mdot
.706 .40266 Mdot
.706 .40267 Mdot
.706 .40275 Mdot
.706 .40313 Mdot
.706 .40331 Mdot
.706 .40338 Mdot
.706 .40383 Mdot
.706 .40389 Mdot
.706 .40421 Mdot
.706 .40432 Mdot
.706 .40433 Mdot
.706 .40433 Mdot
.706 .4044 Mdot
.706 .40443 Mdot
.706 .40452 Mdot
.706 .40473 Mdot
.706 .40483 Mdot
.706 .40484 Mdot
.706 .40497 Mdot
.706 .40531 Mdot
.706 .40549 Mdot
.706 .40573 Mdot
.706 .40609 Mdot
.706 .40631 Mdot
.706 .40653 Mdot
.706 .40668 Mdot
.706 .40679 Mdot
.706 .4068 Mdot
.706 .40681 Mdot
.706 .40691 Mdot
.706 .40695 Mdot
.706 .40714 Mdot
.706 .40734 Mdot
.706 .40749 Mdot
.706 .40785 Mdot
.706 .40796 Mdot
.706 .40801 Mdot
.706 .40816 Mdot
.706 .40838 Mdot
.706 .40856 Mdot
.706 .40877 Mdot
.706 .40894 Mdot
.706 .409 Mdot
.706 .40901 Mdot
.706 .40917 Mdot
.706 .40921 Mdot
.706 .40922 Mdot
.706 .40926 Mdot
.706 .40926 Mdot
.706 .40948 Mdot
.706 .40977 Mdot
.706 .4102 Mdot
.706 .41028 Mdot
.706 .41051 Mdot
.706 .41065 Mdot
.706 .41094 Mdot
.706 .41136 Mdot
.706 .41173 Mdot
.706 .41185 Mdot
.706 .41213 Mdot
.706 .41221 Mdot
.706 .41232 Mdot
.706 .41276 Mdot
.706 .41287 Mdot
.706 .41309 Mdot
.706 .41315 Mdot
.706 .41316 Mdot
.706 .41316 Mdot
.706 .41331 Mdot
.706 .41336 Mdot
.706 .41351 Mdot
.706 .41375 Mdot
.706 .41379 Mdot
.706 .41395 Mdot
.706 .41395 Mdot
.706 .41402 Mdot
.706 .41415 Mdot
.706 .41416 Mdot
.706 .41418 Mdot
.706 .4143 Mdot
.706 .4144 Mdot
.706 .41471 Mdot
.706 .41503 Mdot
.706 .41515 Mdot
.706 .41544 Mdot
.706 .41558 Mdot
.706 .41564 Mdot
.706 .41586 Mdot
.706 .41601 Mdot
.706 .41604 Mdot
.706 .41606 Mdot
.706 .41619 Mdot
.706 .41629 Mdot
.706 .41632 Mdot
.706 .41655 Mdot
.706 .41669 Mdot
.706 .41689 Mdot
.706 .41704 Mdot
.706 .4173 Mdot
.706 .41737 Mdot
.706 .41738 Mdot
.706 .41748 Mdot
.706 .41749 Mdot
.706 .41781 Mdot
.706 .4179 Mdot
.706 .41795 Mdot
.706 .41801 Mdot
.706 .4181 Mdot
.706 .4182 Mdot
.706 .41831 Mdot
.706 .41877 Mdot
.706 .4191 Mdot
.706 .41914 Mdot
.706 .4192 Mdot
.706 .4193 Mdot
.706 .41941 Mdot
.706 .41952 Mdot
.706 .41956 Mdot
.706 .4197 Mdot
.706 .42022 Mdot
.706 .42035 Mdot
.706 .42056 Mdot
.706 .42074 Mdot
.706 .42078 Mdot
.706 .42084 Mdot
.706 .42094 Mdot
.706 .42122 Mdot
.706 .42126 Mdot
.706 .42126 Mdot
.706 .42127 Mdot
.706 .42133 Mdot
.706 .42146 Mdot
.706 .42158 Mdot
.706 .42159 Mdot
.706 .42169 Mdot
.706 .42197 Mdot
.706 .42207 Mdot
.706 .42216 Mdot
.706 .42233 Mdot
.706 .42251 Mdot
.706 .42295 Mdot
.706 .42298 Mdot
.706 .42299 Mdot
.706 .42314 Mdot
.706 .42317 Mdot
.706 .42319 Mdot
.706 .42329 Mdot
.706 .42348 Mdot
.706 .4236 Mdot
.706 .42364 Mdot
.706 .42373 Mdot
.706 .42397 Mdot
.706 .42414 Mdot
.706 .42422 Mdot
.706 .42447 Mdot
.706 .42476 Mdot
.706 .42488 Mdot
.706 .42503 Mdot
.706 .42525 Mdot
.706 .4254 Mdot
.706 .42554 Mdot
.706 .42557 Mdot
.706 .42572 Mdot
.706 .42587 Mdot
.706 .42593 Mdot
.706 .4263 Mdot
.706 .42632 Mdot
.706 .42664 Mdot
.706 .4268 Mdot
.706 .42684 Mdot
.706 .42718 Mdot
.706 .42719 Mdot
.706 .42723 Mdot
.706 .42723 Mdot
.706 .42743 Mdot
.706 .42747 Mdot
.706 .42761 Mdot
.706 .42785 Mdot
.706 .42799 Mdot
.706 .42808 Mdot
.706 .42828 Mdot
.706 .42853 Mdot
.706 .42875 Mdot
.706 .42876 Mdot
.706 .42881 Mdot
.706 .42882 Mdot
.706 .42885 Mdot
.706 .42938 Mdot
.706 .42938 Mdot
.706 .42945 Mdot
.706 .42961 Mdot
.706 .42965 Mdot
.706 .42966 Mdot
.706 .42967 Mdot
.706 .42968 Mdot
.706 .43009 Mdot
.706 .43025 Mdot
.706 .43031 Mdot
.706 .43044 Mdot
.706 .43045 Mdot
.706 .43051 Mdot
.706 .43095 Mdot
.706 .43104 Mdot
.708 .25906 Mdot
.708 .25908 Mdot
.708 .25925 Mdot
.708 .25954 Mdot
.708 .25967 Mdot
.708 .25969 Mdot
.708 .26037 Mdot
.708 .26055 Mdot
.708 .2608 Mdot
.708 .26081 Mdot
.708 .26112 Mdot
.708 .26118 Mdot
.708 .26135 Mdot
.708 .26168 Mdot
.708 .26183 Mdot
.708 .26268 Mdot
.708 .26347 Mdot
.708 .26367 Mdot
.708 .26378 Mdot
.708 .2638 Mdot
.708 .26394 Mdot
.708 .26411 Mdot
.708 .26433 Mdot
.708 .26478 Mdot
.708 .26489 Mdot
.708 .26505 Mdot
.708 .2651 Mdot
.708 .26514 Mdot
.708 .26553 Mdot
.708 .26571 Mdot
.708 .26575 Mdot
.708 .26587 Mdot
.708 .26618 Mdot
.708 .26631 Mdot
.708 .26648 Mdot
.708 .2668 Mdot
.708 .26749 Mdot
.708 .26749 Mdot
.708 .26755 Mdot
.708 .2678 Mdot
.708 .26812 Mdot
.708 .26821 Mdot
.708 .26824 Mdot
.708 .2683 Mdot
.708 .26839 Mdot
.708 .26859 Mdot
.708 .26866 Mdot
.708 .2689 Mdot
.708 .26895 Mdot
.708 .26928 Mdot
.708 .26939 Mdot
.708 .26951 Mdot
.708 .26957 Mdot
.708 .26976 Mdot
.708 .2698 Mdot
.708 .2698 Mdot
.708 .26983 Mdot
.708 .26993 Mdot
.708 .27009 Mdot
.708 .27014 Mdot
.708 .27015 Mdot
.708 .27031 Mdot
.708 .27035 Mdot
.708 .2704 Mdot
.708 .27059 Mdot
.708 .27083 Mdot
.708 .27094 Mdot
.708 .27141 Mdot
.708 .27161 Mdot
.708 .27185 Mdot
.708 .27234 Mdot
.708 .27242 Mdot
.708 .27264 Mdot
.708 .27264 Mdot
.708 .27286 Mdot
.708 .27292 Mdot
.708 .27296 Mdot
.708 .27312 Mdot
.708 .27346 Mdot
.708 .27374 Mdot
.708 .2741 Mdot
.708 .27427 Mdot
.708 .2744 Mdot
.708 .27448 Mdot
.708 .2749 Mdot
.708 .27501 Mdot
.708 .27593 Mdot
.708 .27596 Mdot
.708 .2761 Mdot
.708 .27612 Mdot
.708 .27637 Mdot
.708 .2764 Mdot
.708 .27651 Mdot
.708 .27687 Mdot
.708 .27702 Mdot
.708 .27705 Mdot
.708 .2772 Mdot
.708 .27747 Mdot
.708 .27775 Mdot
.708 .27826 Mdot
.708 .27856 Mdot
.708 .27881 Mdot
.708 .27884 Mdot
.708 .27909 Mdot
.708 .27912 Mdot
.708 .27914 Mdot
.708 .27914 Mdot
.708 .27914 Mdot
.708 .27921 Mdot
.708 .27922 Mdot
.708 .27928 Mdot
.708 .27936 Mdot
.708 .27948 Mdot
.708 .27962 Mdot
.708 .27989 Mdot
.708 .2799 Mdot
.708 .27994 Mdot
.708 .28035 Mdot
.708 .28048 Mdot
.708 .28055 Mdot
.708 .28064 Mdot
.708 .28069 Mdot
.708 .28134 Mdot
.708 .28138 Mdot
.708 .28146 Mdot
.708 .28167 Mdot
.708 .28169 Mdot
.708 .28175 Mdot
.708 .28188 Mdot
.708 .28236 Mdot
.708 .28244 Mdot
.708 .28268 Mdot
.708 .28288 Mdot
.708 .28345 Mdot
.708 .28348 Mdot
.708 .28401 Mdot
.708 .28434 Mdot
.708 .28471 Mdot
.708 .28477 Mdot
.708 .28491 Mdot
.708 .28524 Mdot
.708 .28552 Mdot
.708 .28576 Mdot
.708 .28584 Mdot
.708 .28618 Mdot
.708 .28662 Mdot
.708 .28664 Mdot
.708 .28666 Mdot
.708 .28694 Mdot
.708 .28695 Mdot
.708 .28701 Mdot
.708 .28709 Mdot
.708 .28727 Mdot
.708 .28752 Mdot
.708 .28764 Mdot
.708 .28828 Mdot
.708 .28881 Mdot
.708 .28882 Mdot
.708 .28953 Mdot
.708 .28971 Mdot
.708 .28998 Mdot
.708 .29015 Mdot
.708 .29026 Mdot
.708 .29077 Mdot
.708 .29127 Mdot
.708 .29129 Mdot
.708 .29131 Mdot
.708 .29136 Mdot
.708 .29192 Mdot
.708 .29203 Mdot
.708 .29407 Mdot
.708 .29429 Mdot
.708 .29542 Mdot
.708 .29551 Mdot
.708 .29555 Mdot
.708 .29559 Mdot
.708 .29573 Mdot
.708 .29617 Mdot
.708 .2966 Mdot
.708 .29688 Mdot
.708 .29731 Mdot
.708 .29761 Mdot
.708 .29783 Mdot
.708 .29787 Mdot
.708 .29818 Mdot
.708 .29821 Mdot
.708 .2987 Mdot
.708 .29873 Mdot
.708 .29877 Mdot
.708 .29908 Mdot
.708 .2991 Mdot
.708 .2994 Mdot
.708 .29944 Mdot
.708 .2995 Mdot
.708 .30052 Mdot
.708 .30053 Mdot
.708 .30079 Mdot
.708 .30086 Mdot
.708 .30159 Mdot
.708 .30184 Mdot
.708 .30199 Mdot
.708 .30287 Mdot
.708 .30311 Mdot
.708 .30333 Mdot
.708 .30362 Mdot
.708 .30397 Mdot
.708 .30399 Mdot
.708 .30413 Mdot
.708 .30415 Mdot
.708 .30425 Mdot
.708 .30428 Mdot
.708 .30434 Mdot
.708 .30439 Mdot
.708 .30484 Mdot
.708 .30488 Mdot
.708 .30491 Mdot
.708 .30525 Mdot
.708 .30529 Mdot
.708 .30529 Mdot
.708 .30563 Mdot
.708 .30579 Mdot
.708 .30615 Mdot
.708 .30646 Mdot
.708 .30648 Mdot
.708 .30664 Mdot
.708 .30706 Mdot
.708 .30713 Mdot
.708 .30719 Mdot
.708 .30769 Mdot
.708 .30835 Mdot
.708 .30843 Mdot
.708 .30862 Mdot
.708 .30875 Mdot
.708 .3094 Mdot
.708 .30948 Mdot
.708 .30949 Mdot
.708 .31014 Mdot
.708 .31021 Mdot
.708 .31022 Mdot
.708 .31056 Mdot
.708 .31077 Mdot
.708 .31093 Mdot
.708 .31121 Mdot
.708 .31128 Mdot
.708 .3121 Mdot
.708 .31226 Mdot
.708 .31242 Mdot
.708 .31253 Mdot
.708 .31281 Mdot
.708 .31289 Mdot
.708 .31313 Mdot
.708 .31322 Mdot
.708 .3133 Mdot
.708 .31345 Mdot
.708 .31352 Mdot
.708 .31426 Mdot
.708 .31442 Mdot
.708 .31446 Mdot
.708 .31465 Mdot
.708 .31469 Mdot
.708 .31481 Mdot
.708 .31484 Mdot
.708 .31526 Mdot
.708 .31527 Mdot
.708 .31532 Mdot
.708 .31543 Mdot
.708 .31551 Mdot
.708 .31553 Mdot
.708 .31556 Mdot
.708 .31565 Mdot
.708 .31583 Mdot
.708 .31616 Mdot
.708 .31657 Mdot
.708 .31667 Mdot
.708 .31668 Mdot
.708 .31678 Mdot
.708 .31681 Mdot
.708 .31683 Mdot
.708 .31692 Mdot
.708 .31708 Mdot
.708 .31722 Mdot
.708 .31749 Mdot
.708 .31759 Mdot
.708 .31786 Mdot
.708 .31832 Mdot
.708 .31833 Mdot
.708 .3184 Mdot
.708 .31841 Mdot
.708 .31855 Mdot
.708 .31878 Mdot
.708 .31895 Mdot
.708 .31908 Mdot
.708 .31923 Mdot
.708 .31948 Mdot
.708 .31963 Mdot
.708 .31975 Mdot
.708 .31977 Mdot
.708 .31991 Mdot
.708 .31992 Mdot
.708 .31992 Mdot
.708 .31992 Mdot
.708 .31996 Mdot
.708 .32003 Mdot
.708 .32009 Mdot
.708 .32016 Mdot
.708 .32029 Mdot
.708 .32052 Mdot
.708 .32059 Mdot
.708 .32101 Mdot
.708 .32103 Mdot
.708 .32107 Mdot
.708 .32118 Mdot
.708 .32128 Mdot
.708 .32156 Mdot
.708 .32168 Mdot
.708 .32206 Mdot
.708 .32235 Mdot
.708 .32269 Mdot
.708 .32273 Mdot
.708 .32296 Mdot
.708 .3231 Mdot
.708 .32326 Mdot
.708 .32343 Mdot
.708 .32365 Mdot
.708 .32366 Mdot
.708 .32381 Mdot
.708 .3241 Mdot
.708 .32416 Mdot
.708 .32447 Mdot
.708 .32474 Mdot
.708 .32474 Mdot
.708 .32519 Mdot
.708 .32541 Mdot
.708 .32546 Mdot
.708 .32572 Mdot
.708 .32597 Mdot
.708 .32598 Mdot
.708 .32599 Mdot
.708 .32601 Mdot
.708 .32629 Mdot
.708 .32635 Mdot
.708 .32819 Mdot
.708 .32841 Mdot
.708 .32876 Mdot
.708 .32898 Mdot
.708 .32926 Mdot
.708 .32943 Mdot
.708 .32967 Mdot
.708 .32971 Mdot
.708 .32987 Mdot
.708 .33002 Mdot
.708 .33004 Mdot
.708 .33007 Mdot
.708 .33071 Mdot
.708 .33075 Mdot
.708 .33124 Mdot
.708 .33131 Mdot
.708 .33198 Mdot
.708 .33231 Mdot
.708 .33239 Mdot
.708 .33248 Mdot
.708 .33251 Mdot
.708 .33294 Mdot
.708 .33296 Mdot
.708 .33296 Mdot
.708 .33313 Mdot
.708 .33339 Mdot
.708 .33354 Mdot
.708 .33384 Mdot
.708 .33391 Mdot
.708 .33453 Mdot
.708 .33501 Mdot
.708 .33505 Mdot
.708 .33541 Mdot
.708 .33542 Mdot
.708 .33559 Mdot
.708 .33569 Mdot
.708 .33577 Mdot
.708 .33636 Mdot
.708 .33643 Mdot
.708 .33657 Mdot
.708 .33675 Mdot
.708 .33687 Mdot
.708 .33691 Mdot
.708 .33706 Mdot
.708 .33743 Mdot
.708 .33753 Mdot
.708 .33763 Mdot
.708 .33794 Mdot
.708 .33796 Mdot
.708 .33807 Mdot
.708 .33808 Mdot
.708 .33813 Mdot
.708 .33821 Mdot
.708 .33838 Mdot
.708 .33858 Mdot
.708 .33864 Mdot
.708 .33864 Mdot
.708 .33869 Mdot
.708 .33872 Mdot
.708 .33909 Mdot
.708 .33923 Mdot
.708 .33946 Mdot
.708 .33957 Mdot
.708 .33969 Mdot
.708 .33984 Mdot
.708 .34025 Mdot
.708 .34034 Mdot
.708 .34037 Mdot
.708 .34044 Mdot
.708 .3408 Mdot
.708 .34081 Mdot
.708 .34088 Mdot
.708 .34093 Mdot
.708 .34107 Mdot
.708 .34132 Mdot
.708 .34147 Mdot
.708 .34165 Mdot
.708 .34177 Mdot
.708 .34184 Mdot
.708 .34201 Mdot
.708 .34211 Mdot
.708 .34212 Mdot
.708 .34266 Mdot
.708 .34266 Mdot
.708 .34315 Mdot
.708 .34327 Mdot
.708 .34328 Mdot
.708 .34467 Mdot
.708 .34514 Mdot
.708 .34522 Mdot
.708 .3453 Mdot
.708 .34532 Mdot
.708 .34564 Mdot
.708 .3459 Mdot
.708 .34652 Mdot
.708 .34676 Mdot
.708 .34684 Mdot
.708 .3472 Mdot
.708 .34723 Mdot
.708 .3478 Mdot
.708 .34798 Mdot
.708 .34807 Mdot
.708 .34812 Mdot
.708 .34816 Mdot
.708 .34849 Mdot
.708 .34865 Mdot
.708 .34871 Mdot
.708 .34873 Mdot
.708 .34931 Mdot
.708 .34934 Mdot
.708 .34938 Mdot
.708 .34962 Mdot
.708 .35006 Mdot
.708 .35019 Mdot
.708 .3504 Mdot
.708 .35046 Mdot
.708 .35067 Mdot
.708 .35067 Mdot
.708 .35071 Mdot
.708 .35093 Mdot
.708 .35132 Mdot
.708 .35133 Mdot
.708 .3516 Mdot
.708 .35283 Mdot
.708 .35287 Mdot
.708 .35292 Mdot
.708 .35388 Mdot
.708 .35416 Mdot
.708 .35432 Mdot
.708 .35458 Mdot
.708 .35462 Mdot
.708 .35491 Mdot
.708 .35493 Mdot
.708 .35495 Mdot
.708 .35535 Mdot
.708 .35548 Mdot
.708 .35559 Mdot
.708 .35592 Mdot
.708 .35605 Mdot
.708 .35667 Mdot
.708 .35669 Mdot
.708 .35719 Mdot
.708 .35733 Mdot
.708 .35741 Mdot
.708 .35754 Mdot
.708 .35771 Mdot
.708 .35772 Mdot
.708 .35793 Mdot
.708 .35799 Mdot
.708 .35891 Mdot
.708 .35895 Mdot
.708 .3591 Mdot
.708 .35911 Mdot
.708 .35921 Mdot
.708 .35924 Mdot
.708 .3598 Mdot
.708 .3598 Mdot
.708 .35987 Mdot
.708 .36014 Mdot
.708 .36018 Mdot
.708 .36071 Mdot
.708 .36073 Mdot
.708 .36093 Mdot
.708 .36097 Mdot
.708 .36098 Mdot
.708 .36137 Mdot
.708 .36139 Mdot
.708 .36146 Mdot
.708 .36147 Mdot
.708 .36157 Mdot
.708 .3616 Mdot
.708 .36225 Mdot
.708 .3623 Mdot
.708 .36244 Mdot
.708 .36245 Mdot
.708 .36257 Mdot
.708 .36266 Mdot
.708 .36272 Mdot
.708 .36282 Mdot
.708 .36317 Mdot
.708 .36318 Mdot
.708 .36362 Mdot
.708 .36372 Mdot
.708 .36394 Mdot
.708 .36402 Mdot
.708 .36412 Mdot
.708 .3644 Mdot
.708 .36442 Mdot
.708 .36442 Mdot
.708 .36463 Mdot
.708 .36466 Mdot
.708 .36484 Mdot
.708 .36496 Mdot
.708 .36516 Mdot
.708 .36583 Mdot
.708 .36587 Mdot
.708 .36589 Mdot
.708 .36677 Mdot
.708 .36696 Mdot
.708 .36696 Mdot
.708 .36724 Mdot
.708 .36739 Mdot
.708 .36742 Mdot
.708 .36742 Mdot
.708 .36757 Mdot
.708 .36761 Mdot
.708 .36776 Mdot
.708 .36785 Mdot
.708 .36817 Mdot
.708 .36833 Mdot
.708 .36836 Mdot
.708 .36838 Mdot
.708 .36879 Mdot
.708 .36881 Mdot
.708 .36885 Mdot
.708 .36896 Mdot
.708 .36919 Mdot
.708 .36922 Mdot
.708 .36926 Mdot
.708 .36932 Mdot
.708 .36945 Mdot
.708 .36985 Mdot
.708 .36987 Mdot
.708 .37012 Mdot
.708 .37018 Mdot
.708 .37035 Mdot
.708 .37079 Mdot
.708 .37098 Mdot
.708 .3712 Mdot
.708 .37121 Mdot
.708 .37127 Mdot
.708 .37133 Mdot
.708 .37166 Mdot
.708 .37264 Mdot
.708 .37265 Mdot
.708 .37274 Mdot
.708 .37308 Mdot
.708 .37308 Mdot
.708 .37346 Mdot
.708 .37346 Mdot
.708 .37354 Mdot
.708 .37366 Mdot
.708 .37371 Mdot
.708 .37379 Mdot
.708 .37392 Mdot
.708 .37402 Mdot
.708 .3742 Mdot
.708 .3743 Mdot
.708 .37433 Mdot
.708 .37439 Mdot
.708 .37439 Mdot
.708 .37465 Mdot
.708 .37469 Mdot
.708 .37472 Mdot
.708 .37478 Mdot
.708 .37507 Mdot
.708 .37518 Mdot
.708 .37526 Mdot
.708 .37534 Mdot
.708 .3755 Mdot
.708 .3756 Mdot
.708 .37586 Mdot
.708 .37588 Mdot
.708 .37592 Mdot
.708 .37592 Mdot
.708 .37596 Mdot
.708 .3761 Mdot
.708 .37622 Mdot
.708 .37628 Mdot
.708 .37631 Mdot
.708 .37632 Mdot
.708 .3764 Mdot
.708 .37641 Mdot
.708 .37663 Mdot
.708 .3767 Mdot
.708 .37677 Mdot
.708 .37703 Mdot
.708 .37714 Mdot
.708 .37717 Mdot
.708 .37725 Mdot
.708 .37738 Mdot
.708 .37748 Mdot
.708 .37753 Mdot
.708 .37794 Mdot
.708 .378 Mdot
.708 .37807 Mdot
.708 .37819 Mdot
.708 .3782 Mdot
.708 .37845 Mdot
.708 .37848 Mdot
.708 .37882 Mdot
.708 .37926 Mdot
.708 .37931 Mdot
.708 .37952 Mdot
.708 .37963 Mdot
.708 .37981 Mdot
.708 .37993 Mdot
.708 .37993 Mdot
.708 .37994 Mdot
.708 .38024 Mdot
.708 .38026 Mdot
.708 .38033 Mdot
.708 .38039 Mdot
.708 .38062 Mdot
.708 .38109 Mdot
.708 .38114 Mdot
.708 .38149 Mdot
.708 .38152 Mdot
.708 .38197 Mdot
.708 .38199 Mdot
.708 .382 Mdot
.708 .38211 Mdot
.708 .38223 Mdot
.708 .38225 Mdot
.708 .38242 Mdot
.708 .38254 Mdot
.708 .38289 Mdot
.708 .38314 Mdot
.708 .3833 Mdot
.708 .3846 Mdot
.708 .38464 Mdot
.708 .38484 Mdot
.708 .38485 Mdot
.708 .38486 Mdot
.708 .38487 Mdot
.708 .38504 Mdot
.708 .38522 Mdot
.708 .38526 Mdot
.708 .38542 Mdot
.708 .38573 Mdot
.708 .38573 Mdot
.708 .38592 Mdot
.708 .38614 Mdot
.708 .38619 Mdot
.708 .38639 Mdot
.708 .3865 Mdot
.708 .3865 Mdot
.708 .38666 Mdot
.708 .38678 Mdot
.708 .38689 Mdot
.708 .38699 Mdot
.708 .38716 Mdot
.708 .38718 Mdot
.708 .38742 Mdot
.708 .38762 Mdot
.708 .38789 Mdot
.708 .38798 Mdot
.708 .38818 Mdot
.708 .38825 Mdot
.708 .38832 Mdot
.708 .38835 Mdot
.708 .38837 Mdot
.708 .38867 Mdot
.708 .38871 Mdot
.708 .38888 Mdot
.708 .38897 Mdot
.708 .38902 Mdot
.708 .38906 Mdot
.708 .38911 Mdot
.708 .38914 Mdot
.708 .38914 Mdot
.708 .38914 Mdot
.708 .38915 Mdot
.708 .38925 Mdot
.708 .38926 Mdot
.708 .38934 Mdot
.708 .38945 Mdot
.708 .38963 Mdot
.708 .38973 Mdot
.708 .38982 Mdot
.708 .38994 Mdot
.708 .39011 Mdot
.708 .3902 Mdot
.708 .39021 Mdot
.708 .39026 Mdot
.708 .39027 Mdot
.708 .39059 Mdot
.708 .39078 Mdot
.708 .39085 Mdot
.708 .39104 Mdot
.708 .39114 Mdot
.708 .39126 Mdot
.708 .39132 Mdot
.708 .39133 Mdot
.708 .39135 Mdot
.708 .39143 Mdot
.708 .39143 Mdot
.708 .39151 Mdot
.708 .39179 Mdot
.708 .39203 Mdot
.708 .39215 Mdot
.708 .39222 Mdot
.708 .39223 Mdot
.708 .39225 Mdot
.708 .39231 Mdot
.708 .39238 Mdot
.708 .39242 Mdot
.708 .39243 Mdot
.708 .39273 Mdot
.708 .39275 Mdot
.708 .39283 Mdot
.708 .39286 Mdot
.708 .39299 Mdot
.708 .39302 Mdot
.708 .39314 Mdot
.708 .39366 Mdot
.708 .3937 Mdot
.708 .39381 Mdot
.708 .39387 Mdot
.708 .39393 Mdot
.708 .3941 Mdot
.708 .39416 Mdot
.708 .39436 Mdot
.708 .39443 Mdot
.708 .39455 Mdot
.708 .39466 Mdot
.708 .39524 Mdot
.708 .39529 Mdot
.708 .39549 Mdot
.708 .3956 Mdot
.708 .39575 Mdot
.708 .39599 Mdot
.708 .396 Mdot
.708 .39604 Mdot
.708 .3965 Mdot
.708 .39651 Mdot
.708 .39657 Mdot
.708 .39703 Mdot
.708 .39712 Mdot
.708 .39725 Mdot
.708 .39731 Mdot
.708 .39778 Mdot
.708 .39813 Mdot
.708 .39817 Mdot
.708 .39822 Mdot
.708 .39852 Mdot
.708 .39863 Mdot
.708 .39865 Mdot
.708 .39886 Mdot
.708 .39912 Mdot
.708 .39923 Mdot
.708 .39947 Mdot
.708 .39947 Mdot
.708 .39949 Mdot
.708 .39974 Mdot
.708 .39976 Mdot
.708 .39979 Mdot
.708 .4001 Mdot
.708 .40014 Mdot
.708 .40018 Mdot
.708 .40021 Mdot
.708 .40027 Mdot
.708 .40029 Mdot
.708 .40039 Mdot
.708 .4004 Mdot
.708 .40065 Mdot
.708 .40085 Mdot
.708 .40101 Mdot
.708 .40118 Mdot
.708 .4018 Mdot
.708 .4019 Mdot
.708 .40208 Mdot
.708 .4026 Mdot
.708 .40265 Mdot
.708 .40283 Mdot
.708 .40284 Mdot
.708 .40356 Mdot
.708 .4036 Mdot
.708 .40363 Mdot
.708 .40384 Mdot
.708 .40386 Mdot
.708 .40407 Mdot
.708 .4041 Mdot
.708 .40412 Mdot
.708 .40447 Mdot
.708 .40449 Mdot
.708 .40471 Mdot
.708 .40474 Mdot
.708 .40489 Mdot
.708 .4051 Mdot
.708 .40541 Mdot
.708 .40561 Mdot
.708 .40591 Mdot
.708 .40622 Mdot
.708 .40632 Mdot
.708 .40635 Mdot
.708 .40638 Mdot
.708 .40644 Mdot
.708 .40724 Mdot
.708 .40739 Mdot
.708 .40883 Mdot
.708 .40891 Mdot
.708 .40931 Mdot
.708 .40934 Mdot
.708 .40936 Mdot
.708 .40937 Mdot
.708 .40972 Mdot
.708 .41008 Mdot
.708 .41016 Mdot
.708 .41028 Mdot
.708 .41048 Mdot
.708 .4106 Mdot
.708 .4111 Mdot
.708 .41111 Mdot
.708 .41148 Mdot
.708 .41193 Mdot
.708 .41202 Mdot
.708 .4122 Mdot
.708 .41232 Mdot
.708 .41238 Mdot
.708 .41242 Mdot
.708 .41243 Mdot
.708 .41263 Mdot
.708 .41264 Mdot
.708 .41265 Mdot
.708 .41296 Mdot
.708 .4132 Mdot
.708 .41326 Mdot
.708 .41343 Mdot
.708 .41363 Mdot
.708 .41386 Mdot
.708 .41396 Mdot
.708 .414 Mdot
.708 .41426 Mdot
.708 .41449 Mdot
.708 .41487 Mdot
.708 .4149 Mdot
.708 .4153 Mdot
.708 .41543 Mdot
.708 .41561 Mdot
.708 .41566 Mdot
.708 .416 Mdot
.708 .4161 Mdot
.708 .41614 Mdot
.708 .41615 Mdot
.708 .4163 Mdot
.708 .41636 Mdot
.708 .41639 Mdot
.708 .41684 Mdot
.708 .41688 Mdot
.708 .41694 Mdot
.708 .41699 Mdot
.708 .41708 Mdot
.708 .41737 Mdot
.708 .4174 Mdot
.708 .41741 Mdot
.708 .4176 Mdot
.708 .41769 Mdot
.708 .41778 Mdot
.708 .41784 Mdot
.708 .41788 Mdot
.708 .41788 Mdot
.708 .41793 Mdot
.708 .41794 Mdot
.708 .41794 Mdot
.708 .41795 Mdot
.708 .41798 Mdot
.708 .41815 Mdot
.708 .41817 Mdot
.708 .41835 Mdot
.708 .41856 Mdot
.708 .41892 Mdot
.708 .41911 Mdot
.708 .41931 Mdot
.708 .41941 Mdot
.708 .41943 Mdot
.708 .41954 Mdot
.708 .41979 Mdot
.708 .41987 Mdot
.708 .41989 Mdot
.708 .42007 Mdot
.708 .42008 Mdot
.708 .42018 Mdot
.708 .4202 Mdot
.708 .42085 Mdot
.708 .42093 Mdot
.708 .42123 Mdot
.708 .42129 Mdot
.708 .42137 Mdot
.708 .4215 Mdot
.708 .42175 Mdot
.708 .42195 Mdot
.708 .42219 Mdot
.708 .4223 Mdot
.708 .42233 Mdot
.708 .42237 Mdot
.708 .42252 Mdot
.708 .42253 Mdot
.708 .42268 Mdot
.708 .42274 Mdot
.708 .42308 Mdot
.708 .42325 Mdot
.708 .4234 Mdot
.708 .42373 Mdot
.708 .4238 Mdot
.708 .42398 Mdot
.708 .42411 Mdot
.708 .42414 Mdot
.708 .42418 Mdot
.708 .42428 Mdot
.708 .42429 Mdot
.708 .42433 Mdot
.708 .42444 Mdot
.708 .42451 Mdot
.708 .42453 Mdot
.708 .42453 Mdot
.708 .42456 Mdot
.708 .42469 Mdot
.708 .42474 Mdot
.708 .42482 Mdot
.708 .4249 Mdot
.708 .42513 Mdot
.708 .42517 Mdot
.708 .42534 Mdot
.708 .42539 Mdot
.708 .42553 Mdot
.708 .42559 Mdot
.708 .42563 Mdot
.708 .42566 Mdot
.708 .42572 Mdot
.708 .42595 Mdot
.708 .42612 Mdot
.708 .42616 Mdot
.708 .42617 Mdot
.708 .42665 Mdot
.708 .42688 Mdot
.708 .427 Mdot
.708 .42709 Mdot
.708 .42731 Mdot
.708 .42739 Mdot
.708 .42742 Mdot
.708 .42755 Mdot
.708 .42782 Mdot
.708 .42785 Mdot
.708 .42789 Mdot
.708 .428 Mdot
.708 .42808 Mdot
.708 .4284 Mdot
.708 .42855 Mdot
.708 .42867 Mdot
.708 .42877 Mdot
.708 .42878 Mdot
.708 .42886 Mdot
.708 .429 Mdot
.708 .42956 Mdot
.708 .43016 Mdot
.708 .43026 Mdot
.708 .4305 Mdot
.708 .43062 Mdot
.708 .43067 Mdot
.708 .43088 Mdot
.708 .43089 Mdot
.708 .43107 Mdot
.708 .43119 Mdot
.708 .43167 Mdot
.708 .43169 Mdot
.708 .43178 Mdot
.708 .43199 Mdot
.708 .43211 Mdot
.708 .43212 Mdot
.71 .25815 Mdot
.71 .25835 Mdot
.71 .25835 Mdot
.71 .25854 Mdot
.71 .25854 Mdot
.71 .25922 Mdot
.71 .25951 Mdot
.71 .26013 Mdot
.71 .26015 Mdot
.71 .26022 Mdot
.71 .26056 Mdot
.71 .2608 Mdot
.71 .26087 Mdot
.71 .26119 Mdot
.71 .26142 Mdot
.71 .26171 Mdot
.71 .26172 Mdot
.71 .26191 Mdot
.71 .26289 Mdot
.71 .26293 Mdot
.71 .26352 Mdot
.71 .26368 Mdot
.71 .26386 Mdot
.71 .26391 Mdot
.71 .26455 Mdot
.71 .26486 Mdot
.71 .26499 Mdot
.71 .26518 Mdot
.71 .2654 Mdot
.71 .26565 Mdot
.71 .26577 Mdot
.71 .26585 Mdot
.71 .26586 Mdot
.71 .2671 Mdot
.71 .26727 Mdot
.71 .26753 Mdot
.71 .26757 Mdot
.71 .26759 Mdot
.71 .26787 Mdot
.71 .26791 Mdot
.71 .26822 Mdot
.71 .26825 Mdot
.71 .26836 Mdot
.71 .26844 Mdot
.71 .26855 Mdot
.71 .26857 Mdot
.71 .26922 Mdot
.71 .26942 Mdot
.71 .26946 Mdot
.71 .2695 Mdot
.71 .26965 Mdot
.71 .2698 Mdot
.71 .26989 Mdot
.71 .26994 Mdot
.71 .27074 Mdot
.71 .27099 Mdot
.71 .27101 Mdot
.71 .27118 Mdot
.71 .27139 Mdot
.71 .2714 Mdot
.71 .2714 Mdot
.71 .27152 Mdot
.71 .27185 Mdot
.71 .27199 Mdot
.71 .27207 Mdot
.71 .27226 Mdot
.71 .2723 Mdot
.71 .27258 Mdot
.71 .27272 Mdot
.71 .27287 Mdot
.71 .27299 Mdot
.71 .27323 Mdot
.71 .27326 Mdot
.71 .27335 Mdot
.71 .27355 Mdot
.71 .27392 Mdot
.71 .2746 Mdot
.71 .2749 Mdot
.71 .27522 Mdot
.71 .27523 Mdot
.71 .2754 Mdot
.71 .27541 Mdot
.71 .27581 Mdot
.71 .27592 Mdot
.71 .27593 Mdot
.71 .27602 Mdot
.71 .27606 Mdot
.71 .27607 Mdot
.71 .27608 Mdot
.71 .27618 Mdot
.71 .27633 Mdot
.71 .27662 Mdot
.71 .27673 Mdot
.71 .2778 Mdot
.71 .27786 Mdot
.71 .27793 Mdot
.71 .27794 Mdot
.71 .27836 Mdot
.71 .27851 Mdot
.71 .27855 Mdot
.71 .27857 Mdot
.71 .2793 Mdot
.71 .27936 Mdot
.71 .27943 Mdot
.71 .27953 Mdot
.71 .27989 Mdot
.71 .28003 Mdot
.71 .28015 Mdot
.71 .28019 Mdot
.71 .28035 Mdot
.71 .2804 Mdot
.71 .28087 Mdot
.71 .281 Mdot
.71 .28121 Mdot
.71 .28121 Mdot
.71 .28187 Mdot
.71 .28188 Mdot
.71 .2819 Mdot
.71 .28204 Mdot
.71 .2822 Mdot
.71 .28241 Mdot
.71 .2826 Mdot
.71 .28284 Mdot
.71 .28377 Mdot
.71 .28411 Mdot
.71 .28418 Mdot
.71 .28428 Mdot
.71 .28466 Mdot
.71 .2864 Mdot
.71 .28641 Mdot
.71 .28652 Mdot
.71 .28673 Mdot
.71 .28679 Mdot
.71 .28688 Mdot
.71 .28721 Mdot
.71 .28727 Mdot
.71 .28741 Mdot
.71 .28773 Mdot
.71 .28838 Mdot
.71 .2884 Mdot
.71 .28842 Mdot
.71 .28858 Mdot
.71 .28886 Mdot
.71 .28888 Mdot
.71 .28903 Mdot
.71 .28903 Mdot
.71 .28943 Mdot
.71 .28947 Mdot
.71 .28948 Mdot
.71 .28968 Mdot
.71 .28985 Mdot
.71 .29002 Mdot
.71 .29008 Mdot
.71 .29041 Mdot
.71 .29053 Mdot
.71 .29104 Mdot
.71 .29117 Mdot
.71 .29121 Mdot
.71 .29145 Mdot
.71 .29149 Mdot
.71 .29157 Mdot
.71 .29181 Mdot
.71 .2921 Mdot
.71 .29213 Mdot
.71 .29214 Mdot
.71 .2922 Mdot
.71 .29236 Mdot
.71 .29262 Mdot
.71 .29276 Mdot
.71 .29288 Mdot
.71 .29292 Mdot
.71 .29294 Mdot
.71 .29306 Mdot
.71 .29308 Mdot
.71 .29314 Mdot
.71 .29374 Mdot
.71 .29422 Mdot
.71 .29423 Mdot
.71 .29436 Mdot
.71 .29445 Mdot
.71 .29494 Mdot
.71 .29501 Mdot
.71 .29528 Mdot
.71 .29544 Mdot
.71 .29631 Mdot
.71 .29654 Mdot
.71 .29721 Mdot
.71 .29733 Mdot
.71 .29769 Mdot
.71 .29802 Mdot
.71 .29819 Mdot
.71 .29842 Mdot
.71 .29845 Mdot
.71 .29853 Mdot
.71 .29933 Mdot
.71 .29934 Mdot
.71 .29964 Mdot
.71 .29968 Mdot
.71 .29971 Mdot
.71 .30024 Mdot
.71 .30029 Mdot
.71 .30051 Mdot
.71 .30056 Mdot
.71 .30057 Mdot
.71 .30059 Mdot
.71 .30064 Mdot
.71 .30064 Mdot
.71 .3009 Mdot
.71 .30099 Mdot
.71 .30115 Mdot
.71 .3013 Mdot
.71 .30182 Mdot
.71 .30196 Mdot
.71 .30197 Mdot
.71 .3023 Mdot
.71 .30245 Mdot
.71 .30259 Mdot
.71 .30288 Mdot
.71 .30299 Mdot
.71 .30309 Mdot
.71 .30363 Mdot
.71 .30368 Mdot
.71 .30375 Mdot
.71 .30384 Mdot
.71 .30396 Mdot
.71 .30435 Mdot
.71 .30439 Mdot
.71 .30446 Mdot
.71 .30461 Mdot
.71 .30464 Mdot
.71 .30477 Mdot
.71 .30493 Mdot
.71 .30574 Mdot
.71 .30586 Mdot
.71 .30606 Mdot
.71 .30613 Mdot
.71 .3066 Mdot
.71 .30662 Mdot
.71 .30768 Mdot
.71 .30769 Mdot
.71 .30783 Mdot
.71 .30795 Mdot
.71 .30814 Mdot
.71 .30843 Mdot
.71 .30846 Mdot
.71 .30847 Mdot
.71 .30878 Mdot
.71 .30892 Mdot
.71 .30911 Mdot
.71 .30926 Mdot
.71 .30936 Mdot
.71 .30994 Mdot
.71 .31004 Mdot
.71 .31013 Mdot
.71 .31114 Mdot
.71 .31129 Mdot
.71 .31181 Mdot
.71 .31229 Mdot
.71 .31231 Mdot
.71 .3126 Mdot
.71 .31268 Mdot
.71 .31311 Mdot
.71 .31343 Mdot
.71 .31372 Mdot
.71 .31376 Mdot
.71 .31376 Mdot
.71 .31438 Mdot
.71 .31459 Mdot
.71 .31461 Mdot
.71 .31495 Mdot
.71 .3151 Mdot
.71 .31511 Mdot
.71 .31553 Mdot
.71 .31557 Mdot
.71 .31579 Mdot
.71 .31618 Mdot
.71 .31632 Mdot
.71 .31651 Mdot
.71 .31651 Mdot
.71 .31657 Mdot
.71 .31674 Mdot
.71 .31684 Mdot
.71 .31696 Mdot
.71 .31716 Mdot
.71 .31724 Mdot
.71 .3173 Mdot
.71 .31748 Mdot
.71 .31776 Mdot
.71 .31841 Mdot
.71 .3185 Mdot
.71 .31869 Mdot
.71 .31882 Mdot
.71 .31895 Mdot
.71 .31975 Mdot
.71 .31996 Mdot
.71 .32004 Mdot
.71 .32043 Mdot
.71 .32046 Mdot
.71 .32049 Mdot
.71 .32054 Mdot
.71 .32072 Mdot
.71 .32079 Mdot
.71 .32085 Mdot
.71 .32127 Mdot
.71 .32137 Mdot
.71 .3217 Mdot
.71 .32172 Mdot
.71 .32179 Mdot
.71 .32186 Mdot
.71 .32197 Mdot
.71 .32265 Mdot
.71 .32281 Mdot
.71 .32289 Mdot
.71 .32395 Mdot
.71 .32401 Mdot
.71 .32414 Mdot
.71 .32419 Mdot
.71 .32435 Mdot
.71 .32461 Mdot
.71 .32493 Mdot
.71 .32495 Mdot
.71 .32525 Mdot
.71 .32525 Mdot
.71 .32545 Mdot
.71 .32547 Mdot
.71 .32548 Mdot
.71 .32558 Mdot
.71 .32575 Mdot
.71 .32578 Mdot
.71 .32594 Mdot
.71 .326 Mdot
.71 .32679 Mdot
.71 .3268 Mdot
.71 .32683 Mdot
.71 .3269 Mdot
.71 .3271 Mdot
.71 .32716 Mdot
.71 .32718 Mdot
.71 .32783 Mdot
.71 .32843 Mdot
.71 .32979 Mdot
.71 .33055 Mdot
.71 .33084 Mdot
.71 .33095 Mdot
.71 .33098 Mdot
.71 .33101 Mdot
.71 .33114 Mdot
.71 .33118 Mdot
.71 .33126 Mdot
.71 .33134 Mdot
.71 .33159 Mdot
.71 .33167 Mdot
.71 .33183 Mdot
.71 .33191 Mdot
.71 .33223 Mdot
.71 .33249 Mdot
.71 .33255 Mdot
.71 .33285 Mdot
.71 .33291 Mdot
.71 .33306 Mdot
.71 .33314 Mdot
.71 .33354 Mdot
.71 .3336 Mdot
.71 .3337 Mdot
.71 .33373 Mdot
.71 .33397 Mdot
.71 .33398 Mdot
.71 .3345 Mdot
.71 .33451 Mdot
.71 .33458 Mdot
.71 .33464 Mdot
.71 .33487 Mdot
.71 .33489 Mdot
.71 .3349 Mdot
.71 .33505 Mdot
.71 .33533 Mdot
.71 .33567 Mdot
.71 .33572 Mdot
.71 .33622 Mdot
.71 .33629 Mdot
.71 .33679 Mdot
.71 .33694 Mdot
.71 .33782 Mdot
.71 .33793 Mdot
.71 .33794 Mdot
.71 .33811 Mdot
.71 .33841 Mdot
.71 .33872 Mdot
.71 .33879 Mdot
.71 .33888 Mdot
.71 .33888 Mdot
.71 .33891 Mdot
.71 .3391 Mdot
.71 .33927 Mdot
.71 .33982 Mdot
.71 .34049 Mdot
.71 .34059 Mdot
.71 .34063 Mdot
.71 .34086 Mdot
.71 .34097 Mdot
.71 .341 Mdot
.71 .34124 Mdot
.71 .34129 Mdot
.71 .3415 Mdot
.71 .34192 Mdot
.71 .34201 Mdot
.71 .34205 Mdot
.71 .34257 Mdot
.71 .3426 Mdot
.71 .34269 Mdot
.71 .3429 Mdot
.71 .34306 Mdot
.71 .34322 Mdot
.71 .34356 Mdot
.71 .34398 Mdot
.71 .34404 Mdot
.71 .34414 Mdot
.71 .34599 Mdot
.71 .34606 Mdot
.71 .34607 Mdot
.71 .3462 Mdot
.71 .34623 Mdot
.71 .34636 Mdot
.71 .34648 Mdot
.71 .34684 Mdot
.71 .34699 Mdot
.71 .34701 Mdot
.71 .34736 Mdot
.71 .34742 Mdot
.71 .34754 Mdot
.71 .34781 Mdot
.71 .34781 Mdot
.71 .34784 Mdot
.71 .34807 Mdot
.71 .34869 Mdot
.71 .34894 Mdot
.71 .34901 Mdot
.71 .34951 Mdot
.71 .34998 Mdot
.71 .34999 Mdot
.71 .35009 Mdot
.71 .35044 Mdot
.71 .35077 Mdot
.71 .35101 Mdot
.71 .35127 Mdot
.71 .35155 Mdot
.71 .35197 Mdot
.71 .35205 Mdot
.71 .3525 Mdot
.71 .35253 Mdot
.71 .35258 Mdot
.71 .3535 Mdot
.71 .3536 Mdot
.71 .35369 Mdot
.71 .35392 Mdot
.71 .35401 Mdot
.71 .35418 Mdot
.71 .35427 Mdot
.71 .3544 Mdot
.71 .35442 Mdot
.71 .35496 Mdot
.71 .355 Mdot
.71 .35525 Mdot
.71 .35548 Mdot
.71 .35599 Mdot
.71 .35612 Mdot
.71 .35626 Mdot
.71 .35673 Mdot
.71 .35675 Mdot
.71 .35677 Mdot
.71 .35723 Mdot
.71 .35728 Mdot
.71 .35732 Mdot
.71 .35744 Mdot
.71 .35756 Mdot
.71 .35761 Mdot
.71 .35795 Mdot
.71 .35809 Mdot
.71 .35846 Mdot
.71 .35884 Mdot
.71 .35885 Mdot
.71 .35907 Mdot
.71 .35912 Mdot
.71 .35943 Mdot
.71 .3595 Mdot
.71 .35969 Mdot
.71 .35987 Mdot
.71 .35999 Mdot
.71 .36001 Mdot
.71 .3602 Mdot
.71 .36029 Mdot
.71 .36039 Mdot
.71 .36044 Mdot
.71 .36046 Mdot
.71 .36055 Mdot
.71 .3606 Mdot
.71 .36067 Mdot
.71 .36068 Mdot
.71 .36072 Mdot
.71 .36074 Mdot
.71 .36081 Mdot
.71 .36082 Mdot
.71 .36094 Mdot
.71 .36095 Mdot
.71 .361 Mdot
.71 .36101 Mdot
.71 .3611 Mdot
.71 .36113 Mdot
.71 .3612 Mdot
.71 .36121 Mdot
.71 .36131 Mdot
.71 .36138 Mdot
.71 .36151 Mdot
.71 .36153 Mdot
.71 .36161 Mdot
.71 .36174 Mdot
.71 .36187 Mdot
.71 .36192 Mdot
.71 .36214 Mdot
.71 .36217 Mdot
.71 .36233 Mdot
.71 .36234 Mdot
.71 .3626 Mdot
.71 .36286 Mdot
.71 .36296 Mdot
.71 .3632 Mdot
.71 .36324 Mdot
.71 .36333 Mdot
.71 .36341 Mdot
.71 .36344 Mdot
.71 .36347 Mdot
.71 .36379 Mdot
.71 .36381 Mdot
.71 .36382 Mdot
.71 .36416 Mdot
.71 .36425 Mdot
.71 .36434 Mdot
.71 .3647 Mdot
.71 .36487 Mdot
.71 .36504 Mdot
.71 .36507 Mdot
.71 .36545 Mdot
.71 .36546 Mdot
.71 .36555 Mdot
.71 .36562 Mdot
.71 .36574 Mdot
.71 .3658 Mdot
.71 .36597 Mdot
.71 .36602 Mdot
.71 .3661 Mdot
.71 .36674 Mdot
.71 .36678 Mdot
.71 .3668 Mdot
.71 .36712 Mdot
.71 .36718 Mdot
.71 .36747 Mdot
.71 .36766 Mdot
.71 .36785 Mdot
.71 .36802 Mdot
.71 .36825 Mdot
.71 .3685 Mdot
.71 .36857 Mdot
.71 .36858 Mdot
.71 .36891 Mdot
.71 .36926 Mdot
.71 .36931 Mdot
.71 .36948 Mdot
.71 .36992 Mdot
.71 .37008 Mdot
.71 .37011 Mdot
.71 .37011 Mdot
.71 .37029 Mdot
.71 .37038 Mdot
.71 .37042 Mdot
.71 .37067 Mdot
.71 .37068 Mdot
.71 .37079 Mdot
.71 .37104 Mdot
.71 .37112 Mdot
.71 .37121 Mdot
.71 .37124 Mdot
.71 .37133 Mdot
.71 .37134 Mdot
.71 .37139 Mdot
.71 .37269 Mdot
.71 .37276 Mdot
.71 .3728 Mdot
.71 .3731 Mdot
.71 .37334 Mdot
.71 .37345 Mdot
.71 .37356 Mdot
.71 .37371 Mdot
.71 .37377 Mdot
.71 .37379 Mdot
.71 .37416 Mdot
.71 .37419 Mdot
.71 .37425 Mdot
.71 .37455 Mdot
.71 .37469 Mdot
.71 .37473 Mdot
.71 .3749 Mdot
.71 .37492 Mdot
.71 .375 Mdot
.71 .37516 Mdot
.71 .37519 Mdot
.71 .37526 Mdot
.71 .37573 Mdot
.71 .37612 Mdot
.71 .37624 Mdot
.71 .37637 Mdot
.71 .37639 Mdot
.71 .37639 Mdot
.71 .37646 Mdot
.71 .37651 Mdot
.71 .37672 Mdot
.71 .37694 Mdot
.71 .37705 Mdot
.71 .37706 Mdot
.71 .37714 Mdot
.71 .37776 Mdot
.71 .37787 Mdot
.71 .37822 Mdot
.71 .37827 Mdot
.71 .37862 Mdot
.71 .37865 Mdot
.71 .37889 Mdot
.71 .37909 Mdot
.71 .3792 Mdot
.71 .3792 Mdot
.71 .37921 Mdot
.71 .37938 Mdot
.71 .37942 Mdot
.71 .37947 Mdot
.71 .37947 Mdot
.71 .37984 Mdot
.71 .37985 Mdot
.71 .38002 Mdot
.71 .38004 Mdot
.71 .38011 Mdot
.71 .38015 Mdot
.71 .38043 Mdot
.71 .38049 Mdot
.71 .3806 Mdot
.71 .38064 Mdot
.71 .38085 Mdot
.71 .38089 Mdot
.71 .38108 Mdot
.71 .3813 Mdot
.71 .38136 Mdot
.71 .38147 Mdot
.71 .38152 Mdot
.71 .3817 Mdot
.71 .38176 Mdot
.71 .38181 Mdot
.71 .38184 Mdot
.71 .38194 Mdot
.71 .38196 Mdot
.71 .38198 Mdot
.71 .38206 Mdot
.71 .38226 Mdot
.71 .38279 Mdot
.71 .38375 Mdot
.71 .38417 Mdot
.71 .38463 Mdot
.71 .38464 Mdot
.71 .38469 Mdot
.71 .38483 Mdot
.71 .38488 Mdot
.71 .3849 Mdot
.71 .38491 Mdot
.71 .38546 Mdot
.71 .38551 Mdot
.71 .38562 Mdot
.71 .38564 Mdot
.71 .38576 Mdot
.71 .38583 Mdot
.71 .38584 Mdot
.71 .38585 Mdot
.71 .38599 Mdot
.71 .38599 Mdot
.71 .3862 Mdot
.71 .38622 Mdot
.71 .38644 Mdot
.71 .38662 Mdot
.71 .38674 Mdot
.71 .38677 Mdot
.71 .38686 Mdot
.71 .3869 Mdot
.71 .38765 Mdot
.71 .38771 Mdot
.71 .38783 Mdot
.71 .3883 Mdot
.71 .38838 Mdot
.71 .38843 Mdot
.71 .38848 Mdot
.71 .38849 Mdot
.71 .38872 Mdot
.71 .38879 Mdot
.71 .38909 Mdot
.71 .38913 Mdot
.71 .38918 Mdot
.71 .38931 Mdot
.71 .38934 Mdot
.71 .38937 Mdot
.71 .38939 Mdot
.71 .38966 Mdot
.71 .38972 Mdot
.71 .38987 Mdot
.71 .39043 Mdot
.71 .39052 Mdot
.71 .39061 Mdot
.71 .39075 Mdot
.71 .39081 Mdot
.71 .39126 Mdot
.71 .39146 Mdot
.71 .39159 Mdot
.71 .39163 Mdot
.71 .39169 Mdot
.71 .39183 Mdot
.71 .39191 Mdot
.71 .39199 Mdot
.71 .3921 Mdot
.71 .39214 Mdot
.71 .39215 Mdot
.71 .39228 Mdot
.71 .39238 Mdot
.71 .39266 Mdot
.71 .39281 Mdot
.71 .39284 Mdot
.71 .39314 Mdot
.71 .39314 Mdot
.71 .39325 Mdot
.71 .39348 Mdot
.71 .3935 Mdot
.71 .39365 Mdot
.71 .39408 Mdot
.71 .39408 Mdot
.71 .39411 Mdot
.71 .39432 Mdot
.71 .39454 Mdot
.71 .39484 Mdot
.71 .3949 Mdot
.71 .39511 Mdot
.71 .39512 Mdot
.71 .39546 Mdot
.71 .39583 Mdot
.71 .39593 Mdot
.71 .39664 Mdot
.71 .39671 Mdot
.71 .39678 Mdot
.71 .39718 Mdot
.71 .39725 Mdot
.71 .39736 Mdot
.71 .39749 Mdot
.71 .39759 Mdot
.71 .39781 Mdot
.71 .39781 Mdot
.71 .39784 Mdot
.71 .39804 Mdot
.71 .39818 Mdot
.71 .39826 Mdot
.71 .39836 Mdot
.71 .39836 Mdot
.71 .39911 Mdot
.71 .39913 Mdot
.71 .39946 Mdot
.71 .3995 Mdot
.71 .39965 Mdot
.71 .39973 Mdot
.71 .4003 Mdot
.71 .40041 Mdot
.71 .40051 Mdot
.71 .40052 Mdot
.71 .40063 Mdot
.71 .40068 Mdot
.71 .40071 Mdot
.71 .40098 Mdot
.71 .40107 Mdot
.71 .40113 Mdot
.71 .40118 Mdot
.71 .40121 Mdot
.71 .4016 Mdot
.71 .40166 Mdot
.71 .40174 Mdot
.71 .40195 Mdot
.71 .40204 Mdot
.71 .40216 Mdot
.71 .40238 Mdot
.71 .40239 Mdot
.71 .40249 Mdot
.71 .40286 Mdot
.71 .40296 Mdot
.71 .40308 Mdot
.71 .40314 Mdot
.71 .40332 Mdot
.71 .40333 Mdot
.71 .40335 Mdot
.71 .40337 Mdot
.71 .40338 Mdot
.71 .40341 Mdot
.71 .40357 Mdot
.71 .4036 Mdot
.71 .40398 Mdot
.71 .404 Mdot
.71 .40403 Mdot
.71 .40424 Mdot
.71 .40425 Mdot
.71 .40481 Mdot
.71 .40487 Mdot
.71 .40489 Mdot
.71 .40505 Mdot
.71 .40517 Mdot
.71 .4054 Mdot
.71 .40565 Mdot
.71 .40574 Mdot
.71 .40621 Mdot
.71 .40637 Mdot
.71 .40698 Mdot
.71 .4071 Mdot
.71 .40728 Mdot
.71 .40734 Mdot
.71 .40768 Mdot
.71 .40774 Mdot
.71 .40784 Mdot
.71 .40785 Mdot
.71 .40818 Mdot
.71 .4086 Mdot
.71 .40865 Mdot
.71 .40866 Mdot
.71 .40875 Mdot
.71 .40876 Mdot
.71 .40879 Mdot
.71 .40887 Mdot
.71 .40897 Mdot
.71 .40915 Mdot
.71 .40926 Mdot
.71 .40931 Mdot
.71 .40931 Mdot
.71 .40934 Mdot
.71 .40954 Mdot
.71 .40971 Mdot
.71 .40976 Mdot
.71 .40979 Mdot
.71 .40996 Mdot
.71 .40999 Mdot
.71 .41008 Mdot
.71 .41044 Mdot
.71 .41052 Mdot
.71 .41076 Mdot
.71 .4108 Mdot
.71 .41092 Mdot
.71 .41104 Mdot
.71 .41118 Mdot
.71 .41119 Mdot
.71 .41122 Mdot
.71 .4115 Mdot
.71 .4115 Mdot
.71 .41161 Mdot
.71 .41162 Mdot
.71 .41182 Mdot
.71 .41193 Mdot
.71 .41194 Mdot
.71 .41196 Mdot
.71 .41242 Mdot
.71 .41264 Mdot
.71 .41274 Mdot
.71 .41278 Mdot
.71 .41301 Mdot
.71 .41307 Mdot
.71 .41312 Mdot
.71 .41326 Mdot
.71 .41334 Mdot
.71 .41335 Mdot
.71 .41457 Mdot
.71 .41485 Mdot
.71 .41491 Mdot
.71 .41496 Mdot
.71 .4152 Mdot
.71 .41585 Mdot
.71 .41603 Mdot
.71 .41616 Mdot
.71 .41631 Mdot
.71 .41642 Mdot
.71 .41652 Mdot
.71 .41654 Mdot
.71 .41654 Mdot
.71 .417 Mdot
.71 .41701 Mdot
.71 .41715 Mdot
.71 .41724 Mdot
.71 .41758 Mdot
.71 .41761 Mdot
.71 .41773 Mdot
.71 .41775 Mdot
.71 .41783 Mdot
.71 .41793 Mdot
.71 .41819 Mdot
.71 .41826 Mdot
.71 .41831 Mdot
.71 .41835 Mdot
.71 .41887 Mdot
.71 .41888 Mdot
.71 .4189 Mdot
.71 .41901 Mdot
.71 .41931 Mdot
.71 .41932 Mdot
.71 .41937 Mdot
.71 .4194 Mdot
.71 .42016 Mdot
.71 .42024 Mdot
.71 .42044 Mdot
.71 .42055 Mdot
.71 .42062 Mdot
.71 .42063 Mdot
.71 .42063 Mdot
.71 .42066 Mdot
.71 .42072 Mdot
.71 .42073 Mdot
.71 .42081 Mdot
.71 .42109 Mdot
.71 .4211 Mdot
.71 .42122 Mdot
.71 .42122 Mdot
.71 .42145 Mdot
.71 .42166 Mdot
.71 .42214 Mdot
.71 .4224 Mdot
.71 .42254 Mdot
.71 .42261 Mdot
.71 .42262 Mdot
.71 .42279 Mdot
.71 .42288 Mdot
.71 .42299 Mdot
.71 .42308 Mdot
.71 .42328 Mdot
.71 .42331 Mdot
.71 .42344 Mdot
.71 .4235 Mdot
.71 .42359 Mdot
.71 .42383 Mdot
.71 .42391 Mdot
.71 .42392 Mdot
.71 .42392 Mdot
.71 .42407 Mdot
.71 .42419 Mdot
.71 .42421 Mdot
.71 .42438 Mdot
.71 .42494 Mdot
.71 .42498 Mdot
.71 .42504 Mdot
.71 .42515 Mdot
.71 .42525 Mdot
.71 .42528 Mdot
.71 .42531 Mdot
.71 .42545 Mdot
.71 .42591 Mdot
.71 .42592 Mdot
.71 .426 Mdot
.71 .42605 Mdot
.71 .42613 Mdot
.71 .42615 Mdot
.71 .42637 Mdot
.71 .4264 Mdot
.71 .4266 Mdot
.71 .42661 Mdot
.71 .42664 Mdot
.71 .42682 Mdot
.71 .42694 Mdot
.71 .42782 Mdot
.71 .42782 Mdot
.71 .42788 Mdot
.71 .42796 Mdot
.71 .42814 Mdot
.71 .42829 Mdot
.71 .42843 Mdot
.71 .42852 Mdot
.71 .42874 Mdot
.71 .42919 Mdot
.71 .42922 Mdot
.71 .42935 Mdot
.71 .42946 Mdot
.71 .42988 Mdot
.71 .42991 Mdot
.71 .43059 Mdot
.71 .43073 Mdot
.71 .43074 Mdot
.71 .43094 Mdot
.71 .43111 Mdot
.71 .43133 Mdot
.71 .43138 Mdot
.71 .43154 Mdot
.71 .43179 Mdot
.71 .43183 Mdot
.71 .43185 Mdot
.71 .43228 Mdot
.71 .43249 Mdot
.71 .43297 Mdot
.71 .43297 Mdot
.71 .4331 Mdot
.71 .43311 Mdot
.71 .43325 Mdot
.712 .25694 Mdot
.712 .2571 Mdot
.712 .25714 Mdot
.712 .25728 Mdot
.712 .25764 Mdot
.712 .25809 Mdot
.712 .25823 Mdot
.712 .25847 Mdot
.712 .25868 Mdot
.712 .25944 Mdot
.712 .25945 Mdot
.712 .25946 Mdot
.712 .25978 Mdot
.712 .25991 Mdot
.712 .25993 Mdot
.712 .26081 Mdot
.712 .26098 Mdot
.712 .26121 Mdot
.712 .26166 Mdot
.712 .26167 Mdot
.712 .26251 Mdot
.712 .26252 Mdot
.712 .26255 Mdot
.712 .26259 Mdot
.712 .2627 Mdot
.712 .26276 Mdot
.712 .2628 Mdot
.712 .26285 Mdot
.712 .26298 Mdot
.712 .26301 Mdot
.712 .26321 Mdot
.712 .26348 Mdot
.712 .26361 Mdot
.712 .2637 Mdot
.712 .2639 Mdot
.712 .26445 Mdot
.712 .26547 Mdot
.712 .26579 Mdot
.712 .26594 Mdot
.712 .26612 Mdot
.712 .26631 Mdot
.712 .2664 Mdot
.712 .26643 Mdot
.712 .26659 Mdot
.712 .26663 Mdot
.712 .26694 Mdot
.712 .267 Mdot
.712 .26725 Mdot
.712 .26742 Mdot
.712 .26773 Mdot
.712 .26781 Mdot
.712 .26787 Mdot
.712 .26814 Mdot
.712 .26819 Mdot
.712 .26849 Mdot
.712 .26869 Mdot
.712 .2688 Mdot
.712 .26884 Mdot
.712 .26905 Mdot
.712 .26931 Mdot
.712 .26953 Mdot
.712 .26989 Mdot
.712 .26989 Mdot
.712 .26991 Mdot
.712 .26994 Mdot
.712 .27026 Mdot
.712 .27031 Mdot
.712 .27031 Mdot
.712 .27114 Mdot
.712 .2717 Mdot
.712 .27181 Mdot
.712 .27209 Mdot
.712 .27228 Mdot
.712 .27269 Mdot
.712 .27301 Mdot
.712 .27338 Mdot
.712 .2735 Mdot
.712 .27367 Mdot
.712 .27386 Mdot
.712 .27402 Mdot
.712 .27402 Mdot
.712 .27458 Mdot
.712 .27464 Mdot
.712 .27496 Mdot
.712 .27508 Mdot
.712 .2754 Mdot
.712 .27635 Mdot
.712 .2766 Mdot
.712 .27665 Mdot
.712 .27682 Mdot
.712 .27682 Mdot
.712 .27755 Mdot
.712 .27793 Mdot
.712 .27803 Mdot
.712 .2782 Mdot
.712 .27827 Mdot
.712 .27828 Mdot
.712 .27831 Mdot
.712 .27837 Mdot
.712 .27864 Mdot
.712 .27869 Mdot
.712 .27899 Mdot
.712 .27932 Mdot
.712 .27945 Mdot
.712 .27965 Mdot
.712 .27975 Mdot
.712 .27986 Mdot
.712 .28023 Mdot
.712 .28033 Mdot
.712 .28033 Mdot
.712 .28047 Mdot
.712 .28097 Mdot
.712 .28105 Mdot
.712 .28112 Mdot
.712 .28132 Mdot
.712 .28183 Mdot
.712 .28189 Mdot
.712 .28212 Mdot
.712 .2825 Mdot
.712 .28311 Mdot
.712 .28339 Mdot
.712 .28343 Mdot
.712 .28344 Mdot
.712 .28361 Mdot
.712 .28378 Mdot
.712 .28393 Mdot
.712 .2843 Mdot
.712 .28433 Mdot
.712 .28465 Mdot
.712 .28476 Mdot
.712 .28476 Mdot
.712 .28498 Mdot
.712 .28504 Mdot
.712 .28523 Mdot
.712 .2853 Mdot
.712 .28544 Mdot
.712 .28606 Mdot
.712 .28624 Mdot
.712 .28627 Mdot
.712 .28649 Mdot
.712 .28651 Mdot
.712 .28667 Mdot
.712 .28707 Mdot
.712 .28761 Mdot
.712 .28773 Mdot
.712 .28802 Mdot
.712 .28845 Mdot
.712 .2893 Mdot
.712 .28949 Mdot
.712 .28997 Mdot
.712 .29014 Mdot
.712 .29017 Mdot
.712 .29051 Mdot
.712 .29074 Mdot
.712 .2908 Mdot
.712 .29117 Mdot
.712 .29127 Mdot
.712 .29148 Mdot
.712 .29183 Mdot
.712 .29194 Mdot
.712 .29196 Mdot
.712 .29212 Mdot
.712 .2923 Mdot
.712 .29263 Mdot
.712 .29268 Mdot
.712 .29286 Mdot
.712 .29289 Mdot
.712 .29327 Mdot
.712 .29351 Mdot
.712 .2936 Mdot
.712 .29402 Mdot
.712 .29423 Mdot
.712 .29438 Mdot
.712 .29498 Mdot
.712 .29511 Mdot
.712 .29557 Mdot
.712 .29584 Mdot
.712 .29584 Mdot
.712 .2959 Mdot
.712 .29625 Mdot
.712 .29632 Mdot
.712 .29649 Mdot
.712 .29666 Mdot
.712 .29714 Mdot
.712 .29728 Mdot
.712 .29764 Mdot
.712 .29796 Mdot
.712 .29803 Mdot
.712 .29846 Mdot
.712 .29869 Mdot
.712 .29916 Mdot
.712 .29976 Mdot
.712 .29987 Mdot
.712 .29999 Mdot
.712 .30062 Mdot
.712 .30086 Mdot
.712 .30114 Mdot
.712 .30122 Mdot
.712 .30131 Mdot
.712 .30145 Mdot
.712 .30256 Mdot
.712 .30297 Mdot
.712 .30335 Mdot
.712 .30359 Mdot
.712 .30369 Mdot
.712 .30371 Mdot
.712 .30377 Mdot
.712 .30417 Mdot
.712 .30424 Mdot
.712 .3046 Mdot
.712 .3049 Mdot
.712 .30494 Mdot
.712 .30536 Mdot
.712 .30586 Mdot
.712 .30613 Mdot
.712 .30627 Mdot
.712 .30667 Mdot
.712 .30678 Mdot
.712 .30723 Mdot
.712 .30724 Mdot
.712 .30746 Mdot
.712 .30765 Mdot
.712 .3081 Mdot
.712 .30816 Mdot
.712 .30833 Mdot
.712 .3087 Mdot
.712 .30892 Mdot
.712 .309 Mdot
.712 .30921 Mdot
.712 .30956 Mdot
.712 .30991 Mdot
.712 .30993 Mdot
.712 .31 Mdot
.712 .31059 Mdot
.712 .31107 Mdot
.712 .31108 Mdot
.712 .3113 Mdot
.712 .31182 Mdot
.712 .31258 Mdot
.712 .31258 Mdot
.712 .3126 Mdot
.712 .31267 Mdot
.712 .3127 Mdot
.712 .31274 Mdot
.712 .31281 Mdot
.712 .31282 Mdot
.712 .31292 Mdot
.712 .31306 Mdot
.712 .31317 Mdot
.712 .3142 Mdot
.712 .31427 Mdot
.712 .31436 Mdot
.712 .31451 Mdot
.712 .31459 Mdot
.712 .31461 Mdot
.712 .31476 Mdot
.712 .31492 Mdot
.712 .315 Mdot
.712 .31519 Mdot
.712 .31536 Mdot
.712 .31538 Mdot
.712 .31553 Mdot
.712 .31593 Mdot
.712 .31622 Mdot
.712 .31622 Mdot
.712 .31623 Mdot
.712 .31625 Mdot
.712 .3164 Mdot
.712 .31643 Mdot
.712 .31711 Mdot
.712 .31717 Mdot
.712 .3173 Mdot
.712 .3174 Mdot
.712 .3176 Mdot
.712 .31776 Mdot
.712 .318 Mdot
.712 .31825 Mdot
.712 .31856 Mdot
.712 .31872 Mdot
.712 .31893 Mdot
.712 .31955 Mdot
.712 .31963 Mdot
.712 .31999 Mdot
.712 .32018 Mdot
.712 .32032 Mdot
.712 .32035 Mdot
.712 .32036 Mdot
.712 .32037 Mdot
.712 .3204 Mdot
.712 .32053 Mdot
.712 .32056 Mdot
.712 .32087 Mdot
.712 .32103 Mdot
.712 .32108 Mdot
.712 .32113 Mdot
.712 .32131 Mdot
.712 .32137 Mdot
.712 .32168 Mdot
.712 .32172 Mdot
.712 .32186 Mdot
.712 .32213 Mdot
.712 .32243 Mdot
.712 .32288 Mdot
.712 .3229 Mdot
.712 .32299 Mdot
.712 .32333 Mdot
.712 .32334 Mdot
.712 .32366 Mdot
.712 .32369 Mdot
.712 .32378 Mdot
.712 .32389 Mdot
.712 .32419 Mdot
.712 .32429 Mdot
.712 .32441 Mdot
.712 .3245 Mdot
.712 .32469 Mdot
.712 .32496 Mdot
.712 .3262 Mdot
.712 .32622 Mdot
.712 .32639 Mdot
.712 .32687 Mdot
.712 .32704 Mdot
.712 .3271 Mdot
.712 .32718 Mdot
.712 .32755 Mdot
.712 .32775 Mdot
.712 .32787 Mdot
.712 .32829 Mdot
.712 .32902 Mdot
.712 .32902 Mdot
.712 .32904 Mdot
.712 .32934 Mdot
.712 .32966 Mdot
.712 .32973 Mdot
.712 .33006 Mdot
.712 .33031 Mdot
.712 .33042 Mdot
.712 .33065 Mdot
.712 .331 Mdot
.712 .33106 Mdot
.712 .33149 Mdot
.712 .33163 Mdot
.712 .33171 Mdot
.712 .33253 Mdot
.712 .33284 Mdot
.712 .33292 Mdot
.712 .33348 Mdot
.712 .3335 Mdot
.712 .33371 Mdot
.712 .33484 Mdot
.712 .33517 Mdot
.712 .33536 Mdot
.712 .3355 Mdot
.712 .33653 Mdot
.712 .33653 Mdot
.712 .33664 Mdot
.712 .33727 Mdot
.712 .33728 Mdot
.712 .33732 Mdot
.712 .33733 Mdot
.712 .33735 Mdot
.712 .33739 Mdot
.712 .33739 Mdot
.712 .33744 Mdot
.712 .3381 Mdot
.712 .33815 Mdot
.712 .33822 Mdot
.712 .33826 Mdot
.712 .33846 Mdot
.712 .33856 Mdot
.712 .33864 Mdot
.712 .33865 Mdot
.712 .33872 Mdot
.712 .33907 Mdot
.712 .33908 Mdot
.712 .33915 Mdot
.712 .33951 Mdot
.712 .3396 Mdot
.712 .33982 Mdot
.712 .34022 Mdot
.712 .3403 Mdot
.712 .34084 Mdot
.712 .34093 Mdot
.712 .3411 Mdot
.712 .34111 Mdot
.712 .3412 Mdot
.712 .34144 Mdot
.712 .34149 Mdot
.712 .34158 Mdot
.712 .3416 Mdot
.712 .34176 Mdot
.712 .34178 Mdot
.712 .34198 Mdot
.712 .34213 Mdot
.712 .34235 Mdot
.712 .34236 Mdot
.712 .3424 Mdot
.712 .34274 Mdot
.712 .34285 Mdot
.712 .343 Mdot
.712 .3431 Mdot
.712 .34315 Mdot
.712 .34324 Mdot
.712 .34337 Mdot
.712 .34399 Mdot
.712 .34408 Mdot
.712 .3444 Mdot
.712 .34447 Mdot
.712 .34465 Mdot
.712 .34502 Mdot
.712 .34539 Mdot
.712 .34569 Mdot
.712 .34607 Mdot
.712 .34618 Mdot
.712 .34636 Mdot
.712 .3466 Mdot
.712 .34666 Mdot
.712 .34726 Mdot
.712 .34759 Mdot
.712 .34841 Mdot
.712 .3485 Mdot
.712 .34858 Mdot
.712 .34945 Mdot
.712 .34947 Mdot
.712 .34948 Mdot
.712 .34953 Mdot
.712 .34988 Mdot
.712 .34992 Mdot
.712 .34994 Mdot
.712 .35003 Mdot
.712 .35012 Mdot
.712 .35013 Mdot
.712 .35016 Mdot
.712 .35033 Mdot
.712 .35038 Mdot
.712 .35094 Mdot
.712 .35134 Mdot
.712 .35134 Mdot
.712 .35139 Mdot
.712 .3515 Mdot
.712 .35157 Mdot
.712 .35167 Mdot
.712 .35177 Mdot
.712 .35184 Mdot
.712 .35195 Mdot
.712 .35196 Mdot
.712 .3522 Mdot
.712 .35227 Mdot
.712 .35232 Mdot
.712 .35234 Mdot
.712 .35379 Mdot
.712 .35384 Mdot
.712 .35405 Mdot
.712 .35408 Mdot
.712 .35437 Mdot
.712 .35454 Mdot
.712 .35499 Mdot
.712 .35502 Mdot
.712 .35545 Mdot
.712 .35547 Mdot
.712 .35567 Mdot
.712 .35568 Mdot
.712 .35574 Mdot
.712 .35578 Mdot
.712 .35581 Mdot
.712 .35589 Mdot
.712 .35638 Mdot
.712 .35646 Mdot
.712 .3565 Mdot
.712 .35669 Mdot
.712 .35759 Mdot
.712 .35762 Mdot
.712 .35788 Mdot
.712 .35796 Mdot
.712 .3582 Mdot
.712 .35842 Mdot
.712 .35852 Mdot
.712 .35853 Mdot
.712 .35856 Mdot
.712 .35858 Mdot
.712 .35863 Mdot
.712 .35887 Mdot
.712 .35891 Mdot
.712 .35893 Mdot
.712 .35902 Mdot
.712 .35965 Mdot
.712 .35977 Mdot
.712 .35988 Mdot
.712 .35992 Mdot
.712 .35998 Mdot
.712 .3601 Mdot
.712 .36012 Mdot
.712 .36013 Mdot
.712 .36017 Mdot
.712 .36054 Mdot
.712 .36065 Mdot
.712 .3607 Mdot
.712 .36074 Mdot
.712 .361 Mdot
.712 .36102 Mdot
.712 .36115 Mdot
.712 .36122 Mdot
.712 .36126 Mdot
.712 .36128 Mdot
.712 .36132 Mdot
.712 .36134 Mdot
.712 .36139 Mdot
.712 .36149 Mdot
.712 .3615 Mdot
.712 .36168 Mdot
.712 .36171 Mdot
.712 .36182 Mdot
.712 .36208 Mdot
.712 .36212 Mdot
.712 .36213 Mdot
.712 .36222 Mdot
.712 .36237 Mdot
.712 .36289 Mdot
.712 .36295 Mdot
.712 .36297 Mdot
.712 .36299 Mdot
.712 .36317 Mdot
.712 .3632 Mdot
.712 .36322 Mdot
.712 .36324 Mdot
.712 .36324 Mdot
.712 .36331 Mdot
.712 .36347 Mdot
.712 .36363 Mdot
.712 .36369 Mdot
.712 .36387 Mdot
.712 .36389 Mdot
.712 .36453 Mdot
.712 .36466 Mdot
.712 .36468 Mdot
.712 .36474 Mdot
.712 .36509 Mdot
.712 .36515 Mdot
.712 .36516 Mdot
.712 .36519 Mdot
.712 .36523 Mdot
.712 .36525 Mdot
.712 .36539 Mdot
.712 .3654 Mdot
.712 .3657 Mdot
.712 .36572 Mdot
.712 .36604 Mdot
.712 .36615 Mdot
.712 .36636 Mdot
.712 .36638 Mdot
.712 .36653 Mdot
.712 .36657 Mdot
.712 .36758 Mdot
.712 .36759 Mdot
.712 .36763 Mdot
.712 .36768 Mdot
.712 .36785 Mdot
.712 .36785 Mdot
.712 .36793 Mdot
.712 .36798 Mdot
.712 .36805 Mdot
.712 .36812 Mdot
.712 .36817 Mdot
.712 .36825 Mdot
.712 .36829 Mdot
.712 .36829 Mdot
.712 .36857 Mdot
.712 .36896 Mdot
.712 .36899 Mdot
.712 .36911 Mdot
.712 .36914 Mdot
.712 .36914 Mdot
.712 .3692 Mdot
.712 .36927 Mdot
.712 .36928 Mdot
.712 .36931 Mdot
.712 .36956 Mdot
.712 .36959 Mdot
.712 .36961 Mdot
.712 .37023 Mdot
.712 .37028 Mdot
.712 .37034 Mdot
.712 .37092 Mdot
.712 .37115 Mdot
.712 .37157 Mdot
.712 .37162 Mdot
.712 .37178 Mdot
.712 .37191 Mdot
.712 .37199 Mdot
.712 .37225 Mdot
.712 .37246 Mdot
.712 .37272 Mdot
.712 .37298 Mdot
.712 .37311 Mdot
.712 .37316 Mdot
.712 .37338 Mdot
.712 .37345 Mdot
.712 .37388 Mdot
.712 .37397 Mdot
.712 .37404 Mdot
.712 .37407 Mdot
.712 .37414 Mdot
.712 .37425 Mdot
.712 .37433 Mdot
.712 .37456 Mdot
.712 .37459 Mdot
.712 .3746 Mdot
.712 .37475 Mdot
.712 .37486 Mdot
.712 .375 Mdot
.712 .37501 Mdot
.712 .37512 Mdot
.712 .37514 Mdot
.712 .3752 Mdot
.712 .37524 Mdot
.712 .3754 Mdot
.712 .37547 Mdot
.712 .37547 Mdot
.712 .3756 Mdot
.712 .37566 Mdot
.712 .37604 Mdot
.712 .37609 Mdot
.712 .37637 Mdot
.712 .37653 Mdot
.712 .37659 Mdot
.712 .37684 Mdot
.712 .37689 Mdot
.712 .3769 Mdot
.712 .37714 Mdot
.712 .3772 Mdot
.712 .3772 Mdot
.712 .37726 Mdot
.712 .37733 Mdot
.712 .37747 Mdot
.712 .3775 Mdot
.712 .37755 Mdot
.712 .37758 Mdot
.712 .37805 Mdot
.712 .37808 Mdot
.712 .37808 Mdot
.712 .37811 Mdot
.712 .37812 Mdot
.712 .37813 Mdot
.712 .37816 Mdot
.712 .37816 Mdot
.712 .37861 Mdot
.712 .37868 Mdot
.712 .37869 Mdot
.712 .37941 Mdot
.712 .37951 Mdot
.712 .37964 Mdot
.712 .37987 Mdot
.712 .38067 Mdot
.712 .38081 Mdot
.712 .38082 Mdot
.712 .38122 Mdot
.712 .38128 Mdot
.712 .38149 Mdot
.712 .38207 Mdot
.712 .38213 Mdot
.712 .38222 Mdot
.712 .38252 Mdot
.712 .38257 Mdot
.712 .38281 Mdot
.712 .38298 Mdot
.712 .38305 Mdot
.712 .38323 Mdot
.712 .38346 Mdot
.712 .38351 Mdot
.712 .38374 Mdot
.712 .38394 Mdot
.712 .38396 Mdot
.712 .38396 Mdot
.712 .38447 Mdot
.712 .38477 Mdot
.712 .38485 Mdot
.712 .38499 Mdot
.712 .38525 Mdot
.712 .3853 Mdot
.712 .38535 Mdot
.712 .38547 Mdot
.712 .38581 Mdot
.712 .38592 Mdot
.712 .38594 Mdot
.712 .38681 Mdot
.712 .387 Mdot
.712 .38714 Mdot
.712 .3872 Mdot
.712 .38728 Mdot
.712 .38735 Mdot
.712 .38756 Mdot
.712 .38764 Mdot
.712 .3877 Mdot
.712 .38772 Mdot
.712 .38795 Mdot
.712 .38796 Mdot
.712 .3882 Mdot
.712 .38826 Mdot
.712 .38827 Mdot
.712 .38858 Mdot
.712 .38879 Mdot
.712 .38899 Mdot
.712 .38908 Mdot
.712 .38911 Mdot
.712 .38933 Mdot
.712 .38937 Mdot
.712 .3895 Mdot
.712 .38953 Mdot
.712 .38957 Mdot
.712 .38968 Mdot
.712 .3899 Mdot
.712 .38992 Mdot
.712 .39001 Mdot
.712 .39003 Mdot
.712 .39004 Mdot
.712 .39005 Mdot
.712 .39007 Mdot
.712 .39016 Mdot
.712 .3903 Mdot
.712 .39055 Mdot
.712 .39061 Mdot
.712 .39104 Mdot
.712 .39119 Mdot
.712 .3913 Mdot
.712 .39152 Mdot
.712 .3917 Mdot
.712 .39187 Mdot
.712 .39198 Mdot
.712 .39212 Mdot
.712 .39219 Mdot
.712 .39228 Mdot
.712 .39232 Mdot
.712 .3928 Mdot
.712 .39282 Mdot
.712 .39293 Mdot
.712 .39294 Mdot
.712 .39295 Mdot
.712 .39295 Mdot
.712 .39315 Mdot
.712 .39343 Mdot
.712 .39354 Mdot
.712 .39355 Mdot
.712 .39367 Mdot
.712 .39381 Mdot
.712 .39386 Mdot
.712 .39397 Mdot
.712 .39408 Mdot
.712 .39409 Mdot
.712 .39415 Mdot
.712 .39425 Mdot
.712 .39432 Mdot
.712 .39437 Mdot
.712 .39509 Mdot
.712 .39517 Mdot
.712 .39526 Mdot
.712 .39533 Mdot
.712 .39534 Mdot
.712 .39539 Mdot
.712 .39542 Mdot
.712 .39544 Mdot
.712 .39549 Mdot
.712 .3955 Mdot
.712 .3955 Mdot
.712 .39603 Mdot
.712 .3964 Mdot
.712 .39656 Mdot
.712 .39656 Mdot
.712 .3969 Mdot
.712 .39732 Mdot
.712 .39736 Mdot
.712 .39738 Mdot
.712 .39762 Mdot
.712 .39787 Mdot
.712 .39802 Mdot
.712 .39807 Mdot
.712 .39822 Mdot
.712 .39849 Mdot
.712 .39861 Mdot
.712 .39865 Mdot
.712 .39896 Mdot
.712 .3991 Mdot
.712 .39926 Mdot
.712 .39926 Mdot
.712 .39958 Mdot
.712 .39965 Mdot
.712 .39993 Mdot
.712 .40003 Mdot
.712 .40022 Mdot
.712 .40058 Mdot
.712 .40087 Mdot
.712 .4009 Mdot
.712 .40111 Mdot
.712 .40136 Mdot
.712 .40141 Mdot
.712 .40169 Mdot
.712 .40173 Mdot
.712 .40175 Mdot
.712 .40182 Mdot
.712 .40198 Mdot
.712 .40225 Mdot
.712 .40254 Mdot
.712 .40332 Mdot
.712 .40342 Mdot
.712 .40348 Mdot
.712 .40354 Mdot
.712 .40373 Mdot
.712 .4039 Mdot
.712 .40434 Mdot
.712 .40443 Mdot
.712 .40451 Mdot
.712 .40493 Mdot
.712 .40526 Mdot
.712 .40542 Mdot
.712 .40572 Mdot
.712 .40577 Mdot
.712 .406 Mdot
.712 .40624 Mdot
.712 .40634 Mdot
.712 .40668 Mdot
.712 .4068 Mdot
.712 .40692 Mdot
.712 .40697 Mdot
.712 .40722 Mdot
.712 .40726 Mdot
.712 .40726 Mdot
.712 .40745 Mdot
.712 .40777 Mdot
.712 .40786 Mdot
.712 .40828 Mdot
.712 .40839 Mdot
.712 .40853 Mdot
.712 .40883 Mdot
.712 .4089 Mdot
.712 .40906 Mdot
.712 .40933 Mdot
.712 .40935 Mdot
.712 .40948 Mdot
.712 .40951 Mdot
.712 .40974 Mdot
.712 .40987 Mdot
.712 .40998 Mdot
.712 .41 Mdot
.712 .41007 Mdot
.712 .41032 Mdot
.712 .41047 Mdot
.712 .41054 Mdot
.712 .4108 Mdot
.712 .41084 Mdot
.712 .411 Mdot
.712 .41124 Mdot
.712 .41126 Mdot
.712 .41138 Mdot
.712 .41172 Mdot
.712 .41185 Mdot
.712 .41245 Mdot
.712 .41275 Mdot
.712 .41296 Mdot
.712 .41304 Mdot
.712 .41342 Mdot
.712 .4137 Mdot
.712 .41381 Mdot
.712 .41382 Mdot
.712 .41398 Mdot
.712 .414 Mdot
.712 .41413 Mdot
.712 .41456 Mdot
.712 .41466 Mdot
.712 .41471 Mdot
.712 .41485 Mdot
.712 .41488 Mdot
.712 .41504 Mdot
.712 .41504 Mdot
.712 .41512 Mdot
.712 .41534 Mdot
.712 .41536 Mdot
.712 .41563 Mdot
.712 .41573 Mdot
.712 .41585 Mdot
.712 .41597 Mdot
.712 .41597 Mdot
.712 .416 Mdot
.712 .4162 Mdot
.712 .41663 Mdot
.712 .41689 Mdot
.712 .41706 Mdot
.712 .41709 Mdot
.712 .41745 Mdot
.712 .4176 Mdot
.712 .41765 Mdot
.712 .4177 Mdot
.712 .41805 Mdot
.712 .41815 Mdot
.712 .41815 Mdot
.712 .41822 Mdot
.712 .41848 Mdot
.712 .41856 Mdot
.712 .41863 Mdot
.712 .41877 Mdot
.712 .41886 Mdot
.712 .41909 Mdot
.712 .41931 Mdot
.712 .41933 Mdot
.712 .41953 Mdot
.712 .41957 Mdot
.712 .41959 Mdot
.712 .4196 Mdot
.712 .41965 Mdot
.712 .41976 Mdot
.712 .41983 Mdot
.712 .4201 Mdot
.712 .42061 Mdot
.712 .42062 Mdot
.712 .42074 Mdot
.712 .42077 Mdot
.712 .42095 Mdot
.712 .42162 Mdot
.712 .42184 Mdot
.712 .42192 Mdot
.712 .42214 Mdot
.712 .42219 Mdot
.712 .42258 Mdot
.712 .42258 Mdot
.712 .4227 Mdot
.712 .42283 Mdot
.712 .42295 Mdot
.712 .42303 Mdot
.712 .42329 Mdot
.712 .42352 Mdot
.712 .4238 Mdot
.712 .42394 Mdot
.712 .42413 Mdot
.712 .42421 Mdot
.712 .4246 Mdot
.712 .42518 Mdot
.712 .42519 Mdot
.712 .42522 Mdot
.712 .42544 Mdot
.712 .42547 Mdot
.712 .42548 Mdot
.712 .42548 Mdot
.712 .42573 Mdot
.712 .42589 Mdot
.712 .42607 Mdot
.712 .42622 Mdot
.712 .42625 Mdot
.712 .42633 Mdot
.712 .42646 Mdot
.712 .42668 Mdot
.712 .42671 Mdot
.712 .4269 Mdot
.712 .42694 Mdot
.712 .427 Mdot
.712 .42722 Mdot
.712 .42734 Mdot
.712 .42751 Mdot
.712 .42756 Mdot
.712 .42777 Mdot
.712 .4278 Mdot
.712 .42791 Mdot
.712 .42794 Mdot
.712 .428 Mdot
.712 .42813 Mdot
.712 .42825 Mdot
.712 .42836 Mdot
.712 .42859 Mdot
.712 .4293 Mdot
.712 .42969 Mdot
.712 .42983 Mdot
.712 .42989 Mdot
.712 .42998 Mdot
.712 .43018 Mdot
.712 .43031 Mdot
.712 .43033 Mdot
.712 .43043 Mdot
.712 .43046 Mdot
.712 .43049 Mdot
.712 .43053 Mdot
.712 .43061 Mdot
.712 .43064 Mdot
.712 .43066 Mdot
.712 .43066 Mdot
.712 .43125 Mdot
.712 .43126 Mdot
.712 .43158 Mdot
.712 .43174 Mdot
.712 .43186 Mdot
.712 .43248 Mdot
.712 .43249 Mdot
.712 .43258 Mdot
.712 .4328 Mdot
.712 .43281 Mdot
.712 .43282 Mdot
.712 .43336 Mdot
.712 .4335 Mdot
.712 .43367 Mdot
.712 .43377 Mdot
.712 .43408 Mdot
.712 .43434 Mdot
.712 .43444 Mdot
.712 .43446 Mdot
.712 .43457 Mdot
.714 .25567 Mdot
.714 .25584 Mdot
.714 .25608 Mdot
.714 .25623 Mdot
.714 .25625 Mdot
.714 .25634 Mdot
.714 .25638 Mdot
.714 .25641 Mdot
.714 .25685 Mdot
.714 .25797 Mdot
.714 .25848 Mdot
.714 .25907 Mdot
.714 .25936 Mdot
.714 .25973 Mdot
.714 .26021 Mdot
.714 .26029 Mdot
.714 .26073 Mdot
.714 .26106 Mdot
.714 .26109 Mdot
.714 .26162 Mdot
.714 .26163 Mdot
.714 .26197 Mdot
.714 .26208 Mdot
.714 .2621 Mdot
.714 .2626 Mdot
.714 .26262 Mdot
.714 .2629 Mdot
.714 .26291 Mdot
.714 .26301 Mdot
.714 .26328 Mdot
.714 .26379 Mdot
.714 .2638 Mdot
.714 .26423 Mdot
.714 .2643 Mdot
.714 .26442 Mdot
.714 .2647 Mdot
.714 .26485 Mdot
.714 .265 Mdot
.714 .26516 Mdot
.714 .26526 Mdot
.714 .26581 Mdot
.714 .26592 Mdot
.714 .26604 Mdot
.714 .26609 Mdot
.714 .26646 Mdot
.714 .26678 Mdot
.714 .26681 Mdot
.714 .26692 Mdot
.714 .26716 Mdot
.714 .26764 Mdot
.714 .26764 Mdot
.714 .2677 Mdot
.714 .26784 Mdot
.714 .26819 Mdot
.714 .26862 Mdot
.714 .26879 Mdot
.714 .26887 Mdot
.714 .26889 Mdot
.714 .26898 Mdot
.714 .26907 Mdot
.714 .26912 Mdot
.714 .26918 Mdot
.714 .26935 Mdot
.714 .26945 Mdot
.714 .26957 Mdot
.714 .26972 Mdot
.714 .26993 Mdot
.714 .2702 Mdot
.714 .27054 Mdot
.714 .27074 Mdot
.714 .27156 Mdot
.714 .27175 Mdot
.714 .27273 Mdot
.714 .27277 Mdot
.714 .27307 Mdot
.714 .27315 Mdot
.714 .27319 Mdot
.714 .27324 Mdot
.714 .27401 Mdot
.714 .27423 Mdot
.714 .27435 Mdot
.714 .27479 Mdot
.714 .27479 Mdot
.714 .27511 Mdot
.714 .27529 Mdot
.714 .27539 Mdot
.714 .27545 Mdot
.714 .27572 Mdot
.714 .27583 Mdot
.714 .27587 Mdot
.714 .27595 Mdot
.714 .27611 Mdot
.714 .27623 Mdot
.714 .27654 Mdot
.714 .27656 Mdot
.714 .27689 Mdot
.714 .27695 Mdot
.714 .27708 Mdot
.714 .27737 Mdot
.714 .27738 Mdot
.714 .27739 Mdot
.714 .27774 Mdot
.714 .27789 Mdot
.714 .27828 Mdot
.714 .27835 Mdot
.714 .27844 Mdot
.714 .2787 Mdot
.714 .27879 Mdot
.714 .27908 Mdot
.714 .27982 Mdot
.714 .27985 Mdot
.714 .27988 Mdot
.714 .27999 Mdot
.714 .28002 Mdot
.714 .2803 Mdot
.714 .28069 Mdot
.714 .28095 Mdot
.714 .28102 Mdot
.714 .28109 Mdot
.714 .28143 Mdot
.714 .28145 Mdot
.714 .28153 Mdot
.714 .28165 Mdot
.714 .28189 Mdot
.714 .28208 Mdot
.714 .2831 Mdot
.714 .28324 Mdot
.714 .28333 Mdot
.714 .28336 Mdot
.714 .28348 Mdot
.714 .28402 Mdot
.714 .28442 Mdot
.714 .28463 Mdot
.714 .28463 Mdot
.714 .28472 Mdot
.714 .28515 Mdot
.714 .28566 Mdot
.714 .28579 Mdot
.714 .28587 Mdot
.714 .28608 Mdot
.714 .28613 Mdot
.714 .28631 Mdot
.714 .28645 Mdot
.714 .28649 Mdot
.714 .28677 Mdot
.714 .28739 Mdot
.714 .2874 Mdot
.714 .28766 Mdot
.714 .2878 Mdot
.714 .28787 Mdot
.714 .28792 Mdot
.714 .28794 Mdot
.714 .28808 Mdot
.714 .28814 Mdot
.714 .28822 Mdot
.714 .28854 Mdot
.714 .28864 Mdot
.714 .28868 Mdot
.714 .28876 Mdot
.714 .28883 Mdot
.714 .2893 Mdot
.714 .2898 Mdot
.714 .28986 Mdot
.714 .29002 Mdot
.714 .29051 Mdot
.714 .2906 Mdot
.714 .29061 Mdot
.714 .29083 Mdot
.714 .29096 Mdot
.714 .29116 Mdot
.714 .29117 Mdot
.714 .29174 Mdot
.714 .292 Mdot
.714 .29228 Mdot
.714 .29245 Mdot
.714 .29293 Mdot
.714 .29296 Mdot
.714 .29343 Mdot
.714 .29347 Mdot
.714 .29351 Mdot
.714 .29373 Mdot
.714 .2938 Mdot
.714 .29387 Mdot
.714 .29388 Mdot
.714 .29414 Mdot
.714 .29458 Mdot
.714 .2946 Mdot
.714 .29478 Mdot
.714 .29549 Mdot
.714 .29579 Mdot
.714 .29611 Mdot
.714 .29624 Mdot
.714 .29674 Mdot
.714 .29705 Mdot
.714 .29726 Mdot
.714 .29729 Mdot
.714 .29742 Mdot
.714 .29761 Mdot
.714 .29776 Mdot
.714 .29821 Mdot
.714 .29836 Mdot
.714 .2984 Mdot
.714 .29853 Mdot
.714 .2986 Mdot
.714 .2988 Mdot
.714 .29904 Mdot
.714 .29919 Mdot
.714 .29945 Mdot
.714 .29961 Mdot
.714 .29975 Mdot
.714 .29979 Mdot
.714 .30002 Mdot
.714 .30007 Mdot
.714 .30016 Mdot
.714 .30031 Mdot
.714 .30059 Mdot
.714 .30107 Mdot
.714 .30112 Mdot
.714 .30116 Mdot
.714 .3023 Mdot
.714 .3024 Mdot
.714 .30298 Mdot
.714 .30306 Mdot
.714 .3031 Mdot
.714 .30322 Mdot
.714 .30326 Mdot
.714 .30334 Mdot
.714 .30372 Mdot
.714 .30382 Mdot
.714 .30406 Mdot
.714 .30425 Mdot
.714 .3044 Mdot
.714 .30467 Mdot
.714 .30472 Mdot
.714 .30549 Mdot
.714 .30571 Mdot
.714 .30571 Mdot
.714 .30628 Mdot
.714 .3066 Mdot
.714 .30677 Mdot
.714 .30677 Mdot
.714 .30721 Mdot
.714 .30747 Mdot
.714 .30803 Mdot
.714 .30831 Mdot
.714 .30911 Mdot
.714 .30933 Mdot
.714 .30936 Mdot
.714 .30942 Mdot
.714 .30961 Mdot
.714 .30969 Mdot
.714 .3099 Mdot
.714 .30998 Mdot
.714 .31005 Mdot
.714 .31083 Mdot
.714 .31151 Mdot
.714 .31169 Mdot
.714 .31197 Mdot
.714 .31234 Mdot
.714 .31236 Mdot
.714 .31285 Mdot
.714 .31285 Mdot
.714 .3131 Mdot
.714 .31325 Mdot
.714 .31325 Mdot
.714 .3133 Mdot
.714 .31343 Mdot
.714 .31393 Mdot
.714 .31399 Mdot
.714 .31413 Mdot
.714 .3142 Mdot
.714 .31428 Mdot
.714 .31436 Mdot
.714 .3144 Mdot
.714 .31479 Mdot
.714 .31481 Mdot
.714 .31516 Mdot
.714 .31522 Mdot
.714 .31557 Mdot
.714 .3156 Mdot
.714 .31584 Mdot
.714 .31618 Mdot
.714 .31623 Mdot
.714 .31627 Mdot
.714 .31646 Mdot
.714 .31652 Mdot
.714 .31659 Mdot
.714 .31669 Mdot
.714 .31683 Mdot
.714 .31749 Mdot
.714 .31759 Mdot
.714 .31807 Mdot
.714 .31808 Mdot
.714 .31829 Mdot
.714 .31869 Mdot
.714 .31886 Mdot
.714 .31908 Mdot
.714 .3194 Mdot
.714 .31953 Mdot
.714 .31959 Mdot
.714 .31972 Mdot
.714 .31994 Mdot
.714 .32011 Mdot
.714 .32014 Mdot
.714 .32034 Mdot
.714 .32035 Mdot
.714 .32052 Mdot
.714 .32082 Mdot
.714 .32154 Mdot
.714 .32156 Mdot
.714 .32157 Mdot
.714 .32164 Mdot
.714 .32217 Mdot
.714 .32233 Mdot
.714 .32238 Mdot
.714 .32244 Mdot
.714 .32256 Mdot
.714 .32322 Mdot
.714 .32327 Mdot
.714 .32334 Mdot
.714 .3238 Mdot
.714 .3239 Mdot
.714 .32394 Mdot
.714 .32416 Mdot
.714 .32441 Mdot
.714 .32447 Mdot
.714 .32451 Mdot
.714 .32464 Mdot
.714 .32473 Mdot
.714 .32495 Mdot
.714 .32526 Mdot
.714 .32539 Mdot
.714 .32546 Mdot
.714 .32549 Mdot
.714 .32563 Mdot
.714 .32582 Mdot
.714 .32587 Mdot
.714 .32619 Mdot
.714 .32654 Mdot
.714 .32679 Mdot
.714 .32683 Mdot
.714 .32684 Mdot
.714 .32701 Mdot
.714 .32752 Mdot
.714 .32774 Mdot
.714 .32797 Mdot
.714 .32799 Mdot
.714 .32826 Mdot
.714 .32836 Mdot
.714 .3284 Mdot
.714 .32844 Mdot
.714 .32923 Mdot
.714 .32984 Mdot
.714 .32999 Mdot
.714 .33011 Mdot
.714 .33018 Mdot
.714 .33027 Mdot
.714 .33034 Mdot
.714 .33065 Mdot
.714 .33097 Mdot
.714 .33104 Mdot
.714 .33133 Mdot
.714 .33197 Mdot
.714 .33257 Mdot
.714 .33296 Mdot
.714 .33302 Mdot
.714 .33304 Mdot
.714 .33343 Mdot
.714 .33375 Mdot
.714 .33413 Mdot
.714 .33424 Mdot
.714 .33452 Mdot
.714 .3351 Mdot
.714 .33552 Mdot
.714 .33602 Mdot
.714 .33619 Mdot
.714 .33634 Mdot
.714 .33637 Mdot
.714 .33675 Mdot
.714 .33708 Mdot
.714 .33717 Mdot
.714 .33749 Mdot
.714 .33774 Mdot
.714 .33794 Mdot
.714 .33803 Mdot
.714 .33827 Mdot
.714 .3384 Mdot
.714 .33848 Mdot
.714 .3385 Mdot
.714 .33869 Mdot
.714 .33888 Mdot
.714 .3389 Mdot
.714 .33908 Mdot
.714 .33921 Mdot
.714 .33942 Mdot
.714 .33963 Mdot
.714 .33969 Mdot
.714 .34002 Mdot
.714 .34006 Mdot
.714 .3403 Mdot
.714 .34041 Mdot
.714 .3408 Mdot
.714 .34102 Mdot
.714 .34122 Mdot
.714 .3413 Mdot
.714 .34131 Mdot
.714 .34142 Mdot
.714 .34142 Mdot
.714 .34205 Mdot
.714 .34239 Mdot
.714 .34242 Mdot
.714 .34289 Mdot
.714 .34311 Mdot
.714 .34318 Mdot
.714 .34341 Mdot
.714 .34346 Mdot
.714 .34383 Mdot
.714 .34389 Mdot
.714 .34392 Mdot
.714 .34413 Mdot
.714 .34446 Mdot
.714 .34458 Mdot
.714 .34468 Mdot
.714 .34494 Mdot
.714 .34516 Mdot
.714 .3453 Mdot
.714 .34535 Mdot
.714 .34537 Mdot
.714 .34577 Mdot
.714 .34607 Mdot
.714 .34628 Mdot
.714 .34647 Mdot
.714 .34681 Mdot
.714 .34712 Mdot
.714 .34741 Mdot
.714 .3476 Mdot
.714 .34763 Mdot
.714 .34799 Mdot
.714 .34818 Mdot
.714 .34823 Mdot
.714 .34837 Mdot
.714 .3491 Mdot
.714 .34926 Mdot
.714 .34928 Mdot
.714 .34963 Mdot
.714 .35009 Mdot
.714 .35031 Mdot
.714 .35067 Mdot
.714 .35087 Mdot
.714 .35091 Mdot
.714 .35106 Mdot
.714 .35109 Mdot
.714 .35126 Mdot
.714 .35145 Mdot
.714 .35165 Mdot
.714 .3517 Mdot
.714 .35206 Mdot
.714 .35224 Mdot
.714 .35273 Mdot
.714 .35275 Mdot
.714 .35296 Mdot
.714 .35298 Mdot
.714 .35308 Mdot
.714 .35324 Mdot
.714 .35365 Mdot
.714 .35368 Mdot
.714 .35369 Mdot
.714 .35389 Mdot
.714 .35403 Mdot
.714 .35478 Mdot
.714 .3548 Mdot
.714 .35485 Mdot
.714 .35507 Mdot
.714 .35552 Mdot
.714 .35578 Mdot
.714 .356 Mdot
.714 .35629 Mdot
.714 .3564 Mdot
.714 .35658 Mdot
.714 .35667 Mdot
.714 .35697 Mdot
.714 .35706 Mdot
.714 .35741 Mdot
.714 .35747 Mdot
.714 .35755 Mdot
.714 .35775 Mdot
.714 .35787 Mdot
.714 .35794 Mdot
.714 .35831 Mdot
.714 .35844 Mdot
.714 .35879 Mdot
.714 .3589 Mdot
.714 .35904 Mdot
.714 .35923 Mdot
.714 .35938 Mdot
.714 .35942 Mdot
.714 .3596 Mdot
.714 .35962 Mdot
.714 .35976 Mdot
.714 .35982 Mdot
.714 .35985 Mdot
.714 .3601 Mdot
.714 .36049 Mdot
.714 .36058 Mdot
.714 .36115 Mdot
.714 .36208 Mdot
.714 .36248 Mdot
.714 .36281 Mdot
.714 .36329 Mdot
.714 .36342 Mdot
.714 .36365 Mdot
.714 .36397 Mdot
.714 .36406 Mdot
.714 .36433 Mdot
.714 .36438 Mdot
.714 .36446 Mdot
.714 .3646 Mdot
.714 .36465 Mdot
.714 .36469 Mdot
.714 .36494 Mdot
.714 .365 Mdot
.714 .36521 Mdot
.714 .36528 Mdot
.714 .3654 Mdot
.714 .36548 Mdot
.714 .36568 Mdot
.714 .36584 Mdot
.714 .36602 Mdot
.714 .36634 Mdot
.714 .36649 Mdot
.714 .36652 Mdot
.714 .36653 Mdot
.714 .36706 Mdot
.714 .36716 Mdot
.714 .3673 Mdot
.714 .36731 Mdot
.714 .36733 Mdot
.714 .36761 Mdot
.714 .36773 Mdot
.714 .3678 Mdot
.714 .36781 Mdot
.714 .36796 Mdot
.714 .36797 Mdot
.714 .36832 Mdot
.714 .36844 Mdot
.714 .36869 Mdot
.714 .36873 Mdot
.714 .36887 Mdot
.714 .369 Mdot
.714 .36912 Mdot
.714 .36914 Mdot
.714 .36925 Mdot
.714 .36927 Mdot
.714 .36942 Mdot
.714 .36967 Mdot
.714 .36982 Mdot
.714 .37015 Mdot
.714 .37039 Mdot
.714 .3704 Mdot
.714 .37051 Mdot
.714 .37103 Mdot
.714 .37112 Mdot
.714 .37116 Mdot
.714 .37129 Mdot
.714 .37154 Mdot
.714 .37156 Mdot
.714 .3717 Mdot
.714 .3719 Mdot
.714 .37212 Mdot
.714 .37235 Mdot
.714 .37249 Mdot
.714 .37263 Mdot
.714 .37284 Mdot
.714 .37313 Mdot
.714 .37314 Mdot
.714 .37318 Mdot
.714 .37328 Mdot
.714 .37343 Mdot
.714 .37361 Mdot
.714 .37368 Mdot
.714 .37377 Mdot
.714 .374 Mdot
.714 .37414 Mdot
.714 .37416 Mdot
.714 .37421 Mdot
.714 .37446 Mdot
.714 .3745 Mdot
.714 .37466 Mdot
.714 .37471 Mdot
.714 .37487 Mdot
.714 .3752 Mdot
.714 .37521 Mdot
.714 .37545 Mdot
.714 .37589 Mdot
.714 .3759 Mdot
.714 .37597 Mdot
.714 .37598 Mdot
.714 .37603 Mdot
.714 .37617 Mdot
.714 .37633 Mdot
.714 .3766 Mdot
.714 .37668 Mdot
.714 .37684 Mdot
.714 .37687 Mdot
.714 .3771 Mdot
.714 .37715 Mdot
.714 .37729 Mdot
.714 .37744 Mdot
.714 .37753 Mdot
.714 .37766 Mdot
.714 .37767 Mdot
.714 .3778 Mdot
.714 .37794 Mdot
.714 .37795 Mdot
.714 .378 Mdot
.714 .3781 Mdot
.714 .37827 Mdot
.714 .37833 Mdot
.714 .37847 Mdot
.714 .37864 Mdot
.714 .37887 Mdot
.714 .37893 Mdot
.714 .37916 Mdot
.714 .37943 Mdot
.714 .37945 Mdot
.714 .37955 Mdot
.714 .37968 Mdot
.714 .38003 Mdot
.714 .38032 Mdot
.714 .38072 Mdot
.714 .38092 Mdot
.714 .381 Mdot
.714 .38126 Mdot
.714 .38149 Mdot
.714 .38176 Mdot
.714 .38178 Mdot
.714 .38182 Mdot
.714 .38209 Mdot
.714 .38251 Mdot
.714 .38296 Mdot
.714 .38316 Mdot
.714 .38321 Mdot
.714 .38343 Mdot
.714 .38365 Mdot
.714 .3837 Mdot
.714 .38377 Mdot
.714 .38381 Mdot
.714 .3839 Mdot
.714 .384 Mdot
.714 .38443 Mdot
.714 .38498 Mdot
.714 .38501 Mdot
.714 .38504 Mdot
.714 .38511 Mdot
.714 .3853 Mdot
.714 .38531 Mdot
.714 .38547 Mdot
.714 .38563 Mdot
.714 .38599 Mdot
.714 .38611 Mdot
.714 .38611 Mdot
.714 .38614 Mdot
.714 .38631 Mdot
.714 .38656 Mdot
.714 .38678 Mdot
.714 .38682 Mdot
.714 .38695 Mdot
.714 .38705 Mdot
.714 .38707 Mdot
.714 .38712 Mdot
.714 .38721 Mdot
.714 .38742 Mdot
.714 .38758 Mdot
.714 .38765 Mdot
.714 .38773 Mdot
.714 .38776 Mdot
.714 .3878 Mdot
.714 .38798 Mdot
.714 .38813 Mdot
.714 .38816 Mdot
.714 .38823 Mdot
.714 .38855 Mdot
.714 .3886 Mdot
.714 .38864 Mdot
.714 .3891 Mdot
.714 .38918 Mdot
.714 .38922 Mdot
.714 .38926 Mdot
.714 .38937 Mdot
.714 .38974 Mdot
.714 .38979 Mdot
.714 .3898 Mdot
.714 .38981 Mdot
.714 .39032 Mdot
.714 .39053 Mdot
.714 .39065 Mdot
.714 .39065 Mdot
.714 .3908 Mdot
.714 .39082 Mdot
.714 .39094 Mdot
.714 .39109 Mdot
.714 .39118 Mdot
.714 .39122 Mdot
.714 .39131 Mdot
.714 .39154 Mdot
.714 .39169 Mdot
.714 .39181 Mdot
.714 .39209 Mdot
.714 .39223 Mdot
.714 .39225 Mdot
.714 .39258 Mdot
.714 .39265 Mdot
.714 .39311 Mdot
.714 .39321 Mdot
.714 .39328 Mdot
.714 .39333 Mdot
.714 .39337 Mdot
.714 .3935 Mdot
.714 .39353 Mdot
.714 .39357 Mdot
.714 .39381 Mdot
.714 .39397 Mdot
.714 .39399 Mdot
.714 .39424 Mdot
.714 .39428 Mdot
.714 .39453 Mdot
.714 .39454 Mdot
.714 .39481 Mdot
.714 .39484 Mdot
.714 .3949 Mdot
.714 .39495 Mdot
.714 .395 Mdot
.714 .3951 Mdot
.714 .39514 Mdot
.714 .39549 Mdot
.714 .39559 Mdot
.714 .39562 Mdot
.714 .39562 Mdot
.714 .39573 Mdot
.714 .3959 Mdot
.714 .3959 Mdot
.714 .39624 Mdot
.714 .39626 Mdot
.714 .39652 Mdot
.714 .39671 Mdot
.714 .39684 Mdot
.714 .39732 Mdot
.714 .39786 Mdot
.714 .39791 Mdot
.714 .39797 Mdot
.714 .39811 Mdot
.714 .39817 Mdot
.714 .3983 Mdot
.714 .39834 Mdot
.714 .39836 Mdot
.714 .39852 Mdot
.714 .39908 Mdot
.714 .39928 Mdot
.714 .39967 Mdot
.714 .39985 Mdot
.714 .40016 Mdot
.714 .40016 Mdot
.714 .40028 Mdot
.714 .4005 Mdot
.714 .4009 Mdot
.714 .4009 Mdot
.714 .40105 Mdot
.714 .40159 Mdot
.714 .40163 Mdot
.714 .40182 Mdot
.714 .40193 Mdot
.714 .40206 Mdot
.714 .40222 Mdot
.714 .40229 Mdot
.714 .40256 Mdot
.714 .40262 Mdot
.714 .40265 Mdot
.714 .40273 Mdot
.714 .40275 Mdot
.714 .40281 Mdot
.714 .40322 Mdot
.714 .40329 Mdot
.714 .40409 Mdot
.714 .40412 Mdot
.714 .40415 Mdot
.714 .40448 Mdot
.714 .40468 Mdot
.714 .40479 Mdot
.714 .40485 Mdot
.714 .40488 Mdot
.714 .40505 Mdot
.714 .40508 Mdot
.714 .40517 Mdot
.714 .40529 Mdot
.714 .40546 Mdot
.714 .40557 Mdot
.714 .40574 Mdot
.714 .40588 Mdot
.714 .40593 Mdot
.714 .40602 Mdot
.714 .40605 Mdot
.714 .40615 Mdot
.714 .40646 Mdot
.714 .40657 Mdot
.714 .4067 Mdot
.714 .40679 Mdot
.714 .40682 Mdot
.714 .40697 Mdot
.714 .40718 Mdot
.714 .40753 Mdot
.714 .40762 Mdot
.714 .40785 Mdot
.714 .40806 Mdot
.714 .40855 Mdot
.714 .40868 Mdot
.714 .4087 Mdot
.714 .409 Mdot
.714 .40919 Mdot
.714 .40919 Mdot
.714 .40924 Mdot
.714 .40929 Mdot
.714 .40945 Mdot
.714 .40947 Mdot
.714 .4095 Mdot
.714 .40983 Mdot
.714 .40985 Mdot
.714 .41018 Mdot
.714 .4103 Mdot
.714 .4105 Mdot
.714 .41068 Mdot
.714 .41108 Mdot
.714 .41109 Mdot
.714 .41123 Mdot
.714 .41132 Mdot
.714 .41147 Mdot
.714 .41148 Mdot
.714 .41154 Mdot
.714 .41189 Mdot
.714 .412 Mdot
.714 .41204 Mdot
.714 .41239 Mdot
.714 .41272 Mdot
.714 .41277 Mdot
.714 .41283 Mdot
.714 .41286 Mdot
.714 .41292 Mdot
.714 .41314 Mdot
.714 .4132 Mdot
.714 .41325 Mdot
.714 .41334 Mdot
.714 .41336 Mdot
.714 .41339 Mdot
.714 .41344 Mdot
.714 .41354 Mdot
.714 .41372 Mdot
.714 .41373 Mdot
.714 .41416 Mdot
.714 .41436 Mdot
.714 .41439 Mdot
.714 .41448 Mdot
.714 .41461 Mdot
.714 .41465 Mdot
.714 .41479 Mdot
.714 .41485 Mdot
.714 .41494 Mdot
.714 .4153 Mdot
.714 .4156 Mdot
.714 .41566 Mdot
.714 .41566 Mdot
.714 .41581 Mdot
.714 .41609 Mdot
.714 .41646 Mdot
.714 .41655 Mdot
.714 .41657 Mdot
.714 .41663 Mdot
.714 .41673 Mdot
.714 .41744 Mdot
.714 .41758 Mdot
.714 .41775 Mdot
.714 .41783 Mdot
.714 .41789 Mdot
.714 .4179 Mdot
.714 .41814 Mdot
.714 .41819 Mdot
.714 .41824 Mdot
.714 .41842 Mdot
.714 .41869 Mdot
.714 .41889 Mdot
.714 .41891 Mdot
.714 .41899 Mdot
.714 .41901 Mdot
.714 .41903 Mdot
.714 .41955 Mdot
.714 .41975 Mdot
.714 .41981 Mdot
.714 .42 Mdot
.714 .42006 Mdot
.714 .42011 Mdot
.714 .42038 Mdot
.714 .42049 Mdot
.714 .42073 Mdot
.714 .42074 Mdot
.714 .42074 Mdot
.714 .42095 Mdot
.714 .42104 Mdot
.714 .42108 Mdot
.714 .42131 Mdot
.714 .42133 Mdot
.714 .42154 Mdot
.714 .42163 Mdot
.714 .42174 Mdot
.714 .4218 Mdot
.714 .42183 Mdot
.714 .4219 Mdot
.714 .42209 Mdot
.714 .42214 Mdot
.714 .4222 Mdot
.714 .42233 Mdot
.714 .42255 Mdot
.714 .42255 Mdot
.714 .42286 Mdot
.714 .42295 Mdot
.714 .4231 Mdot
.714 .42363 Mdot
.714 .42368 Mdot
.714 .4237 Mdot
.714 .42376 Mdot
.714 .42397 Mdot
.714 .424 Mdot
.714 .42468 Mdot
.714 .42481 Mdot
.714 .42539 Mdot
.714 .42553 Mdot
.714 .42576 Mdot
.714 .42596 Mdot
.714 .4261 Mdot
.714 .42621 Mdot
.714 .4263 Mdot
.714 .42636 Mdot
.714 .42648 Mdot
.714 .42652 Mdot
.714 .42656 Mdot
.714 .42662 Mdot
.714 .42669 Mdot
.714 .42669 Mdot
.714 .42675 Mdot
.714 .42687 Mdot
.714 .42717 Mdot
.714 .42742 Mdot
.714 .42752 Mdot
.714 .42756 Mdot
.714 .42756 Mdot
.714 .42789 Mdot
.714 .42806 Mdot
.714 .42814 Mdot
.714 .42816 Mdot
.714 .42839 Mdot
.714 .42864 Mdot
.714 .42868 Mdot
.714 .42877 Mdot
.714 .42884 Mdot
.714 .42923 Mdot
.714 .42929 Mdot
.714 .42941 Mdot
.714 .42952 Mdot
.714 .42962 Mdot
.714 .42982 Mdot
.714 .4299 Mdot
.714 .42995 Mdot
.714 .43025 Mdot
.714 .43026 Mdot
.714 .43061 Mdot
.714 .43081 Mdot
.714 .43087 Mdot
.714 .43088 Mdot
.714 .43107 Mdot
.714 .43109 Mdot
.714 .43144 Mdot
.714 .43145 Mdot
.714 .43153 Mdot
.714 .43177 Mdot
.714 .43177 Mdot
.714 .43215 Mdot
.714 .43217 Mdot
.714 .4324 Mdot
.714 .4327 Mdot
.714 .43276 Mdot
.714 .4331 Mdot
.714 .43336 Mdot
.714 .43356 Mdot
.714 .43397 Mdot
.714 .43433 Mdot
.714 .43511 Mdot
.714 .43543 Mdot
.714 .43544 Mdot
.714 .43547 Mdot
.714 .43554 Mdot
.714 .43555 Mdot
.714 .43566 Mdot
.714 .43582 Mdot
.714 .43594 Mdot
.716 .25492 Mdot
.716 .25504 Mdot
.716 .25587 Mdot
.716 .25598 Mdot
.716 .25612 Mdot
.716 .25619 Mdot
.716 .25678 Mdot
.716 .2571 Mdot
.716 .25744 Mdot
.716 .25764 Mdot
.716 .25773 Mdot
.716 .25788 Mdot
.716 .2584 Mdot
.716 .25859 Mdot
.716 .2588 Mdot
.716 .25905 Mdot
.716 .25962 Mdot
.716 .25974 Mdot
.716 .25976 Mdot
.716 .25992 Mdot
.716 .26001 Mdot
.716 .2601 Mdot
.716 .2603 Mdot
.716 .26033 Mdot
.716 .26047 Mdot
.716 .26067 Mdot
.716 .26099 Mdot
.716 .26144 Mdot
.716 .26213 Mdot
.716 .26213 Mdot
.716 .26222 Mdot
.716 .26224 Mdot
.716 .26282 Mdot
.716 .26307 Mdot
.716 .2633 Mdot
.716 .26362 Mdot
.716 .26366 Mdot
.716 .26385 Mdot
.716 .26402 Mdot
.716 .2645 Mdot
.716 .26463 Mdot
.716 .26465 Mdot
.716 .26512 Mdot
.716 .26525 Mdot
.716 .26542 Mdot
.716 .26556 Mdot
.716 .26563 Mdot
.716 .26585 Mdot
.716 .26595 Mdot
.716 .2661 Mdot
.716 .26611 Mdot
.716 .2665 Mdot
.716 .26657 Mdot
.716 .26709 Mdot
.716 .26734 Mdot
.716 .26797 Mdot
.716 .26821 Mdot
.716 .26845 Mdot
.716 .26853 Mdot
.716 .26871 Mdot
.716 .26881 Mdot
.716 .26932 Mdot
.716 .2694 Mdot
.716 .27011 Mdot
.716 .27063 Mdot
.716 .27092 Mdot
.716 .27113 Mdot
.716 .27221 Mdot
.716 .27237 Mdot
.716 .27258 Mdot
.716 .27277 Mdot
.716 .27284 Mdot
.716 .27289 Mdot
.716 .27312 Mdot
.716 .27347 Mdot
.716 .2736 Mdot
.716 .27362 Mdot
.716 .27403 Mdot
.716 .27435 Mdot
.716 .27462 Mdot
.716 .27466 Mdot
.716 .27497 Mdot
.716 .2751 Mdot
.716 .27534 Mdot
.716 .27536 Mdot
.716 .27538 Mdot
.716 .27553 Mdot
.716 .27581 Mdot
.716 .27582 Mdot
.716 .27584 Mdot
.716 .27586 Mdot
.716 .27606 Mdot
.716 .27607 Mdot
.716 .27638 Mdot
.716 .27657 Mdot
.716 .27667 Mdot
.716 .27682 Mdot
.716 .27717 Mdot
.716 .27718 Mdot
.716 .27722 Mdot
.716 .27768 Mdot
.716 .27775 Mdot
.716 .27781 Mdot
.716 .27802 Mdot
.716 .27834 Mdot
.716 .27851 Mdot
.716 .27852 Mdot
.716 .27893 Mdot
.716 .28002 Mdot
.716 .28024 Mdot
.716 .28029 Mdot
.716 .28062 Mdot
.716 .28066 Mdot
.716 .28079 Mdot
.716 .28104 Mdot
.716 .28107 Mdot
.716 .28124 Mdot
.716 .2815 Mdot
.716 .2816 Mdot
.716 .28163 Mdot
.716 .28186 Mdot
.716 .28219 Mdot
.716 .28279 Mdot
.716 .28314 Mdot
.716 .28322 Mdot
.716 .28362 Mdot
.716 .28406 Mdot
.716 .28413 Mdot
.716 .2842 Mdot
.716 .28424 Mdot
.716 .28545 Mdot
.716 .28557 Mdot
.716 .28587 Mdot
.716 .28608 Mdot
.716 .28613 Mdot
.716 .28615 Mdot
.716 .2862 Mdot
.716 .28622 Mdot
.716 .28636 Mdot
.716 .28665 Mdot
.716 .28707 Mdot
.716 .28724 Mdot
.716 .28746 Mdot
.716 .28777 Mdot
.716 .28778 Mdot
.716 .28778 Mdot
.716 .28789 Mdot
.716 .28789 Mdot
.716 .28794 Mdot
.716 .28835 Mdot
.716 .28841 Mdot
.716 .28895 Mdot
.716 .28907 Mdot
.716 .28924 Mdot
.716 .28926 Mdot
.716 .29028 Mdot
.716 .29039 Mdot
.716 .29073 Mdot
.716 .29088 Mdot
.716 .29108 Mdot
.716 .29152 Mdot
.716 .29172 Mdot
.716 .29193 Mdot
.716 .2921 Mdot
.716 .29282 Mdot
.716 .29323 Mdot
.716 .29346 Mdot
.716 .29349 Mdot
.716 .29354 Mdot
.716 .29354 Mdot
.716 .29389 Mdot
.716 .29409 Mdot
.716 .29423 Mdot
.716 .29447 Mdot
.716 .29461 Mdot
.716 .29557 Mdot
.716 .29654 Mdot
.716 .29655 Mdot
.716 .2966 Mdot
.716 .29673 Mdot
.716 .29681 Mdot
.716 .29695 Mdot
.716 .29701 Mdot
.716 .29719 Mdot
.716 .29785 Mdot
.716 .2983 Mdot
.716 .29843 Mdot
.716 .29869 Mdot
.716 .29871 Mdot
.716 .29871 Mdot
.716 .29888 Mdot
.716 .29926 Mdot
.716 .29935 Mdot
.716 .29937 Mdot
.716 .29937 Mdot
.716 .29959 Mdot
.716 .2996 Mdot
.716 .2996 Mdot
.716 .29995 Mdot
.716 .30024 Mdot
.716 .30069 Mdot
.716 .30095 Mdot
.716 .30105 Mdot
.716 .30176 Mdot
.716 .3019 Mdot
.716 .3025 Mdot
.716 .30254 Mdot
.716 .30279 Mdot
.716 .30284 Mdot
.716 .30293 Mdot
.716 .30297 Mdot
.716 .30308 Mdot
.716 .30351 Mdot
.716 .30392 Mdot
.716 .30411 Mdot
.716 .30411 Mdot
.716 .30438 Mdot
.716 .30459 Mdot
.716 .30482 Mdot
.716 .30483 Mdot
.716 .30559 Mdot
.716 .306 Mdot
.716 .30605 Mdot
.716 .3066 Mdot
.716 .30686 Mdot
.716 .30694 Mdot
.716 .30708 Mdot
.716 .30721 Mdot
.716 .30727 Mdot
.716 .30755 Mdot
.716 .30777 Mdot
.716 .30812 Mdot
.716 .30824 Mdot
.716 .3085 Mdot
.716 .30894 Mdot
.716 .30898 Mdot
.716 .3091 Mdot
.716 .30983 Mdot
.716 .30989 Mdot
.716 .31035 Mdot
.716 .31074 Mdot
.716 .31106 Mdot
.716 .3112 Mdot
.716 .31153 Mdot
.716 .31172 Mdot
.716 .31219 Mdot
.716 .31227 Mdot
.716 .31235 Mdot
.716 .31247 Mdot
.716 .31263 Mdot
.716 .31301 Mdot
.716 .31335 Mdot
.716 .3134 Mdot
.716 .31368 Mdot
.716 .31392 Mdot
.716 .31407 Mdot
.716 .31409 Mdot
.716 .31419 Mdot
.716 .31427 Mdot
.716 .3145 Mdot
.716 .31487 Mdot
.716 .31495 Mdot
.716 .31505 Mdot
.716 .31516 Mdot
.716 .31521 Mdot
.716 .31551 Mdot
.716 .31576 Mdot
.716 .31619 Mdot
.716 .31724 Mdot
.716 .31774 Mdot
.716 .31826 Mdot
.716 .31853 Mdot
.716 .31857 Mdot
.716 .31859 Mdot
.716 .31888 Mdot
.716 .31894 Mdot
.716 .31895 Mdot
.716 .31931 Mdot
.716 .31946 Mdot
.716 .31961 Mdot
.716 .31967 Mdot
.716 .31988 Mdot
.716 .32003 Mdot
.716 .32015 Mdot
.716 .32029 Mdot
.716 .32039 Mdot
.716 .32044 Mdot
.716 .32093 Mdot
.716 .32099 Mdot
.716 .32125 Mdot
.716 .32134 Mdot
.716 .32134 Mdot
.716 .32207 Mdot
.716 .32218 Mdot
.716 .32236 Mdot
.716 .32257 Mdot
.716 .32297 Mdot
.716 .32313 Mdot
.716 .32342 Mdot
.716 .32359 Mdot
.716 .32363 Mdot
.716 .32404 Mdot
.716 .32407 Mdot
.716 .32411 Mdot
.716 .32413 Mdot
.716 .32472 Mdot
.716 .32502 Mdot
.716 .32505 Mdot
.716 .32506 Mdot
.716 .32508 Mdot
.716 .32509 Mdot
.716 .32559 Mdot
.716 .3257 Mdot
.716 .32585 Mdot
.716 .32591 Mdot
.716 .32613 Mdot
.716 .32642 Mdot
.716 .32648 Mdot
.716 .32656 Mdot
.716 .32707 Mdot
.716 .32713 Mdot
.716 .32737 Mdot
.716 .32777 Mdot
.716 .32796 Mdot
.716 .32862 Mdot
.716 .32864 Mdot
.716 .32866 Mdot
.716 .32883 Mdot
.716 .32893 Mdot
.716 .32919 Mdot
.716 .32965 Mdot
.716 .33012 Mdot
.716 .33022 Mdot
.716 .33026 Mdot
.716 .33036 Mdot
.716 .33077 Mdot
.716 .33118 Mdot
.716 .33118 Mdot
.716 .33119 Mdot
.716 .33127 Mdot
.716 .33151 Mdot
.716 .33179 Mdot
.716 .33228 Mdot
.716 .33267 Mdot
.716 .33305 Mdot
.716 .33372 Mdot
.716 .33382 Mdot
.716 .33405 Mdot
.716 .33416 Mdot
.716 .33417 Mdot
.716 .33454 Mdot
.716 .33474 Mdot
.716 .33476 Mdot
.716 .33503 Mdot
.716 .33536 Mdot
.716 .3355 Mdot
.716 .3356 Mdot
.716 .33583 Mdot
.716 .33596 Mdot
.716 .33619 Mdot
.716 .33664 Mdot
.716 .33686 Mdot
.716 .33705 Mdot
.716 .33727 Mdot
.716 .33743 Mdot
.716 .33784 Mdot
.716 .33797 Mdot
.716 .33849 Mdot
.716 .33868 Mdot
.716 .33869 Mdot
.716 .33889 Mdot
.716 .33907 Mdot
.716 .33921 Mdot
.716 .33923 Mdot
.716 .3395 Mdot
.716 .33971 Mdot
.716 .34022 Mdot
.716 .34072 Mdot
.716 .34085 Mdot
.716 .34102 Mdot
.716 .34105 Mdot
.716 .34123 Mdot
.716 .3413 Mdot
.716 .34141 Mdot
.716 .34151 Mdot
.716 .34176 Mdot
.716 .34178 Mdot
.716 .34202 Mdot
.716 .34205 Mdot
.716 .34263 Mdot
.716 .34309 Mdot
.716 .34323 Mdot
.716 .34403 Mdot
.716 .34405 Mdot
.716 .34435 Mdot
.716 .34445 Mdot
.716 .34456 Mdot
.716 .3447 Mdot
.716 .34502 Mdot
.716 .34516 Mdot
.716 .34545 Mdot
.716 .34578 Mdot
.716 .34587 Mdot
.716 .34605 Mdot
.716 .34657 Mdot
.716 .34662 Mdot
.716 .34702 Mdot
.716 .34702 Mdot
.716 .34706 Mdot
.716 .34732 Mdot
.716 .34755 Mdot
.716 .34775 Mdot
.716 .34793 Mdot
.716 .3483 Mdot
.716 .34842 Mdot
.716 .34848 Mdot
.716 .34866 Mdot
.716 .34876 Mdot
.716 .3489 Mdot
.716 .34906 Mdot
.716 .34912 Mdot
.716 .34918 Mdot
.716 .34935 Mdot
.716 .34946 Mdot
.716 .34979 Mdot
.716 .34988 Mdot
.716 .35027 Mdot
.716 .35033 Mdot
.716 .35067 Mdot
.716 .35078 Mdot
.716 .35093 Mdot
.716 .35108 Mdot
.716 .35167 Mdot
.716 .35174 Mdot
.716 .35182 Mdot
.716 .35183 Mdot
.716 .35192 Mdot
.716 .35196 Mdot
.716 .35201 Mdot
.716 .35218 Mdot
.716 .35219 Mdot
.716 .35232 Mdot
.716 .3526 Mdot
.716 .35349 Mdot
.716 .35361 Mdot
.716 .35418 Mdot
.716 .35452 Mdot
.716 .35455 Mdot
.716 .35474 Mdot
.716 .355 Mdot
.716 .3551 Mdot
.716 .35519 Mdot
.716 .35543 Mdot
.716 .35545 Mdot
.716 .35559 Mdot
.716 .35566 Mdot
.716 .35579 Mdot
.716 .35588 Mdot
.716 .35593 Mdot
.716 .35614 Mdot
.716 .35636 Mdot
.716 .35653 Mdot
.716 .35665 Mdot
.716 .35672 Mdot
.716 .35701 Mdot
.716 .35704 Mdot
.716 .35708 Mdot
.716 .35709 Mdot
.716 .35713 Mdot
.716 .35733 Mdot
.716 .35747 Mdot
.716 .3579 Mdot
.716 .35824 Mdot
.716 .35841 Mdot
.716 .35851 Mdot
.716 .35864 Mdot
.716 .35868 Mdot
.716 .35884 Mdot
.716 .35886 Mdot
.716 .35896 Mdot
.716 .35902 Mdot
.716 .35919 Mdot
.716 .35944 Mdot
.716 .35962 Mdot
.716 .35965 Mdot
.716 .35967 Mdot
.716 .35984 Mdot
.716 .36005 Mdot
.716 .36021 Mdot
.716 .3603 Mdot
.716 .36041 Mdot
.716 .36051 Mdot
.716 .36056 Mdot
.716 .36068 Mdot
.716 .36089 Mdot
.716 .3609 Mdot
.716 .36091 Mdot
.716 .36122 Mdot
.716 .36135 Mdot
.716 .3614 Mdot
.716 .3615 Mdot
.716 .36152 Mdot
.716 .36181 Mdot
.716 .36181 Mdot
.716 .36229 Mdot
.716 .3625 Mdot
.716 .36251 Mdot
.716 .36258 Mdot
.716 .36271 Mdot
.716 .36292 Mdot
.716 .36293 Mdot
.716 .36294 Mdot
.716 .36308 Mdot
.716 .36316 Mdot
.716 .36335 Mdot
.716 .36367 Mdot
.716 .36378 Mdot
.716 .3638 Mdot
.716 .36383 Mdot
.716 .36395 Mdot
.716 .36412 Mdot
.716 .36424 Mdot
.716 .36429 Mdot
.716 .36437 Mdot
.716 .36451 Mdot
.716 .3646 Mdot
.716 .36466 Mdot
.716 .36479 Mdot
.716 .36502 Mdot
.716 .36533 Mdot
.716 .36542 Mdot
.716 .36556 Mdot
.716 .36559 Mdot
.716 .36559 Mdot
.716 .36562 Mdot
.716 .36564 Mdot
.716 .36585 Mdot
.716 .3659 Mdot
.716 .36598 Mdot
.716 .3661 Mdot
.716 .36625 Mdot
.716 .3664 Mdot
.716 .36643 Mdot
.716 .36649 Mdot
.716 .36659 Mdot
.716 .36664 Mdot
.716 .36673 Mdot
.716 .36675 Mdot
.716 .36692 Mdot
.716 .36698 Mdot
.716 .36705 Mdot
.716 .36723 Mdot
.716 .36737 Mdot
.716 .36738 Mdot
.716 .36762 Mdot
.716 .36802 Mdot
.716 .3681 Mdot
.716 .36872 Mdot
.716 .36892 Mdot
.716 .36901 Mdot
.716 .36902 Mdot
.716 .36914 Mdot
.716 .36917 Mdot
.716 .3692 Mdot
.716 .36926 Mdot
.716 .36927 Mdot
.716 .36933 Mdot
.716 .36937 Mdot
.716 .36979 Mdot
.716 .36989 Mdot
.716 .37 Mdot
.716 .37007 Mdot
.716 .37031 Mdot
.716 .37035 Mdot
.716 .37062 Mdot
.716 .37069 Mdot
.716 .37092 Mdot
.716 .37099 Mdot
.716 .37112 Mdot
.716 .37115 Mdot
.716 .3712 Mdot
.716 .37131 Mdot
.716 .37141 Mdot
.716 .37148 Mdot
.716 .3716 Mdot
.716 .37164 Mdot
.716 .37172 Mdot
.716 .37198 Mdot
.716 .37211 Mdot
.716 .37225 Mdot
.716 .37241 Mdot
.716 .37259 Mdot
.716 .37262 Mdot
.716 .37262 Mdot
.716 .3729 Mdot
.716 .37294 Mdot
.716 .3733 Mdot
.716 .37342 Mdot
.716 .37349 Mdot
.716 .37372 Mdot
.716 .37392 Mdot
.716 .37402 Mdot
.716 .37424 Mdot
.716 .37434 Mdot
.716 .37442 Mdot
.716 .37449 Mdot
.716 .3747 Mdot
.716 .37471 Mdot
.716 .37526 Mdot
.716 .37536 Mdot
.716 .37569 Mdot
.716 .37609 Mdot
.716 .37611 Mdot
.716 .37628 Mdot
.716 .3763 Mdot
.716 .37647 Mdot
.716 .37654 Mdot
.716 .37661 Mdot
.716 .37667 Mdot
.716 .37679 Mdot
.716 .37681 Mdot
.716 .37693 Mdot
.716 .37702 Mdot
.716 .37737 Mdot
.716 .37773 Mdot
.716 .37787 Mdot
.716 .37806 Mdot
.716 .37808 Mdot
.716 .37818 Mdot
.716 .3783 Mdot
.716 .37844 Mdot
.716 .37845 Mdot
.716 .37858 Mdot
.716 .37894 Mdot
.716 .37903 Mdot
.716 .37931 Mdot
.716 .37943 Mdot
.716 .37958 Mdot
.716 .37972 Mdot
.716 .37987 Mdot
.716 .38018 Mdot
.716 .38035 Mdot
.716 .38043 Mdot
.716 .38059 Mdot
.716 .38067 Mdot
.716 .38076 Mdot
.716 .38099 Mdot
.716 .38118 Mdot
.716 .3812 Mdot
.716 .38134 Mdot
.716 .3816 Mdot
.716 .3816 Mdot
.716 .38168 Mdot
.716 .38184 Mdot
.716 .38191 Mdot
.716 .38238 Mdot
.716 .38264 Mdot
.716 .38292 Mdot
.716 .38326 Mdot
.716 .38345 Mdot
.716 .38362 Mdot
.716 .38368 Mdot
.716 .38368 Mdot
.716 .38369 Mdot
.716 .38397 Mdot
.716 .38425 Mdot
.716 .38426 Mdot
.716 .38433 Mdot
.716 .38435 Mdot
.716 .38442 Mdot
.716 .38475 Mdot
.716 .38507 Mdot
.716 .38525 Mdot
.716 .38532 Mdot
.716 .38544 Mdot
.716 .38546 Mdot
.716 .38547 Mdot
.716 .38593 Mdot
.716 .38606 Mdot
.716 .38635 Mdot
.716 .38651 Mdot
.716 .38655 Mdot
.716 .38691 Mdot
.716 .38696 Mdot
.716 .387 Mdot
.716 .38721 Mdot
.716 .38736 Mdot
.716 .3874 Mdot
.716 .38751 Mdot
.716 .38758 Mdot
.716 .38793 Mdot
.716 .38794 Mdot
.716 .38796 Mdot
.716 .38796 Mdot
.716 .38798 Mdot
.716 .3882 Mdot
.716 .38861 Mdot
.716 .38862 Mdot
.716 .38865 Mdot
.716 .38867 Mdot
.716 .38896 Mdot
.716 .38898 Mdot
.716 .3891 Mdot
.716 .38931 Mdot
.716 .38942 Mdot
.716 .3897 Mdot
.716 .38984 Mdot
.716 .38997 Mdot
.716 .39005 Mdot
.716 .39055 Mdot
.716 .39056 Mdot
.716 .39062 Mdot
.716 .3908 Mdot
.716 .39084 Mdot
.716 .39118 Mdot
.716 .39122 Mdot
.716 .39128 Mdot
.716 .39139 Mdot
.716 .39147 Mdot
.716 .39157 Mdot
.716 .39172 Mdot
.716 .39176 Mdot
.716 .39187 Mdot
.716 .39198 Mdot
.716 .39222 Mdot
.716 .39223 Mdot
.716 .39227 Mdot
.716 .39247 Mdot
.716 .39249 Mdot
.716 .39251 Mdot
.716 .3927 Mdot
.716 .39307 Mdot
.716 .39342 Mdot
.716 .39415 Mdot
.716 .39445 Mdot
.716 .39463 Mdot
.716 .39483 Mdot
.716 .39487 Mdot
.716 .39495 Mdot
.716 .39502 Mdot
.716 .39507 Mdot
.716 .39533 Mdot
.716 .39549 Mdot
.716 .39555 Mdot
.716 .39562 Mdot
.716 .39563 Mdot
.716 .39574 Mdot
.716 .3959 Mdot
.716 .3961 Mdot
.716 .39613 Mdot
.716 .39637 Mdot
.716 .39663 Mdot
.716 .39675 Mdot
.716 .39683 Mdot
.716 .39689 Mdot
.716 .39694 Mdot
.716 .39727 Mdot
.716 .39741 Mdot
.716 .39764 Mdot
.716 .39774 Mdot
.716 .39796 Mdot
.716 .39823 Mdot
.716 .39855 Mdot
.716 .39859 Mdot
.716 .3991 Mdot
.716 .39919 Mdot
.716 .39921 Mdot
.716 .39952 Mdot
.716 .3997 Mdot
.716 .39979 Mdot
.716 .40003 Mdot
.716 .40018 Mdot
.716 .40038 Mdot
.716 .40042 Mdot
.716 .40051 Mdot
.716 .40061 Mdot
.716 .40067 Mdot
.716 .40085 Mdot
.716 .40123 Mdot
.716 .40126 Mdot
.716 .40155 Mdot
.716 .40208 Mdot
.716 .40209 Mdot
.716 .40225 Mdot
.716 .4024 Mdot
.716 .40259 Mdot
.716 .40259 Mdot
.716 .40272 Mdot
.716 .40301 Mdot
.716 .40331 Mdot
.716 .40339 Mdot
.716 .40341 Mdot
.716 .40348 Mdot
.716 .40351 Mdot
.716 .40368 Mdot
.716 .40371 Mdot
.716 .40413 Mdot
.716 .40423 Mdot
.716 .40472 Mdot
.716 .40479 Mdot
.716 .40498 Mdot
.716 .40529 Mdot
.716 .40549 Mdot
.716 .40573 Mdot
.716 .40574 Mdot
.716 .40574 Mdot
.716 .40589 Mdot
.716 .4059 Mdot
.716 .40591 Mdot
.716 .40598 Mdot
.716 .40624 Mdot
.716 .40636 Mdot
.716 .40636 Mdot
.716 .40637 Mdot
.716 .40655 Mdot
.716 .40664 Mdot
.716 .40695 Mdot
.716 .40742 Mdot
.716 .40754 Mdot
.716 .40759 Mdot
.716 .40768 Mdot
.716 .40774 Mdot
.716 .40783 Mdot
.716 .40786 Mdot
.716 .40788 Mdot
.716 .40855 Mdot
.716 .40922 Mdot
.716 .40932 Mdot
.716 .40949 Mdot
.716 .40958 Mdot
.716 .40973 Mdot
.716 .40997 Mdot
.716 .40997 Mdot
.716 .41001 Mdot
.716 .41002 Mdot
.716 .41018 Mdot
.716 .41047 Mdot
.716 .41097 Mdot
.716 .41109 Mdot
.716 .41124 Mdot
.716 .41138 Mdot
.716 .41168 Mdot
.716 .41183 Mdot
.716 .41193 Mdot
.716 .41217 Mdot
.716 .41225 Mdot
.716 .41296 Mdot
.716 .41297 Mdot
.716 .41309 Mdot
.716 .41317 Mdot
.716 .41355 Mdot
.716 .41359 Mdot
.716 .41388 Mdot
.716 .41391 Mdot
.716 .41392 Mdot
.716 .41399 Mdot
.716 .41399 Mdot
.716 .414 Mdot
.716 .41421 Mdot
.716 .41436 Mdot
.716 .41449 Mdot
.716 .41478 Mdot
.716 .41498 Mdot
.716 .41508 Mdot
.716 .4151 Mdot
.716 .41513 Mdot
.716 .41514 Mdot
.716 .41518 Mdot
.716 .41532 Mdot
.716 .41553 Mdot
.716 .41562 Mdot
.716 .41646 Mdot
.716 .41649 Mdot
.716 .41654 Mdot
.716 .41659 Mdot
.716 .4169 Mdot
.716 .41718 Mdot
.716 .41723 Mdot
.716 .41748 Mdot
.716 .4179 Mdot
.716 .41812 Mdot
.716 .41828 Mdot
.716 .41831 Mdot
.716 .41838 Mdot
.716 .41856 Mdot
.716 .41868 Mdot
.716 .41869 Mdot
.716 .41887 Mdot
.716 .41896 Mdot
.716 .41899 Mdot
.716 .41922 Mdot
.716 .41926 Mdot
.716 .41941 Mdot
.716 .42017 Mdot
.716 .42045 Mdot
.716 .42046 Mdot
.716 .42058 Mdot
.716 .42081 Mdot
.716 .42095 Mdot
.716 .42099 Mdot
.716 .42104 Mdot
.716 .42137 Mdot
.716 .4214 Mdot
.716 .4214 Mdot
.716 .42165 Mdot
.716 .42175 Mdot
.716 .42182 Mdot
.716 .42195 Mdot
.716 .42216 Mdot
.716 .42218 Mdot
.716 .42232 Mdot
.716 .42233 Mdot
.716 .42234 Mdot
.716 .42235 Mdot
.716 .42255 Mdot
.716 .42265 Mdot
.716 .42266 Mdot
.716 .42268 Mdot
.716 .42285 Mdot
.716 .42293 Mdot
.716 .42315 Mdot
.716 .42318 Mdot
.716 .42337 Mdot
.716 .42359 Mdot
.716 .42388 Mdot
.716 .42389 Mdot
.716 .42398 Mdot
.716 .42423 Mdot
.716 .42439 Mdot
.716 .42442 Mdot
.716 .42447 Mdot
.716 .42461 Mdot
.716 .42475 Mdot
.716 .42486 Mdot
.716 .42561 Mdot
.716 .42576 Mdot
.716 .42597 Mdot
.716 .42633 Mdot
.716 .42682 Mdot
.716 .42688 Mdot
.716 .42724 Mdot
.716 .4273 Mdot
.716 .42743 Mdot
.716 .42749 Mdot
.716 .42765 Mdot
.716 .42783 Mdot
.716 .42827 Mdot
.716 .42844 Mdot
.716 .4288 Mdot
.716 .42885 Mdot
.716 .42912 Mdot
.716 .42913 Mdot
.716 .42923 Mdot
.716 .4293 Mdot
.716 .42946 Mdot
.716 .42951 Mdot
.716 .42961 Mdot
.716 .42972 Mdot
.716 .42981 Mdot
.716 .43014 Mdot
.716 .43016 Mdot
.716 .43024 Mdot
.716 .43058 Mdot
.716 .4307 Mdot
.716 .43084 Mdot
.716 .43086 Mdot
.716 .43109 Mdot
.716 .43125 Mdot
.716 .43142 Mdot
.716 .43182 Mdot
.716 .43184 Mdot
.716 .4319 Mdot
.716 .4319 Mdot
.716 .43239 Mdot
.716 .4327 Mdot
.716 .43292 Mdot
.716 .43306 Mdot
.716 .43316 Mdot
.716 .43318 Mdot
.716 .43332 Mdot
.716 .43338 Mdot
.716 .43345 Mdot
.716 .43356 Mdot
.716 .43357 Mdot
.716 .43365 Mdot
.716 .43405 Mdot
.716 .43423 Mdot
.716 .43437 Mdot
.716 .43451 Mdot
.716 .43487 Mdot
.716 .43498 Mdot
.716 .43504 Mdot
.716 .43518 Mdot
.716 .43542 Mdot
.716 .43564 Mdot
.716 .43605 Mdot
.716 .4361 Mdot
.716 .43619 Mdot
.716 .43627 Mdot
.716 .43686 Mdot
.716 .43694 Mdot
.718 .25376 Mdot
.718 .25427 Mdot
.718 .25427 Mdot
.718 .25461 Mdot
.718 .25465 Mdot
.718 .25485 Mdot
.718 .25521 Mdot
.718 .25535 Mdot
.718 .25623 Mdot
.718 .2564 Mdot
.718 .25654 Mdot
.718 .25688 Mdot
.718 .25711 Mdot
.718 .25729 Mdot
.718 .25784 Mdot
.718 .2579 Mdot
.718 .25871 Mdot
.718 .25887 Mdot
.718 .25933 Mdot
.718 .25946 Mdot
.718 .25973 Mdot
.718 .25978 Mdot
.718 .2598 Mdot
.718 .26009 Mdot
.718 .26099 Mdot
.718 .26109 Mdot
.718 .26129 Mdot
.718 .26132 Mdot
.718 .2616 Mdot
.718 .26184 Mdot
.718 .2622 Mdot
.718 .26272 Mdot
.718 .26278 Mdot
.718 .26298 Mdot
.718 .26335 Mdot
.718 .26335 Mdot
.718 .26346 Mdot
.718 .26347 Mdot
.718 .26357 Mdot
.718 .26358 Mdot
.718 .26359 Mdot
.718 .26372 Mdot
.718 .26374 Mdot
.718 .2638 Mdot
.718 .26415 Mdot
.718 .26459 Mdot
.718 .26465 Mdot
.718 .26493 Mdot
.718 .26515 Mdot
.718 .26521 Mdot
.718 .26532 Mdot
.718 .26534 Mdot
.718 .26537 Mdot
.718 .26558 Mdot
.718 .26569 Mdot
.718 .26614 Mdot
.718 .26614 Mdot
.718 .26618 Mdot
.718 .26627 Mdot
.718 .2666 Mdot
.718 .26697 Mdot
.718 .26718 Mdot
.718 .2673 Mdot
.718 .26745 Mdot
.718 .26749 Mdot
.718 .26803 Mdot
.718 .26848 Mdot
.718 .2693 Mdot
.718 .26943 Mdot
.718 .26965 Mdot
.718 .27002 Mdot
.718 .27017 Mdot
.718 .27029 Mdot
.718 .27043 Mdot
.718 .27045 Mdot
.718 .27063 Mdot
.718 .27122 Mdot
.718 .27123 Mdot
.718 .27132 Mdot
.718 .27173 Mdot
.718 .27194 Mdot
.718 .272 Mdot
.718 .27233 Mdot
.718 .27235 Mdot
.718 .27324 Mdot
.718 .27332 Mdot
.718 .27362 Mdot
.718 .27422 Mdot
.718 .27468 Mdot
.718 .27478 Mdot
.718 .27519 Mdot
.718 .27581 Mdot
.718 .27621 Mdot
.718 .27626 Mdot
.718 .27665 Mdot
.718 .27718 Mdot
.718 .27719 Mdot
.718 .27743 Mdot
.718 .27755 Mdot
.718 .27787 Mdot
.718 .2785 Mdot
.718 .27924 Mdot
.718 .27936 Mdot
.718 .27956 Mdot
.718 .27974 Mdot
.718 .27978 Mdot
.718 .27991 Mdot
.718 .28003 Mdot
.718 .28019 Mdot
.718 .28019 Mdot
.718 .28035 Mdot
.718 .28036 Mdot
.718 .28057 Mdot
.718 .28063 Mdot
.718 .28105 Mdot
.718 .28113 Mdot
.718 .2815 Mdot
.718 .28151 Mdot
.718 .28174 Mdot
.718 .2821 Mdot
.718 .28221 Mdot
.718 .28316 Mdot
.718 .28374 Mdot
.718 .28394 Mdot
.718 .28402 Mdot
.718 .2847 Mdot
.718 .28488 Mdot
.718 .28488 Mdot
.718 .2849 Mdot
.718 .28508 Mdot
.718 .28545 Mdot
.718 .28546 Mdot
.718 .28548 Mdot
.718 .28575 Mdot
.718 .28619 Mdot
.718 .28639 Mdot
.718 .28646 Mdot
.718 .28664 Mdot
.718 .28681 Mdot
.718 .2869 Mdot
.718 .28805 Mdot
.718 .28821 Mdot
.718 .28853 Mdot
.718 .28856 Mdot
.718 .2886 Mdot
.718 .28865 Mdot
.718 .28869 Mdot
.718 .28884 Mdot
.718 .28912 Mdot
.718 .28965 Mdot
.718 .28986 Mdot
.718 .2899 Mdot
.718 .29016 Mdot
.718 .29027 Mdot
.718 .29104 Mdot
.718 .2913 Mdot
.718 .29136 Mdot
.718 .29139 Mdot
.718 .29142 Mdot
.718 .29155 Mdot
.718 .2921 Mdot
.718 .29212 Mdot
.718 .29269 Mdot
.718 .293 Mdot
.718 .29368 Mdot
.718 .2939 Mdot
.718 .29425 Mdot
.718 .29426 Mdot
.718 .29444 Mdot
.718 .29453 Mdot
.718 .29454 Mdot
.718 .29454 Mdot
.718 .29495 Mdot
.718 .29499 Mdot
.718 .29509 Mdot
.718 .29606 Mdot
.718 .29663 Mdot
.718 .29681 Mdot
.718 .29689 Mdot
.718 .29695 Mdot
.718 .29701 Mdot
.718 .29712 Mdot
.718 .29721 Mdot
.718 .29727 Mdot
.718 .29794 Mdot
.718 .29827 Mdot
.718 .29827 Mdot
.718 .29853 Mdot
.718 .29894 Mdot
.718 .29944 Mdot
.718 .3 Mdot
.718 .30063 Mdot
.718 .30081 Mdot
.718 .30116 Mdot
.718 .30116 Mdot
.718 .30153 Mdot
.718 .30155 Mdot
.718 .30161 Mdot
.718 .30167 Mdot
.718 .30203 Mdot
.718 .30209 Mdot
.718 .30249 Mdot
.718 .30271 Mdot
.718 .30299 Mdot
.718 .30306 Mdot
.718 .30356 Mdot
.718 .30361 Mdot
.718 .30363 Mdot
.718 .30385 Mdot
.718 .3039 Mdot
.718 .30402 Mdot
.718 .30402 Mdot
.718 .30411 Mdot
.718 .30438 Mdot
.718 .30476 Mdot
.718 .30479 Mdot
.718 .3048 Mdot
.718 .30486 Mdot
.718 .30487 Mdot
.718 .30487 Mdot
.718 .30498 Mdot
.718 .30498 Mdot
.718 .30516 Mdot
.718 .30553 Mdot
.718 .30596 Mdot
.718 .30598 Mdot
.718 .30608 Mdot
.718 .30656 Mdot
.718 .30671 Mdot
.718 .30674 Mdot
.718 .30693 Mdot
.718 .30715 Mdot
.718 .30828 Mdot
.718 .30835 Mdot
.718 .3092 Mdot
.718 .30922 Mdot
.718 .30938 Mdot
.718 .30977 Mdot
.718 .31001 Mdot
.718 .31029 Mdot
.718 .31047 Mdot
.718 .31054 Mdot
.718 .31096 Mdot
.718 .31128 Mdot
.718 .31139 Mdot
.718 .31148 Mdot
.718 .31174 Mdot
.718 .31177 Mdot
.718 .31216 Mdot
.718 .31253 Mdot
.718 .31269 Mdot
.718 .31327 Mdot
.718 .31356 Mdot
.718 .31368 Mdot
.718 .31411 Mdot
.718 .31414 Mdot
.718 .31447 Mdot
.718 .31447 Mdot
.718 .3148 Mdot
.718 .31504 Mdot
.718 .31518 Mdot
.718 .31531 Mdot
.718 .31539 Mdot
.718 .31577 Mdot
.718 .31599 Mdot
.718 .31617 Mdot
.718 .31627 Mdot
.718 .31642 Mdot
.718 .31747 Mdot
.718 .31765 Mdot
.718 .31794 Mdot
.718 .31828 Mdot
.718 .31848 Mdot
.718 .31861 Mdot
.718 .31878 Mdot
.718 .31921 Mdot
.718 .31925 Mdot
.718 .31969 Mdot
.718 .31991 Mdot
.718 .32016 Mdot
.718 .32065 Mdot
.718 .32067 Mdot
.718 .32124 Mdot
.718 .3213 Mdot
.718 .32176 Mdot
.718 .32236 Mdot
.718 .32258 Mdot
.718 .32266 Mdot
.718 .32267 Mdot
.718 .32279 Mdot
.718 .323 Mdot
.718 .32304 Mdot
.718 .32321 Mdot
.718 .32322 Mdot
.718 .3235 Mdot
.718 .32356 Mdot
.718 .32402 Mdot
.718 .32477 Mdot
.718 .32513 Mdot
.718 .32528 Mdot
.718 .32559 Mdot
.718 .32562 Mdot
.718 .32579 Mdot
.718 .32584 Mdot
.718 .32647 Mdot
.718 .32662 Mdot
.718 .32664 Mdot
.718 .32666 Mdot
.718 .32669 Mdot
.718 .32678 Mdot
.718 .32691 Mdot
.718 .32717 Mdot
.718 .32742 Mdot
.718 .32747 Mdot
.718 .32801 Mdot
.718 .32837 Mdot
.718 .32864 Mdot
.718 .32879 Mdot
.718 .3294 Mdot
.718 .3294 Mdot
.718 .32954 Mdot
.718 .32954 Mdot
.718 .32976 Mdot
.718 .32981 Mdot
.718 .33064 Mdot
.718 .33068 Mdot
.718 .33135 Mdot
.718 .33147 Mdot
.718 .33167 Mdot
.718 .33191 Mdot
.718 .33219 Mdot
.718 .33275 Mdot
.718 .33294 Mdot
.718 .33297 Mdot
.718 .33317 Mdot
.718 .3334 Mdot
.718 .3335 Mdot
.718 .33367 Mdot
.718 .33405 Mdot
.718 .33408 Mdot
.718 .33413 Mdot
.718 .33414 Mdot
.718 .33418 Mdot
.718 .33455 Mdot
.718 .33455 Mdot
.718 .33455 Mdot
.718 .3346 Mdot
.718 .3346 Mdot
.718 .33487 Mdot
.718 .33508 Mdot
.718 .33509 Mdot
.718 .33513 Mdot
.718 .33544 Mdot
.718 .33555 Mdot
.718 .3362 Mdot
.718 .33665 Mdot
.718 .33666 Mdot
.718 .33674 Mdot
.718 .33692 Mdot
.718 .33704 Mdot
.718 .33726 Mdot
.718 .3375 Mdot
.718 .33771 Mdot
.718 .33775 Mdot
.718 .33809 Mdot
.718 .33862 Mdot
.718 .33955 Mdot
.718 .33994 Mdot
.718 .34008 Mdot
.718 .34066 Mdot
.718 .34075 Mdot
.718 .34105 Mdot
.718 .34115 Mdot
.718 .34121 Mdot
.718 .34129 Mdot
.718 .3415 Mdot
.718 .34173 Mdot
.718 .34249 Mdot
.718 .34252 Mdot
.718 .34303 Mdot
.718 .34318 Mdot
.718 .34324 Mdot
.718 .34334 Mdot
.718 .34336 Mdot
.718 .34345 Mdot
.718 .34345 Mdot
.718 .34361 Mdot
.718 .34371 Mdot
.718 .34384 Mdot
.718 .34437 Mdot
.718 .34445 Mdot
.718 .3446 Mdot
.718 .34469 Mdot
.718 .34502 Mdot
.718 .3451 Mdot
.718 .34511 Mdot
.718 .34512 Mdot
.718 .34513 Mdot
.718 .34524 Mdot
.718 .34536 Mdot
.718 .34548 Mdot
.718 .34551 Mdot
.718 .34594 Mdot
.718 .34644 Mdot
.718 .34645 Mdot
.718 .34651 Mdot
.718 .34651 Mdot
.718 .34662 Mdot
.718 .34664 Mdot
.718 .34755 Mdot
.718 .3478 Mdot
.718 .34827 Mdot
.718 .34838 Mdot
.718 .34843 Mdot
.718 .34852 Mdot
.718 .3487 Mdot
.718 .34871 Mdot
.718 .34874 Mdot
.718 .34874 Mdot
.718 .34894 Mdot
.718 .34894 Mdot
.718 .34897 Mdot
.718 .3492 Mdot
.718 .3492 Mdot
.718 .34943 Mdot
.718 .34996 Mdot
.718 .35 Mdot
.718 .35015 Mdot
.718 .35026 Mdot
.718 .35037 Mdot
.718 .35047 Mdot
.718 .3505 Mdot
.718 .35066 Mdot
.718 .35156 Mdot
.718 .35162 Mdot
.718 .35214 Mdot
.718 .35217 Mdot
.718 .35231 Mdot
.718 .35281 Mdot
.718 .35306 Mdot
.718 .35316 Mdot
.718 .3532 Mdot
.718 .35334 Mdot
.718 .35339 Mdot
.718 .35344 Mdot
.718 .35374 Mdot
.718 .35386 Mdot
.718 .35406 Mdot
.718 .35407 Mdot
.718 .35412 Mdot
.718 .35426 Mdot
.718 .35471 Mdot
.718 .35471 Mdot
.718 .35474 Mdot
.718 .35479 Mdot
.718 .35537 Mdot
.718 .35572 Mdot
.718 .35582 Mdot
.718 .35592 Mdot
.718 .35616 Mdot
.718 .35644 Mdot
.718 .35651 Mdot
.718 .35656 Mdot
.718 .35666 Mdot
.718 .35722 Mdot
.718 .35747 Mdot
.718 .35749 Mdot
.718 .35792 Mdot
.718 .35797 Mdot
.718 .35799 Mdot
.718 .35805 Mdot
.718 .35825 Mdot
.718 .35841 Mdot
.718 .35843 Mdot
.718 .3585 Mdot
.718 .35872 Mdot
.718 .35872 Mdot
.718 .35873 Mdot
.718 .35876 Mdot
.718 .35904 Mdot
.718 .35921 Mdot
.718 .35926 Mdot
.718 .35942 Mdot
.718 .35956 Mdot
.718 .36007 Mdot
.718 .36027 Mdot
.718 .3603 Mdot
.718 .36034 Mdot
.718 .36043 Mdot
.718 .36051 Mdot
.718 .36056 Mdot
.718 .36067 Mdot
.718 .36082 Mdot
.718 .361 Mdot
.718 .36143 Mdot
.718 .36145 Mdot
.718 .36153 Mdot
.718 .36161 Mdot
.718 .36168 Mdot
.718 .36177 Mdot
.718 .36198 Mdot
.718 .36199 Mdot
.718 .36206 Mdot
.718 .36225 Mdot
.718 .36237 Mdot
.718 .36244 Mdot
.718 .36246 Mdot
.718 .36253 Mdot
.718 .36258 Mdot
.718 .36266 Mdot
.718 .36279 Mdot
.718 .36285 Mdot
.718 .36306 Mdot
.718 .36311 Mdot
.718 .36322 Mdot
.718 .36323 Mdot
.718 .36353 Mdot
.718 .36366 Mdot
.718 .36376 Mdot
.718 .36384 Mdot
.718 .36387 Mdot
.718 .36393 Mdot
.718 .36399 Mdot
.718 .36402 Mdot
.718 .36463 Mdot
.718 .3649 Mdot
.718 .36509 Mdot
.718 .36511 Mdot
.718 .36527 Mdot
.718 .36532 Mdot
.718 .36534 Mdot
.718 .36545 Mdot
.718 .36558 Mdot
.718 .36565 Mdot
.718 .36568 Mdot
.718 .36598 Mdot
.718 .36599 Mdot
.718 .36616 Mdot
.718 .36655 Mdot
.718 .36662 Mdot
.718 .36666 Mdot
.718 .36671 Mdot
.718 .36691 Mdot
.718 .36707 Mdot
.718 .36714 Mdot
.718 .36721 Mdot
.718 .36746 Mdot
.718 .36785 Mdot
.718 .36789 Mdot
.718 .36791 Mdot
.718 .36791 Mdot
.718 .36823 Mdot
.718 .36832 Mdot
.718 .36836 Mdot
.718 .36836 Mdot
.718 .3685 Mdot
.718 .36859 Mdot
.718 .36879 Mdot
.718 .36884 Mdot
.718 .36887 Mdot
.718 .36896 Mdot
.718 .36899 Mdot
.718 .36906 Mdot
.718 .36924 Mdot
.718 .36958 Mdot
.718 .36968 Mdot
.718 .3697 Mdot
.718 .37006 Mdot
.718 .37011 Mdot
.718 .37085 Mdot
.718 .37086 Mdot
.718 .37093 Mdot
.718 .37101 Mdot
.718 .37109 Mdot
.718 .37119 Mdot
.718 .37122 Mdot
.718 .37159 Mdot
.718 .37175 Mdot
.718 .37175 Mdot
.718 .37191 Mdot
.718 .37193 Mdot
.718 .37193 Mdot
.718 .37207 Mdot
.718 .37207 Mdot
.718 .37209 Mdot
.718 .3721 Mdot
.718 .37223 Mdot
.718 .37228 Mdot
.718 .37232 Mdot
.718 .37239 Mdot
.718 .37273 Mdot
.718 .3729 Mdot
.718 .37353 Mdot
.718 .37355 Mdot
.718 .37362 Mdot
.718 .37362 Mdot
.718 .37367 Mdot
.718 .37367 Mdot
.718 .37402 Mdot
.718 .37432 Mdot
.718 .37434 Mdot
.718 .37442 Mdot
.718 .37451 Mdot
.718 .37459 Mdot
.718 .37459 Mdot
.718 .3746 Mdot
.718 .37461 Mdot
.718 .37466 Mdot
.718 .37489 Mdot
.718 .37496 Mdot
.718 .37506 Mdot
.718 .37511 Mdot
.718 .37549 Mdot
.718 .37557 Mdot
.718 .37564 Mdot
.718 .37575 Mdot
.718 .37576 Mdot
.718 .37582 Mdot
.718 .37583 Mdot
.718 .3759 Mdot
.718 .37595 Mdot
.718 .37604 Mdot
.718 .3764 Mdot
.718 .37642 Mdot
.718 .37695 Mdot
.718 .37711 Mdot
.718 .37726 Mdot
.718 .37731 Mdot
.718 .37736 Mdot
.718 .37742 Mdot
.718 .37764 Mdot
.718 .3777 Mdot
.718 .3781 Mdot
.718 .3782 Mdot
.718 .37847 Mdot
.718 .37912 Mdot
.718 .37949 Mdot
.718 .37972 Mdot
.718 .37975 Mdot
.718 .3799 Mdot
.718 .38006 Mdot
.718 .38022 Mdot
.718 .3803 Mdot
.718 .38043 Mdot
.718 .38048 Mdot
.718 .38049 Mdot
.718 .3808 Mdot
.718 .38126 Mdot
.718 .38133 Mdot
.718 .38154 Mdot
.718 .38158 Mdot
.718 .38158 Mdot
.718 .38173 Mdot
.718 .38191 Mdot
.718 .38191 Mdot
.718 .38195 Mdot
.718 .38195 Mdot
.718 .38195 Mdot
.718 .38221 Mdot
.718 .38224 Mdot
.718 .38224 Mdot
.718 .38228 Mdot
.718 .3823 Mdot
.718 .38256 Mdot
.718 .38268 Mdot
.718 .38275 Mdot
.718 .38291 Mdot
.718 .38305 Mdot
.718 .38307 Mdot
.718 .38321 Mdot
.718 .3836 Mdot
.718 .38379 Mdot
.718 .38396 Mdot
.718 .38409 Mdot
.718 .38418 Mdot
.718 .38465 Mdot
.718 .38467 Mdot
.718 .38525 Mdot
.718 .38529 Mdot
.718 .38544 Mdot
.718 .38544 Mdot
.718 .38554 Mdot
.718 .38554 Mdot
.718 .38596 Mdot
.718 .38606 Mdot
.718 .38626 Mdot
.718 .3865 Mdot
.718 .38688 Mdot
.718 .38692 Mdot
.718 .38709 Mdot
.718 .38727 Mdot
.718 .38737 Mdot
.718 .38743 Mdot
.718 .38745 Mdot
.718 .38746 Mdot
.718 .38747 Mdot
.718 .38758 Mdot
.718 .38802 Mdot
.718 .38805 Mdot
.718 .38817 Mdot
.718 .38819 Mdot
.718 .38841 Mdot
.718 .38851 Mdot
.718 .38876 Mdot
.718 .38929 Mdot
.718 .3896 Mdot
.718 .38964 Mdot
.718 .38984 Mdot
.718 .38985 Mdot
.718 .38997 Mdot
.718 .39 Mdot
.718 .39014 Mdot
.718 .39023 Mdot
.718 .39023 Mdot
.718 .39029 Mdot
.718 .39044 Mdot
.718 .39086 Mdot
.718 .39118 Mdot
.718 .39122 Mdot
.718 .39162 Mdot
.718 .39163 Mdot
.718 .39197 Mdot
.718 .39215 Mdot
.718 .3923 Mdot
.718 .39261 Mdot
.718 .39263 Mdot
.718 .39294 Mdot
.718 .39305 Mdot
.718 .39314 Mdot
.718 .39328 Mdot
.718 .39351 Mdot
.718 .39372 Mdot
.718 .39385 Mdot
.718 .39458 Mdot
.718 .39468 Mdot
.718 .39475 Mdot
.718 .39488 Mdot
.718 .39503 Mdot
.718 .39529 Mdot
.718 .39535 Mdot
.718 .39544 Mdot
.718 .39553 Mdot
.718 .3957 Mdot
.718 .39593 Mdot
.718 .39594 Mdot
.718 .39617 Mdot
.718 .39619 Mdot
.718 .39648 Mdot
.718 .39657 Mdot
.718 .39677 Mdot
.718 .39717 Mdot
.718 .39729 Mdot
.718 .39754 Mdot
.718 .39781 Mdot
.718 .39783 Mdot
.718 .39802 Mdot
.718 .39808 Mdot
.718 .39816 Mdot
.718 .39838 Mdot
.718 .39867 Mdot
.718 .39872 Mdot
.718 .39884 Mdot
.718 .39904 Mdot
.718 .39921 Mdot
.718 .39948 Mdot
.718 .39959 Mdot
.718 .39961 Mdot
.718 .4002 Mdot
.718 .40024 Mdot
.718 .40103 Mdot
.718 .40119 Mdot
.718 .40132 Mdot
.718 .40134 Mdot
.718 .40144 Mdot
.718 .40178 Mdot
.718 .40185 Mdot
.718 .40186 Mdot
.718 .40216 Mdot
.718 .40242 Mdot
.718 .40254 Mdot
.718 .40254 Mdot
.718 .40262 Mdot
.718 .40262 Mdot
.718 .40262 Mdot
.718 .40267 Mdot
.718 .40268 Mdot
.718 .40269 Mdot
.718 .40296 Mdot
.718 .40315 Mdot
.718 .40321 Mdot
.718 .40321 Mdot
.718 .4033 Mdot
.718 .40333 Mdot
.718 .40349 Mdot
.718 .4035 Mdot
.718 .40353 Mdot
.718 .40388 Mdot
.718 .40393 Mdot
.718 .40412 Mdot
.718 .40428 Mdot
.718 .40455 Mdot
.718 .4046 Mdot
.718 .40485 Mdot
.718 .40489 Mdot
.718 .40493 Mdot
.718 .40494 Mdot
.718 .4052 Mdot
.718 .40521 Mdot
.718 .40545 Mdot
.718 .40558 Mdot
.718 .40601 Mdot
.718 .4064 Mdot
.718 .40675 Mdot
.718 .40704 Mdot
.718 .40721 Mdot
.718 .40722 Mdot
.718 .40745 Mdot
.718 .40791 Mdot
.718 .40795 Mdot
.718 .40802 Mdot
.718 .40809 Mdot
.718 .40814 Mdot
.718 .40818 Mdot
.718 .40823 Mdot
.718 .40836 Mdot
.718 .40875 Mdot
.718 .40943 Mdot
.718 .4095 Mdot
.718 .40953 Mdot
.718 .40981 Mdot
.718 .40982 Mdot
.718 .40982 Mdot
.718 .40988 Mdot
.718 .41001 Mdot
.718 .41002 Mdot
.718 .41026 Mdot
.718 .41041 Mdot
.718 .41088 Mdot
.718 .4111 Mdot
.718 .4115 Mdot
.718 .41151 Mdot
.718 .41189 Mdot
.718 .41198 Mdot
.718 .412 Mdot
.718 .41202 Mdot
.718 .41207 Mdot
.718 .41225 Mdot
.718 .41279 Mdot
.718 .41286 Mdot
.718 .41304 Mdot
.718 .41307 Mdot
.718 .41322 Mdot
.718 .41359 Mdot
.718 .41378 Mdot
.718 .41389 Mdot
.718 .41391 Mdot
.718 .41395 Mdot
.718 .41398 Mdot
.718 .414 Mdot
.718 .41422 Mdot
.718 .41434 Mdot
.718 .41513 Mdot
.718 .4152 Mdot
.718 .41531 Mdot
.718 .41544 Mdot
.718 .41549 Mdot
.718 .41563 Mdot
.718 .41593 Mdot
.718 .41612 Mdot
.718 .41614 Mdot
.718 .41615 Mdot
.718 .4164 Mdot
.718 .41653 Mdot
.718 .41654 Mdot
.718 .41654 Mdot
.718 .41666 Mdot
.718 .41714 Mdot
.718 .4172 Mdot
.718 .41734 Mdot
.718 .41774 Mdot
.718 .4184 Mdot
.718 .41848 Mdot
.718 .41873 Mdot
.718 .41889 Mdot
.718 .4189 Mdot
.718 .41915 Mdot
.718 .41921 Mdot
.718 .4195 Mdot
.718 .41954 Mdot
.718 .41969 Mdot
.718 .4197 Mdot
.718 .41981 Mdot
.718 .41981 Mdot
.718 .41992 Mdot
.718 .42 Mdot
.718 .42009 Mdot
.718 .42012 Mdot
.718 .42025 Mdot
.718 .42038 Mdot
.718 .42047 Mdot
.718 .42098 Mdot
.718 .42142 Mdot
.718 .42164 Mdot
.718 .42173 Mdot
.718 .4219 Mdot
.718 .4219 Mdot
.718 .42227 Mdot
.718 .42255 Mdot
.718 .42258 Mdot
.718 .42286 Mdot
.718 .42329 Mdot
.718 .42357 Mdot
.718 .42365 Mdot
.718 .42396 Mdot
.718 .42438 Mdot
.718 .42459 Mdot
.718 .42465 Mdot
.718 .42527 Mdot
.718 .42528 Mdot
.718 .42551 Mdot
.718 .42555 Mdot
.718 .4257 Mdot
.718 .42598 Mdot
.718 .42604 Mdot
.718 .42605 Mdot
.718 .42646 Mdot
.718 .42659 Mdot
.718 .42661 Mdot
.718 .4267 Mdot
.718 .42679 Mdot
.718 .42689 Mdot
.718 .42715 Mdot
.718 .4273 Mdot
.718 .42739 Mdot
.718 .42796 Mdot
.718 .42828 Mdot
.718 .42865 Mdot
.718 .42868 Mdot
.718 .42878 Mdot
.718 .42887 Mdot
.718 .42901 Mdot
.718 .42927 Mdot
.718 .4295 Mdot
.718 .42956 Mdot
.718 .42959 Mdot
.718 .42959 Mdot
.718 .42991 Mdot
.718 .42998 Mdot
.718 .43013 Mdot
.718 .43015 Mdot
.718 .43016 Mdot
.718 .43024 Mdot
.718 .43028 Mdot
.718 .43044 Mdot
.718 .43063 Mdot
.718 .43067 Mdot
.718 .43098 Mdot
.718 .43122 Mdot
.718 .43126 Mdot
.718 .43128 Mdot
.718 .43137 Mdot
.718 .43137 Mdot
.718 .43138 Mdot
.718 .43145 Mdot
.718 .43146 Mdot
.718 .43154 Mdot
.718 .43154 Mdot
.718 .43179 Mdot
.718 .43193 Mdot
.718 .43197 Mdot
.718 .43233 Mdot
.718 .43259 Mdot
.718 .43275 Mdot
.718 .43295 Mdot
.718 .43297 Mdot
.718 .43311 Mdot
.718 .43318 Mdot
.718 .43381 Mdot
.718 .434 Mdot
.718 .43402 Mdot
.718 .43406 Mdot
.718 .43425 Mdot
.718 .43433 Mdot
.718 .43465 Mdot
.718 .43476 Mdot
.718 .43533 Mdot
.718 .43537 Mdot
.718 .43575 Mdot
.718 .43588 Mdot
.718 .43604 Mdot
.718 .43628 Mdot
.718 .43638 Mdot
.718 .43649 Mdot
.718 .4371 Mdot
.718 .4372 Mdot
.718 .43745 Mdot
.718 .43759 Mdot
.718 .43762 Mdot
.718 .43786 Mdot
.718 .43786 Mdot
.718 .43821 Mdot
.72 .2526 Mdot
.72 .25338 Mdot
.72 .25383 Mdot
.72 .25404 Mdot
.72 .25418 Mdot
.72 .25494 Mdot
.72 .25529 Mdot
.72 .25548 Mdot
.72 .25548 Mdot
.72 .25551 Mdot
.72 .25569 Mdot
.72 .25576 Mdot
.72 .25576 Mdot
.72 .25619 Mdot
.72 .25678 Mdot
.72 .2571 Mdot
.72 .25754 Mdot
.72 .25754 Mdot
.72 .25803 Mdot
.72 .25813 Mdot
.72 .25859 Mdot
.72 .25859 Mdot
.72 .2586 Mdot
.72 .25866 Mdot
.72 .25907 Mdot
.72 .25931 Mdot
.72 .25987 Mdot
.72 .25995 Mdot
.72 .26027 Mdot
.72 .26134 Mdot
.72 .26139 Mdot
.72 .26168 Mdot
.72 .26243 Mdot
.72 .26313 Mdot
.72 .26331 Mdot
.72 .26344 Mdot
.72 .2637 Mdot
.72 .26382 Mdot
.72 .26389 Mdot
.72 .26397 Mdot
.72 .264 Mdot
.72 .26407 Mdot
.72 .26432 Mdot
.72 .2644 Mdot
.72 .26443 Mdot
.72 .2649 Mdot
.72 .26553 Mdot
.72 .266 Mdot
.72 .26605 Mdot
.72 .26611 Mdot
.72 .26631 Mdot
.72 .26655 Mdot
.72 .2668 Mdot
.72 .26687 Mdot
.72 .26711 Mdot
.72 .26755 Mdot
.72 .2676 Mdot
.72 .26789 Mdot
.72 .26805 Mdot
.72 .26832 Mdot
.72 .26914 Mdot
.72 .26928 Mdot
.72 .26938 Mdot
.72 .26943 Mdot
.72 .26949 Mdot
.72 .26955 Mdot
.72 .27033 Mdot
.72 .27038 Mdot
.72 .27041 Mdot
.72 .27055 Mdot
.72 .27059 Mdot
.72 .27073 Mdot
.72 .27076 Mdot
.72 .27086 Mdot
.72 .27094 Mdot
.72 .27099 Mdot
.72 .2711 Mdot
.72 .27128 Mdot
.72 .27133 Mdot
.72 .27148 Mdot
.72 .27163 Mdot
.72 .27184 Mdot
.72 .27223 Mdot
.72 .27242 Mdot
.72 .27247 Mdot
.72 .27254 Mdot
.72 .27271 Mdot
.72 .27327 Mdot
.72 .27355 Mdot
.72 .27382 Mdot
.72 .27391 Mdot
.72 .27402 Mdot
.72 .2743 Mdot
.72 .27452 Mdot
.72 .27544 Mdot
.72 .27544 Mdot
.72 .27545 Mdot
.72 .27581 Mdot
.72 .27588 Mdot
.72 .27684 Mdot
.72 .2772 Mdot
.72 .27722 Mdot
.72 .27759 Mdot
.72 .27781 Mdot
.72 .27789 Mdot
.72 .27791 Mdot
.72 .27793 Mdot
.72 .27802 Mdot
.72 .27824 Mdot
.72 .27827 Mdot
.72 .27883 Mdot
.72 .27885 Mdot
.72 .27904 Mdot
.72 .27954 Mdot
.72 .27957 Mdot
.72 .27963 Mdot
.72 .27987 Mdot
.72 .28004 Mdot
.72 .28037 Mdot
.72 .28074 Mdot
.72 .28076 Mdot
.72 .28076 Mdot
.72 .28087 Mdot
.72 .28118 Mdot
.72 .28143 Mdot
.72 .28148 Mdot
.72 .28148 Mdot
.72 .28215 Mdot
.72 .28244 Mdot
.72 .28249 Mdot
.72 .28253 Mdot
.72 .2827 Mdot
.72 .28289 Mdot
.72 .28289 Mdot
.72 .28419 Mdot
.72 .28461 Mdot
.72 .28465 Mdot
.72 .28478 Mdot
.72 .2853 Mdot
.72 .2854 Mdot
.72 .28565 Mdot
.72 .28638 Mdot
.72 .28663 Mdot
.72 .28678 Mdot
.72 .28684 Mdot
.72 .28757 Mdot
.72 .28804 Mdot
.72 .28805 Mdot
.72 .28826 Mdot
.72 .28842 Mdot
.72 .28881 Mdot
.72 .2892 Mdot
.72 .28961 Mdot
.72 .28964 Mdot
.72 .28984 Mdot
.72 .29077 Mdot
.72 .29173 Mdot
.72 .29183 Mdot
.72 .29223 Mdot
.72 .29249 Mdot
.72 .29318 Mdot
.72 .29321 Mdot
.72 .29328 Mdot
.72 .29375 Mdot
.72 .29392 Mdot
.72 .29417 Mdot
.72 .29424 Mdot
.72 .29425 Mdot
.72 .29446 Mdot
.72 .29508 Mdot
.72 .29527 Mdot
.72 .29544 Mdot
.72 .29591 Mdot
.72 .29606 Mdot
.72 .29612 Mdot
.72 .2963 Mdot
.72 .2967 Mdot
.72 .29694 Mdot
.72 .29703 Mdot
.72 .29704 Mdot
.72 .29731 Mdot
.72 .29748 Mdot
.72 .29749 Mdot
.72 .29764 Mdot
.72 .29783 Mdot
.72 .29846 Mdot
.72 .2985 Mdot
.72 .29868 Mdot
.72 .29912 Mdot
.72 .29923 Mdot
.72 .29936 Mdot
.72 .29999 Mdot
.72 .30011 Mdot
.72 .30013 Mdot
.72 .30041 Mdot
.72 .30051 Mdot
.72 .30059 Mdot
.72 .30066 Mdot
.72 .30082 Mdot
.72 .30095 Mdot
.72 .30101 Mdot
.72 .30103 Mdot
.72 .30114 Mdot
.72 .3016 Mdot
.72 .30171 Mdot
.72 .30224 Mdot
.72 .30232 Mdot
.72 .30246 Mdot
.72 .30248 Mdot
.72 .30296 Mdot
.72 .30308 Mdot
.72 .30317 Mdot
.72 .30321 Mdot
.72 .30346 Mdot
.72 .30376 Mdot
.72 .30416 Mdot
.72 .30425 Mdot
.72 .30453 Mdot
.72 .30461 Mdot
.72 .30548 Mdot
.72 .30619 Mdot
.72 .30645 Mdot
.72 .3068 Mdot
.72 .30707 Mdot
.72 .30731 Mdot
.72 .30752 Mdot
.72 .30796 Mdot
.72 .30817 Mdot
.72 .30817 Mdot
.72 .3083 Mdot
.72 .30856 Mdot
.72 .30856 Mdot
.72 .30893 Mdot
.72 .309 Mdot
.72 .3091 Mdot
.72 .3097 Mdot
.72 .31008 Mdot
.72 .311 Mdot
.72 .31109 Mdot
.72 .31111 Mdot
.72 .31119 Mdot
.72 .31172 Mdot
.72 .31208 Mdot
.72 .31237 Mdot
.72 .31259 Mdot
.72 .3126 Mdot
.72 .31263 Mdot
.72 .31282 Mdot
.72 .31325 Mdot
.72 .3134 Mdot
.72 .31394 Mdot
.72 .31408 Mdot
.72 .31444 Mdot
.72 .31493 Mdot
.72 .31506 Mdot
.72 .31511 Mdot
.72 .31519 Mdot
.72 .3152 Mdot
.72 .31535 Mdot
.72 .31539 Mdot
.72 .31541 Mdot
.72 .31616 Mdot
.72 .31655 Mdot
.72 .31659 Mdot
.72 .3167 Mdot
.72 .31728 Mdot
.72 .31775 Mdot
.72 .31782 Mdot
.72 .31785 Mdot
.72 .31788 Mdot
.72 .31828 Mdot
.72 .31829 Mdot
.72 .31846 Mdot
.72 .31851 Mdot
.72 .31855 Mdot
.72 .31862 Mdot
.72 .31871 Mdot
.72 .31917 Mdot
.72 .31932 Mdot
.72 .31967 Mdot
.72 .3198 Mdot
.72 .31994 Mdot
.72 .31998 Mdot
.72 .32072 Mdot
.72 .32072 Mdot
.72 .32139 Mdot
.72 .32157 Mdot
.72 .32186 Mdot
.72 .3219 Mdot
.72 .32196 Mdot
.72 .32207 Mdot
.72 .32271 Mdot
.72 .32274 Mdot
.72 .32285 Mdot
.72 .32294 Mdot
.72 .32328 Mdot
.72 .32328 Mdot
.72 .32361 Mdot
.72 .32363 Mdot
.72 .32363 Mdot
.72 .32409 Mdot
.72 .32413 Mdot
.72 .32422 Mdot
.72 .32431 Mdot
.72 .32552 Mdot
.72 .32599 Mdot
.72 .32657 Mdot
.72 .3268 Mdot
.72 .3268 Mdot
.72 .32698 Mdot
.72 .32735 Mdot
.72 .32755 Mdot
.72 .32811 Mdot
.72 .32857 Mdot
.72 .32881 Mdot
.72 .32894 Mdot
.72 .32927 Mdot
.72 .32929 Mdot
.72 .32932 Mdot
.72 .32963 Mdot
.72 .32979 Mdot
.72 .32989 Mdot
.72 .33028 Mdot
.72 .33036 Mdot
.72 .33066 Mdot
.72 .33069 Mdot
.72 .33078 Mdot
.72 .33109 Mdot
.72 .33113 Mdot
.72 .33126 Mdot
.72 .33142 Mdot
.72 .33151 Mdot
.72 .33184 Mdot
.72 .33192 Mdot
.72 .33214 Mdot
.72 .33219 Mdot
.72 .33225 Mdot
.72 .33263 Mdot
.72 .33281 Mdot
.72 .33284 Mdot
.72 .33288 Mdot
.72 .33296 Mdot
.72 .33305 Mdot
.72 .33306 Mdot
.72 .33311 Mdot
.72 .33333 Mdot
.72 .33339 Mdot
.72 .33364 Mdot
.72 .33368 Mdot
.72 .33376 Mdot
.72 .33405 Mdot
.72 .33411 Mdot
.72 .33423 Mdot
.72 .33437 Mdot
.72 .33457 Mdot
.72 .33554 Mdot
.72 .33567 Mdot
.72 .33584 Mdot
.72 .33597 Mdot
.72 .33609 Mdot
.72 .33619 Mdot
.72 .3364 Mdot
.72 .33656 Mdot
.72 .33669 Mdot
.72 .33742 Mdot
.72 .33787 Mdot
.72 .33839 Mdot
.72 .33874 Mdot
.72 .33895 Mdot
.72 .33928 Mdot
.72 .33988 Mdot
.72 .33989 Mdot
.72 .33997 Mdot
.72 .33998 Mdot
.72 .33999 Mdot
.72 .34061 Mdot
.72 .3409 Mdot
.72 .34117 Mdot
.72 .34118 Mdot
.72 .34138 Mdot
.72 .34154 Mdot
.72 .34188 Mdot
.72 .34205 Mdot
.72 .34211 Mdot
.72 .34255 Mdot
.72 .34288 Mdot
.72 .34297 Mdot
.72 .3431 Mdot
.72 .34312 Mdot
.72 .34315 Mdot
.72 .3432 Mdot
.72 .34353 Mdot
.72 .34362 Mdot
.72 .34379 Mdot
.72 .34379 Mdot
.72 .34418 Mdot
.72 .3442 Mdot
.72 .34424 Mdot
.72 .34429 Mdot
.72 .34548 Mdot
.72 .34575 Mdot
.72 .34634 Mdot
.72 .34646 Mdot
.72 .34652 Mdot
.72 .34668 Mdot
.72 .3467 Mdot
.72 .3472 Mdot
.72 .34735 Mdot
.72 .34736 Mdot
.72 .3474 Mdot
.72 .34757 Mdot
.72 .34764 Mdot
.72 .34771 Mdot
.72 .34796 Mdot
.72 .34808 Mdot
.72 .34838 Mdot
.72 .34842 Mdot
.72 .3485 Mdot
.72 .3485 Mdot
.72 .34878 Mdot
.72 .34914 Mdot
.72 .34923 Mdot
.72 .3497 Mdot
.72 .34976 Mdot
.72 .35019 Mdot
.72 .35061 Mdot
.72 .35082 Mdot
.72 .35125 Mdot
.72 .3518 Mdot
.72 .35183 Mdot
.72 .35185 Mdot
.72 .35215 Mdot
.72 .35241 Mdot
.72 .35242 Mdot
.72 .35276 Mdot
.72 .35287 Mdot
.72 .35324 Mdot
.72 .35336 Mdot
.72 .35337 Mdot
.72 .35355 Mdot
.72 .3536 Mdot
.72 .35368 Mdot
.72 .35368 Mdot
.72 .35388 Mdot
.72 .3539 Mdot
.72 .35392 Mdot
.72 .35463 Mdot
.72 .35491 Mdot
.72 .35508 Mdot
.72 .3554 Mdot
.72 .35553 Mdot
.72 .35575 Mdot
.72 .35589 Mdot
.72 .35591 Mdot
.72 .35595 Mdot
.72 .3563 Mdot
.72 .35653 Mdot
.72 .35656 Mdot
.72 .35677 Mdot
.72 .35707 Mdot
.72 .35727 Mdot
.72 .35754 Mdot
.72 .35756 Mdot
.72 .35756 Mdot
.72 .35784 Mdot
.72 .35784 Mdot
.72 .35824 Mdot
.72 .35829 Mdot
.72 .3583 Mdot
.72 .35839 Mdot
.72 .35841 Mdot
.72 .35845 Mdot
.72 .35845 Mdot
.72 .35854 Mdot
.72 .35855 Mdot
.72 .35856 Mdot
.72 .3589 Mdot
.72 .35904 Mdot
.72 .35928 Mdot
.72 .35934 Mdot
.72 .35952 Mdot
.72 .35954 Mdot
.72 .35971 Mdot
.72 .35982 Mdot
.72 .35984 Mdot
.72 .35994 Mdot
.72 .36031 Mdot
.72 .36032 Mdot
.72 .36045 Mdot
.72 .36046 Mdot
.72 .36065 Mdot
.72 .36067 Mdot
.72 .36068 Mdot
.72 .36075 Mdot
.72 .36075 Mdot
.72 .36097 Mdot
.72 .36115 Mdot
.72 .36141 Mdot
.72 .36142 Mdot
.72 .36147 Mdot
.72 .36165 Mdot
.72 .36171 Mdot
.72 .36172 Mdot
.72 .36182 Mdot
.72 .36182 Mdot
.72 .36196 Mdot
.72 .36232 Mdot
.72 .36244 Mdot
.72 .36328 Mdot
.72 .36353 Mdot
.72 .36371 Mdot
.72 .36375 Mdot
.72 .36422 Mdot
.72 .36438 Mdot
.72 .36438 Mdot
.72 .36443 Mdot
.72 .36443 Mdot
.72 .36458 Mdot
.72 .36458 Mdot
.72 .36468 Mdot
.72 .36494 Mdot
.72 .36501 Mdot
.72 .36502 Mdot
.72 .3651 Mdot
.72 .36523 Mdot
.72 .3654 Mdot
.72 .36566 Mdot
.72 .36589 Mdot
.72 .3659 Mdot
.72 .36591 Mdot
.72 .36597 Mdot
.72 .36597 Mdot
.72 .366 Mdot
.72 .36608 Mdot
.72 .36608 Mdot
.72 .36612 Mdot
.72 .3664 Mdot
.72 .3664 Mdot
.72 .36659 Mdot
.72 .36659 Mdot
.72 .3666 Mdot
.72 .36693 Mdot
.72 .36714 Mdot
.72 .36729 Mdot
.72 .36731 Mdot
.72 .36746 Mdot
.72 .36771 Mdot
.72 .36774 Mdot
.72 .36775 Mdot
.72 .36785 Mdot
.72 .368 Mdot
.72 .36809 Mdot
.72 .36831 Mdot
.72 .36843 Mdot
.72 .36863 Mdot
.72 .36912 Mdot
.72 .36914 Mdot
.72 .36915 Mdot
.72 .36929 Mdot
.72 .36929 Mdot
.72 .36934 Mdot
.72 .36937 Mdot
.72 .3695 Mdot
.72 .36951 Mdot
.72 .36959 Mdot
.72 .36985 Mdot
.72 .36993 Mdot
.72 .37016 Mdot
.72 .37016 Mdot
.72 .37035 Mdot
.72 .37056 Mdot
.72 .37057 Mdot
.72 .37059 Mdot
.72 .37098 Mdot
.72 .37127 Mdot
.72 .37142 Mdot
.72 .37171 Mdot
.72 .372 Mdot
.72 .37205 Mdot
.72 .37237 Mdot
.72 .37244 Mdot
.72 .37269 Mdot
.72 .37288 Mdot
.72 .37288 Mdot
.72 .37294 Mdot
.72 .37296 Mdot
.72 .37317 Mdot
.72 .37326 Mdot
.72 .37343 Mdot
.72 .37348 Mdot
.72 .37353 Mdot
.72 .37364 Mdot
.72 .37367 Mdot
.72 .37368 Mdot
.72 .37378 Mdot
.72 .37413 Mdot
.72 .37415 Mdot
.72 .37426 Mdot
.72 .3743 Mdot
.72 .37438 Mdot
.72 .37479 Mdot
.72 .37498 Mdot
.72 .37581 Mdot
.72 .37584 Mdot
.72 .37587 Mdot
.72 .37588 Mdot
.72 .37615 Mdot
.72 .37615 Mdot
.72 .37627 Mdot
.72 .37634 Mdot
.72 .37656 Mdot
.72 .3766 Mdot
.72 .37662 Mdot
.72 .37663 Mdot
.72 .37673 Mdot
.72 .37679 Mdot
.72 .37701 Mdot
.72 .37732 Mdot
.72 .37736 Mdot
.72 .37748 Mdot
.72 .37771 Mdot
.72 .37783 Mdot
.72 .37797 Mdot
.72 .37798 Mdot
.72 .37816 Mdot
.72 .37836 Mdot
.72 .37879 Mdot
.72 .3788 Mdot
.72 .37881 Mdot
.72 .37886 Mdot
.72 .37887 Mdot
.72 .37928 Mdot
.72 .37952 Mdot
.72 .37966 Mdot
.72 .3799 Mdot
.72 .38027 Mdot
.72 .38058 Mdot
.72 .38108 Mdot
.72 .38117 Mdot
.72 .38129 Mdot
.72 .38143 Mdot
.72 .3815 Mdot
.72 .38158 Mdot
.72 .38167 Mdot
.72 .38179 Mdot
.72 .38188 Mdot
.72 .38256 Mdot
.72 .38269 Mdot
.72 .38279 Mdot
.72 .38288 Mdot
.72 .38292 Mdot
.72 .38312 Mdot
.72 .38318 Mdot
.72 .3832 Mdot
.72 .38338 Mdot
.72 .38342 Mdot
.72 .38357 Mdot
.72 .38361 Mdot
.72 .38361 Mdot
.72 .38368 Mdot
.72 .38373 Mdot
.72 .38376 Mdot
.72 .38378 Mdot
.72 .38391 Mdot
.72 .38417 Mdot
.72 .38421 Mdot
.72 .38425 Mdot
.72 .38439 Mdot
.72 .38445 Mdot
.72 .38468 Mdot
.72 .38474 Mdot
.72 .38485 Mdot
.72 .38495 Mdot
.72 .38498 Mdot
.72 .38519 Mdot
.72 .38525 Mdot
.72 .38527 Mdot
.72 .38548 Mdot
.72 .38553 Mdot
.72 .38581 Mdot
.72 .38588 Mdot
.72 .38599 Mdot
.72 .3862 Mdot
.72 .38623 Mdot
.72 .38624 Mdot
.72 .38647 Mdot
.72 .38655 Mdot
.72 .38672 Mdot
.72 .38704 Mdot
.72 .38743 Mdot
.72 .38757 Mdot
.72 .38783 Mdot
.72 .38795 Mdot
.72 .38796 Mdot
.72 .38811 Mdot
.72 .38851 Mdot
.72 .38884 Mdot
.72 .38968 Mdot
.72 .38974 Mdot
.72 .3898 Mdot
.72 .38983 Mdot
.72 .39015 Mdot
.72 .39016 Mdot
.72 .39017 Mdot
.72 .3904 Mdot
.72 .3904 Mdot
.72 .39064 Mdot
.72 .39069 Mdot
.72 .39077 Mdot
.72 .39079 Mdot
.72 .39124 Mdot
.72 .39131 Mdot
.72 .39136 Mdot
.72 .39138 Mdot
.72 .39158 Mdot
.72 .39171 Mdot
.72 .39217 Mdot
.72 .39218 Mdot
.72 .39269 Mdot
.72 .39272 Mdot
.72 .39281 Mdot
.72 .3929 Mdot
.72 .39315 Mdot
.72 .39325 Mdot
.72 .39357 Mdot
.72 .39363 Mdot
.72 .39368 Mdot
.72 .39371 Mdot
.72 .39374 Mdot
.72 .39386 Mdot
.72 .39387 Mdot
.72 .39415 Mdot
.72 .39417 Mdot
.72 .39419 Mdot
.72 .39424 Mdot
.72 .39456 Mdot
.72 .39497 Mdot
.72 .39504 Mdot
.72 .39507 Mdot
.72 .39534 Mdot
.72 .39586 Mdot
.72 .39587 Mdot
.72 .3959 Mdot
.72 .39601 Mdot
.72 .39602 Mdot
.72 .39607 Mdot
.72 .39611 Mdot
.72 .3962 Mdot
.72 .39653 Mdot
.72 .39678 Mdot
.72 .39688 Mdot
.72 .39726 Mdot
.72 .39737 Mdot
.72 .39766 Mdot
.72 .39779 Mdot
.72 .39782 Mdot
.72 .39782 Mdot
.72 .39797 Mdot
.72 .39817 Mdot
.72 .39843 Mdot
.72 .39879 Mdot
.72 .39885 Mdot
.72 .39886 Mdot
.72 .39892 Mdot
.72 .39957 Mdot
.72 .39982 Mdot
.72 .40025 Mdot
.72 .40032 Mdot
.72 .40036 Mdot
.72 .40062 Mdot
.72 .40062 Mdot
.72 .4008 Mdot
.72 .40089 Mdot
.72 .40089 Mdot
.72 .40104 Mdot
.72 .40134 Mdot
.72 .40149 Mdot
.72 .40165 Mdot
.72 .40184 Mdot
.72 .40208 Mdot
.72 .40227 Mdot
.72 .40276 Mdot
.72 .40336 Mdot
.72 .40342 Mdot
.72 .40361 Mdot
.72 .40367 Mdot
.72 .40395 Mdot
.72 .40416 Mdot
.72 .40434 Mdot
.72 .40436 Mdot
.72 .40443 Mdot
.72 .40451 Mdot
.72 .40484 Mdot
.72 .40486 Mdot
.72 .40495 Mdot
.72 .40501 Mdot
.72 .40537 Mdot
.72 .40545 Mdot
.72 .40577 Mdot
.72 .40585 Mdot
.72 .40586 Mdot
.72 .40591 Mdot
.72 .40599 Mdot
.72 .40611 Mdot
.72 .40616 Mdot
.72 .40621 Mdot
.72 .40628 Mdot
.72 .40647 Mdot
.72 .40649 Mdot
.72 .40657 Mdot
.72 .40701 Mdot
.72 .4071 Mdot
.72 .40718 Mdot
.72 .40748 Mdot
.72 .40761 Mdot
.72 .40763 Mdot
.72 .40807 Mdot
.72 .4082 Mdot
.72 .40831 Mdot
.72 .40832 Mdot
.72 .40843 Mdot
.72 .40862 Mdot
.72 .40863 Mdot
.72 .40869 Mdot
.72 .40886 Mdot
.72 .40913 Mdot
.72 .40926 Mdot
.72 .4093 Mdot
.72 .40941 Mdot
.72 .40973 Mdot
.72 .40984 Mdot
.72 .40998 Mdot
.72 .41041 Mdot
.72 .41055 Mdot
.72 .41057 Mdot
.72 .41061 Mdot
.72 .41079 Mdot
.72 .4109 Mdot
.72 .41123 Mdot
.72 .41128 Mdot
.72 .4113 Mdot
.72 .41178 Mdot
.72 .41196 Mdot
.72 .41224 Mdot
.72 .41231 Mdot
.72 .41297 Mdot
.72 .41362 Mdot
.72 .41376 Mdot
.72 .41378 Mdot
.72 .41406 Mdot
.72 .41434 Mdot
.72 .4146 Mdot
.72 .41472 Mdot
.72 .41486 Mdot
.72 .41487 Mdot
.72 .41519 Mdot
.72 .41571 Mdot
.72 .41574 Mdot
.72 .41585 Mdot
.72 .41603 Mdot
.72 .41653 Mdot
.72 .4167 Mdot
.72 .41677 Mdot
.72 .41713 Mdot
.72 .41722 Mdot
.72 .41725 Mdot
.72 .41754 Mdot
.72 .41844 Mdot
.72 .41844 Mdot
.72 .41857 Mdot
.72 .4187 Mdot
.72 .41872 Mdot
.72 .41875 Mdot
.72 .41896 Mdot
.72 .41942 Mdot
.72 .41943 Mdot
.72 .41946 Mdot
.72 .41963 Mdot
.72 .41985 Mdot
.72 .41993 Mdot
.72 .41993 Mdot
.72 .41994 Mdot
.72 .4202 Mdot
.72 .42042 Mdot
.72 .42054 Mdot
.72 .42071 Mdot
.72 .42075 Mdot
.72 .42077 Mdot
.72 .42112 Mdot
.72 .42125 Mdot
.72 .42126 Mdot
.72 .42165 Mdot
.72 .42168 Mdot
.72 .42183 Mdot
.72 .42189 Mdot
.72 .42191 Mdot
.72 .42192 Mdot
.72 .42197 Mdot
.72 .42213 Mdot
.72 .42238 Mdot
.72 .4224 Mdot
.72 .42265 Mdot
.72 .42331 Mdot
.72 .42336 Mdot
.72 .42361 Mdot
.72 .42362 Mdot
.72 .42362 Mdot
.72 .42426 Mdot
.72 .42441 Mdot
.72 .42461 Mdot
.72 .42468 Mdot
.72 .42474 Mdot
.72 .42493 Mdot
.72 .42512 Mdot
.72 .42552 Mdot
.72 .42563 Mdot
.72 .42568 Mdot
.72 .42572 Mdot
.72 .42585 Mdot
.72 .42612 Mdot
.72 .42626 Mdot
.72 .42637 Mdot
.72 .42647 Mdot
.72 .42651 Mdot
.72 .42663 Mdot
.72 .42671 Mdot
.72 .42674 Mdot
.72 .4268 Mdot
.72 .42687 Mdot
.72 .42689 Mdot
.72 .42699 Mdot
.72 .42701 Mdot
.72 .42711 Mdot
.72 .42713 Mdot
.72 .42717 Mdot
.72 .42771 Mdot
.72 .42775 Mdot
.72 .42779 Mdot
.72 .42783 Mdot
.72 .4279 Mdot
.72 .42799 Mdot
.72 .42856 Mdot
.72 .42875 Mdot
.72 .42886 Mdot
.72 .42907 Mdot
.72 .4291 Mdot
.72 .4294 Mdot
.72 .42957 Mdot
.72 .42962 Mdot
.72 .42979 Mdot
.72 .42996 Mdot
.72 .4301 Mdot
.72 .43014 Mdot
.72 .43018 Mdot
.72 .4305 Mdot
.72 .43094 Mdot
.72 .43127 Mdot
.72 .43129 Mdot
.72 .43134 Mdot
.72 .43152 Mdot
.72 .43156 Mdot
.72 .43158 Mdot
.72 .43164 Mdot
.72 .43169 Mdot
.72 .43177 Mdot
.72 .43195 Mdot
.72 .43205 Mdot
.72 .43216 Mdot
.72 .43266 Mdot
.72 .43317 Mdot
.72 .43338 Mdot
.72 .43341 Mdot
.72 .43415 Mdot
.72 .43438 Mdot
.72 .43443 Mdot
.72 .43482 Mdot
.72 .43499 Mdot
.72 .43527 Mdot
.72 .43531 Mdot
.72 .43532 Mdot
.72 .43532 Mdot
.72 .43564 Mdot
.72 .43571 Mdot
.72 .43605 Mdot
.72 .43605 Mdot
.72 .43635 Mdot
.72 .43658 Mdot
.72 .43699 Mdot
.72 .43728 Mdot
.72 .43729 Mdot
.72 .43734 Mdot
.72 .43746 Mdot
.72 .43748 Mdot
.72 .43748 Mdot
.72 .43761 Mdot
.72 .43785 Mdot
.72 .43838 Mdot
.72 .43848 Mdot
.72 .43863 Mdot
.72 .43894 Mdot
.72 .43948 Mdot
.722 .25196 Mdot
.722 .25207 Mdot
.722 .25219 Mdot
.722 .25224 Mdot
.722 .25238 Mdot
.722 .25264 Mdot
.722 .2527 Mdot
.722 .25284 Mdot
.722 .25286 Mdot
.722 .25293 Mdot
.722 .25308 Mdot
.722 .25312 Mdot
.722 .25315 Mdot
.722 .2536 Mdot
.722 .25373 Mdot
.722 .25409 Mdot
.722 .25411 Mdot
.722 .25452 Mdot
.722 .25458 Mdot
.722 .2547 Mdot
.722 .25496 Mdot
.722 .25505 Mdot
.722 .25569 Mdot
.722 .25589 Mdot
.722 .25605 Mdot
.722 .25633 Mdot
.722 .25652 Mdot
.722 .25674 Mdot
.722 .25688 Mdot
.722 .25767 Mdot
.722 .25771 Mdot
.722 .25791 Mdot
.722 .25862 Mdot
.722 .2587 Mdot
.722 .25873 Mdot
.722 .25931 Mdot
.722 .25952 Mdot
.722 .25987 Mdot
.722 .26002 Mdot
.722 .26102 Mdot
.722 .26109 Mdot
.722 .26112 Mdot
.722 .26148 Mdot
.722 .26168 Mdot
.722 .2624 Mdot
.722 .26252 Mdot
.722 .26287 Mdot
.722 .26314 Mdot
.722 .26329 Mdot
.722 .26392 Mdot
.722 .26392 Mdot
.722 .26413 Mdot
.722 .26482 Mdot
.722 .26508 Mdot
.722 .26539 Mdot
.722 .26573 Mdot
.722 .26589 Mdot
.722 .26607 Mdot
.722 .26687 Mdot
.722 .26715 Mdot
.722 .26758 Mdot
.722 .26805 Mdot
.722 .26849 Mdot
.722 .2685 Mdot
.722 .26856 Mdot
.722 .26867 Mdot
.722 .26871 Mdot
.722 .26872 Mdot
.722 .26901 Mdot
.722 .26949 Mdot
.722 .26993 Mdot
.722 .27031 Mdot
.722 .27041 Mdot
.722 .2705 Mdot
.722 .27123 Mdot
.722 .27157 Mdot
.722 .27174 Mdot
.722 .27174 Mdot
.722 .2718 Mdot
.722 .27193 Mdot
.722 .27266 Mdot
.722 .27292 Mdot
.722 .27293 Mdot
.722 .27301 Mdot
.722 .27395 Mdot
.722 .27402 Mdot
.722 .27427 Mdot
.722 .27457 Mdot
.722 .27458 Mdot
.722 .27477 Mdot
.722 .27479 Mdot
.722 .27507 Mdot
.722 .27508 Mdot
.722 .2755 Mdot
.722 .27562 Mdot
.722 .27591 Mdot
.722 .27608 Mdot
.722 .27609 Mdot
.722 .27612 Mdot
.722 .27627 Mdot
.722 .2764 Mdot
.722 .27646 Mdot
.722 .27647 Mdot
.722 .27665 Mdot
.722 .27689 Mdot
.722 .2772 Mdot
.722 .27758 Mdot
.722 .27786 Mdot
.722 .27828 Mdot
.722 .27847 Mdot
.722 .27875 Mdot
.722 .27896 Mdot
.722 .27896 Mdot
.722 .27911 Mdot
.722 .27997 Mdot
.722 .28077 Mdot
.722 .28081 Mdot
.722 .28085 Mdot
.722 .28149 Mdot
.722 .28151 Mdot
.722 .28165 Mdot
.722 .2819 Mdot
.722 .28206 Mdot
.722 .28211 Mdot
.722 .28216 Mdot
.722 .28253 Mdot
.722 .28259 Mdot
.722 .28295 Mdot
.722 .28303 Mdot
.722 .28322 Mdot
.722 .28344 Mdot
.722 .28346 Mdot
.722 .2843 Mdot
.722 .28433 Mdot
.722 .28441 Mdot
.722 .2854 Mdot
.722 .28571 Mdot
.722 .28576 Mdot
.722 .28634 Mdot
.722 .2865 Mdot
.722 .28741 Mdot
.722 .28754 Mdot
.722 .2878 Mdot
.722 .28786 Mdot
.722 .28807 Mdot
.722 .28811 Mdot
.722 .28937 Mdot
.722 .28968 Mdot
.722 .28981 Mdot
.722 .28985 Mdot
.722 .29016 Mdot
.722 .2902 Mdot
.722 .29058 Mdot
.722 .29133 Mdot
.722 .29141 Mdot
.722 .29216 Mdot
.722 .29218 Mdot
.722 .29221 Mdot
.722 .29228 Mdot
.722 .29231 Mdot
.722 .29243 Mdot
.722 .2925 Mdot
.722 .29293 Mdot
.722 .29301 Mdot
.722 .29329 Mdot
.722 .29393 Mdot
.722 .29451 Mdot
.722 .29481 Mdot
.722 .29504 Mdot
.722 .29533 Mdot
.722 .29534 Mdot
.722 .29606 Mdot
.722 .29655 Mdot
.722 .29665 Mdot
.722 .29708 Mdot
.722 .29721 Mdot
.722 .29754 Mdot
.722 .29774 Mdot
.722 .29793 Mdot
.722 .29801 Mdot
.722 .29821 Mdot
.722 .29841 Mdot
.722 .2988 Mdot
.722 .29957 Mdot
.722 .29992 Mdot
.722 .29998 Mdot
.722 .30001 Mdot
.722 .30001 Mdot
.722 .30026 Mdot
.722 .3007 Mdot
.722 .30109 Mdot
.722 .30146 Mdot
.722 .30154 Mdot
.722 .30157 Mdot
.722 .30178 Mdot
.722 .30201 Mdot
.722 .30221 Mdot
.722 .30282 Mdot
.722 .30306 Mdot
.722 .3032 Mdot
.722 .30427 Mdot
.722 .30443 Mdot
.722 .30449 Mdot
.722 .30512 Mdot
.722 .30515 Mdot
.722 .30625 Mdot
.722 .30627 Mdot
.722 .3063 Mdot
.722 .30676 Mdot
.722 .30714 Mdot
.722 .3072 Mdot
.722 .30731 Mdot
.722 .30806 Mdot
.722 .30818 Mdot
.722 .30824 Mdot
.722 .30847 Mdot
.722 .30848 Mdot
.722 .30865 Mdot
.722 .30871 Mdot
.722 .30894 Mdot
.722 .30896 Mdot
.722 .30907 Mdot
.722 .30914 Mdot
.722 .30917 Mdot
.722 .3093 Mdot
.722 .30939 Mdot
.722 .30944 Mdot
.722 .3095 Mdot
.722 .31003 Mdot
.722 .31032 Mdot
.722 .31036 Mdot
.722 .31047 Mdot
.722 .31112 Mdot
.722 .31138 Mdot
.722 .31168 Mdot
.722 .31178 Mdot
.722 .31186 Mdot
.722 .31199 Mdot
.722 .31265 Mdot
.722 .31275 Mdot
.722 .31342 Mdot
.722 .31352 Mdot
.722 .31369 Mdot
.722 .31376 Mdot
.722 .31429 Mdot
.722 .31446 Mdot
.722 .31456 Mdot
.722 .31526 Mdot
.722 .31533 Mdot
.722 .31563 Mdot
.722 .31563 Mdot
.722 .31573 Mdot
.722 .31606 Mdot
.722 .3165 Mdot
.722 .31666 Mdot
.722 .31705 Mdot
.722 .31783 Mdot
.722 .31791 Mdot
.722 .31793 Mdot
.722 .31807 Mdot
.722 .31851 Mdot
.722 .31874 Mdot
.722 .31879 Mdot
.722 .3193 Mdot
.722 .31995 Mdot
.722 .31995 Mdot
.722 .31999 Mdot
.722 .32044 Mdot
.722 .32048 Mdot
.722 .32074 Mdot
.722 .32075 Mdot
.722 .32083 Mdot
.722 .32084 Mdot
.722 .32098 Mdot
.722 .32124 Mdot
.722 .32147 Mdot
.722 .32148 Mdot
.722 .32155 Mdot
.722 .32162 Mdot
.722 .32165 Mdot
.722 .32174 Mdot
.722 .322 Mdot
.722 .32261 Mdot
.722 .32285 Mdot
.722 .32291 Mdot
.722 .32371 Mdot
.722 .32373 Mdot
.722 .32375 Mdot
.722 .32413 Mdot
.722 .32426 Mdot
.722 .32433 Mdot
.722 .32438 Mdot
.722 .32456 Mdot
.722 .32476 Mdot
.722 .3248 Mdot
.722 .32499 Mdot
.722 .325 Mdot
.722 .32541 Mdot
.722 .32542 Mdot
.722 .32593 Mdot
.722 .32608 Mdot
.722 .32784 Mdot
.722 .32805 Mdot
.722 .32822 Mdot
.722 .32823 Mdot
.722 .32842 Mdot
.722 .32878 Mdot
.722 .32917 Mdot
.722 .32919 Mdot
.722 .32925 Mdot
.722 .32931 Mdot
.722 .32934 Mdot
.722 .3303 Mdot
.722 .33044 Mdot
.722 .33056 Mdot
.722 .33069 Mdot
.722 .3307 Mdot
.722 .33105 Mdot
.722 .33176 Mdot
.722 .33194 Mdot
.722 .33207 Mdot
.722 .33217 Mdot
.722 .33236 Mdot
.722 .33273 Mdot
.722 .33293 Mdot
.722 .33294 Mdot
.722 .33294 Mdot
.722 .33327 Mdot
.722 .33346 Mdot
.722 .33367 Mdot
.722 .33379 Mdot
.722 .3339 Mdot
.722 .33428 Mdot
.722 .3344 Mdot
.722 .33447 Mdot
.722 .33539 Mdot
.722 .33541 Mdot
.722 .33594 Mdot
.722 .33639 Mdot
.722 .33689 Mdot
.722 .337 Mdot
.722 .337 Mdot
.722 .33708 Mdot
.722 .33711 Mdot
.722 .33722 Mdot
.722 .33732 Mdot
.722 .33739 Mdot
.722 .33744 Mdot
.722 .33746 Mdot
.722 .33795 Mdot
.722 .33827 Mdot
.722 .33839 Mdot
.722 .33869 Mdot
.722 .339 Mdot
.722 .33905 Mdot
.722 .33937 Mdot
.722 .3395 Mdot
.722 .33953 Mdot
.722 .33979 Mdot
.722 .33987 Mdot
.722 .33992 Mdot
.722 .34025 Mdot
.722 .34048 Mdot
.722 .34085 Mdot
.722 .34149 Mdot
.722 .34152 Mdot
.722 .3416 Mdot
.722 .34192 Mdot
.722 .34195 Mdot
.722 .3425 Mdot
.722 .34252 Mdot
.722 .34275 Mdot
.722 .34288 Mdot
.722 .34288 Mdot
.722 .34323 Mdot
.722 .34324 Mdot
.722 .34336 Mdot
.722 .34392 Mdot
.722 .34431 Mdot
.722 .34451 Mdot
.722 .34457 Mdot
.722 .34471 Mdot
.722 .34492 Mdot
.722 .34493 Mdot
.722 .34512 Mdot
.722 .34628 Mdot
.722 .34656 Mdot
.722 .34693 Mdot
.722 .34693 Mdot
.722 .34696 Mdot
.722 .34699 Mdot
.722 .347 Mdot
.722 .34754 Mdot
.722 .34825 Mdot
.722 .34832 Mdot
.722 .34836 Mdot
.722 .34845 Mdot
.722 .34863 Mdot
.722 .34873 Mdot
.722 .34873 Mdot
.722 .34873 Mdot
.722 .34914 Mdot
.722 .34919 Mdot
.722 .34938 Mdot
.722 .34943 Mdot
.722 .34992 Mdot
.722 .35017 Mdot
.722 .35063 Mdot
.722 .35073 Mdot
.722 .35079 Mdot
.722 .35087 Mdot
.722 .35114 Mdot
.722 .35129 Mdot
.722 .35149 Mdot
.722 .35164 Mdot
.722 .35166 Mdot
.722 .35188 Mdot
.722 .35189 Mdot
.722 .35202 Mdot
.722 .35206 Mdot
.722 .35208 Mdot
.722 .35235 Mdot
.722 .35283 Mdot
.722 .35285 Mdot
.722 .35289 Mdot
.722 .35304 Mdot
.722 .35305 Mdot
.722 .35333 Mdot
.722 .35344 Mdot
.722 .3535 Mdot
.722 .35367 Mdot
.722 .35373 Mdot
.722 .35418 Mdot
.722 .35428 Mdot
.722 .35438 Mdot
.722 .35448 Mdot
.722 .35448 Mdot
.722 .35513 Mdot
.722 .35544 Mdot
.722 .35544 Mdot
.722 .35546 Mdot
.722 .35573 Mdot
.722 .35608 Mdot
.722 .35613 Mdot
.722 .35617 Mdot
.722 .3563 Mdot
.722 .35631 Mdot
.722 .35631 Mdot
.722 .3565 Mdot
.722 .35662 Mdot
.722 .35664 Mdot
.722 .35721 Mdot
.722 .35727 Mdot
.722 .35729 Mdot
.722 .35733 Mdot
.722 .35746 Mdot
.722 .35753 Mdot
.722 .35763 Mdot
.722 .3577 Mdot
.722 .35781 Mdot
.722 .35782 Mdot
.722 .35788 Mdot
.722 .3579 Mdot
.722 .35804 Mdot
.722 .35828 Mdot
.722 .35837 Mdot
.722 .35851 Mdot
.722 .35856 Mdot
.722 .35859 Mdot
.722 .35867 Mdot
.722 .3587 Mdot
.722 .35892 Mdot
.722 .35897 Mdot
.722 .35901 Mdot
.722 .35906 Mdot
.722 .35906 Mdot
.722 .35952 Mdot
.722 .35953 Mdot
.722 .35966 Mdot
.722 .35983 Mdot
.722 .35985 Mdot
.722 .35994 Mdot
.722 .35994 Mdot
.722 .35994 Mdot
.722 .36003 Mdot
.722 .3601 Mdot
.722 .36037 Mdot
.722 .3604 Mdot
.722 .36043 Mdot
.722 .36053 Mdot
.722 .36067 Mdot
.722 .361 Mdot
.722 .36107 Mdot
.722 .36126 Mdot
.722 .36126 Mdot
.722 .36148 Mdot
.722 .36163 Mdot
.722 .36168 Mdot
.722 .36168 Mdot
.722 .36176 Mdot
.722 .36192 Mdot
.722 .36196 Mdot
.722 .36203 Mdot
.722 .36231 Mdot
.722 .36242 Mdot
.722 .36252 Mdot
.722 .36263 Mdot
.722 .36268 Mdot
.722 .36282 Mdot
.722 .36292 Mdot
.722 .36297 Mdot
.722 .36311 Mdot
.722 .3632 Mdot
.722 .36341 Mdot
.722 .36354 Mdot
.722 .36361 Mdot
.722 .36374 Mdot
.722 .36382 Mdot
.722 .36388 Mdot
.722 .36396 Mdot
.722 .36416 Mdot
.722 .3642 Mdot
.722 .36423 Mdot
.722 .3644 Mdot
.722 .3644 Mdot
.722 .36453 Mdot
.722 .36469 Mdot
.722 .3651 Mdot
.722 .3652 Mdot
.722 .36526 Mdot
.722 .36549 Mdot
.722 .36554 Mdot
.722 .3656 Mdot
.722 .3656 Mdot
.722 .3656 Mdot
.722 .36568 Mdot
.722 .36589 Mdot
.722 .36589 Mdot
.722 .36621 Mdot
.722 .36621 Mdot
.722 .36648 Mdot
.722 .36659 Mdot
.722 .36692 Mdot
.722 .36703 Mdot
.722 .36707 Mdot
.722 .36707 Mdot
.722 .36727 Mdot
.722 .36741 Mdot
.722 .36745 Mdot
.722 .36749 Mdot
.722 .36789 Mdot
.722 .3679 Mdot
.722 .36798 Mdot
.722 .36812 Mdot
.722 .36812 Mdot
.722 .36812 Mdot
.722 .36821 Mdot
.722 .36824 Mdot
.722 .36828 Mdot
.722 .36852 Mdot
.722 .36871 Mdot
.722 .36872 Mdot
.722 .36872 Mdot
.722 .36893 Mdot
.722 .36938 Mdot
.722 .36939 Mdot
.722 .36945 Mdot
.722 .36952 Mdot
.722 .36959 Mdot
.722 .3699 Mdot
.722 .36994 Mdot
.722 .37006 Mdot
.722 .3701 Mdot
.722 .37018 Mdot
.722 .37037 Mdot
.722 .37038 Mdot
.722 .37049 Mdot
.722 .37051 Mdot
.722 .37053 Mdot
.722 .37086 Mdot
.722 .37105 Mdot
.722 .37106 Mdot
.722 .37109 Mdot
.722 .37117 Mdot
.722 .37119 Mdot
.722 .37134 Mdot
.722 .37135 Mdot
.722 .37146 Mdot
.722 .37159 Mdot
.722 .3717 Mdot
.722 .37188 Mdot
.722 .37194 Mdot
.722 .37198 Mdot
.722 .37205 Mdot
.722 .37237 Mdot
.722 .37254 Mdot
.722 .37288 Mdot
.722 .37292 Mdot
.722 .37305 Mdot
.722 .37308 Mdot
.722 .37336 Mdot
.722 .37336 Mdot
.722 .37337 Mdot
.722 .37343 Mdot
.722 .37356 Mdot
.722 .37362 Mdot
.722 .37365 Mdot
.722 .3737 Mdot
.722 .37419 Mdot
.722 .37456 Mdot
.722 .37457 Mdot
.722 .37459 Mdot
.722 .37461 Mdot
.722 .37461 Mdot
.722 .37487 Mdot
.722 .37506 Mdot
.722 .37587 Mdot
.722 .376 Mdot
.722 .376 Mdot
.722 .37615 Mdot
.722 .37625 Mdot
.722 .37629 Mdot
.722 .37643 Mdot
.722 .37669 Mdot
.722 .37708 Mdot
.722 .37717 Mdot
.722 .37717 Mdot
.722 .37741 Mdot
.722 .37742 Mdot
.722 .3775 Mdot
.722 .37767 Mdot
.722 .37768 Mdot
.722 .37806 Mdot
.722 .37808 Mdot
.722 .3783 Mdot
.722 .37836 Mdot
.722 .37838 Mdot
.722 .37883 Mdot
.722 .37908 Mdot
.722 .37924 Mdot
.722 .37947 Mdot
.722 .3795 Mdot
.722 .37956 Mdot
.722 .37973 Mdot
.722 .37976 Mdot
.722 .37985 Mdot
.722 .38007 Mdot
.722 .3801 Mdot
.722 .38032 Mdot
.722 .38053 Mdot
.722 .38061 Mdot
.722 .38083 Mdot
.722 .38117 Mdot
.722 .38119 Mdot
.722 .38122 Mdot
.722 .38127 Mdot
.722 .38133 Mdot
.722 .38141 Mdot
.722 .38143 Mdot
.722 .38149 Mdot
.722 .38149 Mdot
.722 .38157 Mdot
.722 .38191 Mdot
.722 .38222 Mdot
.722 .38259 Mdot
.722 .3826 Mdot
.722 .38324 Mdot
.722 .38329 Mdot
.722 .38337 Mdot
.722 .38364 Mdot
.722 .38371 Mdot
.722 .38379 Mdot
.722 .38394 Mdot
.722 .38407 Mdot
.722 .3843 Mdot
.722 .3843 Mdot
.722 .38431 Mdot
.722 .38445 Mdot
.722 .3847 Mdot
.722 .38483 Mdot
.722 .3849 Mdot
.722 .38499 Mdot
.722 .38512 Mdot
.722 .38561 Mdot
.722 .38585 Mdot
.722 .38586 Mdot
.722 .38595 Mdot
.722 .38603 Mdot
.722 .38613 Mdot
.722 .3868 Mdot
.722 .38682 Mdot
.722 .38686 Mdot
.722 .3869 Mdot
.722 .38691 Mdot
.722 .38718 Mdot
.722 .38743 Mdot
.722 .38756 Mdot
.722 .38757 Mdot
.722 .38769 Mdot
.722 .38784 Mdot
.722 .38905 Mdot
.722 .38915 Mdot
.722 .38951 Mdot
.722 .38952 Mdot
.722 .3898 Mdot
.722 .38981 Mdot
.722 .38994 Mdot
.722 .38997 Mdot
.722 .3901 Mdot
.722 .39023 Mdot
.722 .39026 Mdot
.722 .39031 Mdot
.722 .3904 Mdot
.722 .39066 Mdot
.722 .39068 Mdot
.722 .39069 Mdot
.722 .39124 Mdot
.722 .39129 Mdot
.722 .39146 Mdot
.722 .39188 Mdot
.722 .39206 Mdot
.722 .39212 Mdot
.722 .39214 Mdot
.722 .39218 Mdot
.722 .39223 Mdot
.722 .39224 Mdot
.722 .3924 Mdot
.722 .39259 Mdot
.722 .39268 Mdot
.722 .39268 Mdot
.722 .39275 Mdot
.722 .39275 Mdot
.722 .39293 Mdot
.722 .39296 Mdot
.722 .39327 Mdot
.722 .3933 Mdot
.722 .3933 Mdot
.722 .39375 Mdot
.722 .3941 Mdot
.722 .39413 Mdot
.722 .39429 Mdot
.722 .3946 Mdot
.722 .39469 Mdot
.722 .39471 Mdot
.722 .39476 Mdot
.722 .39531 Mdot
.722 .39557 Mdot
.722 .39569 Mdot
.722 .39599 Mdot
.722 .39622 Mdot
.722 .39629 Mdot
.722 .39629 Mdot
.722 .3965 Mdot
.722 .39655 Mdot
.722 .39703 Mdot
.722 .3971 Mdot
.722 .39722 Mdot
.722 .39758 Mdot
.722 .39763 Mdot
.722 .39775 Mdot
.722 .39782 Mdot
.722 .39828 Mdot
.722 .39835 Mdot
.722 .39881 Mdot
.722 .3989 Mdot
.722 .39895 Mdot
.722 .39902 Mdot
.722 .39923 Mdot
.722 .39941 Mdot
.722 .39986 Mdot
.722 .39994 Mdot
.722 .39997 Mdot
.722 .40017 Mdot
.722 .40053 Mdot
.722 .40057 Mdot
.722 .40061 Mdot
.722 .40067 Mdot
.722 .40076 Mdot
.722 .40078 Mdot
.722 .40083 Mdot
.722 .40091 Mdot
.722 .40092 Mdot
.722 .40108 Mdot
.722 .40112 Mdot
.722 .40124 Mdot
.722 .40125 Mdot
.722 .4014 Mdot
.722 .40145 Mdot
.722 .40153 Mdot
.722 .40205 Mdot
.722 .40212 Mdot
.722 .40217 Mdot
.722 .40243 Mdot
.722 .40275 Mdot
.722 .40277 Mdot
.722 .40278 Mdot
.722 .40354 Mdot
.722 .40357 Mdot
.722 .404 Mdot
.722 .40404 Mdot
.722 .40416 Mdot
.722 .40489 Mdot
.722 .405 Mdot
.722 .40516 Mdot
.722 .40558 Mdot
.722 .40572 Mdot
.722 .40588 Mdot
.722 .40603 Mdot
.722 .40605 Mdot
.722 .4061 Mdot
.722 .40636 Mdot
.722 .40663 Mdot
.722 .40693 Mdot
.722 .4071 Mdot
.722 .4071 Mdot
.722 .40713 Mdot
.722 .40717 Mdot
.722 .40741 Mdot
.722 .40794 Mdot
.722 .40821 Mdot
.722 .40835 Mdot
.722 .40849 Mdot
.722 .40854 Mdot
.722 .40867 Mdot
.722 .40882 Mdot
.722 .40904 Mdot
.722 .40914 Mdot
.722 .40943 Mdot
.722 .4095 Mdot
.722 .40984 Mdot
.722 .41034 Mdot
.722 .41035 Mdot
.722 .41055 Mdot
.722 .41071 Mdot
.722 .41092 Mdot
.722 .41131 Mdot
.722 .41176 Mdot
.722 .41195 Mdot
.722 .412 Mdot
.722 .41231 Mdot
.722 .41235 Mdot
.722 .41244 Mdot
.722 .41246 Mdot
.722 .41251 Mdot
.722 .41253 Mdot
.722 .41254 Mdot
.722 .41306 Mdot
.722 .41312 Mdot
.722 .41364 Mdot
.722 .4139 Mdot
.722 .41393 Mdot
.722 .41414 Mdot
.722 .41417 Mdot
.722 .41426 Mdot
.722 .41448 Mdot
.722 .41534 Mdot
.722 .41538 Mdot
.722 .41552 Mdot
.722 .41556 Mdot
.722 .41574 Mdot
.722 .41583 Mdot
.722 .41646 Mdot
.722 .41658 Mdot
.722 .41698 Mdot
.722 .41701 Mdot
.722 .41722 Mdot
.722 .41791 Mdot
.722 .41796 Mdot
.722 .41798 Mdot
.722 .41857 Mdot
.722 .41858 Mdot
.722 .41874 Mdot
.722 .41886 Mdot
.722 .41892 Mdot
.722 .41917 Mdot
.722 .41921 Mdot
.722 .41947 Mdot
.722 .4195 Mdot
.722 .41954 Mdot
.722 .41964 Mdot
.722 .41982 Mdot
.722 .41992 Mdot
.722 .41993 Mdot
.722 .42037 Mdot
.722 .4204 Mdot
.722 .42043 Mdot
.722 .42098 Mdot
.722 .42158 Mdot
.722 .42168 Mdot
.722 .42168 Mdot
.722 .42182 Mdot
.722 .42202 Mdot
.722 .42215 Mdot
.722 .42245 Mdot
.722 .42264 Mdot
.722 .4229 Mdot
.722 .42311 Mdot
.722 .42328 Mdot
.722 .42341 Mdot
.722 .42341 Mdot
.722 .42346 Mdot
.722 .42354 Mdot
.722 .42365 Mdot
.722 .42367 Mdot
.722 .42368 Mdot
.722 .4238 Mdot
.722 .424 Mdot
.722 .42408 Mdot
.722 .42437 Mdot
.722 .42438 Mdot
.722 .42457 Mdot
.722 .42459 Mdot
.722 .42471 Mdot
.722 .42473 Mdot
.722 .42493 Mdot
.722 .4251 Mdot
.722 .42515 Mdot
.722 .42581 Mdot
.722 .42586 Mdot
.722 .42587 Mdot
.722 .42605 Mdot
.722 .42655 Mdot
.722 .42664 Mdot
.722 .42668 Mdot
.722 .42669 Mdot
.722 .4268 Mdot
.722 .42704 Mdot
.722 .42754 Mdot
.722 .4276 Mdot
.722 .42767 Mdot
.722 .42794 Mdot
.722 .42824 Mdot
.722 .42858 Mdot
.722 .42878 Mdot
.722 .42878 Mdot
.722 .42881 Mdot
.722 .42888 Mdot
.722 .42892 Mdot
.722 .42893 Mdot
.722 .42924 Mdot
.722 .42957 Mdot
.722 .42986 Mdot
.722 .43006 Mdot
.722 .43061 Mdot
.722 .43073 Mdot
.722 .43085 Mdot
.722 .43108 Mdot
.722 .43129 Mdot
.722 .43148 Mdot
.722 .43195 Mdot
.722 .4321 Mdot
.722 .4321 Mdot
.722 .43254 Mdot
.722 .43264 Mdot
.722 .43283 Mdot
.722 .43307 Mdot
.722 .43315 Mdot
.722 .43365 Mdot
.722 .43379 Mdot
.722 .43404 Mdot
.722 .43405 Mdot
.722 .43411 Mdot
.722 .4348 Mdot
.722 .4349 Mdot
.722 .43515 Mdot
.722 .43529 Mdot
.722 .43569 Mdot
.722 .43571 Mdot
.722 .43577 Mdot
.722 .43626 Mdot
.722 .4364 Mdot
.722 .43643 Mdot
.722 .43698 Mdot
.722 .43707 Mdot
.722 .43722 Mdot
.722 .43735 Mdot
.722 .43755 Mdot
.722 .43766 Mdot
.722 .4378 Mdot
.722 .43824 Mdot
.722 .4383 Mdot
.722 .43848 Mdot
.722 .43857 Mdot
.722 .43861 Mdot
.722 .43889 Mdot
.722 .43891 Mdot
.722 .43915 Mdot
.722 .43925 Mdot
.722 .43956 Mdot
.722 .43958 Mdot
.722 .4396 Mdot
.722 .43971 Mdot
.722 .43976 Mdot
.722 .43977 Mdot
.722 .43986 Mdot
.722 .43991 Mdot
.722 .44009 Mdot
.722 .44019 Mdot
.722 .44022 Mdot
.722 .4403 Mdot
.722 .44038 Mdot
.724 .25204 Mdot
.724 .25235 Mdot
.724 .25244 Mdot
.724 .25267 Mdot
.724 .25309 Mdot
.724 .2535 Mdot
.724 .25357 Mdot
.724 .25369 Mdot
.724 .2537 Mdot
.724 .25387 Mdot
.724 .25408 Mdot
.724 .2546 Mdot
.724 .25489 Mdot
.724 .25524 Mdot
.724 .25534 Mdot
.724 .25559 Mdot
.724 .25592 Mdot
.724 .25605 Mdot
.724 .25619 Mdot
.724 .25622 Mdot
.724 .25647 Mdot
.724 .25656 Mdot
.724 .25693 Mdot
.724 .25729 Mdot
.724 .2575 Mdot
.724 .25785 Mdot
.724 .25818 Mdot
.724 .25828 Mdot
.724 .25845 Mdot
.724 .25867 Mdot
.724 .2589 Mdot
.724 .25906 Mdot
.724 .25921 Mdot
.724 .25958 Mdot
.724 .25973 Mdot
.724 .25987 Mdot
.724 .26045 Mdot
.724 .26051 Mdot
.724 .26097 Mdot
.724 .26113 Mdot
.724 .26141 Mdot
.724 .26182 Mdot
.724 .26197 Mdot
.724 .26212 Mdot
.724 .26246 Mdot
.724 .26257 Mdot
.724 .26285 Mdot
.724 .26295 Mdot
.724 .263 Mdot
.724 .26349 Mdot
.724 .26386 Mdot
.724 .26388 Mdot
.724 .26389 Mdot
.724 .26427 Mdot
.724 .26477 Mdot
.724 .26493 Mdot
.724 .26501 Mdot
.724 .26505 Mdot
.724 .26561 Mdot
.724 .2657 Mdot
.724 .26588 Mdot
.724 .26588 Mdot
.724 .26602 Mdot
.724 .26614 Mdot
.724 .26665 Mdot
.724 .26701 Mdot
.724 .26719 Mdot
.724 .26733 Mdot
.724 .26737 Mdot
.724 .26755 Mdot
.724 .2676 Mdot
.724 .26763 Mdot
.724 .26765 Mdot
.724 .26767 Mdot
.724 .26816 Mdot
.724 .26834 Mdot
.724 .26864 Mdot
.724 .26892 Mdot
.724 .26907 Mdot
.724 .26963 Mdot
.724 .26964 Mdot
.724 .26985 Mdot
.724 .26993 Mdot
.724 .27001 Mdot
.724 .27046 Mdot
.724 .271 Mdot
.724 .27104 Mdot
.724 .27164 Mdot
.724 .27208 Mdot
.724 .27221 Mdot
.724 .27242 Mdot
.724 .27299 Mdot
.724 .273 Mdot
.724 .27323 Mdot
.724 .2735 Mdot
.724 .27455 Mdot
.724 .27515 Mdot
.724 .2771 Mdot
.724 .27727 Mdot
.724 .27766 Mdot
.724 .2779 Mdot
.724 .27793 Mdot
.724 .27796 Mdot
.724 .27796 Mdot
.724 .27816 Mdot
.724 .27818 Mdot
.724 .27821 Mdot
.724 .27841 Mdot
.724 .27861 Mdot
.724 .27874 Mdot
.724 .27898 Mdot
.724 .27948 Mdot
.724 .27987 Mdot
.724 .27999 Mdot
.724 .28016 Mdot
.724 .2802 Mdot
.724 .28046 Mdot
.724 .28087 Mdot
.724 .28104 Mdot
.724 .2819 Mdot
.724 .28323 Mdot
.724 .28332 Mdot
.724 .28374 Mdot
.724 .28404 Mdot
.724 .28407 Mdot
.724 .2845 Mdot
.724 .28459 Mdot
.724 .28477 Mdot
.724 .28529 Mdot
.724 .28534 Mdot
.724 .28548 Mdot
.724 .286 Mdot
.724 .28669 Mdot
.724 .28769 Mdot
.724 .2877 Mdot
.724 .28771 Mdot
.724 .28821 Mdot
.724 .28828 Mdot
.724 .28841 Mdot
.724 .2886 Mdot
.724 .28891 Mdot
.724 .28902 Mdot
.724 .28909 Mdot
.724 .28922 Mdot
.724 .28938 Mdot
.724 .28939 Mdot
.724 .29024 Mdot
.724 .2903 Mdot
.724 .29115 Mdot
.724 .29115 Mdot
.724 .29123 Mdot
.724 .29129 Mdot
.724 .29138 Mdot
.724 .29171 Mdot
.724 .29195 Mdot
.724 .29308 Mdot
.724 .2931 Mdot
.724 .29343 Mdot
.724 .29368 Mdot
.724 .2937 Mdot
.724 .29384 Mdot
.724 .29408 Mdot
.724 .29472 Mdot
.724 .29513 Mdot
.724 .2954 Mdot
.724 .29555 Mdot
.724 .29563 Mdot
.724 .29569 Mdot
.724 .29611 Mdot
.724 .29628 Mdot
.724 .29649 Mdot
.724 .2965 Mdot
.724 .2966 Mdot
.724 .29661 Mdot
.724 .29662 Mdot
.724 .297 Mdot
.724 .29793 Mdot
.724 .29822 Mdot
.724 .29872 Mdot
.724 .29885 Mdot
.724 .29896 Mdot
.724 .29912 Mdot
.724 .29992 Mdot
.724 .30017 Mdot
.724 .30046 Mdot
.724 .30083 Mdot
.724 .30118 Mdot
.724 .30127 Mdot
.724 .30151 Mdot
.724 .30152 Mdot
.724 .30156 Mdot
.724 .30164 Mdot
.724 .30166 Mdot
.724 .30199 Mdot
.724 .30244 Mdot
.724 .30248 Mdot
.724 .30276 Mdot
.724 .30312 Mdot
.724 .30331 Mdot
.724 .3035 Mdot
.724 .30376 Mdot
.724 .30422 Mdot
.724 .3043 Mdot
.724 .30462 Mdot
.724 .30492 Mdot
.724 .30495 Mdot
.724 .30561 Mdot
.724 .30579 Mdot
.724 .3059 Mdot
.724 .30598 Mdot
.724 .30603 Mdot
.724 .30646 Mdot
.724 .30684 Mdot
.724 .30711 Mdot
.724 .30727 Mdot
.724 .30743 Mdot
.724 .30817 Mdot
.724 .30877 Mdot
.724 .30896 Mdot
.724 .31058 Mdot
.724 .31073 Mdot
.724 .31094 Mdot
.724 .31113 Mdot
.724 .31116 Mdot
.724 .31122 Mdot
.724 .31131 Mdot
.724 .31141 Mdot
.724 .31165 Mdot
.724 .31179 Mdot
.724 .31201 Mdot
.724 .31235 Mdot
.724 .31241 Mdot
.724 .31243 Mdot
.724 .31259 Mdot
.724 .31277 Mdot
.724 .31304 Mdot
.724 .3132 Mdot
.724 .31371 Mdot
.724 .31385 Mdot
.724 .31403 Mdot
.724 .3141 Mdot
.724 .31417 Mdot
.724 .31469 Mdot
.724 .3149 Mdot
.724 .31524 Mdot
.724 .3154 Mdot
.724 .31546 Mdot
.724 .31559 Mdot
.724 .31566 Mdot
.724 .31607 Mdot
.724 .31609 Mdot
.724 .31651 Mdot
.724 .31658 Mdot
.724 .31662 Mdot
.724 .31703 Mdot
.724 .31704 Mdot
.724 .3171 Mdot
.724 .31716 Mdot
.724 .31757 Mdot
.724 .31766 Mdot
.724 .31786 Mdot
.724 .31788 Mdot
.724 .31835 Mdot
.724 .31849 Mdot
.724 .31883 Mdot
.724 .31883 Mdot
.724 .31897 Mdot
.724 .319 Mdot
.724 .3195 Mdot
.724 .31978 Mdot
.724 .31999 Mdot
.724 .32006 Mdot
.724 .32015 Mdot
.724 .32043 Mdot
.724 .32247 Mdot
.724 .32265 Mdot
.724 .3228 Mdot
.724 .32292 Mdot
.724 .32301 Mdot
.724 .32317 Mdot
.724 .32352 Mdot
.724 .32386 Mdot
.724 .32418 Mdot
.724 .32535 Mdot
.724 .32592 Mdot
.724 .32604 Mdot
.724 .32638 Mdot
.724 .32663 Mdot
.724 .32696 Mdot
.724 .32744 Mdot
.724 .32745 Mdot
.724 .32772 Mdot
.724 .32778 Mdot
.724 .32787 Mdot
.724 .32807 Mdot
.724 .32865 Mdot
.724 .32868 Mdot
.724 .32909 Mdot
.724 .32912 Mdot
.724 .32919 Mdot
.724 .32935 Mdot
.724 .32947 Mdot
.724 .3303 Mdot
.724 .33122 Mdot
.724 .33145 Mdot
.724 .33154 Mdot
.724 .33164 Mdot
.724 .33164 Mdot
.724 .33188 Mdot
.724 .33232 Mdot
.724 .33246 Mdot
.724 .33276 Mdot
.724 .33281 Mdot
.724 .33289 Mdot
.724 .33327 Mdot
.724 .33353 Mdot
.724 .33371 Mdot
.724 .33387 Mdot
.724 .33403 Mdot
.724 .33404 Mdot
.724 .33409 Mdot
.724 .33426 Mdot
.724 .33447 Mdot
.724 .33449 Mdot
.724 .33498 Mdot
.724 .3351 Mdot
.724 .33551 Mdot
.724 .33567 Mdot
.724 .33598 Mdot
.724 .33612 Mdot
.724 .33619 Mdot
.724 .33639 Mdot
.724 .33657 Mdot
.724 .3367 Mdot
.724 .33677 Mdot
.724 .33685 Mdot
.724 .3372 Mdot
.724 .33758 Mdot
.724 .33843 Mdot
.724 .33862 Mdot
.724 .33863 Mdot
.724 .33866 Mdot
.724 .3387 Mdot
.724 .33875 Mdot
.724 .33887 Mdot
.724 .33904 Mdot
.724 .33923 Mdot
.724 .33931 Mdot
.724 .33961 Mdot
.724 .33985 Mdot
.724 .34 Mdot
.724 .34003 Mdot
.724 .34007 Mdot
.724 .34032 Mdot
.724 .34058 Mdot
.724 .34068 Mdot
.724 .34074 Mdot
.724 .34097 Mdot
.724 .34169 Mdot
.724 .34183 Mdot
.724 .34183 Mdot
.724 .34206 Mdot
.724 .34229 Mdot
.724 .34235 Mdot
.724 .34237 Mdot
.724 .34261 Mdot
.724 .34274 Mdot
.724 .34284 Mdot
.724 .34287 Mdot
.724 .34292 Mdot
.724 .34305 Mdot
.724 .34402 Mdot
.724 .34411 Mdot
.724 .34418 Mdot
.724 .34428 Mdot
.724 .34436 Mdot
.724 .34453 Mdot
.724 .34469 Mdot
.724 .3454 Mdot
.724 .34567 Mdot
.724 .34573 Mdot
.724 .34601 Mdot
.724 .34653 Mdot
.724 .34656 Mdot
.724 .3466 Mdot
.724 .3467 Mdot
.724 .34699 Mdot
.724 .3472 Mdot
.724 .34723 Mdot
.724 .34736 Mdot
.724 .3482 Mdot
.724 .34831 Mdot
.724 .3484 Mdot
.724 .34851 Mdot
.724 .34872 Mdot
.724 .34879 Mdot
.724 .34896 Mdot
.724 .34899 Mdot
.724 .34918 Mdot
.724 .3493 Mdot
.724 .34954 Mdot
.724 .34957 Mdot
.724 .34965 Mdot
.724 .34999 Mdot
.724 .35005 Mdot
.724 .35025 Mdot
.724 .35054 Mdot
.724 .35057 Mdot
.724 .35066 Mdot
.724 .35081 Mdot
.724 .35085 Mdot
.724 .35088 Mdot
.724 .35164 Mdot
.724 .35173 Mdot
.724 .35193 Mdot
.724 .35231 Mdot
.724 .3524 Mdot
.724 .35242 Mdot
.724 .35254 Mdot
.724 .35266 Mdot
.724 .35271 Mdot
.724 .35285 Mdot
.724 .35319 Mdot
.724 .35326 Mdot
.724 .35348 Mdot
.724 .35363 Mdot
.724 .35374 Mdot
.724 .35376 Mdot
.724 .35384 Mdot
.724 .35431 Mdot
.724 .35443 Mdot
.724 .35454 Mdot
.724 .35496 Mdot
.724 .35509 Mdot
.724 .35525 Mdot
.724 .35558 Mdot
.724 .35572 Mdot
.724 .35582 Mdot
.724 .35584 Mdot
.724 .3563 Mdot
.724 .35635 Mdot
.724 .35658 Mdot
.724 .35666 Mdot
.724 .35668 Mdot
.724 .35676 Mdot
.724 .35695 Mdot
.724 .35699 Mdot
.724 .35715 Mdot
.724 .35718 Mdot
.724 .35741 Mdot
.724 .35747 Mdot
.724 .35754 Mdot
.724 .35756 Mdot
.724 .35794 Mdot
.724 .35807 Mdot
.724 .3583 Mdot
.724 .35831 Mdot
.724 .35837 Mdot
.724 .35845 Mdot
.724 .35851 Mdot
.724 .35868 Mdot
.724 .35871 Mdot
.724 .35881 Mdot
.724 .35895 Mdot
.724 .35899 Mdot
.724 .35921 Mdot
.724 .35927 Mdot
.724 .35932 Mdot
.724 .35958 Mdot
.724 .35988 Mdot
.724 .35993 Mdot
.724 .35994 Mdot
.724 .36016 Mdot
.724 .36029 Mdot
.724 .36034 Mdot
.724 .36038 Mdot
.724 .36047 Mdot
.724 .36057 Mdot
.724 .36058 Mdot
.724 .36069 Mdot
.724 .36075 Mdot
.724 .36076 Mdot
.724 .36101 Mdot
.724 .36112 Mdot
.724 .36118 Mdot
.724 .36129 Mdot
.724 .36131 Mdot
.724 .36144 Mdot
.724 .3616 Mdot
.724 .36173 Mdot
.724 .3619 Mdot
.724 .362 Mdot
.724 .36206 Mdot
.724 .36209 Mdot
.724 .36219 Mdot
.724 .36225 Mdot
.724 .36249 Mdot
.724 .36254 Mdot
.724 .36261 Mdot
.724 .36269 Mdot
.724 .36275 Mdot
.724 .36288 Mdot
.724 .36297 Mdot
.724 .363 Mdot
.724 .36314 Mdot
.724 .36324 Mdot
.724 .3633 Mdot
.724 .3635 Mdot
.724 .36394 Mdot
.724 .36399 Mdot
.724 .36417 Mdot
.724 .36423 Mdot
.724 .36432 Mdot
.724 .36436 Mdot
.724 .36442 Mdot
.724 .36447 Mdot
.724 .36466 Mdot
.724 .36471 Mdot
.724 .36478 Mdot
.724 .36484 Mdot
.724 .36491 Mdot
.724 .36503 Mdot
.724 .36512 Mdot
.724 .36523 Mdot
.724 .36533 Mdot
.724 .3654 Mdot
.724 .36545 Mdot
.724 .36574 Mdot
.724 .36583 Mdot
.724 .36596 Mdot
.724 .36599 Mdot
.724 .36602 Mdot
.724 .36611 Mdot
.724 .36626 Mdot
.724 .36627 Mdot
.724 .36651 Mdot
.724 .36669 Mdot
.724 .36677 Mdot
.724 .36692 Mdot
.724 .36711 Mdot
.724 .36713 Mdot
.724 .36725 Mdot
.724 .36729 Mdot
.724 .36739 Mdot
.724 .36739 Mdot
.724 .36755 Mdot
.724 .36765 Mdot
.724 .36791 Mdot
.724 .36792 Mdot
.724 .36797 Mdot
.724 .36801 Mdot
.724 .36817 Mdot
.724 .36819 Mdot
.724 .3683 Mdot
.724 .36833 Mdot
.724 .36846 Mdot
.724 .36852 Mdot
.724 .36853 Mdot
.724 .36858 Mdot
.724 .36874 Mdot
.724 .36878 Mdot
.724 .3691 Mdot
.724 .36911 Mdot
.724 .36918 Mdot
.724 .36927 Mdot
.724 .3695 Mdot
.724 .36961 Mdot
.724 .3697 Mdot
.724 .36999 Mdot
.724 .37007 Mdot
.724 .37015 Mdot
.724 .37047 Mdot
.724 .37053 Mdot
.724 .37054 Mdot
.724 .37062 Mdot
.724 .37073 Mdot
.724 .37088 Mdot
.724 .37092 Mdot
.724 .37116 Mdot
.724 .37126 Mdot
.724 .37129 Mdot
.724 .37138 Mdot
.724 .37146 Mdot
.724 .37147 Mdot
.724 .37153 Mdot
.724 .3718 Mdot
.724 .37193 Mdot
.724 .372 Mdot
.724 .37252 Mdot
.724 .37254 Mdot
.724 .37257 Mdot
.724 .37267 Mdot
.724 .37274 Mdot
.724 .37276 Mdot
.724 .37296 Mdot
.724 .37309 Mdot
.724 .37313 Mdot
.724 .37337 Mdot
.724 .37343 Mdot
.724 .37345 Mdot
.724 .37361 Mdot
.724 .3737 Mdot
.724 .37382 Mdot
.724 .37385 Mdot
.724 .37396 Mdot
.724 .37401 Mdot
.724 .37415 Mdot
.724 .37423 Mdot
.724 .37429 Mdot
.724 .37437 Mdot
.724 .37495 Mdot
.724 .37504 Mdot
.724 .37506 Mdot
.724 .37521 Mdot
.724 .37541 Mdot
.724 .37547 Mdot
.724 .3755 Mdot
.724 .37553 Mdot
.724 .37588 Mdot
.724 .37608 Mdot
.724 .37612 Mdot
.724 .3763 Mdot
.724 .37679 Mdot
.724 .37691 Mdot
.724 .37702 Mdot
.724 .37708 Mdot
.724 .37715 Mdot
.724 .37719 Mdot
.724 .37725 Mdot
.724 .37793 Mdot
.724 .37802 Mdot
.724 .37805 Mdot
.724 .37807 Mdot
.724 .37814 Mdot
.724 .37823 Mdot
.724 .3784 Mdot
.724 .37841 Mdot
.724 .37845 Mdot
.724 .37861 Mdot
.724 .37877 Mdot
.724 .37877 Mdot
.724 .37887 Mdot
.724 .37936 Mdot
.724 .37952 Mdot
.724 .37956 Mdot
.724 .37963 Mdot
.724 .37982 Mdot
.724 .37999 Mdot
.724 .38001 Mdot
.724 .38003 Mdot
.724 .38014 Mdot
.724 .38031 Mdot
.724 .38051 Mdot
.724 .38057 Mdot
.724 .3807 Mdot
.724 .38082 Mdot
.724 .3809 Mdot
.724 .38093 Mdot
.724 .38096 Mdot
.724 .38098 Mdot
.724 .38099 Mdot
.724 .38112 Mdot
.724 .3817 Mdot
.724 .38196 Mdot
.724 .38221 Mdot
.724 .38226 Mdot
.724 .38231 Mdot
.724 .3824 Mdot
.724 .38253 Mdot
.724 .38267 Mdot
.724 .38271 Mdot
.724 .38281 Mdot
.724 .38303 Mdot
.724 .38313 Mdot
.724 .38342 Mdot
.724 .3835 Mdot
.724 .38384 Mdot
.724 .38385 Mdot
.724 .384 Mdot
.724 .38411 Mdot
.724 .38415 Mdot
.724 .38416 Mdot
.724 .38426 Mdot
.724 .38438 Mdot
.724 .3845 Mdot
.724 .38468 Mdot
.724 .38494 Mdot
.724 .385 Mdot
.724 .38503 Mdot
.724 .38524 Mdot
.724 .38534 Mdot
.724 .38564 Mdot
.724 .38581 Mdot
.724 .38581 Mdot
.724 .38588 Mdot
.724 .38594 Mdot
.724 .3861 Mdot
.724 .38674 Mdot
.724 .38731 Mdot
.724 .38739 Mdot
.724 .3875 Mdot
.724 .38754 Mdot
.724 .38757 Mdot
.724 .38785 Mdot
.724 .38787 Mdot
.724 .38827 Mdot
.724 .38841 Mdot
.724 .38847 Mdot
.724 .38852 Mdot
.724 .3887 Mdot
.724 .38871 Mdot
.724 .38904 Mdot
.724 .38927 Mdot
.724 .38944 Mdot
.724 .38967 Mdot
.724 .38976 Mdot
.724 .39015 Mdot
.724 .39096 Mdot
.724 .39118 Mdot
.724 .39141 Mdot
.724 .39166 Mdot
.724 .39177 Mdot
.724 .39183 Mdot
.724 .39191 Mdot
.724 .39201 Mdot
.724 .39214 Mdot
.724 .39355 Mdot
.724 .39374 Mdot
.724 .39381 Mdot
.724 .39385 Mdot
.724 .394 Mdot
.724 .39419 Mdot
.724 .39453 Mdot
.724 .39456 Mdot
.724 .39465 Mdot
.724 .39466 Mdot
.724 .39489 Mdot
.724 .39498 Mdot
.724 .39531 Mdot
.724 .39533 Mdot
.724 .39546 Mdot
.724 .39552 Mdot
.724 .39581 Mdot
.724 .39585 Mdot
.724 .39589 Mdot
.724 .39589 Mdot
.724 .39618 Mdot
.724 .39621 Mdot
.724 .39626 Mdot
.724 .39655 Mdot
.724 .39656 Mdot
.724 .39684 Mdot
.724 .39689 Mdot
.724 .39698 Mdot
.724 .39702 Mdot
.724 .39713 Mdot
.724 .39737 Mdot
.724 .39751 Mdot
.724 .39787 Mdot
.724 .39792 Mdot
.724 .39797 Mdot
.724 .39809 Mdot
.724 .39819 Mdot
.724 .39854 Mdot
.724 .39865 Mdot
.724 .39884 Mdot
.724 .39896 Mdot
.724 .39907 Mdot
.724 .39909 Mdot
.724 .39913 Mdot
.724 .39937 Mdot
.724 .39951 Mdot
.724 .39961 Mdot
.724 .39978 Mdot
.724 .39985 Mdot
.724 .39991 Mdot
.724 .39995 Mdot
.724 .39997 Mdot
.724 .40011 Mdot
.724 .40025 Mdot
.724 .40035 Mdot
.724 .40147 Mdot
.724 .4016 Mdot
.724 .40202 Mdot
.724 .40253 Mdot
.724 .40264 Mdot
.724 .40275 Mdot
.724 .40293 Mdot
.724 .4032 Mdot
.724 .40349 Mdot
.724 .40353 Mdot
.724 .40358 Mdot
.724 .40366 Mdot
.724 .40378 Mdot
.724 .40424 Mdot
.724 .40426 Mdot
.724 .40447 Mdot
.724 .40469 Mdot
.724 .40474 Mdot
.724 .40506 Mdot
.724 .40524 Mdot
.724 .40537 Mdot
.724 .4055 Mdot
.724 .40575 Mdot
.724 .40594 Mdot
.724 .40597 Mdot
.724 .40628 Mdot
.724 .40651 Mdot
.724 .40652 Mdot
.724 .40658 Mdot
.724 .4066 Mdot
.724 .40662 Mdot
.724 .40678 Mdot
.724 .40684 Mdot
.724 .40708 Mdot
.724 .40734 Mdot
.724 .40754 Mdot
.724 .40771 Mdot
.724 .40826 Mdot
.724 .40837 Mdot
.724 .40845 Mdot
.724 .40854 Mdot
.724 .40889 Mdot
.724 .40908 Mdot
.724 .40973 Mdot
.724 .40999 Mdot
.724 .41 Mdot
.724 .41001 Mdot
.724 .41007 Mdot
.724 .41008 Mdot
.724 .41022 Mdot
.724 .41034 Mdot
.724 .41064 Mdot
.724 .41068 Mdot
.724 .41073 Mdot
.724 .41083 Mdot
.724 .41102 Mdot
.724 .41131 Mdot
.724 .41174 Mdot
.724 .41191 Mdot
.724 .41201 Mdot
.724 .41202 Mdot
.724 .41219 Mdot
.724 .41242 Mdot
.724 .41244 Mdot
.724 .41321 Mdot
.724 .41338 Mdot
.724 .41361 Mdot
.724 .41367 Mdot
.724 .41372 Mdot
.724 .41377 Mdot
.724 .41377 Mdot
.724 .41435 Mdot
.724 .4144 Mdot
.724 .41499 Mdot
.724 .415 Mdot
.724 .4151 Mdot
.724 .41519 Mdot
.724 .41524 Mdot
.724 .41532 Mdot
.724 .41553 Mdot
.724 .41566 Mdot
.724 .41575 Mdot
.724 .4158 Mdot
.724 .41615 Mdot
.724 .41615 Mdot
.724 .41616 Mdot
.724 .41685 Mdot
.724 .41733 Mdot
.724 .41769 Mdot
.724 .41778 Mdot
.724 .41782 Mdot
.724 .41818 Mdot
.724 .4183 Mdot
.724 .41836 Mdot
.724 .41866 Mdot
.724 .41868 Mdot
.724 .41889 Mdot
.724 .41918 Mdot
.724 .41924 Mdot
.724 .42016 Mdot
.724 .42075 Mdot
.724 .42087 Mdot
.724 .42115 Mdot
.724 .42134 Mdot
.724 .42136 Mdot
.724 .42147 Mdot
.724 .42156 Mdot
.724 .42183 Mdot
.724 .42218 Mdot
.724 .42234 Mdot
.724 .42243 Mdot
.724 .42257 Mdot
.724 .4227 Mdot
.724 .42273 Mdot
.724 .42274 Mdot
.724 .42288 Mdot
.724 .42288 Mdot
.724 .4229 Mdot
.724 .42292 Mdot
.724 .42309 Mdot
.724 .42336 Mdot
.724 .42347 Mdot
.724 .42482 Mdot
.724 .42523 Mdot
.724 .42596 Mdot
.724 .42615 Mdot
.724 .42631 Mdot
.724 .42631 Mdot
.724 .42654 Mdot
.724 .42671 Mdot
.724 .42685 Mdot
.724 .42694 Mdot
.724 .42725 Mdot
.724 .42766 Mdot
.724 .42769 Mdot
.724 .42806 Mdot
.724 .42837 Mdot
.724 .42843 Mdot
.724 .42848 Mdot
.724 .42862 Mdot
.724 .42863 Mdot
.724 .42902 Mdot
.724 .42912 Mdot
.724 .42931 Mdot
.724 .42952 Mdot
.724 .42965 Mdot
.724 .42999 Mdot
.724 .43 Mdot
.724 .43002 Mdot
.724 .43003 Mdot
.724 .43007 Mdot
.724 .43019 Mdot
.724 .43022 Mdot
.724 .43031 Mdot
.724 .43044 Mdot
.724 .43069 Mdot
.724 .43104 Mdot
.724 .43112 Mdot
.724 .43122 Mdot
.724 .43122 Mdot
.724 .43135 Mdot
.724 .43141 Mdot
.724 .4318 Mdot
.724 .43182 Mdot
.724 .43188 Mdot
.724 .43199 Mdot
.724 .43233 Mdot
.724 .43259 Mdot
.724 .4326 Mdot
.724 .43262 Mdot
.724 .43287 Mdot
.724 .43321 Mdot
.724 .43325 Mdot
.724 .43332 Mdot
.724 .43351 Mdot
.724 .43358 Mdot
.724 .43382 Mdot
.724 .43392 Mdot
.724 .43403 Mdot
.724 .43431 Mdot
.724 .4345 Mdot
.724 .43461 Mdot
.724 .43493 Mdot
.724 .43497 Mdot
.724 .43537 Mdot
.724 .43547 Mdot
.724 .43557 Mdot
.724 .43583 Mdot
.724 .43593 Mdot
.724 .43604 Mdot
.724 .4362 Mdot
.724 .43635 Mdot
.724 .43647 Mdot
.724 .43654 Mdot
.724 .43677 Mdot
.724 .43701 Mdot
.724 .43716 Mdot
.724 .4374 Mdot
.724 .43766 Mdot
.724 .43772 Mdot
.724 .43789 Mdot
.724 .43792 Mdot
.724 .43801 Mdot
.724 .4381 Mdot
.724 .43833 Mdot
.724 .4385 Mdot
.724 .43857 Mdot
.724 .43881 Mdot
.724 .43901 Mdot
.724 .43937 Mdot
.724 .43952 Mdot
.724 .43964 Mdot
.724 .43964 Mdot
.724 .43972 Mdot
.724 .43977 Mdot
.724 .44005 Mdot
.724 .44035 Mdot
.724 .4405 Mdot
.724 .44056 Mdot
.724 .44078 Mdot
.726 .24945 Mdot
.726 .2496 Mdot
.726 .25004 Mdot
.726 .25005 Mdot
.726 .25014 Mdot
.726 .25025 Mdot
.726 .25054 Mdot
.726 .2508 Mdot
.726 .25102 Mdot
.726 .25135 Mdot
.726 .25135 Mdot
.726 .25173 Mdot
.726 .25199 Mdot
.726 .25219 Mdot
.726 .2526 Mdot
.726 .25261 Mdot
.726 .25325 Mdot
.726 .25363 Mdot
.726 .25399 Mdot
.726 .25455 Mdot
.726 .25469 Mdot
.726 .25471 Mdot
.726 .25529 Mdot
.726 .2554 Mdot
.726 .25603 Mdot
.726 .25666 Mdot
.726 .25681 Mdot
.726 .25689 Mdot
.726 .25725 Mdot
.726 .2575 Mdot
.726 .25752 Mdot
.726 .2581 Mdot
.726 .25825 Mdot
.726 .25858 Mdot
.726 .25872 Mdot
.726 .2592 Mdot
.726 .25948 Mdot
.726 .25975 Mdot
.726 .25976 Mdot
.726 .26002 Mdot
.726 .26006 Mdot
.726 .26034 Mdot
.726 .26068 Mdot
.726 .26098 Mdot
.726 .26109 Mdot
.726 .26146 Mdot
.726 .26152 Mdot
.726 .26167 Mdot
.726 .26171 Mdot
.726 .26177 Mdot
.726 .26227 Mdot
.726 .26297 Mdot
.726 .26298 Mdot
.726 .26441 Mdot
.726 .26483 Mdot
.726 .26497 Mdot
.726 .26536 Mdot
.726 .26559 Mdot
.726 .26568 Mdot
.726 .2658 Mdot
.726 .26585 Mdot
.726 .26626 Mdot
.726 .26627 Mdot
.726 .26701 Mdot
.726 .26735 Mdot
.726 .26738 Mdot
.726 .26755 Mdot
.726 .2678 Mdot
.726 .26783 Mdot
.726 .26804 Mdot
.726 .26819 Mdot
.726 .26842 Mdot
.726 .26947 Mdot
.726 .26949 Mdot
.726 .27 Mdot
.726 .27 Mdot
.726 .27038 Mdot
.726 .27044 Mdot
.726 .27066 Mdot
.726 .2709 Mdot
.726 .27106 Mdot
.726 .27131 Mdot
.726 .27138 Mdot
.726 .27198 Mdot
.726 .27203 Mdot
.726 .27211 Mdot
.726 .27231 Mdot
.726 .27234 Mdot
.726 .27236 Mdot
.726 .27248 Mdot
.726 .27249 Mdot
.726 .27259 Mdot
.726 .27277 Mdot
.726 .27316 Mdot
.726 .27336 Mdot
.726 .27336 Mdot
.726 .27361 Mdot
.726 .27395 Mdot
.726 .27436 Mdot
.726 .27493 Mdot
.726 .27592 Mdot
.726 .27628 Mdot
.726 .27648 Mdot
.726 .2766 Mdot
.726 .2766 Mdot
.726 .27689 Mdot
.726 .27692 Mdot
.726 .27707 Mdot
.726 .27858 Mdot
.726 .27879 Mdot
.726 .27891 Mdot
.726 .27902 Mdot
.726 .27905 Mdot
.726 .27945 Mdot
.726 .27993 Mdot
.726 .28017 Mdot
.726 .2808 Mdot
.726 .28107 Mdot
.726 .28125 Mdot
.726 .28154 Mdot
.726 .28182 Mdot
.726 .28197 Mdot
.726 .2823 Mdot
.726 .28243 Mdot
.726 .28279 Mdot
.726 .28337 Mdot
.726 .28349 Mdot
.726 .2835 Mdot
.726 .28387 Mdot
.726 .28387 Mdot
.726 .28416 Mdot
.726 .28416 Mdot
.726 .28461 Mdot
.726 .28475 Mdot
.726 .28479 Mdot
.726 .28525 Mdot
.726 .28582 Mdot
.726 .28598 Mdot
.726 .28605 Mdot
.726 .28618 Mdot
.726 .28626 Mdot
.726 .28636 Mdot
.726 .28645 Mdot
.726 .2865 Mdot
.726 .28663 Mdot
.726 .2873 Mdot
.726 .28733 Mdot
.726 .28772 Mdot
.726 .28777 Mdot
.726 .28778 Mdot
.726 .28797 Mdot
.726 .28834 Mdot
.726 .2884 Mdot
.726 .28854 Mdot
.726 .28906 Mdot
.726 .28944 Mdot
.726 .28972 Mdot
.726 .28978 Mdot
.726 .29003 Mdot
.726 .29058 Mdot
.726 .2909 Mdot
.726 .29142 Mdot
.726 .29154 Mdot
.726 .29214 Mdot
.726 .29218 Mdot
.726 .29233 Mdot
.726 .29236 Mdot
.726 .29243 Mdot
.726 .29271 Mdot
.726 .29295 Mdot
.726 .29301 Mdot
.726 .2936 Mdot
.726 .29404 Mdot
.726 .29411 Mdot
.726 .29433 Mdot
.726 .29447 Mdot
.726 .29469 Mdot
.726 .29482 Mdot
.726 .29512 Mdot
.726 .29523 Mdot
.726 .29565 Mdot
.726 .29566 Mdot
.726 .29577 Mdot
.726 .29587 Mdot
.726 .29659 Mdot
.726 .29666 Mdot
.726 .29681 Mdot
.726 .29686 Mdot
.726 .29713 Mdot
.726 .29806 Mdot
.726 .29834 Mdot
.726 .29844 Mdot
.726 .29862 Mdot
.726 .29876 Mdot
.726 .29882 Mdot
.726 .29883 Mdot
.726 .29884 Mdot
.726 .29894 Mdot
.726 .29898 Mdot
.726 .299 Mdot
.726 .29929 Mdot
.726 .29944 Mdot
.726 .29963 Mdot
.726 .29976 Mdot
.726 .30097 Mdot
.726 .3011 Mdot
.726 .3012 Mdot
.726 .30171 Mdot
.726 .30193 Mdot
.726 .30199 Mdot
.726 .30203 Mdot
.726 .30232 Mdot
.726 .30259 Mdot
.726 .30327 Mdot
.726 .30327 Mdot
.726 .30361 Mdot
.726 .30387 Mdot
.726 .30389 Mdot
.726 .30422 Mdot
.726 .30452 Mdot
.726 .30466 Mdot
.726 .30468 Mdot
.726 .3048 Mdot
.726 .30493 Mdot
.726 .30559 Mdot
.726 .30586 Mdot
.726 .30599 Mdot
.726 .30616 Mdot
.726 .30627 Mdot
.726 .30657 Mdot
.726 .30686 Mdot
.726 .30692 Mdot
.726 .30719 Mdot
.726 .30753 Mdot
.726 .30788 Mdot
.726 .30819 Mdot
.726 .30819 Mdot
.726 .30848 Mdot
.726 .30861 Mdot
.726 .30879 Mdot
.726 .30917 Mdot
.726 .30941 Mdot
.726 .30969 Mdot
.726 .30977 Mdot
.726 .30999 Mdot
.726 .31003 Mdot
.726 .31009 Mdot
.726 .31035 Mdot
.726 .31045 Mdot
.726 .31061 Mdot
.726 .31101 Mdot
.726 .31169 Mdot
.726 .31213 Mdot
.726 .31219 Mdot
.726 .3132 Mdot
.726 .31388 Mdot
.726 .31404 Mdot
.726 .3141 Mdot
.726 .31433 Mdot
.726 .31459 Mdot
.726 .31503 Mdot
.726 .31523 Mdot
.726 .3154 Mdot
.726 .31543 Mdot
.726 .31555 Mdot
.726 .317 Mdot
.726 .31725 Mdot
.726 .31749 Mdot
.726 .31768 Mdot
.726 .31803 Mdot
.726 .31821 Mdot
.726 .31841 Mdot
.726 .31852 Mdot
.726 .31859 Mdot
.726 .3187 Mdot
.726 .3192 Mdot
.726 .31921 Mdot
.726 .31945 Mdot
.726 .31945 Mdot
.726 .31966 Mdot
.726 .31988 Mdot
.726 .32007 Mdot
.726 .32063 Mdot
.726 .32068 Mdot
.726 .32105 Mdot
.726 .32116 Mdot
.726 .32152 Mdot
.726 .32179 Mdot
.726 .32243 Mdot
.726 .32259 Mdot
.726 .32272 Mdot
.726 .32368 Mdot
.726 .32394 Mdot
.726 .32479 Mdot
.726 .32513 Mdot
.726 .32552 Mdot
.726 .32585 Mdot
.726 .32586 Mdot
.726 .32603 Mdot
.726 .32603 Mdot
.726 .32617 Mdot
.726 .32617 Mdot
.726 .32647 Mdot
.726 .32713 Mdot
.726 .32717 Mdot
.726 .32728 Mdot
.726 .32734 Mdot
.726 .32766 Mdot
.726 .32767 Mdot
.726 .32788 Mdot
.726 .32788 Mdot
.726 .32815 Mdot
.726 .32818 Mdot
.726 .32824 Mdot
.726 .32867 Mdot
.726 .32884 Mdot
.726 .32895 Mdot
.726 .32922 Mdot
.726 .32997 Mdot
.726 .33004 Mdot
.726 .33006 Mdot
.726 .33009 Mdot
.726 .33022 Mdot
.726 .33037 Mdot
.726 .33065 Mdot
.726 .33089 Mdot
.726 .33116 Mdot
.726 .33122 Mdot
.726 .33137 Mdot
.726 .33172 Mdot
.726 .33217 Mdot
.726 .3322 Mdot
.726 .33232 Mdot
.726 .33309 Mdot
.726 .33312 Mdot
.726 .33313 Mdot
.726 .33318 Mdot
.726 .3332 Mdot
.726 .3335 Mdot
.726 .3342 Mdot
.726 .33425 Mdot
.726 .33449 Mdot
.726 .33463 Mdot
.726 .33491 Mdot
.726 .33539 Mdot
.726 .33568 Mdot
.726 .33583 Mdot
.726 .33596 Mdot
.726 .33633 Mdot
.726 .33646 Mdot
.726 .33652 Mdot
.726 .33665 Mdot
.726 .3368 Mdot
.726 .33694 Mdot
.726 .33726 Mdot
.726 .33757 Mdot
.726 .33771 Mdot
.726 .33776 Mdot
.726 .33803 Mdot
.726 .33828 Mdot
.726 .33842 Mdot
.726 .33844 Mdot
.726 .33847 Mdot
.726 .33864 Mdot
.726 .33871 Mdot
.726 .3389 Mdot
.726 .33943 Mdot
.726 .34026 Mdot
.726 .3409 Mdot
.726 .34099 Mdot
.726 .341 Mdot
.726 .34106 Mdot
.726 .34175 Mdot
.726 .34186 Mdot
.726 .34198 Mdot
.726 .34207 Mdot
.726 .34224 Mdot
.726 .34241 Mdot
.726 .34255 Mdot
.726 .34291 Mdot
.726 .34301 Mdot
.726 .3432 Mdot
.726 .34349 Mdot
.726 .34367 Mdot
.726 .34372 Mdot
.726 .34389 Mdot
.726 .34402 Mdot
.726 .34432 Mdot
.726 .34439 Mdot
.726 .34491 Mdot
.726 .3456 Mdot
.726 .34594 Mdot
.726 .34595 Mdot
.726 .34609 Mdot
.726 .34609 Mdot
.726 .3465 Mdot
.726 .34655 Mdot
.726 .34657 Mdot
.726 .34665 Mdot
.726 .34681 Mdot
.726 .34754 Mdot
.726 .3479 Mdot
.726 .34793 Mdot
.726 .34794 Mdot
.726 .34796 Mdot
.726 .34822 Mdot
.726 .34846 Mdot
.726 .34856 Mdot
.726 .34894 Mdot
.726 .34938 Mdot
.726 .34942 Mdot
.726 .34943 Mdot
.726 .34957 Mdot
.726 .35004 Mdot
.726 .35011 Mdot
.726 .35024 Mdot
.726 .35047 Mdot
.726 .35061 Mdot
.726 .35068 Mdot
.726 .35074 Mdot
.726 .35091 Mdot
.726 .351 Mdot
.726 .35107 Mdot
.726 .35114 Mdot
.726 .3515 Mdot
.726 .35172 Mdot
.726 .35191 Mdot
.726 .35192 Mdot
.726 .35193 Mdot
.726 .35213 Mdot
.726 .35278 Mdot
.726 .35308 Mdot
.726 .35316 Mdot
.726 .35348 Mdot
.726 .35364 Mdot
.726 .35387 Mdot
.726 .35408 Mdot
.726 .35417 Mdot
.726 .35431 Mdot
.726 .35439 Mdot
.726 .3545 Mdot
.726 .3547 Mdot
.726 .35474 Mdot
.726 .35531 Mdot
.726 .35547 Mdot
.726 .35548 Mdot
.726 .35555 Mdot
.726 .35555 Mdot
.726 .35574 Mdot
.726 .35576 Mdot
.726 .35577 Mdot
.726 .35581 Mdot
.726 .35588 Mdot
.726 .35623 Mdot
.726 .3564 Mdot
.726 .35643 Mdot
.726 .35655 Mdot
.726 .35667 Mdot
.726 .35671 Mdot
.726 .3569 Mdot
.726 .3571 Mdot
.726 .35713 Mdot
.726 .3572 Mdot
.726 .35742 Mdot
.726 .35745 Mdot
.726 .35751 Mdot
.726 .35775 Mdot
.726 .35783 Mdot
.726 .3579 Mdot
.726 .35811 Mdot
.726 .35821 Mdot
.726 .35831 Mdot
.726 .35831 Mdot
.726 .35886 Mdot
.726 .3589 Mdot
.726 .35912 Mdot
.726 .35923 Mdot
.726 .35944 Mdot
.726 .35948 Mdot
.726 .35953 Mdot
.726 .35999 Mdot
.726 .36 Mdot
.726 .36003 Mdot
.726 .36012 Mdot
.726 .36013 Mdot
.726 .36015 Mdot
.726 .36035 Mdot
.726 .36056 Mdot
.726 .36077 Mdot
.726 .36092 Mdot
.726 .36093 Mdot
.726 .36107 Mdot
.726 .36124 Mdot
.726 .36162 Mdot
.726 .36173 Mdot
.726 .36214 Mdot
.726 .36215 Mdot
.726 .36221 Mdot
.726 .36231 Mdot
.726 .36241 Mdot
.726 .36258 Mdot
.726 .36296 Mdot
.726 .36316 Mdot
.726 .36319 Mdot
.726 .36324 Mdot
.726 .36328 Mdot
.726 .36368 Mdot
.726 .3637 Mdot
.726 .36388 Mdot
.726 .3639 Mdot
.726 .36398 Mdot
.726 .36403 Mdot
.726 .36413 Mdot
.726 .3642 Mdot
.726 .3642 Mdot
.726 .36433 Mdot
.726 .36435 Mdot
.726 .36462 Mdot
.726 .36465 Mdot
.726 .3651 Mdot
.726 .36522 Mdot
.726 .36529 Mdot
.726 .36535 Mdot
.726 .36539 Mdot
.726 .36569 Mdot
.726 .36602 Mdot
.726 .36624 Mdot
.726 .36625 Mdot
.726 .36635 Mdot
.726 .36649 Mdot
.726 .36663 Mdot
.726 .36677 Mdot
.726 .36686 Mdot
.726 .36688 Mdot
.726 .36688 Mdot
.726 .36724 Mdot
.726 .36726 Mdot
.726 .36748 Mdot
.726 .36764 Mdot
.726 .36811 Mdot
.726 .36818 Mdot
.726 .36832 Mdot
.726 .36843 Mdot
.726 .36864 Mdot
.726 .36866 Mdot
.726 .36881 Mdot
.726 .36887 Mdot
.726 .36902 Mdot
.726 .36917 Mdot
.726 .36947 Mdot
.726 .36971 Mdot
.726 .36976 Mdot
.726 .36979 Mdot
.726 .36981 Mdot
.726 .36995 Mdot
.726 .36999 Mdot
.726 .37 Mdot
.726 .37011 Mdot
.726 .3705 Mdot
.726 .37053 Mdot
.726 .37067 Mdot
.726 .37074 Mdot
.726 .3708 Mdot
.726 .37089 Mdot
.726 .37095 Mdot
.726 .3711 Mdot
.726 .37126 Mdot
.726 .37137 Mdot
.726 .37159 Mdot
.726 .37164 Mdot
.726 .37185 Mdot
.726 .3723 Mdot
.726 .37244 Mdot
.726 .37245 Mdot
.726 .37245 Mdot
.726 .37258 Mdot
.726 .37273 Mdot
.726 .37298 Mdot
.726 .37303 Mdot
.726 .37307 Mdot
.726 .37314 Mdot
.726 .37326 Mdot
.726 .3733 Mdot
.726 .37335 Mdot
.726 .37344 Mdot
.726 .3736 Mdot
.726 .37369 Mdot
.726 .37374 Mdot
.726 .37406 Mdot
.726 .37416 Mdot
.726 .37417 Mdot
.726 .37419 Mdot
.726 .37449 Mdot
.726 .37476 Mdot
.726 .37482 Mdot
.726 .37499 Mdot
.726 .37517 Mdot
.726 .37518 Mdot
.726 .37519 Mdot
.726 .37521 Mdot
.726 .37546 Mdot
.726 .37596 Mdot
.726 .37607 Mdot
.726 .37613 Mdot
.726 .37614 Mdot
.726 .37617 Mdot
.726 .37646 Mdot
.726 .37646 Mdot
.726 .37656 Mdot
.726 .37656 Mdot
.726 .37679 Mdot
.726 .37727 Mdot
.726 .37763 Mdot
.726 .37768 Mdot
.726 .37788 Mdot
.726 .37797 Mdot
.726 .37809 Mdot
.726 .37813 Mdot
.726 .37825 Mdot
.726 .37845 Mdot
.726 .37858 Mdot
.726 .37865 Mdot
.726 .37889 Mdot
.726 .37899 Mdot
.726 .37911 Mdot
.726 .37923 Mdot
.726 .37929 Mdot
.726 .37937 Mdot
.726 .37945 Mdot
.726 .37992 Mdot
.726 .37996 Mdot
.726 .37997 Mdot
.726 .38003 Mdot
.726 .38047 Mdot
.726 .38104 Mdot
.726 .38141 Mdot
.726 .38154 Mdot
.726 .38159 Mdot
.726 .38171 Mdot
.726 .38173 Mdot
.726 .38174 Mdot
.726 .38184 Mdot
.726 .38201 Mdot
.726 .38219 Mdot
.726 .38223 Mdot
.726 .38233 Mdot
.726 .38254 Mdot
.726 .38276 Mdot
.726 .38286 Mdot
.726 .38296 Mdot
.726 .38305 Mdot
.726 .38309 Mdot
.726 .38318 Mdot
.726 .38344 Mdot
.726 .38353 Mdot
.726 .38363 Mdot
.726 .38383 Mdot
.726 .38416 Mdot
.726 .38435 Mdot
.726 .38444 Mdot
.726 .38461 Mdot
.726 .38464 Mdot
.726 .38513 Mdot
.726 .38534 Mdot
.726 .38535 Mdot
.726 .38539 Mdot
.726 .38539 Mdot
.726 .38541 Mdot
.726 .38594 Mdot
.726 .38603 Mdot
.726 .38605 Mdot
.726 .38635 Mdot
.726 .3866 Mdot
.726 .3867 Mdot
.726 .38674 Mdot
.726 .38693 Mdot
.726 .38709 Mdot
.726 .38729 Mdot
.726 .38739 Mdot
.726 .38747 Mdot
.726 .3875 Mdot
.726 .38751 Mdot
.726 .38756 Mdot
.726 .38808 Mdot
.726 .38826 Mdot
.726 .38834 Mdot
.726 .38845 Mdot
.726 .38875 Mdot
.726 .38879 Mdot
.726 .38881 Mdot
.726 .389 Mdot
.726 .389 Mdot
.726 .38914 Mdot
.726 .38915 Mdot
.726 .38937 Mdot
.726 .38941 Mdot
.726 .38949 Mdot
.726 .38952 Mdot
.726 .38997 Mdot
.726 .39018 Mdot
.726 .39018 Mdot
.726 .39027 Mdot
.726 .39027 Mdot
.726 .39039 Mdot
.726 .3904 Mdot
.726 .39063 Mdot
.726 .39089 Mdot
.726 .39113 Mdot
.726 .39172 Mdot
.726 .39189 Mdot
.726 .39255 Mdot
.726 .39265 Mdot
.726 .39275 Mdot
.726 .39319 Mdot
.726 .39338 Mdot
.726 .39363 Mdot
.726 .3937 Mdot
.726 .39396 Mdot
.726 .39399 Mdot
.726 .39438 Mdot
.726 .39451 Mdot
.726 .39466 Mdot
.726 .3948 Mdot
.726 .3948 Mdot
.726 .39497 Mdot
.726 .39498 Mdot
.726 .39532 Mdot
.726 .39539 Mdot
.726 .39544 Mdot
.726 .39552 Mdot
.726 .39566 Mdot
.726 .39578 Mdot
.726 .39602 Mdot
.726 .39616 Mdot
.726 .39632 Mdot
.726 .39649 Mdot
.726 .39749 Mdot
.726 .39757 Mdot
.726 .39759 Mdot
.726 .39771 Mdot
.726 .39785 Mdot
.726 .39815 Mdot
.726 .39833 Mdot
.726 .39849 Mdot
.726 .39853 Mdot
.726 .39864 Mdot
.726 .39911 Mdot
.726 .3998 Mdot
.726 .39985 Mdot
.726 .40015 Mdot
.726 .40062 Mdot
.726 .40089 Mdot
.726 .401 Mdot
.726 .40107 Mdot
.726 .40125 Mdot
.726 .40129 Mdot
.726 .40132 Mdot
.726 .40147 Mdot
.726 .40153 Mdot
.726 .40172 Mdot
.726 .40188 Mdot
.726 .40215 Mdot
.726 .40227 Mdot
.726 .40236 Mdot
.726 .40256 Mdot
.726 .40256 Mdot
.726 .40277 Mdot
.726 .40301 Mdot
.726 .40325 Mdot
.726 .40344 Mdot
.726 .40347 Mdot
.726 .40368 Mdot
.726 .40388 Mdot
.726 .40396 Mdot
.726 .40408 Mdot
.726 .40416 Mdot
.726 .40435 Mdot
.726 .4048 Mdot
.726 .4049 Mdot
.726 .40498 Mdot
.726 .40499 Mdot
.726 .40509 Mdot
.726 .4053 Mdot
.726 .40552 Mdot
.726 .40553 Mdot
.726 .40572 Mdot
.726 .40595 Mdot
.726 .40595 Mdot
.726 .40641 Mdot
.726 .4066 Mdot
.726 .4068 Mdot
.726 .40683 Mdot
.726 .40687 Mdot
.726 .40702 Mdot
.726 .40738 Mdot
.726 .40744 Mdot
.726 .40753 Mdot
.726 .40837 Mdot
.726 .40846 Mdot
.726 .40859 Mdot
.726 .40869 Mdot
.726 .40889 Mdot
.726 .40891 Mdot
.726 .40893 Mdot
.726 .409 Mdot
.726 .40901 Mdot
.726 .40901 Mdot
.726 .40905 Mdot
.726 .40915 Mdot
.726 .40927 Mdot
.726 .40934 Mdot
.726 .40953 Mdot
.726 .41018 Mdot
.726 .41036 Mdot
.726 .4104 Mdot
.726 .4105 Mdot
.726 .41055 Mdot
.726 .41105 Mdot
.726 .41111 Mdot
.726 .41119 Mdot
.726 .4112 Mdot
.726 .41148 Mdot
.726 .41156 Mdot
.726 .41177 Mdot
.726 .41186 Mdot
.726 .41201 Mdot
.726 .4121 Mdot
.726 .41226 Mdot
.726 .4123 Mdot
.726 .41261 Mdot
.726 .41301 Mdot
.726 .41306 Mdot
.726 .41322 Mdot
.726 .41341 Mdot
.726 .41346 Mdot
.726 .41348 Mdot
.726 .41359 Mdot
.726 .41362 Mdot
.726 .41403 Mdot
.726 .41411 Mdot
.726 .41447 Mdot
.726 .41469 Mdot
.726 .41507 Mdot
.726 .41524 Mdot
.726 .41528 Mdot
.726 .41547 Mdot
.726 .41574 Mdot
.726 .4161 Mdot
.726 .41619 Mdot
.726 .41623 Mdot
.726 .41648 Mdot
.726 .41662 Mdot
.726 .41662 Mdot
.726 .41666 Mdot
.726 .41693 Mdot
.726 .41695 Mdot
.726 .41741 Mdot
.726 .4175 Mdot
.726 .41753 Mdot
.726 .41759 Mdot
.726 .41766 Mdot
.726 .41772 Mdot
.726 .41781 Mdot
.726 .41786 Mdot
.726 .41796 Mdot
.726 .41836 Mdot
.726 .41867 Mdot
.726 .4187 Mdot
.726 .4188 Mdot
.726 .41911 Mdot
.726 .41911 Mdot
.726 .41931 Mdot
.726 .41931 Mdot
.726 .41956 Mdot
.726 .41957 Mdot
.726 .41965 Mdot
.726 .42005 Mdot
.726 .4203 Mdot
.726 .42039 Mdot
.726 .42062 Mdot
.726 .42072 Mdot
.726 .42091 Mdot
.726 .42112 Mdot
.726 .42123 Mdot
.726 .42142 Mdot
.726 .42186 Mdot
.726 .42202 Mdot
.726 .42235 Mdot
.726 .42263 Mdot
.726 .42265 Mdot
.726 .42272 Mdot
.726 .42281 Mdot
.726 .42295 Mdot
.726 .42399 Mdot
.726 .42409 Mdot
.726 .42412 Mdot
.726 .42431 Mdot
.726 .42432 Mdot
.726 .4244 Mdot
.726 .42454 Mdot
.726 .42478 Mdot
.726 .42546 Mdot
.726 .42586 Mdot
.726 .42614 Mdot
.726 .42638 Mdot
.726 .42654 Mdot
.726 .42655 Mdot
.726 .42669 Mdot
.726 .42695 Mdot
.726 .42708 Mdot
.726 .42715 Mdot
.726 .42715 Mdot
.726 .42724 Mdot
.726 .42725 Mdot
.726 .42727 Mdot
.726 .42741 Mdot
.726 .42746 Mdot
.726 .4275 Mdot
.726 .42791 Mdot
.726 .42796 Mdot
.726 .42813 Mdot
.726 .42824 Mdot
.726 .4284 Mdot
.726 .42856 Mdot
.726 .4286 Mdot
.726 .42886 Mdot
.726 .42886 Mdot
.726 .42921 Mdot
.726 .42923 Mdot
.726 .42995 Mdot
.726 .43011 Mdot
.726 .43021 Mdot
.726 .43036 Mdot
.726 .43038 Mdot
.726 .43055 Mdot
.726 .43066 Mdot
.726 .43069 Mdot
.726 .43092 Mdot
.726 .43143 Mdot
.726 .43144 Mdot
.726 .43172 Mdot
.726 .43175 Mdot
.726 .43184 Mdot
.726 .4319 Mdot
.726 .43206 Mdot
.726 .43232 Mdot
.726 .43242 Mdot
.726 .43271 Mdot
.726 .4337 Mdot
.726 .4337 Mdot
.726 .43419 Mdot
.726 .43453 Mdot
.726 .43457 Mdot
.726 .4346 Mdot
.726 .4347 Mdot
.726 .43475 Mdot
.726 .435 Mdot
.726 .43507 Mdot
.726 .43528 Mdot
.726 .43551 Mdot
.726 .43571 Mdot
.726 .43574 Mdot
.726 .43591 Mdot
.726 .43592 Mdot
.726 .43611 Mdot
.726 .4363 Mdot
.726 .43663 Mdot
.726 .43673 Mdot
.726 .43696 Mdot
.726 .43706 Mdot
.726 .43746 Mdot
.726 .43747 Mdot
.726 .43764 Mdot
.726 .43789 Mdot
.726 .43795 Mdot
.726 .43805 Mdot
.726 .43848 Mdot
.726 .43891 Mdot
.726 .43899 Mdot
.726 .43939 Mdot
.726 .4394 Mdot
.726 .4395 Mdot
.726 .43989 Mdot
.726 .44014 Mdot
.726 .4404 Mdot
.726 .44084 Mdot
.726 .44085 Mdot
.726 .44113 Mdot
.726 .44127 Mdot
.726 .44144 Mdot
.726 .4417 Mdot
.726 .44171 Mdot
.726 .44193 Mdot
.726 .44208 Mdot
.726 .44227 Mdot
.726 .44246 Mdot
.726 .44254 Mdot
.726 .4426 Mdot
.726 .44261 Mdot
.726 .44291 Mdot
.726 .44302 Mdot
.728 .24856 Mdot
.728 .2486 Mdot
.728 .24868 Mdot
.728 .24929 Mdot
.728 .2494 Mdot
.728 .2496 Mdot
.728 .2496 Mdot
.728 .24986 Mdot
.728 .24998 Mdot
.728 .25 Mdot
.728 .2502 Mdot
.728 .25092 Mdot
.728 .25112 Mdot
.728 .25144 Mdot
.728 .25162 Mdot
.728 .25205 Mdot
.728 .25227 Mdot
.728 .2525 Mdot
.728 .25254 Mdot
.728 .2526 Mdot
.728 .2527 Mdot
.728 .25299 Mdot
.728 .25308 Mdot
.728 .25312 Mdot
.728 .25321 Mdot
.728 .25336 Mdot
.728 .25402 Mdot
.728 .25416 Mdot
.728 .25425 Mdot
.728 .25426 Mdot
.728 .2544 Mdot
.728 .25508 Mdot
.728 .2553 Mdot
.728 .25627 Mdot
.728 .25629 Mdot
.728 .25639 Mdot
.728 .25653 Mdot
.728 .25717 Mdot
.728 .25745 Mdot
.728 .25751 Mdot
.728 .25795 Mdot
.728 .25843 Mdot
.728 .25902 Mdot
.728 .25904 Mdot
.728 .25914 Mdot
.728 .25995 Mdot
.728 .26039 Mdot
.728 .26044 Mdot
.728 .2606 Mdot
.728 .2614 Mdot
.728 .26144 Mdot
.728 .26145 Mdot
.728 .26186 Mdot
.728 .2619 Mdot
.728 .26196 Mdot
.728 .26198 Mdot
.728 .26219 Mdot
.728 .26239 Mdot
.728 .26241 Mdot
.728 .2628 Mdot
.728 .26294 Mdot
.728 .26303 Mdot
.728 .26369 Mdot
.728 .26399 Mdot
.728 .26409 Mdot
.728 .2644 Mdot
.728 .26445 Mdot
.728 .26511 Mdot
.728 .26519 Mdot
.728 .266 Mdot
.728 .26611 Mdot
.728 .26639 Mdot
.728 .26668 Mdot
.728 .26668 Mdot
.728 .26698 Mdot
.728 .26714 Mdot
.728 .26715 Mdot
.728 .26746 Mdot
.728 .26824 Mdot
.728 .26848 Mdot
.728 .26936 Mdot
.728 .26975 Mdot
.728 .2708 Mdot
.728 .27105 Mdot
.728 .27107 Mdot
.728 .27132 Mdot
.728 .27193 Mdot
.728 .27265 Mdot
.728 .27284 Mdot
.728 .2731 Mdot
.728 .27322 Mdot
.728 .27349 Mdot
.728 .27371 Mdot
.728 .27424 Mdot
.728 .27425 Mdot
.728 .27466 Mdot
.728 .27532 Mdot
.728 .27577 Mdot
.728 .27609 Mdot
.728 .27634 Mdot
.728 .27675 Mdot
.728 .27718 Mdot
.728 .27719 Mdot
.728 .27726 Mdot
.728 .27764 Mdot
.728 .27768 Mdot
.728 .27773 Mdot
.728 .27774 Mdot
.728 .27785 Mdot
.728 .27804 Mdot
.728 .27809 Mdot
.728 .27836 Mdot
.728 .27898 Mdot
.728 .27942 Mdot
.728 .27968 Mdot
.728 .27973 Mdot
.728 .28008 Mdot
.728 .28071 Mdot
.728 .28097 Mdot
.728 .28104 Mdot
.728 .28112 Mdot
.728 .28117 Mdot
.728 .28133 Mdot
.728 .28138 Mdot
.728 .28163 Mdot
.728 .28188 Mdot
.728 .28208 Mdot
.728 .28226 Mdot
.728 .28258 Mdot
.728 .2828 Mdot
.728 .283 Mdot
.728 .28334 Mdot
.728 .28345 Mdot
.728 .28378 Mdot
.728 .28398 Mdot
.728 .28451 Mdot
.728 .28471 Mdot
.728 .28484 Mdot
.728 .28494 Mdot
.728 .28582 Mdot
.728 .28601 Mdot
.728 .28617 Mdot
.728 .28629 Mdot
.728 .2873 Mdot
.728 .28744 Mdot
.728 .28773 Mdot
.728 .28805 Mdot
.728 .28817 Mdot
.728 .28838 Mdot
.728 .28881 Mdot
.728 .2889 Mdot
.728 .28946 Mdot
.728 .29057 Mdot
.728 .29062 Mdot
.728 .29082 Mdot
.728 .29126 Mdot
.728 .29194 Mdot
.728 .29203 Mdot
.728 .29244 Mdot
.728 .29255 Mdot
.728 .29264 Mdot
.728 .29299 Mdot
.728 .29314 Mdot
.728 .29319 Mdot
.728 .29335 Mdot
.728 .29355 Mdot
.728 .29379 Mdot
.728 .294 Mdot
.728 .29412 Mdot
.728 .29422 Mdot
.728 .29424 Mdot
.728 .29444 Mdot
.728 .29492 Mdot
.728 .29525 Mdot
.728 .29554 Mdot
.728 .2957 Mdot
.728 .29584 Mdot
.728 .29584 Mdot
.728 .29606 Mdot
.728 .29609 Mdot
.728 .29729 Mdot
.728 .29749 Mdot
.728 .29784 Mdot
.728 .29797 Mdot
.728 .29803 Mdot
.728 .29824 Mdot
.728 .29858 Mdot
.728 .29887 Mdot
.728 .29899 Mdot
.728 .29899 Mdot
.728 .2996 Mdot
.728 .30084 Mdot
.728 .30106 Mdot
.728 .30132 Mdot
.728 .30138 Mdot
.728 .30176 Mdot
.728 .30179 Mdot
.728 .30232 Mdot
.728 .30246 Mdot
.728 .30282 Mdot
.728 .30288 Mdot
.728 .30331 Mdot
.728 .30353 Mdot
.728 .30355 Mdot
.728 .304 Mdot
.728 .30423 Mdot
.728 .30466 Mdot
.728 .30495 Mdot
.728 .30538 Mdot
.728 .30584 Mdot
.728 .30596 Mdot
.728 .30652 Mdot
.728 .30691 Mdot
.728 .30692 Mdot
.728 .30734 Mdot
.728 .30747 Mdot
.728 .30765 Mdot
.728 .30785 Mdot
.728 .30816 Mdot
.728 .30839 Mdot
.728 .30849 Mdot
.728 .30883 Mdot
.728 .30892 Mdot
.728 .30893 Mdot
.728 .30911 Mdot
.728 .30926 Mdot
.728 .30954 Mdot
.728 .3096 Mdot
.728 .30981 Mdot
.728 .31019 Mdot
.728 .31028 Mdot
.728 .3104 Mdot
.728 .31115 Mdot
.728 .31144 Mdot
.728 .31165 Mdot
.728 .31167 Mdot
.728 .3117 Mdot
.728 .31188 Mdot
.728 .31194 Mdot
.728 .31199 Mdot
.728 .31237 Mdot
.728 .31243 Mdot
.728 .31255 Mdot
.728 .31297 Mdot
.728 .31344 Mdot
.728 .31349 Mdot
.728 .31385 Mdot
.728 .31399 Mdot
.728 .31422 Mdot
.728 .31472 Mdot
.728 .31478 Mdot
.728 .31537 Mdot
.728 .31547 Mdot
.728 .31587 Mdot
.728 .31607 Mdot
.728 .31611 Mdot
.728 .31612 Mdot
.728 .31622 Mdot
.728 .31632 Mdot
.728 .31632 Mdot
.728 .31662 Mdot
.728 .31712 Mdot
.728 .31726 Mdot
.728 .31729 Mdot
.728 .3182 Mdot
.728 .31834 Mdot
.728 .31848 Mdot
.728 .31856 Mdot
.728 .3187 Mdot
.728 .31907 Mdot
.728 .31919 Mdot
.728 .3196 Mdot
.728 .32028 Mdot
.728 .32124 Mdot
.728 .32165 Mdot
.728 .32191 Mdot
.728 .32241 Mdot
.728 .32263 Mdot
.728 .32278 Mdot
.728 .3229 Mdot
.728 .32309 Mdot
.728 .32329 Mdot
.728 .32351 Mdot
.728 .32353 Mdot
.728 .32361 Mdot
.728 .32372 Mdot
.728 .32435 Mdot
.728 .3245 Mdot
.728 .32466 Mdot
.728 .32508 Mdot
.728 .32511 Mdot
.728 .32525 Mdot
.728 .32551 Mdot
.728 .32569 Mdot
.728 .32594 Mdot
.728 .3265 Mdot
.728 .3269 Mdot
.728 .32753 Mdot
.728 .32759 Mdot
.728 .32806 Mdot
.728 .32827 Mdot
.728 .32842 Mdot
.728 .32847 Mdot
.728 .32908 Mdot
.728 .32961 Mdot
.728 .32963 Mdot
.728 .32973 Mdot
.728 .33025 Mdot
.728 .3303 Mdot
.728 .33054 Mdot
.728 .33075 Mdot
.728 .33082 Mdot
.728 .33085 Mdot
.728 .33092 Mdot
.728 .33113 Mdot
.728 .33128 Mdot
.728 .33133 Mdot
.728 .33143 Mdot
.728 .33182 Mdot
.728 .33203 Mdot
.728 .33209 Mdot
.728 .3322 Mdot
.728 .33221 Mdot
.728 .33278 Mdot
.728 .33287 Mdot
.728 .33304 Mdot
.728 .33312 Mdot
.728 .33352 Mdot
.728 .33358 Mdot
.728 .33387 Mdot
.728 .33471 Mdot
.728 .3349 Mdot
.728 .33515 Mdot
.728 .33522 Mdot
.728 .33539 Mdot
.728 .33572 Mdot
.728 .33573 Mdot
.728 .33625 Mdot
.728 .33687 Mdot
.728 .33732 Mdot
.728 .33758 Mdot
.728 .33766 Mdot
.728 .3379 Mdot
.728 .33827 Mdot
.728 .33856 Mdot
.728 .33859 Mdot
.728 .33886 Mdot
.728 .33891 Mdot
.728 .33896 Mdot
.728 .33945 Mdot
.728 .33955 Mdot
.728 .33956 Mdot
.728 .33957 Mdot
.728 .33969 Mdot
.728 .33989 Mdot
.728 .33992 Mdot
.728 .34017 Mdot
.728 .3404 Mdot
.728 .34065 Mdot
.728 .34076 Mdot
.728 .341 Mdot
.728 .34163 Mdot
.728 .34175 Mdot
.728 .34189 Mdot
.728 .34271 Mdot
.728 .34277 Mdot
.728 .34281 Mdot
.728 .34288 Mdot
.728 .34311 Mdot
.728 .34427 Mdot
.728 .34439 Mdot
.728 .34463 Mdot
.728 .3448 Mdot
.728 .34486 Mdot
.728 .34495 Mdot
.728 .34504 Mdot
.728 .34519 Mdot
.728 .34524 Mdot
.728 .34554 Mdot
.728 .34561 Mdot
.728 .34589 Mdot
.728 .34597 Mdot
.728 .34609 Mdot
.728 .34704 Mdot
.728 .34707 Mdot
.728 .34729 Mdot
.728 .34739 Mdot
.728 .34749 Mdot
.728 .34778 Mdot
.728 .34802 Mdot
.728 .34803 Mdot
.728 .34846 Mdot
.728 .34856 Mdot
.728 .34861 Mdot
.728 .34864 Mdot
.728 .34874 Mdot
.728 .34881 Mdot
.728 .34883 Mdot
.728 .34888 Mdot
.728 .34906 Mdot
.728 .34916 Mdot
.728 .34919 Mdot
.728 .34924 Mdot
.728 .34925 Mdot
.728 .34952 Mdot
.728 .34956 Mdot
.728 .34968 Mdot
.728 .34976 Mdot
.728 .34987 Mdot
.728 .3499 Mdot
.728 .35043 Mdot
.728 .35052 Mdot
.728 .35064 Mdot
.728 .35067 Mdot
.728 .35075 Mdot
.728 .35091 Mdot
.728 .35145 Mdot
.728 .35166 Mdot
.728 .35178 Mdot
.728 .35182 Mdot
.728 .35211 Mdot
.728 .35239 Mdot
.728 .35244 Mdot
.728 .35267 Mdot
.728 .35272 Mdot
.728 .35278 Mdot
.728 .35287 Mdot
.728 .35289 Mdot
.728 .35311 Mdot
.728 .35323 Mdot
.728 .3537 Mdot
.728 .35375 Mdot
.728 .35382 Mdot
.728 .35423 Mdot
.728 .35425 Mdot
.728 .35439 Mdot
.728 .35511 Mdot
.728 .35519 Mdot
.728 .35522 Mdot
.728 .35526 Mdot
.728 .35537 Mdot
.728 .35554 Mdot
.728 .35557 Mdot
.728 .35574 Mdot
.728 .3558 Mdot
.728 .35625 Mdot
.728 .35626 Mdot
.728 .35641 Mdot
.728 .35671 Mdot
.728 .35671 Mdot
.728 .35692 Mdot
.728 .35696 Mdot
.728 .35705 Mdot
.728 .35708 Mdot
.728 .35709 Mdot
.728 .35711 Mdot
.728 .35725 Mdot
.728 .35726 Mdot
.728 .35729 Mdot
.728 .35729 Mdot
.728 .35758 Mdot
.728 .35759 Mdot
.728 .35784 Mdot
.728 .35789 Mdot
.728 .35807 Mdot
.728 .35832 Mdot
.728 .35842 Mdot
.728 .35848 Mdot
.728 .3585 Mdot
.728 .35864 Mdot
.728 .35877 Mdot
.728 .3589 Mdot
.728 .35893 Mdot
.728 .359 Mdot
.728 .35911 Mdot
.728 .35917 Mdot
.728 .35938 Mdot
.728 .35941 Mdot
.728 .35964 Mdot
.728 .35965 Mdot
.728 .35971 Mdot
.728 .36005 Mdot
.728 .3601 Mdot
.728 .36027 Mdot
.728 .36059 Mdot
.728 .3609 Mdot
.728 .36093 Mdot
.728 .36099 Mdot
.728 .361 Mdot
.728 .36106 Mdot
.728 .36108 Mdot
.728 .36122 Mdot
.728 .36134 Mdot
.728 .36136 Mdot
.728 .36157 Mdot
.728 .36162 Mdot
.728 .36164 Mdot
.728 .36165 Mdot
.728 .36178 Mdot
.728 .36184 Mdot
.728 .36197 Mdot
.728 .36208 Mdot
.728 .36219 Mdot
.728 .36238 Mdot
.728 .36241 Mdot
.728 .36279 Mdot
.728 .36283 Mdot
.728 .36299 Mdot
.728 .36314 Mdot
.728 .36334 Mdot
.728 .36348 Mdot
.728 .36349 Mdot
.728 .36367 Mdot
.728 .36369 Mdot
.728 .36377 Mdot
.728 .36414 Mdot
.728 .36469 Mdot
.728 .36494 Mdot
.728 .36501 Mdot
.728 .36548 Mdot
.728 .36559 Mdot
.728 .36562 Mdot
.728 .36588 Mdot
.728 .36589 Mdot
.728 .3661 Mdot
.728 .3664 Mdot
.728 .36642 Mdot
.728 .36645 Mdot
.728 .3666 Mdot
.728 .36661 Mdot
.728 .3668 Mdot
.728 .36685 Mdot
.728 .36691 Mdot
.728 .36746 Mdot
.728 .3675 Mdot
.728 .36773 Mdot
.728 .36778 Mdot
.728 .36794 Mdot
.728 .3681 Mdot
.728 .36814 Mdot
.728 .36822 Mdot
.728 .36829 Mdot
.728 .36838 Mdot
.728 .36856 Mdot
.728 .36857 Mdot
.728 .36861 Mdot
.728 .36868 Mdot
.728 .36886 Mdot
.728 .36898 Mdot
.728 .36901 Mdot
.728 .36918 Mdot
.728 .36939 Mdot
.728 .36942 Mdot
.728 .36951 Mdot
.728 .36953 Mdot
.728 .36956 Mdot
.728 .36962 Mdot
.728 .36965 Mdot
.728 .37011 Mdot
.728 .37042 Mdot
.728 .37046 Mdot
.728 .37057 Mdot
.728 .3706 Mdot
.728 .37082 Mdot
.728 .37089 Mdot
.728 .37138 Mdot
.728 .37148 Mdot
.728 .37149 Mdot
.728 .37178 Mdot
.728 .37182 Mdot
.728 .37186 Mdot
.728 .37218 Mdot
.728 .37226 Mdot
.728 .37242 Mdot
.728 .37243 Mdot
.728 .37249 Mdot
.728 .37253 Mdot
.728 .37257 Mdot
.728 .37273 Mdot
.728 .37276 Mdot
.728 .37295 Mdot
.728 .37315 Mdot
.728 .37318 Mdot
.728 .37326 Mdot
.728 .37341 Mdot
.728 .37378 Mdot
.728 .37389 Mdot
.728 .37394 Mdot
.728 .37396 Mdot
.728 .37404 Mdot
.728 .37411 Mdot
.728 .37447 Mdot
.728 .37449 Mdot
.728 .37456 Mdot
.728 .37462 Mdot
.728 .3747 Mdot
.728 .37473 Mdot
.728 .37491 Mdot
.728 .37492 Mdot
.728 .37495 Mdot
.728 .37497 Mdot
.728 .37504 Mdot
.728 .37517 Mdot
.728 .3752 Mdot
.728 .37522 Mdot
.728 .37527 Mdot
.728 .37533 Mdot
.728 .37536 Mdot
.728 .37539 Mdot
.728 .37546 Mdot
.728 .37575 Mdot
.728 .37576 Mdot
.728 .37593 Mdot
.728 .37613 Mdot
.728 .37619 Mdot
.728 .37626 Mdot
.728 .37641 Mdot
.728 .37643 Mdot
.728 .37709 Mdot
.728 .37717 Mdot
.728 .37722 Mdot
.728 .37741 Mdot
.728 .37746 Mdot
.728 .37767 Mdot
.728 .3777 Mdot
.728 .3778 Mdot
.728 .37787 Mdot
.728 .37793 Mdot
.728 .37797 Mdot
.728 .37809 Mdot
.728 .37825 Mdot
.728 .37834 Mdot
.728 .37913 Mdot
.728 .37929 Mdot
.728 .37934 Mdot
.728 .37936 Mdot
.728 .37941 Mdot
.728 .37997 Mdot
.728 .38006 Mdot
.728 .38015 Mdot
.728 .38058 Mdot
.728 .38074 Mdot
.728 .38082 Mdot
.728 .381 Mdot
.728 .38115 Mdot
.728 .38132 Mdot
.728 .38134 Mdot
.728 .38148 Mdot
.728 .38156 Mdot
.728 .38157 Mdot
.728 .38158 Mdot
.728 .38165 Mdot
.728 .38198 Mdot
.728 .38202 Mdot
.728 .38205 Mdot
.728 .38224 Mdot
.728 .38226 Mdot
.728 .38246 Mdot
.728 .38271 Mdot
.728 .38287 Mdot
.728 .38293 Mdot
.728 .38311 Mdot
.728 .38342 Mdot
.728 .38384 Mdot
.728 .3842 Mdot
.728 .38421 Mdot
.728 .38444 Mdot
.728 .38455 Mdot
.728 .3846 Mdot
.728 .38477 Mdot
.728 .3849 Mdot
.728 .38548 Mdot
.728 .38568 Mdot
.728 .38572 Mdot
.728 .38587 Mdot
.728 .38599 Mdot
.728 .38605 Mdot
.728 .38616 Mdot
.728 .38623 Mdot
.728 .38662 Mdot
.728 .38663 Mdot
.728 .3867 Mdot
.728 .38674 Mdot
.728 .38689 Mdot
.728 .38715 Mdot
.728 .38722 Mdot
.728 .38725 Mdot
.728 .38736 Mdot
.728 .3875 Mdot
.728 .38756 Mdot
.728 .38757 Mdot
.728 .38762 Mdot
.728 .38776 Mdot
.728 .38793 Mdot
.728 .38796 Mdot
.728 .38832 Mdot
.728 .38839 Mdot
.728 .3884 Mdot
.728 .38877 Mdot
.728 .38918 Mdot
.728 .38922 Mdot
.728 .38932 Mdot
.728 .38947 Mdot
.728 .38979 Mdot
.728 .38983 Mdot
.728 .39026 Mdot
.728 .39054 Mdot
.728 .39092 Mdot
.728 .3911 Mdot
.728 .39122 Mdot
.728 .3914 Mdot
.728 .39149 Mdot
.728 .39152 Mdot
.728 .3918 Mdot
.728 .39192 Mdot
.728 .39202 Mdot
.728 .39245 Mdot
.728 .39253 Mdot
.728 .39258 Mdot
.728 .3926 Mdot
.728 .39274 Mdot
.728 .39288 Mdot
.728 .39302 Mdot
.728 .3931 Mdot
.728 .3932 Mdot
.728 .39335 Mdot
.728 .39369 Mdot
.728 .39387 Mdot
.728 .39415 Mdot
.728 .39481 Mdot
.728 .39528 Mdot
.728 .39556 Mdot
.728 .39564 Mdot
.728 .39589 Mdot
.728 .39599 Mdot
.728 .39605 Mdot
.728 .39615 Mdot
.728 .39624 Mdot
.728 .39687 Mdot
.728 .39688 Mdot
.728 .39698 Mdot
.728 .39733 Mdot
.728 .39753 Mdot
.728 .39753 Mdot
.728 .3976 Mdot
.728 .39767 Mdot
.728 .39768 Mdot
.728 .39771 Mdot
.728 .39784 Mdot
.728 .39811 Mdot
.728 .39818 Mdot
.728 .39859 Mdot
.728 .39863 Mdot
.728 .39898 Mdot
.728 .39913 Mdot
.728 .39948 Mdot
.728 .39951 Mdot
.728 .39983 Mdot
.728 .40012 Mdot
.728 .4002 Mdot
.728 .40025 Mdot
.728 .40051 Mdot
.728 .40054 Mdot
.728 .40058 Mdot
.728 .40071 Mdot
.728 .40073 Mdot
.728 .40074 Mdot
.728 .40089 Mdot
.728 .40108 Mdot
.728 .4016 Mdot
.728 .40168 Mdot
.728 .40174 Mdot
.728 .402 Mdot
.728 .40214 Mdot
.728 .40219 Mdot
.728 .40238 Mdot
.728 .40248 Mdot
.728 .40261 Mdot
.728 .40261 Mdot
.728 .40268 Mdot
.728 .40291 Mdot
.728 .40298 Mdot
.728 .40314 Mdot
.728 .40335 Mdot
.728 .40349 Mdot
.728 .40361 Mdot
.728 .4037 Mdot
.728 .40399 Mdot
.728 .40399 Mdot
.728 .40426 Mdot
.728 .40464 Mdot
.728 .40473 Mdot
.728 .40504 Mdot
.728 .40534 Mdot
.728 .40554 Mdot
.728 .40584 Mdot
.728 .40599 Mdot
.728 .40631 Mdot
.728 .40632 Mdot
.728 .40647 Mdot
.728 .40676 Mdot
.728 .4068 Mdot
.728 .40705 Mdot
.728 .40715 Mdot
.728 .40751 Mdot
.728 .40753 Mdot
.728 .40779 Mdot
.728 .40783 Mdot
.728 .40801 Mdot
.728 .40816 Mdot
.728 .40901 Mdot
.728 .40943 Mdot
.728 .40944 Mdot
.728 .40952 Mdot
.728 .40972 Mdot
.728 .40995 Mdot
.728 .4101 Mdot
.728 .41014 Mdot
.728 .41022 Mdot
.728 .41046 Mdot
.728 .4106 Mdot
.728 .41142 Mdot
.728 .41144 Mdot
.728 .4116 Mdot
.728 .4116 Mdot
.728 .4117 Mdot
.728 .4118 Mdot
.728 .412 Mdot
.728 .41223 Mdot
.728 .41256 Mdot
.728 .4127 Mdot
.728 .41271 Mdot
.728 .41278 Mdot
.728 .41286 Mdot
.728 .413 Mdot
.728 .41317 Mdot
.728 .4133 Mdot
.728 .41341 Mdot
.728 .41345 Mdot
.728 .41356 Mdot
.728 .41379 Mdot
.728 .41386 Mdot
.728 .41393 Mdot
.728 .41422 Mdot
.728 .41428 Mdot
.728 .41474 Mdot
.728 .41505 Mdot
.728 .41518 Mdot
.728 .41522 Mdot
.728 .41598 Mdot
.728 .41636 Mdot
.728 .41643 Mdot
.728 .41672 Mdot
.728 .41687 Mdot
.728 .41695 Mdot
.728 .41717 Mdot
.728 .41737 Mdot
.728 .41746 Mdot
.728 .41815 Mdot
.728 .41824 Mdot
.728 .41835 Mdot
.728 .41848 Mdot
.728 .41908 Mdot
.728 .41915 Mdot
.728 .41924 Mdot
.728 .41938 Mdot
.728 .41975 Mdot
.728 .41988 Mdot
.728 .42011 Mdot
.728 .42018 Mdot
.728 .42041 Mdot
.728 .42055 Mdot
.728 .4207 Mdot
.728 .42093 Mdot
.728 .42105 Mdot
.728 .42119 Mdot
.728 .42136 Mdot
.728 .42153 Mdot
.728 .42156 Mdot
.728 .42167 Mdot
.728 .4217 Mdot
.728 .42176 Mdot
.728 .42181 Mdot
.728 .42199 Mdot
.728 .42242 Mdot
.728 .42266 Mdot
.728 .42269 Mdot
.728 .42288 Mdot
.728 .42318 Mdot
.728 .4236 Mdot
.728 .42379 Mdot
.728 .42382 Mdot
.728 .42395 Mdot
.728 .42403 Mdot
.728 .42403 Mdot
.728 .42407 Mdot
.728 .4241 Mdot
.728 .42436 Mdot
.728 .4244 Mdot
.728 .42441 Mdot
.728 .42471 Mdot
.728 .42499 Mdot
.728 .42516 Mdot
.728 .42538 Mdot
.728 .42569 Mdot
.728 .42614 Mdot
.728 .42643 Mdot
.728 .42643 Mdot
.728 .4268 Mdot
.728 .42695 Mdot
.728 .42713 Mdot
.728 .42722 Mdot
.728 .4274 Mdot
.728 .42753 Mdot
.728 .42802 Mdot
.728 .42844 Mdot
.728 .42861 Mdot
.728 .42863 Mdot
.728 .4288 Mdot
.728 .42951 Mdot
.728 .42978 Mdot
.728 .43039 Mdot
.728 .43056 Mdot
.728 .43109 Mdot
.728 .4313 Mdot
.728 .43131 Mdot
.728 .43142 Mdot
.728 .43162 Mdot
.728 .43163 Mdot
.728 .43183 Mdot
.728 .43202 Mdot
.728 .43209 Mdot
.728 .43265 Mdot
.728 .4327 Mdot
.728 .43315 Mdot
.728 .43319 Mdot
.728 .4334 Mdot
.728 .43347 Mdot
.728 .43368 Mdot
.728 .43413 Mdot
.728 .4342 Mdot
.728 .43429 Mdot
.728 .43456 Mdot
.728 .43457 Mdot
.728 .43471 Mdot
.728 .43485 Mdot
.728 .43487 Mdot
.728 .43491 Mdot
.728 .43493 Mdot
.728 .43522 Mdot
.728 .43523 Mdot
.728 .43525 Mdot
.728 .4358 Mdot
.728 .43591 Mdot
.728 .43595 Mdot
.728 .43625 Mdot
.728 .4368 Mdot
.728 .43687 Mdot
.728 .43689 Mdot
.728 .43729 Mdot
.728 .43762 Mdot
.728 .43792 Mdot
.728 .43796 Mdot
.728 .43816 Mdot
.728 .43859 Mdot
.728 .43869 Mdot
.728 .43876 Mdot
.728 .43877 Mdot
.728 .43944 Mdot
.728 .43959 Mdot
.728 .44006 Mdot
.728 .44015 Mdot
.728 .44016 Mdot
.728 .44023 Mdot
.728 .44032 Mdot
.728 .44077 Mdot
.728 .44088 Mdot
.728 .44093 Mdot
.728 .44096 Mdot
.728 .44103 Mdot
.728 .44123 Mdot
.728 .44129 Mdot
.728 .44134 Mdot
.728 .44137 Mdot
.728 .44153 Mdot
.728 .44168 Mdot
.728 .44197 Mdot
.728 .44209 Mdot
.728 .44231 Mdot
.728 .44245 Mdot
.728 .44294 Mdot
.728 .44308 Mdot
.728 .44309 Mdot
.728 .44318 Mdot
.728 .44335 Mdot
.728 .44336 Mdot
.728 .4435 Mdot
.728 .44357 Mdot
.728 .44398 Mdot
.728 .44404 Mdot
.728 .44407 Mdot
.73 .24731 Mdot
.73 .24731 Mdot
.73 .24741 Mdot
.73 .24753 Mdot
.73 .24783 Mdot
.73 .24816 Mdot
.73 .24838 Mdot
.73 .24857 Mdot
.73 .24859 Mdot
.73 .24865 Mdot
.73 .24896 Mdot
.73 .24916 Mdot
.73 .25048 Mdot
.73 .25097 Mdot
.73 .25208 Mdot
.73 .25211 Mdot
.73 .25262 Mdot
.73 .25309 Mdot
.73 .25311 Mdot
.73 .25348 Mdot
.73 .25417 Mdot
.73 .25425 Mdot
.73 .25439 Mdot
.73 .25487 Mdot
.73 .25513 Mdot
.73 .25528 Mdot
.73 .25553 Mdot
.73 .25608 Mdot
.73 .2567 Mdot
.73 .25672 Mdot
.73 .25677 Mdot
.73 .25684 Mdot
.73 .25721 Mdot
.73 .25737 Mdot
.73 .25745 Mdot
.73 .25773 Mdot
.73 .25784 Mdot
.73 .2581 Mdot
.73 .25818 Mdot
.73 .25859 Mdot
.73 .25915 Mdot
.73 .25924 Mdot
.73 .26041 Mdot
.73 .26066 Mdot
.73 .2607 Mdot
.73 .26081 Mdot
.73 .26104 Mdot
.73 .26125 Mdot
.73 .26145 Mdot
.73 .2615 Mdot
.73 .26263 Mdot
.73 .26269 Mdot
.73 .26274 Mdot
.73 .26293 Mdot
.73 .2635 Mdot
.73 .26397 Mdot
.73 .26401 Mdot
.73 .26506 Mdot
.73 .26521 Mdot
.73 .26526 Mdot
.73 .2657 Mdot
.73 .26648 Mdot
.73 .2665 Mdot
.73 .26654 Mdot
.73 .26659 Mdot
.73 .26718 Mdot
.73 .26746 Mdot
.73 .26753 Mdot
.73 .26777 Mdot
.73 .26785 Mdot
.73 .26812 Mdot
.73 .26827 Mdot
.73 .26853 Mdot
.73 .26873 Mdot
.73 .26889 Mdot
.73 .26952 Mdot
.73 .26954 Mdot
.73 .26962 Mdot
.73 .26988 Mdot
.73 .26997 Mdot
.73 .27026 Mdot
.73 .27056 Mdot
.73 .2706 Mdot
.73 .27076 Mdot
.73 .27119 Mdot
.73 .27162 Mdot
.73 .27191 Mdot
.73 .27199 Mdot
.73 .27211 Mdot
.73 .27213 Mdot
.73 .27214 Mdot
.73 .27226 Mdot
.73 .27249 Mdot
.73 .2726 Mdot
.73 .27267 Mdot
.73 .27273 Mdot
.73 .27309 Mdot
.73 .27312 Mdot
.73 .27317 Mdot
.73 .27346 Mdot
.73 .2735 Mdot
.73 .27405 Mdot
.73 .27405 Mdot
.73 .27452 Mdot
.73 .27471 Mdot
.73 .27481 Mdot
.73 .27484 Mdot
.73 .27499 Mdot
.73 .27506 Mdot
.73 .27574 Mdot
.73 .27618 Mdot
.73 .27618 Mdot
.73 .27619 Mdot
.73 .27646 Mdot
.73 .27744 Mdot
.73 .27746 Mdot
.73 .27747 Mdot
.73 .2778 Mdot
.73 .27801 Mdot
.73 .27823 Mdot
.73 .27833 Mdot
.73 .27869 Mdot
.73 .2789 Mdot
.73 .27913 Mdot
.73 .28017 Mdot
.73 .28041 Mdot
.73 .28042 Mdot
.73 .28053 Mdot
.73 .2807 Mdot
.73 .2807 Mdot
.73 .28112 Mdot
.73 .28159 Mdot
.73 .28178 Mdot
.73 .28198 Mdot
.73 .28217 Mdot
.73 .28249 Mdot
.73 .28279 Mdot
.73 .2833 Mdot
.73 .28354 Mdot
.73 .28433 Mdot
.73 .28486 Mdot
.73 .28487 Mdot
.73 .28494 Mdot
.73 .285 Mdot
.73 .28531 Mdot
.73 .28539 Mdot
.73 .28555 Mdot
.73 .28558 Mdot
.73 .28585 Mdot
.73 .28589 Mdot
.73 .28591 Mdot
.73 .286 Mdot
.73 .28631 Mdot
.73 .28648 Mdot
.73 .28677 Mdot
.73 .28684 Mdot
.73 .28706 Mdot
.73 .28723 Mdot
.73 .28777 Mdot
.73 .28884 Mdot
.73 .28911 Mdot
.73 .28917 Mdot
.73 .28962 Mdot
.73 .29007 Mdot
.73 .2907 Mdot
.73 .29104 Mdot
.73 .29114 Mdot
.73 .29117 Mdot
.73 .29139 Mdot
.73 .2916 Mdot
.73 .29173 Mdot
.73 .29186 Mdot
.73 .29206 Mdot
.73 .29342 Mdot
.73 .29402 Mdot
.73 .29475 Mdot
.73 .29513 Mdot
.73 .29518 Mdot
.73 .29553 Mdot
.73 .29554 Mdot
.73 .29601 Mdot
.73 .29614 Mdot
.73 .29635 Mdot
.73 .29666 Mdot
.73 .29669 Mdot
.73 .29677 Mdot
.73 .29678 Mdot
.73 .29692 Mdot
.73 .29693 Mdot
.73 .29714 Mdot
.73 .29739 Mdot
.73 .29779 Mdot
.73 .29787 Mdot
.73 .29798 Mdot
.73 .29803 Mdot
.73 .2981 Mdot
.73 .29868 Mdot
.73 .29875 Mdot
.73 .29878 Mdot
.73 .29892 Mdot
.73 .29909 Mdot
.73 .29926 Mdot
.73 .29963 Mdot
.73 .29985 Mdot
.73 .29992 Mdot
.73 .30005 Mdot
.73 .3002 Mdot
.73 .30023 Mdot
.73 .30036 Mdot
.73 .30128 Mdot
.73 .30135 Mdot
.73 .30186 Mdot
.73 .30244 Mdot
.73 .30302 Mdot
.73 .30314 Mdot
.73 .30354 Mdot
.73 .30408 Mdot
.73 .30439 Mdot
.73 .30462 Mdot
.73 .30474 Mdot
.73 .30479 Mdot
.73 .30521 Mdot
.73 .30527 Mdot
.73 .30557 Mdot
.73 .30583 Mdot
.73 .30594 Mdot
.73 .30614 Mdot
.73 .30636 Mdot
.73 .30642 Mdot
.73 .30679 Mdot
.73 .30696 Mdot
.73 .30719 Mdot
.73 .30743 Mdot
.73 .30745 Mdot
.73 .30796 Mdot
.73 .3082 Mdot
.73 .30908 Mdot
.73 .30909 Mdot
.73 .30944 Mdot
.73 .30958 Mdot
.73 .30964 Mdot
.73 .30968 Mdot
.73 .30971 Mdot
.73 .31011 Mdot
.73 .31021 Mdot
.73 .31034 Mdot
.73 .31049 Mdot
.73 .31058 Mdot
.73 .31242 Mdot
.73 .31293 Mdot
.73 .31338 Mdot
.73 .31412 Mdot
.73 .31415 Mdot
.73 .31436 Mdot
.73 .31443 Mdot
.73 .31447 Mdot
.73 .31481 Mdot
.73 .31527 Mdot
.73 .31597 Mdot
.73 .31599 Mdot
.73 .31605 Mdot
.73 .31615 Mdot
.73 .31635 Mdot
.73 .3169 Mdot
.73 .31693 Mdot
.73 .31704 Mdot
.73 .31731 Mdot
.73 .31755 Mdot
.73 .31813 Mdot
.73 .31834 Mdot
.73 .31871 Mdot
.73 .31872 Mdot
.73 .31873 Mdot
.73 .31875 Mdot
.73 .31931 Mdot
.73 .31967 Mdot
.73 .31984 Mdot
.73 .32014 Mdot
.73 .32018 Mdot
.73 .32034 Mdot
.73 .32092 Mdot
.73 .32112 Mdot
.73 .32125 Mdot
.73 .32135 Mdot
.73 .32135 Mdot
.73 .32157 Mdot
.73 .32164 Mdot
.73 .32181 Mdot
.73 .32182 Mdot
.73 .32185 Mdot
.73 .32198 Mdot
.73 .32226 Mdot
.73 .32257 Mdot
.73 .32326 Mdot
.73 .32326 Mdot
.73 .32402 Mdot
.73 .32412 Mdot
.73 .32443 Mdot
.73 .32453 Mdot
.73 .32513 Mdot
.73 .32524 Mdot
.73 .32524 Mdot
.73 .3253 Mdot
.73 .32537 Mdot
.73 .32557 Mdot
.73 .32579 Mdot
.73 .32588 Mdot
.73 .32607 Mdot
.73 .32621 Mdot
.73 .32636 Mdot
.73 .3266 Mdot
.73 .32671 Mdot
.73 .32708 Mdot
.73 .32733 Mdot
.73 .32736 Mdot
.73 .32739 Mdot
.73 .32758 Mdot
.73 .32765 Mdot
.73 .32781 Mdot
.73 .32782 Mdot
.73 .32786 Mdot
.73 .32809 Mdot
.73 .32844 Mdot
.73 .3292 Mdot
.73 .32935 Mdot
.73 .32956 Mdot
.73 .33007 Mdot
.73 .33027 Mdot
.73 .33039 Mdot
.73 .33049 Mdot
.73 .33061 Mdot
.73 .33071 Mdot
.73 .33134 Mdot
.73 .33197 Mdot
.73 .33215 Mdot
.73 .33233 Mdot
.73 .33272 Mdot
.73 .33287 Mdot
.73 .33288 Mdot
.73 .33292 Mdot
.73 .33298 Mdot
.73 .33299 Mdot
.73 .33321 Mdot
.73 .33343 Mdot
.73 .33386 Mdot
.73 .33392 Mdot
.73 .33426 Mdot
.73 .33436 Mdot
.73 .3346 Mdot
.73 .33503 Mdot
.73 .3353 Mdot
.73 .33558 Mdot
.73 .3359 Mdot
.73 .33635 Mdot
.73 .33649 Mdot
.73 .33665 Mdot
.73 .33668 Mdot
.73 .33687 Mdot
.73 .33704 Mdot
.73 .33716 Mdot
.73 .33731 Mdot
.73 .33744 Mdot
.73 .3377 Mdot
.73 .33792 Mdot
.73 .33792 Mdot
.73 .33817 Mdot
.73 .33892 Mdot
.73 .33895 Mdot
.73 .33917 Mdot
.73 .33928 Mdot
.73 .33935 Mdot
.73 .33939 Mdot
.73 .34106 Mdot
.73 .3412 Mdot
.73 .34122 Mdot
.73 .34201 Mdot
.73 .3421 Mdot
.73 .34236 Mdot
.73 .34237 Mdot
.73 .34242 Mdot
.73 .34255 Mdot
.73 .34266 Mdot
.73 .34303 Mdot
.73 .34323 Mdot
.73 .34349 Mdot
.73 .34374 Mdot
.73 .34388 Mdot
.73 .34389 Mdot
.73 .34397 Mdot
.73 .34424 Mdot
.73 .34444 Mdot
.73 .34445 Mdot
.73 .34466 Mdot
.73 .34467 Mdot
.73 .34474 Mdot
.73 .34502 Mdot
.73 .3457 Mdot
.73 .34574 Mdot
.73 .34627 Mdot
.73 .34633 Mdot
.73 .34643 Mdot
.73 .34653 Mdot
.73 .34657 Mdot
.73 .34696 Mdot
.73 .34737 Mdot
.73 .34748 Mdot
.73 .3475 Mdot
.73 .34761 Mdot
.73 .34813 Mdot
.73 .3483 Mdot
.73 .34854 Mdot
.73 .34869 Mdot
.73 .34873 Mdot
.73 .3496 Mdot
.73 .34985 Mdot
.73 .3499 Mdot
.73 .34991 Mdot
.73 .35001 Mdot
.73 .35011 Mdot
.73 .35031 Mdot
.73 .35034 Mdot
.73 .35055 Mdot
.73 .35099 Mdot
.73 .35148 Mdot
.73 .35164 Mdot
.73 .35173 Mdot
.73 .35181 Mdot
.73 .352 Mdot
.73 .35211 Mdot
.73 .35222 Mdot
.73 .35233 Mdot
.73 .35269 Mdot
.73 .3527 Mdot
.73 .35376 Mdot
.73 .35377 Mdot
.73 .3543 Mdot
.73 .35431 Mdot
.73 .35439 Mdot
.73 .35444 Mdot
.73 .35462 Mdot
.73 .35471 Mdot
.73 .35483 Mdot
.73 .35495 Mdot
.73 .35501 Mdot
.73 .35502 Mdot
.73 .35506 Mdot
.73 .35519 Mdot
.73 .35528 Mdot
.73 .35528 Mdot
.73 .35538 Mdot
.73 .35555 Mdot
.73 .35587 Mdot
.73 .35614 Mdot
.73 .35617 Mdot
.73 .35621 Mdot
.73 .35626 Mdot
.73 .35628 Mdot
.73 .35671 Mdot
.73 .35701 Mdot
.73 .35709 Mdot
.73 .3572 Mdot
.73 .35727 Mdot
.73 .35729 Mdot
.73 .3577 Mdot
.73 .35781 Mdot
.73 .35784 Mdot
.73 .35784 Mdot
.73 .35803 Mdot
.73 .35805 Mdot
.73 .35865 Mdot
.73 .35882 Mdot
.73 .35888 Mdot
.73 .35893 Mdot
.73 .35915 Mdot
.73 .35915 Mdot
.73 .35965 Mdot
.73 .35965 Mdot
.73 .35995 Mdot
.73 .3601 Mdot
.73 .36021 Mdot
.73 .36024 Mdot
.73 .36032 Mdot
.73 .36036 Mdot
.73 .36036 Mdot
.73 .36041 Mdot
.73 .36083 Mdot
.73 .36126 Mdot
.73 .36131 Mdot
.73 .3615 Mdot
.73 .36156 Mdot
.73 .36157 Mdot
.73 .36165 Mdot
.73 .36205 Mdot
.73 .36218 Mdot
.73 .36241 Mdot
.73 .36273 Mdot
.73 .36275 Mdot
.73 .36275 Mdot
.73 .36277 Mdot
.73 .36297 Mdot
.73 .36328 Mdot
.73 .36331 Mdot
.73 .36335 Mdot
.73 .3636 Mdot
.73 .36371 Mdot
.73 .36386 Mdot
.73 .36397 Mdot
.73 .36415 Mdot
.73 .36432 Mdot
.73 .36439 Mdot
.73 .36444 Mdot
.73 .36464 Mdot
.73 .36518 Mdot
.73 .36534 Mdot
.73 .36546 Mdot
.73 .36554 Mdot
.73 .36564 Mdot
.73 .36571 Mdot
.73 .36588 Mdot
.73 .36593 Mdot
.73 .36615 Mdot
.73 .3663 Mdot
.73 .36631 Mdot
.73 .36653 Mdot
.73 .36669 Mdot
.73 .36705 Mdot
.73 .36711 Mdot
.73 .36711 Mdot
.73 .36716 Mdot
.73 .36761 Mdot
.73 .3679 Mdot
.73 .36793 Mdot
.73 .36793 Mdot
.73 .36796 Mdot
.73 .36802 Mdot
.73 .36804 Mdot
.73 .36812 Mdot
.73 .36822 Mdot
.73 .36842 Mdot
.73 .36876 Mdot
.73 .36876 Mdot
.73 .36895 Mdot
.73 .36899 Mdot
.73 .3691 Mdot
.73 .36952 Mdot
.73 .36953 Mdot
.73 .36966 Mdot
.73 .36966 Mdot
.73 .36968 Mdot
.73 .36976 Mdot
.73 .37004 Mdot
.73 .37005 Mdot
.73 .3701 Mdot
.73 .37018 Mdot
.73 .37073 Mdot
.73 .37078 Mdot
.73 .37134 Mdot
.73 .37141 Mdot
.73 .37141 Mdot
.73 .37148 Mdot
.73 .37159 Mdot
.73 .3716 Mdot
.73 .37164 Mdot
.73 .37172 Mdot
.73 .37181 Mdot
.73 .37202 Mdot
.73 .37245 Mdot
.73 .37246 Mdot
.73 .37318 Mdot
.73 .37319 Mdot
.73 .37343 Mdot
.73 .37351 Mdot
.73 .37358 Mdot
.73 .37366 Mdot
.73 .37379 Mdot
.73 .37385 Mdot
.73 .37391 Mdot
.73 .37402 Mdot
.73 .37435 Mdot
.73 .37466 Mdot
.73 .3748 Mdot
.73 .37482 Mdot
.73 .37495 Mdot
.73 .37502 Mdot
.73 .37509 Mdot
.73 .3751 Mdot
.73 .37513 Mdot
.73 .37531 Mdot
.73 .3759 Mdot
.73 .37593 Mdot
.73 .37603 Mdot
.73 .3762 Mdot
.73 .37631 Mdot
.73 .37667 Mdot
.73 .37674 Mdot
.73 .37676 Mdot
.73 .37683 Mdot
.73 .37711 Mdot
.73 .37738 Mdot
.73 .37741 Mdot
.73 .37748 Mdot
.73 .37754 Mdot
.73 .37759 Mdot
.73 .37795 Mdot
.73 .37798 Mdot
.73 .37844 Mdot
.73 .37863 Mdot
.73 .37868 Mdot
.73 .37869 Mdot
.73 .37883 Mdot
.73 .37884 Mdot
.73 .37897 Mdot
.73 .37916 Mdot
.73 .37921 Mdot
.73 .37922 Mdot
.73 .37932 Mdot
.73 .37949 Mdot
.73 .37967 Mdot
.73 .3798 Mdot
.73 .38006 Mdot
.73 .38013 Mdot
.73 .38022 Mdot
.73 .38026 Mdot
.73 .38027 Mdot
.73 .38044 Mdot
.73 .3805 Mdot
.73 .38105 Mdot
.73 .38106 Mdot
.73 .38116 Mdot
.73 .3823 Mdot
.73 .38233 Mdot
.73 .38237 Mdot
.73 .38245 Mdot
.73 .3826 Mdot
.73 .38262 Mdot
.73 .38314 Mdot
.73 .3833 Mdot
.73 .38331 Mdot
.73 .38346 Mdot
.73 .38363 Mdot
.73 .38372 Mdot
.73 .38382 Mdot
.73 .38391 Mdot
.73 .38402 Mdot
.73 .38416 Mdot
.73 .38417 Mdot
.73 .38429 Mdot
.73 .38438 Mdot
.73 .38469 Mdot
.73 .38491 Mdot
.73 .3851 Mdot
.73 .38528 Mdot
.73 .38558 Mdot
.73 .38574 Mdot
.73 .38581 Mdot
.73 .38604 Mdot
.73 .38609 Mdot
.73 .38638 Mdot
.73 .38653 Mdot
.73 .38668 Mdot
.73 .38669 Mdot
.73 .38673 Mdot
.73 .38676 Mdot
.73 .38677 Mdot
.73 .38687 Mdot
.73 .38713 Mdot
.73 .38726 Mdot
.73 .38738 Mdot
.73 .38781 Mdot
.73 .38825 Mdot
.73 .38831 Mdot
.73 .38839 Mdot
.73 .38846 Mdot
.73 .38854 Mdot
.73 .38868 Mdot
.73 .38903 Mdot
.73 .38918 Mdot
.73 .38928 Mdot
.73 .3898 Mdot
.73 .39004 Mdot
.73 .39019 Mdot
.73 .39022 Mdot
.73 .39023 Mdot
.73 .39034 Mdot
.73 .39039 Mdot
.73 .39051 Mdot
.73 .39053 Mdot
.73 .39056 Mdot
.73 .39073 Mdot
.73 .39098 Mdot
.73 .39106 Mdot
.73 .39122 Mdot
.73 .39132 Mdot
.73 .39142 Mdot
.73 .39155 Mdot
.73 .39161 Mdot
.73 .39176 Mdot
.73 .3919 Mdot
.73 .39195 Mdot
.73 .39199 Mdot
.73 .39199 Mdot
.73 .39207 Mdot
.73 .39248 Mdot
.73 .39254 Mdot
.73 .39276 Mdot
.73 .39283 Mdot
.73 .39335 Mdot
.73 .39335 Mdot
.73 .39382 Mdot
.73 .39403 Mdot
.73 .39422 Mdot
.73 .39431 Mdot
.73 .39433 Mdot
.73 .39434 Mdot
.73 .39446 Mdot
.73 .3945 Mdot
.73 .39465 Mdot
.73 .39466 Mdot
.73 .39472 Mdot
.73 .39481 Mdot
.73 .39495 Mdot
.73 .39535 Mdot
.73 .39546 Mdot
.73 .39548 Mdot
.73 .39569 Mdot
.73 .39581 Mdot
.73 .39605 Mdot
.73 .39643 Mdot
.73 .39645 Mdot
.73 .39646 Mdot
.73 .39647 Mdot
.73 .39672 Mdot
.73 .39686 Mdot
.73 .39726 Mdot
.73 .39742 Mdot
.73 .39761 Mdot
.73 .39768 Mdot
.73 .3977 Mdot
.73 .39808 Mdot
.73 .39821 Mdot
.73 .39829 Mdot
.73 .39832 Mdot
.73 .39834 Mdot
.73 .39882 Mdot
.73 .39913 Mdot
.73 .39937 Mdot
.73 .39939 Mdot
.73 .39944 Mdot
.73 .39959 Mdot
.73 .3996 Mdot
.73 .40011 Mdot
.73 .40042 Mdot
.73 .40077 Mdot
.73 .40203 Mdot
.73 .4021 Mdot
.73 .4022 Mdot
.73 .40228 Mdot
.73 .40235 Mdot
.73 .40262 Mdot
.73 .40265 Mdot
.73 .40268 Mdot
.73 .40272 Mdot
.73 .40281 Mdot
.73 .40305 Mdot
.73 .40306 Mdot
.73 .40366 Mdot
.73 .40382 Mdot
.73 .40418 Mdot
.73 .40419 Mdot
.73 .40435 Mdot
.73 .40451 Mdot
.73 .40463 Mdot
.73 .40488 Mdot
.73 .40492 Mdot
.73 .40507 Mdot
.73 .40521 Mdot
.73 .40529 Mdot
.73 .40546 Mdot
.73 .40566 Mdot
.73 .40571 Mdot
.73 .40599 Mdot
.73 .40603 Mdot
.73 .40611 Mdot
.73 .40627 Mdot
.73 .40648 Mdot
.73 .40686 Mdot
.73 .40712 Mdot
.73 .40721 Mdot
.73 .4076 Mdot
.73 .408 Mdot
.73 .40835 Mdot
.73 .4084 Mdot
.73 .40903 Mdot
.73 .40912 Mdot
.73 .40914 Mdot
.73 .40924 Mdot
.73 .40933 Mdot
.73 .40938 Mdot
.73 .40953 Mdot
.73 .40978 Mdot
.73 .4099 Mdot
.73 .41002 Mdot
.73 .41012 Mdot
.73 .41013 Mdot
.73 .41018 Mdot
.73 .41058 Mdot
.73 .41063 Mdot
.73 .41066 Mdot
.73 .41074 Mdot
.73 .41079 Mdot
.73 .41106 Mdot
.73 .41124 Mdot
.73 .41138 Mdot
.73 .41139 Mdot
.73 .41148 Mdot
.73 .41149 Mdot
.73 .41154 Mdot
.73 .41156 Mdot
.73 .41178 Mdot
.73 .41192 Mdot
.73 .41201 Mdot
.73 .41233 Mdot
.73 .41234 Mdot
.73 .41258 Mdot
.73 .41261 Mdot
.73 .41287 Mdot
.73 .41338 Mdot
.73 .41379 Mdot
.73 .41472 Mdot
.73 .41486 Mdot
.73 .41494 Mdot
.73 .41503 Mdot
.73 .41518 Mdot
.73 .41533 Mdot
.73 .41535 Mdot
.73 .41542 Mdot
.73 .41565 Mdot
.73 .41608 Mdot
.73 .41639 Mdot
.73 .4167 Mdot
.73 .41674 Mdot
.73 .41692 Mdot
.73 .41765 Mdot
.73 .41803 Mdot
.73 .41814 Mdot
.73 .41829 Mdot
.73 .41834 Mdot
.73 .41854 Mdot
.73 .41866 Mdot
.73 .41887 Mdot
.73 .41893 Mdot
.73 .41894 Mdot
.73 .41897 Mdot
.73 .41915 Mdot
.73 .41918 Mdot
.73 .41928 Mdot
.73 .41934 Mdot
.73 .41955 Mdot
.73 .41959 Mdot
.73 .41964 Mdot
.73 .41965 Mdot
.73 .42001 Mdot
.73 .42055 Mdot
.73 .42071 Mdot
.73 .42106 Mdot
.73 .42127 Mdot
.73 .42149 Mdot
.73 .42162 Mdot
.73 .42176 Mdot
.73 .42189 Mdot
.73 .42221 Mdot
.73 .4225 Mdot
.73 .4225 Mdot
.73 .42261 Mdot
.73 .42269 Mdot
.73 .4227 Mdot
.73 .42286 Mdot
.73 .42357 Mdot
.73 .42373 Mdot
.73 .42388 Mdot
.73 .42412 Mdot
.73 .42419 Mdot
.73 .42434 Mdot
.73 .42448 Mdot
.73 .42471 Mdot
.73 .42471 Mdot
.73 .4254 Mdot
.73 .42559 Mdot
.73 .42559 Mdot
.73 .42559 Mdot
.73 .4259 Mdot
.73 .42636 Mdot
.73 .42641 Mdot
.73 .42651 Mdot
.73 .42653 Mdot
.73 .4266 Mdot
.73 .42673 Mdot
.73 .42675 Mdot
.73 .42705 Mdot
.73 .42705 Mdot
.73 .42743 Mdot
.73 .42746 Mdot
.73 .42765 Mdot
.73 .42769 Mdot
.73 .42771 Mdot
.73 .42795 Mdot
.73 .428 Mdot
.73 .42805 Mdot
.73 .42812 Mdot
.73 .42828 Mdot
.73 .42836 Mdot
.73 .42837 Mdot
.73 .42838 Mdot
.73 .42846 Mdot
.73 .42852 Mdot
.73 .42871 Mdot
.73 .42901 Mdot
.73 .4293 Mdot
.73 .42941 Mdot
.73 .42944 Mdot
.73 .42965 Mdot
.73 .42985 Mdot
.73 .42991 Mdot
.73 .43009 Mdot
.73 .43014 Mdot
.73 .43015 Mdot
.73 .43058 Mdot
.73 .43069 Mdot
.73 .43083 Mdot
.73 .43101 Mdot
.73 .43111 Mdot
.73 .4313 Mdot
.73 .43135 Mdot
.73 .43152 Mdot
.73 .43156 Mdot
.73 .43176 Mdot
.73 .43216 Mdot
.73 .4322 Mdot
.73 .43222 Mdot
.73 .43223 Mdot
.73 .43277 Mdot
.73 .43307 Mdot
.73 .4331 Mdot
.73 .43321 Mdot
.73 .43393 Mdot
.73 .43395 Mdot
.73 .43427 Mdot
.73 .43467 Mdot
.73 .4348 Mdot
.73 .43483 Mdot
.73 .43487 Mdot
.73 .43565 Mdot
.73 .43568 Mdot
.73 .43582 Mdot
.73 .43596 Mdot
.73 .43612 Mdot
.73 .4362 Mdot
.73 .43622 Mdot
.73 .43639 Mdot
.73 .43719 Mdot
.73 .43726 Mdot
.73 .43764 Mdot
.73 .43792 Mdot
.73 .43798 Mdot
.73 .43815 Mdot
.73 .43823 Mdot
.73 .43842 Mdot
.73 .43848 Mdot
.73 .43858 Mdot
.73 .43884 Mdot
.73 .43889 Mdot
.73 .43892 Mdot
.73 .43893 Mdot
.73 .43936 Mdot
.73 .43974 Mdot
.73 .43991 Mdot
.73 .44001 Mdot
.73 .44019 Mdot
.73 .44052 Mdot
.73 .44061 Mdot
.73 .44067 Mdot
.73 .44114 Mdot
.73 .44139 Mdot
.73 .4414 Mdot
.73 .44173 Mdot
.73 .44208 Mdot
.73 .4421 Mdot
.73 .44286 Mdot
.73 .4432 Mdot
.73 .4441 Mdot
.73 .44424 Mdot
.73 .44445 Mdot
.73 .44449 Mdot
.73 .44451 Mdot
.73 .44463 Mdot
.73 .44478 Mdot
.73 .44501 Mdot
.73 .44522 Mdot
.73 .4453 Mdot
.73 .44536 Mdot
.73 .44537 Mdot
.732 .24626 Mdot
.732 .24661 Mdot
.732 .24698 Mdot
.732 .24741 Mdot
.732 .24855 Mdot
.732 .24894 Mdot
.732 .24988 Mdot
.732 .25001 Mdot
.732 .25001 Mdot
.732 .25037 Mdot
.732 .25042 Mdot
.732 .25158 Mdot
.732 .25179 Mdot
.732 .25196 Mdot
.732 .25244 Mdot
.732 .25246 Mdot
.732 .25252 Mdot
.732 .25313 Mdot
.732 .25361 Mdot
.732 .25365 Mdot
.732 .25392 Mdot
.732 .25435 Mdot
.732 .25438 Mdot
.732 .25453 Mdot
.732 .25484 Mdot
.732 .25491 Mdot
.732 .255 Mdot
.732 .25551 Mdot
.732 .25555 Mdot
.732 .25561 Mdot
.732 .25587 Mdot
.732 .2565 Mdot
.732 .25657 Mdot
.732 .25765 Mdot
.732 .25766 Mdot
.732 .25771 Mdot
.732 .25849 Mdot
.732 .25858 Mdot
.732 .2588 Mdot
.732 .2591 Mdot
.732 .25944 Mdot
.732 .25949 Mdot
.732 .25979 Mdot
.732 .25997 Mdot
.732 .26083 Mdot
.732 .26158 Mdot
.732 .2617 Mdot
.732 .26178 Mdot
.732 .26192 Mdot
.732 .26213 Mdot
.732 .26216 Mdot
.732 .26227 Mdot
.732 .26257 Mdot
.732 .26271 Mdot
.732 .26275 Mdot
.732 .26324 Mdot
.732 .26326 Mdot
.732 .26327 Mdot
.732 .26339 Mdot
.732 .26408 Mdot
.732 .26437 Mdot
.732 .26458 Mdot
.732 .26462 Mdot
.732 .26466 Mdot
.732 .26486 Mdot
.732 .26528 Mdot
.732 .26581 Mdot
.732 .26587 Mdot
.732 .2662 Mdot
.732 .26687 Mdot
.732 .26688 Mdot
.732 .26695 Mdot
.732 .26707 Mdot
.732 .26741 Mdot
.732 .26749 Mdot
.732 .26764 Mdot
.732 .2678 Mdot
.732 .26812 Mdot
.732 .26814 Mdot
.732 .26824 Mdot
.732 .26931 Mdot
.732 .2701 Mdot
.732 .27064 Mdot
.732 .27081 Mdot
.732 .271 Mdot
.732 .27167 Mdot
.732 .27168 Mdot
.732 .27188 Mdot
.732 .27225 Mdot
.732 .27275 Mdot
.732 .27282 Mdot
.732 .27296 Mdot
.732 .27309 Mdot
.732 .27343 Mdot
.732 .27345 Mdot
.732 .27356 Mdot
.732 .27367 Mdot
.732 .27414 Mdot
.732 .27427 Mdot
.732 .27527 Mdot
.732 .2754 Mdot
.732 .27556 Mdot
.732 .27556 Mdot
.732 .27571 Mdot
.732 .27606 Mdot
.732 .27611 Mdot
.732 .27646 Mdot
.732 .27647 Mdot
.732 .27656 Mdot
.732 .27669 Mdot
.732 .27817 Mdot
.732 .27825 Mdot
.732 .27838 Mdot
.732 .27884 Mdot
.732 .27947 Mdot
.732 .2798 Mdot
.732 .27989 Mdot
.732 .28058 Mdot
.732 .28098 Mdot
.732 .28184 Mdot
.732 .2821 Mdot
.732 .28217 Mdot
.732 .28231 Mdot
.732 .28256 Mdot
.732 .28276 Mdot
.732 .28295 Mdot
.732 .28378 Mdot
.732 .28378 Mdot
.732 .28378 Mdot
.732 .28396 Mdot
.732 .28422 Mdot
.732 .28434 Mdot
.732 .28458 Mdot
.732 .2847 Mdot
.732 .28477 Mdot
.732 .28527 Mdot
.732 .28543 Mdot
.732 .28547 Mdot
.732 .28574 Mdot
.732 .28585 Mdot
.732 .286 Mdot
.732 .28605 Mdot
.732 .28615 Mdot
.732 .2864 Mdot
.732 .28658 Mdot
.732 .28666 Mdot
.732 .28703 Mdot
.732 .2874 Mdot
.732 .28783 Mdot
.732 .28798 Mdot
.732 .28825 Mdot
.732 .28825 Mdot
.732 .28837 Mdot
.732 .2887 Mdot
.732 .28873 Mdot
.732 .28896 Mdot
.732 .28938 Mdot
.732 .28947 Mdot
.732 .28949 Mdot
.732 .2895 Mdot
.732 .28955 Mdot
.732 .28974 Mdot
.732 .29002 Mdot
.732 .29007 Mdot
.732 .2902 Mdot
.732 .29064 Mdot
.732 .29085 Mdot
.732 .29105 Mdot
.732 .29112 Mdot
.732 .29119 Mdot
.732 .29137 Mdot
.732 .29139 Mdot
.732 .2919 Mdot
.732 .29195 Mdot
.732 .29207 Mdot
.732 .29216 Mdot
.732 .29216 Mdot
.732 .29254 Mdot
.732 .29272 Mdot
.732 .29291 Mdot
.732 .29306 Mdot
.732 .29397 Mdot
.732 .29468 Mdot
.732 .29478 Mdot
.732 .29557 Mdot
.732 .29557 Mdot
.732 .29574 Mdot
.732 .29613 Mdot
.732 .29666 Mdot
.732 .29687 Mdot
.732 .29698 Mdot
.732 .29721 Mdot
.732 .2973 Mdot
.732 .29754 Mdot
.732 .29771 Mdot
.732 .2978 Mdot
.732 .29812 Mdot
.732 .29821 Mdot
.732 .29829 Mdot
.732 .29854 Mdot
.732 .29891 Mdot
.732 .29947 Mdot
.732 .29961 Mdot
.732 .29976 Mdot
.732 .30001 Mdot
.732 .30052 Mdot
.732 .30054 Mdot
.732 .30079 Mdot
.732 .30099 Mdot
.732 .30108 Mdot
.732 .30135 Mdot
.732 .30167 Mdot
.732 .30172 Mdot
.732 .30173 Mdot
.732 .30174 Mdot
.732 .30252 Mdot
.732 .30327 Mdot
.732 .30349 Mdot
.732 .30351 Mdot
.732 .30367 Mdot
.732 .30391 Mdot
.732 .30396 Mdot
.732 .30432 Mdot
.732 .30434 Mdot
.732 .30488 Mdot
.732 .30518 Mdot
.732 .30535 Mdot
.732 .30559 Mdot
.732 .30566 Mdot
.732 .30587 Mdot
.732 .30589 Mdot
.732 .30646 Mdot
.732 .30677 Mdot
.732 .30678 Mdot
.732 .30774 Mdot
.732 .30791 Mdot
.732 .30859 Mdot
.732 .30966 Mdot
.732 .30989 Mdot
.732 .31007 Mdot
.732 .31027 Mdot
.732 .31098 Mdot
.732 .31142 Mdot
.732 .31148 Mdot
.732 .31167 Mdot
.732 .31221 Mdot
.732 .31231 Mdot
.732 .31239 Mdot
.732 .31265 Mdot
.732 .31316 Mdot
.732 .31318 Mdot
.732 .31331 Mdot
.732 .31359 Mdot
.732 .31377 Mdot
.732 .31407 Mdot
.732 .31409 Mdot
.732 .31454 Mdot
.732 .31504 Mdot
.732 .31558 Mdot
.732 .31604 Mdot
.732 .31653 Mdot
.732 .31694 Mdot
.732 .31697 Mdot
.732 .31704 Mdot
.732 .31713 Mdot
.732 .31715 Mdot
.732 .3172 Mdot
.732 .31734 Mdot
.732 .3174 Mdot
.732 .31742 Mdot
.732 .31818 Mdot
.732 .31828 Mdot
.732 .3183 Mdot
.732 .31903 Mdot
.732 .31935 Mdot
.732 .31935 Mdot
.732 .31944 Mdot
.732 .3196 Mdot
.732 .31971 Mdot
.732 .31994 Mdot
.732 .31998 Mdot
.732 .32158 Mdot
.732 .32212 Mdot
.732 .32225 Mdot
.732 .3224 Mdot
.732 .32247 Mdot
.732 .3228 Mdot
.732 .32332 Mdot
.732 .3234 Mdot
.732 .3234 Mdot
.732 .32347 Mdot
.732 .32363 Mdot
.732 .32387 Mdot
.732 .32393 Mdot
.732 .32466 Mdot
.732 .32493 Mdot
.732 .32522 Mdot
.732 .32538 Mdot
.732 .32574 Mdot
.732 .32593 Mdot
.732 .32645 Mdot
.732 .32655 Mdot
.732 .32676 Mdot
.732 .32724 Mdot
.732 .32761 Mdot
.732 .32767 Mdot
.732 .3277 Mdot
.732 .32793 Mdot
.732 .32815 Mdot
.732 .32829 Mdot
.732 .32846 Mdot
.732 .32858 Mdot
.732 .32893 Mdot
.732 .32912 Mdot
.732 .32932 Mdot
.732 .32953 Mdot
.732 .32955 Mdot
.732 .3299 Mdot
.732 .33015 Mdot
.732 .33017 Mdot
.732 .33023 Mdot
.732 .33054 Mdot
.732 .33063 Mdot
.732 .33078 Mdot
.732 .33079 Mdot
.732 .33105 Mdot
.732 .3311 Mdot
.732 .33133 Mdot
.732 .33149 Mdot
.732 .33232 Mdot
.732 .33274 Mdot
.732 .3335 Mdot
.732 .33373 Mdot
.732 .33378 Mdot
.732 .334 Mdot
.732 .33429 Mdot
.732 .33455 Mdot
.732 .33504 Mdot
.732 .33526 Mdot
.732 .33531 Mdot
.732 .33558 Mdot
.732 .33598 Mdot
.732 .33633 Mdot
.732 .33643 Mdot
.732 .33652 Mdot
.732 .33665 Mdot
.732 .33682 Mdot
.732 .33741 Mdot
.732 .33744 Mdot
.732 .33754 Mdot
.732 .33782 Mdot
.732 .33796 Mdot
.732 .33797 Mdot
.732 .3385 Mdot
.732 .33931 Mdot
.732 .33942 Mdot
.732 .34013 Mdot
.732 .34016 Mdot
.732 .34025 Mdot
.732 .3405 Mdot
.732 .34059 Mdot
.732 .34071 Mdot
.732 .34094 Mdot
.732 .34095 Mdot
.732 .34137 Mdot
.732 .34138 Mdot
.732 .34159 Mdot
.732 .34182 Mdot
.732 .34207 Mdot
.732 .34229 Mdot
.732 .34251 Mdot
.732 .34272 Mdot
.732 .34275 Mdot
.732 .3428 Mdot
.732 .3428 Mdot
.732 .34289 Mdot
.732 .34334 Mdot
.732 .34387 Mdot
.732 .34395 Mdot
.732 .34411 Mdot
.732 .34487 Mdot
.732 .34518 Mdot
.732 .34529 Mdot
.732 .34544 Mdot
.732 .34569 Mdot
.732 .34572 Mdot
.732 .34575 Mdot
.732 .34681 Mdot
.732 .3469 Mdot
.732 .34719 Mdot
.732 .34729 Mdot
.732 .34769 Mdot
.732 .34784 Mdot
.732 .34794 Mdot
.732 .348 Mdot
.732 .34808 Mdot
.732 .34814 Mdot
.732 .3483 Mdot
.732 .34848 Mdot
.732 .34859 Mdot
.732 .34887 Mdot
.732 .34888 Mdot
.732 .34891 Mdot
.732 .34905 Mdot
.732 .34909 Mdot
.732 .34916 Mdot
.732 .34917 Mdot
.732 .34932 Mdot
.732 .34942 Mdot
.732 .34988 Mdot
.732 .35043 Mdot
.732 .35054 Mdot
.732 .35056 Mdot
.732 .35067 Mdot
.732 .3508 Mdot
.732 .35093 Mdot
.732 .35141 Mdot
.732 .3518 Mdot
.732 .35184 Mdot
.732 .35226 Mdot
.732 .35227 Mdot
.732 .35276 Mdot
.732 .35315 Mdot
.732 .3534 Mdot
.732 .35354 Mdot
.732 .3537 Mdot
.732 .35374 Mdot
.732 .3538 Mdot
.732 .35391 Mdot
.732 .35391 Mdot
.732 .3541 Mdot
.732 .35421 Mdot
.732 .35432 Mdot
.732 .35443 Mdot
.732 .35464 Mdot
.732 .35475 Mdot
.732 .35477 Mdot
.732 .35527 Mdot
.732 .35538 Mdot
.732 .35574 Mdot
.732 .35588 Mdot
.732 .35593 Mdot
.732 .35687 Mdot
.732 .35705 Mdot
.732 .35717 Mdot
.732 .3572 Mdot
.732 .35734 Mdot
.732 .35742 Mdot
.732 .3576 Mdot
.732 .35762 Mdot
.732 .35771 Mdot
.732 .35774 Mdot
.732 .35774 Mdot
.732 .35786 Mdot
.732 .35808 Mdot
.732 .35833 Mdot
.732 .35839 Mdot
.732 .35839 Mdot
.732 .35844 Mdot
.732 .35851 Mdot
.732 .35879 Mdot
.732 .35897 Mdot
.732 .35899 Mdot
.732 .35919 Mdot
.732 .35919 Mdot
.732 .35972 Mdot
.732 .35978 Mdot
.732 .35988 Mdot
.732 .35996 Mdot
.732 .36005 Mdot
.732 .36015 Mdot
.732 .3602 Mdot
.732 .36036 Mdot
.732 .36088 Mdot
.732 .36134 Mdot
.732 .36148 Mdot
.732 .36149 Mdot
.732 .36156 Mdot
.732 .3616 Mdot
.732 .36174 Mdot
.732 .3618 Mdot
.732 .3619 Mdot
.732 .36202 Mdot
.732 .36204 Mdot
.732 .36205 Mdot
.732 .36207 Mdot
.732 .3621 Mdot
.732 .36223 Mdot
.732 .36232 Mdot
.732 .36274 Mdot
.732 .36278 Mdot
.732 .36287 Mdot
.732 .36297 Mdot
.732 .36321 Mdot
.732 .36342 Mdot
.732 .36349 Mdot
.732 .36354 Mdot
.732 .36361 Mdot
.732 .36368 Mdot
.732 .36374 Mdot
.732 .36375 Mdot
.732 .36376 Mdot
.732 .36418 Mdot
.732 .36429 Mdot
.732 .36442 Mdot
.732 .36445 Mdot
.732 .36452 Mdot
.732 .36454 Mdot
.732 .36475 Mdot
.732 .3648 Mdot
.732 .36492 Mdot
.732 .36555 Mdot
.732 .36558 Mdot
.732 .36572 Mdot
.732 .36581 Mdot
.732 .36589 Mdot
.732 .36597 Mdot
.732 .36626 Mdot
.732 .36627 Mdot
.732 .36631 Mdot
.732 .36636 Mdot
.732 .36641 Mdot
.732 .36645 Mdot
.732 .36649 Mdot
.732 .36664 Mdot
.732 .3668 Mdot
.732 .36724 Mdot
.732 .3673 Mdot
.732 .36739 Mdot
.732 .36741 Mdot
.732 .36743 Mdot
.732 .36745 Mdot
.732 .36753 Mdot
.732 .36764 Mdot
.732 .36774 Mdot
.732 .36776 Mdot
.732 .36782 Mdot
.732 .36791 Mdot
.732 .36823 Mdot
.732 .36858 Mdot
.732 .36869 Mdot
.732 .36873 Mdot
.732 .3688 Mdot
.732 .36886 Mdot
.732 .36891 Mdot
.732 .36953 Mdot
.732 .36966 Mdot
.732 .36985 Mdot
.732 .36989 Mdot
.732 .36992 Mdot
.732 .36993 Mdot
.732 .36997 Mdot
.732 .37014 Mdot
.732 .37029 Mdot
.732 .37037 Mdot
.732 .37037 Mdot
.732 .37039 Mdot
.732 .37046 Mdot
.732 .37059 Mdot
.732 .37065 Mdot
.732 .37074 Mdot
.732 .37076 Mdot
.732 .37097 Mdot
.732 .37161 Mdot
.732 .37164 Mdot
.732 .37174 Mdot
.732 .37206 Mdot
.732 .3724 Mdot
.732 .37249 Mdot
.732 .37263 Mdot
.732 .37271 Mdot
.732 .37285 Mdot
.732 .37299 Mdot
.732 .37299 Mdot
.732 .37307 Mdot
.732 .3731 Mdot
.732 .37324 Mdot
.732 .37334 Mdot
.732 .37351 Mdot
.732 .37377 Mdot
.732 .3741 Mdot
.732 .37412 Mdot
.732 .3744 Mdot
.732 .37443 Mdot
.732 .3747 Mdot
.732 .37503 Mdot
.732 .37511 Mdot
.732 .3752 Mdot
.732 .37527 Mdot
.732 .37529 Mdot
.732 .37536 Mdot
.732 .37574 Mdot
.732 .37606 Mdot
.732 .37613 Mdot
.732 .37623 Mdot
.732 .37623 Mdot
.732 .37628 Mdot
.732 .37631 Mdot
.732 .3764 Mdot
.732 .37642 Mdot
.732 .37643 Mdot
.732 .37662 Mdot
.732 .37669 Mdot
.732 .37682 Mdot
.732 .37693 Mdot
.732 .37697 Mdot
.732 .37702 Mdot
.732 .37707 Mdot
.732 .37714 Mdot
.732 .37724 Mdot
.732 .37751 Mdot
.732 .37758 Mdot
.732 .37778 Mdot
.732 .37783 Mdot
.732 .37856 Mdot
.732 .37858 Mdot
.732 .3786 Mdot
.732 .37877 Mdot
.732 .37888 Mdot
.732 .37895 Mdot
.732 .37916 Mdot
.732 .37968 Mdot
.732 .37979 Mdot
.732 .37984 Mdot
.732 .38021 Mdot
.732 .38051 Mdot
.732 .38057 Mdot
.732 .38058 Mdot
.732 .38061 Mdot
.732 .38063 Mdot
.732 .38077 Mdot
.732 .38092 Mdot
.732 .38107 Mdot
.732 .38124 Mdot
.732 .3814 Mdot
.732 .38155 Mdot
.732 .38156 Mdot
.732 .38184 Mdot
.732 .38185 Mdot
.732 .38201 Mdot
.732 .38209 Mdot
.732 .38215 Mdot
.732 .38232 Mdot
.732 .38238 Mdot
.732 .3824 Mdot
.732 .38259 Mdot
.732 .38289 Mdot
.732 .38296 Mdot
.732 .38352 Mdot
.732 .38388 Mdot
.732 .38388 Mdot
.732 .38398 Mdot
.732 .38417 Mdot
.732 .38423 Mdot
.732 .38426 Mdot
.732 .38466 Mdot
.732 .38478 Mdot
.732 .38487 Mdot
.732 .38493 Mdot
.732 .385 Mdot
.732 .38524 Mdot
.732 .38551 Mdot
.732 .38569 Mdot
.732 .38572 Mdot
.732 .38587 Mdot
.732 .38621 Mdot
.732 .38639 Mdot
.732 .38658 Mdot
.732 .38674 Mdot
.732 .38677 Mdot
.732 .38693 Mdot
.732 .38745 Mdot
.732 .38773 Mdot
.732 .38841 Mdot
.732 .38856 Mdot
.732 .3886 Mdot
.732 .38878 Mdot
.732 .38879 Mdot
.732 .38889 Mdot
.732 .38895 Mdot
.732 .38916 Mdot
.732 .3892 Mdot
.732 .38922 Mdot
.732 .38939 Mdot
.732 .38963 Mdot
.732 .38964 Mdot
.732 .38978 Mdot
.732 .38992 Mdot
.732 .39005 Mdot
.732 .39029 Mdot
.732 .39037 Mdot
.732 .39048 Mdot
.732 .39058 Mdot
.732 .39073 Mdot
.732 .39089 Mdot
.732 .39091 Mdot
.732 .39095 Mdot
.732 .39121 Mdot
.732 .39153 Mdot
.732 .39168 Mdot
.732 .39174 Mdot
.732 .3921 Mdot
.732 .39223 Mdot
.732 .39248 Mdot
.732 .39258 Mdot
.732 .39278 Mdot
.732 .39297 Mdot
.732 .39347 Mdot
.732 .39351 Mdot
.732 .39367 Mdot
.732 .39378 Mdot
.732 .39383 Mdot
.732 .39383 Mdot
.732 .39388 Mdot
.732 .39424 Mdot
.732 .39446 Mdot
.732 .39451 Mdot
.732 .39462 Mdot
.732 .3947 Mdot
.732 .39507 Mdot
.732 .39616 Mdot
.732 .39619 Mdot
.732 .39635 Mdot
.732 .39642 Mdot
.732 .39653 Mdot
.732 .39659 Mdot
.732 .39659 Mdot
.732 .39681 Mdot
.732 .39731 Mdot
.732 .39733 Mdot
.732 .39739 Mdot
.732 .39791 Mdot
.732 .39792 Mdot
.732 .39797 Mdot
.732 .39806 Mdot
.732 .3981 Mdot
.732 .39811 Mdot
.732 .39817 Mdot
.732 .39822 Mdot
.732 .39824 Mdot
.732 .39852 Mdot
.732 .39885 Mdot
.732 .39917 Mdot
.732 .39954 Mdot
.732 .39988 Mdot
.732 .40018 Mdot
.732 .4002 Mdot
.732 .40041 Mdot
.732 .40053 Mdot
.732 .40072 Mdot
.732 .40081 Mdot
.732 .40082 Mdot
.732 .40117 Mdot
.732 .40135 Mdot
.732 .4014 Mdot
.732 .40147 Mdot
.732 .40184 Mdot
.732 .40197 Mdot
.732 .40201 Mdot
.732 .40231 Mdot
.732 .4028 Mdot
.732 .40294 Mdot
.732 .40305 Mdot
.732 .40321 Mdot
.732 .40394 Mdot
.732 .40441 Mdot
.732 .40452 Mdot
.732 .40518 Mdot
.732 .40519 Mdot
.732 .4054 Mdot
.732 .40579 Mdot
.732 .4058 Mdot
.732 .40594 Mdot
.732 .406 Mdot
.732 .40616 Mdot
.732 .40627 Mdot
.732 .40647 Mdot
.732 .40685 Mdot
.732 .40686 Mdot
.732 .40711 Mdot
.732 .40714 Mdot
.732 .4073 Mdot
.732 .40741 Mdot
.732 .40743 Mdot
.732 .40758 Mdot
.732 .40809 Mdot
.732 .40862 Mdot
.732 .40863 Mdot
.732 .40863 Mdot
.732 .40867 Mdot
.732 .40889 Mdot
.732 .40907 Mdot
.732 .40914 Mdot
.732 .40927 Mdot
.732 .40944 Mdot
.732 .40946 Mdot
.732 .4098 Mdot
.732 .40998 Mdot
.732 .41008 Mdot
.732 .41018 Mdot
.732 .41056 Mdot
.732 .41081 Mdot
.732 .41098 Mdot
.732 .41104 Mdot
.732 .4111 Mdot
.732 .41131 Mdot
.732 .41138 Mdot
.732 .41149 Mdot
.732 .41165 Mdot
.732 .41172 Mdot
.732 .41188 Mdot
.732 .41195 Mdot
.732 .41209 Mdot
.732 .41245 Mdot
.732 .41272 Mdot
.732 .41284 Mdot
.732 .41284 Mdot
.732 .41338 Mdot
.732 .41345 Mdot
.732 .41393 Mdot
.732 .41455 Mdot
.732 .41466 Mdot
.732 .41478 Mdot
.732 .4149 Mdot
.732 .41517 Mdot
.732 .41517 Mdot
.732 .41523 Mdot
.732 .41531 Mdot
.732 .41535 Mdot
.732 .41569 Mdot
.732 .41571 Mdot
.732 .41583 Mdot
.732 .41588 Mdot
.732 .41592 Mdot
.732 .41606 Mdot
.732 .4162 Mdot
.732 .41651 Mdot
.732 .41659 Mdot
.732 .41663 Mdot
.732 .41682 Mdot
.732 .41695 Mdot
.732 .41698 Mdot
.732 .41699 Mdot
.732 .41701 Mdot
.732 .41707 Mdot
.732 .41736 Mdot
.732 .41751 Mdot
.732 .41753 Mdot
.732 .41776 Mdot
.732 .41784 Mdot
.732 .41784 Mdot
.732 .41802 Mdot
.732 .41813 Mdot
.732 .41842 Mdot
.732 .41867 Mdot
.732 .41893 Mdot
.732 .41898 Mdot
.732 .4191 Mdot
.732 .41927 Mdot
.732 .41934 Mdot
.732 .41937 Mdot
.732 .41948 Mdot
.732 .41955 Mdot
.732 .41974 Mdot
.732 .41977 Mdot
.732 .41987 Mdot
.732 .42021 Mdot
.732 .42026 Mdot
.732 .42034 Mdot
.732 .42051 Mdot
.732 .42059 Mdot
.732 .42077 Mdot
.732 .42089 Mdot
.732 .42089 Mdot
.732 .42089 Mdot
.732 .42146 Mdot
.732 .42158 Mdot
.732 .42172 Mdot
.732 .42189 Mdot
.732 .42199 Mdot
.732 .42204 Mdot
.732 .42221 Mdot
.732 .42281 Mdot
.732 .42308 Mdot
.732 .42355 Mdot
.732 .42361 Mdot
.732 .42384 Mdot
.732 .42426 Mdot
.732 .42458 Mdot
.732 .42467 Mdot
.732 .42472 Mdot
.732 .42573 Mdot
.732 .42582 Mdot
.732 .42588 Mdot
.732 .42589 Mdot
.732 .42613 Mdot
.732 .42616 Mdot
.732 .4264 Mdot
.732 .4265 Mdot
.732 .4265 Mdot
.732 .42662 Mdot
.732 .42671 Mdot
.732 .42739 Mdot
.732 .42748 Mdot
.732 .4278 Mdot
.732 .42787 Mdot
.732 .42794 Mdot
.732 .42796 Mdot
.732 .42819 Mdot
.732 .42828 Mdot
.732 .42838 Mdot
.732 .42843 Mdot
.732 .42877 Mdot
.732 .42902 Mdot
.732 .42915 Mdot
.732 .42916 Mdot
.732 .42962 Mdot
.732 .42975 Mdot
.732 .42987 Mdot
.732 .43023 Mdot
.732 .43077 Mdot
.732 .43151 Mdot
.732 .43158 Mdot
.732 .43159 Mdot
.732 .4318 Mdot
.732 .43191 Mdot
.732 .43202 Mdot
.732 .43207 Mdot
.732 .4323 Mdot
.732 .43239 Mdot
.732 .43244 Mdot
.732 .43244 Mdot
.732 .4329 Mdot
.732 .43313 Mdot
.732 .43316 Mdot
.732 .43352 Mdot
.732 .43381 Mdot
.732 .43395 Mdot
.732 .43398 Mdot
.732 .43401 Mdot
.732 .43415 Mdot
.732 .43434 Mdot
.732 .43482 Mdot
.732 .4349 Mdot
.732 .43491 Mdot
.732 .43492 Mdot
.732 .43526 Mdot
.732 .43528 Mdot
.732 .43538 Mdot
.732 .43558 Mdot
.732 .43566 Mdot
.732 .43568 Mdot
.732 .43582 Mdot
.732 .43592 Mdot
.732 .43597 Mdot
.732 .43605 Mdot
.732 .43657 Mdot
.732 .43715 Mdot
.732 .43727 Mdot
.732 .43748 Mdot
.732 .43752 Mdot
.732 .43775 Mdot
.732 .43795 Mdot
.732 .4381 Mdot
.732 .43816 Mdot
.732 .4387 Mdot
.732 .43873 Mdot
.732 .43874 Mdot
.732 .43947 Mdot
.732 .43952 Mdot
.732 .43996 Mdot
.732 .44013 Mdot
.732 .44017 Mdot
.732 .4402 Mdot
.732 .44055 Mdot
.732 .44061 Mdot
.732 .44066 Mdot
.732 .44087 Mdot
.732 .44097 Mdot
.732 .44099 Mdot
.732 .44128 Mdot
.732 .44147 Mdot
.732 .4415 Mdot
.732 .44183 Mdot
.732 .44224 Mdot
.732 .44228 Mdot
.732 .4423 Mdot
.732 .44262 Mdot
.732 .44274 Mdot
.732 .44288 Mdot
.732 .44368 Mdot
.732 .44371 Mdot
.732 .44395 Mdot
.732 .44396 Mdot
.732 .44405 Mdot
.732 .44469 Mdot
.732 .44495 Mdot
.732 .44573 Mdot
.732 .44603 Mdot
.732 .44628 Mdot
.732 .44652 Mdot
.734 .24545 Mdot
.734 .24605 Mdot
.734 .24612 Mdot
.734 .24612 Mdot
.734 .24629 Mdot
.734 .24639 Mdot
.734 .24647 Mdot
.734 .24666 Mdot
.734 .24691 Mdot
.734 .24699 Mdot
.734 .24716 Mdot
.734 .24784 Mdot
.734 .24823 Mdot
.734 .24867 Mdot
.734 .24898 Mdot
.734 .25005 Mdot
.734 .25027 Mdot
.734 .25051 Mdot
.734 .25056 Mdot
.734 .25109 Mdot
.734 .25197 Mdot
.734 .2524 Mdot
.734 .25241 Mdot
.734 .25241 Mdot
.734 .25252 Mdot
.734 .25261 Mdot
.734 .25276 Mdot
.734 .25309 Mdot
.734 .25319 Mdot
.734 .25333 Mdot
.734 .25344 Mdot
.734 .25425 Mdot
.734 .25427 Mdot
.734 .25454 Mdot
.734 .25482 Mdot
.734 .25521 Mdot
.734 .25543 Mdot
.734 .25588 Mdot
.734 .25614 Mdot
.734 .25618 Mdot
.734 .25673 Mdot
.734 .25733 Mdot
.734 .2574 Mdot
.734 .25746 Mdot
.734 .25764 Mdot
.734 .25765 Mdot
.734 .25815 Mdot
.734 .25851 Mdot
.734 .25929 Mdot
.734 .25937 Mdot
.734 .2596 Mdot
.734 .25986 Mdot
.734 .25989 Mdot
.734 .26007 Mdot
.734 .26061 Mdot
.734 .26074 Mdot
.734 .26108 Mdot
.734 .26136 Mdot
.734 .26143 Mdot
.734 .26237 Mdot
.734 .26247 Mdot
.734 .26273 Mdot
.734 .26283 Mdot
.734 .26295 Mdot
.734 .26327 Mdot
.734 .26328 Mdot
.734 .26386 Mdot
.734 .26393 Mdot
.734 .26431 Mdot
.734 .26457 Mdot
.734 .26505 Mdot
.734 .26561 Mdot
.734 .26608 Mdot
.734 .26616 Mdot
.734 .26619 Mdot
.734 .26691 Mdot
.734 .26706 Mdot
.734 .26706 Mdot
.734 .26737 Mdot
.734 .26744 Mdot
.734 .26786 Mdot
.734 .26859 Mdot
.734 .26929 Mdot
.734 .26972 Mdot
.734 .26998 Mdot
.734 .27008 Mdot
.734 .27036 Mdot
.734 .27041 Mdot
.734 .27105 Mdot
.734 .2711 Mdot
.734 .2716 Mdot
.734 .27165 Mdot
.734 .27192 Mdot
.734 .27222 Mdot
.734 .27263 Mdot
.734 .27292 Mdot
.734 .273 Mdot
.734 .27306 Mdot
.734 .2731 Mdot
.734 .27341 Mdot
.734 .27349 Mdot
.734 .27354 Mdot
.734 .27368 Mdot
.734 .27372 Mdot
.734 .27379 Mdot
.734 .274 Mdot
.734 .27436 Mdot
.734 .2749 Mdot
.734 .27502 Mdot
.734 .2752 Mdot
.734 .2758 Mdot
.734 .27587 Mdot
.734 .27592 Mdot
.734 .27599 Mdot
.734 .27627 Mdot
.734 .27664 Mdot
.734 .27774 Mdot
.734 .27799 Mdot
.734 .27814 Mdot
.734 .27842 Mdot
.734 .2786 Mdot
.734 .27932 Mdot
.734 .27944 Mdot
.734 .27992 Mdot
.734 .27994 Mdot
.734 .27994 Mdot
.734 .28016 Mdot
.734 .28079 Mdot
.734 .28089 Mdot
.734 .2812 Mdot
.734 .28129 Mdot
.734 .28132 Mdot
.734 .28169 Mdot
.734 .28194 Mdot
.734 .28238 Mdot
.734 .28253 Mdot
.734 .28277 Mdot
.734 .2829 Mdot
.734 .28425 Mdot
.734 .28445 Mdot
.734 .28462 Mdot
.734 .28502 Mdot
.734 .2851 Mdot
.734 .28532 Mdot
.734 .28549 Mdot
.734 .28584 Mdot
.734 .28588 Mdot
.734 .28616 Mdot
.734 .28675 Mdot
.734 .28683 Mdot
.734 .28709 Mdot
.734 .28722 Mdot
.734 .28727 Mdot
.734 .28743 Mdot
.734 .28786 Mdot
.734 .28823 Mdot
.734 .28831 Mdot
.734 .28842 Mdot
.734 .28856 Mdot
.734 .28869 Mdot
.734 .28883 Mdot
.734 .28959 Mdot
.734 .28985 Mdot
.734 .29005 Mdot
.734 .29033 Mdot
.734 .29037 Mdot
.734 .29064 Mdot
.734 .29079 Mdot
.734 .29095 Mdot
.734 .29117 Mdot
.734 .29135 Mdot
.734 .29152 Mdot
.734 .29215 Mdot
.734 .29239 Mdot
.734 .29308 Mdot
.734 .29342 Mdot
.734 .29352 Mdot
.734 .29353 Mdot
.734 .29381 Mdot
.734 .29436 Mdot
.734 .29454 Mdot
.734 .29539 Mdot
.734 .29573 Mdot
.734 .29581 Mdot
.734 .29641 Mdot
.734 .2965 Mdot
.734 .29674 Mdot
.734 .29711 Mdot
.734 .29725 Mdot
.734 .29739 Mdot
.734 .29763 Mdot
.734 .2981 Mdot
.734 .29827 Mdot
.734 .29847 Mdot
.734 .29913 Mdot
.734 .2995 Mdot
.734 .29992 Mdot
.734 .30017 Mdot
.734 .30163 Mdot
.734 .30211 Mdot
.734 .30243 Mdot
.734 .3025 Mdot
.734 .30283 Mdot
.734 .30296 Mdot
.734 .3031 Mdot
.734 .30364 Mdot
.734 .30387 Mdot
.734 .30387 Mdot
.734 .30396 Mdot
.734 .3043 Mdot
.734 .30455 Mdot
.734 .30457 Mdot
.734 .3049 Mdot
.734 .30543 Mdot
.734 .30625 Mdot
.734 .3063 Mdot
.734 .3065 Mdot
.734 .30716 Mdot
.734 .30718 Mdot
.734 .30739 Mdot
.734 .30789 Mdot
.734 .30804 Mdot
.734 .30842 Mdot
.734 .30874 Mdot
.734 .30897 Mdot
.734 .30906 Mdot
.734 .30922 Mdot
.734 .30922 Mdot
.734 .30925 Mdot
.734 .30953 Mdot
.734 .31025 Mdot
.734 .3103 Mdot
.734 .31054 Mdot
.734 .31058 Mdot
.734 .31116 Mdot
.734 .3121 Mdot
.734 .31248 Mdot
.734 .31309 Mdot
.734 .31309 Mdot
.734 .31319 Mdot
.734 .31326 Mdot
.734 .31341 Mdot
.734 .31345 Mdot
.734 .31352 Mdot
.734 .31357 Mdot
.734 .31395 Mdot
.734 .31408 Mdot
.734 .31421 Mdot
.734 .31439 Mdot
.734 .3147 Mdot
.734 .31538 Mdot
.734 .31541 Mdot
.734 .31592 Mdot
.734 .31632 Mdot
.734 .31655 Mdot
.734 .31665 Mdot
.734 .31712 Mdot
.734 .31725 Mdot
.734 .31772 Mdot
.734 .31788 Mdot
.734 .31793 Mdot
.734 .31798 Mdot
.734 .31814 Mdot
.734 .31814 Mdot
.734 .31841 Mdot
.734 .31844 Mdot
.734 .31861 Mdot
.734 .31874 Mdot
.734 .31896 Mdot
.734 .31944 Mdot
.734 .31949 Mdot
.734 .31982 Mdot
.734 .31989 Mdot
.734 .32004 Mdot
.734 .32007 Mdot
.734 .3206 Mdot
.734 .32124 Mdot
.734 .32142 Mdot
.734 .32145 Mdot
.734 .32175 Mdot
.734 .32202 Mdot
.734 .32248 Mdot
.734 .32261 Mdot
.734 .32268 Mdot
.734 .3227 Mdot
.734 .32284 Mdot
.734 .32288 Mdot
.734 .32297 Mdot
.734 .32301 Mdot
.734 .32311 Mdot
.734 .32328 Mdot
.734 .32353 Mdot
.734 .32395 Mdot
.734 .32398 Mdot
.734 .32404 Mdot
.734 .32417 Mdot
.734 .32434 Mdot
.734 .32497 Mdot
.734 .32516 Mdot
.734 .32525 Mdot
.734 .32563 Mdot
.734 .32586 Mdot
.734 .32626 Mdot
.734 .32645 Mdot
.734 .3265 Mdot
.734 .32651 Mdot
.734 .32668 Mdot
.734 .3268 Mdot
.734 .32707 Mdot
.734 .32718 Mdot
.734 .32796 Mdot
.734 .32826 Mdot
.734 .32836 Mdot
.734 .32863 Mdot
.734 .32919 Mdot
.734 .32925 Mdot
.734 .32927 Mdot
.734 .32971 Mdot
.734 .32975 Mdot
.734 .32987 Mdot
.734 .32993 Mdot
.734 .33 Mdot
.734 .33035 Mdot
.734 .33047 Mdot
.734 .33069 Mdot
.734 .3309 Mdot
.734 .33124 Mdot
.734 .33165 Mdot
.734 .33217 Mdot
.734 .33304 Mdot
.734 .33319 Mdot
.734 .33367 Mdot
.734 .33384 Mdot
.734 .33397 Mdot
.734 .33447 Mdot
.734 .33526 Mdot
.734 .33593 Mdot
.734 .33616 Mdot
.734 .33631 Mdot
.734 .33634 Mdot
.734 .33655 Mdot
.734 .33697 Mdot
.734 .33697 Mdot
.734 .33717 Mdot
.734 .33729 Mdot
.734 .3373 Mdot
.734 .33851 Mdot
.734 .33884 Mdot
.734 .33891 Mdot
.734 .33908 Mdot
.734 .33934 Mdot
.734 .33938 Mdot
.734 .3396 Mdot
.734 .33994 Mdot
.734 .34009 Mdot
.734 .34035 Mdot
.734 .34125 Mdot
.734 .3413 Mdot
.734 .34142 Mdot
.734 .34145 Mdot
.734 .34147 Mdot
.734 .34171 Mdot
.734 .34177 Mdot
.734 .34185 Mdot
.734 .342 Mdot
.734 .34231 Mdot
.734 .34233 Mdot
.734 .34257 Mdot
.734 .34286 Mdot
.734 .3429 Mdot
.734 .34318 Mdot
.734 .3435 Mdot
.734 .34359 Mdot
.734 .34372 Mdot
.734 .34373 Mdot
.734 .34382 Mdot
.734 .34387 Mdot
.734 .34398 Mdot
.734 .34422 Mdot
.734 .34441 Mdot
.734 .34447 Mdot
.734 .34474 Mdot
.734 .34512 Mdot
.734 .34513 Mdot
.734 .34527 Mdot
.734 .3457 Mdot
.734 .34578 Mdot
.734 .34579 Mdot
.734 .34583 Mdot
.734 .3461 Mdot
.734 .3463 Mdot
.734 .34685 Mdot
.734 .34689 Mdot
.734 .34707 Mdot
.734 .34736 Mdot
.734 .34745 Mdot
.734 .34747 Mdot
.734 .34756 Mdot
.734 .34761 Mdot
.734 .34815 Mdot
.734 .34846 Mdot
.734 .34872 Mdot
.734 .34875 Mdot
.734 .34876 Mdot
.734 .34897 Mdot
.734 .34906 Mdot
.734 .3491 Mdot
.734 .34926 Mdot
.734 .34952 Mdot
.734 .34986 Mdot
.734 .35051 Mdot
.734 .35058 Mdot
.734 .35088 Mdot
.734 .35094 Mdot
.734 .35117 Mdot
.734 .35185 Mdot
.734 .35204 Mdot
.734 .35214 Mdot
.734 .35243 Mdot
.734 .35248 Mdot
.734 .35305 Mdot
.734 .35343 Mdot
.734 .35345 Mdot
.734 .35355 Mdot
.734 .35371 Mdot
.734 .3539 Mdot
.734 .35432 Mdot
.734 .3544 Mdot
.734 .35441 Mdot
.734 .35442 Mdot
.734 .35453 Mdot
.734 .35456 Mdot
.734 .3546 Mdot
.734 .35467 Mdot
.734 .35481 Mdot
.734 .35493 Mdot
.734 .35506 Mdot
.734 .35521 Mdot
.734 .35536 Mdot
.734 .35541 Mdot
.734 .35547 Mdot
.734 .35551 Mdot
.734 .35558 Mdot
.734 .3557 Mdot
.734 .35578 Mdot
.734 .35581 Mdot
.734 .35594 Mdot
.734 .35618 Mdot
.734 .35638 Mdot
.734 .35642 Mdot
.734 .35643 Mdot
.734 .35694 Mdot
.734 .35716 Mdot
.734 .3572 Mdot
.734 .35721 Mdot
.734 .35725 Mdot
.734 .35727 Mdot
.734 .35752 Mdot
.734 .35766 Mdot
.734 .35778 Mdot
.734 .3578 Mdot
.734 .3578 Mdot
.734 .3579 Mdot
.734 .35794 Mdot
.734 .35815 Mdot
.734 .35861 Mdot
.734 .35881 Mdot
.734 .35892 Mdot
.734 .35924 Mdot
.734 .35937 Mdot
.734 .35998 Mdot
.734 .36019 Mdot
.734 .36042 Mdot
.734 .36048 Mdot
.734 .36049 Mdot
.734 .36051 Mdot
.734 .36073 Mdot
.734 .36087 Mdot
.734 .36092 Mdot
.734 .36093 Mdot
.734 .36106 Mdot
.734 .36108 Mdot
.734 .36134 Mdot
.734 .36136 Mdot
.734 .36136 Mdot
.734 .3617 Mdot
.734 .36172 Mdot
.734 .36172 Mdot
.734 .36199 Mdot
.734 .362 Mdot
.734 .36204 Mdot
.734 .36247 Mdot
.734 .36252 Mdot
.734 .36273 Mdot
.734 .36301 Mdot
.734 .36324 Mdot
.734 .36335 Mdot
.734 .36336 Mdot
.734 .36344 Mdot
.734 .36352 Mdot
.734 .36364 Mdot
.734 .36365 Mdot
.734 .36365 Mdot
.734 .36381 Mdot
.734 .36382 Mdot
.734 .36394 Mdot
.734 .36395 Mdot
.734 .36416 Mdot
.734 .36428 Mdot
.734 .36452 Mdot
.734 .36457 Mdot
.734 .36462 Mdot
.734 .36465 Mdot
.734 .36479 Mdot
.734 .36501 Mdot
.734 .36516 Mdot
.734 .36632 Mdot
.734 .36636 Mdot
.734 .36639 Mdot
.734 .36655 Mdot
.734 .36678 Mdot
.734 .36687 Mdot
.734 .36707 Mdot
.734 .36712 Mdot
.734 .36718 Mdot
.734 .36719 Mdot
.734 .36726 Mdot
.734 .36761 Mdot
.734 .36775 Mdot
.734 .36779 Mdot
.734 .36808 Mdot
.734 .36811 Mdot
.734 .36811 Mdot
.734 .3683 Mdot
.734 .36831 Mdot
.734 .36854 Mdot
.734 .36855 Mdot
.734 .36856 Mdot
.734 .36874 Mdot
.734 .36875 Mdot
.734 .36885 Mdot
.734 .36897 Mdot
.734 .36899 Mdot
.734 .36913 Mdot
.734 .36914 Mdot
.734 .36918 Mdot
.734 .36948 Mdot
.734 .3699 Mdot
.734 .36999 Mdot
.734 .3702 Mdot
.734 .37028 Mdot
.734 .37087 Mdot
.734 .3709 Mdot
.734 .37097 Mdot
.734 .37097 Mdot
.734 .37098 Mdot
.734 .37106 Mdot
.734 .37133 Mdot
.734 .37135 Mdot
.734 .37137 Mdot
.734 .37138 Mdot
.734 .37141 Mdot
.734 .3719 Mdot
.734 .37191 Mdot
.734 .37193 Mdot
.734 .37207 Mdot
.734 .37232 Mdot
.734 .37234 Mdot
.734 .37253 Mdot
.734 .37256 Mdot
.734 .3726 Mdot
.734 .37263 Mdot
.734 .37283 Mdot
.734 .37315 Mdot
.734 .37318 Mdot
.734 .37319 Mdot
.734 .37329 Mdot
.734 .37362 Mdot
.734 .37376 Mdot
.734 .37386 Mdot
.734 .37393 Mdot
.734 .37421 Mdot
.734 .37459 Mdot
.734 .37463 Mdot
.734 .37483 Mdot
.734 .37489 Mdot
.734 .37502 Mdot
.734 .37548 Mdot
.734 .37564 Mdot
.734 .37568 Mdot
.734 .37589 Mdot
.734 .37594 Mdot
.734 .37638 Mdot
.734 .37661 Mdot
.734 .37679 Mdot
.734 .3769 Mdot
.734 .37692 Mdot
.734 .37699 Mdot
.734 .37713 Mdot
.734 .37713 Mdot
.734 .37715 Mdot
.734 .37733 Mdot
.734 .37754 Mdot
.734 .37791 Mdot
.734 .37795 Mdot
.734 .378 Mdot
.734 .37802 Mdot
.734 .37808 Mdot
.734 .37828 Mdot
.734 .3784 Mdot
.734 .37842 Mdot
.734 .3788 Mdot
.734 .37894 Mdot
.734 .37912 Mdot
.734 .37915 Mdot
.734 .37916 Mdot
.734 .37921 Mdot
.734 .37951 Mdot
.734 .3796 Mdot
.734 .37961 Mdot
.734 .37987 Mdot
.734 .38005 Mdot
.734 .38009 Mdot
.734 .38022 Mdot
.734 .38039 Mdot
.734 .38046 Mdot
.734 .3805 Mdot
.734 .38055 Mdot
.734 .38056 Mdot
.734 .38065 Mdot
.734 .38071 Mdot
.734 .38093 Mdot
.734 .38112 Mdot
.734 .38115 Mdot
.734 .38135 Mdot
.734 .38151 Mdot
.734 .38152 Mdot
.734 .38173 Mdot
.734 .38183 Mdot
.734 .38189 Mdot
.734 .38193 Mdot
.734 .38209 Mdot
.734 .3821 Mdot
.734 .38213 Mdot
.734 .38221 Mdot
.734 .38224 Mdot
.734 .38285 Mdot
.734 .38304 Mdot
.734 .38314 Mdot
.734 .38337 Mdot
.734 .38352 Mdot
.734 .38355 Mdot
.734 .38372 Mdot
.734 .38384 Mdot
.734 .38389 Mdot
.734 .38411 Mdot
.734 .38494 Mdot
.734 .38494 Mdot
.734 .38502 Mdot
.734 .38516 Mdot
.734 .38516 Mdot
.734 .38544 Mdot
.734 .38559 Mdot
.734 .38561 Mdot
.734 .38571 Mdot
.734 .38586 Mdot
.734 .38633 Mdot
.734 .38686 Mdot
.734 .3872 Mdot
.734 .38729 Mdot
.734 .38741 Mdot
.734 .38773 Mdot
.734 .38784 Mdot
.734 .38843 Mdot
.734 .38878 Mdot
.734 .38906 Mdot
.734 .38929 Mdot
.734 .38944 Mdot
.734 .38959 Mdot
.734 .38967 Mdot
.734 .38991 Mdot
.734 .38996 Mdot
.734 .39 Mdot
.734 .39007 Mdot
.734 .3901 Mdot
.734 .3904 Mdot
.734 .39042 Mdot
.734 .39046 Mdot
.734 .39084 Mdot
.734 .39102 Mdot
.734 .39109 Mdot
.734 .3913 Mdot
.734 .39182 Mdot
.734 .3919 Mdot
.734 .39209 Mdot
.734 .39217 Mdot
.734 .39229 Mdot
.734 .39229 Mdot
.734 .39232 Mdot
.734 .39245 Mdot
.734 .39273 Mdot
.734 .39288 Mdot
.734 .39314 Mdot
.734 .3932 Mdot
.734 .39334 Mdot
.734 .39376 Mdot
.734 .39388 Mdot
.734 .39397 Mdot
.734 .39401 Mdot
.734 .39403 Mdot
.734 .39431 Mdot
.734 .39448 Mdot
.734 .3946 Mdot
.734 .39467 Mdot
.734 .3947 Mdot
.734 .39476 Mdot
.734 .39478 Mdot
.734 .39488 Mdot
.734 .39489 Mdot
.734 .39494 Mdot
.734 .39503 Mdot
.734 .39534 Mdot
.734 .39553 Mdot
.734 .39573 Mdot
.734 .39575 Mdot
.734 .39587 Mdot
.734 .39631 Mdot
.734 .39667 Mdot
.734 .39669 Mdot
.734 .39679 Mdot
.734 .39684 Mdot
.734 .39707 Mdot
.734 .3971 Mdot
.734 .39743 Mdot
.734 .39758 Mdot
.734 .39766 Mdot
.734 .39778 Mdot
.734 .3978 Mdot
.734 .39799 Mdot
.734 .39799 Mdot
.734 .39809 Mdot
.734 .39813 Mdot
.734 .39816 Mdot
.734 .39827 Mdot
.734 .39859 Mdot
.734 .39868 Mdot
.734 .399 Mdot
.734 .39907 Mdot
.734 .39922 Mdot
.734 .3995 Mdot
.734 .39985 Mdot
.734 .39987 Mdot
.734 .40033 Mdot
.734 .40054 Mdot
.734 .40066 Mdot
.734 .40075 Mdot
.734 .40084 Mdot
.734 .4011 Mdot
.734 .40113 Mdot
.734 .40118 Mdot
.734 .40121 Mdot
.734 .40136 Mdot
.734 .40142 Mdot
.734 .40142 Mdot
.734 .40184 Mdot
.734 .4021 Mdot
.734 .40274 Mdot
.734 .40314 Mdot
.734 .40316 Mdot
.734 .40333 Mdot
.734 .40336 Mdot
.734 .40385 Mdot
.734 .40404 Mdot
.734 .40406 Mdot
.734 .40406 Mdot
.734 .40417 Mdot
.734 .40423 Mdot
.734 .40439 Mdot
.734 .40461 Mdot
.734 .40487 Mdot
.734 .40497 Mdot
.734 .40531 Mdot
.734 .40545 Mdot
.734 .40547 Mdot
.734 .40591 Mdot
.734 .40605 Mdot
.734 .40608 Mdot
.734 .40664 Mdot
.734 .407 Mdot
.734 .40723 Mdot
.734 .40724 Mdot
.734 .40742 Mdot
.734 .40765 Mdot
.734 .4077 Mdot
.734 .40771 Mdot
.734 .40786 Mdot
.734 .40823 Mdot
.734 .40832 Mdot
.734 .40842 Mdot
.734 .40864 Mdot
.734 .40869 Mdot
.734 .4089 Mdot
.734 .40923 Mdot
.734 .41023 Mdot
.734 .4104 Mdot
.734 .41068 Mdot
.734 .41093 Mdot
.734 .41139 Mdot
.734 .41152 Mdot
.734 .41164 Mdot
.734 .41196 Mdot
.734 .41212 Mdot
.734 .41222 Mdot
.734 .41231 Mdot
.734 .41256 Mdot
.734 .41273 Mdot
.734 .41279 Mdot
.734 .4132 Mdot
.734 .41325 Mdot
.734 .41348 Mdot
.734 .41406 Mdot
.734 .41418 Mdot
.734 .41456 Mdot
.734 .41475 Mdot
.734 .41475 Mdot
.734 .41482 Mdot
.734 .41506 Mdot
.734 .41552 Mdot
.734 .41569 Mdot
.734 .41612 Mdot
.734 .41623 Mdot
.734 .41636 Mdot
.734 .41651 Mdot
.734 .41662 Mdot
.734 .41672 Mdot
.734 .41691 Mdot
.734 .41693 Mdot
.734 .41712 Mdot
.734 .41726 Mdot
.734 .41743 Mdot
.734 .41795 Mdot
.734 .41805 Mdot
.734 .41813 Mdot
.734 .41823 Mdot
.734 .4183 Mdot
.734 .41836 Mdot
.734 .41861 Mdot
.734 .41891 Mdot
.734 .41901 Mdot
.734 .41905 Mdot
.734 .41914 Mdot
.734 .41931 Mdot
.734 .41937 Mdot
.734 .41977 Mdot
.734 .41996 Mdot
.734 .41999 Mdot
.734 .42022 Mdot
.734 .42034 Mdot
.734 .42049 Mdot
.734 .42055 Mdot
.734 .42082 Mdot
.734 .42094 Mdot
.734 .42107 Mdot
.734 .42199 Mdot
.734 .42208 Mdot
.734 .42224 Mdot
.734 .42234 Mdot
.734 .42264 Mdot
.734 .42281 Mdot
.734 .42307 Mdot
.734 .42309 Mdot
.734 .42315 Mdot
.734 .42336 Mdot
.734 .42343 Mdot
.734 .42386 Mdot
.734 .42401 Mdot
.734 .42401 Mdot
.734 .42402 Mdot
.734 .42435 Mdot
.734 .42443 Mdot
.734 .42492 Mdot
.734 .42504 Mdot
.734 .42523 Mdot
.734 .42533 Mdot
.734 .4255 Mdot
.734 .42625 Mdot
.734 .4265 Mdot
.734 .42669 Mdot
.734 .42675 Mdot
.734 .42678 Mdot
.734 .42683 Mdot
.734 .42724 Mdot
.734 .42736 Mdot
.734 .42744 Mdot
.734 .42781 Mdot
.734 .42806 Mdot
.734 .4282 Mdot
.734 .42824 Mdot
.734 .42827 Mdot
.734 .42837 Mdot
.734 .4284 Mdot
.734 .42845 Mdot
.734 .42866 Mdot
.734 .42869 Mdot
.734 .42873 Mdot
.734 .42879 Mdot
.734 .42899 Mdot
.734 .42927 Mdot
.734 .42947 Mdot
.734 .42965 Mdot
.734 .42969 Mdot
.734 .43003 Mdot
.734 .43006 Mdot
.734 .4305 Mdot
.734 .43054 Mdot
.734 .43072 Mdot
.734 .43079 Mdot
.734 .43097 Mdot
.734 .43126 Mdot
.734 .43174 Mdot
.734 .43224 Mdot
.734 .43252 Mdot
.734 .43257 Mdot
.734 .43278 Mdot
.734 .43278 Mdot
.734 .43288 Mdot
.734 .43337 Mdot
.734 .43339 Mdot
.734 .43345 Mdot
.734 .43377 Mdot
.734 .43415 Mdot
.734 .43447 Mdot
.734 .43466 Mdot
.734 .43491 Mdot
.734 .43496 Mdot
.734 .43536 Mdot
.734 .43536 Mdot
.734 .43558 Mdot
.734 .43567 Mdot
.734 .43573 Mdot
.734 .4359 Mdot
.734 .43597 Mdot
.734 .43661 Mdot
.734 .43666 Mdot
.734 .43686 Mdot
.734 .43708 Mdot
.734 .43718 Mdot
.734 .43754 Mdot
.734 .43767 Mdot
.734 .43768 Mdot
.734 .43786 Mdot
.734 .43802 Mdot
.734 .43807 Mdot
.734 .43861 Mdot
.734 .43885 Mdot
.734 .43919 Mdot
.734 .4392 Mdot
.734 .43932 Mdot
.734 .43936 Mdot
.734 .43941 Mdot
.734 .43982 Mdot
.734 .44019 Mdot
.734 .44022 Mdot
.734 .4404 Mdot
.734 .44071 Mdot
.734 .44086 Mdot
.734 .44112 Mdot
.734 .44131 Mdot
.734 .44149 Mdot
.734 .44151 Mdot
.734 .44206 Mdot
.734 .44213 Mdot
.734 .44223 Mdot
.734 .4423 Mdot
.734 .44252 Mdot
.734 .44262 Mdot
.734 .44269 Mdot
.734 .44276 Mdot
.734 .44276 Mdot
.734 .44276 Mdot
.734 .44306 Mdot
.734 .44366 Mdot
.734 .44402 Mdot
.734 .44405 Mdot
.734 .44422 Mdot
.734 .44437 Mdot
.734 .4451 Mdot
.734 .44531 Mdot
.734 .4456 Mdot
.734 .44588 Mdot
.734 .44634 Mdot
.734 .44645 Mdot
.734 .4465 Mdot
.734 .44668 Mdot
.734 .44681 Mdot
.734 .44686 Mdot
.734 .44693 Mdot
.734 .44704 Mdot
.734 .44705 Mdot
.734 .44709 Mdot
.734 .4475 Mdot
.736 .24404 Mdot
.736 .24444 Mdot
.736 .24469 Mdot
.736 .24556 Mdot
.736 .24582 Mdot
.736 .2459 Mdot
.736 .24623 Mdot
.736 .24665 Mdot
.736 .24672 Mdot
.736 .24716 Mdot
.736 .24721 Mdot
.736 .24773 Mdot
.736 .24787 Mdot
.736 .24798 Mdot
.736 .24821 Mdot
.736 .24877 Mdot
.736 .249 Mdot
.736 .24916 Mdot
.736 .24924 Mdot
.736 .2493 Mdot
.736 .24941 Mdot
.736 .24942 Mdot
.736 .25016 Mdot
.736 .25067 Mdot
.736 .2509 Mdot
.736 .25091 Mdot
.736 .25168 Mdot
.736 .25179 Mdot
.736 .25196 Mdot
.736 .25221 Mdot
.736 .25247 Mdot
.736 .25251 Mdot
.736 .25291 Mdot
.736 .25345 Mdot
.736 .25364 Mdot
.736 .25372 Mdot
.736 .25373 Mdot
.736 .25385 Mdot
.736 .25398 Mdot
.736 .25416 Mdot
.736 .25459 Mdot
.736 .25494 Mdot
.736 .25505 Mdot
.736 .25536 Mdot
.736 .25578 Mdot
.736 .256 Mdot
.736 .25652 Mdot
.736 .25695 Mdot
.736 .25716 Mdot
.736 .25721 Mdot
.736 .25753 Mdot
.736 .25759 Mdot
.736 .25763 Mdot
.736 .25785 Mdot
.736 .25795 Mdot
.736 .25856 Mdot
.736 .25866 Mdot
.736 .25909 Mdot
.736 .25929 Mdot
.736 .25953 Mdot
.736 .25977 Mdot
.736 .25984 Mdot
.736 .25989 Mdot
.736 .26048 Mdot
.736 .26064 Mdot
.736 .26086 Mdot
.736 .26167 Mdot
.736 .26173 Mdot
.736 .26218 Mdot
.736 .26373 Mdot
.736 .26381 Mdot
.736 .26407 Mdot
.736 .26442 Mdot
.736 .26511 Mdot
.736 .26521 Mdot
.736 .2653 Mdot
.736 .26559 Mdot
.736 .26589 Mdot
.736 .2659 Mdot
.736 .26634 Mdot
.736 .26646 Mdot
.736 .26649 Mdot
.736 .26699 Mdot
.736 .26745 Mdot
.736 .26752 Mdot
.736 .26802 Mdot
.736 .26881 Mdot
.736 .26914 Mdot
.736 .26953 Mdot
.736 .27036 Mdot
.736 .27093 Mdot
.736 .27123 Mdot
.736 .27144 Mdot
.736 .27191 Mdot
.736 .27205 Mdot
.736 .2722 Mdot
.736 .2726 Mdot
.736 .27299 Mdot
.736 .27313 Mdot
.736 .27327 Mdot
.736 .27375 Mdot
.736 .27392 Mdot
.736 .27408 Mdot
.736 .27447 Mdot
.736 .27457 Mdot
.736 .27577 Mdot
.736 .276 Mdot
.736 .27624 Mdot
.736 .27641 Mdot
.736 .27647 Mdot
.736 .2766 Mdot
.736 .27761 Mdot
.736 .27835 Mdot
.736 .27847 Mdot
.736 .27857 Mdot
.736 .27896 Mdot
.736 .27898 Mdot
.736 .27935 Mdot
.736 .27946 Mdot
.736 .28004 Mdot
.736 .28047 Mdot
.736 .2805 Mdot
.736 .28103 Mdot
.736 .28118 Mdot
.736 .28144 Mdot
.736 .28144 Mdot
.736 .28163 Mdot
.736 .28204 Mdot
.736 .28217 Mdot
.736 .28234 Mdot
.736 .28263 Mdot
.736 .28324 Mdot
.736 .28359 Mdot
.736 .28365 Mdot
.736 .28404 Mdot
.736 .28449 Mdot
.736 .28473 Mdot
.736 .28532 Mdot
.736 .28578 Mdot
.736 .28588 Mdot
.736 .28619 Mdot
.736 .28628 Mdot
.736 .28632 Mdot
.736 .2869 Mdot
.736 .28693 Mdot
.736 .28705 Mdot
.736 .28714 Mdot
.736 .28773 Mdot
.736 .28851 Mdot
.736 .28869 Mdot
.736 .2895 Mdot
.736 .28982 Mdot
.736 .28989 Mdot
.736 .29016 Mdot
.736 .291 Mdot
.736 .29158 Mdot
.736 .29199 Mdot
.736 .29213 Mdot
.736 .29285 Mdot
.736 .29305 Mdot
.736 .29332 Mdot
.736 .29337 Mdot
.736 .29355 Mdot
.736 .29373 Mdot
.736 .29464 Mdot
.736 .29473 Mdot
.736 .29481 Mdot
.736 .29492 Mdot
.736 .29558 Mdot
.736 .29581 Mdot
.736 .29674 Mdot
.736 .2968 Mdot
.736 .29702 Mdot
.736 .29726 Mdot
.736 .29808 Mdot
.736 .2986 Mdot
.736 .29958 Mdot
.736 .29959 Mdot
.736 .29972 Mdot
.736 .29995 Mdot
.736 .30026 Mdot
.736 .30042 Mdot
.736 .30054 Mdot
.736 .30058 Mdot
.736 .30095 Mdot
.736 .3013 Mdot
.736 .30153 Mdot
.736 .30208 Mdot
.736 .30252 Mdot
.736 .30263 Mdot
.736 .30297 Mdot
.736 .30325 Mdot
.736 .3034 Mdot
.736 .30344 Mdot
.736 .30362 Mdot
.736 .30391 Mdot
.736 .30415 Mdot
.736 .30425 Mdot
.736 .30445 Mdot
.736 .30459 Mdot
.736 .3048 Mdot
.736 .30508 Mdot
.736 .30514 Mdot
.736 .3052 Mdot
.736 .3052 Mdot
.736 .30532 Mdot
.736 .30576 Mdot
.736 .30578 Mdot
.736 .30602 Mdot
.736 .30609 Mdot
.736 .3065 Mdot
.736 .30661 Mdot
.736 .30684 Mdot
.736 .30719 Mdot
.736 .30724 Mdot
.736 .30727 Mdot
.736 .3073 Mdot
.736 .30785 Mdot
.736 .3079 Mdot
.736 .3082 Mdot
.736 .30823 Mdot
.736 .30866 Mdot
.736 .30949 Mdot
.736 .30973 Mdot
.736 .31002 Mdot
.736 .31043 Mdot
.736 .31055 Mdot
.736 .31058 Mdot
.736 .31093 Mdot
.736 .31096 Mdot
.736 .31143 Mdot
.736 .31165 Mdot
.736 .31191 Mdot
.736 .31201 Mdot
.736 .31221 Mdot
.736 .3129 Mdot
.736 .31325 Mdot
.736 .31349 Mdot
.736 .31382 Mdot
.736 .31415 Mdot
.736 .31439 Mdot
.736 .31476 Mdot
.736 .31568 Mdot
.736 .3158 Mdot
.736 .31598 Mdot
.736 .3161 Mdot
.736 .31647 Mdot
.736 .31667 Mdot
.736 .31698 Mdot
.736 .31702 Mdot
.736 .31704 Mdot
.736 .31738 Mdot
.736 .31749 Mdot
.736 .31789 Mdot
.736 .3195 Mdot
.736 .31954 Mdot
.736 .32002 Mdot
.736 .32007 Mdot
.736 .32008 Mdot
.736 .32032 Mdot
.736 .32053 Mdot
.736 .32056 Mdot
.736 .32116 Mdot
.736 .32149 Mdot
.736 .32187 Mdot
.736 .32227 Mdot
.736 .32272 Mdot
.736 .3229 Mdot
.736 .32308 Mdot
.736 .32315 Mdot
.736 .32322 Mdot
.736 .32344 Mdot
.736 .32352 Mdot
.736 .32377 Mdot
.736 .32437 Mdot
.736 .32469 Mdot
.736 .32522 Mdot
.736 .32556 Mdot
.736 .32561 Mdot
.736 .32585 Mdot
.736 .32655 Mdot
.736 .3268 Mdot
.736 .32687 Mdot
.736 .32699 Mdot
.736 .32699 Mdot
.736 .32707 Mdot
.736 .32732 Mdot
.736 .32753 Mdot
.736 .32798 Mdot
.736 .328 Mdot
.736 .32818 Mdot
.736 .3285 Mdot
.736 .32877 Mdot
.736 .32899 Mdot
.736 .32904 Mdot
.736 .32918 Mdot
.736 .32922 Mdot
.736 .32952 Mdot
.736 .32962 Mdot
.736 .33025 Mdot
.736 .33033 Mdot
.736 .33085 Mdot
.736 .33101 Mdot
.736 .3314 Mdot
.736 .33185 Mdot
.736 .33192 Mdot
.736 .33258 Mdot
.736 .33266 Mdot
.736 .33315 Mdot
.736 .33405 Mdot
.736 .33418 Mdot
.736 .33429 Mdot
.736 .33536 Mdot
.736 .33542 Mdot
.736 .33553 Mdot
.736 .33567 Mdot
.736 .33582 Mdot
.736 .33599 Mdot
.736 .33626 Mdot
.736 .33651 Mdot
.736 .33671 Mdot
.736 .33692 Mdot
.736 .33712 Mdot
.736 .33714 Mdot
.736 .33747 Mdot
.736 .33751 Mdot
.736 .3376 Mdot
.736 .33767 Mdot
.736 .3379 Mdot
.736 .33792 Mdot
.736 .33801 Mdot
.736 .33822 Mdot
.736 .33833 Mdot
.736 .33855 Mdot
.736 .3386 Mdot
.736 .33871 Mdot
.736 .33887 Mdot
.736 .3389 Mdot
.736 .33917 Mdot
.736 .3392 Mdot
.736 .33934 Mdot
.736 .33955 Mdot
.736 .34018 Mdot
.736 .34036 Mdot
.736 .34059 Mdot
.736 .34061 Mdot
.736 .3411 Mdot
.736 .34118 Mdot
.736 .3415 Mdot
.736 .34167 Mdot
.736 .34193 Mdot
.736 .34208 Mdot
.736 .34219 Mdot
.736 .34236 Mdot
.736 .34284 Mdot
.736 .34324 Mdot
.736 .3434 Mdot
.736 .34341 Mdot
.736 .34357 Mdot
.736 .34381 Mdot
.736 .34455 Mdot
.736 .34457 Mdot
.736 .34479 Mdot
.736 .34481 Mdot
.736 .34502 Mdot
.736 .34583 Mdot
.736 .34604 Mdot
.736 .3462 Mdot
.736 .34623 Mdot
.736 .34637 Mdot
.736 .34652 Mdot
.736 .34695 Mdot
.736 .34737 Mdot
.736 .3478 Mdot
.736 .34792 Mdot
.736 .34801 Mdot
.736 .34801 Mdot
.736 .34804 Mdot
.736 .34826 Mdot
.736 .34847 Mdot
.736 .34856 Mdot
.736 .3487 Mdot
.736 .34883 Mdot
.736 .34893 Mdot
.736 .34895 Mdot
.736 .34902 Mdot
.736 .34917 Mdot
.736 .34922 Mdot
.736 .34951 Mdot
.736 .34955 Mdot
.736 .34979 Mdot
.736 .35004 Mdot
.736 .35028 Mdot
.736 .35062 Mdot
.736 .35085 Mdot
.736 .35126 Mdot
.736 .35132 Mdot
.736 .3519 Mdot
.736 .35201 Mdot
.736 .35208 Mdot
.736 .35216 Mdot
.736 .35228 Mdot
.736 .35249 Mdot
.736 .35259 Mdot
.736 .35268 Mdot
.736 .35269 Mdot
.736 .35284 Mdot
.736 .35286 Mdot
.736 .35304 Mdot
.736 .35309 Mdot
.736 .35319 Mdot
.736 .35324 Mdot
.736 .35334 Mdot
.736 .35337 Mdot
.736 .35342 Mdot
.736 .35363 Mdot
.736 .35364 Mdot
.736 .35371 Mdot
.736 .35429 Mdot
.736 .35452 Mdot
.736 .35456 Mdot
.736 .3547 Mdot
.736 .35478 Mdot
.736 .3549 Mdot
.736 .35502 Mdot
.736 .3551 Mdot
.736 .35551 Mdot
.736 .35559 Mdot
.736 .35577 Mdot
.736 .35611 Mdot
.736 .35612 Mdot
.736 .35622 Mdot
.736 .35623 Mdot
.736 .35633 Mdot
.736 .3567 Mdot
.736 .3568 Mdot
.736 .35687 Mdot
.736 .35689 Mdot
.736 .35695 Mdot
.736 .35702 Mdot
.736 .35741 Mdot
.736 .35761 Mdot
.736 .35771 Mdot
.736 .35771 Mdot
.736 .35782 Mdot
.736 .35792 Mdot
.736 .35796 Mdot
.736 .35803 Mdot
.736 .35809 Mdot
.736 .35813 Mdot
.736 .35814 Mdot
.736 .35817 Mdot
.736 .35824 Mdot
.736 .35827 Mdot
.736 .3584 Mdot
.736 .35842 Mdot
.736 .35865 Mdot
.736 .35902 Mdot
.736 .35921 Mdot
.736 .35924 Mdot
.736 .35959 Mdot
.736 .35978 Mdot
.736 .35982 Mdot
.736 .35987 Mdot
.736 .35994 Mdot
.736 .36003 Mdot
.736 .36005 Mdot
.736 .36017 Mdot
.736 .36018 Mdot
.736 .3602 Mdot
.736 .3603 Mdot
.736 .36034 Mdot
.736 .36061 Mdot
.736 .3608 Mdot
.736 .36098 Mdot
.736 .3612 Mdot
.736 .36129 Mdot
.736 .3615 Mdot
.736 .36172 Mdot
.736 .36205 Mdot
.736 .36214 Mdot
.736 .3623 Mdot
.736 .36233 Mdot
.736 .36238 Mdot
.736 .36238 Mdot
.736 .3624 Mdot
.736 .36243 Mdot
.736 .3625 Mdot
.736 .36262 Mdot
.736 .36279 Mdot
.736 .36314 Mdot
.736 .36318 Mdot
.736 .36327 Mdot
.736 .36332 Mdot
.736 .36338 Mdot
.736 .36352 Mdot
.736 .36369 Mdot
.736 .3638 Mdot
.736 .36393 Mdot
.736 .36423 Mdot
.736 .3643 Mdot
.736 .36432 Mdot
.736 .36436 Mdot
.736 .3644 Mdot
.736 .36453 Mdot
.736 .36469 Mdot
.736 .36471 Mdot
.736 .36475 Mdot
.736 .36477 Mdot
.736 .36499 Mdot
.736 .36519 Mdot
.736 .36526 Mdot
.736 .36527 Mdot
.736 .36533 Mdot
.736 .36544 Mdot
.736 .36564 Mdot
.736 .36584 Mdot
.736 .36614 Mdot
.736 .36628 Mdot
.736 .36641 Mdot
.736 .36653 Mdot
.736 .36654 Mdot
.736 .36658 Mdot
.736 .36672 Mdot
.736 .36687 Mdot
.736 .36691 Mdot
.736 .36703 Mdot
.736 .36712 Mdot
.736 .36714 Mdot
.736 .36718 Mdot
.736 .36724 Mdot
.736 .36753 Mdot
.736 .36781 Mdot
.736 .36785 Mdot
.736 .36789 Mdot
.736 .36795 Mdot
.736 .36798 Mdot
.736 .36821 Mdot
.736 .36833 Mdot
.736 .36841 Mdot
.736 .36846 Mdot
.736 .36849 Mdot
.736 .36853 Mdot
.736 .36855 Mdot
.736 .36866 Mdot
.736 .36894 Mdot
.736 .36909 Mdot
.736 .36929 Mdot
.736 .36944 Mdot
.736 .36957 Mdot
.736 .3697 Mdot
.736 .36988 Mdot
.736 .3699 Mdot
.736 .36999 Mdot
.736 .37007 Mdot
.736 .3702 Mdot
.736 .37026 Mdot
.736 .37065 Mdot
.736 .37078 Mdot
.736 .37103 Mdot
.736 .3712 Mdot
.736 .37129 Mdot
.736 .3713 Mdot
.736 .37135 Mdot
.736 .37137 Mdot
.736 .37138 Mdot
.736 .37145 Mdot
.736 .37149 Mdot
.736 .37159 Mdot
.736 .37167 Mdot
.736 .37173 Mdot
.736 .37187 Mdot
.736 .37213 Mdot
.736 .37222 Mdot
.736 .37228 Mdot
.736 .37235 Mdot
.736 .3726 Mdot
.736 .37268 Mdot
.736 .37275 Mdot
.736 .37298 Mdot
.736 .37311 Mdot
.736 .37344 Mdot
.736 .37366 Mdot
.736 .37371 Mdot
.736 .37381 Mdot
.736 .37399 Mdot
.736 .37439 Mdot
.736 .37443 Mdot
.736 .37444 Mdot
.736 .37458 Mdot
.736 .37462 Mdot
.736 .37463 Mdot
.736 .37474 Mdot
.736 .3748 Mdot
.736 .37484 Mdot
.736 .37497 Mdot
.736 .37507 Mdot
.736 .37508 Mdot
.736 .37514 Mdot
.736 .37521 Mdot
.736 .37543 Mdot
.736 .37549 Mdot
.736 .37553 Mdot
.736 .37561 Mdot
.736 .376 Mdot
.736 .37604 Mdot
.736 .37632 Mdot
.736 .37648 Mdot
.736 .37671 Mdot
.736 .37687 Mdot
.736 .37705 Mdot
.736 .37721 Mdot
.736 .37724 Mdot
.736 .37743 Mdot
.736 .37746 Mdot
.736 .37757 Mdot
.736 .37762 Mdot
.736 .37763 Mdot
.736 .3777 Mdot
.736 .37778 Mdot
.736 .37788 Mdot
.736 .37794 Mdot
.736 .37809 Mdot
.736 .37823 Mdot
.736 .37826 Mdot
.736 .37826 Mdot
.736 .37832 Mdot
.736 .37839 Mdot
.736 .37869 Mdot
.736 .37898 Mdot
.736 .37927 Mdot
.736 .37937 Mdot
.736 .37946 Mdot
.736 .37948 Mdot
.736 .37959 Mdot
.736 .37974 Mdot
.736 .38028 Mdot
.736 .38043 Mdot
.736 .38044 Mdot
.736 .38059 Mdot
.736 .38061 Mdot
.736 .38111 Mdot
.736 .38127 Mdot
.736 .38138 Mdot
.736 .38138 Mdot
.736 .38149 Mdot
.736 .38176 Mdot
.736 .38209 Mdot
.736 .38221 Mdot
.736 .38228 Mdot
.736 .38239 Mdot
.736 .38256 Mdot
.736 .38268 Mdot
.736 .38289 Mdot
.736 .38295 Mdot
.736 .38328 Mdot
.736 .38329 Mdot
.736 .38345 Mdot
.736 .38358 Mdot
.736 .384 Mdot
.736 .38415 Mdot
.736 .38424 Mdot
.736 .38426 Mdot
.736 .38444 Mdot
.736 .38446 Mdot
.736 .38457 Mdot
.736 .38465 Mdot
.736 .38468 Mdot
.736 .38483 Mdot
.736 .38491 Mdot
.736 .38505 Mdot
.736 .38511 Mdot
.736 .38513 Mdot
.736 .38528 Mdot
.736 .38533 Mdot
.736 .38539 Mdot
.736 .38542 Mdot
.736 .38564 Mdot
.736 .38565 Mdot
.736 .38579 Mdot
.736 .38593 Mdot
.736 .38607 Mdot
.736 .38624 Mdot
.736 .38642 Mdot
.736 .38654 Mdot
.736 .38664 Mdot
.736 .38674 Mdot
.736 .38681 Mdot
.736 .38685 Mdot
.736 .38758 Mdot
.736 .38765 Mdot
.736 .38774 Mdot
.736 .38835 Mdot
.736 .38868 Mdot
.736 .38874 Mdot
.736 .38919 Mdot
.736 .38923 Mdot
.736 .38954 Mdot
.736 .3898 Mdot
.736 .38991 Mdot
.736 .39027 Mdot
.736 .39032 Mdot
.736 .39075 Mdot
.736 .39082 Mdot
.736 .39102 Mdot
.736 .39105 Mdot
.736 .39114 Mdot
.736 .39118 Mdot
.736 .39132 Mdot
.736 .39151 Mdot
.736 .39172 Mdot
.736 .39185 Mdot
.736 .39186 Mdot
.736 .39217 Mdot
.736 .39231 Mdot
.736 .39248 Mdot
.736 .39254 Mdot
.736 .39254 Mdot
.736 .39262 Mdot
.736 .39267 Mdot
.736 .39283 Mdot
.736 .39331 Mdot
.736 .39347 Mdot
.736 .39351 Mdot
.736 .39374 Mdot
.736 .3941 Mdot
.736 .39432 Mdot
.736 .39472 Mdot
.736 .39489 Mdot
.736 .39495 Mdot
.736 .3951 Mdot
.736 .39514 Mdot
.736 .39519 Mdot
.736 .39531 Mdot
.736 .39543 Mdot
.736 .39574 Mdot
.736 .39601 Mdot
.736 .39627 Mdot
.736 .3965 Mdot
.736 .39693 Mdot
.736 .39707 Mdot
.736 .39723 Mdot
.736 .39724 Mdot
.736 .39727 Mdot
.736 .3976 Mdot
.736 .39763 Mdot
.736 .39872 Mdot
.736 .39899 Mdot
.736 .39906 Mdot
.736 .39929 Mdot
.736 .39931 Mdot
.736 .39933 Mdot
.736 .39955 Mdot
.736 .39968 Mdot
.736 .39994 Mdot
.736 .40002 Mdot
.736 .40013 Mdot
.736 .40022 Mdot
.736 .40085 Mdot
.736 .40109 Mdot
.736 .40125 Mdot
.736 .40148 Mdot
.736 .4017 Mdot
.736 .40187 Mdot
.736 .40211 Mdot
.736 .40258 Mdot
.736 .40271 Mdot
.736 .40278 Mdot
.736 .40296 Mdot
.736 .40311 Mdot
.736 .40342 Mdot
.736 .40345 Mdot
.736 .40368 Mdot
.736 .40371 Mdot
.736 .40379 Mdot
.736 .40406 Mdot
.736 .40426 Mdot
.736 .40443 Mdot
.736 .40499 Mdot
.736 .40528 Mdot
.736 .4053 Mdot
.736 .4055 Mdot
.736 .40554 Mdot
.736 .40591 Mdot
.736 .40593 Mdot
.736 .40595 Mdot
.736 .40598 Mdot
.736 .40622 Mdot
.736 .40638 Mdot
.736 .40645 Mdot
.736 .40673 Mdot
.736 .40678 Mdot
.736 .40694 Mdot
.736 .40696 Mdot
.736 .40725 Mdot
.736 .40734 Mdot
.736 .40734 Mdot
.736 .40738 Mdot
.736 .40742 Mdot
.736 .40761 Mdot
.736 .40775 Mdot
.736 .40785 Mdot
.736 .40798 Mdot
.736 .40805 Mdot
.736 .40821 Mdot
.736 .40841 Mdot
.736 .40853 Mdot
.736 .40856 Mdot
.736 .40866 Mdot
.736 .40885 Mdot
.736 .40908 Mdot
.736 .40916 Mdot
.736 .40946 Mdot
.736 .40983 Mdot
.736 .40999 Mdot
.736 .41022 Mdot
.736 .41048 Mdot
.736 .4105 Mdot
.736 .41058 Mdot
.736 .41069 Mdot
.736 .41091 Mdot
.736 .41106 Mdot
.736 .41115 Mdot
.736 .41116 Mdot
.736 .41182 Mdot
.736 .41217 Mdot
.736 .41273 Mdot
.736 .41289 Mdot
.736 .41304 Mdot
.736 .41308 Mdot
.736 .41372 Mdot
.736 .41387 Mdot
.736 .41432 Mdot
.736 .4144 Mdot
.736 .41445 Mdot
.736 .41451 Mdot
.736 .41513 Mdot
.736 .41525 Mdot
.736 .41537 Mdot
.736 .41541 Mdot
.736 .41559 Mdot
.736 .41572 Mdot
.736 .41622 Mdot
.736 .41631 Mdot
.736 .41659 Mdot
.736 .41698 Mdot
.736 .41756 Mdot
.736 .41774 Mdot
.736 .41779 Mdot
.736 .418 Mdot
.736 .41856 Mdot
.736 .41868 Mdot
.736 .41921 Mdot
.736 .41961 Mdot
.736 .41967 Mdot
.736 .41975 Mdot
.736 .41977 Mdot
.736 .42017 Mdot
.736 .42019 Mdot
.736 .42025 Mdot
.736 .42046 Mdot
.736 .42053 Mdot
.736 .42085 Mdot
.736 .42125 Mdot
.736 .42141 Mdot
.736 .42171 Mdot
.736 .42198 Mdot
.736 .42202 Mdot
.736 .42225 Mdot
.736 .42267 Mdot
.736 .42287 Mdot
.736 .42298 Mdot
.736 .42307 Mdot
.736 .42335 Mdot
.736 .42348 Mdot
.736 .42348 Mdot
.736 .42365 Mdot
.736 .42376 Mdot
.736 .42412 Mdot
.736 .42414 Mdot
.736 .42443 Mdot
.736 .42482 Mdot
.736 .4249 Mdot
.736 .42515 Mdot
.736 .42517 Mdot
.736 .42543 Mdot
.736 .4255 Mdot
.736 .42558 Mdot
.736 .42608 Mdot
.736 .42676 Mdot
.736 .42686 Mdot
.736 .42689 Mdot
.736 .42701 Mdot
.736 .42717 Mdot
.736 .42733 Mdot
.736 .42814 Mdot
.736 .42822 Mdot
.736 .42848 Mdot
.736 .42858 Mdot
.736 .4287 Mdot
.736 .42903 Mdot
.736 .42913 Mdot
.736 .42922 Mdot
.736 .42949 Mdot
.736 .42975 Mdot
.736 .42986 Mdot
.736 .42995 Mdot
.736 .43027 Mdot
.736 .43041 Mdot
.736 .43062 Mdot
.736 .43101 Mdot
.736 .43157 Mdot
.736 .43183 Mdot
.736 .43206 Mdot
.736 .4326 Mdot
.736 .43293 Mdot
.736 .43299 Mdot
.736 .43329 Mdot
.736 .43364 Mdot
.736 .43366 Mdot
.736 .43374 Mdot
.736 .43403 Mdot
.736 .43404 Mdot
.736 .43425 Mdot
.736 .43444 Mdot
.736 .4345 Mdot
.736 .43457 Mdot
.736 .43504 Mdot
.736 .43528 Mdot
.736 .43546 Mdot
.736 .43551 Mdot
.736 .43606 Mdot
.736 .43657 Mdot
.736 .43687 Mdot
.736 .43691 Mdot
.736 .43746 Mdot
.736 .43761 Mdot
.736 .43772 Mdot
.736 .43812 Mdot
.736 .43815 Mdot
.736 .4382 Mdot
.736 .43836 Mdot
.736 .43852 Mdot
.736 .43866 Mdot
.736 .43895 Mdot
.736 .43902 Mdot
.736 .43944 Mdot
.736 .43951 Mdot
.736 .43965 Mdot
.736 .43968 Mdot
.736 .43972 Mdot
.736 .43994 Mdot
.736 .43998 Mdot
.736 .44011 Mdot
.736 .44041 Mdot
.736 .44076 Mdot
.736 .44091 Mdot
.736 .4412 Mdot
.736 .4414 Mdot
.736 .44148 Mdot
.736 .44172 Mdot
.736 .44201 Mdot
.736 .44214 Mdot
.736 .44222 Mdot
.736 .44231 Mdot
.736 .44231 Mdot
.736 .44237 Mdot
.736 .44249 Mdot
.736 .44286 Mdot
.736 .44313 Mdot
.736 .44316 Mdot
.736 .44334 Mdot
.736 .44351 Mdot
.736 .44362 Mdot
.736 .4437 Mdot
.736 .44422 Mdot
.736 .44422 Mdot
.736 .44438 Mdot
.736 .44473 Mdot
.736 .44523 Mdot
.736 .44524 Mdot
.736 .44531 Mdot
.736 .44535 Mdot
.736 .44541 Mdot
.736 .44551 Mdot
.736 .44568 Mdot
.736 .44605 Mdot
.736 .44621 Mdot
.736 .44628 Mdot
.736 .44638 Mdot
.736 .44673 Mdot
.736 .44677 Mdot
.736 .44706 Mdot
.736 .44712 Mdot
.736 .4474 Mdot
.736 .44762 Mdot
.736 .44768 Mdot
.736 .44785 Mdot
.736 .44844 Mdot
.736 .44862 Mdot
.736 .44889 Mdot
.738 .24287 Mdot
.738 .24308 Mdot
.738 .24325 Mdot
.738 .24356 Mdot
.738 .24357 Mdot
.738 .24381 Mdot
.738 .24385 Mdot
.738 .24451 Mdot
.738 .24509 Mdot
.738 .24511 Mdot
.738 .24573 Mdot
.738 .24573 Mdot
.738 .24592 Mdot
.738 .24617 Mdot
.738 .24625 Mdot
.738 .24632 Mdot
.738 .24652 Mdot
.738 .24655 Mdot
.738 .24677 Mdot
.738 .24726 Mdot
.738 .24741 Mdot
.738 .24751 Mdot
.738 .24804 Mdot
.738 .24812 Mdot
.738 .24823 Mdot
.738 .24859 Mdot
.738 .24872 Mdot
.738 .2488 Mdot
.738 .24916 Mdot
.738 .24927 Mdot
.738 .24936 Mdot
.738 .24941 Mdot
.738 .2495 Mdot
.738 .24996 Mdot
.738 .25021 Mdot
.738 .25023 Mdot
.738 .25035 Mdot
.738 .25098 Mdot
.738 .25131 Mdot
.738 .25136 Mdot
.738 .25141 Mdot
.738 .25201 Mdot
.738 .25365 Mdot
.738 .25377 Mdot
.738 .25393 Mdot
.738 .25403 Mdot
.738 .25508 Mdot
.738 .2552 Mdot
.738 .2552 Mdot
.738 .2555 Mdot
.738 .25552 Mdot
.738 .25558 Mdot
.738 .2556 Mdot
.738 .25561 Mdot
.738 .25613 Mdot
.738 .25686 Mdot
.738 .25791 Mdot
.738 .25791 Mdot
.738 .2585 Mdot
.738 .2586 Mdot
.738 .25879 Mdot
.738 .25935 Mdot
.738 .25944 Mdot
.738 .26019 Mdot
.738 .26033 Mdot
.738 .26043 Mdot
.738 .26073 Mdot
.738 .26108 Mdot
.738 .26193 Mdot
.738 .26229 Mdot
.738 .2626 Mdot
.738 .26287 Mdot
.738 .263 Mdot
.738 .26326 Mdot
.738 .26358 Mdot
.738 .26365 Mdot
.738 .26374 Mdot
.738 .26422 Mdot
.738 .26431 Mdot
.738 .26432 Mdot
.738 .26438 Mdot
.738 .26456 Mdot
.738 .26462 Mdot
.738 .26472 Mdot
.738 .26555 Mdot
.738 .26565 Mdot
.738 .26572 Mdot
.738 .26575 Mdot
.738 .26576 Mdot
.738 .26576 Mdot
.738 .26602 Mdot
.738 .267 Mdot
.738 .26701 Mdot
.738 .26718 Mdot
.738 .26768 Mdot
.738 .26791 Mdot
.738 .26807 Mdot
.738 .26818 Mdot
.738 .26832 Mdot
.738 .26937 Mdot
.738 .26941 Mdot
.738 .27006 Mdot
.738 .27008 Mdot
.738 .27017 Mdot
.738 .27045 Mdot
.738 .27055 Mdot
.738 .2712 Mdot
.738 .27144 Mdot
.738 .27156 Mdot
.738 .27261 Mdot
.738 .27261 Mdot
.738 .273 Mdot
.738 .27328 Mdot
.738 .27329 Mdot
.738 .27343 Mdot
.738 .27365 Mdot
.738 .27371 Mdot
.738 .27389 Mdot
.738 .27393 Mdot
.738 .27419 Mdot
.738 .27448 Mdot
.738 .27464 Mdot
.738 .27532 Mdot
.738 .27636 Mdot
.738 .27762 Mdot
.738 .27764 Mdot
.738 .27789 Mdot
.738 .27824 Mdot
.738 .27867 Mdot
.738 .27881 Mdot
.738 .27897 Mdot
.738 .27917 Mdot
.738 .27994 Mdot
.738 .28012 Mdot
.738 .28132 Mdot
.738 .28135 Mdot
.738 .28159 Mdot
.738 .28249 Mdot
.738 .2827 Mdot
.738 .28278 Mdot
.738 .28304 Mdot
.738 .28354 Mdot
.738 .28383 Mdot
.738 .28384 Mdot
.738 .28461 Mdot
.738 .28485 Mdot
.738 .28529 Mdot
.738 .28529 Mdot
.738 .28537 Mdot
.738 .28634 Mdot
.738 .28687 Mdot
.738 .28765 Mdot
.738 .28796 Mdot
.738 .28845 Mdot
.738 .28852 Mdot
.738 .28864 Mdot
.738 .28866 Mdot
.738 .28868 Mdot
.738 .28874 Mdot
.738 .289 Mdot
.738 .28914 Mdot
.738 .2895 Mdot
.738 .29022 Mdot
.738 .29053 Mdot
.738 .29089 Mdot
.738 .29089 Mdot
.738 .29192 Mdot
.738 .29204 Mdot
.738 .29259 Mdot
.738 .29362 Mdot
.738 .29373 Mdot
.738 .29374 Mdot
.738 .29432 Mdot
.738 .2948 Mdot
.738 .29518 Mdot
.738 .29531 Mdot
.738 .29554 Mdot
.738 .29556 Mdot
.738 .29566 Mdot
.738 .29586 Mdot
.738 .29604 Mdot
.738 .29604 Mdot
.738 .29669 Mdot
.738 .29699 Mdot
.738 .29703 Mdot
.738 .29751 Mdot
.738 .2982 Mdot
.738 .29907 Mdot
.738 .29919 Mdot
.738 .2992 Mdot
.738 .29928 Mdot
.738 .29971 Mdot
.738 .29974 Mdot
.738 .29985 Mdot
.738 .29985 Mdot
.738 .29989 Mdot
.738 .30033 Mdot
.738 .30045 Mdot
.738 .30064 Mdot
.738 .30094 Mdot
.738 .30133 Mdot
.738 .30149 Mdot
.738 .30168 Mdot
.738 .30209 Mdot
.738 .30213 Mdot
.738 .30239 Mdot
.738 .30252 Mdot
.738 .30409 Mdot
.738 .30457 Mdot
.738 .30462 Mdot
.738 .30469 Mdot
.738 .30474 Mdot
.738 .30577 Mdot
.738 .30579 Mdot
.738 .30582 Mdot
.738 .30597 Mdot
.738 .30632 Mdot
.738 .30644 Mdot
.738 .3068 Mdot
.738 .30701 Mdot
.738 .30728 Mdot
.738 .30732 Mdot
.738 .30756 Mdot
.738 .30768 Mdot
.738 .30802 Mdot
.738 .30811 Mdot
.738 .30838 Mdot
.738 .30926 Mdot
.738 .30937 Mdot
.738 .30938 Mdot
.738 .3097 Mdot
.738 .3098 Mdot
.738 .30988 Mdot
.738 .31015 Mdot
.738 .31045 Mdot
.738 .31072 Mdot
.738 .31073 Mdot
.738 .31101 Mdot
.738 .3111 Mdot
.738 .31121 Mdot
.738 .31125 Mdot
.738 .31139 Mdot
.738 .31149 Mdot
.738 .31179 Mdot
.738 .31216 Mdot
.738 .31233 Mdot
.738 .31242 Mdot
.738 .31264 Mdot
.738 .31268 Mdot
.738 .3127 Mdot
.738 .31274 Mdot
.738 .31308 Mdot
.738 .31313 Mdot
.738 .31389 Mdot
.738 .31536 Mdot
.738 .31536 Mdot
.738 .3155 Mdot
.738 .31551 Mdot
.738 .31553 Mdot
.738 .31554 Mdot
.738 .31555 Mdot
.738 .31579 Mdot
.738 .31612 Mdot
.738 .3166 Mdot
.738 .3166 Mdot
.738 .31692 Mdot
.738 .31765 Mdot
.738 .31776 Mdot
.738 .31862 Mdot
.738 .31888 Mdot
.738 .31921 Mdot
.738 .31924 Mdot
.738 .31928 Mdot
.738 .31957 Mdot
.738 .31973 Mdot
.738 .32016 Mdot
.738 .32021 Mdot
.738 .32021 Mdot
.738 .32078 Mdot
.738 .32078 Mdot
.738 .32086 Mdot
.738 .32109 Mdot
.738 .32127 Mdot
.738 .32132 Mdot
.738 .32138 Mdot
.738 .32186 Mdot
.738 .32218 Mdot
.738 .32219 Mdot
.738 .32223 Mdot
.738 .32282 Mdot
.738 .32287 Mdot
.738 .32366 Mdot
.738 .32366 Mdot
.738 .32394 Mdot
.738 .32396 Mdot
.738 .32428 Mdot
.738 .32594 Mdot
.738 .32613 Mdot
.738 .3262 Mdot
.738 .32627 Mdot
.738 .32636 Mdot
.738 .32672 Mdot
.738 .32736 Mdot
.738 .32789 Mdot
.738 .32798 Mdot
.738 .32802 Mdot
.738 .32814 Mdot
.738 .32837 Mdot
.738 .32897 Mdot
.738 .32917 Mdot
.738 .32921 Mdot
.738 .32965 Mdot
.738 .33062 Mdot
.738 .33072 Mdot
.738 .3311 Mdot
.738 .33158 Mdot
.738 .33174 Mdot
.738 .33221 Mdot
.738 .33227 Mdot
.738 .333 Mdot
.738 .33305 Mdot
.738 .33332 Mdot
.738 .33354 Mdot
.738 .33371 Mdot
.738 .33377 Mdot
.738 .33388 Mdot
.738 .33389 Mdot
.738 .33393 Mdot
.738 .3344 Mdot
.738 .33456 Mdot
.738 .3351 Mdot
.738 .3355 Mdot
.738 .3356 Mdot
.738 .33579 Mdot
.738 .3358 Mdot
.738 .33586 Mdot
.738 .33587 Mdot
.738 .33608 Mdot
.738 .33613 Mdot
.738 .33622 Mdot
.738 .33654 Mdot
.738 .33688 Mdot
.738 .33702 Mdot
.738 .33708 Mdot
.738 .33802 Mdot
.738 .33857 Mdot
.738 .33858 Mdot
.738 .33859 Mdot
.738 .33866 Mdot
.738 .33883 Mdot
.738 .33888 Mdot
.738 .33905 Mdot
.738 .33914 Mdot
.738 .33928 Mdot
.738 .3394 Mdot
.738 .3396 Mdot
.738 .33965 Mdot
.738 .33977 Mdot
.738 .34018 Mdot
.738 .34023 Mdot
.738 .34038 Mdot
.738 .34046 Mdot
.738 .34085 Mdot
.738 .34085 Mdot
.738 .34098 Mdot
.738 .34102 Mdot
.738 .34107 Mdot
.738 .34109 Mdot
.738 .3412 Mdot
.738 .34133 Mdot
.738 .34158 Mdot
.738 .34163 Mdot
.738 .34173 Mdot
.738 .34174 Mdot
.738 .34193 Mdot
.738 .34195 Mdot
.738 .3423 Mdot
.738 .34297 Mdot
.738 .34297 Mdot
.738 .34304 Mdot
.738 .34305 Mdot
.738 .34306 Mdot
.738 .34306 Mdot
.738 .34317 Mdot
.738 .34332 Mdot
.738 .34355 Mdot
.738 .34355 Mdot
.738 .34369 Mdot
.738 .34403 Mdot
.738 .34447 Mdot
.738 .34459 Mdot
.738 .34474 Mdot
.738 .34477 Mdot
.738 .34498 Mdot
.738 .34518 Mdot
.738 .3452 Mdot
.738 .34546 Mdot
.738 .3456 Mdot
.738 .34571 Mdot
.738 .34613 Mdot
.738 .34642 Mdot
.738 .34691 Mdot
.738 .34692 Mdot
.738 .34707 Mdot
.738 .34792 Mdot
.738 .34798 Mdot
.738 .34802 Mdot
.738 .34848 Mdot
.738 .34873 Mdot
.738 .34877 Mdot
.738 .34879 Mdot
.738 .34954 Mdot
.738 .3502 Mdot
.738 .35042 Mdot
.738 .35049 Mdot
.738 .35071 Mdot
.738 .35074 Mdot
.738 .35109 Mdot
.738 .3514 Mdot
.738 .35143 Mdot
.738 .35147 Mdot
.738 .3515 Mdot
.738 .35179 Mdot
.738 .35203 Mdot
.738 .35226 Mdot
.738 .35235 Mdot
.738 .35236 Mdot
.738 .35248 Mdot
.738 .35251 Mdot
.738 .35255 Mdot
.738 .35269 Mdot
.738 .35285 Mdot
.738 .35292 Mdot
.738 .35294 Mdot
.738 .35377 Mdot
.738 .35389 Mdot
.738 .35396 Mdot
.738 .35401 Mdot
.738 .3541 Mdot
.738 .35412 Mdot
.738 .35418 Mdot
.738 .35437 Mdot
.738 .35439 Mdot
.738 .35446 Mdot
.738 .35449 Mdot
.738 .35467 Mdot
.738 .35473 Mdot
.738 .35475 Mdot
.738 .35478 Mdot
.738 .3549 Mdot
.738 .35503 Mdot
.738 .35518 Mdot
.738 .35534 Mdot
.738 .35565 Mdot
.738 .35568 Mdot
.738 .35569 Mdot
.738 .35569 Mdot
.738 .35569 Mdot
.738 .35591 Mdot
.738 .35591 Mdot
.738 .35598 Mdot
.738 .35634 Mdot
.738 .35646 Mdot
.738 .35648 Mdot
.738 .35657 Mdot
.738 .35666 Mdot
.738 .35667 Mdot
.738 .35686 Mdot
.738 .35691 Mdot
.738 .35723 Mdot
.738 .35746 Mdot
.738 .35753 Mdot
.738 .35792 Mdot
.738 .35795 Mdot
.738 .35797 Mdot
.738 .35818 Mdot
.738 .35829 Mdot
.738 .35832 Mdot
.738 .3591 Mdot
.738 .35921 Mdot
.738 .35938 Mdot
.738 .35952 Mdot
.738 .35953 Mdot
.738 .35956 Mdot
.738 .35991 Mdot
.738 .35996 Mdot
.738 .36011 Mdot
.738 .36023 Mdot
.738 .36069 Mdot
.738 .36071 Mdot
.738 .36076 Mdot
.738 .36077 Mdot
.738 .36088 Mdot
.738 .36092 Mdot
.738 .36094 Mdot
.738 .36102 Mdot
.738 .36105 Mdot
.738 .36112 Mdot
.738 .36118 Mdot
.738 .36125 Mdot
.738 .36133 Mdot
.738 .36147 Mdot
.738 .36159 Mdot
.738 .36159 Mdot
.738 .36185 Mdot
.738 .36193 Mdot
.738 .36194 Mdot
.738 .3623 Mdot
.738 .36233 Mdot
.738 .36251 Mdot
.738 .36268 Mdot
.738 .36324 Mdot
.738 .36325 Mdot
.738 .36345 Mdot
.738 .36393 Mdot
.738 .36401 Mdot
.738 .36407 Mdot
.738 .36414 Mdot
.738 .36435 Mdot
.738 .3647 Mdot
.738 .36495 Mdot
.738 .36496 Mdot
.738 .36739 Mdot
.738 .36756 Mdot
.738 .3678 Mdot
.738 .36794 Mdot
.738 .36854 Mdot
.738 .36855 Mdot
.738 .36893 Mdot
.738 .36944 Mdot
.738 .36949 Mdot
.738 .36967 Mdot
.738 .36967 Mdot
.738 .36975 Mdot
.738 .36985 Mdot
.738 .36994 Mdot
.738 .37005 Mdot
.738 .37011 Mdot
.738 .37015 Mdot
.738 .37023 Mdot
.738 .37026 Mdot
.738 .37028 Mdot
.738 .37077 Mdot
.738 .37104 Mdot
.738 .37106 Mdot
.738 .37107 Mdot
.738 .3719 Mdot
.738 .37212 Mdot
.738 .37215 Mdot
.738 .37242 Mdot
.738 .37246 Mdot
.738 .373 Mdot
.738 .37301 Mdot
.738 .37313 Mdot
.738 .37351 Mdot
.738 .37351 Mdot
.738 .37366 Mdot
.738 .37367 Mdot
.738 .37369 Mdot
.738 .3739 Mdot
.738 .37401 Mdot
.738 .37411 Mdot
.738 .3742 Mdot
.738 .37431 Mdot
.738 .37435 Mdot
.738 .37447 Mdot
.738 .3745 Mdot
.738 .37455 Mdot
.738 .37456 Mdot
.738 .37469 Mdot
.738 .37473 Mdot
.738 .37474 Mdot
.738 .3748 Mdot
.738 .37484 Mdot
.738 .37497 Mdot
.738 .37553 Mdot
.738 .37569 Mdot
.738 .37579 Mdot
.738 .37592 Mdot
.738 .37593 Mdot
.738 .37599 Mdot
.738 .3765 Mdot
.738 .37655 Mdot
.738 .37657 Mdot
.738 .37678 Mdot
.738 .37702 Mdot
.738 .37704 Mdot
.738 .37719 Mdot
.738 .37724 Mdot
.738 .37738 Mdot
.738 .37783 Mdot
.738 .37834 Mdot
.738 .37835 Mdot
.738 .37838 Mdot
.738 .37855 Mdot
.738 .37886 Mdot
.738 .37889 Mdot
.738 .37893 Mdot
.738 .3795 Mdot
.738 .37961 Mdot
.738 .37961 Mdot
.738 .37994 Mdot
.738 .38014 Mdot
.738 .38043 Mdot
.738 .3805 Mdot
.738 .38059 Mdot
.738 .38077 Mdot
.738 .38079 Mdot
.738 .38092 Mdot
.738 .38106 Mdot
.738 .38108 Mdot
.738 .38118 Mdot
.738 .38127 Mdot
.738 .38157 Mdot
.738 .38179 Mdot
.738 .38189 Mdot
.738 .38189 Mdot
.738 .38204 Mdot
.738 .38215 Mdot
.738 .38222 Mdot
.738 .38222 Mdot
.738 .38223 Mdot
.738 .38223 Mdot
.738 .38228 Mdot
.738 .38228 Mdot
.738 .38274 Mdot
.738 .38297 Mdot
.738 .38299 Mdot
.738 .38311 Mdot
.738 .38313 Mdot
.738 .38319 Mdot
.738 .38322 Mdot
.738 .38339 Mdot
.738 .38348 Mdot
.738 .38356 Mdot
.738 .38357 Mdot
.738 .3836 Mdot
.738 .38363 Mdot
.738 .38372 Mdot
.738 .38372 Mdot
.738 .38399 Mdot
.738 .38404 Mdot
.738 .38414 Mdot
.738 .38418 Mdot
.738 .38445 Mdot
.738 .38454 Mdot
.738 .38456 Mdot
.738 .3847 Mdot
.738 .38478 Mdot
.738 .38488 Mdot
.738 .38494 Mdot
.738 .38505 Mdot
.738 .38509 Mdot
.738 .3852 Mdot
.738 .38525 Mdot
.738 .38525 Mdot
.738 .38526 Mdot
.738 .38564 Mdot
.738 .38627 Mdot
.738 .38631 Mdot
.738 .38641 Mdot
.738 .38664 Mdot
.738 .38686 Mdot
.738 .38692 Mdot
.738 .38695 Mdot
.738 .38709 Mdot
.738 .3871 Mdot
.738 .38714 Mdot
.738 .38715 Mdot
.738 .38728 Mdot
.738 .38735 Mdot
.738 .38762 Mdot
.738 .38798 Mdot
.738 .38809 Mdot
.738 .38841 Mdot
.738 .38844 Mdot
.738 .38844 Mdot
.738 .38851 Mdot
.738 .38856 Mdot
.738 .38867 Mdot
.738 .38882 Mdot
.738 .38901 Mdot
.738 .38904 Mdot
.738 .38953 Mdot
.738 .38957 Mdot
.738 .38989 Mdot
.738 .39 Mdot
.738 .39032 Mdot
.738 .39058 Mdot
.738 .39065 Mdot
.738 .3913 Mdot
.738 .39161 Mdot
.738 .39163 Mdot
.738 .39177 Mdot
.738 .39218 Mdot
.738 .39233 Mdot
.738 .39241 Mdot
.738 .39244 Mdot
.738 .3925 Mdot
.738 .39286 Mdot
.738 .39329 Mdot
.738 .39353 Mdot
.738 .3936 Mdot
.738 .39365 Mdot
.738 .39369 Mdot
.738 .39382 Mdot
.738 .39494 Mdot
.738 .39516 Mdot
.738 .39517 Mdot
.738 .39536 Mdot
.738 .39537 Mdot
.738 .3959 Mdot
.738 .39594 Mdot
.738 .39633 Mdot
.738 .39636 Mdot
.738 .39637 Mdot
.738 .39658 Mdot
.738 .39691 Mdot
.738 .39695 Mdot
.738 .39698 Mdot
.738 .39711 Mdot
.738 .39726 Mdot
.738 .39732 Mdot
.738 .39732 Mdot
.738 .3977 Mdot
.738 .39771 Mdot
.738 .39774 Mdot
.738 .39803 Mdot
.738 .39813 Mdot
.738 .39833 Mdot
.738 .39836 Mdot
.738 .39838 Mdot
.738 .3986 Mdot
.738 .39878 Mdot
.738 .39936 Mdot
.738 .39944 Mdot
.738 .39993 Mdot
.738 .40015 Mdot
.738 .40015 Mdot
.738 .40047 Mdot
.738 .4007 Mdot
.738 .40086 Mdot
.738 .40086 Mdot
.738 .40087 Mdot
.738 .40089 Mdot
.738 .4009 Mdot
.738 .40099 Mdot
.738 .40099 Mdot
.738 .40198 Mdot
.738 .4025 Mdot
.738 .40253 Mdot
.738 .40276 Mdot
.738 .40279 Mdot
.738 .40281 Mdot
.738 .40283 Mdot
.738 .40298 Mdot
.738 .40304 Mdot
.738 .40316 Mdot
.738 .40341 Mdot
.738 .40361 Mdot
.738 .40368 Mdot
.738 .40377 Mdot
.738 .4038 Mdot
.738 .40387 Mdot
.738 .40393 Mdot
.738 .40413 Mdot
.738 .40413 Mdot
.738 .40431 Mdot
.738 .40452 Mdot
.738 .4047 Mdot
.738 .40476 Mdot
.738 .40482 Mdot
.738 .40504 Mdot
.738 .40505 Mdot
.738 .40512 Mdot
.738 .40572 Mdot
.738 .4059 Mdot
.738 .40596 Mdot
.738 .40619 Mdot
.738 .40627 Mdot
.738 .40644 Mdot
.738 .40646 Mdot
.738 .40665 Mdot
.738 .40679 Mdot
.738 .40703 Mdot
.738 .40711 Mdot
.738 .40735 Mdot
.738 .40745 Mdot
.738 .40747 Mdot
.738 .40748 Mdot
.738 .40822 Mdot
.738 .40827 Mdot
.738 .4083 Mdot
.738 .40863 Mdot
.738 .40969 Mdot
.738 .40978 Mdot
.738 .40995 Mdot
.738 .40998 Mdot
.738 .41026 Mdot
.738 .41038 Mdot
.738 .41049 Mdot
.738 .41076 Mdot
.738 .41096 Mdot
.738 .41109 Mdot
.738 .41117 Mdot
.738 .41147 Mdot
.738 .4115 Mdot
.738 .4115 Mdot
.738 .41157 Mdot
.738 .41159 Mdot
.738 .41188 Mdot
.738 .41194 Mdot
.738 .41195 Mdot
.738 .41203 Mdot
.738 .41262 Mdot
.738 .41308 Mdot
.738 .4134 Mdot
.738 .41344 Mdot
.738 .41364 Mdot
.738 .41408 Mdot
.738 .41408 Mdot
.738 .4142 Mdot
.738 .41433 Mdot
.738 .4144 Mdot
.738 .41442 Mdot
.738 .41457 Mdot
.738 .41466 Mdot
.738 .41492 Mdot
.738 .41524 Mdot
.738 .41564 Mdot
.738 .41564 Mdot
.738 .41572 Mdot
.738 .41641 Mdot
.738 .41679 Mdot
.738 .41687 Mdot
.738 .41757 Mdot
.738 .41757 Mdot
.738 .41781 Mdot
.738 .41802 Mdot
.738 .41851 Mdot
.738 .41876 Mdot
.738 .41885 Mdot
.738 .41903 Mdot
.738 .41906 Mdot
.738 .41908 Mdot
.738 .41909 Mdot
.738 .41917 Mdot
.738 .41922 Mdot
.738 .41955 Mdot
.738 .41976 Mdot
.738 .42029 Mdot
.738 .42065 Mdot
.738 .42131 Mdot
.738 .42136 Mdot
.738 .42136 Mdot
.738 .42166 Mdot
.738 .42182 Mdot
.738 .42234 Mdot
.738 .42235 Mdot
.738 .42255 Mdot
.738 .42289 Mdot
.738 .42306 Mdot
.738 .42312 Mdot
.738 .42326 Mdot
.738 .42387 Mdot
.738 .42403 Mdot
.738 .42405 Mdot
.738 .42486 Mdot
.738 .42498 Mdot
.738 .42551 Mdot
.738 .42564 Mdot
.738 .42575 Mdot
.738 .42585 Mdot
.738 .42614 Mdot
.738 .42638 Mdot
.738 .42655 Mdot
.738 .42656 Mdot
.738 .42741 Mdot
.738 .42812 Mdot
.738 .42858 Mdot
.738 .42868 Mdot
.738 .42888 Mdot
.738 .42906 Mdot
.738 .42908 Mdot
.738 .42921 Mdot
.738 .42925 Mdot
.738 .42939 Mdot
.738 .42949 Mdot
.738 .4295 Mdot
.738 .42969 Mdot
.738 .42995 Mdot
.738 .42995 Mdot
.738 .43066 Mdot
.738 .43074 Mdot
.738 .4309 Mdot
.738 .43135 Mdot
.738 .43142 Mdot
.738 .43161 Mdot
.738 .43167 Mdot
.738 .43168 Mdot
.738 .43212 Mdot
.738 .43215 Mdot
.738 .43286 Mdot
.738 .43296 Mdot
.738 .43302 Mdot
.738 .43313 Mdot
.738 .43329 Mdot
.738 .43363 Mdot
.738 .43375 Mdot
.738 .43375 Mdot
.738 .43442 Mdot
.738 .43459 Mdot
.738 .43459 Mdot
.738 .4346 Mdot
.738 .43462 Mdot
.738 .43467 Mdot
.738 .43474 Mdot
.738 .4353 Mdot
.738 .43537 Mdot
.738 .43541 Mdot
.738 .43553 Mdot
.738 .43557 Mdot
.738 .43558 Mdot
.738 .43563 Mdot
.738 .43596 Mdot
.738 .43602 Mdot
.738 .43607 Mdot
.738 .43629 Mdot
.738 .43646 Mdot
.738 .43655 Mdot
.738 .43673 Mdot
.738 .43694 Mdot
.738 .43718 Mdot
.738 .43776 Mdot
.738 .438 Mdot
.738 .43821 Mdot
.738 .43828 Mdot
.738 .43837 Mdot
.738 .43888 Mdot
.738 .43894 Mdot
.738 .43932 Mdot
.738 .43944 Mdot
.738 .43951 Mdot
.738 .43991 Mdot
.738 .43991 Mdot
.738 .44062 Mdot
.738 .44112 Mdot
.738 .44147 Mdot
.738 .44148 Mdot
.738 .44149 Mdot
.738 .44153 Mdot
.738 .44155 Mdot
.738 .44175 Mdot
.738 .44175 Mdot
.738 .44183 Mdot
.738 .44254 Mdot
.738 .44261 Mdot
.738 .44271 Mdot
.738 .4428 Mdot
.738 .44391 Mdot
.738 .44432 Mdot
.738 .44435 Mdot
.738 .44438 Mdot
.738 .44461 Mdot
.738 .44503 Mdot
.738 .44512 Mdot
.738 .44513 Mdot
.738 .4453 Mdot
.738 .44561 Mdot
.738 .44567 Mdot
.738 .44571 Mdot
.738 .44576 Mdot
.738 .44584 Mdot
.738 .44608 Mdot
.738 .44614 Mdot
.738 .44623 Mdot
.738 .44647 Mdot
.738 .44655 Mdot
.738 .4466 Mdot
.738 .44696 Mdot
.738 .44702 Mdot
.738 .44713 Mdot
.738 .44746 Mdot
.738 .44761 Mdot
.738 .44763 Mdot
.738 .44776 Mdot
.738 .44781 Mdot
.738 .44787 Mdot
.738 .44803 Mdot
.738 .44817 Mdot
.738 .44817 Mdot
.738 .44858 Mdot
.738 .4486 Mdot
.738 .44899 Mdot
.738 .44944 Mdot
.738 .44947 Mdot
.738 .44963 Mdot
.738 .44964 Mdot
.738 .44984 Mdot
.738 .44996 Mdot
.738 .4501 Mdot
.74 .24182 Mdot
.74 .24211 Mdot
.74 .24214 Mdot
.74 .24282 Mdot
.74 .2436 Mdot
.74 .24371 Mdot
.74 .24401 Mdot
.74 .24459 Mdot
.74 .24489 Mdot
.74 .24492 Mdot
.74 .24511 Mdot
.74 .24555 Mdot
.74 .24571 Mdot
.74 .24661 Mdot
.74 .2468 Mdot
.74 .24698 Mdot
.74 .24726 Mdot
.74 .24754 Mdot
.74 .24768 Mdot
.74 .24894 Mdot
.74 .24929 Mdot
.74 .25005 Mdot
.74 .2503 Mdot
.74 .2503 Mdot
.74 .25031 Mdot
.74 .25059 Mdot
.74 .25081 Mdot
.74 .25137 Mdot
.74 .25177 Mdot
.74 .25228 Mdot
.74 .2525 Mdot
.74 .25287 Mdot
.74 .25289 Mdot
.74 .25302 Mdot
.74 .2532 Mdot
.74 .2535 Mdot
.74 .25352 Mdot
.74 .25394 Mdot
.74 .25421 Mdot
.74 .25493 Mdot
.74 .25554 Mdot
.74 .25602 Mdot
.74 .25605 Mdot
.74 .25606 Mdot
.74 .25609 Mdot
.74 .25614 Mdot
.74 .25671 Mdot
.74 .25675 Mdot
.74 .25689 Mdot
.74 .2571 Mdot
.74 .25787 Mdot
.74 .25795 Mdot
.74 .25953 Mdot
.74 .25995 Mdot
.74 .26058 Mdot
.74 .26067 Mdot
.74 .26113 Mdot
.74 .26163 Mdot
.74 .2621 Mdot
.74 .26212 Mdot
.74 .26231 Mdot
.74 .26338 Mdot
.74 .2644 Mdot
.74 .26472 Mdot
.74 .2648 Mdot
.74 .26481 Mdot
.74 .26529 Mdot
.74 .26546 Mdot
.74 .26556 Mdot
.74 .26587 Mdot
.74 .26593 Mdot
.74 .26604 Mdot
.74 .26624 Mdot
.74 .2663 Mdot
.74 .26677 Mdot
.74 .26681 Mdot
.74 .26691 Mdot
.74 .26699 Mdot
.74 .267 Mdot
.74 .26701 Mdot
.74 .26784 Mdot
.74 .26802 Mdot
.74 .26805 Mdot
.74 .2681 Mdot
.74 .2683 Mdot
.74 .26877 Mdot
.74 .26905 Mdot
.74 .26908 Mdot
.74 .26924 Mdot
.74 .26924 Mdot
.74 .26955 Mdot
.74 .27118 Mdot
.74 .27134 Mdot
.74 .27195 Mdot
.74 .27216 Mdot
.74 .27287 Mdot
.74 .27294 Mdot
.74 .27342 Mdot
.74 .27356 Mdot
.74 .27376 Mdot
.74 .27394 Mdot
.74 .27438 Mdot
.74 .27442 Mdot
.74 .27452 Mdot
.74 .27568 Mdot
.74 .27579 Mdot
.74 .27607 Mdot
.74 .27628 Mdot
.74 .27635 Mdot
.74 .27647 Mdot
.74 .27678 Mdot
.74 .27688 Mdot
.74 .27717 Mdot
.74 .27765 Mdot
.74 .27865 Mdot
.74 .27906 Mdot
.74 .27926 Mdot
.74 .27937 Mdot
.74 .2795 Mdot
.74 .27976 Mdot
.74 .27988 Mdot
.74 .27991 Mdot
.74 .28068 Mdot
.74 .28113 Mdot
.74 .28165 Mdot
.74 .28165 Mdot
.74 .28166 Mdot
.74 .28205 Mdot
.74 .28271 Mdot
.74 .28292 Mdot
.74 .28373 Mdot
.74 .28394 Mdot
.74 .28436 Mdot
.74 .2844 Mdot
.74 .28481 Mdot
.74 .28516 Mdot
.74 .28527 Mdot
.74 .28534 Mdot
.74 .28547 Mdot
.74 .28548 Mdot
.74 .28574 Mdot
.74 .28577 Mdot
.74 .28587 Mdot
.74 .28588 Mdot
.74 .28663 Mdot
.74 .28679 Mdot
.74 .28688 Mdot
.74 .28699 Mdot
.74 .28699 Mdot
.74 .28721 Mdot
.74 .28746 Mdot
.74 .28765 Mdot
.74 .28772 Mdot
.74 .28776 Mdot
.74 .28785 Mdot
.74 .28787 Mdot
.74 .28806 Mdot
.74 .28808 Mdot
.74 .28826 Mdot
.74 .28828 Mdot
.74 .28837 Mdot
.74 .28839 Mdot
.74 .2884 Mdot
.74 .28841 Mdot
.74 .28845 Mdot
.74 .28845 Mdot
.74 .28864 Mdot
.74 .28868 Mdot
.74 .28874 Mdot
.74 .28909 Mdot
.74 .28913 Mdot
.74 .2892 Mdot
.74 .28954 Mdot
.74 .28959 Mdot
.74 .2896 Mdot
.74 .28979 Mdot
.74 .28987 Mdot
.74 .29003 Mdot
.74 .29022 Mdot
.74 .29023 Mdot
.74 .29043 Mdot
.74 .29099 Mdot
.74 .29147 Mdot
.74 .29147 Mdot
.74 .29147 Mdot
.74 .29171 Mdot
.74 .29192 Mdot
.74 .29227 Mdot
.74 .29228 Mdot
.74 .29246 Mdot
.74 .29251 Mdot
.74 .29266 Mdot
.74 .29284 Mdot
.74 .2937 Mdot
.74 .29389 Mdot
.74 .29392 Mdot
.74 .29402 Mdot
.74 .29415 Mdot
.74 .2942 Mdot
.74 .29477 Mdot
.74 .29479 Mdot
.74 .29508 Mdot
.74 .29523 Mdot
.74 .29548 Mdot
.74 .29625 Mdot
.74 .29714 Mdot
.74 .29721 Mdot
.74 .29722 Mdot
.74 .29735 Mdot
.74 .29768 Mdot
.74 .2977 Mdot
.74 .29778 Mdot
.74 .29816 Mdot
.74 .29816 Mdot
.74 .29825 Mdot
.74 .2986 Mdot
.74 .29865 Mdot
.74 .29868 Mdot
.74 .29882 Mdot
.74 .29916 Mdot
.74 .2992 Mdot
.74 .30039 Mdot
.74 .30084 Mdot
.74 .30105 Mdot
.74 .30109 Mdot
.74 .30138 Mdot
.74 .30229 Mdot
.74 .30233 Mdot
.74 .30278 Mdot
.74 .30284 Mdot
.74 .30286 Mdot
.74 .30312 Mdot
.74 .30314 Mdot
.74 .30316 Mdot
.74 .30317 Mdot
.74 .30367 Mdot
.74 .30431 Mdot
.74 .30454 Mdot
.74 .3046 Mdot
.74 .30511 Mdot
.74 .3053 Mdot
.74 .30565 Mdot
.74 .30578 Mdot
.74 .3059 Mdot
.74 .30698 Mdot
.74 .30704 Mdot
.74 .3073 Mdot
.74 .30788 Mdot
.74 .30815 Mdot
.74 .30824 Mdot
.74 .30826 Mdot
.74 .30839 Mdot
.74 .30866 Mdot
.74 .30884 Mdot
.74 .30974 Mdot
.74 .30987 Mdot
.74 .30988 Mdot
.74 .31019 Mdot
.74 .3106 Mdot
.74 .31144 Mdot
.74 .31192 Mdot
.74 .31201 Mdot
.74 .31222 Mdot
.74 .31299 Mdot
.74 .31315 Mdot
.74 .31361 Mdot
.74 .31361 Mdot
.74 .31384 Mdot
.74 .31451 Mdot
.74 .31461 Mdot
.74 .31478 Mdot
.74 .31493 Mdot
.74 .31507 Mdot
.74 .31527 Mdot
.74 .31539 Mdot
.74 .316 Mdot
.74 .31624 Mdot
.74 .31671 Mdot
.74 .31782 Mdot
.74 .31878 Mdot
.74 .31899 Mdot
.74 .31909 Mdot
.74 .31958 Mdot
.74 .32004 Mdot
.74 .32023 Mdot
.74 .32045 Mdot
.74 .32053 Mdot
.74 .32088 Mdot
.74 .32091 Mdot
.74 .32113 Mdot
.74 .32119 Mdot
.74 .32123 Mdot
.74 .32173 Mdot
.74 .32183 Mdot
.74 .32225 Mdot
.74 .3224 Mdot
.74 .32321 Mdot
.74 .32349 Mdot
.74 .32359 Mdot
.74 .32394 Mdot
.74 .32423 Mdot
.74 .3244 Mdot
.74 .32467 Mdot
.74 .32555 Mdot
.74 .32574 Mdot
.74 .32587 Mdot
.74 .32609 Mdot
.74 .32683 Mdot
.74 .32706 Mdot
.74 .3281 Mdot
.74 .3285 Mdot
.74 .32887 Mdot
.74 .32957 Mdot
.74 .32967 Mdot
.74 .32967 Mdot
.74 .32985 Mdot
.74 .33013 Mdot
.74 .33036 Mdot
.74 .33036 Mdot
.74 .33046 Mdot
.74 .33057 Mdot
.74 .33069 Mdot
.74 .33076 Mdot
.74 .33085 Mdot
.74 .33085 Mdot
.74 .331 Mdot
.74 .33102 Mdot
.74 .33115 Mdot
.74 .33137 Mdot
.74 .33155 Mdot
.74 .33183 Mdot
.74 .33184 Mdot
.74 .3324 Mdot
.74 .33277 Mdot
.74 .33285 Mdot
.74 .33288 Mdot
.74 .33294 Mdot
.74 .33303 Mdot
.74 .33342 Mdot
.74 .33357 Mdot
.74 .33502 Mdot
.74 .33509 Mdot
.74 .33524 Mdot
.74 .33525 Mdot
.74 .33528 Mdot
.74 .33546 Mdot
.74 .3355 Mdot
.74 .33568 Mdot
.74 .33576 Mdot
.74 .33592 Mdot
.74 .33593 Mdot
.74 .33678 Mdot
.74 .3368 Mdot
.74 .33693 Mdot
.74 .33736 Mdot
.74 .33757 Mdot
.74 .33759 Mdot
.74 .3376 Mdot
.74 .33772 Mdot
.74 .33797 Mdot
.74 .33837 Mdot
.74 .3384 Mdot
.74 .33863 Mdot
.74 .33888 Mdot
.74 .33894 Mdot
.74 .33899 Mdot
.74 .34006 Mdot
.74 .34007 Mdot
.74 .34025 Mdot
.74 .3408 Mdot
.74 .34081 Mdot
.74 .34095 Mdot
.74 .34114 Mdot
.74 .34152 Mdot
.74 .34178 Mdot
.74 .34188 Mdot
.74 .3423 Mdot
.74 .34251 Mdot
.74 .34297 Mdot
.74 .34318 Mdot
.74 .34327 Mdot
.74 .34393 Mdot
.74 .34443 Mdot
.74 .34524 Mdot
.74 .34553 Mdot
.74 .34567 Mdot
.74 .34584 Mdot
.74 .34594 Mdot
.74 .34599 Mdot
.74 .34622 Mdot
.74 .34626 Mdot
.74 .3469 Mdot
.74 .34702 Mdot
.74 .34707 Mdot
.74 .34736 Mdot
.74 .34756 Mdot
.74 .34796 Mdot
.74 .34811 Mdot
.74 .34855 Mdot
.74 .34865 Mdot
.74 .34913 Mdot
.74 .34931 Mdot
.74 .34948 Mdot
.74 .3498 Mdot
.74 .34984 Mdot
.74 .34992 Mdot
.74 .35005 Mdot
.74 .3502 Mdot
.74 .35026 Mdot
.74 .35038 Mdot
.74 .35038 Mdot
.74 .35045 Mdot
.74 .35046 Mdot
.74 .35052 Mdot
.74 .3507 Mdot
.74 .35083 Mdot
.74 .35083 Mdot
.74 .35126 Mdot
.74 .35131 Mdot
.74 .35162 Mdot
.74 .35229 Mdot
.74 .35232 Mdot
.74 .3525 Mdot
.74 .35269 Mdot
.74 .3527 Mdot
.74 .35309 Mdot
.74 .35345 Mdot
.74 .35346 Mdot
.74 .35363 Mdot
.74 .35382 Mdot
.74 .35405 Mdot
.74 .35407 Mdot
.74 .35493 Mdot
.74 .35493 Mdot
.74 .35508 Mdot
.74 .35525 Mdot
.74 .35537 Mdot
.74 .35542 Mdot
.74 .35561 Mdot
.74 .35571 Mdot
.74 .35591 Mdot
.74 .35605 Mdot
.74 .35635 Mdot
.74 .35658 Mdot
.74 .35695 Mdot
.74 .35715 Mdot
.74 .35723 Mdot
.74 .3574 Mdot
.74 .35742 Mdot
.74 .35771 Mdot
.74 .35779 Mdot
.74 .35792 Mdot
.74 .35801 Mdot
.74 .3582 Mdot
.74 .35846 Mdot
.74 .35851 Mdot
.74 .35889 Mdot
.74 .35903 Mdot
.74 .35905 Mdot
.74 .35909 Mdot
.74 .35915 Mdot
.74 .35922 Mdot
.74 .35924 Mdot
.74 .3593 Mdot
.74 .3593 Mdot
.74 .35933 Mdot
.74 .35933 Mdot
.74 .35936 Mdot
.74 .35951 Mdot
.74 .36017 Mdot
.74 .36027 Mdot
.74 .36035 Mdot
.74 .36036 Mdot
.74 .36053 Mdot
.74 .3607 Mdot
.74 .36087 Mdot
.74 .36097 Mdot
.74 .36137 Mdot
.74 .36169 Mdot
.74 .36182 Mdot
.74 .36189 Mdot
.74 .36239 Mdot
.74 .36242 Mdot
.74 .36251 Mdot
.74 .36278 Mdot
.74 .36301 Mdot
.74 .36325 Mdot
.74 .36327 Mdot
.74 .36338 Mdot
.74 .36339 Mdot
.74 .3634 Mdot
.74 .36377 Mdot
.74 .36381 Mdot
.74 .36385 Mdot
.74 .36393 Mdot
.74 .36401 Mdot
.74 .36409 Mdot
.74 .36413 Mdot
.74 .36452 Mdot
.74 .36478 Mdot
.74 .3648 Mdot
.74 .36484 Mdot
.74 .36496 Mdot
.74 .36517 Mdot
.74 .36541 Mdot
.74 .36549 Mdot
.74 .36552 Mdot
.74 .36556 Mdot
.74 .36575 Mdot
.74 .36588 Mdot
.74 .36605 Mdot
.74 .36616 Mdot
.74 .36621 Mdot
.74 .36632 Mdot
.74 .36645 Mdot
.74 .36664 Mdot
.74 .36702 Mdot
.74 .36718 Mdot
.74 .36722 Mdot
.74 .36729 Mdot
.74 .3674 Mdot
.74 .36749 Mdot
.74 .36765 Mdot
.74 .36767 Mdot
.74 .36772 Mdot
.74 .36788 Mdot
.74 .36811 Mdot
.74 .36814 Mdot
.74 .36815 Mdot
.74 .36832 Mdot
.74 .36862 Mdot
.74 .36867 Mdot
.74 .36872 Mdot
.74 .36877 Mdot
.74 .36883 Mdot
.74 .36916 Mdot
.74 .36918 Mdot
.74 .3695 Mdot
.74 .36968 Mdot
.74 .36974 Mdot
.74 .36976 Mdot
.74 .37014 Mdot
.74 .37024 Mdot
.74 .37072 Mdot
.74 .37079 Mdot
.74 .37091 Mdot
.74 .37102 Mdot
.74 .37114 Mdot
.74 .37114 Mdot
.74 .3712 Mdot
.74 .37126 Mdot
.74 .37181 Mdot
.74 .37183 Mdot
.74 .37183 Mdot
.74 .37185 Mdot
.74 .37189 Mdot
.74 .37191 Mdot
.74 .37195 Mdot
.74 .37199 Mdot
.74 .37202 Mdot
.74 .37203 Mdot
.74 .37238 Mdot
.74 .37272 Mdot
.74 .37287 Mdot
.74 .37293 Mdot
.74 .37312 Mdot
.74 .37313 Mdot
.74 .37325 Mdot
.74 .3733 Mdot
.74 .37344 Mdot
.74 .37404 Mdot
.74 .37414 Mdot
.74 .37434 Mdot
.74 .37458 Mdot
.74 .3747 Mdot
.74 .3748 Mdot
.74 .3754 Mdot
.74 .37556 Mdot
.74 .3758 Mdot
.74 .37605 Mdot
.74 .37631 Mdot
.74 .37631 Mdot
.74 .37644 Mdot
.74 .37659 Mdot
.74 .37704 Mdot
.74 .37757 Mdot
.74 .37766 Mdot
.74 .37778 Mdot
.74 .37782 Mdot
.74 .37783 Mdot
.74 .37787 Mdot
.74 .37788 Mdot
.74 .37796 Mdot
.74 .378 Mdot
.74 .3781 Mdot
.74 .37819 Mdot
.74 .37824 Mdot
.74 .37827 Mdot
.74 .37849 Mdot
.74 .3786 Mdot
.74 .37872 Mdot
.74 .37905 Mdot
.74 .37912 Mdot
.74 .37941 Mdot
.74 .37951 Mdot
.74 .37978 Mdot
.74 .37992 Mdot
.74 .38012 Mdot
.74 .38015 Mdot
.74 .38023 Mdot
.74 .38066 Mdot
.74 .38069 Mdot
.74 .38084 Mdot
.74 .38088 Mdot
.74 .38094 Mdot
.74 .38106 Mdot
.74 .38115 Mdot
.74 .38135 Mdot
.74 .3819 Mdot
.74 .38224 Mdot
.74 .38268 Mdot
.74 .38274 Mdot
.74 .38288 Mdot
.74 .38319 Mdot
.74 .38334 Mdot
.74 .38362 Mdot
.74 .38369 Mdot
.74 .38386 Mdot
.74 .38412 Mdot
.74 .38425 Mdot
.74 .38434 Mdot
.74 .38435 Mdot
.74 .38472 Mdot
.74 .38485 Mdot
.74 .38485 Mdot
.74 .38557 Mdot
.74 .38561 Mdot
.74 .38565 Mdot
.74 .38581 Mdot
.74 .38597 Mdot
.74 .38599 Mdot
.74 .38626 Mdot
.74 .38643 Mdot
.74 .38651 Mdot
.74 .38652 Mdot
.74 .38654 Mdot
.74 .38667 Mdot
.74 .38697 Mdot
.74 .38706 Mdot
.74 .38707 Mdot
.74 .38764 Mdot
.74 .38765 Mdot
.74 .38776 Mdot
.74 .38781 Mdot
.74 .38793 Mdot
.74 .38796 Mdot
.74 .38808 Mdot
.74 .3881 Mdot
.74 .38811 Mdot
.74 .38821 Mdot
.74 .38825 Mdot
.74 .38924 Mdot
.74 .38934 Mdot
.74 .3896 Mdot
.74 .38966 Mdot
.74 .3897 Mdot
.74 .38972 Mdot
.74 .38977 Mdot
.74 .39002 Mdot
.74 .3904 Mdot
.74 .39041 Mdot
.74 .3906 Mdot
.74 .39072 Mdot
.74 .39087 Mdot
.74 .39096 Mdot
.74 .39097 Mdot
.74 .39107 Mdot
.74 .39108 Mdot
.74 .39113 Mdot
.74 .39118 Mdot
.74 .39126 Mdot
.74 .39134 Mdot
.74 .39141 Mdot
.74 .39141 Mdot
.74 .39156 Mdot
.74 .39175 Mdot
.74 .39187 Mdot
.74 .39187 Mdot
.74 .39194 Mdot
.74 .39241 Mdot
.74 .39266 Mdot
.74 .39293 Mdot
.74 .39364 Mdot
.74 .39379 Mdot
.74 .39429 Mdot
.74 .39444 Mdot
.74 .39452 Mdot
.74 .39465 Mdot
.74 .39525 Mdot
.74 .39543 Mdot
.74 .39555 Mdot
.74 .39574 Mdot
.74 .39598 Mdot
.74 .39604 Mdot
.74 .39623 Mdot
.74 .39679 Mdot
.74 .39688 Mdot
.74 .39717 Mdot
.74 .39723 Mdot
.74 .39758 Mdot
.74 .3976 Mdot
.74 .39764 Mdot
.74 .39779 Mdot
.74 .39781 Mdot
.74 .39805 Mdot
.74 .3981 Mdot
.74 .39825 Mdot
.74 .39837 Mdot
.74 .39869 Mdot
.74 .39902 Mdot
.74 .39908 Mdot
.74 .39923 Mdot
.74 .39988 Mdot
.74 .40063 Mdot
.74 .40095 Mdot
.74 .40111 Mdot
.74 .40152 Mdot
.74 .4016 Mdot
.74 .40174 Mdot
.74 .40183 Mdot
.74 .40193 Mdot
.74 .40204 Mdot
.74 .40211 Mdot
.74 .40257 Mdot
.74 .40272 Mdot
.74 .40272 Mdot
.74 .40303 Mdot
.74 .40314 Mdot
.74 .40366 Mdot
.74 .4038 Mdot
.74 .40386 Mdot
.74 .40419 Mdot
.74 .40475 Mdot
.74 .40503 Mdot
.74 .40524 Mdot
.74 .40525 Mdot
.74 .40534 Mdot
.74 .40594 Mdot
.74 .40607 Mdot
.74 .40625 Mdot
.74 .40634 Mdot
.74 .40635 Mdot
.74 .40641 Mdot
.74 .40659 Mdot
.74 .40698 Mdot
.74 .40716 Mdot
.74 .4072 Mdot
.74 .40793 Mdot
.74 .40801 Mdot
.74 .4081 Mdot
.74 .40834 Mdot
.74 .40846 Mdot
.74 .40881 Mdot
.74 .40885 Mdot
.74 .409 Mdot
.74 .40944 Mdot
.74 .40977 Mdot
.74 .40978 Mdot
.74 .4098 Mdot
.74 .40981 Mdot
.74 .40999 Mdot
.74 .41 Mdot
.74 .41004 Mdot
.74 .41034 Mdot
.74 .41037 Mdot
.74 .41098 Mdot
.74 .41118 Mdot
.74 .41121 Mdot
.74 .41135 Mdot
.74 .41166 Mdot
.74 .41246 Mdot
.74 .41248 Mdot
.74 .41272 Mdot
.74 .41281 Mdot
.74 .41283 Mdot
.74 .41286 Mdot
.74 .4131 Mdot
.74 .41316 Mdot
.74 .41316 Mdot
.74 .41342 Mdot
.74 .41347 Mdot
.74 .41349 Mdot
.74 .41371 Mdot
.74 .41379 Mdot
.74 .4138 Mdot
.74 .41385 Mdot
.74 .41445 Mdot
.74 .41497 Mdot
.74 .41514 Mdot
.74 .41524 Mdot
.74 .41544 Mdot
.74 .41545 Mdot
.74 .41584 Mdot
.74 .41587 Mdot
.74 .41596 Mdot
.74 .41602 Mdot
.74 .41604 Mdot
.74 .41618 Mdot
.74 .41675 Mdot
.74 .41688 Mdot
.74 .41698 Mdot
.74 .41702 Mdot
.74 .41713 Mdot
.74 .41714 Mdot
.74 .41738 Mdot
.74 .41752 Mdot
.74 .41768 Mdot
.74 .41768 Mdot
.74 .41768 Mdot
.74 .41801 Mdot
.74 .41838 Mdot
.74 .41852 Mdot
.74 .41853 Mdot
.74 .41865 Mdot
.74 .41876 Mdot
.74 .41882 Mdot
.74 .41894 Mdot
.74 .41895 Mdot
.74 .41899 Mdot
.74 .41921 Mdot
.74 .41926 Mdot
.74 .41929 Mdot
.74 .41953 Mdot
.74 .41956 Mdot
.74 .41959 Mdot
.74 .41972 Mdot
.74 .41972 Mdot
.74 .41975 Mdot
.74 .41976 Mdot
.74 .41976 Mdot
.74 .41978 Mdot
.74 .41984 Mdot
.74 .41985 Mdot
.74 .41997 Mdot
.74 .41999 Mdot
.74 .42011 Mdot
.74 .42013 Mdot
.74 .42019 Mdot
.74 .42022 Mdot
.74 .42026 Mdot
.74 .42039 Mdot
.74 .42056 Mdot
.74 .42071 Mdot
.74 .42071 Mdot
.74 .42078 Mdot
.74 .42085 Mdot
.74 .42095 Mdot
.74 .42146 Mdot
.74 .42147 Mdot
.74 .42153 Mdot
.74 .42155 Mdot
.74 .42173 Mdot
.74 .42173 Mdot
.74 .42182 Mdot
.74 .42187 Mdot
.74 .42195 Mdot
.74 .42218 Mdot
.74 .42246 Mdot
.74 .42248 Mdot
.74 .42277 Mdot
.74 .42291 Mdot
.74 .42346 Mdot
.74 .4236 Mdot
.74 .42405 Mdot
.74 .42431 Mdot
.74 .42431 Mdot
.74 .42432 Mdot
.74 .42467 Mdot
.74 .42497 Mdot
.74 .42549 Mdot
.74 .42551 Mdot
.74 .42559 Mdot
.74 .42577 Mdot
.74 .42585 Mdot
.74 .42593 Mdot
.74 .42607 Mdot
.74 .42634 Mdot
.74 .42702 Mdot
.74 .42735 Mdot
.74 .42754 Mdot
.74 .42761 Mdot
.74 .42782 Mdot
.74 .4279 Mdot
.74 .42795 Mdot
.74 .42809 Mdot
.74 .42828 Mdot
.74 .42835 Mdot
.74 .42913 Mdot
.74 .4292 Mdot
.74 .42923 Mdot
.74 .42952 Mdot
.74 .42965 Mdot
.74 .42978 Mdot
.74 .42988 Mdot
.74 .4302 Mdot
.74 .43025 Mdot
.74 .43073 Mdot
.74 .43087 Mdot
.74 .43128 Mdot
.74 .43139 Mdot
.74 .43249 Mdot
.74 .4327 Mdot
.74 .4327 Mdot
.74 .43281 Mdot
.74 .43283 Mdot
.74 .43302 Mdot
.74 .43334 Mdot
.74 .43347 Mdot
.74 .4335 Mdot
.74 .43353 Mdot
.74 .43365 Mdot
.74 .43421 Mdot
.74 .43421 Mdot
.74 .43422 Mdot
.74 .43428 Mdot
.74 .43435 Mdot
.74 .43437 Mdot
.74 .43469 Mdot
.74 .43473 Mdot
.74 .43486 Mdot
.74 .43494 Mdot
.74 .43498 Mdot
.74 .43518 Mdot
.74 .43526 Mdot
.74 .43537 Mdot
.74 .4357 Mdot
.74 .4357 Mdot
.74 .43576 Mdot
.74 .43597 Mdot
.74 .43666 Mdot
.74 .43739 Mdot
.74 .43751 Mdot
.74 .43753 Mdot
.74 .43785 Mdot
.74 .43818 Mdot
.74 .43849 Mdot
.74 .43855 Mdot
.74 .43898 Mdot
.74 .43926 Mdot
.74 .44033 Mdot
.74 .44038 Mdot
.74 .44091 Mdot
.74 .44105 Mdot
.74 .44114 Mdot
.74 .44117 Mdot
.74 .44156 Mdot
.74 .44159 Mdot
.74 .44161 Mdot
.74 .44161 Mdot
.74 .44163 Mdot
.74 .44196 Mdot
.74 .44237 Mdot
.74 .44286 Mdot
.74 .44304 Mdot
.74 .44332 Mdot
.74 .44334 Mdot
.74 .44354 Mdot
.74 .44366 Mdot
.74 .44375 Mdot
.74 .44376 Mdot
.74 .44401 Mdot
.74 .44416 Mdot
.74 .44451 Mdot
.74 .44478 Mdot
.74 .44516 Mdot
.74 .4453 Mdot
.74 .44549 Mdot
.74 .4455 Mdot
.74 .4455 Mdot
.74 .44567 Mdot
.74 .44618 Mdot
.74 .44641 Mdot
.74 .44727 Mdot
.74 .44736 Mdot
.74 .44755 Mdot
.74 .44774 Mdot
.74 .44787 Mdot
.74 .44799 Mdot
.74 .4486 Mdot
.74 .44871 Mdot
.74 .449 Mdot
.74 .44913 Mdot
.74 .44916 Mdot
.74 .44936 Mdot
.74 .44975 Mdot
.74 .44995 Mdot
.74 .45003 Mdot
.74 .45055 Mdot
.74 .45101 Mdot
.74 .45103 Mdot
.74 .45123 Mdot
.742 .24074 Mdot
.742 .2409 Mdot
.742 .24186 Mdot
.742 .24221 Mdot
.742 .24271 Mdot
.742 .24273 Mdot
.742 .24277 Mdot
.742 .24385 Mdot
.742 .24476 Mdot
.742 .2448 Mdot
.742 .24502 Mdot
.742 .24526 Mdot
.742 .24547 Mdot
.742 .24615 Mdot
.742 .24643 Mdot
.742 .24662 Mdot
.742 .24664 Mdot
.742 .24713 Mdot
.742 .24714 Mdot
.742 .24723 Mdot
.742 .24767 Mdot
.742 .24781 Mdot
.742 .24796 Mdot
.742 .24817 Mdot
.742 .24842 Mdot
.742 .24918 Mdot
.742 .24922 Mdot
.742 .24942 Mdot
.742 .24952 Mdot
.742 .24971 Mdot
.742 .24978 Mdot
.742 .25009 Mdot
.742 .25046 Mdot
.742 .25078 Mdot
.742 .25091 Mdot
.742 .25106 Mdot
.742 .2513 Mdot
.742 .25152 Mdot
.742 .25197 Mdot
.742 .25212 Mdot
.742 .25298 Mdot
.742 .25311 Mdot
.742 .25323 Mdot
.742 .25424 Mdot
.742 .25484 Mdot
.742 .25488 Mdot
.742 .25513 Mdot
.742 .25527 Mdot
.742 .25536 Mdot
.742 .25542 Mdot
.742 .25589 Mdot
.742 .25639 Mdot
.742 .25639 Mdot
.742 .25683 Mdot
.742 .25697 Mdot
.742 .25742 Mdot
.742 .25769 Mdot
.742 .25788 Mdot
.742 .25879 Mdot
.742 .25975 Mdot
.742 .2601 Mdot
.742 .26011 Mdot
.742 .26056 Mdot
.742 .26118 Mdot
.742 .26151 Mdot
.742 .26158 Mdot
.742 .26247 Mdot
.742 .26264 Mdot
.742 .26273 Mdot
.742 .26279 Mdot
.742 .26305 Mdot
.742 .2634 Mdot
.742 .26387 Mdot
.742 .26451 Mdot
.742 .2648 Mdot
.742 .2649 Mdot
.742 .26505 Mdot
.742 .26604 Mdot
.742 .26617 Mdot
.742 .26722 Mdot
.742 .2674 Mdot
.742 .26742 Mdot
.742 .26751 Mdot
.742 .26769 Mdot
.742 .26784 Mdot
.742 .26793 Mdot
.742 .26797 Mdot
.742 .26812 Mdot
.742 .26847 Mdot
.742 .26911 Mdot
.742 .26915 Mdot
.742 .26918 Mdot
.742 .26929 Mdot
.742 .26933 Mdot
.742 .2694 Mdot
.742 .27012 Mdot
.742 .27036 Mdot
.742 .27082 Mdot
.742 .27082 Mdot
.742 .27091 Mdot
.742 .27143 Mdot
.742 .27183 Mdot
.742 .27209 Mdot
.742 .27238 Mdot
.742 .27239 Mdot
.742 .27264 Mdot
.742 .27268 Mdot
.742 .27273 Mdot
.742 .27279 Mdot
.742 .27328 Mdot
.742 .27401 Mdot
.742 .2742 Mdot
.742 .2743 Mdot
.742 .27494 Mdot
.742 .27538 Mdot
.742 .27619 Mdot
.742 .27622 Mdot
.742 .27636 Mdot
.742 .27644 Mdot
.742 .27654 Mdot
.742 .27686 Mdot
.742 .27695 Mdot
.742 .27697 Mdot
.742 .27731 Mdot
.742 .27765 Mdot
.742 .27787 Mdot
.742 .27806 Mdot
.742 .27829 Mdot
.742 .27838 Mdot
.742 .27865 Mdot
.742 .27919 Mdot
.742 .27923 Mdot
.742 .27946 Mdot
.742 .27952 Mdot
.742 .27988 Mdot
.742 .28035 Mdot
.742 .28053 Mdot
.742 .2809 Mdot
.742 .28092 Mdot
.742 .28137 Mdot
.742 .28158 Mdot
.742 .28179 Mdot
.742 .28188 Mdot
.742 .28227 Mdot
.742 .28286 Mdot
.742 .28302 Mdot
.742 .28385 Mdot
.742 .28387 Mdot
.742 .28421 Mdot
.742 .28441 Mdot
.742 .28455 Mdot
.742 .28487 Mdot
.742 .28493 Mdot
.742 .28506 Mdot
.742 .28527 Mdot
.742 .2854 Mdot
.742 .28566 Mdot
.742 .28571 Mdot
.742 .28642 Mdot
.742 .28673 Mdot
.742 .28677 Mdot
.742 .28756 Mdot
.742 .28761 Mdot
.742 .288 Mdot
.742 .28835 Mdot
.742 .28837 Mdot
.742 .28923 Mdot
.742 .28935 Mdot
.742 .29005 Mdot
.742 .29077 Mdot
.742 .29099 Mdot
.742 .29109 Mdot
.742 .29118 Mdot
.742 .2914 Mdot
.742 .29186 Mdot
.742 .29202 Mdot
.742 .29215 Mdot
.742 .29258 Mdot
.742 .29277 Mdot
.742 .29302 Mdot
.742 .29323 Mdot
.742 .29342 Mdot
.742 .29346 Mdot
.742 .29352 Mdot
.742 .29353 Mdot
.742 .2941 Mdot
.742 .29439 Mdot
.742 .29444 Mdot
.742 .29486 Mdot
.742 .2951 Mdot
.742 .29513 Mdot
.742 .29514 Mdot
.742 .29526 Mdot
.742 .29552 Mdot
.742 .29597 Mdot
.742 .29618 Mdot
.742 .29629 Mdot
.742 .29673 Mdot
.742 .29704 Mdot
.742 .29732 Mdot
.742 .29748 Mdot
.742 .29752 Mdot
.742 .29866 Mdot
.742 .2987 Mdot
.742 .29884 Mdot
.742 .29913 Mdot
.742 .29934 Mdot
.742 .2995 Mdot
.742 .29962 Mdot
.742 .29969 Mdot
.742 .30017 Mdot
.742 .301 Mdot
.742 .30185 Mdot
.742 .30205 Mdot
.742 .30252 Mdot
.742 .30297 Mdot
.742 .30303 Mdot
.742 .30396 Mdot
.742 .30402 Mdot
.742 .30453 Mdot
.742 .30484 Mdot
.742 .30495 Mdot
.742 .30522 Mdot
.742 .30553 Mdot
.742 .30569 Mdot
.742 .3058 Mdot
.742 .30614 Mdot
.742 .30626 Mdot
.742 .30673 Mdot
.742 .30695 Mdot
.742 .30696 Mdot
.742 .30705 Mdot
.742 .30718 Mdot
.742 .30758 Mdot
.742 .30769 Mdot
.742 .30779 Mdot
.742 .30873 Mdot
.742 .30896 Mdot
.742 .30956 Mdot
.742 .30976 Mdot
.742 .31027 Mdot
.742 .31066 Mdot
.742 .31068 Mdot
.742 .31118 Mdot
.742 .31159 Mdot
.742 .31191 Mdot
.742 .31267 Mdot
.742 .31271 Mdot
.742 .31291 Mdot
.742 .31297 Mdot
.742 .31304 Mdot
.742 .31361 Mdot
.742 .31375 Mdot
.742 .31383 Mdot
.742 .31401 Mdot
.742 .31432 Mdot
.742 .31438 Mdot
.742 .31466 Mdot
.742 .31493 Mdot
.742 .31532 Mdot
.742 .31589 Mdot
.742 .31617 Mdot
.742 .31618 Mdot
.742 .3164 Mdot
.742 .31664 Mdot
.742 .31687 Mdot
.742 .31707 Mdot
.742 .31713 Mdot
.742 .31746 Mdot
.742 .31796 Mdot
.742 .31855 Mdot
.742 .31856 Mdot
.742 .31876 Mdot
.742 .31905 Mdot
.742 .31919 Mdot
.742 .31963 Mdot
.742 .31975 Mdot
.742 .3208 Mdot
.742 .32125 Mdot
.742 .32131 Mdot
.742 .32179 Mdot
.742 .32188 Mdot
.742 .322 Mdot
.742 .32211 Mdot
.742 .32213 Mdot
.742 .3222 Mdot
.742 .32264 Mdot
.742 .32268 Mdot
.742 .32272 Mdot
.742 .32274 Mdot
.742 .32278 Mdot
.742 .32342 Mdot
.742 .32346 Mdot
.742 .3237 Mdot
.742 .324 Mdot
.742 .32414 Mdot
.742 .32431 Mdot
.742 .32487 Mdot
.742 .32549 Mdot
.742 .32602 Mdot
.742 .32621 Mdot
.742 .32621 Mdot
.742 .32652 Mdot
.742 .32671 Mdot
.742 .32685 Mdot
.742 .32698 Mdot
.742 .32722 Mdot
.742 .32735 Mdot
.742 .32775 Mdot
.742 .32783 Mdot
.742 .32801 Mdot
.742 .32844 Mdot
.742 .32889 Mdot
.742 .32896 Mdot
.742 .32934 Mdot
.742 .3295 Mdot
.742 .32959 Mdot
.742 .32966 Mdot
.742 .3298 Mdot
.742 .32983 Mdot
.742 .32989 Mdot
.742 .32998 Mdot
.742 .33018 Mdot
.742 .3305 Mdot
.742 .33064 Mdot
.742 .33066 Mdot
.742 .33122 Mdot
.742 .33138 Mdot
.742 .33215 Mdot
.742 .33248 Mdot
.742 .33258 Mdot
.742 .33276 Mdot
.742 .33305 Mdot
.742 .33311 Mdot
.742 .3333 Mdot
.742 .33339 Mdot
.742 .3335 Mdot
.742 .3336 Mdot
.742 .3337 Mdot
.742 .33373 Mdot
.742 .33414 Mdot
.742 .33445 Mdot
.742 .33446 Mdot
.742 .33463 Mdot
.742 .33494 Mdot
.742 .33533 Mdot
.742 .33546 Mdot
.742 .33606 Mdot
.742 .33608 Mdot
.742 .33614 Mdot
.742 .33627 Mdot
.742 .33644 Mdot
.742 .3365 Mdot
.742 .33675 Mdot
.742 .33805 Mdot
.742 .33873 Mdot
.742 .33892 Mdot
.742 .33918 Mdot
.742 .33926 Mdot
.742 .3393 Mdot
.742 .33946 Mdot
.742 .33973 Mdot
.742 .33983 Mdot
.742 .33983 Mdot
.742 .34011 Mdot
.742 .34063 Mdot
.742 .34151 Mdot
.742 .34193 Mdot
.742 .34256 Mdot
.742 .34259 Mdot
.742 .34291 Mdot
.742 .34333 Mdot
.742 .34345 Mdot
.742 .34363 Mdot
.742 .34389 Mdot
.742 .34402 Mdot
.742 .34412 Mdot
.742 .34423 Mdot
.742 .34433 Mdot
.742 .34442 Mdot
.742 .3446 Mdot
.742 .34482 Mdot
.742 .3451 Mdot
.742 .34532 Mdot
.742 .34558 Mdot
.742 .34564 Mdot
.742 .34632 Mdot
.742 .34635 Mdot
.742 .34656 Mdot
.742 .34672 Mdot
.742 .34695 Mdot
.742 .34697 Mdot
.742 .34699 Mdot
.742 .34732 Mdot
.742 .34743 Mdot
.742 .34763 Mdot
.742 .34771 Mdot
.742 .34825 Mdot
.742 .34871 Mdot
.742 .3488 Mdot
.742 .34887 Mdot
.742 .34892 Mdot
.742 .34909 Mdot
.742 .34931 Mdot
.742 .34939 Mdot
.742 .34959 Mdot
.742 .34979 Mdot
.742 .34982 Mdot
.742 .35014 Mdot
.742 .3502 Mdot
.742 .35038 Mdot
.742 .35052 Mdot
.742 .35059 Mdot
.742 .35059 Mdot
.742 .35085 Mdot
.742 .35168 Mdot
.742 .35179 Mdot
.742 .35183 Mdot
.742 .35193 Mdot
.742 .35231 Mdot
.742 .35232 Mdot
.742 .3524 Mdot
.742 .35253 Mdot
.742 .35271 Mdot
.742 .35277 Mdot
.742 .35305 Mdot
.742 .35306 Mdot
.742 .35308 Mdot
.742 .35314 Mdot
.742 .35324 Mdot
.742 .35395 Mdot
.742 .35426 Mdot
.742 .35446 Mdot
.742 .35452 Mdot
.742 .35471 Mdot
.742 .35476 Mdot
.742 .35476 Mdot
.742 .35512 Mdot
.742 .35571 Mdot
.742 .35601 Mdot
.742 .35611 Mdot
.742 .35616 Mdot
.742 .3564 Mdot
.742 .35648 Mdot
.742 .3567 Mdot
.742 .3568 Mdot
.742 .35684 Mdot
.742 .35702 Mdot
.742 .35715 Mdot
.742 .35725 Mdot
.742 .35737 Mdot
.742 .35739 Mdot
.742 .3577 Mdot
.742 .35772 Mdot
.742 .35799 Mdot
.742 .358 Mdot
.742 .35801 Mdot
.742 .35816 Mdot
.742 .3583 Mdot
.742 .35834 Mdot
.742 .35858 Mdot
.742 .35879 Mdot
.742 .35886 Mdot
.742 .35888 Mdot
.742 .35896 Mdot
.742 .35906 Mdot
.742 .3591 Mdot
.742 .35919 Mdot
.742 .35947 Mdot
.742 .35961 Mdot
.742 .35964 Mdot
.742 .35976 Mdot
.742 .36014 Mdot
.742 .36021 Mdot
.742 .36025 Mdot
.742 .36043 Mdot
.742 .36046 Mdot
.742 .36053 Mdot
.742 .36063 Mdot
.742 .36076 Mdot
.742 .36085 Mdot
.742 .36117 Mdot
.742 .36131 Mdot
.742 .3614 Mdot
.742 .36143 Mdot
.742 .36154 Mdot
.742 .3621 Mdot
.742 .36228 Mdot
.742 .36246 Mdot
.742 .36267 Mdot
.742 .36272 Mdot
.742 .36273 Mdot
.742 .36287 Mdot
.742 .36288 Mdot
.742 .36301 Mdot
.742 .36314 Mdot
.742 .36316 Mdot
.742 .36337 Mdot
.742 .36344 Mdot
.742 .36349 Mdot
.742 .36355 Mdot
.742 .36367 Mdot
.742 .36401 Mdot
.742 .36415 Mdot
.742 .36456 Mdot
.742 .36487 Mdot
.742 .36495 Mdot
.742 .36503 Mdot
.742 .36522 Mdot
.742 .36522 Mdot
.742 .36534 Mdot
.742 .36544 Mdot
.742 .3655 Mdot
.742 .36558 Mdot
.742 .3658 Mdot
.742 .36613 Mdot
.742 .36634 Mdot
.742 .36645 Mdot
.742 .3668 Mdot
.742 .36685 Mdot
.742 .36702 Mdot
.742 .36739 Mdot
.742 .36766 Mdot
.742 .36773 Mdot
.742 .36824 Mdot
.742 .3683 Mdot
.742 .36841 Mdot
.742 .36849 Mdot
.742 .36867 Mdot
.742 .36872 Mdot
.742 .36921 Mdot
.742 .36953 Mdot
.742 .36965 Mdot
.742 .36974 Mdot
.742 .36989 Mdot
.742 .37007 Mdot
.742 .37007 Mdot
.742 .37016 Mdot
.742 .37035 Mdot
.742 .37047 Mdot
.742 .37059 Mdot
.742 .37104 Mdot
.742 .37106 Mdot
.742 .37112 Mdot
.742 .3715 Mdot
.742 .37165 Mdot
.742 .37169 Mdot
.742 .37184 Mdot
.742 .37187 Mdot
.742 .37191 Mdot
.742 .37237 Mdot
.742 .37255 Mdot
.742 .37261 Mdot
.742 .37264 Mdot
.742 .37271 Mdot
.742 .37282 Mdot
.742 .37313 Mdot
.742 .37315 Mdot
.742 .37335 Mdot
.742 .37336 Mdot
.742 .37336 Mdot
.742 .37354 Mdot
.742 .37355 Mdot
.742 .37376 Mdot
.742 .37378 Mdot
.742 .37386 Mdot
.742 .37401 Mdot
.742 .37416 Mdot
.742 .37423 Mdot
.742 .37443 Mdot
.742 .37469 Mdot
.742 .3749 Mdot
.742 .37529 Mdot
.742 .37554 Mdot
.742 .37557 Mdot
.742 .3757 Mdot
.742 .37574 Mdot
.742 .37588 Mdot
.742 .37608 Mdot
.742 .37656 Mdot
.742 .37669 Mdot
.742 .37688 Mdot
.742 .37692 Mdot
.742 .37704 Mdot
.742 .37713 Mdot
.742 .37719 Mdot
.742 .37745 Mdot
.742 .37751 Mdot
.742 .37761 Mdot
.742 .37817 Mdot
.742 .37834 Mdot
.742 .37835 Mdot
.742 .37839 Mdot
.742 .37861 Mdot
.742 .37886 Mdot
.742 .37889 Mdot
.742 .37902 Mdot
.742 .37916 Mdot
.742 .37921 Mdot
.742 .37936 Mdot
.742 .37947 Mdot
.742 .37951 Mdot
.742 .37955 Mdot
.742 .37961 Mdot
.742 .37993 Mdot
.742 .38029 Mdot
.742 .38034 Mdot
.742 .38048 Mdot
.742 .38055 Mdot
.742 .38077 Mdot
.742 .38079 Mdot
.742 .3808 Mdot
.742 .38096 Mdot
.742 .38106 Mdot
.742 .38121 Mdot
.742 .38122 Mdot
.742 .38168 Mdot
.742 .38172 Mdot
.742 .3819 Mdot
.742 .38205 Mdot
.742 .38223 Mdot
.742 .38238 Mdot
.742 .3825 Mdot
.742 .38257 Mdot
.742 .38263 Mdot
.742 .38271 Mdot
.742 .38277 Mdot
.742 .38286 Mdot
.742 .38304 Mdot
.742 .38316 Mdot
.742 .38324 Mdot
.742 .38352 Mdot
.742 .38374 Mdot
.742 .38376 Mdot
.742 .38418 Mdot
.742 .38447 Mdot
.742 .38506 Mdot
.742 .38541 Mdot
.742 .3856 Mdot
.742 .3856 Mdot
.742 .38567 Mdot
.742 .38585 Mdot
.742 .38595 Mdot
.742 .38599 Mdot
.742 .38604 Mdot
.742 .38621 Mdot
.742 .38634 Mdot
.742 .3868 Mdot
.742 .38767 Mdot
.742 .38784 Mdot
.742 .38788 Mdot
.742 .38799 Mdot
.742 .38808 Mdot
.742 .38812 Mdot
.742 .38814 Mdot
.742 .38855 Mdot
.742 .38863 Mdot
.742 .3889 Mdot
.742 .3891 Mdot
.742 .38922 Mdot
.742 .38922 Mdot
.742 .38943 Mdot
.742 .38971 Mdot
.742 .38973 Mdot
.742 .3898 Mdot
.742 .38986 Mdot
.742 .38994 Mdot
.742 .39 Mdot
.742 .39013 Mdot
.742 .39017 Mdot
.742 .39036 Mdot
.742 .39048 Mdot
.742 .39055 Mdot
.742 .39077 Mdot
.742 .39129 Mdot
.742 .3914 Mdot
.742 .39178 Mdot
.742 .39179 Mdot
.742 .39188 Mdot
.742 .3921 Mdot
.742 .39223 Mdot
.742 .3923 Mdot
.742 .39234 Mdot
.742 .39236 Mdot
.742 .39245 Mdot
.742 .3925 Mdot
.742 .39256 Mdot
.742 .39267 Mdot
.742 .39292 Mdot
.742 .39297 Mdot
.742 .39327 Mdot
.742 .39356 Mdot
.742 .39369 Mdot
.742 .39374 Mdot
.742 .39401 Mdot
.742 .3941 Mdot
.742 .39426 Mdot
.742 .39434 Mdot
.742 .39444 Mdot
.742 .39457 Mdot
.742 .39477 Mdot
.742 .39478 Mdot
.742 .3949 Mdot
.742 .39526 Mdot
.742 .39568 Mdot
.742 .39605 Mdot
.742 .39617 Mdot
.742 .39627 Mdot
.742 .39647 Mdot
.742 .39663 Mdot
.742 .39665 Mdot
.742 .39709 Mdot
.742 .39711 Mdot
.742 .39712 Mdot
.742 .39716 Mdot
.742 .39718 Mdot
.742 .39748 Mdot
.742 .39753 Mdot
.742 .39754 Mdot
.742 .39761 Mdot
.742 .3977 Mdot
.742 .39776 Mdot
.742 .39808 Mdot
.742 .39812 Mdot
.742 .39842 Mdot
.742 .39913 Mdot
.742 .39921 Mdot
.742 .3995 Mdot
.742 .3996 Mdot
.742 .39979 Mdot
.742 .39993 Mdot
.742 .39994 Mdot
.742 .40034 Mdot
.742 .40067 Mdot
.742 .40089 Mdot
.742 .40094 Mdot
.742 .40107 Mdot
.742 .40122 Mdot
.742 .40138 Mdot
.742 .40153 Mdot
.742 .40154 Mdot
.742 .40173 Mdot
.742 .40211 Mdot
.742 .40238 Mdot
.742 .40256 Mdot
.742 .40275 Mdot
.742 .40279 Mdot
.742 .403 Mdot
.742 .40312 Mdot
.742 .40317 Mdot
.742 .40326 Mdot
.742 .40365 Mdot
.742 .40369 Mdot
.742 .40374 Mdot
.742 .40387 Mdot
.742 .4039 Mdot
.742 .40441 Mdot
.742 .40463 Mdot
.742 .40491 Mdot
.742 .40524 Mdot
.742 .40526 Mdot
.742 .40552 Mdot
.742 .40586 Mdot
.742 .406 Mdot
.742 .4064 Mdot
.742 .40656 Mdot
.742 .40719 Mdot
.742 .40726 Mdot
.742 .40733 Mdot
.742 .4076 Mdot
.742 .40769 Mdot
.742 .40775 Mdot
.742 .40775 Mdot
.742 .4079 Mdot
.742 .40822 Mdot
.742 .4083 Mdot
.742 .40853 Mdot
.742 .4086 Mdot
.742 .40871 Mdot
.742 .40892 Mdot
.742 .4091 Mdot
.742 .40918 Mdot
.742 .40938 Mdot
.742 .40973 Mdot
.742 .40977 Mdot
.742 .41039 Mdot
.742 .41044 Mdot
.742 .41074 Mdot
.742 .41105 Mdot
.742 .41119 Mdot
.742 .41176 Mdot
.742 .41232 Mdot
.742 .41265 Mdot
.742 .4127 Mdot
.742 .41277 Mdot
.742 .41288 Mdot
.742 .41303 Mdot
.742 .41322 Mdot
.742 .41331 Mdot
.742 .41334 Mdot
.742 .41411 Mdot
.742 .41414 Mdot
.742 .41424 Mdot
.742 .41443 Mdot
.742 .41464 Mdot
.742 .41494 Mdot
.742 .41501 Mdot
.742 .41515 Mdot
.742 .41546 Mdot
.742 .41563 Mdot
.742 .41571 Mdot
.742 .41572 Mdot
.742 .41574 Mdot
.742 .4159 Mdot
.742 .41619 Mdot
.742 .41622 Mdot
.742 .41641 Mdot
.742 .4168 Mdot
.742 .4168 Mdot
.742 .41685 Mdot
.742 .41687 Mdot
.742 .417 Mdot
.742 .41714 Mdot
.742 .41731 Mdot
.742 .41744 Mdot
.742 .41773 Mdot
.742 .41781 Mdot
.742 .41792 Mdot
.742 .41824 Mdot
.742 .41838 Mdot
.742 .41844 Mdot
.742 .41851 Mdot
.742 .41865 Mdot
.742 .41914 Mdot
.742 .41961 Mdot
.742 .41969 Mdot
.742 .42027 Mdot
.742 .42029 Mdot
.742 .42052 Mdot
.742 .42079 Mdot
.742 .42082 Mdot
.742 .42135 Mdot
.742 .42138 Mdot
.742 .42159 Mdot
.742 .42207 Mdot
.742 .4221 Mdot
.742 .42227 Mdot
.742 .42236 Mdot
.742 .42251 Mdot
.742 .42259 Mdot
.742 .42263 Mdot
.742 .42285 Mdot
.742 .42294 Mdot
.742 .42308 Mdot
.742 .42331 Mdot
.742 .42332 Mdot
.742 .42388 Mdot
.742 .42398 Mdot
.742 .42439 Mdot
.742 .42465 Mdot
.742 .42471 Mdot
.742 .42485 Mdot
.742 .42499 Mdot
.742 .42529 Mdot
.742 .42531 Mdot
.742 .42556 Mdot
.742 .42568 Mdot
.742 .42599 Mdot
.742 .42624 Mdot
.742 .42628 Mdot
.742 .42643 Mdot
.742 .42646 Mdot
.742 .42682 Mdot
.742 .427 Mdot
.742 .42707 Mdot
.742 .42722 Mdot
.742 .42735 Mdot
.742 .4275 Mdot
.742 .42772 Mdot
.742 .42796 Mdot
.742 .42797 Mdot
.742 .42803 Mdot
.742 .42825 Mdot
.742 .42831 Mdot
.742 .42837 Mdot
.742 .42846 Mdot
.742 .42848 Mdot
.742 .42903 Mdot
.742 .42932 Mdot
.742 .42976 Mdot
.742 .42982 Mdot
.742 .42995 Mdot
.742 .43044 Mdot
.742 .43077 Mdot
.742 .43081 Mdot
.742 .43084 Mdot
.742 .43087 Mdot
.742 .43104 Mdot
.742 .43105 Mdot
.742 .43125 Mdot
.742 .43142 Mdot
.742 .43169 Mdot
.742 .43204 Mdot
.742 .4321 Mdot
.742 .4321 Mdot
.742 .43241 Mdot
.742 .43257 Mdot
.742 .43306 Mdot
.742 .43311 Mdot
.742 .43313 Mdot
.742 .43321 Mdot
.742 .43322 Mdot
.742 .43325 Mdot
.742 .43368 Mdot
.742 .43392 Mdot
.742 .43402 Mdot
.742 .43405 Mdot
.742 .43411 Mdot
.742 .43421 Mdot
.742 .43433 Mdot
.742 .43439 Mdot
.742 .4344 Mdot
.742 .43453 Mdot
.742 .43523 Mdot
.742 .43532 Mdot
.742 .43599 Mdot
.742 .43609 Mdot
.742 .43615 Mdot
.742 .43635 Mdot
.742 .43678 Mdot
.742 .4371 Mdot
.742 .43734 Mdot
.742 .43751 Mdot
.742 .43755 Mdot
.742 .43761 Mdot
.742 .43773 Mdot
.742 .43833 Mdot
.742 .43838 Mdot
.742 .43859 Mdot
.742 .43901 Mdot
.742 .43931 Mdot
.742 .43932 Mdot
.742 .43956 Mdot
.742 .44021 Mdot
.742 .44082 Mdot
.742 .44095 Mdot
.742 .44113 Mdot
.742 .44143 Mdot
.742 .44153 Mdot
.742 .44182 Mdot
.742 .44183 Mdot
.742 .44216 Mdot
.742 .44248 Mdot
.742 .44252 Mdot
.742 .44258 Mdot
.742 .44284 Mdot
.742 .44287 Mdot
.742 .44328 Mdot
.742 .44395 Mdot
.742 .44404 Mdot
.742 .44412 Mdot
.742 .4447 Mdot
.742 .44481 Mdot
.742 .44511 Mdot
.742 .44526 Mdot
.742 .44542 Mdot
.742 .44552 Mdot
.742 .44561 Mdot
.742 .44582 Mdot
.742 .44607 Mdot
.742 .44628 Mdot
.742 .44633 Mdot
.742 .44646 Mdot
.742 .44652 Mdot
.742 .44666 Mdot
.742 .44668 Mdot
.742 .44719 Mdot
.742 .44736 Mdot
.742 .44751 Mdot
.742 .4476 Mdot
.742 .4477 Mdot
.742 .448 Mdot
.742 .44805 Mdot
.742 .44807 Mdot
.742 .4484 Mdot
.742 .44841 Mdot
.742 .44854 Mdot
.742 .44873 Mdot
.742 .44919 Mdot
.742 .44933 Mdot
.742 .44949 Mdot
.742 .44964 Mdot
.742 .44966 Mdot
.742 .45027 Mdot
.742 .451 Mdot
.742 .45103 Mdot
.742 .45104 Mdot
.742 .45138 Mdot
.742 .45162 Mdot
.742 .45226 Mdot
.742 .45237 Mdot
.744 .23974 Mdot
.744 .23976 Mdot
.744 .2399 Mdot
.744 .24067 Mdot
.744 .241 Mdot
.744 .2412 Mdot
.744 .2414 Mdot
.744 .24209 Mdot
.744 .24246 Mdot
.744 .24297 Mdot
.744 .24308 Mdot
.744 .24429 Mdot
.744 .24434 Mdot
.744 .24454 Mdot
.744 .24494 Mdot
.744 .24508 Mdot
.744 .24563 Mdot
.744 .24609 Mdot
.744 .24629 Mdot
.744 .2464 Mdot
.744 .24652 Mdot
.744 .24655 Mdot
.744 .24672 Mdot
.744 .24694 Mdot
.744 .24772 Mdot
.744 .2478 Mdot
.744 .2479 Mdot
.744 .2483 Mdot
.744 .24897 Mdot
.744 .24898 Mdot
.744 .24962 Mdot
.744 .25018 Mdot
.744 .25027 Mdot
.744 .25071 Mdot
.744 .2512 Mdot
.744 .25174 Mdot
.744 .25184 Mdot
.744 .25215 Mdot
.744 .25217 Mdot
.744 .25243 Mdot
.744 .25287 Mdot
.744 .25299 Mdot
.744 .25303 Mdot
.744 .25304 Mdot
.744 .25315 Mdot
.744 .2533 Mdot
.744 .25347 Mdot
.744 .25454 Mdot
.744 .25462 Mdot
.744 .25475 Mdot
.744 .25477 Mdot
.744 .25492 Mdot
.744 .25527 Mdot
.744 .25532 Mdot
.744 .25572 Mdot
.744 .25614 Mdot
.744 .25618 Mdot
.744 .25653 Mdot
.744 .25672 Mdot
.744 .25688 Mdot
.744 .25694 Mdot
.744 .25718 Mdot
.744 .25719 Mdot
.744 .25764 Mdot
.744 .25773 Mdot
.744 .25774 Mdot
.744 .25832 Mdot
.744 .25862 Mdot
.744 .25875 Mdot
.744 .25881 Mdot
.744 .25913 Mdot
.744 .25976 Mdot
.744 .25994 Mdot
.744 .26033 Mdot
.744 .26055 Mdot
.744 .26145 Mdot
.744 .26282 Mdot
.744 .26319 Mdot
.744 .26332 Mdot
.744 .26375 Mdot
.744 .26409 Mdot
.744 .26442 Mdot
.744 .2649 Mdot
.744 .26505 Mdot
.744 .2651 Mdot
.744 .26521 Mdot
.744 .26525 Mdot
.744 .26558 Mdot
.744 .26637 Mdot
.744 .26701 Mdot
.744 .26709 Mdot
.744 .26722 Mdot
.744 .26751 Mdot
.744 .26755 Mdot
.744 .26879 Mdot
.744 .26885 Mdot
.744 .26905 Mdot
.744 .26967 Mdot
.744 .27119 Mdot
.744 .27271 Mdot
.744 .27301 Mdot
.744 .27371 Mdot
.744 .27424 Mdot
.744 .27426 Mdot
.744 .27473 Mdot
.744 .27489 Mdot
.744 .27511 Mdot
.744 .27537 Mdot
.744 .27603 Mdot
.744 .27693 Mdot
.744 .27743 Mdot
.744 .27791 Mdot
.744 .27833 Mdot
.744 .27837 Mdot
.744 .27912 Mdot
.744 .27932 Mdot
.744 .27945 Mdot
.744 .27966 Mdot
.744 .27967 Mdot
.744 .27991 Mdot
.744 .28016 Mdot
.744 .28037 Mdot
.744 .2805 Mdot
.744 .28073 Mdot
.744 .28074 Mdot
.744 .28149 Mdot
.744 .28154 Mdot
.744 .28159 Mdot
.744 .28159 Mdot
.744 .28188 Mdot
.744 .28192 Mdot
.744 .28211 Mdot
.744 .28215 Mdot
.744 .28246 Mdot
.744 .28319 Mdot
.744 .2832 Mdot
.744 .28359 Mdot
.744 .2837 Mdot
.744 .28395 Mdot
.744 .28413 Mdot
.744 .28444 Mdot
.744 .28496 Mdot
.744 .2852 Mdot
.744 .28606 Mdot
.744 .28639 Mdot
.744 .28662 Mdot
.744 .28668 Mdot
.744 .28674 Mdot
.744 .287 Mdot
.744 .28834 Mdot
.744 .28836 Mdot
.744 .28839 Mdot
.744 .28849 Mdot
.744 .28971 Mdot
.744 .28976 Mdot
.744 .28994 Mdot
.744 .29027 Mdot
.744 .29041 Mdot
.744 .29051 Mdot
.744 .29053 Mdot
.744 .29071 Mdot
.744 .29105 Mdot
.744 .29142 Mdot
.744 .29178 Mdot
.744 .29214 Mdot
.744 .29254 Mdot
.744 .29277 Mdot
.744 .29318 Mdot
.744 .29359 Mdot
.744 .29369 Mdot
.744 .29397 Mdot
.744 .29422 Mdot
.744 .29536 Mdot
.744 .29605 Mdot
.744 .29633 Mdot
.744 .29642 Mdot
.744 .29644 Mdot
.744 .297 Mdot
.744 .29702 Mdot
.744 .29721 Mdot
.744 .29725 Mdot
.744 .29754 Mdot
.744 .29789 Mdot
.744 .29811 Mdot
.744 .29813 Mdot
.744 .29842 Mdot
.744 .29914 Mdot
.744 .29976 Mdot
.744 .30017 Mdot
.744 .30044 Mdot
.744 .30052 Mdot
.744 .30081 Mdot
.744 .30095 Mdot
.744 .30098 Mdot
.744 .30104 Mdot
.744 .30143 Mdot
.744 .30168 Mdot
.744 .30169 Mdot
.744 .3018 Mdot
.744 .30182 Mdot
.744 .3019 Mdot
.744 .30198 Mdot
.744 .30235 Mdot
.744 .30255 Mdot
.744 .30271 Mdot
.744 .30278 Mdot
.744 .30285 Mdot
.744 .30344 Mdot
.744 .30351 Mdot
.744 .30356 Mdot
.744 .30356 Mdot
.744 .30358 Mdot
.744 .30364 Mdot
.744 .30384 Mdot
.744 .30396 Mdot
.744 .3041 Mdot
.744 .30415 Mdot
.744 .30439 Mdot
.744 .30461 Mdot
.744 .30485 Mdot
.744 .30539 Mdot
.744 .30588 Mdot
.744 .30592 Mdot
.744 .30596 Mdot
.744 .30631 Mdot
.744 .30641 Mdot
.744 .3065 Mdot
.744 .3067 Mdot
.744 .30716 Mdot
.744 .30751 Mdot
.744 .30834 Mdot
.744 .30881 Mdot
.744 .30891 Mdot
.744 .30915 Mdot
.744 .30949 Mdot
.744 .30956 Mdot
.744 .30984 Mdot
.744 .3104 Mdot
.744 .31089 Mdot
.744 .31129 Mdot
.744 .31133 Mdot
.744 .3119 Mdot
.744 .31199 Mdot
.744 .31218 Mdot
.744 .31249 Mdot
.744 .31279 Mdot
.744 .31283 Mdot
.744 .3129 Mdot
.744 .31369 Mdot
.744 .314 Mdot
.744 .31429 Mdot
.744 .31458 Mdot
.744 .31544 Mdot
.744 .31603 Mdot
.744 .31651 Mdot
.744 .31661 Mdot
.744 .31686 Mdot
.744 .31724 Mdot
.744 .31725 Mdot
.744 .31791 Mdot
.744 .31795 Mdot
.744 .31822 Mdot
.744 .31913 Mdot
.744 .32042 Mdot
.744 .32048 Mdot
.744 .32067 Mdot
.744 .32082 Mdot
.744 .32119 Mdot
.744 .32133 Mdot
.744 .32135 Mdot
.744 .32224 Mdot
.744 .32472 Mdot
.744 .32486 Mdot
.744 .32541 Mdot
.744 .32563 Mdot
.744 .32592 Mdot
.744 .32707 Mdot
.744 .32727 Mdot
.744 .32771 Mdot
.744 .32776 Mdot
.744 .32786 Mdot
.744 .32786 Mdot
.744 .32808 Mdot
.744 .32818 Mdot
.744 .32824 Mdot
.744 .32834 Mdot
.744 .32871 Mdot
.744 .32873 Mdot
.744 .32873 Mdot
.744 .32897 Mdot
.744 .32945 Mdot
.744 .3298 Mdot
.744 .32988 Mdot
.744 .33002 Mdot
.744 .33025 Mdot
.744 .33036 Mdot
.744 .33075 Mdot
.744 .33117 Mdot
.744 .33178 Mdot
.744 .33179 Mdot
.744 .3318 Mdot
.744 .33185 Mdot
.744 .33242 Mdot
.744 .3325 Mdot
.744 .33276 Mdot
.744 .33285 Mdot
.744 .33317 Mdot
.744 .33349 Mdot
.744 .33368 Mdot
.744 .33378 Mdot
.744 .33396 Mdot
.744 .33415 Mdot
.744 .33432 Mdot
.744 .33539 Mdot
.744 .33543 Mdot
.744 .3357 Mdot
.744 .33578 Mdot
.744 .33593 Mdot
.744 .33609 Mdot
.744 .33633 Mdot
.744 .33666 Mdot
.744 .33712 Mdot
.744 .33741 Mdot
.744 .33749 Mdot
.744 .33769 Mdot
.744 .33787 Mdot
.744 .33794 Mdot
.744 .3381 Mdot
.744 .3382 Mdot
.744 .33827 Mdot
.744 .3383 Mdot
.744 .33833 Mdot
.744 .3386 Mdot
.744 .33863 Mdot
.744 .33865 Mdot
.744 .33869 Mdot
.744 .33878 Mdot
.744 .33883 Mdot
.744 .33892 Mdot
.744 .33913 Mdot
.744 .3397 Mdot
.744 .3399 Mdot
.744 .33998 Mdot
.744 .34044 Mdot
.744 .34081 Mdot
.744 .34117 Mdot
.744 .34133 Mdot
.744 .34136 Mdot
.744 .34174 Mdot
.744 .34214 Mdot
.744 .34216 Mdot
.744 .34242 Mdot
.744 .34254 Mdot
.744 .34268 Mdot
.744 .34282 Mdot
.744 .34284 Mdot
.744 .34287 Mdot
.744 .34323 Mdot
.744 .3435 Mdot
.744 .34363 Mdot
.744 .34454 Mdot
.744 .34483 Mdot
.744 .34484 Mdot
.744 .34527 Mdot
.744 .34627 Mdot
.744 .34629 Mdot
.744 .34645 Mdot
.744 .34662 Mdot
.744 .34668 Mdot
.744 .34709 Mdot
.744 .34827 Mdot
.744 .34852 Mdot
.744 .34862 Mdot
.744 .34875 Mdot
.744 .34927 Mdot
.744 .34936 Mdot
.744 .34956 Mdot
.744 .34958 Mdot
.744 .34962 Mdot
.744 .34963 Mdot
.744 .34977 Mdot
.744 .3498 Mdot
.744 .34984 Mdot
.744 .35001 Mdot
.744 .35002 Mdot
.744 .35002 Mdot
.744 .35013 Mdot
.744 .3505 Mdot
.744 .35071 Mdot
.744 .35076 Mdot
.744 .35093 Mdot
.744 .35112 Mdot
.744 .3514 Mdot
.744 .3514 Mdot
.744 .35141 Mdot
.744 .35143 Mdot
.744 .35169 Mdot
.744 .35172 Mdot
.744 .35202 Mdot
.744 .35225 Mdot
.744 .35247 Mdot
.744 .35255 Mdot
.744 .35304 Mdot
.744 .35317 Mdot
.744 .35321 Mdot
.744 .35327 Mdot
.744 .35334 Mdot
.744 .35345 Mdot
.744 .3536 Mdot
.744 .35394 Mdot
.744 .35397 Mdot
.744 .35407 Mdot
.744 .35425 Mdot
.744 .35433 Mdot
.744 .35436 Mdot
.744 .35448 Mdot
.744 .3545 Mdot
.744 .35452 Mdot
.744 .35456 Mdot
.744 .35458 Mdot
.744 .35462 Mdot
.744 .35471 Mdot
.744 .3551 Mdot
.744 .35548 Mdot
.744 .35571 Mdot
.744 .35573 Mdot
.744 .3559 Mdot
.744 .35609 Mdot
.744 .35626 Mdot
.744 .35632 Mdot
.744 .35638 Mdot
.744 .35639 Mdot
.744 .35641 Mdot
.744 .35669 Mdot
.744 .35675 Mdot
.744 .35716 Mdot
.744 .35729 Mdot
.744 .35729 Mdot
.744 .35749 Mdot
.744 .35795 Mdot
.744 .35802 Mdot
.744 .3581 Mdot
.744 .35813 Mdot
.744 .35831 Mdot
.744 .35896 Mdot
.744 .359 Mdot
.744 .3593 Mdot
.744 .35934 Mdot
.744 .35946 Mdot
.744 .35952 Mdot
.744 .35956 Mdot
.744 .35963 Mdot
.744 .35963 Mdot
.744 .35968 Mdot
.744 .35985 Mdot
.744 .35995 Mdot
.744 .35997 Mdot
.744 .36013 Mdot
.744 .36026 Mdot
.744 .36026 Mdot
.744 .36039 Mdot
.744 .36074 Mdot
.744 .36106 Mdot
.744 .3611 Mdot
.744 .36114 Mdot
.744 .36119 Mdot
.744 .36141 Mdot
.744 .36142 Mdot
.744 .36146 Mdot
.744 .36155 Mdot
.744 .36158 Mdot
.744 .36168 Mdot
.744 .3617 Mdot
.744 .36171 Mdot
.744 .36193 Mdot
.744 .3621 Mdot
.744 .36229 Mdot
.744 .36238 Mdot
.744 .36252 Mdot
.744 .36292 Mdot
.744 .36328 Mdot
.744 .3633 Mdot
.744 .36384 Mdot
.744 .36393 Mdot
.744 .36394 Mdot
.744 .36398 Mdot
.744 .3642 Mdot
.744 .36426 Mdot
.744 .36432 Mdot
.744 .36466 Mdot
.744 .36468 Mdot
.744 .3648 Mdot
.744 .3649 Mdot
.744 .36492 Mdot
.744 .36501 Mdot
.744 .36509 Mdot
.744 .36522 Mdot
.744 .36528 Mdot
.744 .36546 Mdot
.744 .36588 Mdot
.744 .36592 Mdot
.744 .36594 Mdot
.744 .36604 Mdot
.744 .36626 Mdot
.744 .36631 Mdot
.744 .36661 Mdot
.744 .36681 Mdot
.744 .36682 Mdot
.744 .36687 Mdot
.744 .36699 Mdot
.744 .36722 Mdot
.744 .3673 Mdot
.744 .36741 Mdot
.744 .36744 Mdot
.744 .3675 Mdot
.744 .36753 Mdot
.744 .36754 Mdot
.744 .36755 Mdot
.744 .36755 Mdot
.744 .36756 Mdot
.744 .36756 Mdot
.744 .36757 Mdot
.744 .36759 Mdot
.744 .36763 Mdot
.744 .36772 Mdot
.744 .36778 Mdot
.744 .36793 Mdot
.744 .36801 Mdot
.744 .36805 Mdot
.744 .36805 Mdot
.744 .36839 Mdot
.744 .36843 Mdot
.744 .36857 Mdot
.744 .36864 Mdot
.744 .36866 Mdot
.744 .36896 Mdot
.744 .36908 Mdot
.744 .36926 Mdot
.744 .36933 Mdot
.744 .36934 Mdot
.744 .3694 Mdot
.744 .36949 Mdot
.744 .3695 Mdot
.744 .36973 Mdot
.744 .36981 Mdot
.744 .36996 Mdot
.744 .36998 Mdot
.744 .36999 Mdot
.744 .37005 Mdot
.744 .37067 Mdot
.744 .37094 Mdot
.744 .37104 Mdot
.744 .37122 Mdot
.744 .37133 Mdot
.744 .37148 Mdot
.744 .3715 Mdot
.744 .37157 Mdot
.744 .37165 Mdot
.744 .37169 Mdot
.744 .37183 Mdot
.744 .37187 Mdot
.744 .37189 Mdot
.744 .37192 Mdot
.744 .37213 Mdot
.744 .37237 Mdot
.744 .37246 Mdot
.744 .37254 Mdot
.744 .37265 Mdot
.744 .37273 Mdot
.744 .37288 Mdot
.744 .37293 Mdot
.744 .37295 Mdot
.744 .37308 Mdot
.744 .37333 Mdot
.744 .37389 Mdot
.744 .37391 Mdot
.744 .37396 Mdot
.744 .37401 Mdot
.744 .37445 Mdot
.744 .37454 Mdot
.744 .37482 Mdot
.744 .37505 Mdot
.744 .37506 Mdot
.744 .37515 Mdot
.744 .37526 Mdot
.744 .37539 Mdot
.744 .3755 Mdot
.744 .37551 Mdot
.744 .37567 Mdot
.744 .37592 Mdot
.744 .37618 Mdot
.744 .37625 Mdot
.744 .37627 Mdot
.744 .37629 Mdot
.744 .37633 Mdot
.744 .37634 Mdot
.744 .37644 Mdot
.744 .37649 Mdot
.744 .37662 Mdot
.744 .37668 Mdot
.744 .3767 Mdot
.744 .37703 Mdot
.744 .3771 Mdot
.744 .37715 Mdot
.744 .3772 Mdot
.744 .37722 Mdot
.744 .37764 Mdot
.744 .37769 Mdot
.744 .37784 Mdot
.744 .37793 Mdot
.744 .37822 Mdot
.744 .37841 Mdot
.744 .37841 Mdot
.744 .37841 Mdot
.744 .3786 Mdot
.744 .37884 Mdot
.744 .37888 Mdot
.744 .37901 Mdot
.744 .37927 Mdot
.744 .37934 Mdot
.744 .37934 Mdot
.744 .37935 Mdot
.744 .37946 Mdot
.744 .37951 Mdot
.744 .3796 Mdot
.744 .3796 Mdot
.744 .37978 Mdot
.744 .37984 Mdot
.744 .38019 Mdot
.744 .38028 Mdot
.744 .38035 Mdot
.744 .38051 Mdot
.744 .38131 Mdot
.744 .38158 Mdot
.744 .38163 Mdot
.744 .38174 Mdot
.744 .38184 Mdot
.744 .38186 Mdot
.744 .38253 Mdot
.744 .38282 Mdot
.744 .38283 Mdot
.744 .38302 Mdot
.744 .38363 Mdot
.744 .38372 Mdot
.744 .3839 Mdot
.744 .38414 Mdot
.744 .38416 Mdot
.744 .38418 Mdot
.744 .38427 Mdot
.744 .38436 Mdot
.744 .38445 Mdot
.744 .38462 Mdot
.744 .38463 Mdot
.744 .3849 Mdot
.744 .38516 Mdot
.744 .38518 Mdot
.744 .38528 Mdot
.744 .38553 Mdot
.744 .38578 Mdot
.744 .38608 Mdot
.744 .38627 Mdot
.744 .38666 Mdot
.744 .3868 Mdot
.744 .38686 Mdot
.744 .38689 Mdot
.744 .38696 Mdot
.744 .38698 Mdot
.744 .38699 Mdot
.744 .38701 Mdot
.744 .38719 Mdot
.744 .38722 Mdot
.744 .38724 Mdot
.744 .38728 Mdot
.744 .38735 Mdot
.744 .38746 Mdot
.744 .38751 Mdot
.744 .38762 Mdot
.744 .38776 Mdot
.744 .38781 Mdot
.744 .38801 Mdot
.744 .38832 Mdot
.744 .38854 Mdot
.744 .3887 Mdot
.744 .38881 Mdot
.744 .38891 Mdot
.744 .38896 Mdot
.744 .38915 Mdot
.744 .38917 Mdot
.744 .38989 Mdot
.744 .39 Mdot
.744 .39013 Mdot
.744 .39025 Mdot
.744 .39032 Mdot
.744 .39045 Mdot
.744 .39066 Mdot
.744 .39088 Mdot
.744 .39094 Mdot
.744 .39111 Mdot
.744 .39117 Mdot
.744 .39155 Mdot
.744 .39158 Mdot
.744 .39159 Mdot
.744 .3916 Mdot
.744 .39201 Mdot
.744 .39229 Mdot
.744 .39255 Mdot
.744 .39262 Mdot
.744 .39278 Mdot
.744 .39287 Mdot
.744 .39293 Mdot
.744 .39316 Mdot
.744 .39349 Mdot
.744 .39365 Mdot
.744 .39365 Mdot
.744 .39366 Mdot
.744 .39391 Mdot
.744 .39398 Mdot
.744 .39402 Mdot
.744 .39408 Mdot
.744 .39423 Mdot
.744 .39423 Mdot
.744 .3943 Mdot
.744 .39433 Mdot
.744 .39462 Mdot
.744 .39476 Mdot
.744 .39553 Mdot
.744 .39573 Mdot
.744 .39588 Mdot
.744 .39625 Mdot
.744 .39634 Mdot
.744 .39801 Mdot
.744 .39861 Mdot
.744 .39862 Mdot
.744 .39871 Mdot
.744 .39896 Mdot
.744 .39906 Mdot
.744 .39919 Mdot
.744 .39923 Mdot
.744 .4001 Mdot
.744 .40071 Mdot
.744 .40089 Mdot
.744 .40092 Mdot
.744 .40136 Mdot
.744 .40137 Mdot
.744 .40162 Mdot
.744 .40179 Mdot
.744 .40186 Mdot
.744 .40218 Mdot
.744 .40258 Mdot
.744 .40315 Mdot
.744 .40335 Mdot
.744 .40355 Mdot
.744 .40375 Mdot
.744 .40428 Mdot
.744 .40433 Mdot
.744 .40436 Mdot
.744 .40456 Mdot
.744 .40477 Mdot
.744 .40489 Mdot
.744 .40495 Mdot
.744 .40534 Mdot
.744 .40537 Mdot
.744 .40564 Mdot
.744 .40597 Mdot
.744 .40634 Mdot
.744 .40653 Mdot
.744 .40658 Mdot
.744 .40681 Mdot
.744 .40697 Mdot
.744 .40703 Mdot
.744 .40735 Mdot
.744 .40791 Mdot
.744 .40815 Mdot
.744 .40845 Mdot
.744 .40858 Mdot
.744 .40865 Mdot
.744 .40871 Mdot
.744 .40895 Mdot
.744 .40897 Mdot
.744 .409 Mdot
.744 .40933 Mdot
.744 .4097 Mdot
.744 .40986 Mdot
.744 .41001 Mdot
.744 .41017 Mdot
.744 .4102 Mdot
.744 .41029 Mdot
.744 .41038 Mdot
.744 .41051 Mdot
.744 .41055 Mdot
.744 .41056 Mdot
.744 .41056 Mdot
.744 .4106 Mdot
.744 .41064 Mdot
.744 .41104 Mdot
.744 .41109 Mdot
.744 .41113 Mdot
.744 .41124 Mdot
.744 .41138 Mdot
.744 .41162 Mdot
.744 .41168 Mdot
.744 .41173 Mdot
.744 .41175 Mdot
.744 .41182 Mdot
.744 .41182 Mdot
.744 .41199 Mdot
.744 .41226 Mdot
.744 .4123 Mdot
.744 .41232 Mdot
.744 .41241 Mdot
.744 .4126 Mdot
.744 .41266 Mdot
.744 .41284 Mdot
.744 .41312 Mdot
.744 .41353 Mdot
.744 .41402 Mdot
.744 .41421 Mdot
.744 .41422 Mdot
.744 .41437 Mdot
.744 .41461 Mdot
.744 .4148 Mdot
.744 .41483 Mdot
.744 .41496 Mdot
.744 .41497 Mdot
.744 .41534 Mdot
.744 .41536 Mdot
.744 .41542 Mdot
.744 .41561 Mdot
.744 .41607 Mdot
.744 .41684 Mdot
.744 .417 Mdot
.744 .4172 Mdot
.744 .41726 Mdot
.744 .41754 Mdot
.744 .41781 Mdot
.744 .41797 Mdot
.744 .41824 Mdot
.744 .41848 Mdot
.744 .41872 Mdot
.744 .41897 Mdot
.744 .4192 Mdot
.744 .41932 Mdot
.744 .41933 Mdot
.744 .4194 Mdot
.744 .41949 Mdot
.744 .41972 Mdot
.744 .41984 Mdot
.744 .41987 Mdot
.744 .42069 Mdot
.744 .42076 Mdot
.744 .42077 Mdot
.744 .42079 Mdot
.744 .42169 Mdot
.744 .42186 Mdot
.744 .42191 Mdot
.744 .42194 Mdot
.744 .4221 Mdot
.744 .42232 Mdot
.744 .4229 Mdot
.744 .42306 Mdot
.744 .42341 Mdot
.744 .42362 Mdot
.744 .42374 Mdot
.744 .42391 Mdot
.744 .42398 Mdot
.744 .42424 Mdot
.744 .42425 Mdot
.744 .42474 Mdot
.744 .42495 Mdot
.744 .42498 Mdot
.744 .42511 Mdot
.744 .42513 Mdot
.744 .42533 Mdot
.744 .42533 Mdot
.744 .42536 Mdot
.744 .42539 Mdot
.744 .4259 Mdot
.744 .4259 Mdot
.744 .42606 Mdot
.744 .42615 Mdot
.744 .42629 Mdot
.744 .42645 Mdot
.744 .42661 Mdot
.744 .42663 Mdot
.744 .42676 Mdot
.744 .42685 Mdot
.744 .42699 Mdot
.744 .42749 Mdot
.744 .42752 Mdot
.744 .4278 Mdot
.744 .42812 Mdot
.744 .42846 Mdot
.744 .42906 Mdot
.744 .4295 Mdot
.744 .42968 Mdot
.744 .42983 Mdot
.744 .42993 Mdot
.744 .43025 Mdot
.744 .43027 Mdot
.744 .43062 Mdot
.744 .43109 Mdot
.744 .4313 Mdot
.744 .43232 Mdot
.744 .43334 Mdot
.744 .43376 Mdot
.744 .43389 Mdot
.744 .43393 Mdot
.744 .43476 Mdot
.744 .43479 Mdot
.744 .43498 Mdot
.744 .43507 Mdot
.744 .43512 Mdot
.744 .43556 Mdot
.744 .43608 Mdot
.744 .43631 Mdot
.744 .43633 Mdot
.744 .43641 Mdot
.744 .43644 Mdot
.744 .43654 Mdot
.744 .43687 Mdot
.744 .43709 Mdot
.744 .43731 Mdot
.744 .43761 Mdot
.744 .43769 Mdot
.744 .43794 Mdot
.744 .43886 Mdot
.744 .43947 Mdot
.744 .43961 Mdot
.744 .43988 Mdot
.744 .44 Mdot
.744 .44042 Mdot
.744 .44063 Mdot
.744 .44068 Mdot
.744 .44077 Mdot
.744 .44097 Mdot
.744 .44135 Mdot
.744 .44136 Mdot
.744 .44142 Mdot
.744 .44173 Mdot
.744 .44173 Mdot
.744 .44189 Mdot
.744 .44193 Mdot
.744 .44204 Mdot
.744 .44217 Mdot
.744 .44241 Mdot
.744 .44243 Mdot
.744 .44271 Mdot
.744 .44298 Mdot
.744 .44302 Mdot
.744 .44325 Mdot
.744 .44335 Mdot
.744 .44336 Mdot
.744 .44345 Mdot
.744 .44351 Mdot
.744 .44422 Mdot
.744 .44434 Mdot
.744 .44444 Mdot
.744 .44452 Mdot
.744 .44452 Mdot
.744 .44455 Mdot
.744 .44463 Mdot
.744 .44493 Mdot
.744 .4451 Mdot
.744 .44511 Mdot
.744 .44532 Mdot
.744 .44539 Mdot
.744 .44575 Mdot
.744 .44608 Mdot
.744 .44638 Mdot
.744 .44643 Mdot
.744 .44681 Mdot
.744 .44724 Mdot
.744 .44725 Mdot
.744 .4477 Mdot
.744 .44797 Mdot
.744 .44803 Mdot
.744 .44809 Mdot
.744 .44861 Mdot
.744 .44876 Mdot
.744 .44888 Mdot
.744 .4489 Mdot
.744 .44898 Mdot
.744 .44905 Mdot
.744 .44918 Mdot
.744 .4495 Mdot
.744 .44987 Mdot
.744 .44996 Mdot
.744 .45023 Mdot
.744 .45036 Mdot
.744 .45039 Mdot
.744 .45121 Mdot
.744 .45128 Mdot
.744 .45162 Mdot
.744 .45187 Mdot
.744 .45233 Mdot
.744 .45247 Mdot
.744 .4526 Mdot
.744 .45283 Mdot
.744 .45334 Mdot
.744 .45344 Mdot
.744 .45345 Mdot
.746 .23883 Mdot
.746 .23939 Mdot
.746 .23949 Mdot
.746 .23963 Mdot
.746 .23968 Mdot
.746 .23977 Mdot
.746 .24056 Mdot
.746 .24127 Mdot
.746 .2418 Mdot
.746 .2421 Mdot
.746 .24215 Mdot
.746 .24259 Mdot
.746 .24285 Mdot
.746 .24367 Mdot
.746 .2442 Mdot
.746 .24421 Mdot
.746 .24431 Mdot
.746 .24452 Mdot
.746 .24467 Mdot
.746 .24485 Mdot
.746 .24523 Mdot
.746 .24527 Mdot
.746 .24561 Mdot
.746 .24601 Mdot
.746 .24621 Mdot
.746 .24688 Mdot
.746 .24705 Mdot
.746 .24738 Mdot
.746 .2474 Mdot
.746 .2482 Mdot
.746 .24853 Mdot
.746 .2487 Mdot
.746 .24874 Mdot
.746 .24945 Mdot
.746 .25002 Mdot
.746 .25011 Mdot
.746 .25023 Mdot
.746 .25039 Mdot
.746 .2504 Mdot
.746 .25065 Mdot
.746 .25078 Mdot
.746 .25205 Mdot
.746 .25232 Mdot
.746 .25246 Mdot
.746 .25249 Mdot
.746 .25307 Mdot
.746 .25351 Mdot
.746 .25375 Mdot
.746 .25425 Mdot
.746 .25443 Mdot
.746 .25454 Mdot
.746 .25512 Mdot
.746 .25532 Mdot
.746 .25575 Mdot
.746 .256 Mdot
.746 .25628 Mdot
.746 .25637 Mdot
.746 .25683 Mdot
.746 .25702 Mdot
.746 .25704 Mdot
.746 .25732 Mdot
.746 .25777 Mdot
.746 .25788 Mdot
.746 .25789 Mdot
.746 .25798 Mdot
.746 .2582 Mdot
.746 .25908 Mdot
.746 .2592 Mdot
.746 .26027 Mdot
.746 .26074 Mdot
.746 .26075 Mdot
.746 .26106 Mdot
.746 .26133 Mdot
.746 .26187 Mdot
.746 .26196 Mdot
.746 .26242 Mdot
.746 .26249 Mdot
.746 .26263 Mdot
.746 .26265 Mdot
.746 .26267 Mdot
.746 .26286 Mdot
.746 .26294 Mdot
.746 .26316 Mdot
.746 .26362 Mdot
.746 .26411 Mdot
.746 .265 Mdot
.746 .26525 Mdot
.746 .26542 Mdot
.746 .26544 Mdot
.746 .26555 Mdot
.746 .2661 Mdot
.746 .26646 Mdot
.746 .26662 Mdot
.746 .26676 Mdot
.746 .26755 Mdot
.746 .26766 Mdot
.746 .26783 Mdot
.746 .26784 Mdot
.746 .26798 Mdot
.746 .26835 Mdot
.746 .26841 Mdot
.746 .26875 Mdot
.746 .26892 Mdot
.746 .26944 Mdot
.746 .26963 Mdot
.746 .27016 Mdot
.746 .27016 Mdot
.746 .27019 Mdot
.746 .27077 Mdot
.746 .27089 Mdot
.746 .27092 Mdot
.746 .27103 Mdot
.746 .27147 Mdot
.746 .27166 Mdot
.746 .27166 Mdot
.746 .27218 Mdot
.746 .27223 Mdot
.746 .27319 Mdot
.746 .27418 Mdot
.746 .27422 Mdot
.746 .27455 Mdot
.746 .2751 Mdot
.746 .27524 Mdot
.746 .27525 Mdot
.746 .27589 Mdot
.746 .27622 Mdot
.746 .2763 Mdot
.746 .27738 Mdot
.746 .2774 Mdot
.746 .27789 Mdot
.746 .2779 Mdot
.746 .27833 Mdot
.746 .27871 Mdot
.746 .27881 Mdot
.746 .27945 Mdot
.746 .27973 Mdot
.746 .28006 Mdot
.746 .28045 Mdot
.746 .28048 Mdot
.746 .28084 Mdot
.746 .28088 Mdot
.746 .28136 Mdot
.746 .2814 Mdot
.746 .28155 Mdot
.746 .28157 Mdot
.746 .28227 Mdot
.746 .28249 Mdot
.746 .2825 Mdot
.746 .28259 Mdot
.746 .28352 Mdot
.746 .2837 Mdot
.746 .28391 Mdot
.746 .28394 Mdot
.746 .28423 Mdot
.746 .28605 Mdot
.746 .28613 Mdot
.746 .28654 Mdot
.746 .28656 Mdot
.746 .28675 Mdot
.746 .28678 Mdot
.746 .28736 Mdot
.746 .28736 Mdot
.746 .28766 Mdot
.746 .28801 Mdot
.746 .28802 Mdot
.746 .28821 Mdot
.746 .2893 Mdot
.746 .28938 Mdot
.746 .28979 Mdot
.746 .28984 Mdot
.746 .29076 Mdot
.746 .29093 Mdot
.746 .29213 Mdot
.746 .29214 Mdot
.746 .29262 Mdot
.746 .29266 Mdot
.746 .29281 Mdot
.746 .29356 Mdot
.746 .29357 Mdot
.746 .29447 Mdot
.746 .29499 Mdot
.746 .29505 Mdot
.746 .29537 Mdot
.746 .29538 Mdot
.746 .29538 Mdot
.746 .29562 Mdot
.746 .2957 Mdot
.746 .29594 Mdot
.746 .29617 Mdot
.746 .2965 Mdot
.746 .29655 Mdot
.746 .29697 Mdot
.746 .29704 Mdot
.746 .2981 Mdot
.746 .29832 Mdot
.746 .29862 Mdot
.746 .29866 Mdot
.746 .29875 Mdot
.746 .29876 Mdot
.746 .29883 Mdot
.746 .29886 Mdot
.746 .2991 Mdot
.746 .29935 Mdot
.746 .29947 Mdot
.746 .29961 Mdot
.746 .30075 Mdot
.746 .30085 Mdot
.746 .3009 Mdot
.746 .30095 Mdot
.746 .30115 Mdot
.746 .30128 Mdot
.746 .30128 Mdot
.746 .30137 Mdot
.746 .30186 Mdot
.746 .3024 Mdot
.746 .30245 Mdot
.746 .30253 Mdot
.746 .30332 Mdot
.746 .30333 Mdot
.746 .3034 Mdot
.746 .30426 Mdot
.746 .30426 Mdot
.746 .305 Mdot
.746 .30525 Mdot
.746 .30562 Mdot
.746 .30641 Mdot
.746 .30656 Mdot
.746 .30704 Mdot
.746 .30728 Mdot
.746 .30765 Mdot
.746 .30812 Mdot
.746 .30868 Mdot
.746 .30907 Mdot
.746 .3091 Mdot
.746 .30994 Mdot
.746 .31019 Mdot
.746 .31023 Mdot
.746 .31036 Mdot
.746 .31103 Mdot
.746 .31141 Mdot
.746 .31143 Mdot
.746 .31163 Mdot
.746 .31236 Mdot
.746 .3124 Mdot
.746 .31249 Mdot
.746 .31256 Mdot
.746 .31264 Mdot
.746 .31281 Mdot
.746 .31316 Mdot
.746 .31325 Mdot
.746 .31356 Mdot
.746 .31363 Mdot
.746 .31379 Mdot
.746 .3143 Mdot
.746 .31437 Mdot
.746 .31471 Mdot
.746 .31496 Mdot
.746 .315 Mdot
.746 .31506 Mdot
.746 .31525 Mdot
.746 .3153 Mdot
.746 .31588 Mdot
.746 .31634 Mdot
.746 .31653 Mdot
.746 .31664 Mdot
.746 .31726 Mdot
.746 .31734 Mdot
.746 .31765 Mdot
.746 .31778 Mdot
.746 .31782 Mdot
.746 .3185 Mdot
.746 .31903 Mdot
.746 .31909 Mdot
.746 .31957 Mdot
.746 .31979 Mdot
.746 .32033 Mdot
.746 .32064 Mdot
.746 .32087 Mdot
.746 .32169 Mdot
.746 .3218 Mdot
.746 .32188 Mdot
.746 .32189 Mdot
.746 .32194 Mdot
.746 .32219 Mdot
.746 .32248 Mdot
.746 .32297 Mdot
.746 .32297 Mdot
.746 .32303 Mdot
.746 .3232 Mdot
.746 .32338 Mdot
.746 .32429 Mdot
.746 .32436 Mdot
.746 .3246 Mdot
.746 .32468 Mdot
.746 .32469 Mdot
.746 .32494 Mdot
.746 .32537 Mdot
.746 .32598 Mdot
.746 .32623 Mdot
.746 .32629 Mdot
.746 .3263 Mdot
.746 .32748 Mdot
.746 .32749 Mdot
.746 .32768 Mdot
.746 .32785 Mdot
.746 .3279 Mdot
.746 .32819 Mdot
.746 .32831 Mdot
.746 .32865 Mdot
.746 .32881 Mdot
.746 .32883 Mdot
.746 .32904 Mdot
.746 .32906 Mdot
.746 .32913 Mdot
.746 .32914 Mdot
.746 .32945 Mdot
.746 .32955 Mdot
.746 .33019 Mdot
.746 .3302 Mdot
.746 .33033 Mdot
.746 .33115 Mdot
.746 .33146 Mdot
.746 .33148 Mdot
.746 .33174 Mdot
.746 .33187 Mdot
.746 .33212 Mdot
.746 .33388 Mdot
.746 .33389 Mdot
.746 .3341 Mdot
.746 .33412 Mdot
.746 .33419 Mdot
.746 .33452 Mdot
.746 .33453 Mdot
.746 .33493 Mdot
.746 .3352 Mdot
.746 .33534 Mdot
.746 .33534 Mdot
.746 .33534 Mdot
.746 .33559 Mdot
.746 .33585 Mdot
.746 .33606 Mdot
.746 .33609 Mdot
.746 .33656 Mdot
.746 .33666 Mdot
.746 .33681 Mdot
.746 .33685 Mdot
.746 .33686 Mdot
.746 .33701 Mdot
.746 .33718 Mdot
.746 .33724 Mdot
.746 .33776 Mdot
.746 .3378 Mdot
.746 .33793 Mdot
.746 .33799 Mdot
.746 .33825 Mdot
.746 .33849 Mdot
.746 .33891 Mdot
.746 .33933 Mdot
.746 .33977 Mdot
.746 .3403 Mdot
.746 .34036 Mdot
.746 .34085 Mdot
.746 .34132 Mdot
.746 .34188 Mdot
.746 .34207 Mdot
.746 .34237 Mdot
.746 .34254 Mdot
.746 .34255 Mdot
.746 .34264 Mdot
.746 .34297 Mdot
.746 .34299 Mdot
.746 .34303 Mdot
.746 .34306 Mdot
.746 .34333 Mdot
.746 .34337 Mdot
.746 .34354 Mdot
.746 .34361 Mdot
.746 .34384 Mdot
.746 .34387 Mdot
.746 .34403 Mdot
.746 .34418 Mdot
.746 .34427 Mdot
.746 .34455 Mdot
.746 .34476 Mdot
.746 .34489 Mdot
.746 .34535 Mdot
.746 .3454 Mdot
.746 .34542 Mdot
.746 .34573 Mdot
.746 .34597 Mdot
.746 .34599 Mdot
.746 .34631 Mdot
.746 .34655 Mdot
.746 .34669 Mdot
.746 .34679 Mdot
.746 .34725 Mdot
.746 .34725 Mdot
.746 .34727 Mdot
.746 .34738 Mdot
.746 .34752 Mdot
.746 .34776 Mdot
.746 .34784 Mdot
.746 .34833 Mdot
.746 .34851 Mdot
.746 .34881 Mdot
.746 .34909 Mdot
.746 .34977 Mdot
.746 .34985 Mdot
.746 .34993 Mdot
.746 .35008 Mdot
.746 .35013 Mdot
.746 .35029 Mdot
.746 .35036 Mdot
.746 .35037 Mdot
.746 .35046 Mdot
.746 .3505 Mdot
.746 .35051 Mdot
.746 .35069 Mdot
.746 .35098 Mdot
.746 .35168 Mdot
.746 .35264 Mdot
.746 .35274 Mdot
.746 .35274 Mdot
.746 .35293 Mdot
.746 .35311 Mdot
.746 .35323 Mdot
.746 .35329 Mdot
.746 .35329 Mdot
.746 .35341 Mdot
.746 .35352 Mdot
.746 .35361 Mdot
.746 .35363 Mdot
.746 .35389 Mdot
.746 .35397 Mdot
.746 .35404 Mdot
.746 .35412 Mdot
.746 .35438 Mdot
.746 .35446 Mdot
.746 .35448 Mdot
.746 .3546 Mdot
.746 .35471 Mdot
.746 .3549 Mdot
.746 .35509 Mdot
.746 .35552 Mdot
.746 .35555 Mdot
.746 .35598 Mdot
.746 .35632 Mdot
.746 .35653 Mdot
.746 .35657 Mdot
.746 .35672 Mdot
.746 .35688 Mdot
.746 .35701 Mdot
.746 .35711 Mdot
.746 .35712 Mdot
.746 .35713 Mdot
.746 .35719 Mdot
.746 .35726 Mdot
.746 .3573 Mdot
.746 .35758 Mdot
.746 .35779 Mdot
.746 .35781 Mdot
.746 .35782 Mdot
.746 .35796 Mdot
.746 .35808 Mdot
.746 .35822 Mdot
.746 .35839 Mdot
.746 .35844 Mdot
.746 .35864 Mdot
.746 .3587 Mdot
.746 .35876 Mdot
.746 .35887 Mdot
.746 .35891 Mdot
.746 .35921 Mdot
.746 .35935 Mdot
.746 .35977 Mdot
.746 .35981 Mdot
.746 .35994 Mdot
.746 .36004 Mdot
.746 .36009 Mdot
.746 .36011 Mdot
.746 .36106 Mdot
.746 .36111 Mdot
.746 .36128 Mdot
.746 .36133 Mdot
.746 .36136 Mdot
.746 .36136 Mdot
.746 .36173 Mdot
.746 .36184 Mdot
.746 .36188 Mdot
.746 .36194 Mdot
.746 .36281 Mdot
.746 .36283 Mdot
.746 .3629 Mdot
.746 .36297 Mdot
.746 .36308 Mdot
.746 .36316 Mdot
.746 .36338 Mdot
.746 .36345 Mdot
.746 .36357 Mdot
.746 .36367 Mdot
.746 .36381 Mdot
.746 .36386 Mdot
.746 .36388 Mdot
.746 .36434 Mdot
.746 .36439 Mdot
.746 .36441 Mdot
.746 .36494 Mdot
.746 .36498 Mdot
.746 .36524 Mdot
.746 .36563 Mdot
.746 .36567 Mdot
.746 .3657 Mdot
.746 .36579 Mdot
.746 .36592 Mdot
.746 .36602 Mdot
.746 .36611 Mdot
.746 .36634 Mdot
.746 .36635 Mdot
.746 .36661 Mdot
.746 .36673 Mdot
.746 .36692 Mdot
.746 .36882 Mdot
.746 .36922 Mdot
.746 .36943 Mdot
.746 .36945 Mdot
.746 .36948 Mdot
.746 .36974 Mdot
.746 .36992 Mdot
.746 .3703 Mdot
.746 .37031 Mdot
.746 .37034 Mdot
.746 .37066 Mdot
.746 .37079 Mdot
.746 .37094 Mdot
.746 .37099 Mdot
.746 .37114 Mdot
.746 .37126 Mdot
.746 .37131 Mdot
.746 .37136 Mdot
.746 .37137 Mdot
.746 .37195 Mdot
.746 .3721 Mdot
.746 .37234 Mdot
.746 .37236 Mdot
.746 .3724 Mdot
.746 .37254 Mdot
.746 .3732 Mdot
.746 .37323 Mdot
.746 .37329 Mdot
.746 .37341 Mdot
.746 .37369 Mdot
.746 .37399 Mdot
.746 .37401 Mdot
.746 .37408 Mdot
.746 .3743 Mdot
.746 .37433 Mdot
.746 .37445 Mdot
.746 .37462 Mdot
.746 .37471 Mdot
.746 .37474 Mdot
.746 .37506 Mdot
.746 .37513 Mdot
.746 .37519 Mdot
.746 .37526 Mdot
.746 .37534 Mdot
.746 .37545 Mdot
.746 .37555 Mdot
.746 .37558 Mdot
.746 .37595 Mdot
.746 .37624 Mdot
.746 .37626 Mdot
.746 .37668 Mdot
.746 .37687 Mdot
.746 .37697 Mdot
.746 .37702 Mdot
.746 .3772 Mdot
.746 .37735 Mdot
.746 .37752 Mdot
.746 .37753 Mdot
.746 .37767 Mdot
.746 .37775 Mdot
.746 .37775 Mdot
.746 .37779 Mdot
.746 .37787 Mdot
.746 .378 Mdot
.746 .37812 Mdot
.746 .37819 Mdot
.746 .3793 Mdot
.746 .37949 Mdot
.746 .37962 Mdot
.746 .37964 Mdot
.746 .37972 Mdot
.746 .37987 Mdot
.746 .38006 Mdot
.746 .38011 Mdot
.746 .38075 Mdot
.746 .38096 Mdot
.746 .38108 Mdot
.746 .3814 Mdot
.746 .38145 Mdot
.746 .38162 Mdot
.746 .38171 Mdot
.746 .38178 Mdot
.746 .3818 Mdot
.746 .3818 Mdot
.746 .38211 Mdot
.746 .38218 Mdot
.746 .38227 Mdot
.746 .38243 Mdot
.746 .38264 Mdot
.746 .38266 Mdot
.746 .38282 Mdot
.746 .38303 Mdot
.746 .38304 Mdot
.746 .38307 Mdot
.746 .38338 Mdot
.746 .38347 Mdot
.746 .38361 Mdot
.746 .3838 Mdot
.746 .38386 Mdot
.746 .38396 Mdot
.746 .38406 Mdot
.746 .38408 Mdot
.746 .38409 Mdot
.746 .38424 Mdot
.746 .38429 Mdot
.746 .3844 Mdot
.746 .38443 Mdot
.746 .38461 Mdot
.746 .38463 Mdot
.746 .38466 Mdot
.746 .38467 Mdot
.746 .38489 Mdot
.746 .38495 Mdot
.746 .38496 Mdot
.746 .38507 Mdot
.746 .38527 Mdot
.746 .3854 Mdot
.746 .38578 Mdot
.746 .38609 Mdot
.746 .38641 Mdot
.746 .38646 Mdot
.746 .38681 Mdot
.746 .38711 Mdot
.746 .38739 Mdot
.746 .38767 Mdot
.746 .38783 Mdot
.746 .38801 Mdot
.746 .38804 Mdot
.746 .38813 Mdot
.746 .38816 Mdot
.746 .38851 Mdot
.746 .38855 Mdot
.746 .38866 Mdot
.746 .38876 Mdot
.746 .38877 Mdot
.746 .38879 Mdot
.746 .3889 Mdot
.746 .38896 Mdot
.746 .38928 Mdot
.746 .3893 Mdot
.746 .38944 Mdot
.746 .38961 Mdot
.746 .38978 Mdot
.746 .38978 Mdot
.746 .38978 Mdot
.746 .38988 Mdot
.746 .39005 Mdot
.746 .39032 Mdot
.746 .39033 Mdot
.746 .39055 Mdot
.746 .3906 Mdot
.746 .39061 Mdot
.746 .39076 Mdot
.746 .39076 Mdot
.746 .39194 Mdot
.746 .39211 Mdot
.746 .3922 Mdot
.746 .39237 Mdot
.746 .39238 Mdot
.746 .39259 Mdot
.746 .39314 Mdot
.746 .39322 Mdot
.746 .39324 Mdot
.746 .39366 Mdot
.746 .39373 Mdot
.746 .39394 Mdot
.746 .39394 Mdot
.746 .39399 Mdot
.746 .394 Mdot
.746 .39415 Mdot
.746 .39416 Mdot
.746 .39427 Mdot
.746 .39449 Mdot
.746 .39458 Mdot
.746 .39477 Mdot
.746 .3948 Mdot
.746 .39492 Mdot
.746 .39504 Mdot
.746 .39505 Mdot
.746 .39584 Mdot
.746 .39585 Mdot
.746 .39589 Mdot
.746 .39605 Mdot
.746 .39646 Mdot
.746 .39675 Mdot
.746 .39692 Mdot
.746 .39692 Mdot
.746 .39698 Mdot
.746 .39714 Mdot
.746 .39719 Mdot
.746 .3978 Mdot
.746 .39792 Mdot
.746 .39803 Mdot
.746 .39807 Mdot
.746 .39807 Mdot
.746 .3984 Mdot
.746 .3986 Mdot
.746 .39876 Mdot
.746 .3988 Mdot
.746 .3988 Mdot
.746 .39885 Mdot
.746 .39893 Mdot
.746 .39948 Mdot
.746 .39964 Mdot
.746 .39984 Mdot
.746 .40021 Mdot
.746 .40035 Mdot
.746 .40067 Mdot
.746 .40071 Mdot
.746 .40107 Mdot
.746 .40153 Mdot
.746 .40155 Mdot
.746 .40164 Mdot
.746 .40184 Mdot
.746 .4019 Mdot
.746 .40231 Mdot
.746 .40239 Mdot
.746 .40252 Mdot
.746 .40283 Mdot
.746 .40321 Mdot
.746 .40325 Mdot
.746 .40337 Mdot
.746 .40341 Mdot
.746 .40344 Mdot
.746 .40361 Mdot
.746 .40384 Mdot
.746 .40389 Mdot
.746 .40423 Mdot
.746 .40433 Mdot
.746 .40438 Mdot
.746 .40458 Mdot
.746 .40464 Mdot
.746 .40488 Mdot
.746 .40499 Mdot
.746 .40505 Mdot
.746 .40509 Mdot
.746 .40516 Mdot
.746 .40519 Mdot
.746 .40567 Mdot
.746 .40581 Mdot
.746 .40582 Mdot
.746 .40607 Mdot
.746 .40652 Mdot
.746 .40661 Mdot
.746 .40664 Mdot
.746 .40681 Mdot
.746 .40737 Mdot
.746 .40739 Mdot
.746 .40765 Mdot
.746 .40802 Mdot
.746 .40834 Mdot
.746 .40859 Mdot
.746 .40875 Mdot
.746 .40907 Mdot
.746 .40917 Mdot
.746 .4097 Mdot
.746 .40995 Mdot
.746 .41011 Mdot
.746 .41061 Mdot
.746 .41061 Mdot
.746 .41119 Mdot
.746 .41123 Mdot
.746 .41124 Mdot
.746 .41177 Mdot
.746 .41183 Mdot
.746 .41186 Mdot
.746 .41222 Mdot
.746 .41255 Mdot
.746 .41261 Mdot
.746 .41261 Mdot
.746 .4127 Mdot
.746 .41283 Mdot
.746 .41287 Mdot
.746 .4129 Mdot
.746 .41296 Mdot
.746 .41373 Mdot
.746 .41383 Mdot
.746 .4139 Mdot
.746 .41407 Mdot
.746 .41423 Mdot
.746 .41426 Mdot
.746 .4143 Mdot
.746 .41431 Mdot
.746 .41437 Mdot
.746 .41439 Mdot
.746 .4146 Mdot
.746 .41474 Mdot
.746 .41545 Mdot
.746 .4155 Mdot
.746 .41578 Mdot
.746 .41581 Mdot
.746 .41604 Mdot
.746 .41619 Mdot
.746 .41635 Mdot
.746 .4164 Mdot
.746 .41656 Mdot
.746 .41657 Mdot
.746 .41657 Mdot
.746 .41678 Mdot
.746 .41683 Mdot
.746 .41717 Mdot
.746 .41778 Mdot
.746 .41779 Mdot
.746 .41829 Mdot
.746 .41839 Mdot
.746 .41841 Mdot
.746 .41874 Mdot
.746 .41874 Mdot
.746 .41955 Mdot
.746 .41966 Mdot
.746 .42028 Mdot
.746 .42031 Mdot
.746 .42059 Mdot
.746 .42064 Mdot
.746 .42137 Mdot
.746 .4215 Mdot
.746 .4215 Mdot
.746 .42174 Mdot
.746 .42194 Mdot
.746 .42194 Mdot
.746 .42233 Mdot
.746 .42235 Mdot
.746 .42248 Mdot
.746 .42249 Mdot
.746 .42277 Mdot
.746 .42282 Mdot
.746 .42404 Mdot
.746 .42423 Mdot
.746 .42425 Mdot
.746 .42439 Mdot
.746 .42451 Mdot
.746 .42513 Mdot
.746 .42519 Mdot
.746 .42521 Mdot
.746 .42535 Mdot
.746 .42582 Mdot
.746 .42583 Mdot
.746 .42593 Mdot
.746 .42596 Mdot
.746 .42629 Mdot
.746 .42631 Mdot
.746 .42655 Mdot
.746 .42657 Mdot
.746 .42683 Mdot
.746 .42706 Mdot
.746 .42724 Mdot
.746 .42767 Mdot
.746 .42774 Mdot
.746 .42799 Mdot
.746 .42828 Mdot
.746 .42829 Mdot
.746 .42862 Mdot
.746 .42863 Mdot
.746 .42936 Mdot
.746 .42941 Mdot
.746 .42963 Mdot
.746 .43005 Mdot
.746 .43007 Mdot
.746 .43016 Mdot
.746 .43053 Mdot
.746 .43074 Mdot
.746 .43077 Mdot
.746 .43144 Mdot
.746 .43208 Mdot
.746 .43211 Mdot
.746 .43246 Mdot
.746 .43246 Mdot
.746 .43259 Mdot
.746 .43288 Mdot
.746 .43296 Mdot
.746 .43298 Mdot
.746 .43306 Mdot
.746 .43345 Mdot
.746 .43346 Mdot
.746 .43347 Mdot
.746 .43382 Mdot
.746 .43395 Mdot
.746 .4343 Mdot
.746 .43442 Mdot
.746 .43464 Mdot
.746 .43468 Mdot
.746 .43493 Mdot
.746 .43502 Mdot
.746 .43503 Mdot
.746 .43514 Mdot
.746 .43522 Mdot
.746 .43575 Mdot
.746 .43584 Mdot
.746 .43595 Mdot
.746 .43619 Mdot
.746 .43656 Mdot
.746 .43663 Mdot
.746 .43665 Mdot
.746 .43676 Mdot
.746 .43693 Mdot
.746 .43752 Mdot
.746 .43785 Mdot
.746 .43816 Mdot
.746 .43831 Mdot
.746 .43836 Mdot
.746 .43849 Mdot
.746 .4385 Mdot
.746 .43851 Mdot
.746 .43861 Mdot
.746 .43866 Mdot
.746 .43896 Mdot
.746 .43902 Mdot
.746 .43939 Mdot
.746 .43956 Mdot
.746 .43977 Mdot
.746 .43978 Mdot
.746 .4401 Mdot
.746 .44081 Mdot
.746 .4409 Mdot
.746 .44148 Mdot
.746 .44163 Mdot
.746 .44169 Mdot
.746 .4417 Mdot
.746 .44177 Mdot
.746 .44208 Mdot
.746 .44226 Mdot
.746 .44227 Mdot
.746 .4424 Mdot
.746 .44271 Mdot
.746 .44277 Mdot
.746 .44296 Mdot
.746 .44313 Mdot
.746 .44342 Mdot
.746 .44355 Mdot
.746 .44393 Mdot
.746 .44401 Mdot
.746 .44413 Mdot
.746 .44447 Mdot
.746 .44463 Mdot
.746 .44492 Mdot
.746 .44531 Mdot
.746 .44533 Mdot
.746 .44543 Mdot
.746 .4456 Mdot
.746 .44646 Mdot
.746 .44655 Mdot
.746 .44671 Mdot
.746 .44672 Mdot
.746 .44682 Mdot
.746 .44691 Mdot
.746 .44697 Mdot
.746 .44735 Mdot
.746 .44782 Mdot
.746 .44785 Mdot
.746 .44796 Mdot
.746 .44819 Mdot
.746 .44872 Mdot
.746 .44874 Mdot
.746 .44896 Mdot
.746 .44907 Mdot
.746 .44952 Mdot
.746 .44965 Mdot
.746 .44992 Mdot
.746 .45015 Mdot
.746 .45018 Mdot
.746 .45043 Mdot
.746 .45055 Mdot
.746 .45065 Mdot
.746 .4508 Mdot
.746 .45086 Mdot
.746 .45087 Mdot
.746 .45122 Mdot
.746 .45178 Mdot
.746 .45194 Mdot
.746 .45224 Mdot
.746 .45228 Mdot
.746 .45248 Mdot
.746 .45283 Mdot
.746 .45331 Mdot
.746 .45383 Mdot
.746 .4539 Mdot
.746 .45393 Mdot
.746 .45402 Mdot
.746 .45409 Mdot
.746 .45447 Mdot
.748 .23903 Mdot
.748 .23916 Mdot
.748 .23924 Mdot
.748 .23958 Mdot
.748 .23971 Mdot
.748 .23975 Mdot
.748 .23977 Mdot
.748 .24053 Mdot
.748 .24105 Mdot
.748 .24107 Mdot
.748 .24119 Mdot
.748 .24156 Mdot
.748 .24202 Mdot
.748 .2421 Mdot
.748 .24212 Mdot
.748 .24215 Mdot
.748 .24219 Mdot
.748 .24244 Mdot
.748 .24257 Mdot
.748 .24257 Mdot
.748 .2431 Mdot
.748 .24358 Mdot
.748 .2443 Mdot
.748 .24471 Mdot
.748 .24499 Mdot
.748 .24538 Mdot
.748 .24556 Mdot
.748 .24563 Mdot
.748 .24586 Mdot
.748 .2459 Mdot
.748 .24819 Mdot
.748 .24831 Mdot
.748 .24855 Mdot
.748 .24857 Mdot
.748 .24894 Mdot
.748 .24942 Mdot
.748 .25052 Mdot
.748 .25082 Mdot
.748 .2513 Mdot
.748 .25134 Mdot
.748 .25173 Mdot
.748 .25197 Mdot
.748 .25285 Mdot
.748 .25351 Mdot
.748 .25373 Mdot
.748 .25387 Mdot
.748 .25402 Mdot
.748 .25428 Mdot
.748 .25464 Mdot
.748 .25467 Mdot
.748 .25484 Mdot
.748 .25491 Mdot
.748 .25537 Mdot
.748 .25562 Mdot
.748 .25563 Mdot
.748 .25572 Mdot
.748 .25611 Mdot
.748 .25613 Mdot
.748 .2562 Mdot
.748 .25655 Mdot
.748 .25662 Mdot
.748 .25684 Mdot
.748 .25705 Mdot
.748 .25725 Mdot
.748 .2578 Mdot
.748 .25827 Mdot
.748 .25839 Mdot
.748 .25842 Mdot
.748 .25935 Mdot
.748 .25963 Mdot
.748 .25982 Mdot
.748 .26005 Mdot
.748 .26047 Mdot
.748 .26063 Mdot
.748 .26088 Mdot
.748 .26099 Mdot
.748 .26115 Mdot
.748 .2613 Mdot
.748 .26151 Mdot
.748 .26169 Mdot
.748 .26178 Mdot
.748 .26259 Mdot
.748 .263 Mdot
.748 .26309 Mdot
.748 .26314 Mdot
.748 .26323 Mdot
.748 .26443 Mdot
.748 .26454 Mdot
.748 .26456 Mdot
.748 .26476 Mdot
.748 .26493 Mdot
.748 .26498 Mdot
.748 .26552 Mdot
.748 .26621 Mdot
.748 .26633 Mdot
.748 .26643 Mdot
.748 .267 Mdot
.748 .26769 Mdot
.748 .26787 Mdot
.748 .26787 Mdot
.748 .26809 Mdot
.748 .26832 Mdot
.748 .26881 Mdot
.748 .26906 Mdot
.748 .26946 Mdot
.748 .27029 Mdot
.748 .27054 Mdot
.748 .27082 Mdot
.748 .27109 Mdot
.748 .27172 Mdot
.748 .27179 Mdot
.748 .2718 Mdot
.748 .27208 Mdot
.748 .27209 Mdot
.748 .27251 Mdot
.748 .27274 Mdot
.748 .27278 Mdot
.748 .27348 Mdot
.748 .27377 Mdot
.748 .27393 Mdot
.748 .27413 Mdot
.748 .27435 Mdot
.748 .27444 Mdot
.748 .27557 Mdot
.748 .27559 Mdot
.748 .27584 Mdot
.748 .27627 Mdot
.748 .27628 Mdot
.748 .27686 Mdot
.748 .27689 Mdot
.748 .2778 Mdot
.748 .27805 Mdot
.748 .27806 Mdot
.748 .27825 Mdot
.748 .27833 Mdot
.748 .27856 Mdot
.748 .27901 Mdot
.748 .27902 Mdot
.748 .27948 Mdot
.748 .27963 Mdot
.748 .28054 Mdot
.748 .28081 Mdot
.748 .28108 Mdot
.748 .28152 Mdot
.748 .28193 Mdot
.748 .28217 Mdot
.748 .28279 Mdot
.748 .28283 Mdot
.748 .2831 Mdot
.748 .28312 Mdot
.748 .28323 Mdot
.748 .28341 Mdot
.748 .2836 Mdot
.748 .28394 Mdot
.748 .28419 Mdot
.748 .28419 Mdot
.748 .28439 Mdot
.748 .28509 Mdot
.748 .28539 Mdot
.748 .28554 Mdot
.748 .28594 Mdot
.748 .28605 Mdot
.748 .28639 Mdot
.748 .28648 Mdot
.748 .28662 Mdot
.748 .28702 Mdot
.748 .28765 Mdot
.748 .28789 Mdot
.748 .28806 Mdot
.748 .28813 Mdot
.748 .28858 Mdot
.748 .28878 Mdot
.748 .28909 Mdot
.748 .28927 Mdot
.748 .28929 Mdot
.748 .29006 Mdot
.748 .2903 Mdot
.748 .29118 Mdot
.748 .29141 Mdot
.748 .29152 Mdot
.748 .29194 Mdot
.748 .2922 Mdot
.748 .29251 Mdot
.748 .29302 Mdot
.748 .29316 Mdot
.748 .29332 Mdot
.748 .29377 Mdot
.748 .2942 Mdot
.748 .29421 Mdot
.748 .29424 Mdot
.748 .29452 Mdot
.748 .29476 Mdot
.748 .29554 Mdot
.748 .29576 Mdot
.748 .29596 Mdot
.748 .29596 Mdot
.748 .29635 Mdot
.748 .2966 Mdot
.748 .29665 Mdot
.748 .29701 Mdot
.748 .29725 Mdot
.748 .29735 Mdot
.748 .29832 Mdot
.748 .29868 Mdot
.748 .29872 Mdot
.748 .29896 Mdot
.748 .29908 Mdot
.748 .29926 Mdot
.748 .29977 Mdot
.748 .30018 Mdot
.748 .30046 Mdot
.748 .3008 Mdot
.748 .30089 Mdot
.748 .30102 Mdot
.748 .30117 Mdot
.748 .3012 Mdot
.748 .30139 Mdot
.748 .30143 Mdot
.748 .30143 Mdot
.748 .30175 Mdot
.748 .30178 Mdot
.748 .30237 Mdot
.748 .30358 Mdot
.748 .30371 Mdot
.748 .30442 Mdot
.748 .30458 Mdot
.748 .30459 Mdot
.748 .30475 Mdot
.748 .30577 Mdot
.748 .30579 Mdot
.748 .30601 Mdot
.748 .30618 Mdot
.748 .30631 Mdot
.748 .30681 Mdot
.748 .30703 Mdot
.748 .30726 Mdot
.748 .30732 Mdot
.748 .30743 Mdot
.748 .30751 Mdot
.748 .30788 Mdot
.748 .30793 Mdot
.748 .30794 Mdot
.748 .30818 Mdot
.748 .30851 Mdot
.748 .30853 Mdot
.748 .3086 Mdot
.748 .31055 Mdot
.748 .31061 Mdot
.748 .31064 Mdot
.748 .31085 Mdot
.748 .31168 Mdot
.748 .31192 Mdot
.748 .31193 Mdot
.748 .31194 Mdot
.748 .31213 Mdot
.748 .3129 Mdot
.748 .31347 Mdot
.748 .31349 Mdot
.748 .31469 Mdot
.748 .31519 Mdot
.748 .31603 Mdot
.748 .31605 Mdot
.748 .31622 Mdot
.748 .31633 Mdot
.748 .31672 Mdot
.748 .31712 Mdot
.748 .31718 Mdot
.748 .31724 Mdot
.748 .31736 Mdot
.748 .31752 Mdot
.748 .31753 Mdot
.748 .31785 Mdot
.748 .31818 Mdot
.748 .31841 Mdot
.748 .31869 Mdot
.748 .31915 Mdot
.748 .3192 Mdot
.748 .31975 Mdot
.748 .31984 Mdot
.748 .31994 Mdot
.748 .3202 Mdot
.748 .32036 Mdot
.748 .3205 Mdot
.748 .32059 Mdot
.748 .32126 Mdot
.748 .3213 Mdot
.748 .32132 Mdot
.748 .32136 Mdot
.748 .3219 Mdot
.748 .32195 Mdot
.748 .32195 Mdot
.748 .32212 Mdot
.748 .32269 Mdot
.748 .32336 Mdot
.748 .32353 Mdot
.748 .32397 Mdot
.748 .32414 Mdot
.748 .32452 Mdot
.748 .32475 Mdot
.748 .32531 Mdot
.748 .32532 Mdot
.748 .32551 Mdot
.748 .32561 Mdot
.748 .32594 Mdot
.748 .32614 Mdot
.748 .32633 Mdot
.748 .32688 Mdot
.748 .32699 Mdot
.748 .32719 Mdot
.748 .32746 Mdot
.748 .32798 Mdot
.748 .32807 Mdot
.748 .32811 Mdot
.748 .32841 Mdot
.748 .32842 Mdot
.748 .32862 Mdot
.748 .32869 Mdot
.748 .32921 Mdot
.748 .32953 Mdot
.748 .32972 Mdot
.748 .32982 Mdot
.748 .33024 Mdot
.748 .33025 Mdot
.748 .33038 Mdot
.748 .33046 Mdot
.748 .33073 Mdot
.748 .33073 Mdot
.748 .33113 Mdot
.748 .33155 Mdot
.748 .33171 Mdot
.748 .33181 Mdot
.748 .33227 Mdot
.748 .33246 Mdot
.748 .33249 Mdot
.748 .33269 Mdot
.748 .333 Mdot
.748 .33395 Mdot
.748 .33419 Mdot
.748 .33444 Mdot
.748 .33467 Mdot
.748 .33473 Mdot
.748 .33481 Mdot
.748 .33522 Mdot
.748 .33534 Mdot
.748 .33589 Mdot
.748 .33598 Mdot
.748 .33645 Mdot
.748 .33704 Mdot
.748 .3372 Mdot
.748 .33733 Mdot
.748 .33738 Mdot
.748 .33769 Mdot
.748 .338 Mdot
.748 .33815 Mdot
.748 .33819 Mdot
.748 .33825 Mdot
.748 .33833 Mdot
.748 .33841 Mdot
.748 .33843 Mdot
.748 .33843 Mdot
.748 .33857 Mdot
.748 .33939 Mdot
.748 .33945 Mdot
.748 .33984 Mdot
.748 .33984 Mdot
.748 .34047 Mdot
.748 .34055 Mdot
.748 .34061 Mdot
.748 .34093 Mdot
.748 .34103 Mdot
.748 .34111 Mdot
.748 .34131 Mdot
.748 .34144 Mdot
.748 .3416 Mdot
.748 .34163 Mdot
.748 .34255 Mdot
.748 .34264 Mdot
.748 .34301 Mdot
.748 .34312 Mdot
.748 .34321 Mdot
.748 .34436 Mdot
.748 .34458 Mdot
.748 .34496 Mdot
.748 .34509 Mdot
.748 .34544 Mdot
.748 .3455 Mdot
.748 .34555 Mdot
.748 .34562 Mdot
.748 .34577 Mdot
.748 .34601 Mdot
.748 .34614 Mdot
.748 .34634 Mdot
.748 .34637 Mdot
.748 .3467 Mdot
.748 .34681 Mdot
.748 .34695 Mdot
.748 .34699 Mdot
.748 .34729 Mdot
.748 .34733 Mdot
.748 .34757 Mdot
.748 .34793 Mdot
.748 .34823 Mdot
.748 .3485 Mdot
.748 .34874 Mdot
.748 .3491 Mdot
.748 .34919 Mdot
.748 .34923 Mdot
.748 .34938 Mdot
.748 .34947 Mdot
.748 .34956 Mdot
.748 .3498 Mdot
.748 .34985 Mdot
.748 .35006 Mdot
.748 .35029 Mdot
.748 .35035 Mdot
.748 .35049 Mdot
.748 .35049 Mdot
.748 .35061 Mdot
.748 .35084 Mdot
.748 .35099 Mdot
.748 .35112 Mdot
.748 .35131 Mdot
.748 .35136 Mdot
.748 .3514 Mdot
.748 .35189 Mdot
.748 .35196 Mdot
.748 .352 Mdot
.748 .35221 Mdot
.748 .35229 Mdot
.748 .35231 Mdot
.748 .35253 Mdot
.748 .35328 Mdot
.748 .35331 Mdot
.748 .35334 Mdot
.748 .35353 Mdot
.748 .35358 Mdot
.748 .35383 Mdot
.748 .35408 Mdot
.748 .35434 Mdot
.748 .35449 Mdot
.748 .35477 Mdot
.748 .35488 Mdot
.748 .35492 Mdot
.748 .35495 Mdot
.748 .35496 Mdot
.748 .35501 Mdot
.748 .35502 Mdot
.748 .35539 Mdot
.748 .35542 Mdot
.748 .35559 Mdot
.748 .35559 Mdot
.748 .35588 Mdot
.748 .35591 Mdot
.748 .35593 Mdot
.748 .35608 Mdot
.748 .35613 Mdot
.748 .35638 Mdot
.748 .35684 Mdot
.748 .35701 Mdot
.748 .35706 Mdot
.748 .3571 Mdot
.748 .35794 Mdot
.748 .35812 Mdot
.748 .35814 Mdot
.748 .35817 Mdot
.748 .35835 Mdot
.748 .3585 Mdot
.748 .35866 Mdot
.748 .35871 Mdot
.748 .35879 Mdot
.748 .35894 Mdot
.748 .35905 Mdot
.748 .35921 Mdot
.748 .35946 Mdot
.748 .35973 Mdot
.748 .35979 Mdot
.748 .35985 Mdot
.748 .35989 Mdot
.748 .35993 Mdot
.748 .36006 Mdot
.748 .36016 Mdot
.748 .36029 Mdot
.748 .36035 Mdot
.748 .36051 Mdot
.748 .36057 Mdot
.748 .36103 Mdot
.748 .36116 Mdot
.748 .36116 Mdot
.748 .36173 Mdot
.748 .36184 Mdot
.748 .36207 Mdot
.748 .36237 Mdot
.748 .36276 Mdot
.748 .36278 Mdot
.748 .36287 Mdot
.748 .36386 Mdot
.748 .36393 Mdot
.748 .364 Mdot
.748 .36413 Mdot
.748 .36417 Mdot
.748 .36436 Mdot
.748 .36453 Mdot
.748 .36457 Mdot
.748 .36506 Mdot
.748 .36512 Mdot
.748 .36542 Mdot
.748 .36583 Mdot
.748 .36584 Mdot
.748 .36633 Mdot
.748 .36635 Mdot
.748 .36644 Mdot
.748 .36686 Mdot
.748 .36702 Mdot
.748 .36721 Mdot
.748 .36744 Mdot
.748 .36748 Mdot
.748 .36774 Mdot
.748 .36782 Mdot
.748 .36792 Mdot
.748 .36864 Mdot
.748 .3687 Mdot
.748 .3689 Mdot
.748 .36905 Mdot
.748 .36918 Mdot
.748 .36929 Mdot
.748 .36957 Mdot
.748 .36962 Mdot
.748 .36964 Mdot
.748 .36997 Mdot
.748 .37025 Mdot
.748 .37049 Mdot
.748 .37096 Mdot
.748 .37111 Mdot
.748 .37125 Mdot
.748 .37129 Mdot
.748 .37196 Mdot
.748 .37201 Mdot
.748 .37203 Mdot
.748 .37229 Mdot
.748 .37249 Mdot
.748 .37264 Mdot
.748 .37271 Mdot
.748 .3731 Mdot
.748 .3731 Mdot
.748 .37319 Mdot
.748 .37364 Mdot
.748 .37368 Mdot
.748 .37392 Mdot
.748 .37394 Mdot
.748 .37397 Mdot
.748 .37405 Mdot
.748 .37423 Mdot
.748 .37451 Mdot
.748 .37458 Mdot
.748 .37474 Mdot
.748 .37477 Mdot
.748 .37488 Mdot
.748 .37498 Mdot
.748 .37511 Mdot
.748 .37513 Mdot
.748 .37525 Mdot
.748 .37584 Mdot
.748 .37587 Mdot
.748 .37598 Mdot
.748 .37646 Mdot
.748 .37649 Mdot
.748 .37659 Mdot
.748 .37661 Mdot
.748 .37663 Mdot
.748 .37694 Mdot
.748 .37721 Mdot
.748 .37724 Mdot
.748 .37755 Mdot
.748 .37766 Mdot
.748 .378 Mdot
.748 .37816 Mdot
.748 .37836 Mdot
.748 .37902 Mdot
.748 .37902 Mdot
.748 .37908 Mdot
.748 .37922 Mdot
.748 .37925 Mdot
.748 .37929 Mdot
.748 .3799 Mdot
.748 .37999 Mdot
.748 .38023 Mdot
.748 .38032 Mdot
.748 .38052 Mdot
.748 .38066 Mdot
.748 .38069 Mdot
.748 .38085 Mdot
.748 .38091 Mdot
.748 .38097 Mdot
.748 .38107 Mdot
.748 .3811 Mdot
.748 .38116 Mdot
.748 .3814 Mdot
.748 .38156 Mdot
.748 .38174 Mdot
.748 .38194 Mdot
.748 .38218 Mdot
.748 .38234 Mdot
.748 .38237 Mdot
.748 .38257 Mdot
.748 .3826 Mdot
.748 .38269 Mdot
.748 .38276 Mdot
.748 .38299 Mdot
.748 .383 Mdot
.748 .38314 Mdot
.748 .38322 Mdot
.748 .38339 Mdot
.748 .38349 Mdot
.748 .38353 Mdot
.748 .38357 Mdot
.748 .38361 Mdot
.748 .38384 Mdot
.748 .38393 Mdot
.748 .38418 Mdot
.748 .38433 Mdot
.748 .3851 Mdot
.748 .38516 Mdot
.748 .38523 Mdot
.748 .38548 Mdot
.748 .38554 Mdot
.748 .38615 Mdot
.748 .38617 Mdot
.748 .38628 Mdot
.748 .38637 Mdot
.748 .3865 Mdot
.748 .38655 Mdot
.748 .38662 Mdot
.748 .38683 Mdot
.748 .38687 Mdot
.748 .38692 Mdot
.748 .38735 Mdot
.748 .38735 Mdot
.748 .38761 Mdot
.748 .38765 Mdot
.748 .3882 Mdot
.748 .38821 Mdot
.748 .38829 Mdot
.748 .38829 Mdot
.748 .3883 Mdot
.748 .38836 Mdot
.748 .38841 Mdot
.748 .38845 Mdot
.748 .38848 Mdot
.748 .38858 Mdot
.748 .38879 Mdot
.748 .38899 Mdot
.748 .38903 Mdot
.748 .38911 Mdot
.748 .38922 Mdot
.748 .38961 Mdot
.748 .38993 Mdot
.748 .38999 Mdot
.748 .39035 Mdot
.748 .39044 Mdot
.748 .39071 Mdot
.748 .39076 Mdot
.748 .3908 Mdot
.748 .39096 Mdot
.748 .39113 Mdot
.748 .39129 Mdot
.748 .39192 Mdot
.748 .39213 Mdot
.748 .39226 Mdot
.748 .39228 Mdot
.748 .39241 Mdot
.748 .39272 Mdot
.748 .39278 Mdot
.748 .39289 Mdot
.748 .39317 Mdot
.748 .39344 Mdot
.748 .39344 Mdot
.748 .39362 Mdot
.748 .39367 Mdot
.748 .39376 Mdot
.748 .39377 Mdot
.748 .39404 Mdot
.748 .39412 Mdot
.748 .39424 Mdot
.748 .39445 Mdot
.748 .3948 Mdot
.748 .39485 Mdot
.748 .39498 Mdot
.748 .39499 Mdot
.748 .39519 Mdot
.748 .39522 Mdot
.748 .39527 Mdot
.748 .39562 Mdot
.748 .39581 Mdot
.748 .39594 Mdot
.748 .39601 Mdot
.748 .39638 Mdot
.748 .39651 Mdot
.748 .39664 Mdot
.748 .39686 Mdot
.748 .39693 Mdot
.748 .39706 Mdot
.748 .39706 Mdot
.748 .39744 Mdot
.748 .39759 Mdot
.748 .39784 Mdot
.748 .39796 Mdot
.748 .39825 Mdot
.748 .39837 Mdot
.748 .39881 Mdot
.748 .39919 Mdot
.748 .3993 Mdot
.748 .39931 Mdot
.748 .39934 Mdot
.748 .3997 Mdot
.748 .39973 Mdot
.748 .39974 Mdot
.748 .39977 Mdot
.748 .40021 Mdot
.748 .40028 Mdot
.748 .40037 Mdot
.748 .40048 Mdot
.748 .40065 Mdot
.748 .40072 Mdot
.748 .40078 Mdot
.748 .40115 Mdot
.748 .40118 Mdot
.748 .40149 Mdot
.748 .40168 Mdot
.748 .40183 Mdot
.748 .40205 Mdot
.748 .40226 Mdot
.748 .40227 Mdot
.748 .40238 Mdot
.748 .40245 Mdot
.748 .4025 Mdot
.748 .40254 Mdot
.748 .4028 Mdot
.748 .40307 Mdot
.748 .40314 Mdot
.748 .40325 Mdot
.748 .40326 Mdot
.748 .40383 Mdot
.748 .40416 Mdot
.748 .40496 Mdot
.748 .40498 Mdot
.748 .40536 Mdot
.748 .40587 Mdot
.748 .406 Mdot
.748 .40601 Mdot
.748 .40601 Mdot
.748 .40617 Mdot
.748 .40673 Mdot
.748 .40687 Mdot
.748 .40689 Mdot
.748 .40693 Mdot
.748 .40823 Mdot
.748 .40828 Mdot
.748 .40829 Mdot
.748 .40851 Mdot
.748 .40867 Mdot
.748 .40868 Mdot
.748 .40871 Mdot
.748 .40896 Mdot
.748 .40901 Mdot
.748 .40908 Mdot
.748 .40912 Mdot
.748 .40928 Mdot
.748 .40943 Mdot
.748 .40976 Mdot
.748 .40985 Mdot
.748 .40996 Mdot
.748 .41011 Mdot
.748 .41012 Mdot
.748 .4108 Mdot
.748 .41091 Mdot
.748 .41092 Mdot
.748 .41103 Mdot
.748 .4115 Mdot
.748 .41159 Mdot
.748 .41239 Mdot
.748 .41279 Mdot
.748 .41281 Mdot
.748 .41302 Mdot
.748 .41303 Mdot
.748 .41305 Mdot
.748 .41317 Mdot
.748 .4132 Mdot
.748 .4133 Mdot
.748 .41339 Mdot
.748 .41345 Mdot
.748 .41367 Mdot
.748 .41386 Mdot
.748 .41414 Mdot
.748 .41447 Mdot
.748 .41459 Mdot
.748 .41467 Mdot
.748 .41483 Mdot
.748 .41486 Mdot
.748 .4151 Mdot
.748 .41575 Mdot
.748 .41582 Mdot
.748 .41598 Mdot
.748 .41622 Mdot
.748 .41625 Mdot
.748 .41642 Mdot
.748 .41668 Mdot
.748 .41668 Mdot
.748 .41682 Mdot
.748 .41696 Mdot
.748 .41748 Mdot
.748 .41764 Mdot
.748 .41783 Mdot
.748 .41785 Mdot
.748 .41785 Mdot
.748 .41815 Mdot
.748 .41844 Mdot
.748 .41855 Mdot
.748 .41864 Mdot
.748 .41898 Mdot
.748 .41919 Mdot
.748 .41937 Mdot
.748 .41965 Mdot
.748 .41972 Mdot
.748 .41987 Mdot
.748 .42047 Mdot
.748 .42063 Mdot
.748 .42114 Mdot
.748 .42115 Mdot
.748 .42127 Mdot
.748 .42148 Mdot
.748 .42161 Mdot
.748 .42191 Mdot
.748 .42196 Mdot
.748 .42208 Mdot
.748 .42224 Mdot
.748 .42266 Mdot
.748 .42293 Mdot
.748 .42302 Mdot
.748 .42308 Mdot
.748 .42331 Mdot
.748 .42338 Mdot
.748 .42364 Mdot
.748 .42374 Mdot
.748 .42395 Mdot
.748 .42441 Mdot
.748 .42455 Mdot
.748 .42455 Mdot
.748 .42471 Mdot
.748 .42494 Mdot
.748 .42507 Mdot
.748 .42519 Mdot
.748 .42526 Mdot
.748 .42528 Mdot
.748 .42546 Mdot
.748 .42548 Mdot
.748 .4259 Mdot
.748 .42606 Mdot
.748 .42633 Mdot
.748 .42663 Mdot
.748 .42681 Mdot
.748 .42699 Mdot
.748 .4276 Mdot
.748 .4277 Mdot
.748 .428 Mdot
.748 .42801 Mdot
.748 .42831 Mdot
.748 .42846 Mdot
.748 .42852 Mdot
.748 .42865 Mdot
.748 .42865 Mdot
.748 .42882 Mdot
.748 .42943 Mdot
.748 .42944 Mdot
.748 .42984 Mdot
.748 .42984 Mdot
.748 .43013 Mdot
.748 .4303 Mdot
.748 .43031 Mdot
.748 .43106 Mdot
.748 .43112 Mdot
.748 .43127 Mdot
.748 .43141 Mdot
.748 .43151 Mdot
.748 .43171 Mdot
.748 .43218 Mdot
.748 .4322 Mdot
.748 .43236 Mdot
.748 .43264 Mdot
.748 .43265 Mdot
.748 .43283 Mdot
.748 .43283 Mdot
.748 .43288 Mdot
.748 .43331 Mdot
.748 .43349 Mdot
.748 .43367 Mdot
.748 .43384 Mdot
.748 .4344 Mdot
.748 .43466 Mdot
.748 .43483 Mdot
.748 .43515 Mdot
.748 .43531 Mdot
.748 .43545 Mdot
.748 .43545 Mdot
.748 .43557 Mdot
.748 .43604 Mdot
.748 .43642 Mdot
.748 .43649 Mdot
.748 .43656 Mdot
.748 .43702 Mdot
.748 .43739 Mdot
.748 .43743 Mdot
.748 .43753 Mdot
.748 .43767 Mdot
.748 .43768 Mdot
.748 .43775 Mdot
.748 .43856 Mdot
.748 .43862 Mdot
.748 .43865 Mdot
.748 .43871 Mdot
.748 .43898 Mdot
.748 .43952 Mdot
.748 .43959 Mdot
.748 .43971 Mdot
.748 .43985 Mdot
.748 .43995 Mdot
.748 .44006 Mdot
.748 .44013 Mdot
.748 .4403 Mdot
.748 .4404 Mdot
.748 .44068 Mdot
.748 .44084 Mdot
.748 .44097 Mdot
.748 .44115 Mdot
.748 .44178 Mdot
.748 .4418 Mdot
.748 .44187 Mdot
.748 .44219 Mdot
.748 .44255 Mdot
.748 .44269 Mdot
.748 .44283 Mdot
.748 .44298 Mdot
.748 .44303 Mdot
.748 .44325 Mdot
.748 .4433 Mdot
.748 .44332 Mdot
.748 .44358 Mdot
.748 .44364 Mdot
.748 .44364 Mdot
.748 .44381 Mdot
.748 .44412 Mdot
.748 .44417 Mdot
.748 .44428 Mdot
.748 .4443 Mdot
.748 .44454 Mdot
.748 .44471 Mdot
.748 .44482 Mdot
.748 .44491 Mdot
.748 .44505 Mdot
.748 .4455 Mdot
.748 .44609 Mdot
.748 .44625 Mdot
.748 .44651 Mdot
.748 .44653 Mdot
.748 .44686 Mdot
.748 .44705 Mdot
.748 .44779 Mdot
.748 .44811 Mdot
.748 .44835 Mdot
.748 .44837 Mdot
.748 .44853 Mdot
.748 .44861 Mdot
.748 .45014 Mdot
.748 .45017 Mdot
.748 .45033 Mdot
.748 .45037 Mdot
.748 .45049 Mdot
.748 .45075 Mdot
.748 .45094 Mdot
.748 .45121 Mdot
.748 .45169 Mdot
.748 .45201 Mdot
.748 .45237 Mdot
.748 .45237 Mdot
.748 .45246 Mdot
.748 .45262 Mdot
.748 .45265 Mdot
.748 .45267 Mdot
.748 .45268 Mdot
.748 .45273 Mdot
.748 .45304 Mdot
.748 .45329 Mdot
.748 .45337 Mdot
.748 .45339 Mdot
.748 .45373 Mdot
.748 .45424 Mdot
.748 .45426 Mdot
.748 .45428 Mdot
.748 .45437 Mdot
.748 .45459 Mdot
.748 .45465 Mdot
.748 .45473 Mdot
.75 .23646 Mdot
.75 .23673 Mdot
.75 .23799 Mdot
.75 .23818 Mdot
.75 .23849 Mdot
.75 .23859 Mdot
.75 .23879 Mdot
.75 .23891 Mdot
.75 .23895 Mdot
.75 .23916 Mdot
.75 .24018 Mdot
.75 .2404 Mdot
.75 .24058 Mdot
.75 .2406 Mdot
.75 .24086 Mdot
.75 .24095 Mdot
.75 .24098 Mdot
.75 .24113 Mdot
.75 .24121 Mdot
.75 .24131 Mdot
.75 .24136 Mdot
.75 .24183 Mdot
.75 .24207 Mdot
.75 .24224 Mdot
.75 .24263 Mdot
.75 .2431 Mdot
.75 .24324 Mdot
.75 .24329 Mdot
.75 .24491 Mdot
.75 .24591 Mdot
.75 .24664 Mdot
.75 .24732 Mdot
.75 .24739 Mdot
.75 .24748 Mdot
.75 .24775 Mdot
.75 .24822 Mdot
.75 .24898 Mdot
.75 .24914 Mdot
.75 .24992 Mdot
.75 .25062 Mdot
.75 .25125 Mdot
.75 .25146 Mdot
.75 .25189 Mdot
.75 .25213 Mdot
.75 .25222 Mdot
.75 .25248 Mdot
.75 .25334 Mdot
.75 .25378 Mdot
.75 .25392 Mdot
.75 .25412 Mdot
.75 .25423 Mdot
.75 .25438 Mdot
.75 .25475 Mdot
.75 .25478 Mdot
.75 .2549 Mdot
.75 .25514 Mdot
.75 .25517 Mdot
.75 .25518 Mdot
.75 .2552 Mdot
.75 .2559 Mdot
.75 .2563 Mdot
.75 .25663 Mdot
.75 .25671 Mdot
.75 .25678 Mdot
.75 .25705 Mdot
.75 .25708 Mdot
.75 .25714 Mdot
.75 .2572 Mdot
.75 .25746 Mdot
.75 .25803 Mdot
.75 .25909 Mdot
.75 .25922 Mdot
.75 .25993 Mdot
.75 .26005 Mdot
.75 .26053 Mdot
.75 .26078 Mdot
.75 .26093 Mdot
.75 .26093 Mdot
.75 .26148 Mdot
.75 .26217 Mdot
.75 .26259 Mdot
.75 .26264 Mdot
.75 .26272 Mdot
.75 .26278 Mdot
.75 .2628 Mdot
.75 .26287 Mdot
.75 .26299 Mdot
.75 .26351 Mdot
.75 .26372 Mdot
.75 .26411 Mdot
.75 .26418 Mdot
.75 .26424 Mdot
.75 .26493 Mdot
.75 .26525 Mdot
.75 .26533 Mdot
.75 .26535 Mdot
.75 .26583 Mdot
.75 .26586 Mdot
.75 .26673 Mdot
.75 .26676 Mdot
.75 .26678 Mdot
.75 .26717 Mdot
.75 .26823 Mdot
.75 .26895 Mdot
.75 .26927 Mdot
.75 .26962 Mdot
.75 .26977 Mdot
.75 .2698 Mdot
.75 .26982 Mdot
.75 .26988 Mdot
.75 .27005 Mdot
.75 .27075 Mdot
.75 .27133 Mdot
.75 .27158 Mdot
.75 .27162 Mdot
.75 .27166 Mdot
.75 .27188 Mdot
.75 .27199 Mdot
.75 .27216 Mdot
.75 .27218 Mdot
.75 .2729 Mdot
.75 .27313 Mdot
.75 .27331 Mdot
.75 .27366 Mdot
.75 .2745 Mdot
.75 .27467 Mdot
.75 .27551 Mdot
.75 .27586 Mdot
.75 .27593 Mdot
.75 .276 Mdot
.75 .27604 Mdot
.75 .27633 Mdot
.75 .27648 Mdot
.75 .27677 Mdot
.75 .27784 Mdot
.75 .27816 Mdot
.75 .27824 Mdot
.75 .27837 Mdot
.75 .27918 Mdot
.75 .2792 Mdot
.75 .27949 Mdot
.75 .27994 Mdot
.75 .28064 Mdot
.75 .28101 Mdot
.75 .28109 Mdot
.75 .28109 Mdot
.75 .28111 Mdot
.75 .28182 Mdot
.75 .28222 Mdot
.75 .28248 Mdot
.75 .28271 Mdot
.75 .283 Mdot
.75 .28352 Mdot
.75 .28397 Mdot
.75 .28519 Mdot
.75 .2853 Mdot
.75 .28582 Mdot
.75 .28598 Mdot
.75 .28606 Mdot
.75 .28611 Mdot
.75 .28616 Mdot
.75 .28641 Mdot
.75 .2868 Mdot
.75 .28727 Mdot
.75 .28738 Mdot
.75 .28746 Mdot
.75 .28753 Mdot
.75 .28835 Mdot
.75 .28855 Mdot
.75 .28879 Mdot
.75 .28892 Mdot
.75 .28902 Mdot
.75 .28913 Mdot
.75 .28931 Mdot
.75 .28967 Mdot
.75 .28983 Mdot
.75 .29048 Mdot
.75 .29084 Mdot
.75 .29108 Mdot
.75 .29168 Mdot
.75 .29188 Mdot
.75 .29193 Mdot
.75 .29196 Mdot
.75 .29212 Mdot
.75 .29383 Mdot
.75 .29397 Mdot
.75 .29454 Mdot
.75 .29462 Mdot
.75 .29464 Mdot
.75 .29465 Mdot
.75 .29484 Mdot
.75 .29489 Mdot
.75 .29503 Mdot
.75 .29535 Mdot
.75 .29599 Mdot
.75 .296 Mdot
.75 .29602 Mdot
.75 .29642 Mdot
.75 .29663 Mdot
.75 .29664 Mdot
.75 .29667 Mdot
.75 .29718 Mdot
.75 .29736 Mdot
.75 .29773 Mdot
.75 .29777 Mdot
.75 .2978 Mdot
.75 .29866 Mdot
.75 .29935 Mdot
.75 .29941 Mdot
.75 .29988 Mdot
.75 .30014 Mdot
.75 .30025 Mdot
.75 .30028 Mdot
.75 .30031 Mdot
.75 .30032 Mdot
.75 .30044 Mdot
.75 .30051 Mdot
.75 .30083 Mdot
.75 .30114 Mdot
.75 .30115 Mdot
.75 .30133 Mdot
.75 .30134 Mdot
.75 .30151 Mdot
.75 .30261 Mdot
.75 .3028 Mdot
.75 .3029 Mdot
.75 .30318 Mdot
.75 .30349 Mdot
.75 .30384 Mdot
.75 .30391 Mdot
.75 .30445 Mdot
.75 .30457 Mdot
.75 .30461 Mdot
.75 .30494 Mdot
.75 .30643 Mdot
.75 .30646 Mdot
.75 .30673 Mdot
.75 .3069 Mdot
.75 .30708 Mdot
.75 .3074 Mdot
.75 .30746 Mdot
.75 .30751 Mdot
.75 .30764 Mdot
.75 .30782 Mdot
.75 .30827 Mdot
.75 .30852 Mdot
.75 .30857 Mdot
.75 .30947 Mdot
.75 .31004 Mdot
.75 .3106 Mdot
.75 .31069 Mdot
.75 .31096 Mdot
.75 .31101 Mdot
.75 .31103 Mdot
.75 .31167 Mdot
.75 .31176 Mdot
.75 .31192 Mdot
.75 .31203 Mdot
.75 .31208 Mdot
.75 .3121 Mdot
.75 .31242 Mdot
.75 .31288 Mdot
.75 .31368 Mdot
.75 .31412 Mdot
.75 .31475 Mdot
.75 .31515 Mdot
.75 .31689 Mdot
.75 .31693 Mdot
.75 .31704 Mdot
.75 .31742 Mdot
.75 .31762 Mdot
.75 .31768 Mdot
.75 .31777 Mdot
.75 .31782 Mdot
.75 .31812 Mdot
.75 .31822 Mdot
.75 .31824 Mdot
.75 .31874 Mdot
.75 .31892 Mdot
.75 .32036 Mdot
.75 .32041 Mdot
.75 .32062 Mdot
.75 .3208 Mdot
.75 .3208 Mdot
.75 .32104 Mdot
.75 .32135 Mdot
.75 .32153 Mdot
.75 .32156 Mdot
.75 .32163 Mdot
.75 .32172 Mdot
.75 .32195 Mdot
.75 .32224 Mdot
.75 .32227 Mdot
.75 .32258 Mdot
.75 .32299 Mdot
.75 .32357 Mdot
.75 .32466 Mdot
.75 .32473 Mdot
.75 .32516 Mdot
.75 .32553 Mdot
.75 .32555 Mdot
.75 .32566 Mdot
.75 .32571 Mdot
.75 .32579 Mdot
.75 .3258 Mdot
.75 .32612 Mdot
.75 .32622 Mdot
.75 .3263 Mdot
.75 .32645 Mdot
.75 .32683 Mdot
.75 .32691 Mdot
.75 .3275 Mdot
.75 .32764 Mdot
.75 .32784 Mdot
.75 .32846 Mdot
.75 .32849 Mdot
.75 .32891 Mdot
.75 .32905 Mdot
.75 .32925 Mdot
.75 .32976 Mdot
.75 .32976 Mdot
.75 .32977 Mdot
.75 .33158 Mdot
.75 .33163 Mdot
.75 .33197 Mdot
.75 .33199 Mdot
.75 .3323 Mdot
.75 .33251 Mdot
.75 .33255 Mdot
.75 .33262 Mdot
.75 .33308 Mdot
.75 .33318 Mdot
.75 .33364 Mdot
.75 .33393 Mdot
.75 .33447 Mdot
.75 .33455 Mdot
.75 .33457 Mdot
.75 .33459 Mdot
.75 .33466 Mdot
.75 .33548 Mdot
.75 .33574 Mdot
.75 .33577 Mdot
.75 .33578 Mdot
.75 .33579 Mdot
.75 .33589 Mdot
.75 .33595 Mdot
.75 .3361 Mdot
.75 .33638 Mdot
.75 .33639 Mdot
.75 .33657 Mdot
.75 .33667 Mdot
.75 .33667 Mdot
.75 .33699 Mdot
.75 .33715 Mdot
.75 .33718 Mdot
.75 .33788 Mdot
.75 .3379 Mdot
.75 .33811 Mdot
.75 .33822 Mdot
.75 .33827 Mdot
.75 .33836 Mdot
.75 .33853 Mdot
.75 .33867 Mdot
.75 .33868 Mdot
.75 .33876 Mdot
.75 .33883 Mdot
.75 .33932 Mdot
.75 .33941 Mdot
.75 .33957 Mdot
.75 .33971 Mdot
.75 .33987 Mdot
.75 .34014 Mdot
.75 .34036 Mdot
.75 .34103 Mdot
.75 .34131 Mdot
.75 .34145 Mdot
.75 .34148 Mdot
.75 .3415 Mdot
.75 .34164 Mdot
.75 .34184 Mdot
.75 .34195 Mdot
.75 .34197 Mdot
.75 .34237 Mdot
.75 .34288 Mdot
.75 .34303 Mdot
.75 .34306 Mdot
.75 .34351 Mdot
.75 .34354 Mdot
.75 .34368 Mdot
.75 .34424 Mdot
.75 .34444 Mdot
.75 .34567 Mdot
.75 .34569 Mdot
.75 .34591 Mdot
.75 .34599 Mdot
.75 .34602 Mdot
.75 .34606 Mdot
.75 .34622 Mdot
.75 .34627 Mdot
.75 .34657 Mdot
.75 .34733 Mdot
.75 .34741 Mdot
.75 .34765 Mdot
.75 .34774 Mdot
.75 .34792 Mdot
.75 .34805 Mdot
.75 .3482 Mdot
.75 .34838 Mdot
.75 .34912 Mdot
.75 .34915 Mdot
.75 .34952 Mdot
.75 .34963 Mdot
.75 .34982 Mdot
.75 .34985 Mdot
.75 .34992 Mdot
.75 .35009 Mdot
.75 .35038 Mdot
.75 .35053 Mdot
.75 .35081 Mdot
.75 .35083 Mdot
.75 .35101 Mdot
.75 .35107 Mdot
.75 .35139 Mdot
.75 .35139 Mdot
.75 .35139 Mdot
.75 .3522 Mdot
.75 .35237 Mdot
.75 .35238 Mdot
.75 .35252 Mdot
.75 .35286 Mdot
.75 .35291 Mdot
.75 .35312 Mdot
.75 .35324 Mdot
.75 .35348 Mdot
.75 .35352 Mdot
.75 .35354 Mdot
.75 .35393 Mdot
.75 .35407 Mdot
.75 .35407 Mdot
.75 .35411 Mdot
.75 .35421 Mdot
.75 .35433 Mdot
.75 .35433 Mdot
.75 .35442 Mdot
.75 .35446 Mdot
.75 .3546 Mdot
.75 .35468 Mdot
.75 .35469 Mdot
.75 .355 Mdot
.75 .35501 Mdot
.75 .3551 Mdot
.75 .35517 Mdot
.75 .35535 Mdot
.75 .35535 Mdot
.75 .35539 Mdot
.75 .35542 Mdot
.75 .35564 Mdot
.75 .35575 Mdot
.75 .35581 Mdot
.75 .356 Mdot
.75 .3561 Mdot
.75 .35658 Mdot
.75 .35682 Mdot
.75 .35699 Mdot
.75 .35729 Mdot
.75 .3573 Mdot
.75 .3575 Mdot
.75 .35751 Mdot
.75 .35758 Mdot
.75 .35783 Mdot
.75 .35857 Mdot
.75 .3586 Mdot
.75 .35863 Mdot
.75 .3587 Mdot
.75 .35873 Mdot
.75 .35923 Mdot
.75 .35952 Mdot
.75 .35958 Mdot
.75 .35967 Mdot
.75 .36 Mdot
.75 .36001 Mdot
.75 .36032 Mdot
.75 .36042 Mdot
.75 .36074 Mdot
.75 .361 Mdot
.75 .361 Mdot
.75 .36144 Mdot
.75 .36144 Mdot
.75 .3615 Mdot
.75 .36166 Mdot
.75 .36177 Mdot
.75 .36246 Mdot
.75 .36261 Mdot
.75 .36265 Mdot
.75 .36276 Mdot
.75 .36279 Mdot
.75 .36289 Mdot
.75 .36341 Mdot
.75 .36362 Mdot
.75 .36372 Mdot
.75 .36386 Mdot
.75 .36426 Mdot
.75 .36468 Mdot
.75 .36483 Mdot
.75 .36497 Mdot
.75 .36527 Mdot
.75 .36547 Mdot
.75 .36557 Mdot
.75 .36592 Mdot
.75 .36601 Mdot
.75 .36607 Mdot
.75 .36611 Mdot
.75 .36635 Mdot
.75 .36697 Mdot
.75 .3673 Mdot
.75 .36746 Mdot
.75 .36753 Mdot
.75 .36808 Mdot
.75 .36842 Mdot
.75 .36857 Mdot
.75 .36888 Mdot
.75 .3691 Mdot
.75 .36951 Mdot
.75 .36962 Mdot
.75 .36984 Mdot
.75 .37044 Mdot
.75 .37048 Mdot
.75 .37054 Mdot
.75 .37078 Mdot
.75 .37084 Mdot
.75 .37097 Mdot
.75 .37127 Mdot
.75 .37137 Mdot
.75 .37221 Mdot
.75 .37256 Mdot
.75 .37262 Mdot
.75 .37265 Mdot
.75 .37272 Mdot
.75 .37285 Mdot
.75 .37331 Mdot
.75 .37338 Mdot
.75 .37353 Mdot
.75 .37353 Mdot
.75 .37382 Mdot
.75 .37382 Mdot
.75 .37399 Mdot
.75 .37421 Mdot
.75 .37428 Mdot
.75 .37449 Mdot
.75 .37471 Mdot
.75 .37477 Mdot
.75 .37481 Mdot
.75 .375 Mdot
.75 .37534 Mdot
.75 .37535 Mdot
.75 .3754 Mdot
.75 .37542 Mdot
.75 .37544 Mdot
.75 .37594 Mdot
.75 .37614 Mdot
.75 .3763 Mdot
.75 .37649 Mdot
.75 .37661 Mdot
.75 .37709 Mdot
.75 .37728 Mdot
.75 .37739 Mdot
.75 .37754 Mdot
.75 .37759 Mdot
.75 .37759 Mdot
.75 .37771 Mdot
.75 .37775 Mdot
.75 .37782 Mdot
.75 .37782 Mdot
.75 .37804 Mdot
.75 .37821 Mdot
.75 .37827 Mdot
.75 .37835 Mdot
.75 .37844 Mdot
.75 .37883 Mdot
.75 .37908 Mdot
.75 .37925 Mdot
.75 .37948 Mdot
.75 .37957 Mdot
.75 .37957 Mdot
.75 .37969 Mdot
.75 .38023 Mdot
.75 .38023 Mdot
.75 .38061 Mdot
.75 .3811 Mdot
.75 .38125 Mdot
.75 .38128 Mdot
.75 .38148 Mdot
.75 .38172 Mdot
.75 .38174 Mdot
.75 .38223 Mdot
.75 .38236 Mdot
.75 .38246 Mdot
.75 .38254 Mdot
.75 .38272 Mdot
.75 .38288 Mdot
.75 .38344 Mdot
.75 .38364 Mdot
.75 .38368 Mdot
.75 .38378 Mdot
.75 .38381 Mdot
.75 .38383 Mdot
.75 .38388 Mdot
.75 .38403 Mdot
.75 .38404 Mdot
.75 .38486 Mdot
.75 .38499 Mdot
.75 .38537 Mdot
.75 .38546 Mdot
.75 .38548 Mdot
.75 .38578 Mdot
.75 .3858 Mdot
.75 .3859 Mdot
.75 .38624 Mdot
.75 .38651 Mdot
.75 .38652 Mdot
.75 .3866 Mdot
.75 .38673 Mdot
.75 .38682 Mdot
.75 .38684 Mdot
.75 .38685 Mdot
.75 .38695 Mdot
.75 .38713 Mdot
.75 .38758 Mdot
.75 .38773 Mdot
.75 .38791 Mdot
.75 .38801 Mdot
.75 .3881 Mdot
.75 .38822 Mdot
.75 .38827 Mdot
.75 .3886 Mdot
.75 .38865 Mdot
.75 .3887 Mdot
.75 .38871 Mdot
.75 .3888 Mdot
.75 .38892 Mdot
.75 .38897 Mdot
.75 .38901 Mdot
.75 .38908 Mdot
.75 .38922 Mdot
.75 .38924 Mdot
.75 .3897 Mdot
.75 .38972 Mdot
.75 .38983 Mdot
.75 .39004 Mdot
.75 .39004 Mdot
.75 .39011 Mdot
.75 .39023 Mdot
.75 .39023 Mdot
.75 .39042 Mdot
.75 .39052 Mdot
.75 .39056 Mdot
.75 .39063 Mdot
.75 .39063 Mdot
.75 .39064 Mdot
.75 .39066 Mdot
.75 .39083 Mdot
.75 .39138 Mdot
.75 .39143 Mdot
.75 .39144 Mdot
.75 .39145 Mdot
.75 .39151 Mdot
.75 .39187 Mdot
.75 .39206 Mdot
.75 .39237 Mdot
.75 .39244 Mdot
.75 .39274 Mdot
.75 .39278 Mdot
.75 .39282 Mdot
.75 .39296 Mdot
.75 .39316 Mdot
.75 .39318 Mdot
.75 .3934 Mdot
.75 .39343 Mdot
.75 .39464 Mdot
.75 .39465 Mdot
.75 .39465 Mdot
.75 .39499 Mdot
.75 .39512 Mdot
.75 .39522 Mdot
.75 .39549 Mdot
.75 .39552 Mdot
.75 .39593 Mdot
.75 .39606 Mdot
.75 .39616 Mdot
.75 .39655 Mdot
.75 .3966 Mdot
.75 .39685 Mdot
.75 .39695 Mdot
.75 .39701 Mdot
.75 .39708 Mdot
.75 .39729 Mdot
.75 .39729 Mdot
.75 .39735 Mdot
.75 .39738 Mdot
.75 .39746 Mdot
.75 .39747 Mdot
.75 .39771 Mdot
.75 .398 Mdot
.75 .39805 Mdot
.75 .39877 Mdot
.75 .39916 Mdot
.75 .39944 Mdot
.75 .39964 Mdot
.75 .39966 Mdot
.75 .39986 Mdot
.75 .40001 Mdot
.75 .40007 Mdot
.75 .40012 Mdot
.75 .40013 Mdot
.75 .40025 Mdot
.75 .40046 Mdot
.75 .40062 Mdot
.75 .40062 Mdot
.75 .40074 Mdot
.75 .40088 Mdot
.75 .40092 Mdot
.75 .40187 Mdot
.75 .402 Mdot
.75 .40232 Mdot
.75 .40234 Mdot
.75 .40241 Mdot
.75 .40261 Mdot
.75 .40264 Mdot
.75 .4027 Mdot
.75 .40274 Mdot
.75 .40287 Mdot
.75 .40313 Mdot
.75 .4032 Mdot
.75 .40323 Mdot
.75 .40439 Mdot
.75 .40465 Mdot
.75 .40507 Mdot
.75 .40537 Mdot
.75 .4059 Mdot
.75 .40621 Mdot
.75 .40642 Mdot
.75 .40644 Mdot
.75 .40647 Mdot
.75 .40654 Mdot
.75 .40665 Mdot
.75 .40671 Mdot
.75 .40713 Mdot
.75 .40715 Mdot
.75 .40718 Mdot
.75 .40736 Mdot
.75 .40742 Mdot
.75 .40779 Mdot
.75 .40817 Mdot
.75 .40878 Mdot
.75 .40881 Mdot
.75 .40898 Mdot
.75 .40928 Mdot
.75 .4094 Mdot
.75 .40948 Mdot
.75 .40951 Mdot
.75 .40956 Mdot
.75 .40977 Mdot
.75 .40989 Mdot
.75 .41 Mdot
.75 .41018 Mdot
.75 .4102 Mdot
.75 .41119 Mdot
.75 .41141 Mdot
.75 .41144 Mdot
.75 .41152 Mdot
.75 .41188 Mdot
.75 .41193 Mdot
.75 .41216 Mdot
.75 .41237 Mdot
.75 .41256 Mdot
.75 .41262 Mdot
.75 .41275 Mdot
.75 .41348 Mdot
.75 .41359 Mdot
.75 .4136 Mdot
.75 .41372 Mdot
.75 .41373 Mdot
.75 .41393 Mdot
.75 .41415 Mdot
.75 .4142 Mdot
.75 .41427 Mdot
.75 .41428 Mdot
.75 .4143 Mdot
.75 .41432 Mdot
.75 .4144 Mdot
.75 .41457 Mdot
.75 .41488 Mdot
.75 .41492 Mdot
.75 .41538 Mdot
.75 .41596 Mdot
.75 .41597 Mdot
.75 .416 Mdot
.75 .41625 Mdot
.75 .41637 Mdot
.75 .4167 Mdot
.75 .41673 Mdot
.75 .41673 Mdot
.75 .41688 Mdot
.75 .41714 Mdot
.75 .41715 Mdot
.75 .41716 Mdot
.75 .41759 Mdot
.75 .4178 Mdot
.75 .4179 Mdot
.75 .41793 Mdot
.75 .41805 Mdot
.75 .41806 Mdot
.75 .41808 Mdot
.75 .41813 Mdot
.75 .41851 Mdot
.75 .4186 Mdot
.75 .41974 Mdot
.75 .41985 Mdot
.75 .41987 Mdot
.75 .4199 Mdot
.75 .42003 Mdot
.75 .42043 Mdot
.75 .42059 Mdot
.75 .42084 Mdot
.75 .42126 Mdot
.75 .42137 Mdot
.75 .42162 Mdot
.75 .42173 Mdot
.75 .42181 Mdot
.75 .42188 Mdot
.75 .42196 Mdot
.75 .42212 Mdot
.75 .42225 Mdot
.75 .4228 Mdot
.75 .42285 Mdot
.75 .4229 Mdot
.75 .42297 Mdot
.75 .42329 Mdot
.75 .42355 Mdot
.75 .42372 Mdot
.75 .42375 Mdot
.75 .42378 Mdot
.75 .42383 Mdot
.75 .42394 Mdot
.75 .42429 Mdot
.75 .42436 Mdot
.75 .42517 Mdot
.75 .42547 Mdot
.75 .42582 Mdot
.75 .42602 Mdot
.75 .42617 Mdot
.75 .42634 Mdot
.75 .4266 Mdot
.75 .42708 Mdot
.75 .42709 Mdot
.75 .4271 Mdot
.75 .42715 Mdot
.75 .42739 Mdot
.75 .42786 Mdot
.75 .42816 Mdot
.75 .42836 Mdot
.75 .42837 Mdot
.75 .42891 Mdot
.75 .42899 Mdot
.75 .42905 Mdot
.75 .42926 Mdot
.75 .42998 Mdot
.75 .43017 Mdot
.75 .43027 Mdot
.75 .43046 Mdot
.75 .43049 Mdot
.75 .43053 Mdot
.75 .43058 Mdot
.75 .43082 Mdot
.75 .43137 Mdot
.75 .43149 Mdot
.75 .43205 Mdot
.75 .43228 Mdot
.75 .4324 Mdot
.75 .43255 Mdot
.75 .43303 Mdot
.75 .43305 Mdot
.75 .43316 Mdot
.75 .43324 Mdot
.75 .43338 Mdot
.75 .43341 Mdot
.75 .43344 Mdot
.75 .4336 Mdot
.75 .43399 Mdot
.75 .43446 Mdot
.75 .43457 Mdot
.75 .43461 Mdot
.75 .43462 Mdot
.75 .43464 Mdot
.75 .43474 Mdot
.75 .4349 Mdot
.75 .43497 Mdot
.75 .43519 Mdot
.75 .43567 Mdot
.75 .43637 Mdot
.75 .43663 Mdot
.75 .43665 Mdot
.75 .43667 Mdot
.75 .43725 Mdot
.75 .43727 Mdot
.75 .43759 Mdot
.75 .4376 Mdot
.75 .43765 Mdot
.75 .43787 Mdot
.75 .43833 Mdot
.75 .43837 Mdot
.75 .43842 Mdot
.75 .43868 Mdot
.75 .43881 Mdot
.75 .43916 Mdot
.75 .43924 Mdot
.75 .43929 Mdot
.75 .4393 Mdot
.75 .43934 Mdot
.75 .4394 Mdot
.75 .43943 Mdot
.75 .4397 Mdot
.75 .44017 Mdot
.75 .44053 Mdot
.75 .44054 Mdot
.75 .44064 Mdot
.75 .4408 Mdot
.75 .44112 Mdot
.75 .4412 Mdot
.75 .44167 Mdot
.75 .44176 Mdot
.75 .44247 Mdot
.75 .44285 Mdot
.75 .44302 Mdot
.75 .44306 Mdot
.75 .4431 Mdot
.75 .44312 Mdot
.75 .4433 Mdot
.75 .44335 Mdot
.75 .4434 Mdot
.75 .44362 Mdot
.75 .44389 Mdot
.75 .44435 Mdot
.75 .44437 Mdot
.75 .44437 Mdot
.75 .44439 Mdot
.75 .44455 Mdot
.75 .44464 Mdot
.75 .44466 Mdot
.75 .4449 Mdot
.75 .445 Mdot
.75 .44508 Mdot
.75 .44521 Mdot
.75 .4453 Mdot
.75 .4456 Mdot
.75 .44617 Mdot
.75 .44634 Mdot
.75 .4464 Mdot
.75 .44656 Mdot
.75 .44685 Mdot
.75 .44699 Mdot
.75 .44741 Mdot
.75 .44787 Mdot
.75 .4484 Mdot
.75 .4485 Mdot
.75 .44901 Mdot
.75 .44932 Mdot
.75 .4495 Mdot
.75 .44956 Mdot
.75 .44961 Mdot
.75 .45006 Mdot
.75 .45055 Mdot
.75 .45121 Mdot
.75 .45229 Mdot
.75 .45233 Mdot
.75 .45242 Mdot
.75 .45274 Mdot
.75 .45299 Mdot
.75 .45311 Mdot
.75 .45327 Mdot
.75 .45358 Mdot
.75 .45362 Mdot
.75 .45368 Mdot
.75 .45374 Mdot
.75 .45383 Mdot
.75 .45386 Mdot
.75 .45391 Mdot
.75 .45409 Mdot
.75 .4541 Mdot
.75 .45422 Mdot
.75 .45437 Mdot
.75 .45505 Mdot
.75 .45519 Mdot
.75 .45521 Mdot
.75 .4553 Mdot
.75 .45542 Mdot
.75 .45549 Mdot
.75 .4557 Mdot
.75 .45583 Mdot
.75 .45667 Mdot
.75 .45685 Mdot
.752 .23525 Mdot
.752 .23625 Mdot
.752 .23694 Mdot
.752 .23768 Mdot
.752 .23803 Mdot
.752 .23807 Mdot
.752 .23874 Mdot
.752 .23903 Mdot
.752 .23997 Mdot
.752 .24042 Mdot
.752 .24072 Mdot
.752 .24126 Mdot
.752 .24141 Mdot
.752 .24184 Mdot
.752 .24309 Mdot
.752 .24314 Mdot
.752 .24321 Mdot
.752 .24321 Mdot
.752 .24369 Mdot
.752 .24406 Mdot
.752 .24408 Mdot
.752 .2441 Mdot
.752 .24424 Mdot
.752 .24437 Mdot
.752 .24451 Mdot
.752 .2448 Mdot
.752 .24484 Mdot
.752 .24518 Mdot
.752 .24528 Mdot
.752 .24546 Mdot
.752 .24566 Mdot
.752 .24714 Mdot
.752 .2473 Mdot
.752 .24788 Mdot
.752 .24814 Mdot
.752 .24821 Mdot
.752 .24828 Mdot
.752 .24903 Mdot
.752 .24923 Mdot
.752 .24932 Mdot
.752 .24963 Mdot
.752 .24964 Mdot
.752 .24984 Mdot
.752 .24996 Mdot
.752 .25004 Mdot
.752 .25014 Mdot
.752 .25073 Mdot
.752 .25177 Mdot
.752 .25243 Mdot
.752 .25292 Mdot
.752 .25305 Mdot
.752 .25311 Mdot
.752 .25338 Mdot
.752 .25344 Mdot
.752 .25367 Mdot
.752 .25374 Mdot
.752 .2541 Mdot
.752 .25426 Mdot
.752 .25434 Mdot
.752 .25459 Mdot
.752 .25471 Mdot
.752 .2557 Mdot
.752 .25578 Mdot
.752 .25597 Mdot
.752 .2566 Mdot
.752 .25668 Mdot
.752 .25744 Mdot
.752 .25746 Mdot
.752 .25815 Mdot
.752 .25903 Mdot
.752 .25944 Mdot
.752 .25947 Mdot
.752 .25959 Mdot
.752 .25963 Mdot
.752 .25978 Mdot
.752 .2601 Mdot
.752 .26036 Mdot
.752 .26055 Mdot
.752 .26076 Mdot
.752 .26079 Mdot
.752 .261 Mdot
.752 .26132 Mdot
.752 .2618 Mdot
.752 .26218 Mdot
.752 .26316 Mdot
.752 .26318 Mdot
.752 .26324 Mdot
.752 .26354 Mdot
.752 .26389 Mdot
.752 .26484 Mdot
.752 .26538 Mdot
.752 .26547 Mdot
.752 .26563 Mdot
.752 .26596 Mdot
.752 .26609 Mdot
.752 .26676 Mdot
.752 .26756 Mdot
.752 .26757 Mdot
.752 .26764 Mdot
.752 .26785 Mdot
.752 .26803 Mdot
.752 .26827 Mdot
.752 .26842 Mdot
.752 .26848 Mdot
.752 .26877 Mdot
.752 .27007 Mdot
.752 .27144 Mdot
.752 .27174 Mdot
.752 .27267 Mdot
.752 .27279 Mdot
.752 .27286 Mdot
.752 .273 Mdot
.752 .27362 Mdot
.752 .27412 Mdot
.752 .27444 Mdot
.752 .27467 Mdot
.752 .27475 Mdot
.752 .27475 Mdot
.752 .27494 Mdot
.752 .2758 Mdot
.752 .27615 Mdot
.752 .27648 Mdot
.752 .27721 Mdot
.752 .27722 Mdot
.752 .27759 Mdot
.752 .27768 Mdot
.752 .27845 Mdot
.752 .27853 Mdot
.752 .27899 Mdot
.752 .27941 Mdot
.752 .27948 Mdot
.752 .27948 Mdot
.752 .27956 Mdot
.752 .2799 Mdot
.752 .28002 Mdot
.752 .28021 Mdot
.752 .28044 Mdot
.752 .28068 Mdot
.752 .28084 Mdot
.752 .28085 Mdot
.752 .28131 Mdot
.752 .28139 Mdot
.752 .28142 Mdot
.752 .28146 Mdot
.752 .28161 Mdot
.752 .28214 Mdot
.752 .2826 Mdot
.752 .283 Mdot
.752 .28315 Mdot
.752 .28322 Mdot
.752 .28426 Mdot
.752 .28442 Mdot
.752 .28487 Mdot
.752 .28496 Mdot
.752 .28521 Mdot
.752 .28542 Mdot
.752 .28545 Mdot
.752 .28573 Mdot
.752 .28643 Mdot
.752 .28648 Mdot
.752 .28667 Mdot
.752 .28675 Mdot
.752 .28686 Mdot
.752 .28729 Mdot
.752 .28731 Mdot
.752 .28739 Mdot
.752 .28755 Mdot
.752 .28782 Mdot
.752 .28837 Mdot
.752 .28855 Mdot
.752 .28899 Mdot
.752 .28905 Mdot
.752 .28908 Mdot
.752 .2894 Mdot
.752 .28961 Mdot
.752 .28969 Mdot
.752 .29015 Mdot
.752 .29073 Mdot
.752 .29077 Mdot
.752 .29093 Mdot
.752 .29156 Mdot
.752 .29193 Mdot
.752 .29202 Mdot
.752 .2923 Mdot
.752 .29289 Mdot
.752 .29466 Mdot
.752 .29479 Mdot
.752 .29482 Mdot
.752 .29516 Mdot
.752 .2952 Mdot
.752 .2952 Mdot
.752 .29555 Mdot
.752 .29605 Mdot
.752 .29616 Mdot
.752 .2964 Mdot
.752 .29711 Mdot
.752 .29758 Mdot
.752 .2983 Mdot
.752 .29864 Mdot
.752 .29872 Mdot
.752 .29879 Mdot
.752 .29897 Mdot
.752 .29936 Mdot
.752 .29967 Mdot
.752 .30001 Mdot
.752 .30004 Mdot
.752 .30041 Mdot
.752 .30044 Mdot
.752 .30093 Mdot
.752 .30104 Mdot
.752 .30144 Mdot
.752 .30147 Mdot
.752 .30189 Mdot
.752 .30218 Mdot
.752 .30294 Mdot
.752 .30298 Mdot
.752 .30312 Mdot
.752 .30313 Mdot
.752 .30326 Mdot
.752 .3033 Mdot
.752 .30339 Mdot
.752 .30375 Mdot
.752 .30378 Mdot
.752 .30423 Mdot
.752 .30526 Mdot
.752 .30545 Mdot
.752 .30596 Mdot
.752 .30597 Mdot
.752 .30682 Mdot
.752 .30706 Mdot
.752 .3072 Mdot
.752 .3074 Mdot
.752 .30781 Mdot
.752 .30824 Mdot
.752 .30826 Mdot
.752 .30841 Mdot
.752 .30991 Mdot
.752 .31035 Mdot
.752 .31066 Mdot
.752 .31145 Mdot
.752 .31263 Mdot
.752 .31282 Mdot
.752 .31338 Mdot
.752 .3134 Mdot
.752 .31364 Mdot
.752 .31381 Mdot
.752 .31381 Mdot
.752 .31382 Mdot
.752 .31388 Mdot
.752 .314 Mdot
.752 .31415 Mdot
.752 .3143 Mdot
.752 .31435 Mdot
.752 .31442 Mdot
.752 .31451 Mdot
.752 .31524 Mdot
.752 .31549 Mdot
.752 .31567 Mdot
.752 .31636 Mdot
.752 .31649 Mdot
.752 .31676 Mdot
.752 .31772 Mdot
.752 .31778 Mdot
.752 .3178 Mdot
.752 .31805 Mdot
.752 .31809 Mdot
.752 .31825 Mdot
.752 .31831 Mdot
.752 .31851 Mdot
.752 .31907 Mdot
.752 .31973 Mdot
.752 .32062 Mdot
.752 .32069 Mdot
.752 .32089 Mdot
.752 .32101 Mdot
.752 .32119 Mdot
.752 .3212 Mdot
.752 .3213 Mdot
.752 .32143 Mdot
.752 .32165 Mdot
.752 .32225 Mdot
.752 .32226 Mdot
.752 .32242 Mdot
.752 .32257 Mdot
.752 .32327 Mdot
.752 .32349 Mdot
.752 .32355 Mdot
.752 .32432 Mdot
.752 .3244 Mdot
.752 .32451 Mdot
.752 .3253 Mdot
.752 .32591 Mdot
.752 .32604 Mdot
.752 .32645 Mdot
.752 .32654 Mdot
.752 .3266 Mdot
.752 .32687 Mdot
.752 .32724 Mdot
.752 .32734 Mdot
.752 .32737 Mdot
.752 .32799 Mdot
.752 .32814 Mdot
.752 .32846 Mdot
.752 .32901 Mdot
.752 .32904 Mdot
.752 .32943 Mdot
.752 .32946 Mdot
.752 .32946 Mdot
.752 .3295 Mdot
.752 .32965 Mdot
.752 .32989 Mdot
.752 .33006 Mdot
.752 .33007 Mdot
.752 .33027 Mdot
.752 .33032 Mdot
.752 .33064 Mdot
.752 .33109 Mdot
.752 .33112 Mdot
.752 .33165 Mdot
.752 .33189 Mdot
.752 .33222 Mdot
.752 .33256 Mdot
.752 .33268 Mdot
.752 .33292 Mdot
.752 .33303 Mdot
.752 .33315 Mdot
.752 .3334 Mdot
.752 .33347 Mdot
.752 .3337 Mdot
.752 .33371 Mdot
.752 .33385 Mdot
.752 .33445 Mdot
.752 .3348 Mdot
.752 .33501 Mdot
.752 .33539 Mdot
.752 .33623 Mdot
.752 .33641 Mdot
.752 .33641 Mdot
.752 .33657 Mdot
.752 .33684 Mdot
.752 .33694 Mdot
.752 .33746 Mdot
.752 .33825 Mdot
.752 .33839 Mdot
.752 .33873 Mdot
.752 .339 Mdot
.752 .33917 Mdot
.752 .33985 Mdot
.752 .34 Mdot
.752 .34003 Mdot
.752 .3402 Mdot
.752 .34021 Mdot
.752 .34117 Mdot
.752 .34117 Mdot
.752 .34155 Mdot
.752 .34166 Mdot
.752 .34199 Mdot
.752 .34225 Mdot
.752 .34311 Mdot
.752 .34412 Mdot
.752 .3442 Mdot
.752 .34446 Mdot
.752 .34457 Mdot
.752 .34464 Mdot
.752 .34467 Mdot
.752 .34479 Mdot
.752 .34486 Mdot
.752 .34488 Mdot
.752 .34491 Mdot
.752 .34538 Mdot
.752 .34546 Mdot
.752 .34583 Mdot
.752 .34594 Mdot
.752 .34637 Mdot
.752 .34641 Mdot
.752 .34652 Mdot
.752 .34663 Mdot
.752 .34697 Mdot
.752 .34726 Mdot
.752 .34768 Mdot
.752 .34777 Mdot
.752 .34782 Mdot
.752 .3479 Mdot
.752 .34791 Mdot
.752 .34801 Mdot
.752 .3481 Mdot
.752 .34837 Mdot
.752 .34837 Mdot
.752 .34845 Mdot
.752 .34851 Mdot
.752 .34882 Mdot
.752 .34892 Mdot
.752 .34894 Mdot
.752 .34929 Mdot
.752 .34937 Mdot
.752 .34972 Mdot
.752 .34999 Mdot
.752 .35005 Mdot
.752 .35023 Mdot
.752 .35027 Mdot
.752 .35029 Mdot
.752 .35042 Mdot
.752 .35058 Mdot
.752 .35064 Mdot
.752 .35138 Mdot
.752 .35156 Mdot
.752 .35156 Mdot
.752 .35158 Mdot
.752 .35164 Mdot
.752 .35192 Mdot
.752 .35194 Mdot
.752 .35208 Mdot
.752 .35228 Mdot
.752 .35229 Mdot
.752 .35253 Mdot
.752 .35278 Mdot
.752 .35293 Mdot
.752 .35298 Mdot
.752 .35309 Mdot
.752 .35314 Mdot
.752 .35319 Mdot
.752 .35333 Mdot
.752 .35344 Mdot
.752 .3535 Mdot
.752 .35418 Mdot
.752 .35463 Mdot
.752 .35463 Mdot
.752 .3547 Mdot
.752 .35482 Mdot
.752 .35487 Mdot
.752 .3551 Mdot
.752 .35545 Mdot
.752 .35566 Mdot
.752 .35577 Mdot
.752 .3563 Mdot
.752 .35631 Mdot
.752 .35674 Mdot
.752 .35674 Mdot
.752 .3569 Mdot
.752 .35695 Mdot
.752 .3571 Mdot
.752 .35804 Mdot
.752 .35819 Mdot
.752 .35824 Mdot
.752 .35827 Mdot
.752 .35828 Mdot
.752 .35834 Mdot
.752 .35837 Mdot
.752 .35837 Mdot
.752 .35879 Mdot
.752 .3591 Mdot
.752 .3591 Mdot
.752 .35915 Mdot
.752 .35943 Mdot
.752 .35965 Mdot
.752 .35968 Mdot
.752 .35971 Mdot
.752 .35992 Mdot
.752 .35998 Mdot
.752 .36012 Mdot
.752 .36016 Mdot
.752 .36032 Mdot
.752 .36052 Mdot
.752 .36063 Mdot
.752 .36074 Mdot
.752 .36076 Mdot
.752 .36077 Mdot
.752 .36082 Mdot
.752 .36133 Mdot
.752 .36133 Mdot
.752 .36134 Mdot
.752 .36149 Mdot
.752 .3615 Mdot
.752 .36165 Mdot
.752 .36165 Mdot
.752 .36176 Mdot
.752 .36187 Mdot
.752 .36201 Mdot
.752 .36203 Mdot
.752 .36205 Mdot
.752 .36211 Mdot
.752 .36216 Mdot
.752 .36269 Mdot
.752 .36277 Mdot
.752 .36289 Mdot
.752 .36319 Mdot
.752 .36371 Mdot
.752 .36378 Mdot
.752 .36419 Mdot
.752 .36428 Mdot
.752 .3643 Mdot
.752 .36432 Mdot
.752 .36453 Mdot
.752 .36466 Mdot
.752 .36534 Mdot
.752 .36539 Mdot
.752 .36539 Mdot
.752 .36565 Mdot
.752 .36579 Mdot
.752 .36579 Mdot
.752 .36589 Mdot
.752 .36595 Mdot
.752 .36599 Mdot
.752 .36625 Mdot
.752 .3667 Mdot
.752 .36673 Mdot
.752 .36691 Mdot
.752 .36697 Mdot
.752 .36712 Mdot
.752 .36742 Mdot
.752 .36744 Mdot
.752 .36756 Mdot
.752 .36769 Mdot
.752 .36782 Mdot
.752 .36802 Mdot
.752 .36804 Mdot
.752 .36812 Mdot
.752 .36814 Mdot
.752 .36835 Mdot
.752 .36846 Mdot
.752 .36852 Mdot
.752 .36865 Mdot
.752 .3688 Mdot
.752 .36948 Mdot
.752 .36969 Mdot
.752 .3697 Mdot
.752 .3699 Mdot
.752 .36999 Mdot
.752 .37015 Mdot
.752 .37046 Mdot
.752 .3705 Mdot
.752 .37063 Mdot
.752 .37064 Mdot
.752 .37095 Mdot
.752 .37115 Mdot
.752 .37125 Mdot
.752 .37135 Mdot
.752 .37152 Mdot
.752 .37155 Mdot
.752 .372 Mdot
.752 .37222 Mdot
.752 .37224 Mdot
.752 .37231 Mdot
.752 .37259 Mdot
.752 .37263 Mdot
.752 .37298 Mdot
.752 .37318 Mdot
.752 .37326 Mdot
.752 .37331 Mdot
.752 .37366 Mdot
.752 .3737 Mdot
.752 .37375 Mdot
.752 .37377 Mdot
.752 .37386 Mdot
.752 .374 Mdot
.752 .37401 Mdot
.752 .3741 Mdot
.752 .37421 Mdot
.752 .37422 Mdot
.752 .3746 Mdot
.752 .37461 Mdot
.752 .37468 Mdot
.752 .37476 Mdot
.752 .37499 Mdot
.752 .37511 Mdot
.752 .37548 Mdot
.752 .37567 Mdot
.752 .3757 Mdot
.752 .3759 Mdot
.752 .37621 Mdot
.752 .37624 Mdot
.752 .37627 Mdot
.752 .3764 Mdot
.752 .37703 Mdot
.752 .37713 Mdot
.752 .37716 Mdot
.752 .37727 Mdot
.752 .37727 Mdot
.752 .37756 Mdot
.752 .37791 Mdot
.752 .37836 Mdot
.752 .37851 Mdot
.752 .37854 Mdot
.752 .37862 Mdot
.752 .37867 Mdot
.752 .37946 Mdot
.752 .37953 Mdot
.752 .37963 Mdot
.752 .37966 Mdot
.752 .37969 Mdot
.752 .37977 Mdot
.752 .3798 Mdot
.752 .3799 Mdot
.752 .38007 Mdot
.752 .38023 Mdot
.752 .38023 Mdot
.752 .38046 Mdot
.752 .38047 Mdot
.752 .3807 Mdot
.752 .38071 Mdot
.752 .38071 Mdot
.752 .38083 Mdot
.752 .38147 Mdot
.752 .38155 Mdot
.752 .38157 Mdot
.752 .3816 Mdot
.752 .38176 Mdot
.752 .38193 Mdot
.752 .38217 Mdot
.752 .38222 Mdot
.752 .38247 Mdot
.752 .38253 Mdot
.752 .38274 Mdot
.752 .38278 Mdot
.752 .38283 Mdot
.752 .38283 Mdot
.752 .38301 Mdot
.752 .38307 Mdot
.752 .38314 Mdot
.752 .3832 Mdot
.752 .38323 Mdot
.752 .38329 Mdot
.752 .38357 Mdot
.752 .38377 Mdot
.752 .38399 Mdot
.752 .38406 Mdot
.752 .38407 Mdot
.752 .38416 Mdot
.752 .38445 Mdot
.752 .38452 Mdot
.752 .38477 Mdot
.752 .38482 Mdot
.752 .38513 Mdot
.752 .38516 Mdot
.752 .38517 Mdot
.752 .38521 Mdot
.752 .38529 Mdot
.752 .38531 Mdot
.752 .38536 Mdot
.752 .38543 Mdot
.752 .3856 Mdot
.752 .38566 Mdot
.752 .38633 Mdot
.752 .3869 Mdot
.752 .38708 Mdot
.752 .3873 Mdot
.752 .38737 Mdot
.752 .38762 Mdot
.752 .38762 Mdot
.752 .38826 Mdot
.752 .38827 Mdot
.752 .38837 Mdot
.752 .3884 Mdot
.752 .3885 Mdot
.752 .38895 Mdot
.752 .38907 Mdot
.752 .38924 Mdot
.752 .38947 Mdot
.752 .38956 Mdot
.752 .39008 Mdot
.752 .39043 Mdot
.752 .3905 Mdot
.752 .39068 Mdot
.752 .39078 Mdot
.752 .39078 Mdot
.752 .3909 Mdot
.752 .39146 Mdot
.752 .39172 Mdot
.752 .39185 Mdot
.752 .39209 Mdot
.752 .39249 Mdot
.752 .39258 Mdot
.752 .39259 Mdot
.752 .39274 Mdot
.752 .39279 Mdot
.752 .39295 Mdot
.752 .39303 Mdot
.752 .3931 Mdot
.752 .39327 Mdot
.752 .39335 Mdot
.752 .39357 Mdot
.752 .39379 Mdot
.752 .39395 Mdot
.752 .39431 Mdot
.752 .39433 Mdot
.752 .39462 Mdot
.752 .39483 Mdot
.752 .39486 Mdot
.752 .395 Mdot
.752 .395 Mdot
.752 .39512 Mdot
.752 .39528 Mdot
.752 .39538 Mdot
.752 .3954 Mdot
.752 .3954 Mdot
.752 .39542 Mdot
.752 .39568 Mdot
.752 .39571 Mdot
.752 .39607 Mdot
.752 .39629 Mdot
.752 .39638 Mdot
.752 .39679 Mdot
.752 .39682 Mdot
.752 .39688 Mdot
.752 .39712 Mdot
.752 .39731 Mdot
.752 .39735 Mdot
.752 .3974 Mdot
.752 .39768 Mdot
.752 .39777 Mdot
.752 .39817 Mdot
.752 .3987 Mdot
.752 .39877 Mdot
.752 .39882 Mdot
.752 .39934 Mdot
.752 .39938 Mdot
.752 .39952 Mdot
.752 .39999 Mdot
.752 .40009 Mdot
.752 .4002 Mdot
.752 .4002 Mdot
.752 .4006 Mdot
.752 .40074 Mdot
.752 .40083 Mdot
.752 .4009 Mdot
.752 .40091 Mdot
.752 .40102 Mdot
.752 .4011 Mdot
.752 .40124 Mdot
.752 .40128 Mdot
.752 .40188 Mdot
.752 .40232 Mdot
.752 .40268 Mdot
.752 .40282 Mdot
.752 .40286 Mdot
.752 .40297 Mdot
.752 .40299 Mdot
.752 .40316 Mdot
.752 .40317 Mdot
.752 .40321 Mdot
.752 .40385 Mdot
.752 .40403 Mdot
.752 .40411 Mdot
.752 .40457 Mdot
.752 .40469 Mdot
.752 .40486 Mdot
.752 .40535 Mdot
.752 .4054 Mdot
.752 .40546 Mdot
.752 .40549 Mdot
.752 .40559 Mdot
.752 .40568 Mdot
.752 .40576 Mdot
.752 .4058 Mdot
.752 .40581 Mdot
.752 .40581 Mdot
.752 .40592 Mdot
.752 .40608 Mdot
.752 .4061 Mdot
.752 .40647 Mdot
.752 .4066 Mdot
.752 .40738 Mdot
.752 .40791 Mdot
.752 .40811 Mdot
.752 .4084 Mdot
.752 .4094 Mdot
.752 .4095 Mdot
.752 .40952 Mdot
.752 .4098 Mdot
.752 .41008 Mdot
.752 .41021 Mdot
.752 .4103 Mdot
.752 .41046 Mdot
.752 .41103 Mdot
.752 .41103 Mdot
.752 .41137 Mdot
.752 .4115 Mdot
.752 .41218 Mdot
.752 .41248 Mdot
.752 .4125 Mdot
.752 .41274 Mdot
.752 .4128 Mdot
.752 .41282 Mdot
.752 .41291 Mdot
.752 .41292 Mdot
.752 .41301 Mdot
.752 .41304 Mdot
.752 .41355 Mdot
.752 .41374 Mdot
.752 .41402 Mdot
.752 .41403 Mdot
.752 .4143 Mdot
.752 .41437 Mdot
.752 .4147 Mdot
.752 .41472 Mdot
.752 .41496 Mdot
.752 .41499 Mdot
.752 .41521 Mdot
.752 .41542 Mdot
.752 .41568 Mdot
.752 .4158 Mdot
.752 .41584 Mdot
.752 .4159 Mdot
.752 .41612 Mdot
.752 .4166 Mdot
.752 .41692 Mdot
.752 .41739 Mdot
.752 .41755 Mdot
.752 .41762 Mdot
.752 .41795 Mdot
.752 .41819 Mdot
.752 .41819 Mdot
.752 .41821 Mdot
.752 .41844 Mdot
.752 .41846 Mdot
.752 .41854 Mdot
.752 .41972 Mdot
.752 .42011 Mdot
.752 .4203 Mdot
.752 .42036 Mdot
.752 .42061 Mdot
.752 .42102 Mdot
.752 .42113 Mdot
.752 .42116 Mdot
.752 .42155 Mdot
.752 .42185 Mdot
.752 .4219 Mdot
.752 .42204 Mdot
.752 .42225 Mdot
.752 .42227 Mdot
.752 .42232 Mdot
.752 .42261 Mdot
.752 .42272 Mdot
.752 .4231 Mdot
.752 .42327 Mdot
.752 .42338 Mdot
.752 .42343 Mdot
.752 .42345 Mdot
.752 .42373 Mdot
.752 .4238 Mdot
.752 .42386 Mdot
.752 .42399 Mdot
.752 .42402 Mdot
.752 .42448 Mdot
.752 .42467 Mdot
.752 .42469 Mdot
.752 .42482 Mdot
.752 .425 Mdot
.752 .42506 Mdot
.752 .42535 Mdot
.752 .42546 Mdot
.752 .42615 Mdot
.752 .4262 Mdot
.752 .4263 Mdot
.752 .42656 Mdot
.752 .42687 Mdot
.752 .42722 Mdot
.752 .42732 Mdot
.752 .42735 Mdot
.752 .42737 Mdot
.752 .42742 Mdot
.752 .42772 Mdot
.752 .42773 Mdot
.752 .42784 Mdot
.752 .428 Mdot
.752 .42815 Mdot
.752 .42828 Mdot
.752 .42836 Mdot
.752 .42859 Mdot
.752 .42864 Mdot
.752 .42864 Mdot
.752 .42868 Mdot
.752 .42896 Mdot
.752 .42927 Mdot
.752 .42932 Mdot
.752 .42984 Mdot
.752 .4299 Mdot
.752 .43014 Mdot
.752 .43015 Mdot
.752 .43063 Mdot
.752 .43085 Mdot
.752 .43109 Mdot
.752 .43165 Mdot
.752 .43178 Mdot
.752 .43178 Mdot
.752 .43184 Mdot
.752 .43199 Mdot
.752 .4322 Mdot
.752 .43253 Mdot
.752 .43295 Mdot
.752 .43304 Mdot
.752 .43308 Mdot
.752 .43316 Mdot
.752 .43378 Mdot
.752 .43398 Mdot
.752 .43489 Mdot
.752 .43576 Mdot
.752 .43595 Mdot
.752 .43599 Mdot
.752 .43609 Mdot
.752 .43625 Mdot
.752 .43637 Mdot
.752 .43651 Mdot
.752 .43656 Mdot
.752 .43656 Mdot
.752 .43709 Mdot
.752 .43754 Mdot
.752 .43763 Mdot
.752 .43785 Mdot
.752 .43795 Mdot
.752 .43801 Mdot
.752 .43837 Mdot
.752 .43901 Mdot
.752 .43924 Mdot
.752 .43944 Mdot
.752 .43948 Mdot
.752 .43949 Mdot
.752 .44014 Mdot
.752 .44039 Mdot
.752 .44071 Mdot
.752 .44092 Mdot
.752 .44106 Mdot
.752 .44108 Mdot
.752 .44123 Mdot
.752 .44135 Mdot
.752 .44153 Mdot
.752 .44174 Mdot
.752 .44183 Mdot
.752 .44186 Mdot
.752 .44194 Mdot
.752 .44196 Mdot
.752 .44223 Mdot
.752 .44282 Mdot
.752 .44328 Mdot
.752 .44329 Mdot
.752 .4438 Mdot
.752 .44385 Mdot
.752 .44427 Mdot
.752 .4444 Mdot
.752 .44445 Mdot
.752 .44511 Mdot
.752 .44519 Mdot
.752 .44535 Mdot
.752 .4454 Mdot
.752 .44551 Mdot
.752 .44575 Mdot
.752 .4458 Mdot
.752 .44595 Mdot
.752 .44599 Mdot
.752 .44617 Mdot
.752 .44621 Mdot
.752 .4463 Mdot
.752 .44662 Mdot
.752 .44706 Mdot
.752 .44775 Mdot
.752 .44814 Mdot
.752 .44821 Mdot
.752 .44827 Mdot
.752 .44834 Mdot
.752 .44848 Mdot
.752 .44849 Mdot
.752 .44869 Mdot
.752 .44875 Mdot
.752 .44888 Mdot
.752 .44938 Mdot
.752 .44943 Mdot
.752 .44947 Mdot
.752 .44965 Mdot
.752 .45003 Mdot
.752 .45014 Mdot
.752 .45113 Mdot
.752 .45126 Mdot
.752 .45138 Mdot
.752 .45145 Mdot
.752 .45167 Mdot
.752 .45169 Mdot
.752 .45189 Mdot
.752 .45198 Mdot
.752 .45207 Mdot
.752 .45216 Mdot
.752 .45218 Mdot
.752 .45219 Mdot
.752 .45243 Mdot
.752 .45275 Mdot
.752 .45276 Mdot
.752 .4528 Mdot
.752 .45283 Mdot
.752 .45366 Mdot
.752 .45395 Mdot
.752 .45405 Mdot
.752 .45441 Mdot
.752 .45461 Mdot
.752 .45491 Mdot
.752 .45553 Mdot
.752 .45573 Mdot
.752 .45617 Mdot
.752 .4562 Mdot
.752 .45643 Mdot
.752 .45692 Mdot
.752 .45738 Mdot
.752 .45804 Mdot
.754 .23365 Mdot
.754 .23376 Mdot
.754 .23381 Mdot
.754 .23454 Mdot
.754 .23569 Mdot
.754 .23659 Mdot
.754 .23692 Mdot
.754 .23746 Mdot
.754 .23749 Mdot
.754 .23758 Mdot
.754 .23785 Mdot
.754 .23888 Mdot
.754 .23918 Mdot
.754 .23929 Mdot
.754 .2394 Mdot
.754 .2403 Mdot
.754 .24049 Mdot
.754 .24051 Mdot
.754 .24097 Mdot
.754 .2413 Mdot
.754 .24138 Mdot
.754 .24154 Mdot
.754 .24206 Mdot
.754 .2423 Mdot
.754 .24234 Mdot
.754 .24268 Mdot
.754 .24273 Mdot
.754 .24304 Mdot
.754 .24323 Mdot
.754 .24324 Mdot
.754 .24362 Mdot
.754 .24372 Mdot
.754 .24568 Mdot
.754 .24641 Mdot
.754 .24703 Mdot
.754 .24708 Mdot
.754 .24741 Mdot
.754 .24749 Mdot
.754 .24756 Mdot
.754 .24766 Mdot
.754 .24794 Mdot
.754 .24839 Mdot
.754 .24913 Mdot
.754 .24929 Mdot
.754 .24967 Mdot
.754 .24983 Mdot
.754 .25037 Mdot
.754 .25038 Mdot
.754 .25039 Mdot
.754 .25048 Mdot
.754 .2506 Mdot
.754 .25097 Mdot
.754 .25102 Mdot
.754 .2511 Mdot
.754 .25191 Mdot
.754 .2525 Mdot
.754 .25253 Mdot
.754 .25279 Mdot
.754 .25311 Mdot
.754 .25313 Mdot
.754 .25368 Mdot
.754 .25389 Mdot
.754 .25413 Mdot
.754 .25449 Mdot
.754 .25488 Mdot
.754 .25568 Mdot
.754 .25585 Mdot
.754 .25587 Mdot
.754 .25607 Mdot
.754 .25698 Mdot
.754 .25711 Mdot
.754 .25728 Mdot
.754 .25764 Mdot
.754 .25829 Mdot
.754 .25891 Mdot
.754 .259 Mdot
.754 .25903 Mdot
.754 .25906 Mdot
.754 .26068 Mdot
.754 .26091 Mdot
.754 .26151 Mdot
.754 .26224 Mdot
.754 .26268 Mdot
.754 .26269 Mdot
.754 .26293 Mdot
.754 .26295 Mdot
.754 .26298 Mdot
.754 .26311 Mdot
.754 .26314 Mdot
.754 .26325 Mdot
.754 .26402 Mdot
.754 .26411 Mdot
.754 .2643 Mdot
.754 .26433 Mdot
.754 .26498 Mdot
.754 .26525 Mdot
.754 .26544 Mdot
.754 .26561 Mdot
.754 .26598 Mdot
.754 .26644 Mdot
.754 .26687 Mdot
.754 .26702 Mdot
.754 .26702 Mdot
.754 .26745 Mdot
.754 .26783 Mdot
.754 .26845 Mdot
.754 .26881 Mdot
.754 .26881 Mdot
.754 .26941 Mdot
.754 .26967 Mdot
.754 .26975 Mdot
.754 .27003 Mdot
.754 .27053 Mdot
.754 .27059 Mdot
.754 .27093 Mdot
.754 .27132 Mdot
.754 .27191 Mdot
.754 .27191 Mdot
.754 .2721 Mdot
.754 .27233 Mdot
.754 .27297 Mdot
.754 .27336 Mdot
.754 .27374 Mdot
.754 .27426 Mdot
.754 .27445 Mdot
.754 .27458 Mdot
.754 .27509 Mdot
.754 .27514 Mdot
.754 .27697 Mdot
.754 .27725 Mdot
.754 .27772 Mdot
.754 .27776 Mdot
.754 .27883 Mdot
.754 .27893 Mdot
.754 .27895 Mdot
.754 .27923 Mdot
.754 .27988 Mdot
.754 .28 Mdot
.754 .28114 Mdot
.754 .28115 Mdot
.754 .28146 Mdot
.754 .2819 Mdot
.754 .28193 Mdot
.754 .28194 Mdot
.754 .28217 Mdot
.754 .28315 Mdot
.754 .28327 Mdot
.754 .28345 Mdot
.754 .28409 Mdot
.754 .28415 Mdot
.754 .28426 Mdot
.754 .28477 Mdot
.754 .28497 Mdot
.754 .2852 Mdot
.754 .28548 Mdot
.754 .28562 Mdot
.754 .28587 Mdot
.754 .28599 Mdot
.754 .28629 Mdot
.754 .28636 Mdot
.754 .28652 Mdot
.754 .28665 Mdot
.754 .2867 Mdot
.754 .28681 Mdot
.754 .28718 Mdot
.754 .28748 Mdot
.754 .28776 Mdot
.754 .28833 Mdot
.754 .28843 Mdot
.754 .28845 Mdot
.754 .28864 Mdot
.754 .28928 Mdot
.754 .28933 Mdot
.754 .28979 Mdot
.754 .29026 Mdot
.754 .29028 Mdot
.754 .29142 Mdot
.754 .29166 Mdot
.754 .29172 Mdot
.754 .2918 Mdot
.754 .29327 Mdot
.754 .29342 Mdot
.754 .29367 Mdot
.754 .29382 Mdot
.754 .29394 Mdot
.754 .2942 Mdot
.754 .29436 Mdot
.754 .29505 Mdot
.754 .29524 Mdot
.754 .29544 Mdot
.754 .29568 Mdot
.754 .29589 Mdot
.754 .29617 Mdot
.754 .29619 Mdot
.754 .29665 Mdot
.754 .2967 Mdot
.754 .29671 Mdot
.754 .29679 Mdot
.754 .29741 Mdot
.754 .29778 Mdot
.754 .29849 Mdot
.754 .29851 Mdot
.754 .29935 Mdot
.754 .2994 Mdot
.754 .2998 Mdot
.754 .29997 Mdot
.754 .3005 Mdot
.754 .30066 Mdot
.754 .30109 Mdot
.754 .30111 Mdot
.754 .30125 Mdot
.754 .30136 Mdot
.754 .30137 Mdot
.754 .30199 Mdot
.754 .30203 Mdot
.754 .30205 Mdot
.754 .30221 Mdot
.754 .30231 Mdot
.754 .30262 Mdot
.754 .30286 Mdot
.754 .3035 Mdot
.754 .30354 Mdot
.754 .30357 Mdot
.754 .30361 Mdot
.754 .30376 Mdot
.754 .30437 Mdot
.754 .30586 Mdot
.754 .30619 Mdot
.754 .3063 Mdot
.754 .30645 Mdot
.754 .30674 Mdot
.754 .30718 Mdot
.754 .30736 Mdot
.754 .30782 Mdot
.754 .30794 Mdot
.754 .30798 Mdot
.754 .30876 Mdot
.754 .30961 Mdot
.754 .30966 Mdot
.754 .3098 Mdot
.754 .31012 Mdot
.754 .31102 Mdot
.754 .31117 Mdot
.754 .31142 Mdot
.754 .31216 Mdot
.754 .31226 Mdot
.754 .31274 Mdot
.754 .31275 Mdot
.754 .31313 Mdot
.754 .31343 Mdot
.754 .31355 Mdot
.754 .3137 Mdot
.754 .31372 Mdot
.754 .31394 Mdot
.754 .31395 Mdot
.754 .31412 Mdot
.754 .31416 Mdot
.754 .31534 Mdot
.754 .31562 Mdot
.754 .31601 Mdot
.754 .31621 Mdot
.754 .31661 Mdot
.754 .31685 Mdot
.754 .31709 Mdot
.754 .31709 Mdot
.754 .31713 Mdot
.754 .31776 Mdot
.754 .31854 Mdot
.754 .31863 Mdot
.754 .31907 Mdot
.754 .3195 Mdot
.754 .3195 Mdot
.754 .32012 Mdot
.754 .32028 Mdot
.754 .32057 Mdot
.754 .32084 Mdot
.754 .32089 Mdot
.754 .32172 Mdot
.754 .3223 Mdot
.754 .3225 Mdot
.754 .3225 Mdot
.754 .32261 Mdot
.754 .32263 Mdot
.754 .32309 Mdot
.754 .32313 Mdot
.754 .32363 Mdot
.754 .32379 Mdot
.754 .32441 Mdot
.754 .32441 Mdot
.754 .32459 Mdot
.754 .32476 Mdot
.754 .32519 Mdot
.754 .32561 Mdot
.754 .32595 Mdot
.754 .3263 Mdot
.754 .32656 Mdot
.754 .32656 Mdot
.754 .32664 Mdot
.754 .32674 Mdot
.754 .32702 Mdot
.754 .32719 Mdot
.754 .32736 Mdot
.754 .32796 Mdot
.754 .32878 Mdot
.754 .3289 Mdot
.754 .32964 Mdot
.754 .32965 Mdot
.754 .32977 Mdot
.754 .33061 Mdot
.754 .33062 Mdot
.754 .33096 Mdot
.754 .3315 Mdot
.754 .33155 Mdot
.754 .33194 Mdot
.754 .33199 Mdot
.754 .3323 Mdot
.754 .3324 Mdot
.754 .33252 Mdot
.754 .33291 Mdot
.754 .33298 Mdot
.754 .33306 Mdot
.754 .33327 Mdot
.754 .33382 Mdot
.754 .33383 Mdot
.754 .33422 Mdot
.754 .33464 Mdot
.754 .33527 Mdot
.754 .33601 Mdot
.754 .33619 Mdot
.754 .33636 Mdot
.754 .33643 Mdot
.754 .33673 Mdot
.754 .33682 Mdot
.754 .3369 Mdot
.754 .33701 Mdot
.754 .3371 Mdot
.754 .33723 Mdot
.754 .33743 Mdot
.754 .33777 Mdot
.754 .33862 Mdot
.754 .33864 Mdot
.754 .33882 Mdot
.754 .3389 Mdot
.754 .33913 Mdot
.754 .3392 Mdot
.754 .33939 Mdot
.754 .33946 Mdot
.754 .33951 Mdot
.754 .33978 Mdot
.754 .3398 Mdot
.754 .33981 Mdot
.754 .33988 Mdot
.754 .33992 Mdot
.754 .34006 Mdot
.754 .34048 Mdot
.754 .3405 Mdot
.754 .34083 Mdot
.754 .34148 Mdot
.754 .34174 Mdot
.754 .34187 Mdot
.754 .34207 Mdot
.754 .34234 Mdot
.754 .3424 Mdot
.754 .34276 Mdot
.754 .34313 Mdot
.754 .34316 Mdot
.754 .34322 Mdot
.754 .34336 Mdot
.754 .34375 Mdot
.754 .34382 Mdot
.754 .34393 Mdot
.754 .34451 Mdot
.754 .34451 Mdot
.754 .34468 Mdot
.754 .34487 Mdot
.754 .34493 Mdot
.754 .34504 Mdot
.754 .34504 Mdot
.754 .34511 Mdot
.754 .34577 Mdot
.754 .34595 Mdot
.754 .34621 Mdot
.754 .34632 Mdot
.754 .34642 Mdot
.754 .34644 Mdot
.754 .34672 Mdot
.754 .3471 Mdot
.754 .34775 Mdot
.754 .34783 Mdot
.754 .34795 Mdot
.754 .34809 Mdot
.754 .34872 Mdot
.754 .3488 Mdot
.754 .34885 Mdot
.754 .34906 Mdot
.754 .34908 Mdot
.754 .3493 Mdot
.754 .34964 Mdot
.754 .3498 Mdot
.754 .35017 Mdot
.754 .35032 Mdot
.754 .35047 Mdot
.754 .35062 Mdot
.754 .35067 Mdot
.754 .35079 Mdot
.754 .35086 Mdot
.754 .3512 Mdot
.754 .35162 Mdot
.754 .35195 Mdot
.754 .352 Mdot
.754 .35276 Mdot
.754 .35278 Mdot
.754 .35297 Mdot
.754 .35311 Mdot
.754 .35315 Mdot
.754 .35321 Mdot
.754 .35338 Mdot
.754 .35344 Mdot
.754 .35354 Mdot
.754 .35378 Mdot
.754 .35474 Mdot
.754 .35482 Mdot
.754 .3549 Mdot
.754 .35493 Mdot
.754 .35514 Mdot
.754 .35518 Mdot
.754 .35522 Mdot
.754 .35552 Mdot
.754 .35589 Mdot
.754 .3559 Mdot
.754 .35598 Mdot
.754 .35601 Mdot
.754 .35611 Mdot
.754 .35623 Mdot
.754 .3564 Mdot
.754 .35641 Mdot
.754 .35652 Mdot
.754 .35686 Mdot
.754 .35726 Mdot
.754 .35732 Mdot
.754 .35741 Mdot
.754 .35753 Mdot
.754 .35755 Mdot
.754 .35771 Mdot
.754 .35788 Mdot
.754 .35791 Mdot
.754 .35797 Mdot
.754 .35815 Mdot
.754 .35818 Mdot
.754 .35823 Mdot
.754 .35848 Mdot
.754 .35856 Mdot
.754 .35867 Mdot
.754 .35904 Mdot
.754 .35911 Mdot
.754 .35927 Mdot
.754 .35932 Mdot
.754 .35933 Mdot
.754 .35945 Mdot
.754 .35962 Mdot
.754 .35991 Mdot
.754 .35994 Mdot
.754 .36006 Mdot
.754 .36049 Mdot
.754 .36074 Mdot
.754 .36097 Mdot
.754 .36103 Mdot
.754 .36127 Mdot
.754 .36161 Mdot
.754 .36177 Mdot
.754 .3622 Mdot
.754 .36226 Mdot
.754 .36256 Mdot
.754 .36298 Mdot
.754 .36301 Mdot
.754 .36306 Mdot
.754 .36315 Mdot
.754 .36348 Mdot
.754 .36358 Mdot
.754 .36363 Mdot
.754 .36391 Mdot
.754 .36409 Mdot
.754 .36411 Mdot
.754 .36415 Mdot
.754 .3642 Mdot
.754 .36429 Mdot
.754 .36436 Mdot
.754 .36448 Mdot
.754 .36449 Mdot
.754 .36471 Mdot
.754 .36497 Mdot
.754 .36505 Mdot
.754 .36512 Mdot
.754 .36562 Mdot
.754 .36575 Mdot
.754 .36585 Mdot
.754 .366 Mdot
.754 .36607 Mdot
.754 .36642 Mdot
.754 .36664 Mdot
.754 .36668 Mdot
.754 .36682 Mdot
.754 .36701 Mdot
.754 .36709 Mdot
.754 .36712 Mdot
.754 .36714 Mdot
.754 .36718 Mdot
.754 .36721 Mdot
.754 .36726 Mdot
.754 .36727 Mdot
.754 .36736 Mdot
.754 .36796 Mdot
.754 .36821 Mdot
.754 .36823 Mdot
.754 .36843 Mdot
.754 .36845 Mdot
.754 .36846 Mdot
.754 .36848 Mdot
.754 .36849 Mdot
.754 .36853 Mdot
.754 .36902 Mdot
.754 .36904 Mdot
.754 .36927 Mdot
.754 .36971 Mdot
.754 .37005 Mdot
.754 .37008 Mdot
.754 .37008 Mdot
.754 .3701 Mdot
.754 .37012 Mdot
.754 .37025 Mdot
.754 .37043 Mdot
.754 .37083 Mdot
.754 .37089 Mdot
.754 .37089 Mdot
.754 .37093 Mdot
.754 .37095 Mdot
.754 .37097 Mdot
.754 .37099 Mdot
.754 .37106 Mdot
.754 .37118 Mdot
.754 .37128 Mdot
.754 .37131 Mdot
.754 .37168 Mdot
.754 .37241 Mdot
.754 .37259 Mdot
.754 .37273 Mdot
.754 .37274 Mdot
.754 .37282 Mdot
.754 .37287 Mdot
.754 .37292 Mdot
.754 .37296 Mdot
.754 .373 Mdot
.754 .37311 Mdot
.754 .3733 Mdot
.754 .37333 Mdot
.754 .3734 Mdot
.754 .37362 Mdot
.754 .37368 Mdot
.754 .37373 Mdot
.754 .37401 Mdot
.754 .37421 Mdot
.754 .37425 Mdot
.754 .37453 Mdot
.754 .37464 Mdot
.754 .37486 Mdot
.754 .37502 Mdot
.754 .37507 Mdot
.754 .37522 Mdot
.754 .37538 Mdot
.754 .37575 Mdot
.754 .37596 Mdot
.754 .37607 Mdot
.754 .37619 Mdot
.754 .3763 Mdot
.754 .37659 Mdot
.754 .37689 Mdot
.754 .37692 Mdot
.754 .37694 Mdot
.754 .37712 Mdot
.754 .37723 Mdot
.754 .37735 Mdot
.754 .37743 Mdot
.754 .37749 Mdot
.754 .37752 Mdot
.754 .37779 Mdot
.754 .3781 Mdot
.754 .37821 Mdot
.754 .37829 Mdot
.754 .37835 Mdot
.754 .37838 Mdot
.754 .37843 Mdot
.754 .37868 Mdot
.754 .37893 Mdot
.754 .37907 Mdot
.754 .37914 Mdot
.754 .37919 Mdot
.754 .37983 Mdot
.754 .38006 Mdot
.754 .38025 Mdot
.754 .38028 Mdot
.754 .38037 Mdot
.754 .3805 Mdot
.754 .38101 Mdot
.754 .38105 Mdot
.754 .38127 Mdot
.754 .38177 Mdot
.754 .38203 Mdot
.754 .38213 Mdot
.754 .38223 Mdot
.754 .38258 Mdot
.754 .38295 Mdot
.754 .38296 Mdot
.754 .3831 Mdot
.754 .38314 Mdot
.754 .38319 Mdot
.754 .3836 Mdot
.754 .38378 Mdot
.754 .38383 Mdot
.754 .38426 Mdot
.754 .38452 Mdot
.754 .3847 Mdot
.754 .38471 Mdot
.754 .38478 Mdot
.754 .38503 Mdot
.754 .38514 Mdot
.754 .38563 Mdot
.754 .3857 Mdot
.754 .38587 Mdot
.754 .38598 Mdot
.754 .38598 Mdot
.754 .38637 Mdot
.754 .38644 Mdot
.754 .38648 Mdot
.754 .38674 Mdot
.754 .38684 Mdot
.754 .38688 Mdot
.754 .38689 Mdot
.754 .38714 Mdot
.754 .38738 Mdot
.754 .38742 Mdot
.754 .3876 Mdot
.754 .38773 Mdot
.754 .38782 Mdot
.754 .38799 Mdot
.754 .38842 Mdot
.754 .38864 Mdot
.754 .38865 Mdot
.754 .38893 Mdot
.754 .38902 Mdot
.754 .38905 Mdot
.754 .3891 Mdot
.754 .38911 Mdot
.754 .38912 Mdot
.754 .3893 Mdot
.754 .38933 Mdot
.754 .38938 Mdot
.754 .3895 Mdot
.754 .38955 Mdot
.754 .3897 Mdot
.754 .38975 Mdot
.754 .38987 Mdot
.754 .38989 Mdot
.754 .39045 Mdot
.754 .39067 Mdot
.754 .39081 Mdot
.754 .3909 Mdot
.754 .39095 Mdot
.754 .39102 Mdot
.754 .39108 Mdot
.754 .39114 Mdot
.754 .39134 Mdot
.754 .39139 Mdot
.754 .3915 Mdot
.754 .39162 Mdot
.754 .39211 Mdot
.754 .39253 Mdot
.754 .39281 Mdot
.754 .39307 Mdot
.754 .39307 Mdot
.754 .39343 Mdot
.754 .39357 Mdot
.754 .39363 Mdot
.754 .39367 Mdot
.754 .39393 Mdot
.754 .39401 Mdot
.754 .39408 Mdot
.754 .39429 Mdot
.754 .39432 Mdot
.754 .39457 Mdot
.754 .39461 Mdot
.754 .39496 Mdot
.754 .39519 Mdot
.754 .3952 Mdot
.754 .39575 Mdot
.754 .39584 Mdot
.754 .39584 Mdot
.754 .39633 Mdot
.754 .39641 Mdot
.754 .39696 Mdot
.754 .39735 Mdot
.754 .39747 Mdot
.754 .39758 Mdot
.754 .39776 Mdot
.754 .39783 Mdot
.754 .39789 Mdot
.754 .39789 Mdot
.754 .39806 Mdot
.754 .39829 Mdot
.754 .39852 Mdot
.754 .39879 Mdot
.754 .39908 Mdot
.754 .39919 Mdot
.754 .39931 Mdot
.754 .39931 Mdot
.754 .39972 Mdot
.754 .39983 Mdot
.754 .40016 Mdot
.754 .40019 Mdot
.754 .40049 Mdot
.754 .4005 Mdot
.754 .40058 Mdot
.754 .40058 Mdot
.754 .40071 Mdot
.754 .40109 Mdot
.754 .40164 Mdot
.754 .40168 Mdot
.754 .40186 Mdot
.754 .40205 Mdot
.754 .40215 Mdot
.754 .40256 Mdot
.754 .40257 Mdot
.754 .40285 Mdot
.754 .40314 Mdot
.754 .4032 Mdot
.754 .40372 Mdot
.754 .40414 Mdot
.754 .40416 Mdot
.754 .40417 Mdot
.754 .40433 Mdot
.754 .40448 Mdot
.754 .40475 Mdot
.754 .40488 Mdot
.754 .40514 Mdot
.754 .40532 Mdot
.754 .40611 Mdot
.754 .40614 Mdot
.754 .40625 Mdot
.754 .40625 Mdot
.754 .4064 Mdot
.754 .40641 Mdot
.754 .40651 Mdot
.754 .40659 Mdot
.754 .40679 Mdot
.754 .40704 Mdot
.754 .40705 Mdot
.754 .40737 Mdot
.754 .40743 Mdot
.754 .40792 Mdot
.754 .40809 Mdot
.754 .40819 Mdot
.754 .40878 Mdot
.754 .409 Mdot
.754 .40909 Mdot
.754 .40912 Mdot
.754 .40969 Mdot
.754 .4102 Mdot
.754 .41023 Mdot
.754 .41031 Mdot
.754 .41062 Mdot
.754 .41073 Mdot
.754 .41103 Mdot
.754 .41122 Mdot
.754 .41132 Mdot
.754 .41139 Mdot
.754 .41161 Mdot
.754 .4126 Mdot
.754 .41301 Mdot
.754 .4131 Mdot
.754 .41313 Mdot
.754 .41315 Mdot
.754 .41318 Mdot
.754 .4136 Mdot
.754 .41376 Mdot
.754 .41396 Mdot
.754 .41403 Mdot
.754 .41414 Mdot
.754 .41415 Mdot
.754 .41418 Mdot
.754 .41459 Mdot
.754 .41459 Mdot
.754 .41467 Mdot
.754 .41476 Mdot
.754 .41477 Mdot
.754 .41506 Mdot
.754 .41517 Mdot
.754 .41551 Mdot
.754 .41563 Mdot
.754 .41589 Mdot
.754 .41593 Mdot
.754 .41648 Mdot
.754 .4165 Mdot
.754 .41697 Mdot
.754 .41721 Mdot
.754 .41763 Mdot
.754 .41768 Mdot
.754 .41769 Mdot
.754 .41772 Mdot
.754 .41803 Mdot
.754 .41804 Mdot
.754 .41822 Mdot
.754 .41836 Mdot
.754 .41852 Mdot
.754 .41865 Mdot
.754 .41878 Mdot
.754 .41924 Mdot
.754 .41934 Mdot
.754 .41952 Mdot
.754 .41959 Mdot
.754 .4197 Mdot
.754 .41986 Mdot
.754 .41996 Mdot
.754 .42093 Mdot
.754 .42099 Mdot
.754 .42102 Mdot
.754 .42119 Mdot
.754 .42194 Mdot
.754 .42195 Mdot
.754 .42227 Mdot
.754 .42257 Mdot
.754 .42261 Mdot
.754 .42303 Mdot
.754 .42316 Mdot
.754 .42317 Mdot
.754 .42324 Mdot
.754 .42361 Mdot
.754 .4238 Mdot
.754 .424 Mdot
.754 .42424 Mdot
.754 .42432 Mdot
.754 .42435 Mdot
.754 .42444 Mdot
.754 .42454 Mdot
.754 .42459 Mdot
.754 .42479 Mdot
.754 .42487 Mdot
.754 .42503 Mdot
.754 .42512 Mdot
.754 .42531 Mdot
.754 .42546 Mdot
.754 .4256 Mdot
.754 .42594 Mdot
.754 .42601 Mdot
.754 .42605 Mdot
.754 .42647 Mdot
.754 .42659 Mdot
.754 .42667 Mdot
.754 .42732 Mdot
.754 .42747 Mdot
.754 .42748 Mdot
.754 .4275 Mdot
.754 .42779 Mdot
.754 .428 Mdot
.754 .428 Mdot
.754 .42876 Mdot
.754 .42884 Mdot
.754 .42927 Mdot
.754 .42946 Mdot
.754 .42947 Mdot
.754 .42953 Mdot
.754 .43024 Mdot
.754 .43027 Mdot
.754 .43058 Mdot
.754 .43077 Mdot
.754 .43198 Mdot
.754 .43201 Mdot
.754 .43235 Mdot
.754 .43244 Mdot
.754 .43257 Mdot
.754 .43291 Mdot
.754 .43316 Mdot
.754 .43342 Mdot
.754 .43384 Mdot
.754 .434 Mdot
.754 .43412 Mdot
.754 .43412 Mdot
.754 .43451 Mdot
.754 .43477 Mdot
.754 .435 Mdot
.754 .43504 Mdot
.754 .43537 Mdot
.754 .43555 Mdot
.754 .43561 Mdot
.754 .43578 Mdot
.754 .43618 Mdot
.754 .43618 Mdot
.754 .43642 Mdot
.754 .43683 Mdot
.754 .43708 Mdot
.754 .43736 Mdot
.754 .43737 Mdot
.754 .43747 Mdot
.754 .43775 Mdot
.754 .43805 Mdot
.754 .4383 Mdot
.754 .43842 Mdot
.754 .43854 Mdot
.754 .43872 Mdot
.754 .43915 Mdot
.754 .43917 Mdot
.754 .43929 Mdot
.754 .43935 Mdot
.754 .43987 Mdot
.754 .43994 Mdot
.754 .43996 Mdot
.754 .44005 Mdot
.754 .44007 Mdot
.754 .44008 Mdot
.754 .44024 Mdot
.754 .44025 Mdot
.754 .44053 Mdot
.754 .44102 Mdot
.754 .44142 Mdot
.754 .44157 Mdot
.754 .44264 Mdot
.754 .44267 Mdot
.754 .44268 Mdot
.754 .44274 Mdot
.754 .44316 Mdot
.754 .44359 Mdot
.754 .44383 Mdot
.754 .44394 Mdot
.754 .44402 Mdot
.754 .44463 Mdot
.754 .44476 Mdot
.754 .44477 Mdot
.754 .44488 Mdot
.754 .44542 Mdot
.754 .44568 Mdot
.754 .44592 Mdot
.754 .44608 Mdot
.754 .44622 Mdot
.754 .44658 Mdot
.754 .44659 Mdot
.754 .4468 Mdot
.754 .44698 Mdot
.754 .44699 Mdot
.754 .44738 Mdot
.754 .44792 Mdot
.754 .44798 Mdot
.754 .44801 Mdot
.754 .44826 Mdot
.754 .44833 Mdot
.754 .44839 Mdot
.754 .4484 Mdot
.754 .44841 Mdot
.754 .44877 Mdot
.754 .44887 Mdot
.754 .44913 Mdot
.754 .44923 Mdot
.754 .44972 Mdot
.754 .45002 Mdot
.754 .4502 Mdot
.754 .45027 Mdot
.754 .45031 Mdot
.754 .45037 Mdot
.754 .45059 Mdot
.754 .45062 Mdot
.754 .45103 Mdot
.754 .45152 Mdot
.754 .45282 Mdot
.754 .45288 Mdot
.754 .45314 Mdot
.754 .45314 Mdot
.754 .45327 Mdot
.754 .45348 Mdot
.754 .45351 Mdot
.754 .45373 Mdot
.754 .45376 Mdot
.754 .45392 Mdot
.754 .45426 Mdot
.754 .45437 Mdot
.754 .45442 Mdot
.754 .45464 Mdot
.754 .45494 Mdot
.754 .45496 Mdot
.754 .45509 Mdot
.754 .45568 Mdot
.754 .45575 Mdot
.754 .45583 Mdot
.754 .45603 Mdot
.754 .45671 Mdot
.754 .45689 Mdot
.754 .45695 Mdot
.754 .45697 Mdot
.754 .45733 Mdot
.754 .45755 Mdot
.754 .45814 Mdot
.754 .45891 Mdot
.754 .45939 Mdot
.754 .45942 Mdot
.754 .4595 Mdot
.756 .23238 Mdot
.756 .23286 Mdot
.756 .23293 Mdot
.756 .23395 Mdot
.756 .23397 Mdot
.756 .23412 Mdot
.756 .23456 Mdot
.756 .23484 Mdot
.756 .2351 Mdot
.756 .23599 Mdot
.756 .23632 Mdot
.756 .23668 Mdot
.756 .23684 Mdot
.756 .23709 Mdot
.756 .23711 Mdot
.756 .2377 Mdot
.756 .23777 Mdot
.756 .2379 Mdot
.756 .23792 Mdot
.756 .23811 Mdot
.756 .23832 Mdot
.756 .23852 Mdot
.756 .23865 Mdot
.756 .23933 Mdot
.756 .24127 Mdot
.756 .24136 Mdot
.756 .24142 Mdot
.756 .24147 Mdot
.756 .24197 Mdot
.756 .24223 Mdot
.756 .24227 Mdot
.756 .24318 Mdot
.756 .2433 Mdot
.756 .24358 Mdot
.756 .24377 Mdot
.756 .24388 Mdot
.756 .24405 Mdot
.756 .24462 Mdot
.756 .2449 Mdot
.756 .24527 Mdot
.756 .24556 Mdot
.756 .24639 Mdot
.756 .24652 Mdot
.756 .24771 Mdot
.756 .24837 Mdot
.756 .24878 Mdot
.756 .24904 Mdot
.756 .24912 Mdot
.756 .24914 Mdot
.756 .24937 Mdot
.756 .24994 Mdot
.756 .25015 Mdot
.756 .25038 Mdot
.756 .25046 Mdot
.756 .25088 Mdot
.756 .25114 Mdot
.756 .25116 Mdot
.756 .25118 Mdot
.756 .25167 Mdot
.756 .25187 Mdot
.756 .25199 Mdot
.756 .25251 Mdot
.756 .25256 Mdot
.756 .25309 Mdot
.756 .25324 Mdot
.756 .2534 Mdot
.756 .2539 Mdot
.756 .25427 Mdot
.756 .25444 Mdot
.756 .25522 Mdot
.756 .25529 Mdot
.756 .25536 Mdot
.756 .25547 Mdot
.756 .25583 Mdot
.756 .25592 Mdot
.756 .25611 Mdot
.756 .25653 Mdot
.756 .25656 Mdot
.756 .25711 Mdot
.756 .25762 Mdot
.756 .25874 Mdot
.756 .25881 Mdot
.756 .25943 Mdot
.756 .26033 Mdot
.756 .26063 Mdot
.756 .26072 Mdot
.756 .26075 Mdot
.756 .26121 Mdot
.756 .26126 Mdot
.756 .26154 Mdot
.756 .26245 Mdot
.756 .26276 Mdot
.756 .26467 Mdot
.756 .26503 Mdot
.756 .26508 Mdot
.756 .26534 Mdot
.756 .26539 Mdot
.756 .26576 Mdot
.756 .26674 Mdot
.756 .26696 Mdot
.756 .26708 Mdot
.756 .26737 Mdot
.756 .26753 Mdot
.756 .26761 Mdot
.756 .26791 Mdot
.756 .26824 Mdot
.756 .26913 Mdot
.756 .26917 Mdot
.756 .26923 Mdot
.756 .26956 Mdot
.756 .27006 Mdot
.756 .27034 Mdot
.756 .27035 Mdot
.756 .27083 Mdot
.756 .27104 Mdot
.756 .27114 Mdot
.756 .27133 Mdot
.756 .27188 Mdot
.756 .27227 Mdot
.756 .27241 Mdot
.756 .27243 Mdot
.756 .27266 Mdot
.756 .27268 Mdot
.756 .27353 Mdot
.756 .27364 Mdot
.756 .27373 Mdot
.756 .27399 Mdot
.756 .27454 Mdot
.756 .27535 Mdot
.756 .27554 Mdot
.756 .27597 Mdot
.756 .27598 Mdot
.756 .27634 Mdot
.756 .27656 Mdot
.756 .27678 Mdot
.756 .27761 Mdot
.756 .27771 Mdot
.756 .27807 Mdot
.756 .27834 Mdot
.756 .27893 Mdot
.756 .27923 Mdot
.756 .27927 Mdot
.756 .2796 Mdot
.756 .27973 Mdot
.756 .27999 Mdot
.756 .2801 Mdot
.756 .28026 Mdot
.756 .28036 Mdot
.756 .28093 Mdot
.756 .28128 Mdot
.756 .2813 Mdot
.756 .28205 Mdot
.756 .28245 Mdot
.756 .2826 Mdot
.756 .28291 Mdot
.756 .28327 Mdot
.756 .28353 Mdot
.756 .28354 Mdot
.756 .28394 Mdot
.756 .28485 Mdot
.756 .28523 Mdot
.756 .28548 Mdot
.756 .28566 Mdot
.756 .28639 Mdot
.756 .28674 Mdot
.756 .28714 Mdot
.756 .28731 Mdot
.756 .28743 Mdot
.756 .28759 Mdot
.756 .28772 Mdot
.756 .28796 Mdot
.756 .28829 Mdot
.756 .2883 Mdot
.756 .28875 Mdot
.756 .28887 Mdot
.756 .28904 Mdot
.756 .28918 Mdot
.756 .2897 Mdot
.756 .2909 Mdot
.756 .29125 Mdot
.756 .29169 Mdot
.756 .29207 Mdot
.756 .29217 Mdot
.756 .29218 Mdot
.756 .29278 Mdot
.756 .29309 Mdot
.756 .29362 Mdot
.756 .29401 Mdot
.756 .29432 Mdot
.756 .29456 Mdot
.756 .29466 Mdot
.756 .29509 Mdot
.756 .29557 Mdot
.756 .29728 Mdot
.756 .2973 Mdot
.756 .29733 Mdot
.756 .29813 Mdot
.756 .2994 Mdot
.756 .29944 Mdot
.756 .29967 Mdot
.756 .30004 Mdot
.756 .30028 Mdot
.756 .30063 Mdot
.756 .30087 Mdot
.756 .30089 Mdot
.756 .30117 Mdot
.756 .30149 Mdot
.756 .30192 Mdot
.756 .30201 Mdot
.756 .30226 Mdot
.756 .30237 Mdot
.756 .30252 Mdot
.756 .3027 Mdot
.756 .30393 Mdot
.756 .30405 Mdot
.756 .30421 Mdot
.756 .30466 Mdot
.756 .30491 Mdot
.756 .30537 Mdot
.756 .3055 Mdot
.756 .30572 Mdot
.756 .30576 Mdot
.756 .30719 Mdot
.756 .30727 Mdot
.756 .30762 Mdot
.756 .30811 Mdot
.756 .30862 Mdot
.756 .30874 Mdot
.756 .309 Mdot
.756 .30945 Mdot
.756 .30948 Mdot
.756 .3097 Mdot
.756 .31039 Mdot
.756 .31046 Mdot
.756 .31089 Mdot
.756 .31142 Mdot
.756 .31158 Mdot
.756 .31165 Mdot
.756 .31176 Mdot
.756 .31203 Mdot
.756 .31206 Mdot
.756 .31212 Mdot
.756 .3123 Mdot
.756 .31239 Mdot
.756 .31245 Mdot
.756 .31274 Mdot
.756 .31359 Mdot
.756 .31365 Mdot
.756 .31401 Mdot
.756 .31442 Mdot
.756 .3146 Mdot
.756 .31468 Mdot
.756 .31481 Mdot
.756 .31506 Mdot
.756 .31583 Mdot
.756 .31589 Mdot
.756 .31641 Mdot
.756 .31699 Mdot
.756 .31703 Mdot
.756 .31757 Mdot
.756 .31761 Mdot
.756 .3178 Mdot
.756 .31792 Mdot
.756 .31793 Mdot
.756 .31814 Mdot
.756 .31828 Mdot
.756 .31883 Mdot
.756 .31889 Mdot
.756 .31928 Mdot
.756 .31969 Mdot
.756 .31975 Mdot
.756 .3198 Mdot
.756 .32008 Mdot
.756 .32026 Mdot
.756 .32028 Mdot
.756 .32052 Mdot
.756 .32074 Mdot
.756 .32123 Mdot
.756 .32154 Mdot
.756 .32193 Mdot
.756 .32231 Mdot
.756 .32233 Mdot
.756 .32246 Mdot
.756 .32285 Mdot
.756 .32299 Mdot
.756 .32398 Mdot
.756 .32401 Mdot
.756 .32412 Mdot
.756 .32414 Mdot
.756 .32488 Mdot
.756 .32501 Mdot
.756 .32511 Mdot
.756 .32524 Mdot
.756 .3258 Mdot
.756 .32582 Mdot
.756 .32597 Mdot
.756 .32618 Mdot
.756 .32631 Mdot
.756 .32652 Mdot
.756 .32665 Mdot
.756 .32674 Mdot
.756 .32698 Mdot
.756 .32715 Mdot
.756 .32733 Mdot
.756 .32775 Mdot
.756 .32779 Mdot
.756 .3279 Mdot
.756 .32858 Mdot
.756 .32877 Mdot
.756 .32877 Mdot
.756 .32893 Mdot
.756 .32903 Mdot
.756 .32912 Mdot
.756 .32949 Mdot
.756 .32953 Mdot
.756 .32981 Mdot
.756 .33006 Mdot
.756 .3302 Mdot
.756 .33042 Mdot
.756 .33057 Mdot
.756 .33069 Mdot
.756 .33094 Mdot
.756 .3316 Mdot
.756 .33208 Mdot
.756 .33282 Mdot
.756 .33293 Mdot
.756 .33332 Mdot
.756 .33348 Mdot
.756 .33365 Mdot
.756 .33378 Mdot
.756 .33385 Mdot
.756 .33401 Mdot
.756 .33416 Mdot
.756 .33436 Mdot
.756 .33441 Mdot
.756 .33448 Mdot
.756 .33478 Mdot
.756 .3353 Mdot
.756 .33565 Mdot
.756 .33581 Mdot
.756 .33625 Mdot
.756 .33666 Mdot
.756 .3369 Mdot
.756 .33713 Mdot
.756 .3381 Mdot
.756 .33902 Mdot
.756 .33956 Mdot
.756 .33967 Mdot
.756 .33993 Mdot
.756 .34027 Mdot
.756 .34032 Mdot
.756 .34038 Mdot
.756 .341 Mdot
.756 .34112 Mdot
.756 .34143 Mdot
.756 .34163 Mdot
.756 .3418 Mdot
.756 .34242 Mdot
.756 .34246 Mdot
.756 .3431 Mdot
.756 .34321 Mdot
.756 .34352 Mdot
.756 .34382 Mdot
.756 .34428 Mdot
.756 .34435 Mdot
.756 .34438 Mdot
.756 .34442 Mdot
.756 .34454 Mdot
.756 .34455 Mdot
.756 .34458 Mdot
.756 .34466 Mdot
.756 .3447 Mdot
.756 .34472 Mdot
.756 .34522 Mdot
.756 .34525 Mdot
.756 .34559 Mdot
.756 .3457 Mdot
.756 .3462 Mdot
.756 .34623 Mdot
.756 .34646 Mdot
.756 .34706 Mdot
.756 .34712 Mdot
.756 .34721 Mdot
.756 .34727 Mdot
.756 .34754 Mdot
.756 .34771 Mdot
.756 .34789 Mdot
.756 .34792 Mdot
.756 .34794 Mdot
.756 .34814 Mdot
.756 .34815 Mdot
.756 .3487 Mdot
.756 .34887 Mdot
.756 .3491 Mdot
.756 .34928 Mdot
.756 .34977 Mdot
.756 .34978 Mdot
.756 .34984 Mdot
.756 .35032 Mdot
.756 .35056 Mdot
.756 .35057 Mdot
.756 .35064 Mdot
.756 .35073 Mdot
.756 .35079 Mdot
.756 .35088 Mdot
.756 .35094 Mdot
.756 .35098 Mdot
.756 .35108 Mdot
.756 .35123 Mdot
.756 .35142 Mdot
.756 .35143 Mdot
.756 .35186 Mdot
.756 .35194 Mdot
.756 .35198 Mdot
.756 .35218 Mdot
.756 .3522 Mdot
.756 .35249 Mdot
.756 .35258 Mdot
.756 .3527 Mdot
.756 .35281 Mdot
.756 .3531 Mdot
.756 .35331 Mdot
.756 .35368 Mdot
.756 .35386 Mdot
.756 .35392 Mdot
.756 .35409 Mdot
.756 .35416 Mdot
.756 .35422 Mdot
.756 .35433 Mdot
.756 .35449 Mdot
.756 .35487 Mdot
.756 .35494 Mdot
.756 .35514 Mdot
.756 .35531 Mdot
.756 .35542 Mdot
.756 .35552 Mdot
.756 .35594 Mdot
.756 .35635 Mdot
.756 .35658 Mdot
.756 .35675 Mdot
.756 .35689 Mdot
.756 .35691 Mdot
.756 .35721 Mdot
.756 .35727 Mdot
.756 .3574 Mdot
.756 .35749 Mdot
.756 .35756 Mdot
.756 .35784 Mdot
.756 .35832 Mdot
.756 .35869 Mdot
.756 .35871 Mdot
.756 .35878 Mdot
.756 .35883 Mdot
.756 .35884 Mdot
.756 .35907 Mdot
.756 .35922 Mdot
.756 .35927 Mdot
.756 .35987 Mdot
.756 .35993 Mdot
.756 .36015 Mdot
.756 .36023 Mdot
.756 .36024 Mdot
.756 .36034 Mdot
.756 .36034 Mdot
.756 .36076 Mdot
.756 .36105 Mdot
.756 .36108 Mdot
.756 .36122 Mdot
.756 .3614 Mdot
.756 .36143 Mdot
.756 .36147 Mdot
.756 .3615 Mdot
.756 .36154 Mdot
.756 .36162 Mdot
.756 .36169 Mdot
.756 .36177 Mdot
.756 .362 Mdot
.756 .36233 Mdot
.756 .36276 Mdot
.756 .36294 Mdot
.756 .36297 Mdot
.756 .363 Mdot
.756 .36311 Mdot
.756 .36331 Mdot
.756 .3634 Mdot
.756 .36352 Mdot
.756 .36375 Mdot
.756 .36417 Mdot
.756 .36431 Mdot
.756 .36458 Mdot
.756 .36501 Mdot
.756 .36502 Mdot
.756 .36518 Mdot
.756 .36521 Mdot
.756 .36547 Mdot
.756 .36562 Mdot
.756 .36563 Mdot
.756 .36567 Mdot
.756 .36614 Mdot
.756 .36618 Mdot
.756 .3662 Mdot
.756 .36623 Mdot
.756 .36626 Mdot
.756 .3664 Mdot
.756 .36681 Mdot
.756 .36682 Mdot
.756 .36701 Mdot
.756 .36707 Mdot
.756 .36735 Mdot
.756 .36779 Mdot
.756 .36792 Mdot
.756 .36798 Mdot
.756 .36799 Mdot
.756 .36801 Mdot
.756 .36823 Mdot
.756 .36826 Mdot
.756 .36832 Mdot
.756 .3685 Mdot
.756 .36861 Mdot
.756 .36874 Mdot
.756 .36899 Mdot
.756 .36902 Mdot
.756 .36912 Mdot
.756 .36914 Mdot
.756 .36917 Mdot
.756 .36952 Mdot
.756 .37028 Mdot
.756 .37037 Mdot
.756 .37069 Mdot
.756 .37081 Mdot
.756 .37085 Mdot
.756 .37087 Mdot
.756 .37103 Mdot
.756 .37103 Mdot
.756 .37108 Mdot
.756 .37116 Mdot
.756 .37146 Mdot
.756 .37164 Mdot
.756 .3718 Mdot
.756 .37181 Mdot
.756 .37208 Mdot
.756 .37217 Mdot
.756 .37219 Mdot
.756 .37222 Mdot
.756 .37223 Mdot
.756 .37226 Mdot
.756 .37256 Mdot
.756 .37259 Mdot
.756 .37259 Mdot
.756 .3727 Mdot
.756 .37289 Mdot
.756 .373 Mdot
.756 .37329 Mdot
.756 .37347 Mdot
.756 .37356 Mdot
.756 .37399 Mdot
.756 .37407 Mdot
.756 .37425 Mdot
.756 .37433 Mdot
.756 .37435 Mdot
.756 .37437 Mdot
.756 .37499 Mdot
.756 .37514 Mdot
.756 .3752 Mdot
.756 .37524 Mdot
.756 .3753 Mdot
.756 .37533 Mdot
.756 .37537 Mdot
.756 .37539 Mdot
.756 .3756 Mdot
.756 .37609 Mdot
.756 .37616 Mdot
.756 .37616 Mdot
.756 .37636 Mdot
.756 .3764 Mdot
.756 .3768 Mdot
.756 .37683 Mdot
.756 .37693 Mdot
.756 .37708 Mdot
.756 .37709 Mdot
.756 .37718 Mdot
.756 .37775 Mdot
.756 .37816 Mdot
.756 .37836 Mdot
.756 .37837 Mdot
.756 .37847 Mdot
.756 .37858 Mdot
.756 .37873 Mdot
.756 .379 Mdot
.756 .37928 Mdot
.756 .37934 Mdot
.756 .37941 Mdot
.756 .37953 Mdot
.756 .37966 Mdot
.756 .37971 Mdot
.756 .37996 Mdot
.756 .38014 Mdot
.756 .38018 Mdot
.756 .38023 Mdot
.756 .38033 Mdot
.756 .38038 Mdot
.756 .38049 Mdot
.756 .38114 Mdot
.756 .38122 Mdot
.756 .38165 Mdot
.756 .38198 Mdot
.756 .38199 Mdot
.756 .38211 Mdot
.756 .38221 Mdot
.756 .38235 Mdot
.756 .38241 Mdot
.756 .38244 Mdot
.756 .38251 Mdot
.756 .38255 Mdot
.756 .38303 Mdot
.756 .38308 Mdot
.756 .38352 Mdot
.756 .38368 Mdot
.756 .38379 Mdot
.756 .38415 Mdot
.756 .38416 Mdot
.756 .3843 Mdot
.756 .38432 Mdot
.756 .38444 Mdot
.756 .38473 Mdot
.756 .38477 Mdot
.756 .38487 Mdot
.756 .38577 Mdot
.756 .38585 Mdot
.756 .38607 Mdot
.756 .38609 Mdot
.756 .38642 Mdot
.756 .38644 Mdot
.756 .38651 Mdot
.756 .38654 Mdot
.756 .38662 Mdot
.756 .38665 Mdot
.756 .38667 Mdot
.756 .38671 Mdot
.756 .38721 Mdot
.756 .38742 Mdot
.756 .38749 Mdot
.756 .38792 Mdot
.756 .38794 Mdot
.756 .38835 Mdot
.756 .38847 Mdot
.756 .3886 Mdot
.756 .3888 Mdot
.756 .38888 Mdot
.756 .38929 Mdot
.756 .38933 Mdot
.756 .38937 Mdot
.756 .38959 Mdot
.756 .38976 Mdot
.756 .38984 Mdot
.756 .39019 Mdot
.756 .3908 Mdot
.756 .39144 Mdot
.756 .39159 Mdot
.756 .39175 Mdot
.756 .39202 Mdot
.756 .39231 Mdot
.756 .39242 Mdot
.756 .39265 Mdot
.756 .393 Mdot
.756 .39319 Mdot
.756 .39324 Mdot
.756 .39327 Mdot
.756 .39341 Mdot
.756 .3935 Mdot
.756 .39361 Mdot
.756 .39366 Mdot
.756 .39374 Mdot
.756 .39385 Mdot
.756 .39396 Mdot
.756 .39422 Mdot
.756 .39429 Mdot
.756 .39478 Mdot
.756 .3951 Mdot
.756 .39554 Mdot
.756 .3957 Mdot
.756 .39578 Mdot
.756 .39588 Mdot
.756 .39603 Mdot
.756 .39611 Mdot
.756 .39628 Mdot
.756 .39647 Mdot
.756 .3965 Mdot
.756 .39674 Mdot
.756 .3968 Mdot
.756 .39686 Mdot
.756 .39697 Mdot
.756 .39697 Mdot
.756 .3971 Mdot
.756 .39754 Mdot
.756 .39762 Mdot
.756 .39765 Mdot
.756 .39792 Mdot
.756 .39804 Mdot
.756 .39815 Mdot
.756 .39831 Mdot
.756 .39837 Mdot
.756 .39846 Mdot
.756 .3986 Mdot
.756 .39868 Mdot
.756 .39882 Mdot
.756 .39892 Mdot
.756 .39894 Mdot
.756 .3993 Mdot
.756 .39939 Mdot
.756 .39946 Mdot
.756 .39954 Mdot
.756 .40003 Mdot
.756 .40005 Mdot
.756 .40012 Mdot
.756 .40014 Mdot
.756 .40079 Mdot
.756 .40088 Mdot
.756 .40114 Mdot
.756 .40123 Mdot
.756 .40124 Mdot
.756 .40149 Mdot
.756 .40175 Mdot
.756 .40196 Mdot
.756 .40228 Mdot
.756 .40243 Mdot
.756 .40259 Mdot
.756 .4026 Mdot
.756 .40272 Mdot
.756 .4029 Mdot
.756 .40293 Mdot
.756 .40297 Mdot
.756 .40325 Mdot
.756 .4035 Mdot
.756 .40355 Mdot
.756 .40391 Mdot
.756 .404 Mdot
.756 .40414 Mdot
.756 .40415 Mdot
.756 .40423 Mdot
.756 .40435 Mdot
.756 .40438 Mdot
.756 .40473 Mdot
.756 .40476 Mdot
.756 .40514 Mdot
.756 .40549 Mdot
.756 .40553 Mdot
.756 .40604 Mdot
.756 .4062 Mdot
.756 .40629 Mdot
.756 .40634 Mdot
.756 .40646 Mdot
.756 .40673 Mdot
.756 .40697 Mdot
.756 .40701 Mdot
.756 .40757 Mdot
.756 .40777 Mdot
.756 .40781 Mdot
.756 .40786 Mdot
.756 .40798 Mdot
.756 .40802 Mdot
.756 .40804 Mdot
.756 .40822 Mdot
.756 .40829 Mdot
.756 .40834 Mdot
.756 .40844 Mdot
.756 .40879 Mdot
.756 .40908 Mdot
.756 .40913 Mdot
.756 .40958 Mdot
.756 .40973 Mdot
.756 .40975 Mdot
.756 .41005 Mdot
.756 .41022 Mdot
.756 .4103 Mdot
.756 .41063 Mdot
.756 .41096 Mdot
.756 .41119 Mdot
.756 .41125 Mdot
.756 .41219 Mdot
.756 .41222 Mdot
.756 .41236 Mdot
.756 .41245 Mdot
.756 .41275 Mdot
.756 .41292 Mdot
.756 .41321 Mdot
.756 .41332 Mdot
.756 .4134 Mdot
.756 .41421 Mdot
.756 .41433 Mdot
.756 .41443 Mdot
.756 .4145 Mdot
.756 .41467 Mdot
.756 .41473 Mdot
.756 .41502 Mdot
.756 .41522 Mdot
.756 .41541 Mdot
.756 .41542 Mdot
.756 .41558 Mdot
.756 .41581 Mdot
.756 .41597 Mdot
.756 .41622 Mdot
.756 .41637 Mdot
.756 .4164 Mdot
.756 .41723 Mdot
.756 .41776 Mdot
.756 .41779 Mdot
.756 .41779 Mdot
.756 .41893 Mdot
.756 .41924 Mdot
.756 .41953 Mdot
.756 .41959 Mdot
.756 .41976 Mdot
.756 .41996 Mdot
.756 .42022 Mdot
.756 .42057 Mdot
.756 .42077 Mdot
.756 .42117 Mdot
.756 .42117 Mdot
.756 .42124 Mdot
.756 .42149 Mdot
.756 .42178 Mdot
.756 .42202 Mdot
.756 .42281 Mdot
.756 .42315 Mdot
.756 .42325 Mdot
.756 .42336 Mdot
.756 .42344 Mdot
.756 .42373 Mdot
.756 .42374 Mdot
.756 .42396 Mdot
.756 .42412 Mdot
.756 .4242 Mdot
.756 .42431 Mdot
.756 .42439 Mdot
.756 .4245 Mdot
.756 .42477 Mdot
.756 .425 Mdot
.756 .42548 Mdot
.756 .4256 Mdot
.756 .42577 Mdot
.756 .42602 Mdot
.756 .42662 Mdot
.756 .42689 Mdot
.756 .42689 Mdot
.756 .42706 Mdot
.756 .4273 Mdot
.756 .42751 Mdot
.756 .42761 Mdot
.756 .42787 Mdot
.756 .42836 Mdot
.756 .42838 Mdot
.756 .42861 Mdot
.756 .42899 Mdot
.756 .42905 Mdot
.756 .42916 Mdot
.756 .42923 Mdot
.756 .4294 Mdot
.756 .42949 Mdot
.756 .42971 Mdot
.756 .42973 Mdot
.756 .42993 Mdot
.756 .43032 Mdot
.756 .4305 Mdot
.756 .43074 Mdot
.756 .4308 Mdot
.756 .43136 Mdot
.756 .4315 Mdot
.756 .43164 Mdot
.756 .43188 Mdot
.756 .43189 Mdot
.756 .43218 Mdot
.756 .4323 Mdot
.756 .43284 Mdot
.756 .4332 Mdot
.756 .43337 Mdot
.756 .43343 Mdot
.756 .43351 Mdot
.756 .43406 Mdot
.756 .43408 Mdot
.756 .43423 Mdot
.756 .43424 Mdot
.756 .43434 Mdot
.756 .4346 Mdot
.756 .43496 Mdot
.756 .43509 Mdot
.756 .43515 Mdot
.756 .43529 Mdot
.756 .4356 Mdot
.756 .43561 Mdot
.756 .4358 Mdot
.756 .43613 Mdot
.756 .43635 Mdot
.756 .43638 Mdot
.756 .43641 Mdot
.756 .437 Mdot
.756 .43722 Mdot
.756 .43742 Mdot
.756 .43747 Mdot
.756 .43757 Mdot
.756 .43777 Mdot
.756 .43785 Mdot
.756 .43799 Mdot
.756 .43864 Mdot
.756 .43889 Mdot
.756 .43892 Mdot
.756 .43909 Mdot
.756 .43913 Mdot
.756 .43936 Mdot
.756 .44063 Mdot
.756 .44083 Mdot
.756 .44143 Mdot
.756 .44162 Mdot
.756 .44165 Mdot
.756 .44196 Mdot
.756 .44198 Mdot
.756 .44204 Mdot
.756 .44223 Mdot
.756 .44283 Mdot
.756 .44324 Mdot
.756 .44329 Mdot
.756 .44403 Mdot
.756 .44436 Mdot
.756 .44473 Mdot
.756 .44475 Mdot
.756 .44502 Mdot
.756 .44515 Mdot
.756 .44521 Mdot
.756 .44545 Mdot
.756 .44552 Mdot
.756 .44557 Mdot
.756 .44561 Mdot
.756 .44613 Mdot
.756 .44624 Mdot
.756 .44649 Mdot
.756 .44682 Mdot
.756 .44692 Mdot
.756 .44702 Mdot
.756 .44737 Mdot
.756 .44741 Mdot
.756 .44775 Mdot
.756 .44783 Mdot
.756 .44796 Mdot
.756 .44828 Mdot
.756 .4483 Mdot
.756 .44831 Mdot
.756 .44848 Mdot
.756 .44876 Mdot
.756 .44882 Mdot
.756 .44897 Mdot
.756 .44911 Mdot
.756 .44948 Mdot
.756 .44963 Mdot
.756 .44965 Mdot
.756 .4497 Mdot
.756 .44988 Mdot
.756 .45014 Mdot
.756 .45058 Mdot
.756 .45137 Mdot
.756 .45145 Mdot
.756 .452 Mdot
.756 .45219 Mdot
.756 .45244 Mdot
.756 .45262 Mdot
.756 .453 Mdot
.756 .45311 Mdot
.756 .45318 Mdot
.756 .45331 Mdot
.756 .4535 Mdot
.756 .45358 Mdot
.756 .45418 Mdot
.756 .45421 Mdot
.756 .45438 Mdot
.756 .45471 Mdot
.756 .45474 Mdot
.756 .45478 Mdot
.756 .45484 Mdot
.756 .45612 Mdot
.756 .45657 Mdot
.756 .45666 Mdot
.756 .45679 Mdot
.756 .45693 Mdot
.756 .45706 Mdot
.756 .45707 Mdot
.756 .45715 Mdot
.756 .4572 Mdot
.756 .45759 Mdot
.756 .45761 Mdot
.756 .45777 Mdot
.756 .45788 Mdot
.756 .45811 Mdot
.756 .45833 Mdot
.756 .45892 Mdot
.756 .45909 Mdot
.756 .45928 Mdot
.756 .45957 Mdot
.756 .45967 Mdot
.756 .45968 Mdot
.756 .46035 Mdot
.756 .4604 Mdot
.756 .46072 Mdot
.758 .23158 Mdot
.758 .23224 Mdot
.758 .23248 Mdot
.758 .23323 Mdot
.758 .23323 Mdot
.758 .23345 Mdot
.758 .23423 Mdot
.758 .2344 Mdot
.758 .23462 Mdot
.758 .23495 Mdot
.758 .235 Mdot
.758 .23506 Mdot
.758 .2354 Mdot
.758 .23589 Mdot
.758 .23628 Mdot
.758 .23737 Mdot
.758 .23801 Mdot
.758 .23871 Mdot
.758 .23874 Mdot
.758 .23879 Mdot
.758 .23885 Mdot
.758 .23886 Mdot
.758 .24017 Mdot
.758 .24022 Mdot
.758 .24045 Mdot
.758 .24066 Mdot
.758 .24139 Mdot
.758 .24144 Mdot
.758 .2423 Mdot
.758 .24231 Mdot
.758 .24234 Mdot
.758 .24237 Mdot
.758 .2426 Mdot
.758 .24274 Mdot
.758 .24329 Mdot
.758 .24342 Mdot
.758 .24359 Mdot
.758 .24398 Mdot
.758 .24402 Mdot
.758 .24403 Mdot
.758 .24407 Mdot
.758 .24452 Mdot
.758 .24464 Mdot
.758 .24474 Mdot
.758 .24507 Mdot
.758 .24562 Mdot
.758 .24609 Mdot
.758 .24623 Mdot
.758 .24644 Mdot
.758 .24721 Mdot
.758 .24789 Mdot
.758 .24797 Mdot
.758 .24831 Mdot
.758 .24847 Mdot
.758 .24868 Mdot
.758 .24926 Mdot
.758 .24949 Mdot
.758 .25034 Mdot
.758 .25034 Mdot
.758 .25046 Mdot
.758 .25133 Mdot
.758 .25169 Mdot
.758 .25181 Mdot
.758 .25228 Mdot
.758 .25268 Mdot
.758 .2532 Mdot
.758 .25341 Mdot
.758 .25343 Mdot
.758 .2535 Mdot
.758 .25441 Mdot
.758 .25446 Mdot
.758 .2548 Mdot
.758 .2551 Mdot
.758 .25514 Mdot
.758 .25568 Mdot
.758 .25609 Mdot
.758 .25647 Mdot
.758 .25671 Mdot
.758 .25676 Mdot
.758 .25698 Mdot
.758 .25737 Mdot
.758 .25777 Mdot
.758 .25786 Mdot
.758 .25787 Mdot
.758 .25829 Mdot
.758 .25868 Mdot
.758 .25933 Mdot
.758 .25937 Mdot
.758 .25941 Mdot
.758 .25953 Mdot
.758 .25959 Mdot
.758 .25973 Mdot
.758 .25981 Mdot
.758 .25989 Mdot
.758 .26002 Mdot
.758 .2614 Mdot
.758 .26144 Mdot
.758 .26161 Mdot
.758 .26359 Mdot
.758 .26383 Mdot
.758 .26475 Mdot
.758 .26493 Mdot
.758 .26508 Mdot
.758 .26621 Mdot
.758 .26672 Mdot
.758 .2668 Mdot
.758 .26688 Mdot
.758 .267 Mdot
.758 .26772 Mdot
.758 .26774 Mdot
.758 .26792 Mdot
.758 .2686 Mdot
.758 .26976 Mdot
.758 .27018 Mdot
.758 .27098 Mdot
.758 .27105 Mdot
.758 .27129 Mdot
.758 .27227 Mdot
.758 .27235 Mdot
.758 .27289 Mdot
.758 .2731 Mdot
.758 .27409 Mdot
.758 .27472 Mdot
.758 .27478 Mdot
.758 .27494 Mdot
.758 .27513 Mdot
.758 .27544 Mdot
.758 .27573 Mdot
.758 .27577 Mdot
.758 .27618 Mdot
.758 .27624 Mdot
.758 .27682 Mdot
.758 .27695 Mdot
.758 .27724 Mdot
.758 .27765 Mdot
.758 .27826 Mdot
.758 .27835 Mdot
.758 .27842 Mdot
.758 .27871 Mdot
.758 .27899 Mdot
.758 .28017 Mdot
.758 .28036 Mdot
.758 .28056 Mdot
.758 .28058 Mdot
.758 .28087 Mdot
.758 .28091 Mdot
.758 .28099 Mdot
.758 .28188 Mdot
.758 .28245 Mdot
.758 .28248 Mdot
.758 .28261 Mdot
.758 .28307 Mdot
.758 .28377 Mdot
.758 .28381 Mdot
.758 .28406 Mdot
.758 .28419 Mdot
.758 .28446 Mdot
.758 .28452 Mdot
.758 .2848 Mdot
.758 .28488 Mdot
.758 .28496 Mdot
.758 .28524 Mdot
.758 .28568 Mdot
.758 .28584 Mdot
.758 .28597 Mdot
.758 .28616 Mdot
.758 .28629 Mdot
.758 .28632 Mdot
.758 .28635 Mdot
.758 .28648 Mdot
.758 .2865 Mdot
.758 .2868 Mdot
.758 .28711 Mdot
.758 .28731 Mdot
.758 .28736 Mdot
.758 .28738 Mdot
.758 .28801 Mdot
.758 .28805 Mdot
.758 .28806 Mdot
.758 .2882 Mdot
.758 .28837 Mdot
.758 .28901 Mdot
.758 .28916 Mdot
.758 .2892 Mdot
.758 .28977 Mdot
.758 .29008 Mdot
.758 .29065 Mdot
.758 .29074 Mdot
.758 .29154 Mdot
.758 .29234 Mdot
.758 .2929 Mdot
.758 .2934 Mdot
.758 .2937 Mdot
.758 .29378 Mdot
.758 .29415 Mdot
.758 .29419 Mdot
.758 .29508 Mdot
.758 .29714 Mdot
.758 .29723 Mdot
.758 .29732 Mdot
.758 .29735 Mdot
.758 .2974 Mdot
.758 .29744 Mdot
.758 .29789 Mdot
.758 .29807 Mdot
.758 .29808 Mdot
.758 .29812 Mdot
.758 .29829 Mdot
.758 .29856 Mdot
.758 .29858 Mdot
.758 .29903 Mdot
.758 .29956 Mdot
.758 .30011 Mdot
.758 .30071 Mdot
.758 .30172 Mdot
.758 .30182 Mdot
.758 .30216 Mdot
.758 .30238 Mdot
.758 .30305 Mdot
.758 .3032 Mdot
.758 .3034 Mdot
.758 .30429 Mdot
.758 .30466 Mdot
.758 .30482 Mdot
.758 .30556 Mdot
.758 .30575 Mdot
.758 .30577 Mdot
.758 .30635 Mdot
.758 .30641 Mdot
.758 .30672 Mdot
.758 .30699 Mdot
.758 .30764 Mdot
.758 .30802 Mdot
.758 .30805 Mdot
.758 .30819 Mdot
.758 .30879 Mdot
.758 .30912 Mdot
.758 .30922 Mdot
.758 .30988 Mdot
.758 .3106 Mdot
.758 .31069 Mdot
.758 .31103 Mdot
.758 .31111 Mdot
.758 .3114 Mdot
.758 .31155 Mdot
.758 .31192 Mdot
.758 .313 Mdot
.758 .31302 Mdot
.758 .31305 Mdot
.758 .31374 Mdot
.758 .31415 Mdot
.758 .31417 Mdot
.758 .31455 Mdot
.758 .31455 Mdot
.758 .31456 Mdot
.758 .31467 Mdot
.758 .31498 Mdot
.758 .31503 Mdot
.758 .31528 Mdot
.758 .31529 Mdot
.758 .3153 Mdot
.758 .31531 Mdot
.758 .31551 Mdot
.758 .31556 Mdot
.758 .31561 Mdot
.758 .31575 Mdot
.758 .31626 Mdot
.758 .31668 Mdot
.758 .31698 Mdot
.758 .31716 Mdot
.758 .31732 Mdot
.758 .31804 Mdot
.758 .31804 Mdot
.758 .3181 Mdot
.758 .31848 Mdot
.758 .31863 Mdot
.758 .31889 Mdot
.758 .31906 Mdot
.758 .31938 Mdot
.758 .31939 Mdot
.758 .31942 Mdot
.758 .31981 Mdot
.758 .31999 Mdot
.758 .32012 Mdot
.758 .32013 Mdot
.758 .32055 Mdot
.758 .32071 Mdot
.758 .32093 Mdot
.758 .32167 Mdot
.758 .32197 Mdot
.758 .32213 Mdot
.758 .3222 Mdot
.758 .32285 Mdot
.758 .32287 Mdot
.758 .32295 Mdot
.758 .32381 Mdot
.758 .32391 Mdot
.758 .32439 Mdot
.758 .32446 Mdot
.758 .32495 Mdot
.758 .32517 Mdot
.758 .32529 Mdot
.758 .32561 Mdot
.758 .32668 Mdot
.758 .32703 Mdot
.758 .32716 Mdot
.758 .32759 Mdot
.758 .32762 Mdot
.758 .32794 Mdot
.758 .32838 Mdot
.758 .32868 Mdot
.758 .32883 Mdot
.758 .32897 Mdot
.758 .32909 Mdot
.758 .32911 Mdot
.758 .32929 Mdot
.758 .32957 Mdot
.758 .32975 Mdot
.758 .32992 Mdot
.758 .33026 Mdot
.758 .33051 Mdot
.758 .33111 Mdot
.758 .3312 Mdot
.758 .33177 Mdot
.758 .33261 Mdot
.758 .33271 Mdot
.758 .33277 Mdot
.758 .33349 Mdot
.758 .33363 Mdot
.758 .33368 Mdot
.758 .3337 Mdot
.758 .33377 Mdot
.758 .33378 Mdot
.758 .33391 Mdot
.758 .33404 Mdot
.758 .33413 Mdot
.758 .33416 Mdot
.758 .33445 Mdot
.758 .33446 Mdot
.758 .33495 Mdot
.758 .33597 Mdot
.758 .33656 Mdot
.758 .33711 Mdot
.758 .33712 Mdot
.758 .33845 Mdot
.758 .3385 Mdot
.758 .33854 Mdot
.758 .33873 Mdot
.758 .33881 Mdot
.758 .33891 Mdot
.758 .33902 Mdot
.758 .33946 Mdot
.758 .3397 Mdot
.758 .33996 Mdot
.758 .34044 Mdot
.758 .34059 Mdot
.758 .34152 Mdot
.758 .34168 Mdot
.758 .34207 Mdot
.758 .34216 Mdot
.758 .34241 Mdot
.758 .34269 Mdot
.758 .34297 Mdot
.758 .34314 Mdot
.758 .34348 Mdot
.758 .3443 Mdot
.758 .34448 Mdot
.758 .34484 Mdot
.758 .34531 Mdot
.758 .34533 Mdot
.758 .34563 Mdot
.758 .34581 Mdot
.758 .34582 Mdot
.758 .34598 Mdot
.758 .34598 Mdot
.758 .34599 Mdot
.758 .34604 Mdot
.758 .34617 Mdot
.758 .34619 Mdot
.758 .3463 Mdot
.758 .34631 Mdot
.758 .34631 Mdot
.758 .3464 Mdot
.758 .34642 Mdot
.758 .34644 Mdot
.758 .34672 Mdot
.758 .34683 Mdot
.758 .34691 Mdot
.758 .34719 Mdot
.758 .3475 Mdot
.758 .3475 Mdot
.758 .34753 Mdot
.758 .34769 Mdot
.758 .34776 Mdot
.758 .34787 Mdot
.758 .34795 Mdot
.758 .34808 Mdot
.758 .34809 Mdot
.758 .34827 Mdot
.758 .3484 Mdot
.758 .34859 Mdot
.758 .34866 Mdot
.758 .34876 Mdot
.758 .34908 Mdot
.758 .34928 Mdot
.758 .34931 Mdot
.758 .3496 Mdot
.758 .3496 Mdot
.758 .35001 Mdot
.758 .35006 Mdot
.758 .35026 Mdot
.758 .35029 Mdot
.758 .35051 Mdot
.758 .3506 Mdot
.758 .35066 Mdot
.758 .35126 Mdot
.758 .35141 Mdot
.758 .35181 Mdot
.758 .352 Mdot
.758 .35213 Mdot
.758 .3522 Mdot
.758 .35225 Mdot
.758 .35231 Mdot
.758 .35232 Mdot
.758 .35282 Mdot
.758 .35293 Mdot
.758 .35323 Mdot
.758 .35347 Mdot
.758 .35384 Mdot
.758 .35389 Mdot
.758 .35391 Mdot
.758 .35422 Mdot
.758 .35428 Mdot
.758 .35431 Mdot
.758 .35434 Mdot
.758 .35435 Mdot
.758 .35441 Mdot
.758 .3545 Mdot
.758 .35451 Mdot
.758 .35464 Mdot
.758 .35486 Mdot
.758 .3553 Mdot
.758 .3558 Mdot
.758 .35638 Mdot
.758 .3564 Mdot
.758 .35642 Mdot
.758 .35651 Mdot
.758 .35654 Mdot
.758 .35658 Mdot
.758 .35663 Mdot
.758 .35682 Mdot
.758 .35692 Mdot
.758 .35704 Mdot
.758 .35725 Mdot
.758 .35731 Mdot
.758 .35772 Mdot
.758 .35811 Mdot
.758 .35823 Mdot
.758 .35835 Mdot
.758 .35842 Mdot
.758 .35893 Mdot
.758 .35937 Mdot
.758 .35968 Mdot
.758 .35974 Mdot
.758 .35975 Mdot
.758 .3598 Mdot
.758 .35984 Mdot
.758 .35985 Mdot
.758 .36018 Mdot
.758 .36032 Mdot
.758 .36033 Mdot
.758 .3604 Mdot
.758 .36048 Mdot
.758 .36051 Mdot
.758 .36057 Mdot
.758 .36066 Mdot
.758 .36101 Mdot
.758 .36123 Mdot
.758 .36123 Mdot
.758 .36143 Mdot
.758 .36169 Mdot
.758 .36195 Mdot
.758 .36219 Mdot
.758 .36228 Mdot
.758 .36233 Mdot
.758 .36236 Mdot
.758 .36241 Mdot
.758 .36308 Mdot
.758 .3631 Mdot
.758 .36311 Mdot
.758 .36325 Mdot
.758 .36328 Mdot
.758 .36343 Mdot
.758 .36352 Mdot
.758 .36393 Mdot
.758 .36418 Mdot
.758 .36419 Mdot
.758 .3642 Mdot
.758 .36437 Mdot
.758 .36447 Mdot
.758 .36476 Mdot
.758 .36529 Mdot
.758 .36549 Mdot
.758 .36562 Mdot
.758 .36569 Mdot
.758 .3659 Mdot
.758 .36601 Mdot
.758 .36604 Mdot
.758 .36629 Mdot
.758 .36661 Mdot
.758 .3671 Mdot
.758 .36717 Mdot
.758 .36729 Mdot
.758 .36758 Mdot
.758 .36758 Mdot
.758 .36766 Mdot
.758 .3682 Mdot
.758 .36833 Mdot
.758 .36839 Mdot
.758 .3685 Mdot
.758 .36863 Mdot
.758 .36885 Mdot
.758 .36909 Mdot
.758 .36941 Mdot
.758 .36946 Mdot
.758 .36951 Mdot
.758 .36987 Mdot
.758 .37005 Mdot
.758 .37029 Mdot
.758 .37041 Mdot
.758 .37064 Mdot
.758 .37068 Mdot
.758 .37122 Mdot
.758 .37131 Mdot
.758 .37138 Mdot
.758 .37186 Mdot
.758 .37192 Mdot
.758 .37192 Mdot
.758 .37211 Mdot
.758 .37224 Mdot
.758 .37256 Mdot
.758 .37277 Mdot
.758 .37293 Mdot
.758 .37302 Mdot
.758 .37321 Mdot
.758 .37343 Mdot
.758 .37397 Mdot
.758 .37403 Mdot
.758 .37415 Mdot
.758 .37415 Mdot
.758 .37416 Mdot
.758 .37459 Mdot
.758 .37478 Mdot
.758 .37487 Mdot
.758 .37489 Mdot
.758 .37547 Mdot
.758 .37563 Mdot
.758 .37611 Mdot
.758 .37625 Mdot
.758 .37649 Mdot
.758 .37654 Mdot
.758 .37658 Mdot
.758 .3766 Mdot
.758 .3767 Mdot
.758 .37671 Mdot
.758 .37702 Mdot
.758 .37713 Mdot
.758 .37733 Mdot
.758 .37762 Mdot
.758 .37809 Mdot
.758 .37817 Mdot
.758 .37842 Mdot
.758 .37869 Mdot
.758 .37887 Mdot
.758 .37901 Mdot
.758 .37914 Mdot
.758 .3792 Mdot
.758 .37928 Mdot
.758 .37929 Mdot
.758 .37931 Mdot
.758 .37969 Mdot
.758 .38002 Mdot
.758 .38031 Mdot
.758 .38045 Mdot
.758 .38064 Mdot
.758 .38067 Mdot
.758 .38073 Mdot
.758 .38093 Mdot
.758 .38095 Mdot
.758 .38098 Mdot
.758 .38122 Mdot
.758 .38158 Mdot
.758 .38165 Mdot
.758 .38199 Mdot
.758 .38199 Mdot
.758 .38207 Mdot
.758 .38211 Mdot
.758 .3822 Mdot
.758 .38232 Mdot
.758 .38258 Mdot
.758 .38268 Mdot
.758 .38308 Mdot
.758 .38318 Mdot
.758 .38332 Mdot
.758 .38334 Mdot
.758 .38348 Mdot
.758 .38378 Mdot
.758 .38378 Mdot
.758 .38397 Mdot
.758 .38412 Mdot
.758 .38457 Mdot
.758 .38465 Mdot
.758 .38478 Mdot
.758 .38487 Mdot
.758 .38492 Mdot
.758 .38504 Mdot
.758 .38515 Mdot
.758 .38516 Mdot
.758 .38537 Mdot
.758 .38555 Mdot
.758 .38561 Mdot
.758 .38567 Mdot
.758 .38586 Mdot
.758 .38587 Mdot
.758 .38589 Mdot
.758 .38595 Mdot
.758 .38595 Mdot
.758 .38603 Mdot
.758 .38604 Mdot
.758 .38613 Mdot
.758 .38616 Mdot
.758 .38627 Mdot
.758 .3864 Mdot
.758 .3866 Mdot
.758 .3866 Mdot
.758 .38727 Mdot
.758 .38804 Mdot
.758 .38815 Mdot
.758 .38833 Mdot
.758 .38852 Mdot
.758 .38868 Mdot
.758 .38874 Mdot
.758 .389 Mdot
.758 .38911 Mdot
.758 .38972 Mdot
.758 .38982 Mdot
.758 .39014 Mdot
.758 .39031 Mdot
.758 .39047 Mdot
.758 .39075 Mdot
.758 .39083 Mdot
.758 .39089 Mdot
.758 .39094 Mdot
.758 .39108 Mdot
.758 .3911 Mdot
.758 .39113 Mdot
.758 .39201 Mdot
.758 .39202 Mdot
.758 .39238 Mdot
.758 .39277 Mdot
.758 .39344 Mdot
.758 .39377 Mdot
.758 .39377 Mdot
.758 .39396 Mdot
.758 .39398 Mdot
.758 .39404 Mdot
.758 .39413 Mdot
.758 .39421 Mdot
.758 .39422 Mdot
.758 .39427 Mdot
.758 .39428 Mdot
.758 .39431 Mdot
.758 .3944 Mdot
.758 .39488 Mdot
.758 .39492 Mdot
.758 .39499 Mdot
.758 .39554 Mdot
.758 .39591 Mdot
.758 .39598 Mdot
.758 .39637 Mdot
.758 .39653 Mdot
.758 .39676 Mdot
.758 .39687 Mdot
.758 .39699 Mdot
.758 .39718 Mdot
.758 .39729 Mdot
.758 .39731 Mdot
.758 .39739 Mdot
.758 .39748 Mdot
.758 .39758 Mdot
.758 .39778 Mdot
.758 .39806 Mdot
.758 .39827 Mdot
.758 .3983 Mdot
.758 .39858 Mdot
.758 .39867 Mdot
.758 .3989 Mdot
.758 .3996 Mdot
.758 .39981 Mdot
.758 .39989 Mdot
.758 .40004 Mdot
.758 .40036 Mdot
.758 .40041 Mdot
.758 .40072 Mdot
.758 .40079 Mdot
.758 .40136 Mdot
.758 .40141 Mdot
.758 .40142 Mdot
.758 .40185 Mdot
.758 .4019 Mdot
.758 .402 Mdot
.758 .4022 Mdot
.758 .40269 Mdot
.758 .40283 Mdot
.758 .40294 Mdot
.758 .40322 Mdot
.758 .40323 Mdot
.758 .40331 Mdot
.758 .40343 Mdot
.758 .40369 Mdot
.758 .40371 Mdot
.758 .40371 Mdot
.758 .40392 Mdot
.758 .40404 Mdot
.758 .40421 Mdot
.758 .40431 Mdot
.758 .40456 Mdot
.758 .40459 Mdot
.758 .40459 Mdot
.758 .40507 Mdot
.758 .40518 Mdot
.758 .4053 Mdot
.758 .40549 Mdot
.758 .40562 Mdot
.758 .40577 Mdot
.758 .40611 Mdot
.758 .4062 Mdot
.758 .40623 Mdot
.758 .40626 Mdot
.758 .40639 Mdot
.758 .4064 Mdot
.758 .40641 Mdot
.758 .40642 Mdot
.758 .40658 Mdot
.758 .40662 Mdot
.758 .40682 Mdot
.758 .40689 Mdot
.758 .4069 Mdot
.758 .4069 Mdot
.758 .40715 Mdot
.758 .40716 Mdot
.758 .40743 Mdot
.758 .40789 Mdot
.758 .40791 Mdot
.758 .40792 Mdot
.758 .40863 Mdot
.758 .40888 Mdot
.758 .40898 Mdot
.758 .40917 Mdot
.758 .40922 Mdot
.758 .40944 Mdot
.758 .4095 Mdot
.758 .40998 Mdot
.758 .41041 Mdot
.758 .41048 Mdot
.758 .4107 Mdot
.758 .41109 Mdot
.758 .41119 Mdot
.758 .4112 Mdot
.758 .41146 Mdot
.758 .41188 Mdot
.758 .41207 Mdot
.758 .41227 Mdot
.758 .41231 Mdot
.758 .41269 Mdot
.758 .4127 Mdot
.758 .41283 Mdot
.758 .41332 Mdot
.758 .41342 Mdot
.758 .41367 Mdot
.758 .41425 Mdot
.758 .41439 Mdot
.758 .41449 Mdot
.758 .41492 Mdot
.758 .41507 Mdot
.758 .4153 Mdot
.758 .41536 Mdot
.758 .41603 Mdot
.758 .41643 Mdot
.758 .41679 Mdot
.758 .41714 Mdot
.758 .41743 Mdot
.758 .41745 Mdot
.758 .41762 Mdot
.758 .41774 Mdot
.758 .41776 Mdot
.758 .41777 Mdot
.758 .41789 Mdot
.758 .41819 Mdot
.758 .41821 Mdot
.758 .41824 Mdot
.758 .41826 Mdot
.758 .41832 Mdot
.758 .41838 Mdot
.758 .41974 Mdot
.758 .42033 Mdot
.758 .42035 Mdot
.758 .4206 Mdot
.758 .42065 Mdot
.758 .42085 Mdot
.758 .42118 Mdot
.758 .42155 Mdot
.758 .42208 Mdot
.758 .4226 Mdot
.758 .42267 Mdot
.758 .42304 Mdot
.758 .42324 Mdot
.758 .42362 Mdot
.758 .42364 Mdot
.758 .42375 Mdot
.758 .42417 Mdot
.758 .42428 Mdot
.758 .42437 Mdot
.758 .42438 Mdot
.758 .4244 Mdot
.758 .42482 Mdot
.758 .42483 Mdot
.758 .42487 Mdot
.758 .425 Mdot
.758 .4252 Mdot
.758 .4254 Mdot
.758 .42542 Mdot
.758 .4255 Mdot
.758 .42552 Mdot
.758 .42554 Mdot
.758 .42562 Mdot
.758 .42575 Mdot
.758 .42583 Mdot
.758 .42594 Mdot
.758 .42623 Mdot
.758 .42642 Mdot
.758 .42647 Mdot
.758 .42652 Mdot
.758 .4267 Mdot
.758 .42675 Mdot
.758 .42692 Mdot
.758 .42701 Mdot
.758 .42717 Mdot
.758 .4272 Mdot
.758 .42766 Mdot
.758 .42797 Mdot
.758 .42805 Mdot
.758 .42807 Mdot
.758 .42845 Mdot
.758 .42904 Mdot
.758 .42909 Mdot
.758 .42911 Mdot
.758 .42931 Mdot
.758 .42932 Mdot
.758 .42945 Mdot
.758 .42958 Mdot
.758 .43035 Mdot
.758 .43054 Mdot
.758 .43073 Mdot
.758 .43078 Mdot
.758 .43084 Mdot
.758 .43124 Mdot
.758 .43151 Mdot
.758 .4317 Mdot
.758 .43179 Mdot
.758 .43217 Mdot
.758 .43221 Mdot
.758 .43248 Mdot
.758 .43251 Mdot
.758 .43269 Mdot
.758 .4329 Mdot
.758 .43303 Mdot
.758 .43313 Mdot
.758 .43317 Mdot
.758 .43359 Mdot
.758 .43424 Mdot
.758 .43438 Mdot
.758 .43473 Mdot
.758 .43478 Mdot
.758 .43543 Mdot
.758 .43559 Mdot
.758 .43564 Mdot
.758 .43616 Mdot
.758 .43644 Mdot
.758 .43721 Mdot
.758 .43765 Mdot
.758 .43778 Mdot
.758 .43779 Mdot
.758 .43826 Mdot
.758 .43834 Mdot
.758 .4384 Mdot
.758 .43845 Mdot
.758 .43879 Mdot
.758 .43953 Mdot
.758 .43963 Mdot
.758 .43975 Mdot
.758 .44035 Mdot
.758 .44051 Mdot
.758 .44182 Mdot
.758 .44193 Mdot
.758 .44196 Mdot
.758 .44286 Mdot
.758 .44295 Mdot
.758 .44301 Mdot
.758 .44306 Mdot
.758 .44315 Mdot
.758 .44319 Mdot
.758 .44327 Mdot
.758 .4433 Mdot
.758 .44332 Mdot
.758 .44375 Mdot
.758 .44401 Mdot
.758 .44428 Mdot
.758 .44429 Mdot
.758 .44435 Mdot
.758 .44461 Mdot
.758 .44487 Mdot
.758 .44502 Mdot
.758 .44505 Mdot
.758 .44521 Mdot
.758 .44546 Mdot
.758 .44573 Mdot
.758 .44609 Mdot
.758 .44611 Mdot
.758 .44631 Mdot
.758 .44654 Mdot
.758 .44657 Mdot
.758 .44717 Mdot
.758 .44722 Mdot
.758 .44723 Mdot
.758 .44737 Mdot
.758 .44771 Mdot
.758 .44797 Mdot
.758 .44828 Mdot
.758 .44836 Mdot
.758 .4486 Mdot
.758 .44917 Mdot
.758 .44925 Mdot
.758 .44926 Mdot
.758 .44981 Mdot
.758 .44996 Mdot
.758 .45035 Mdot
.758 .45048 Mdot
.758 .45059 Mdot
.758 .45082 Mdot
.758 .45087 Mdot
.758 .45132 Mdot
.758 .45183 Mdot
.758 .45196 Mdot
.758 .45205 Mdot
.758 .45237 Mdot
.758 .45273 Mdot
.758 .45295 Mdot
.758 .45301 Mdot
.758 .45309 Mdot
.758 .45339 Mdot
.758 .45341 Mdot
.758 .45342 Mdot
.758 .45345 Mdot
.758 .4537 Mdot
.758 .45382 Mdot
.758 .4539 Mdot
.758 .45427 Mdot
.758 .45436 Mdot
.758 .45451 Mdot
.758 .45453 Mdot
.758 .45455 Mdot
.758 .45455 Mdot
.758 .45513 Mdot
.758 .45516 Mdot
.758 .45564 Mdot
.758 .45578 Mdot
.758 .45593 Mdot
.758 .45596 Mdot
.758 .45683 Mdot
.758 .45683 Mdot
.758 .45687 Mdot
.758 .4569 Mdot
.758 .45693 Mdot
.758 .45739 Mdot
.758 .45781 Mdot
.758 .45853 Mdot
.758 .45879 Mdot
.758 .4591 Mdot
.758 .45933 Mdot
.758 .45937 Mdot
.758 .4594 Mdot
.758 .45962 Mdot
.758 .45977 Mdot
.758 .45988 Mdot
.758 .46039 Mdot
.758 .46054 Mdot
.758 .46054 Mdot
.758 .46104 Mdot
.758 .46119 Mdot
.758 .46163 Mdot
.76 .23013 Mdot
.76 .2302 Mdot
.76 .23037 Mdot
.76 .23053 Mdot
.76 .23086 Mdot
.76 .23155 Mdot
.76 .23193 Mdot
.76 .23201 Mdot
.76 .23246 Mdot
.76 .23294 Mdot
.76 .23308 Mdot
.76 .23347 Mdot
.76 .23384 Mdot
.76 .23409 Mdot
.76 .23421 Mdot
.76 .23442 Mdot
.76 .23455 Mdot
.76 .23463 Mdot
.76 .23503 Mdot
.76 .2351 Mdot
.76 .23531 Mdot
.76 .23545 Mdot
.76 .23553 Mdot
.76 .23614 Mdot
.76 .23622 Mdot
.76 .23668 Mdot
.76 .23695 Mdot
.76 .23695 Mdot
.76 .23778 Mdot
.76 .2378 Mdot
.76 .23906 Mdot
.76 .23914 Mdot
.76 .23971 Mdot
.76 .24044 Mdot
.76 .24056 Mdot
.76 .24103 Mdot
.76 .24162 Mdot
.76 .24182 Mdot
.76 .24201 Mdot
.76 .24202 Mdot
.76 .24269 Mdot
.76 .24276 Mdot
.76 .24305 Mdot
.76 .24319 Mdot
.76 .24373 Mdot
.76 .24376 Mdot
.76 .24425 Mdot
.76 .24445 Mdot
.76 .24495 Mdot
.76 .24498 Mdot
.76 .245 Mdot
.76 .24524 Mdot
.76 .24599 Mdot
.76 .24648 Mdot
.76 .2465 Mdot
.76 .24667 Mdot
.76 .2468 Mdot
.76 .24778 Mdot
.76 .24897 Mdot
.76 .24937 Mdot
.76 .2494 Mdot
.76 .24949 Mdot
.76 .24961 Mdot
.76 .25094 Mdot
.76 .25096 Mdot
.76 .2515 Mdot
.76 .25166 Mdot
.76 .25193 Mdot
.76 .25227 Mdot
.76 .25317 Mdot
.76 .25323 Mdot
.76 .25366 Mdot
.76 .25393 Mdot
.76 .25476 Mdot
.76 .25495 Mdot
.76 .255 Mdot
.76 .25516 Mdot
.76 .2554 Mdot
.76 .25548 Mdot
.76 .25578 Mdot
.76 .25677 Mdot
.76 .25679 Mdot
.76 .25716 Mdot
.76 .25738 Mdot
.76 .25749 Mdot
.76 .25782 Mdot
.76 .25797 Mdot
.76 .25805 Mdot
.76 .25848 Mdot
.76 .25863 Mdot
.76 .25864 Mdot
.76 .25916 Mdot
.76 .25925 Mdot
.76 .25972 Mdot
.76 .25986 Mdot
.76 .26016 Mdot
.76 .2604 Mdot
.76 .26059 Mdot
.76 .26073 Mdot
.76 .26088 Mdot
.76 .26135 Mdot
.76 .26204 Mdot
.76 .26211 Mdot
.76 .26226 Mdot
.76 .26226 Mdot
.76 .26266 Mdot
.76 .26284 Mdot
.76 .26375 Mdot
.76 .26384 Mdot
.76 .2639 Mdot
.76 .26489 Mdot
.76 .26495 Mdot
.76 .26503 Mdot
.76 .26503 Mdot
.76 .26507 Mdot
.76 .26612 Mdot
.76 .26677 Mdot
.76 .26685 Mdot
.76 .26765 Mdot
.76 .26777 Mdot
.76 .26826 Mdot
.76 .26912 Mdot
.76 .26943 Mdot
.76 .26947 Mdot
.76 .26968 Mdot
.76 .26991 Mdot
.76 .26992 Mdot
.76 .27007 Mdot
.76 .27081 Mdot
.76 .27204 Mdot
.76 .2723 Mdot
.76 .27235 Mdot
.76 .27236 Mdot
.76 .27258 Mdot
.76 .27334 Mdot
.76 .27386 Mdot
.76 .27417 Mdot
.76 .27422 Mdot
.76 .27437 Mdot
.76 .27444 Mdot
.76 .2748 Mdot
.76 .27506 Mdot
.76 .27514 Mdot
.76 .27565 Mdot
.76 .27576 Mdot
.76 .27644 Mdot
.76 .27649 Mdot
.76 .27716 Mdot
.76 .2774 Mdot
.76 .27743 Mdot
.76 .27828 Mdot
.76 .27881 Mdot
.76 .27882 Mdot
.76 .27967 Mdot
.76 .28034 Mdot
.76 .28055 Mdot
.76 .28094 Mdot
.76 .28106 Mdot
.76 .28134 Mdot
.76 .28154 Mdot
.76 .28173 Mdot
.76 .28207 Mdot
.76 .28257 Mdot
.76 .2834 Mdot
.76 .28388 Mdot
.76 .28407 Mdot
.76 .28407 Mdot
.76 .28449 Mdot
.76 .28462 Mdot
.76 .2848 Mdot
.76 .28484 Mdot
.76 .28488 Mdot
.76 .28728 Mdot
.76 .28736 Mdot
.76 .28745 Mdot
.76 .28779 Mdot
.76 .28788 Mdot
.76 .28817 Mdot
.76 .28854 Mdot
.76 .28854 Mdot
.76 .28914 Mdot
.76 .28915 Mdot
.76 .28955 Mdot
.76 .28957 Mdot
.76 .28986 Mdot
.76 .29013 Mdot
.76 .29043 Mdot
.76 .29068 Mdot
.76 .29091 Mdot
.76 .29133 Mdot
.76 .292 Mdot
.76 .29249 Mdot
.76 .2926 Mdot
.76 .29375 Mdot
.76 .29449 Mdot
.76 .2945 Mdot
.76 .29454 Mdot
.76 .295 Mdot
.76 .29502 Mdot
.76 .29545 Mdot
.76 .29577 Mdot
.76 .2961 Mdot
.76 .29637 Mdot
.76 .29662 Mdot
.76 .29675 Mdot
.76 .29727 Mdot
.76 .29734 Mdot
.76 .29777 Mdot
.76 .29781 Mdot
.76 .29851 Mdot
.76 .29878 Mdot
.76 .29885 Mdot
.76 .29887 Mdot
.76 .29931 Mdot
.76 .29964 Mdot
.76 .30003 Mdot
.76 .30127 Mdot
.76 .30128 Mdot
.76 .30252 Mdot
.76 .30253 Mdot
.76 .30341 Mdot
.76 .3035 Mdot
.76 .30372 Mdot
.76 .30447 Mdot
.76 .30455 Mdot
.76 .30489 Mdot
.76 .3051 Mdot
.76 .30515 Mdot
.76 .30575 Mdot
.76 .3063 Mdot
.76 .30666 Mdot
.76 .30677 Mdot
.76 .30701 Mdot
.76 .30731 Mdot
.76 .30746 Mdot
.76 .30766 Mdot
.76 .30776 Mdot
.76 .30834 Mdot
.76 .3086 Mdot
.76 .3088 Mdot
.76 .30978 Mdot
.76 .30981 Mdot
.76 .30989 Mdot
.76 .30995 Mdot
.76 .3101 Mdot
.76 .3104 Mdot
.76 .31056 Mdot
.76 .311 Mdot
.76 .31123 Mdot
.76 .31139 Mdot
.76 .31149 Mdot
.76 .31155 Mdot
.76 .3117 Mdot
.76 .3119 Mdot
.76 .31202 Mdot
.76 .31212 Mdot
.76 .31242 Mdot
.76 .31273 Mdot
.76 .3131 Mdot
.76 .31368 Mdot
.76 .31393 Mdot
.76 .31476 Mdot
.76 .31493 Mdot
.76 .31522 Mdot
.76 .31525 Mdot
.76 .31537 Mdot
.76 .31543 Mdot
.76 .31568 Mdot
.76 .31619 Mdot
.76 .31621 Mdot
.76 .31622 Mdot
.76 .31632 Mdot
.76 .31665 Mdot
.76 .31694 Mdot
.76 .31699 Mdot
.76 .31742 Mdot
.76 .31794 Mdot
.76 .31816 Mdot
.76 .31821 Mdot
.76 .31879 Mdot
.76 .3188 Mdot
.76 .31903 Mdot
.76 .3191 Mdot
.76 .31922 Mdot
.76 .31978 Mdot
.76 .31996 Mdot
.76 .32044 Mdot
.76 .32072 Mdot
.76 .32075 Mdot
.76 .32131 Mdot
.76 .32132 Mdot
.76 .32148 Mdot
.76 .32176 Mdot
.76 .32183 Mdot
.76 .32187 Mdot
.76 .32212 Mdot
.76 .32234 Mdot
.76 .32239 Mdot
.76 .32259 Mdot
.76 .32288 Mdot
.76 .32297 Mdot
.76 .32309 Mdot
.76 .32359 Mdot
.76 .32369 Mdot
.76 .32369 Mdot
.76 .32386 Mdot
.76 .32433 Mdot
.76 .32483 Mdot
.76 .32489 Mdot
.76 .32536 Mdot
.76 .32567 Mdot
.76 .32602 Mdot
.76 .32607 Mdot
.76 .32628 Mdot
.76 .32666 Mdot
.76 .32681 Mdot
.76 .327 Mdot
.76 .327 Mdot
.76 .32707 Mdot
.76 .32792 Mdot
.76 .32804 Mdot
.76 .32806 Mdot
.76 .32816 Mdot
.76 .32884 Mdot
.76 .32886 Mdot
.76 .32893 Mdot
.76 .32912 Mdot
.76 .32923 Mdot
.76 .32948 Mdot
.76 .33014 Mdot
.76 .33062 Mdot
.76 .33177 Mdot
.76 .33182 Mdot
.76 .33226 Mdot
.76 .33248 Mdot
.76 .33284 Mdot
.76 .33305 Mdot
.76 .33313 Mdot
.76 .33313 Mdot
.76 .33331 Mdot
.76 .33345 Mdot
.76 .33346 Mdot
.76 .33348 Mdot
.76 .33474 Mdot
.76 .33506 Mdot
.76 .33506 Mdot
.76 .3355 Mdot
.76 .33563 Mdot
.76 .33575 Mdot
.76 .33588 Mdot
.76 .33609 Mdot
.76 .33627 Mdot
.76 .33656 Mdot
.76 .33677 Mdot
.76 .33764 Mdot
.76 .33764 Mdot
.76 .33787 Mdot
.76 .33819 Mdot
.76 .33856 Mdot
.76 .33861 Mdot
.76 .33887 Mdot
.76 .33908 Mdot
.76 .33938 Mdot
.76 .33949 Mdot
.76 .33952 Mdot
.76 .33953 Mdot
.76 .33987 Mdot
.76 .34003 Mdot
.76 .34112 Mdot
.76 .3415 Mdot
.76 .34154 Mdot
.76 .34163 Mdot
.76 .34214 Mdot
.76 .34225 Mdot
.76 .34251 Mdot
.76 .34275 Mdot
.76 .34306 Mdot
.76 .34319 Mdot
.76 .34325 Mdot
.76 .34334 Mdot
.76 .34338 Mdot
.76 .34383 Mdot
.76 .34427 Mdot
.76 .3443 Mdot
.76 .34439 Mdot
.76 .34452 Mdot
.76 .34478 Mdot
.76 .34488 Mdot
.76 .345 Mdot
.76 .34509 Mdot
.76 .34527 Mdot
.76 .3454 Mdot
.76 .34569 Mdot
.76 .34595 Mdot
.76 .34641 Mdot
.76 .34649 Mdot
.76 .34661 Mdot
.76 .34662 Mdot
.76 .34668 Mdot
.76 .3467 Mdot
.76 .34704 Mdot
.76 .34723 Mdot
.76 .34738 Mdot
.76 .34756 Mdot
.76 .34779 Mdot
.76 .34788 Mdot
.76 .34791 Mdot
.76 .34816 Mdot
.76 .34816 Mdot
.76 .34826 Mdot
.76 .34829 Mdot
.76 .34834 Mdot
.76 .34866 Mdot
.76 .34887 Mdot
.76 .34899 Mdot
.76 .34901 Mdot
.76 .34925 Mdot
.76 .34925 Mdot
.76 .34944 Mdot
.76 .3496 Mdot
.76 .34969 Mdot
.76 .3498 Mdot
.76 .35002 Mdot
.76 .35024 Mdot
.76 .35028 Mdot
.76 .35035 Mdot
.76 .35056 Mdot
.76 .35077 Mdot
.76 .35079 Mdot
.76 .351 Mdot
.76 .35129 Mdot
.76 .35131 Mdot
.76 .3514 Mdot
.76 .35156 Mdot
.76 .35171 Mdot
.76 .35171 Mdot
.76 .35211 Mdot
.76 .35216 Mdot
.76 .35217 Mdot
.76 .35221 Mdot
.76 .35251 Mdot
.76 .35252 Mdot
.76 .35267 Mdot
.76 .35278 Mdot
.76 .35307 Mdot
.76 .35378 Mdot
.76 .3538 Mdot
.76 .35399 Mdot
.76 .35408 Mdot
.76 .35424 Mdot
.76 .35451 Mdot
.76 .35451 Mdot
.76 .35506 Mdot
.76 .3552 Mdot
.76 .3552 Mdot
.76 .35539 Mdot
.76 .35545 Mdot
.76 .35572 Mdot
.76 .35585 Mdot
.76 .35594 Mdot
.76 .35631 Mdot
.76 .35632 Mdot
.76 .35641 Mdot
.76 .35671 Mdot
.76 .35685 Mdot
.76 .35694 Mdot
.76 .35707 Mdot
.76 .35712 Mdot
.76 .35782 Mdot
.76 .35799 Mdot
.76 .358 Mdot
.76 .35872 Mdot
.76 .35878 Mdot
.76 .35918 Mdot
.76 .35929 Mdot
.76 .35941 Mdot
.76 .35962 Mdot
.76 .35991 Mdot
.76 .3602 Mdot
.76 .36023 Mdot
.76 .36038 Mdot
.76 .36053 Mdot
.76 .36061 Mdot
.76 .36087 Mdot
.76 .36092 Mdot
.76 .36123 Mdot
.76 .36134 Mdot
.76 .36178 Mdot
.76 .362 Mdot
.76 .3621 Mdot
.76 .36234 Mdot
.76 .3624 Mdot
.76 .3624 Mdot
.76 .3626 Mdot
.76 .36282 Mdot
.76 .36287 Mdot
.76 .36299 Mdot
.76 .36339 Mdot
.76 .36343 Mdot
.76 .3635 Mdot
.76 .36361 Mdot
.76 .36385 Mdot
.76 .36391 Mdot
.76 .36402 Mdot
.76 .3644 Mdot
.76 .36467 Mdot
.76 .36472 Mdot
.76 .36474 Mdot
.76 .36512 Mdot
.76 .36564 Mdot
.76 .36569 Mdot
.76 .36626 Mdot
.76 .36637 Mdot
.76 .36639 Mdot
.76 .3669 Mdot
.76 .36701 Mdot
.76 .36703 Mdot
.76 .36703 Mdot
.76 .36729 Mdot
.76 .36748 Mdot
.76 .36751 Mdot
.76 .36766 Mdot
.76 .36875 Mdot
.76 .36876 Mdot
.76 .36898 Mdot
.76 .36904 Mdot
.76 .36924 Mdot
.76 .36931 Mdot
.76 .36978 Mdot
.76 .37023 Mdot
.76 .37079 Mdot
.76 .37108 Mdot
.76 .37139 Mdot
.76 .37144 Mdot
.76 .37157 Mdot
.76 .37175 Mdot
.76 .37176 Mdot
.76 .37248 Mdot
.76 .37258 Mdot
.76 .37289 Mdot
.76 .37298 Mdot
.76 .37331 Mdot
.76 .37333 Mdot
.76 .37378 Mdot
.76 .37381 Mdot
.76 .37462 Mdot
.76 .37487 Mdot
.76 .37498 Mdot
.76 .37522 Mdot
.76 .37526 Mdot
.76 .37529 Mdot
.76 .37555 Mdot
.76 .3758 Mdot
.76 .37593 Mdot
.76 .37594 Mdot
.76 .37598 Mdot
.76 .37614 Mdot
.76 .37691 Mdot
.76 .37695 Mdot
.76 .37712 Mdot
.76 .37717 Mdot
.76 .37726 Mdot
.76 .37791 Mdot
.76 .37798 Mdot
.76 .37805 Mdot
.76 .37832 Mdot
.76 .37884 Mdot
.76 .37941 Mdot
.76 .37945 Mdot
.76 .37953 Mdot
.76 .37959 Mdot
.76 .37988 Mdot
.76 .37994 Mdot
.76 .37994 Mdot
.76 .38019 Mdot
.76 .38051 Mdot
.76 .38055 Mdot
.76 .38068 Mdot
.76 .38068 Mdot
.76 .38077 Mdot
.76 .38113 Mdot
.76 .38113 Mdot
.76 .38131 Mdot
.76 .38141 Mdot
.76 .38147 Mdot
.76 .38208 Mdot
.76 .38226 Mdot
.76 .38234 Mdot
.76 .38264 Mdot
.76 .38267 Mdot
.76 .38268 Mdot
.76 .38297 Mdot
.76 .38297 Mdot
.76 .38307 Mdot
.76 .38324 Mdot
.76 .38344 Mdot
.76 .38357 Mdot
.76 .38359 Mdot
.76 .38373 Mdot
.76 .38391 Mdot
.76 .38423 Mdot
.76 .38446 Mdot
.76 .38459 Mdot
.76 .38459 Mdot
.76 .38475 Mdot
.76 .38522 Mdot
.76 .38524 Mdot
.76 .38531 Mdot
.76 .38547 Mdot
.76 .38549 Mdot
.76 .3857 Mdot
.76 .38582 Mdot
.76 .38604 Mdot
.76 .38626 Mdot
.76 .38628 Mdot
.76 .38633 Mdot
.76 .38641 Mdot
.76 .38676 Mdot
.76 .38712 Mdot
.76 .38721 Mdot
.76 .38733 Mdot
.76 .38753 Mdot
.76 .3877 Mdot
.76 .38778 Mdot
.76 .38787 Mdot
.76 .38815 Mdot
.76 .38845 Mdot
.76 .38848 Mdot
.76 .38858 Mdot
.76 .38866 Mdot
.76 .3896 Mdot
.76 .38966 Mdot
.76 .38969 Mdot
.76 .38994 Mdot
.76 .39065 Mdot
.76 .39076 Mdot
.76 .39098 Mdot
.76 .39099 Mdot
.76 .39101 Mdot
.76 .39108 Mdot
.76 .39128 Mdot
.76 .39142 Mdot
.76 .39159 Mdot
.76 .39162 Mdot
.76 .39186 Mdot
.76 .39208 Mdot
.76 .39222 Mdot
.76 .39223 Mdot
.76 .3928 Mdot
.76 .39294 Mdot
.76 .39313 Mdot
.76 .39325 Mdot
.76 .39338 Mdot
.76 .39347 Mdot
.76 .39355 Mdot
.76 .39364 Mdot
.76 .39392 Mdot
.76 .39392 Mdot
.76 .39414 Mdot
.76 .39497 Mdot
.76 .39498 Mdot
.76 .39499 Mdot
.76 .39508 Mdot
.76 .3952 Mdot
.76 .3952 Mdot
.76 .39525 Mdot
.76 .39539 Mdot
.76 .39562 Mdot
.76 .39576 Mdot
.76 .39605 Mdot
.76 .39609 Mdot
.76 .39685 Mdot
.76 .39716 Mdot
.76 .39759 Mdot
.76 .39776 Mdot
.76 .39784 Mdot
.76 .39796 Mdot
.76 .398 Mdot
.76 .39802 Mdot
.76 .39847 Mdot
.76 .39853 Mdot
.76 .39855 Mdot
.76 .39862 Mdot
.76 .39918 Mdot
.76 .39922 Mdot
.76 .39923 Mdot
.76 .39935 Mdot
.76 .39945 Mdot
.76 .3997 Mdot
.76 .39984 Mdot
.76 .39987 Mdot
.76 .4001 Mdot
.76 .40031 Mdot
.76 .40062 Mdot
.76 .40066 Mdot
.76 .40098 Mdot
.76 .40129 Mdot
.76 .40141 Mdot
.76 .40141 Mdot
.76 .40147 Mdot
.76 .4018 Mdot
.76 .40188 Mdot
.76 .40194 Mdot
.76 .40213 Mdot
.76 .40226 Mdot
.76 .40229 Mdot
.76 .40244 Mdot
.76 .4026 Mdot
.76 .40263 Mdot
.76 .40267 Mdot
.76 .40286 Mdot
.76 .40296 Mdot
.76 .40297 Mdot
.76 .40334 Mdot
.76 .40336 Mdot
.76 .40354 Mdot
.76 .40386 Mdot
.76 .40398 Mdot
.76 .40435 Mdot
.76 .40442 Mdot
.76 .40447 Mdot
.76 .40462 Mdot
.76 .40463 Mdot
.76 .40501 Mdot
.76 .40504 Mdot
.76 .40519 Mdot
.76 .40553 Mdot
.76 .40581 Mdot
.76 .40585 Mdot
.76 .40604 Mdot
.76 .40625 Mdot
.76 .40632 Mdot
.76 .40633 Mdot
.76 .40634 Mdot
.76 .40667 Mdot
.76 .40684 Mdot
.76 .40688 Mdot
.76 .40696 Mdot
.76 .40698 Mdot
.76 .40717 Mdot
.76 .40728 Mdot
.76 .40783 Mdot
.76 .40799 Mdot
.76 .40837 Mdot
.76 .40861 Mdot
.76 .40882 Mdot
.76 .40902 Mdot
.76 .40908 Mdot
.76 .40916 Mdot
.76 .4093 Mdot
.76 .40939 Mdot
.76 .40943 Mdot
.76 .4095 Mdot
.76 .4096 Mdot
.76 .40976 Mdot
.76 .41004 Mdot
.76 .41015 Mdot
.76 .41035 Mdot
.76 .41044 Mdot
.76 .41049 Mdot
.76 .41054 Mdot
.76 .41056 Mdot
.76 .4112 Mdot
.76 .41133 Mdot
.76 .41151 Mdot
.76 .41189 Mdot
.76 .41195 Mdot
.76 .41208 Mdot
.76 .41218 Mdot
.76 .41238 Mdot
.76 .41253 Mdot
.76 .41261 Mdot
.76 .41285 Mdot
.76 .41321 Mdot
.76 .4136 Mdot
.76 .41364 Mdot
.76 .41377 Mdot
.76 .41399 Mdot
.76 .41405 Mdot
.76 .41454 Mdot
.76 .41469 Mdot
.76 .41475 Mdot
.76 .41532 Mdot
.76 .41533 Mdot
.76 .41615 Mdot
.76 .41615 Mdot
.76 .41697 Mdot
.76 .41723 Mdot
.76 .41744 Mdot
.76 .41774 Mdot
.76 .41775 Mdot
.76 .41779 Mdot
.76 .41797 Mdot
.76 .41843 Mdot
.76 .41846 Mdot
.76 .41874 Mdot
.76 .41878 Mdot
.76 .41913 Mdot
.76 .41922 Mdot
.76 .41938 Mdot
.76 .41956 Mdot
.76 .41977 Mdot
.76 .41998 Mdot
.76 .42027 Mdot
.76 .42028 Mdot
.76 .42058 Mdot
.76 .42061 Mdot
.76 .42062 Mdot
.76 .4211 Mdot
.76 .42186 Mdot
.76 .42193 Mdot
.76 .42225 Mdot
.76 .42269 Mdot
.76 .42297 Mdot
.76 .42312 Mdot
.76 .42328 Mdot
.76 .42348 Mdot
.76 .42366 Mdot
.76 .42385 Mdot
.76 .42387 Mdot
.76 .42413 Mdot
.76 .42414 Mdot
.76 .42453 Mdot
.76 .42453 Mdot
.76 .42477 Mdot
.76 .42496 Mdot
.76 .42502 Mdot
.76 .42525 Mdot
.76 .4253 Mdot
.76 .42536 Mdot
.76 .42694 Mdot
.76 .42696 Mdot
.76 .42699 Mdot
.76 .42719 Mdot
.76 .42747 Mdot
.76 .42747 Mdot
.76 .42759 Mdot
.76 .42791 Mdot
.76 .42846 Mdot
.76 .42878 Mdot
.76 .42901 Mdot
.76 .42914 Mdot
.76 .42927 Mdot
.76 .42945 Mdot
.76 .42953 Mdot
.76 .42979 Mdot
.76 .42993 Mdot
.76 .43037 Mdot
.76 .43092 Mdot
.76 .43093 Mdot
.76 .43128 Mdot
.76 .43184 Mdot
.76 .43186 Mdot
.76 .43201 Mdot
.76 .43246 Mdot
.76 .43249 Mdot
.76 .43294 Mdot
.76 .43301 Mdot
.76 .43335 Mdot
.76 .4334 Mdot
.76 .43357 Mdot
.76 .43381 Mdot
.76 .43385 Mdot
.76 .43395 Mdot
.76 .43399 Mdot
.76 .43419 Mdot
.76 .43453 Mdot
.76 .43503 Mdot
.76 .43517 Mdot
.76 .43518 Mdot
.76 .43521 Mdot
.76 .43539 Mdot
.76 .4362 Mdot
.76 .43668 Mdot
.76 .43678 Mdot
.76 .43679 Mdot
.76 .43694 Mdot
.76 .43708 Mdot
.76 .4371 Mdot
.76 .43731 Mdot
.76 .43787 Mdot
.76 .4382 Mdot
.76 .43827 Mdot
.76 .4388 Mdot
.76 .43885 Mdot
.76 .43928 Mdot
.76 .43997 Mdot
.76 .44 Mdot
.76 .44 Mdot
.76 .44005 Mdot
.76 .44009 Mdot
.76 .44074 Mdot
.76 .44078 Mdot
.76 .44084 Mdot
.76 .44144 Mdot
.76 .44156 Mdot
.76 .44182 Mdot
.76 .44182 Mdot
.76 .44191 Mdot
.76 .44196 Mdot
.76 .44242 Mdot
.76 .44273 Mdot
.76 .44282 Mdot
.76 .44292 Mdot
.76 .44304 Mdot
.76 .4432 Mdot
.76 .4434 Mdot
.76 .44349 Mdot
.76 .4438 Mdot
.76 .44386 Mdot
.76 .4442 Mdot
.76 .4442 Mdot
.76 .4443 Mdot
.76 .44459 Mdot
.76 .44464 Mdot
.76 .44474 Mdot
.76 .44496 Mdot
.76 .44503 Mdot
.76 .44517 Mdot
.76 .44541 Mdot
.76 .44543 Mdot
.76 .44609 Mdot
.76 .44628 Mdot
.76 .44633 Mdot
.76 .44649 Mdot
.76 .4466 Mdot
.76 .44663 Mdot
.76 .44675 Mdot
.76 .4473 Mdot
.76 .44748 Mdot
.76 .44776 Mdot
.76 .4478 Mdot
.76 .44839 Mdot
.76 .44861 Mdot
.76 .44879 Mdot
.76 .4489 Mdot
.76 .44925 Mdot
.76 .44927 Mdot
.76 .45014 Mdot
.76 .45022 Mdot
.76 .45028 Mdot
.76 .4503 Mdot
.76 .45056 Mdot
.76 .45134 Mdot
.76 .45199 Mdot
.76 .45208 Mdot
.76 .45219 Mdot
.76 .4522 Mdot
.76 .45252 Mdot
.76 .45301 Mdot
.76 .45318 Mdot
.76 .45319 Mdot
.76 .45321 Mdot
.76 .45354 Mdot
.76 .45367 Mdot
.76 .45399 Mdot
.76 .45401 Mdot
.76 .45437 Mdot
.76 .45446 Mdot
.76 .45465 Mdot
.76 .4547 Mdot
.76 .45513 Mdot
.76 .45514 Mdot
.76 .45527 Mdot
.76 .4554 Mdot
.76 .45579 Mdot
.76 .45609 Mdot
.76 .45617 Mdot
.76 .45665 Mdot
.76 .45703 Mdot
.76 .45708 Mdot
.76 .45791 Mdot
.76 .45792 Mdot
.76 .45847 Mdot
.76 .45847 Mdot
.76 .45865 Mdot
.76 .45895 Mdot
.76 .459 Mdot
.76 .45941 Mdot
.76 .45946 Mdot
.76 .45955 Mdot
.76 .45969 Mdot
.76 .45973 Mdot
.76 .46 Mdot
.76 .46005 Mdot
.76 .46014 Mdot
.76 .46028 Mdot
.76 .46035 Mdot
.76 .46052 Mdot
.76 .46076 Mdot
.76 .46102 Mdot
.76 .46111 Mdot
.76 .46142 Mdot
.76 .46172 Mdot
.76 .46177 Mdot
.76 .46202 Mdot
.76 .46248 Mdot
.76 .4627 Mdot
.76 .4628 Mdot
.76 .46291 Mdot
.76 .46296 Mdot
.762 .22896 Mdot
.762 .22945 Mdot
.762 .22966 Mdot
.762 .22985 Mdot
.762 .23 Mdot
.762 .23037 Mdot
.762 .23074 Mdot
.762 .23078 Mdot
.762 .2308 Mdot
.762 .23131 Mdot
.762 .23161 Mdot
.762 .23176 Mdot
.762 .23209 Mdot
.762 .23246 Mdot
.762 .23366 Mdot
.762 .23442 Mdot
.762 .23461 Mdot
.762 .23479 Mdot
.762 .23513 Mdot
.762 .23524 Mdot
.762 .23534 Mdot
.762 .23579 Mdot
.762 .23598 Mdot
.762 .23636 Mdot
.762 .23646 Mdot
.762 .23707 Mdot
.762 .23757 Mdot
.762 .23765 Mdot
.762 .23766 Mdot
.762 .23818 Mdot
.762 .23886 Mdot
.762 .23941 Mdot
.762 .23944 Mdot
.762 .23965 Mdot
.762 .23973 Mdot
.762 .23976 Mdot
.762 .24066 Mdot
.762 .24099 Mdot
.762 .24145 Mdot
.762 .24192 Mdot
.762 .24202 Mdot
.762 .2421 Mdot
.762 .24244 Mdot
.762 .24256 Mdot
.762 .24275 Mdot
.762 .24279 Mdot
.762 .24337 Mdot
.762 .24364 Mdot
.762 .24387 Mdot
.762 .24426 Mdot
.762 .24446 Mdot
.762 .24491 Mdot
.762 .24531 Mdot
.762 .24542 Mdot
.762 .24579 Mdot
.762 .24601 Mdot
.762 .24604 Mdot
.762 .24622 Mdot
.762 .24625 Mdot
.762 .24668 Mdot
.762 .24674 Mdot
.762 .24705 Mdot
.762 .24766 Mdot
.762 .248 Mdot
.762 .24809 Mdot
.762 .24832 Mdot
.762 .24848 Mdot
.762 .24927 Mdot
.762 .24953 Mdot
.762 .25076 Mdot
.762 .25093 Mdot
.762 .25134 Mdot
.762 .25166 Mdot
.762 .25259 Mdot
.762 .25275 Mdot
.762 .25304 Mdot
.762 .25372 Mdot
.762 .254 Mdot
.762 .25455 Mdot
.762 .25551 Mdot
.762 .25553 Mdot
.762 .25586 Mdot
.762 .2561 Mdot
.762 .25632 Mdot
.762 .25702 Mdot
.762 .25713 Mdot
.762 .25844 Mdot
.762 .25855 Mdot
.762 .25864 Mdot
.762 .25875 Mdot
.762 .25924 Mdot
.762 .25928 Mdot
.762 .25965 Mdot
.762 .26121 Mdot
.762 .26139 Mdot
.762 .26164 Mdot
.762 .26207 Mdot
.762 .26225 Mdot
.762 .26228 Mdot
.762 .26244 Mdot
.762 .2625 Mdot
.762 .26281 Mdot
.762 .26285 Mdot
.762 .26312 Mdot
.762 .26333 Mdot
.762 .26338 Mdot
.762 .26351 Mdot
.762 .26367 Mdot
.762 .26371 Mdot
.762 .26373 Mdot
.762 .26375 Mdot
.762 .26452 Mdot
.762 .26624 Mdot
.762 .26633 Mdot
.762 .26658 Mdot
.762 .26675 Mdot
.762 .26685 Mdot
.762 .26758 Mdot
.762 .26762 Mdot
.762 .2678 Mdot
.762 .26785 Mdot
.762 .2684 Mdot
.762 .2688 Mdot
.762 .26925 Mdot
.762 .2697 Mdot
.762 .27013 Mdot
.762 .2707 Mdot
.762 .27119 Mdot
.762 .27149 Mdot
.762 .27172 Mdot
.762 .27175 Mdot
.762 .27225 Mdot
.762 .27235 Mdot
.762 .27246 Mdot
.762 .27277 Mdot
.762 .27278 Mdot
.762 .27317 Mdot
.762 .27318 Mdot
.762 .27347 Mdot
.762 .2737 Mdot
.762 .27376 Mdot
.762 .27451 Mdot
.762 .27496 Mdot
.762 .275 Mdot
.762 .27504 Mdot
.762 .27521 Mdot
.762 .27671 Mdot
.762 .27704 Mdot
.762 .27731 Mdot
.762 .27759 Mdot
.762 .27771 Mdot
.762 .27783 Mdot
.762 .27803 Mdot
.762 .27823 Mdot
.762 .27902 Mdot
.762 .27986 Mdot
.762 .28128 Mdot
.762 .28146 Mdot
.762 .28208 Mdot
.762 .28226 Mdot
.762 .28261 Mdot
.762 .2827 Mdot
.762 .28316 Mdot
.762 .2834 Mdot
.762 .28431 Mdot
.762 .28645 Mdot
.762 .28706 Mdot
.762 .28767 Mdot
.762 .28846 Mdot
.762 .28854 Mdot
.762 .28865 Mdot
.762 .28888 Mdot
.762 .28903 Mdot
.762 .28975 Mdot
.762 .28978 Mdot
.762 .29032 Mdot
.762 .29042 Mdot
.762 .29072 Mdot
.762 .29072 Mdot
.762 .2914 Mdot
.762 .29161 Mdot
.762 .29186 Mdot
.762 .29204 Mdot
.762 .29224 Mdot
.762 .29243 Mdot
.762 .29284 Mdot
.762 .29294 Mdot
.762 .29331 Mdot
.762 .29353 Mdot
.762 .29428 Mdot
.762 .29461 Mdot
.762 .29462 Mdot
.762 .29471 Mdot
.762 .29476 Mdot
.762 .29517 Mdot
.762 .29551 Mdot
.762 .29637 Mdot
.762 .29653 Mdot
.762 .29655 Mdot
.762 .29681 Mdot
.762 .2975 Mdot
.762 .298 Mdot
.762 .29814 Mdot
.762 .29857 Mdot
.762 .29892 Mdot
.762 .29922 Mdot
.762 .29941 Mdot
.762 .29981 Mdot
.762 .29995 Mdot
.762 .30118 Mdot
.762 .30153 Mdot
.762 .30179 Mdot
.762 .30193 Mdot
.762 .30214 Mdot
.762 .30224 Mdot
.762 .30272 Mdot
.762 .303 Mdot
.762 .30316 Mdot
.762 .30326 Mdot
.762 .30365 Mdot
.762 .30378 Mdot
.762 .30393 Mdot
.762 .3044 Mdot
.762 .30455 Mdot
.762 .30498 Mdot
.762 .30509 Mdot
.762 .30532 Mdot
.762 .30562 Mdot
.762 .30688 Mdot
.762 .30693 Mdot
.762 .30824 Mdot
.762 .30838 Mdot
.762 .30844 Mdot
.762 .30879 Mdot
.762 .3088 Mdot
.762 .3092 Mdot
.762 .30928 Mdot
.762 .30938 Mdot
.762 .30958 Mdot
.762 .31026 Mdot
.762 .31042 Mdot
.762 .31058 Mdot
.762 .31082 Mdot
.762 .31132 Mdot
.762 .31183 Mdot
.762 .31216 Mdot
.762 .31232 Mdot
.762 .31256 Mdot
.762 .31275 Mdot
.762 .31283 Mdot
.762 .31299 Mdot
.762 .31304 Mdot
.762 .3133 Mdot
.762 .31352 Mdot
.762 .31355 Mdot
.762 .31355 Mdot
.762 .31432 Mdot
.762 .31445 Mdot
.762 .31446 Mdot
.762 .31518 Mdot
.762 .31539 Mdot
.762 .31543 Mdot
.762 .31567 Mdot
.762 .31576 Mdot
.762 .31601 Mdot
.762 .31648 Mdot
.762 .31685 Mdot
.762 .3169 Mdot
.762 .31705 Mdot
.762 .31716 Mdot
.762 .31724 Mdot
.762 .31744 Mdot
.762 .31801 Mdot
.762 .31804 Mdot
.762 .31814 Mdot
.762 .31855 Mdot
.762 .31867 Mdot
.762 .3192 Mdot
.762 .31927 Mdot
.762 .32005 Mdot
.762 .32059 Mdot
.762 .32124 Mdot
.762 .32149 Mdot
.762 .32159 Mdot
.762 .32194 Mdot
.762 .3225 Mdot
.762 .32255 Mdot
.762 .32264 Mdot
.762 .32369 Mdot
.762 .32377 Mdot
.762 .32406 Mdot
.762 .32414 Mdot
.762 .32415 Mdot
.762 .32425 Mdot
.762 .32438 Mdot
.762 .3244 Mdot
.762 .32451 Mdot
.762 .3246 Mdot
.762 .32475 Mdot
.762 .32478 Mdot
.762 .3259 Mdot
.762 .326 Mdot
.762 .32612 Mdot
.762 .32643 Mdot
.762 .32653 Mdot
.762 .32679 Mdot
.762 .32812 Mdot
.762 .32822 Mdot
.762 .32823 Mdot
.762 .32845 Mdot
.762 .32849 Mdot
.762 .32854 Mdot
.762 .32884 Mdot
.762 .32885 Mdot
.762 .3291 Mdot
.762 .32942 Mdot
.762 .32963 Mdot
.762 .32972 Mdot
.762 .33062 Mdot
.762 .3308 Mdot
.762 .33102 Mdot
.762 .33136 Mdot
.762 .33241 Mdot
.762 .33268 Mdot
.762 .33275 Mdot
.762 .33291 Mdot
.762 .33315 Mdot
.762 .33325 Mdot
.762 .33364 Mdot
.762 .33456 Mdot
.762 .33482 Mdot
.762 .33542 Mdot
.762 .33546 Mdot
.762 .33551 Mdot
.762 .33561 Mdot
.762 .33567 Mdot
.762 .33598 Mdot
.762 .33627 Mdot
.762 .3364 Mdot
.762 .3364 Mdot
.762 .33689 Mdot
.762 .33697 Mdot
.762 .33705 Mdot
.762 .33736 Mdot
.762 .33752 Mdot
.762 .33761 Mdot
.762 .33807 Mdot
.762 .33808 Mdot
.762 .33814 Mdot
.762 .33832 Mdot
.762 .33846 Mdot
.762 .33883 Mdot
.762 .3389 Mdot
.762 .33891 Mdot
.762 .33902 Mdot
.762 .33932 Mdot
.762 .3396 Mdot
.762 .33978 Mdot
.762 .33993 Mdot
.762 .34006 Mdot
.762 .34014 Mdot
.762 .34031 Mdot
.762 .3409 Mdot
.762 .34105 Mdot
.762 .34123 Mdot
.762 .34132 Mdot
.762 .34176 Mdot
.762 .34196 Mdot
.762 .34202 Mdot
.762 .34229 Mdot
.762 .34254 Mdot
.762 .34258 Mdot
.762 .34281 Mdot
.762 .34336 Mdot
.762 .34338 Mdot
.762 .34394 Mdot
.762 .344 Mdot
.762 .34403 Mdot
.762 .34418 Mdot
.762 .34452 Mdot
.762 .34481 Mdot
.762 .34495 Mdot
.762 .34505 Mdot
.762 .34527 Mdot
.762 .34549 Mdot
.762 .3458 Mdot
.762 .34588 Mdot
.762 .34599 Mdot
.762 .34601 Mdot
.762 .34612 Mdot
.762 .34623 Mdot
.762 .34656 Mdot
.762 .34702 Mdot
.762 .34718 Mdot
.762 .34729 Mdot
.762 .34749 Mdot
.762 .34774 Mdot
.762 .34778 Mdot
.762 .34782 Mdot
.762 .34815 Mdot
.762 .34816 Mdot
.762 .34838 Mdot
.762 .34843 Mdot
.762 .34866 Mdot
.762 .34903 Mdot
.762 .34954 Mdot
.762 .34965 Mdot
.762 .34984 Mdot
.762 .35008 Mdot
.762 .3501 Mdot
.762 .35063 Mdot
.762 .35075 Mdot
.762 .35079 Mdot
.762 .35079 Mdot
.762 .35084 Mdot
.762 .35089 Mdot
.762 .3509 Mdot
.762 .35095 Mdot
.762 .35105 Mdot
.762 .35106 Mdot
.762 .35164 Mdot
.762 .35193 Mdot
.762 .3525 Mdot
.762 .35255 Mdot
.762 .35266 Mdot
.762 .35268 Mdot
.762 .35281 Mdot
.762 .35292 Mdot
.762 .35319 Mdot
.762 .35358 Mdot
.762 .35365 Mdot
.762 .35375 Mdot
.762 .3539 Mdot
.762 .35435 Mdot
.762 .35446 Mdot
.762 .35448 Mdot
.762 .3545 Mdot
.762 .35456 Mdot
.762 .35467 Mdot
.762 .35471 Mdot
.762 .35527 Mdot
.762 .35539 Mdot
.762 .35575 Mdot
.762 .35607 Mdot
.762 .35631 Mdot
.762 .35635 Mdot
.762 .35648 Mdot
.762 .35679 Mdot
.762 .35679 Mdot
.762 .35682 Mdot
.762 .35714 Mdot
.762 .35719 Mdot
.762 .35744 Mdot
.762 .35752 Mdot
.762 .35759 Mdot
.762 .35764 Mdot
.762 .35768 Mdot
.762 .35807 Mdot
.762 .35837 Mdot
.762 .35849 Mdot
.762 .35871 Mdot
.762 .35906 Mdot
.762 .35942 Mdot
.762 .35956 Mdot
.762 .35979 Mdot
.762 .3602 Mdot
.762 .36025 Mdot
.762 .3603 Mdot
.762 .36071 Mdot
.762 .36097 Mdot
.762 .36098 Mdot
.762 .36112 Mdot
.762 .36113 Mdot
.762 .36125 Mdot
.762 .36134 Mdot
.762 .3615 Mdot
.762 .36177 Mdot
.762 .36196 Mdot
.762 .36225 Mdot
.762 .36228 Mdot
.762 .36231 Mdot
.762 .36231 Mdot
.762 .36238 Mdot
.762 .36302 Mdot
.762 .36313 Mdot
.762 .36318 Mdot
.762 .3635 Mdot
.762 .3636 Mdot
.762 .36393 Mdot
.762 .36395 Mdot
.762 .36424 Mdot
.762 .3644 Mdot
.762 .36453 Mdot
.762 .36466 Mdot
.762 .36471 Mdot
.762 .36485 Mdot
.762 .36486 Mdot
.762 .36513 Mdot
.762 .36519 Mdot
.762 .36553 Mdot
.762 .36558 Mdot
.762 .36598 Mdot
.762 .36614 Mdot
.762 .36632 Mdot
.762 .36653 Mdot
.762 .36671 Mdot
.762 .36688 Mdot
.762 .36721 Mdot
.762 .36722 Mdot
.762 .36725 Mdot
.762 .36753 Mdot
.762 .36758 Mdot
.762 .36792 Mdot
.762 .36812 Mdot
.762 .36823 Mdot
.762 .36826 Mdot
.762 .36832 Mdot
.762 .36844 Mdot
.762 .3688 Mdot
.762 .36904 Mdot
.762 .36912 Mdot
.762 .36934 Mdot
.762 .36964 Mdot
.762 .36972 Mdot
.762 .36978 Mdot
.762 .37015 Mdot
.762 .37025 Mdot
.762 .37038 Mdot
.762 .37044 Mdot
.762 .3706 Mdot
.762 .37072 Mdot
.762 .37079 Mdot
.762 .37087 Mdot
.762 .37098 Mdot
.762 .37103 Mdot
.762 .37116 Mdot
.762 .37126 Mdot
.762 .37145 Mdot
.762 .37169 Mdot
.762 .37179 Mdot
.762 .37199 Mdot
.762 .37213 Mdot
.762 .37218 Mdot
.762 .37258 Mdot
.762 .3727 Mdot
.762 .37278 Mdot
.762 .37292 Mdot
.762 .37337 Mdot
.762 .37371 Mdot
.762 .37383 Mdot
.762 .37419 Mdot
.762 .37445 Mdot
.762 .37471 Mdot
.762 .37475 Mdot
.762 .37493 Mdot
.762 .37502 Mdot
.762 .37506 Mdot
.762 .37523 Mdot
.762 .37533 Mdot
.762 .37553 Mdot
.762 .37582 Mdot
.762 .37606 Mdot
.762 .37613 Mdot
.762 .37655 Mdot
.762 .3766 Mdot
.762 .37662 Mdot
.762 .37713 Mdot
.762 .37723 Mdot
.762 .37737 Mdot
.762 .37748 Mdot
.762 .37765 Mdot
.762 .37792 Mdot
.762 .37798 Mdot
.762 .37825 Mdot
.762 .3785 Mdot
.762 .37896 Mdot
.762 .37911 Mdot
.762 .37918 Mdot
.762 .37938 Mdot
.762 .3797 Mdot
.762 .37979 Mdot
.762 .3802 Mdot
.762 .38022 Mdot
.762 .38022 Mdot
.762 .38042 Mdot
.762 .38051 Mdot
.762 .38069 Mdot
.762 .3809 Mdot
.762 .38114 Mdot
.762 .38158 Mdot
.762 .38161 Mdot
.762 .38168 Mdot
.762 .38172 Mdot
.762 .38212 Mdot
.762 .38221 Mdot
.762 .38228 Mdot
.762 .38258 Mdot
.762 .38276 Mdot
.762 .38283 Mdot
.762 .38292 Mdot
.762 .383 Mdot
.762 .38398 Mdot
.762 .38398 Mdot
.762 .38408 Mdot
.762 .38409 Mdot
.762 .38413 Mdot
.762 .38416 Mdot
.762 .38418 Mdot
.762 .38462 Mdot
.762 .38491 Mdot
.762 .38531 Mdot
.762 .38555 Mdot
.762 .3857 Mdot
.762 .38588 Mdot
.762 .38589 Mdot
.762 .38611 Mdot
.762 .38613 Mdot
.762 .38616 Mdot
.762 .38632 Mdot
.762 .38645 Mdot
.762 .38652 Mdot
.762 .38663 Mdot
.762 .38715 Mdot
.762 .38722 Mdot
.762 .38729 Mdot
.762 .38738 Mdot
.762 .38743 Mdot
.762 .38792 Mdot
.762 .38799 Mdot
.762 .38827 Mdot
.762 .38849 Mdot
.762 .38903 Mdot
.762 .38957 Mdot
.762 .38991 Mdot
.762 .39008 Mdot
.762 .39037 Mdot
.762 .39054 Mdot
.762 .39064 Mdot
.762 .39103 Mdot
.762 .39114 Mdot
.762 .3912 Mdot
.762 .39128 Mdot
.762 .39138 Mdot
.762 .3915 Mdot
.762 .39168 Mdot
.762 .39188 Mdot
.762 .39195 Mdot
.762 .39196 Mdot
.762 .392 Mdot
.762 .39224 Mdot
.762 .39234 Mdot
.762 .39246 Mdot
.762 .3925 Mdot
.762 .3925 Mdot
.762 .3928 Mdot
.762 .39287 Mdot
.762 .39297 Mdot
.762 .39317 Mdot
.762 .39323 Mdot
.762 .39328 Mdot
.762 .3936 Mdot
.762 .3936 Mdot
.762 .39368 Mdot
.762 .39387 Mdot
.762 .39408 Mdot
.762 .39412 Mdot
.762 .39419 Mdot
.762 .39421 Mdot
.762 .39424 Mdot
.762 .39463 Mdot
.762 .39481 Mdot
.762 .39541 Mdot
.762 .39567 Mdot
.762 .39573 Mdot
.762 .39589 Mdot
.762 .39599 Mdot
.762 .39601 Mdot
.762 .39604 Mdot
.762 .39621 Mdot
.762 .3969 Mdot
.762 .39713 Mdot
.762 .39728 Mdot
.762 .39739 Mdot
.762 .39798 Mdot
.762 .39804 Mdot
.762 .39818 Mdot
.762 .39839 Mdot
.762 .39855 Mdot
.762 .39856 Mdot
.762 .39876 Mdot
.762 .39879 Mdot
.762 .39882 Mdot
.762 .39896 Mdot
.762 .39897 Mdot
.762 .39903 Mdot
.762 .3999 Mdot
.762 .40007 Mdot
.762 .40014 Mdot
.762 .40034 Mdot
.762 .40042 Mdot
.762 .40049 Mdot
.762 .40122 Mdot
.762 .40124 Mdot
.762 .40134 Mdot
.762 .4014 Mdot
.762 .40147 Mdot
.762 .40149 Mdot
.762 .40157 Mdot
.762 .40163 Mdot
.762 .40164 Mdot
.762 .40169 Mdot
.762 .40189 Mdot
.762 .40194 Mdot
.762 .40263 Mdot
.762 .40269 Mdot
.762 .40272 Mdot
.762 .40309 Mdot
.762 .40332 Mdot
.762 .40338 Mdot
.762 .40355 Mdot
.762 .40397 Mdot
.762 .40433 Mdot
.762 .40484 Mdot
.762 .40489 Mdot
.762 .40524 Mdot
.762 .40531 Mdot
.762 .40558 Mdot
.762 .40564 Mdot
.762 .40567 Mdot
.762 .40604 Mdot
.762 .40617 Mdot
.762 .40622 Mdot
.762 .40629 Mdot
.762 .4064 Mdot
.762 .40643 Mdot
.762 .40667 Mdot
.762 .40698 Mdot
.762 .40714 Mdot
.762 .4072 Mdot
.762 .40736 Mdot
.762 .40738 Mdot
.762 .40752 Mdot
.762 .408 Mdot
.762 .408 Mdot
.762 .40809 Mdot
.762 .40859 Mdot
.762 .40859 Mdot
.762 .40861 Mdot
.762 .40876 Mdot
.762 .40893 Mdot
.762 .40896 Mdot
.762 .40906 Mdot
.762 .40912 Mdot
.762 .40924 Mdot
.762 .4094 Mdot
.762 .40951 Mdot
.762 .40972 Mdot
.762 .41006 Mdot
.762 .41038 Mdot
.762 .41054 Mdot
.762 .41065 Mdot
.762 .41075 Mdot
.762 .41119 Mdot
.762 .41133 Mdot
.762 .41139 Mdot
.762 .41145 Mdot
.762 .41171 Mdot
.762 .41171 Mdot
.762 .41194 Mdot
.762 .41198 Mdot
.762 .41208 Mdot
.762 .41294 Mdot
.762 .41297 Mdot
.762 .4138 Mdot
.762 .41399 Mdot
.762 .41414 Mdot
.762 .41421 Mdot
.762 .4145 Mdot
.762 .41459 Mdot
.762 .41491 Mdot
.762 .415 Mdot
.762 .41509 Mdot
.762 .41534 Mdot
.762 .41541 Mdot
.762 .41551 Mdot
.762 .4157 Mdot
.762 .41601 Mdot
.762 .41608 Mdot
.762 .41622 Mdot
.762 .41631 Mdot
.762 .41648 Mdot
.762 .41671 Mdot
.762 .41752 Mdot
.762 .41761 Mdot
.762 .41787 Mdot
.762 .418 Mdot
.762 .41819 Mdot
.762 .41842 Mdot
.762 .4187 Mdot
.762 .41879 Mdot
.762 .41912 Mdot
.762 .41958 Mdot
.762 .41975 Mdot
.762 .41976 Mdot
.762 .41986 Mdot
.762 .42043 Mdot
.762 .42065 Mdot
.762 .42092 Mdot
.762 .42095 Mdot
.762 .42101 Mdot
.762 .42102 Mdot
.762 .42124 Mdot
.762 .42173 Mdot
.762 .42187 Mdot
.762 .42211 Mdot
.762 .42218 Mdot
.762 .42245 Mdot
.762 .42258 Mdot
.762 .4227 Mdot
.762 .42283 Mdot
.762 .42299 Mdot
.762 .42312 Mdot
.762 .42357 Mdot
.762 .42357 Mdot
.762 .42377 Mdot
.762 .42383 Mdot
.762 .42419 Mdot
.762 .42421 Mdot
.762 .42468 Mdot
.762 .42478 Mdot
.762 .42493 Mdot
.762 .425 Mdot
.762 .42506 Mdot
.762 .42557 Mdot
.762 .42597 Mdot
.762 .42638 Mdot
.762 .42778 Mdot
.762 .42838 Mdot
.762 .42853 Mdot
.762 .42883 Mdot
.762 .42889 Mdot
.762 .42913 Mdot
.762 .42924 Mdot
.762 .42965 Mdot
.762 .42977 Mdot
.762 .4307 Mdot
.762 .43125 Mdot
.762 .43177 Mdot
.762 .4319 Mdot
.762 .43203 Mdot
.762 .43211 Mdot
.762 .43219 Mdot
.762 .43237 Mdot
.762 .43255 Mdot
.762 .43277 Mdot
.762 .43375 Mdot
.762 .43386 Mdot
.762 .43389 Mdot
.762 .43391 Mdot
.762 .43421 Mdot
.762 .4347 Mdot
.762 .43474 Mdot
.762 .43489 Mdot
.762 .43508 Mdot
.762 .43509 Mdot
.762 .43534 Mdot
.762 .43535 Mdot
.762 .43555 Mdot
.762 .43562 Mdot
.762 .43569 Mdot
.762 .43602 Mdot
.762 .43604 Mdot
.762 .43619 Mdot
.762 .43639 Mdot
.762 .43671 Mdot
.762 .43708 Mdot
.762 .43736 Mdot
.762 .43766 Mdot
.762 .43796 Mdot
.762 .43821 Mdot
.762 .43858 Mdot
.762 .43861 Mdot
.762 .43873 Mdot
.762 .43876 Mdot
.762 .43924 Mdot
.762 .4393 Mdot
.762 .43941 Mdot
.762 .43958 Mdot
.762 .43963 Mdot
.762 .44077 Mdot
.762 .44127 Mdot
.762 .44128 Mdot
.762 .44129 Mdot
.762 .44132 Mdot
.762 .44143 Mdot
.762 .44151 Mdot
.762 .44155 Mdot
.762 .44169 Mdot
.762 .44186 Mdot
.762 .44189 Mdot
.762 .44209 Mdot
.762 .44213 Mdot
.762 .44223 Mdot
.762 .44226 Mdot
.762 .44237 Mdot
.762 .44265 Mdot
.762 .44282 Mdot
.762 .44294 Mdot
.762 .44396 Mdot
.762 .4442 Mdot
.762 .44423 Mdot
.762 .44455 Mdot
.762 .44462 Mdot
.762 .44468 Mdot
.762 .44475 Mdot
.762 .44561 Mdot
.762 .44569 Mdot
.762 .44615 Mdot
.762 .44629 Mdot
.762 .44645 Mdot
.762 .44666 Mdot
.762 .44668 Mdot
.762 .44731 Mdot
.762 .44767 Mdot
.762 .44785 Mdot
.762 .4483 Mdot
.762 .44849 Mdot
.762 .44859 Mdot
.762 .4492 Mdot
.762 .44941 Mdot
.762 .44968 Mdot
.762 .44979 Mdot
.762 .4506 Mdot
.762 .45077 Mdot
.762 .45129 Mdot
.762 .4514 Mdot
.762 .45155 Mdot
.762 .4516 Mdot
.762 .45183 Mdot
.762 .45222 Mdot
.762 .45243 Mdot
.762 .45247 Mdot
.762 .45275 Mdot
.762 .45277 Mdot
.762 .45289 Mdot
.762 .45291 Mdot
.762 .45305 Mdot
.762 .45329 Mdot
.762 .45337 Mdot
.762 .45363 Mdot
.762 .45393 Mdot
.762 .45406 Mdot
.762 .45431 Mdot
.762 .45446 Mdot
.762 .45464 Mdot
.762 .45502 Mdot
.762 .45505 Mdot
.762 .45517 Mdot
.762 .45525 Mdot
.762 .45548 Mdot
.762 .45553 Mdot
.762 .45559 Mdot
.762 .4559 Mdot
.762 .4562 Mdot
.762 .45642 Mdot
.762 .45701 Mdot
.762 .45703 Mdot
.762 .45708 Mdot
.762 .45722 Mdot
.762 .45724 Mdot
.762 .4576 Mdot
.762 .45805 Mdot
.762 .45839 Mdot
.762 .4584 Mdot
.762 .45845 Mdot
.762 .45878 Mdot
.762 .45917 Mdot
.762 .45924 Mdot
.762 .45949 Mdot
.762 .45961 Mdot
.762 .45991 Mdot
.762 .45998 Mdot
.762 .46005 Mdot
.762 .46027 Mdot
.762 .46039 Mdot
.762 .46052 Mdot
.762 .46102 Mdot
.762 .4618 Mdot
.762 .46205 Mdot
.762 .46226 Mdot
.762 .46236 Mdot
.762 .46255 Mdot
.762 .46289 Mdot
.762 .4629 Mdot
.762 .46293 Mdot
.762 .46317 Mdot
.762 .46341 Mdot
.762 .46351 Mdot
.762 .46364 Mdot
.762 .46378 Mdot
.762 .4641 Mdot
.764 .22757 Mdot
.764 .22757 Mdot
.764 .22768 Mdot
.764 .22788 Mdot
.764 .2283 Mdot
.764 .22912 Mdot
.764 .22924 Mdot
.764 .22934 Mdot
.764 .22949 Mdot
.764 .22951 Mdot
.764 .22952 Mdot
.764 .22955 Mdot
.764 .22991 Mdot
.764 .23102 Mdot
.764 .23124 Mdot
.764 .23165 Mdot
.764 .23208 Mdot
.764 .23211 Mdot
.764 .23244 Mdot
.764 .23246 Mdot
.764 .2325 Mdot
.764 .23258 Mdot
.764 .23438 Mdot
.764 .23443 Mdot
.764 .23467 Mdot
.764 .23469 Mdot
.764 .23487 Mdot
.764 .23502 Mdot
.764 .23502 Mdot
.764 .23616 Mdot
.764 .23642 Mdot
.764 .23647 Mdot
.764 .23662 Mdot
.764 .23757 Mdot
.764 .23765 Mdot
.764 .23799 Mdot
.764 .23805 Mdot
.764 .2382 Mdot
.764 .23823 Mdot
.764 .23828 Mdot
.764 .23837 Mdot
.764 .2385 Mdot
.764 .23877 Mdot
.764 .239 Mdot
.764 .23906 Mdot
.764 .2393 Mdot
.764 .23964 Mdot
.764 .2398 Mdot
.764 .24059 Mdot
.764 .24068 Mdot
.764 .24095 Mdot
.764 .24095 Mdot
.764 .24115 Mdot
.764 .24121 Mdot
.764 .24128 Mdot
.764 .24148 Mdot
.764 .24158 Mdot
.764 .2418 Mdot
.764 .24211 Mdot
.764 .24229 Mdot
.764 .24257 Mdot
.764 .24269 Mdot
.764 .24282 Mdot
.764 .24472 Mdot
.764 .24473 Mdot
.764 .24482 Mdot
.764 .2459 Mdot
.764 .24668 Mdot
.764 .2468 Mdot
.764 .24781 Mdot
.764 .24809 Mdot
.764 .24842 Mdot
.764 .24898 Mdot
.764 .24906 Mdot
.764 .25026 Mdot
.764 .25069 Mdot
.764 .25093 Mdot
.764 .25123 Mdot
.764 .25127 Mdot
.764 .25186 Mdot
.764 .25192 Mdot
.764 .25196 Mdot
.764 .2521 Mdot
.764 .25337 Mdot
.764 .25362 Mdot
.764 .25442 Mdot
.764 .2545 Mdot
.764 .2545 Mdot
.764 .25513 Mdot
.764 .25519 Mdot
.764 .25587 Mdot
.764 .25628 Mdot
.764 .25716 Mdot
.764 .25735 Mdot
.764 .25752 Mdot
.764 .25756 Mdot
.764 .2576 Mdot
.764 .2577 Mdot
.764 .25787 Mdot
.764 .25867 Mdot
.764 .2592 Mdot
.764 .25922 Mdot
.764 .25955 Mdot
.764 .25975 Mdot
.764 .26028 Mdot
.764 .26126 Mdot
.764 .26157 Mdot
.764 .2622 Mdot
.764 .26247 Mdot
.764 .26251 Mdot
.764 .26302 Mdot
.764 .26319 Mdot
.764 .26326 Mdot
.764 .26402 Mdot
.764 .26408 Mdot
.764 .2647 Mdot
.764 .26549 Mdot
.764 .26572 Mdot
.764 .26591 Mdot
.764 .26635 Mdot
.764 .26664 Mdot
.764 .26687 Mdot
.764 .26705 Mdot
.764 .26713 Mdot
.764 .2672 Mdot
.764 .26742 Mdot
.764 .2675 Mdot
.764 .26795 Mdot
.764 .2689 Mdot
.764 .26895 Mdot
.764 .26995 Mdot
.764 .27 Mdot
.764 .27175 Mdot
.764 .27184 Mdot
.764 .27195 Mdot
.764 .272 Mdot
.764 .2723 Mdot
.764 .2726 Mdot
.764 .27371 Mdot
.764 .2741 Mdot
.764 .2741 Mdot
.764 .27415 Mdot
.764 .27432 Mdot
.764 .2744 Mdot
.764 .27451 Mdot
.764 .27517 Mdot
.764 .27539 Mdot
.764 .2758 Mdot
.764 .27583 Mdot
.764 .27586 Mdot
.764 .27645 Mdot
.764 .2766 Mdot
.764 .27671 Mdot
.764 .27764 Mdot
.764 .27786 Mdot
.764 .27878 Mdot
.764 .27996 Mdot
.764 .28002 Mdot
.764 .28073 Mdot
.764 .28085 Mdot
.764 .28104 Mdot
.764 .28149 Mdot
.764 .2817 Mdot
.764 .2818 Mdot
.764 .28227 Mdot
.764 .28368 Mdot
.764 .2841 Mdot
.764 .28439 Mdot
.764 .28444 Mdot
.764 .28642 Mdot
.764 .28655 Mdot
.764 .28675 Mdot
.764 .28718 Mdot
.764 .28721 Mdot
.764 .28772 Mdot
.764 .2882 Mdot
.764 .2886 Mdot
.764 .28897 Mdot
.764 .28899 Mdot
.764 .28917 Mdot
.764 .28959 Mdot
.764 .28963 Mdot
.764 .28972 Mdot
.764 .28989 Mdot
.764 .29036 Mdot
.764 .29064 Mdot
.764 .29148 Mdot
.764 .2915 Mdot
.764 .29258 Mdot
.764 .29268 Mdot
.764 .29282 Mdot
.764 .29292 Mdot
.764 .29331 Mdot
.764 .29375 Mdot
.764 .29401 Mdot
.764 .29436 Mdot
.764 .29439 Mdot
.764 .29482 Mdot
.764 .29509 Mdot
.764 .29564 Mdot
.764 .2961 Mdot
.764 .29675 Mdot
.764 .29689 Mdot
.764 .29782 Mdot
.764 .29811 Mdot
.764 .29812 Mdot
.764 .29815 Mdot
.764 .29849 Mdot
.764 .2992 Mdot
.764 .29952 Mdot
.764 .29964 Mdot
.764 .30072 Mdot
.764 .30086 Mdot
.764 .30098 Mdot
.764 .3018 Mdot
.764 .30226 Mdot
.764 .3023 Mdot
.764 .30317 Mdot
.764 .30365 Mdot
.764 .30378 Mdot
.764 .30403 Mdot
.764 .30407 Mdot
.764 .30441 Mdot
.764 .30448 Mdot
.764 .30473 Mdot
.764 .30485 Mdot
.764 .30497 Mdot
.764 .30502 Mdot
.764 .30506 Mdot
.764 .30509 Mdot
.764 .30516 Mdot
.764 .30586 Mdot
.764 .30597 Mdot
.764 .30646 Mdot
.764 .30646 Mdot
.764 .30652 Mdot
.764 .3066 Mdot
.764 .30661 Mdot
.764 .30755 Mdot
.764 .30757 Mdot
.764 .30771 Mdot
.764 .30772 Mdot
.764 .30808 Mdot
.764 .30882 Mdot
.764 .30889 Mdot
.764 .3096 Mdot
.764 .30965 Mdot
.764 .30965 Mdot
.764 .30987 Mdot
.764 .31006 Mdot
.764 .31041 Mdot
.764 .31046 Mdot
.764 .31057 Mdot
.764 .31057 Mdot
.764 .31059 Mdot
.764 .31075 Mdot
.764 .31122 Mdot
.764 .31149 Mdot
.764 .31185 Mdot
.764 .31189 Mdot
.764 .31266 Mdot
.764 .31268 Mdot
.764 .31355 Mdot
.764 .31362 Mdot
.764 .31402 Mdot
.764 .31406 Mdot
.764 .31421 Mdot
.764 .31431 Mdot
.764 .31464 Mdot
.764 .31477 Mdot
.764 .31547 Mdot
.764 .31548 Mdot
.764 .31556 Mdot
.764 .31559 Mdot
.764 .3157 Mdot
.764 .31584 Mdot
.764 .31597 Mdot
.764 .31605 Mdot
.764 .31617 Mdot
.764 .31628 Mdot
.764 .31709 Mdot
.764 .31793 Mdot
.764 .31798 Mdot
.764 .31891 Mdot
.764 .31895 Mdot
.764 .31946 Mdot
.764 .31964 Mdot
.764 .3199 Mdot
.764 .32015 Mdot
.764 .32017 Mdot
.764 .32025 Mdot
.764 .32079 Mdot
.764 .32155 Mdot
.764 .32186 Mdot
.764 .32204 Mdot
.764 .32242 Mdot
.764 .32257 Mdot
.764 .32259 Mdot
.764 .3226 Mdot
.764 .32272 Mdot
.764 .32306 Mdot
.764 .3233 Mdot
.764 .32344 Mdot
.764 .32353 Mdot
.764 .32417 Mdot
.764 .32469 Mdot
.764 .32471 Mdot
.764 .32493 Mdot
.764 .32536 Mdot
.764 .32598 Mdot
.764 .32616 Mdot
.764 .32635 Mdot
.764 .32665 Mdot
.764 .32669 Mdot
.764 .32684 Mdot
.764 .32704 Mdot
.764 .32744 Mdot
.764 .32747 Mdot
.764 .32799 Mdot
.764 .32867 Mdot
.764 .32871 Mdot
.764 .32877 Mdot
.764 .3289 Mdot
.764 .32967 Mdot
.764 .32969 Mdot
.764 .32985 Mdot
.764 .33013 Mdot
.764 .33042 Mdot
.764 .33068 Mdot
.764 .33074 Mdot
.764 .33128 Mdot
.764 .33251 Mdot
.764 .33256 Mdot
.764 .33293 Mdot
.764 .33317 Mdot
.764 .33378 Mdot
.764 .33396 Mdot
.764 .33408 Mdot
.764 .3341 Mdot
.764 .33509 Mdot
.764 .33528 Mdot
.764 .3355 Mdot
.764 .33588 Mdot
.764 .33604 Mdot
.764 .33605 Mdot
.764 .33613 Mdot
.764 .33631 Mdot
.764 .33632 Mdot
.764 .33636 Mdot
.764 .33644 Mdot
.764 .33664 Mdot
.764 .33676 Mdot
.764 .33712 Mdot
.764 .33763 Mdot
.764 .33773 Mdot
.764 .33809 Mdot
.764 .3382 Mdot
.764 .33836 Mdot
.764 .3389 Mdot
.764 .3391 Mdot
.764 .33983 Mdot
.764 .33996 Mdot
.764 .33996 Mdot
.764 .33997 Mdot
.764 .34012 Mdot
.764 .34042 Mdot
.764 .34056 Mdot
.764 .34107 Mdot
.764 .34113 Mdot
.764 .34119 Mdot
.764 .34173 Mdot
.764 .34212 Mdot
.764 .34233 Mdot
.764 .34238 Mdot
.764 .34249 Mdot
.764 .34251 Mdot
.764 .34266 Mdot
.764 .34284 Mdot
.764 .34289 Mdot
.764 .34292 Mdot
.764 .34293 Mdot
.764 .34298 Mdot
.764 .34328 Mdot
.764 .34332 Mdot
.764 .34353 Mdot
.764 .34359 Mdot
.764 .34401 Mdot
.764 .34407 Mdot
.764 .34407 Mdot
.764 .34454 Mdot
.764 .34457 Mdot
.764 .3449 Mdot
.764 .3449 Mdot
.764 .34522 Mdot
.764 .3453 Mdot
.764 .34537 Mdot
.764 .34557 Mdot
.764 .34584 Mdot
.764 .34586 Mdot
.764 .34619 Mdot
.764 .3462 Mdot
.764 .34657 Mdot
.764 .3466 Mdot
.764 .34677 Mdot
.764 .34685 Mdot
.764 .34689 Mdot
.764 .34704 Mdot
.764 .34739 Mdot
.764 .34743 Mdot
.764 .34749 Mdot
.764 .34761 Mdot
.764 .34769 Mdot
.764 .34774 Mdot
.764 .34809 Mdot
.764 .34844 Mdot
.764 .34847 Mdot
.764 .34887 Mdot
.764 .34888 Mdot
.764 .3491 Mdot
.764 .34918 Mdot
.764 .34929 Mdot
.764 .3494 Mdot
.764 .34967 Mdot
.764 .34999 Mdot
.764 .35013 Mdot
.764 .35021 Mdot
.764 .35037 Mdot
.764 .35043 Mdot
.764 .35045 Mdot
.764 .35064 Mdot
.764 .35075 Mdot
.764 .35081 Mdot
.764 .35084 Mdot
.764 .35112 Mdot
.764 .35134 Mdot
.764 .35135 Mdot
.764 .35163 Mdot
.764 .35205 Mdot
.764 .35218 Mdot
.764 .35253 Mdot
.764 .35306 Mdot
.764 .35309 Mdot
.764 .35314 Mdot
.764 .35347 Mdot
.764 .35355 Mdot
.764 .35379 Mdot
.764 .35393 Mdot
.764 .35416 Mdot
.764 .35471 Mdot
.764 .35487 Mdot
.764 .35523 Mdot
.764 .35536 Mdot
.764 .35579 Mdot
.764 .35587 Mdot
.764 .35597 Mdot
.764 .35621 Mdot
.764 .35624 Mdot
.764 .35632 Mdot
.764 .35632 Mdot
.764 .35634 Mdot
.764 .35646 Mdot
.764 .35651 Mdot
.764 .35666 Mdot
.764 .35708 Mdot
.764 .35713 Mdot
.764 .35743 Mdot
.764 .35751 Mdot
.764 .35789 Mdot
.764 .35838 Mdot
.764 .35841 Mdot
.764 .35864 Mdot
.764 .35881 Mdot
.764 .35892 Mdot
.764 .35897 Mdot
.764 .3593 Mdot
.764 .35932 Mdot
.764 .35944 Mdot
.764 .35961 Mdot
.764 .35964 Mdot
.764 .35986 Mdot
.764 .36 Mdot
.764 .36 Mdot
.764 .3604 Mdot
.764 .36041 Mdot
.764 .36055 Mdot
.764 .36071 Mdot
.764 .3608 Mdot
.764 .36091 Mdot
.764 .36119 Mdot
.764 .36121 Mdot
.764 .36136 Mdot
.764 .36151 Mdot
.764 .3617 Mdot
.764 .36193 Mdot
.764 .36218 Mdot
.764 .36227 Mdot
.764 .36237 Mdot
.764 .36246 Mdot
.764 .3625 Mdot
.764 .36288 Mdot
.764 .36306 Mdot
.764 .36326 Mdot
.764 .36349 Mdot
.764 .36387 Mdot
.764 .36396 Mdot
.764 .36466 Mdot
.764 .36523 Mdot
.764 .36595 Mdot
.764 .366 Mdot
.764 .36616 Mdot
.764 .36617 Mdot
.764 .36622 Mdot
.764 .3663 Mdot
.764 .36631 Mdot
.764 .36646 Mdot
.764 .3667 Mdot
.764 .36697 Mdot
.764 .36711 Mdot
.764 .36796 Mdot
.764 .36901 Mdot
.764 .36903 Mdot
.764 .36916 Mdot
.764 .36923 Mdot
.764 .36933 Mdot
.764 .36945 Mdot
.764 .36951 Mdot
.764 .37032 Mdot
.764 .37051 Mdot
.764 .37054 Mdot
.764 .37089 Mdot
.764 .37097 Mdot
.764 .37116 Mdot
.764 .37124 Mdot
.764 .37128 Mdot
.764 .3713 Mdot
.764 .37131 Mdot
.764 .37132 Mdot
.764 .37135 Mdot
.764 .3714 Mdot
.764 .37153 Mdot
.764 .37181 Mdot
.764 .37183 Mdot
.764 .37195 Mdot
.764 .37248 Mdot
.764 .37252 Mdot
.764 .37266 Mdot
.764 .37279 Mdot
.764 .37281 Mdot
.764 .37405 Mdot
.764 .37414 Mdot
.764 .37432 Mdot
.764 .37448 Mdot
.764 .37458 Mdot
.764 .37463 Mdot
.764 .37478 Mdot
.764 .37481 Mdot
.764 .37528 Mdot
.764 .37565 Mdot
.764 .37611 Mdot
.764 .37618 Mdot
.764 .37642 Mdot
.764 .37707 Mdot
.764 .37716 Mdot
.764 .37722 Mdot
.764 .37745 Mdot
.764 .37771 Mdot
.764 .37793 Mdot
.764 .37834 Mdot
.764 .37871 Mdot
.764 .37894 Mdot
.764 .37896 Mdot
.764 .37908 Mdot
.764 .37915 Mdot
.764 .37916 Mdot
.764 .37938 Mdot
.764 .37941 Mdot
.764 .37949 Mdot
.764 .37976 Mdot
.764 .38059 Mdot
.764 .38099 Mdot
.764 .3811 Mdot
.764 .38111 Mdot
.764 .38146 Mdot
.764 .38206 Mdot
.764 .38217 Mdot
.764 .38253 Mdot
.764 .38268 Mdot
.764 .38319 Mdot
.764 .38325 Mdot
.764 .38359 Mdot
.764 .38382 Mdot
.764 .38391 Mdot
.764 .38419 Mdot
.764 .38476 Mdot
.764 .38483 Mdot
.764 .38497 Mdot
.764 .38512 Mdot
.764 .38517 Mdot
.764 .38525 Mdot
.764 .38547 Mdot
.764 .38564 Mdot
.764 .38572 Mdot
.764 .38579 Mdot
.764 .38584 Mdot
.764 .38598 Mdot
.764 .38599 Mdot
.764 .38625 Mdot
.764 .38627 Mdot
.764 .3865 Mdot
.764 .38673 Mdot
.764 .38676 Mdot
.764 .38719 Mdot
.764 .38736 Mdot
.764 .38748 Mdot
.764 .38749 Mdot
.764 .38774 Mdot
.764 .38796 Mdot
.764 .38797 Mdot
.764 .38828 Mdot
.764 .38833 Mdot
.764 .38859 Mdot
.764 .38859 Mdot
.764 .3888 Mdot
.764 .38882 Mdot
.764 .38913 Mdot
.764 .38913 Mdot
.764 .38917 Mdot
.764 .38944 Mdot
.764 .38962 Mdot
.764 .38965 Mdot
.764 .38993 Mdot
.764 .39016 Mdot
.764 .39024 Mdot
.764 .3904 Mdot
.764 .39066 Mdot
.764 .39102 Mdot
.764 .39105 Mdot
.764 .39143 Mdot
.764 .39181 Mdot
.764 .39191 Mdot
.764 .39239 Mdot
.764 .39252 Mdot
.764 .39287 Mdot
.764 .39297 Mdot
.764 .39305 Mdot
.764 .39328 Mdot
.764 .39335 Mdot
.764 .39368 Mdot
.764 .39392 Mdot
.764 .394 Mdot
.764 .39413 Mdot
.764 .39418 Mdot
.764 .3942 Mdot
.764 .39421 Mdot
.764 .39433 Mdot
.764 .39438 Mdot
.764 .39439 Mdot
.764 .39449 Mdot
.764 .39474 Mdot
.764 .39489 Mdot
.764 .39501 Mdot
.764 .39565 Mdot
.764 .39567 Mdot
.764 .39575 Mdot
.764 .39587 Mdot
.764 .39626 Mdot
.764 .39642 Mdot
.764 .39666 Mdot
.764 .3967 Mdot
.764 .3975 Mdot
.764 .39785 Mdot
.764 .3979 Mdot
.764 .39807 Mdot
.764 .39825 Mdot
.764 .39844 Mdot
.764 .39854 Mdot
.764 .39855 Mdot
.764 .39906 Mdot
.764 .39914 Mdot
.764 .39919 Mdot
.764 .39921 Mdot
.764 .39965 Mdot
.764 .4 Mdot
.764 .40001 Mdot
.764 .40028 Mdot
.764 .4004 Mdot
.764 .40051 Mdot
.764 .40053 Mdot
.764 .40073 Mdot
.764 .40085 Mdot
.764 .40097 Mdot
.764 .40138 Mdot
.764 .40166 Mdot
.764 .4018 Mdot
.764 .40181 Mdot
.764 .40215 Mdot
.764 .40258 Mdot
.764 .40263 Mdot
.764 .40272 Mdot
.764 .40288 Mdot
.764 .4031 Mdot
.764 .40318 Mdot
.764 .40319 Mdot
.764 .4032 Mdot
.764 .4033 Mdot
.764 .40355 Mdot
.764 .40367 Mdot
.764 .40387 Mdot
.764 .40436 Mdot
.764 .40472 Mdot
.764 .40477 Mdot
.764 .40479 Mdot
.764 .40495 Mdot
.764 .40512 Mdot
.764 .40524 Mdot
.764 .40557 Mdot
.764 .4056 Mdot
.764 .40621 Mdot
.764 .40624 Mdot
.764 .40679 Mdot
.764 .40732 Mdot
.764 .40739 Mdot
.764 .40747 Mdot
.764 .40752 Mdot
.764 .40761 Mdot
.764 .4077 Mdot
.764 .40777 Mdot
.764 .40779 Mdot
.764 .40785 Mdot
.764 .40785 Mdot
.764 .40831 Mdot
.764 .40839 Mdot
.764 .40861 Mdot
.764 .40868 Mdot
.764 .40877 Mdot
.764 .40879 Mdot
.764 .40906 Mdot
.764 .4091 Mdot
.764 .40967 Mdot
.764 .40969 Mdot
.764 .41019 Mdot
.764 .41021 Mdot
.764 .41045 Mdot
.764 .41063 Mdot
.764 .41094 Mdot
.764 .41104 Mdot
.764 .41105 Mdot
.764 .41106 Mdot
.764 .41113 Mdot
.764 .41116 Mdot
.764 .41139 Mdot
.764 .41151 Mdot
.764 .41166 Mdot
.764 .41166 Mdot
.764 .41169 Mdot
.764 .41215 Mdot
.764 .4122 Mdot
.764 .41269 Mdot
.764 .41292 Mdot
.764 .41293 Mdot
.764 .41302 Mdot
.764 .41303 Mdot
.764 .41365 Mdot
.764 .41365 Mdot
.764 .41371 Mdot
.764 .41375 Mdot
.764 .41375 Mdot
.764 .41407 Mdot
.764 .41414 Mdot
.764 .4146 Mdot
.764 .41464 Mdot
.764 .41466 Mdot
.764 .41468 Mdot
.764 .41472 Mdot
.764 .4148 Mdot
.764 .41488 Mdot
.764 .41504 Mdot
.764 .41509 Mdot
.764 .41531 Mdot
.764 .41533 Mdot
.764 .4155 Mdot
.764 .41558 Mdot
.764 .4159 Mdot
.764 .41647 Mdot
.764 .41649 Mdot
.764 .41679 Mdot
.764 .41733 Mdot
.764 .41741 Mdot
.764 .4175 Mdot
.764 .41821 Mdot
.764 .41829 Mdot
.764 .41849 Mdot
.764 .41896 Mdot
.764 .41919 Mdot
.764 .41921 Mdot
.764 .41921 Mdot
.764 .4194 Mdot
.764 .42001 Mdot
.764 .4201 Mdot
.764 .42052 Mdot
.764 .42083 Mdot
.764 .42119 Mdot
.764 .42136 Mdot
.764 .42164 Mdot
.764 .42166 Mdot
.764 .42189 Mdot
.764 .42207 Mdot
.764 .42235 Mdot
.764 .42261 Mdot
.764 .42267 Mdot
.764 .42277 Mdot
.764 .42283 Mdot
.764 .42354 Mdot
.764 .42355 Mdot
.764 .4241 Mdot
.764 .42428 Mdot
.764 .42459 Mdot
.764 .4247 Mdot
.764 .42476 Mdot
.764 .42478 Mdot
.764 .42506 Mdot
.764 .42518 Mdot
.764 .42519 Mdot
.764 .42543 Mdot
.764 .42569 Mdot
.764 .42601 Mdot
.764 .42634 Mdot
.764 .42636 Mdot
.764 .42665 Mdot
.764 .42677 Mdot
.764 .42686 Mdot
.764 .42815 Mdot
.764 .42819 Mdot
.764 .42838 Mdot
.764 .42865 Mdot
.764 .42958 Mdot
.764 .42988 Mdot
.764 .42995 Mdot
.764 .43008 Mdot
.764 .43038 Mdot
.764 .43051 Mdot
.764 .43058 Mdot
.764 .43105 Mdot
.764 .43109 Mdot
.764 .43186 Mdot
.764 .43247 Mdot
.764 .43261 Mdot
.764 .43322 Mdot
.764 .43329 Mdot
.764 .43339 Mdot
.764 .43377 Mdot
.764 .43379 Mdot
.764 .43381 Mdot
.764 .43408 Mdot
.764 .43422 Mdot
.764 .43465 Mdot
.764 .43473 Mdot
.764 .43478 Mdot
.764 .43489 Mdot
.764 .43492 Mdot
.764 .43492 Mdot
.764 .43518 Mdot
.764 .4359 Mdot
.764 .4361 Mdot
.764 .4363 Mdot
.764 .43633 Mdot
.764 .4364 Mdot
.764 .43646 Mdot
.764 .43749 Mdot
.764 .43761 Mdot
.764 .43764 Mdot
.764 .43829 Mdot
.764 .43833 Mdot
.764 .43895 Mdot
.764 .43924 Mdot
.764 .43929 Mdot
.764 .43944 Mdot
.764 .43949 Mdot
.764 .43954 Mdot
.764 .43965 Mdot
.764 .43981 Mdot
.764 .44 Mdot
.764 .44028 Mdot
.764 .44041 Mdot
.764 .44056 Mdot
.764 .44107 Mdot
.764 .44148 Mdot
.764 .44152 Mdot
.764 .44202 Mdot
.764 .44206 Mdot
.764 .44217 Mdot
.764 .44251 Mdot
.764 .44254 Mdot
.764 .44271 Mdot
.764 .44313 Mdot
.764 .44333 Mdot
.764 .44397 Mdot
.764 .44431 Mdot
.764 .44445 Mdot
.764 .44466 Mdot
.764 .44468 Mdot
.764 .44502 Mdot
.764 .44555 Mdot
.764 .44566 Mdot
.764 .44572 Mdot
.764 .44575 Mdot
.764 .44578 Mdot
.764 .44588 Mdot
.764 .44601 Mdot
.764 .44659 Mdot
.764 .44686 Mdot
.764 .4473 Mdot
.764 .44734 Mdot
.764 .44775 Mdot
.764 .44775 Mdot
.764 .4478 Mdot
.764 .44833 Mdot
.764 .44849 Mdot
.764 .44932 Mdot
.764 .44941 Mdot
.764 .44944 Mdot
.764 .44948 Mdot
.764 .44986 Mdot
.764 .44989 Mdot
.764 .45009 Mdot
.764 .45025 Mdot
.764 .45052 Mdot
.764 .45131 Mdot
.764 .45137 Mdot
.764 .45173 Mdot
.764 .45194 Mdot
.764 .45213 Mdot
.764 .45279 Mdot
.764 .45287 Mdot
.764 .45338 Mdot
.764 .45409 Mdot
.764 .45415 Mdot
.764 .45415 Mdot
.764 .45539 Mdot
.764 .45548 Mdot
.764 .45556 Mdot
.764 .45574 Mdot
.764 .45586 Mdot
.764 .45606 Mdot
.764 .45621 Mdot
.764 .45627 Mdot
.764 .4564 Mdot
.764 .45645 Mdot
.764 .45649 Mdot
.764 .45662 Mdot
.764 .45662 Mdot
.764 .45679 Mdot
.764 .45685 Mdot
.764 .45737 Mdot
.764 .45747 Mdot
.764 .4577 Mdot
.764 .45786 Mdot
.764 .45789 Mdot
.764 .45804 Mdot
.764 .45822 Mdot
.764 .45831 Mdot
.764 .45837 Mdot
.764 .4584 Mdot
.764 .45842 Mdot
.764 .45852 Mdot
.764 .45856 Mdot
.764 .45878 Mdot
.764 .45883 Mdot
.764 .45945 Mdot
.764 .45955 Mdot
.764 .45959 Mdot
.764 .45975 Mdot
.764 .4605 Mdot
.764 .4605 Mdot
.764 .46059 Mdot
.764 .46071 Mdot
.764 .46073 Mdot
.764 .46088 Mdot
.764 .46092 Mdot
.764 .4621 Mdot
.764 .46215 Mdot
.764 .46217 Mdot
.764 .46219 Mdot
.764 .4624 Mdot
.764 .46242 Mdot
.764 .46271 Mdot
.764 .46297 Mdot
.764 .46312 Mdot
.764 .46384 Mdot
.764 .46408 Mdot
.764 .4641 Mdot
.764 .46411 Mdot
.764 .46412 Mdot
.764 .46422 Mdot
.764 .46428 Mdot
.764 .46436 Mdot
.764 .4649 Mdot
.764 .46517 Mdot
.764 .46531 Mdot
.764 .46537 Mdot
.764 .46537 Mdot
.766 .22624 Mdot
.766 .22631 Mdot
.766 .22653 Mdot
.766 .22654 Mdot
.766 .22673 Mdot
.766 .22673 Mdot
.766 .22699 Mdot
.766 .22792 Mdot
.766 .22839 Mdot
.766 .22866 Mdot
.766 .22903 Mdot
.766 .22973 Mdot
.766 .22982 Mdot
.766 .23003 Mdot
.766 .23005 Mdot
.766 .23042 Mdot
.766 .23042 Mdot
.766 .23109 Mdot
.766 .23132 Mdot
.766 .23135 Mdot
.766 .23177 Mdot
.766 .23179 Mdot
.766 .23213 Mdot
.766 .23254 Mdot
.766 .23295 Mdot
.766 .23323 Mdot
.766 .23327 Mdot
.766 .23328 Mdot
.766 .23358 Mdot
.766 .23395 Mdot
.766 .23461 Mdot
.766 .23505 Mdot
.766 .23559 Mdot
.766 .23691 Mdot
.766 .23692 Mdot
.766 .23712 Mdot
.766 .23726 Mdot
.766 .23845 Mdot
.766 .23887 Mdot
.766 .23909 Mdot
.766 .23954 Mdot
.766 .24013 Mdot
.766 .24016 Mdot
.766 .24023 Mdot
.766 .24039 Mdot
.766 .2408 Mdot
.766 .24113 Mdot
.766 .24119 Mdot
.766 .24156 Mdot
.766 .24158 Mdot
.766 .24239 Mdot
.766 .24244 Mdot
.766 .24263 Mdot
.766 .24279 Mdot
.766 .2434 Mdot
.766 .24352 Mdot
.766 .24357 Mdot
.766 .2437 Mdot
.766 .24382 Mdot
.766 .24454 Mdot
.766 .24459 Mdot
.766 .24487 Mdot
.766 .247 Mdot
.766 .24707 Mdot
.766 .24723 Mdot
.766 .24726 Mdot
.766 .24769 Mdot
.766 .24782 Mdot
.766 .24806 Mdot
.766 .24825 Mdot
.766 .2484 Mdot
.766 .24945 Mdot
.766 .2495 Mdot
.766 .24966 Mdot
.766 .24973 Mdot
.766 .24977 Mdot
.766 .24984 Mdot
.766 .25006 Mdot
.766 .25154 Mdot
.766 .2524 Mdot
.766 .2527 Mdot
.766 .25297 Mdot
.766 .25298 Mdot
.766 .25353 Mdot
.766 .25374 Mdot
.766 .25374 Mdot
.766 .25441 Mdot
.766 .2546 Mdot
.766 .25551 Mdot
.766 .25552 Mdot
.766 .25559 Mdot
.766 .25565 Mdot
.766 .25607 Mdot
.766 .25686 Mdot
.766 .2569 Mdot
.766 .25725 Mdot
.766 .25728 Mdot
.766 .25778 Mdot
.766 .25784 Mdot
.766 .25788 Mdot
.766 .25949 Mdot
.766 .25952 Mdot
.766 .25957 Mdot
.766 .26012 Mdot
.766 .26104 Mdot
.766 .2611 Mdot
.766 .26115 Mdot
.766 .26137 Mdot
.766 .26155 Mdot
.766 .262 Mdot
.766 .26208 Mdot
.766 .26268 Mdot
.766 .2634 Mdot
.766 .26359 Mdot
.766 .26374 Mdot
.766 .26431 Mdot
.766 .26501 Mdot
.766 .26526 Mdot
.766 .26537 Mdot
.766 .26587 Mdot
.766 .26619 Mdot
.766 .26647 Mdot
.766 .26708 Mdot
.766 .2675 Mdot
.766 .26839 Mdot
.766 .26856 Mdot
.766 .26913 Mdot
.766 .26932 Mdot
.766 .26987 Mdot
.766 .2699 Mdot
.766 .2708 Mdot
.766 .27095 Mdot
.766 .27098 Mdot
.766 .27111 Mdot
.766 .2717 Mdot
.766 .27336 Mdot
.766 .27343 Mdot
.766 .27413 Mdot
.766 .27418 Mdot
.766 .27444 Mdot
.766 .27506 Mdot
.766 .27573 Mdot
.766 .27583 Mdot
.766 .27607 Mdot
.766 .27642 Mdot
.766 .27706 Mdot
.766 .27725 Mdot
.766 .27746 Mdot
.766 .27794 Mdot
.766 .27945 Mdot
.766 .28028 Mdot
.766 .28047 Mdot
.766 .28054 Mdot
.766 .28132 Mdot
.766 .28181 Mdot
.766 .28228 Mdot
.766 .28268 Mdot
.766 .28313 Mdot
.766 .28339 Mdot
.766 .28343 Mdot
.766 .28352 Mdot
.766 .28379 Mdot
.766 .28422 Mdot
.766 .28516 Mdot
.766 .28528 Mdot
.766 .28601 Mdot
.766 .28621 Mdot
.766 .28701 Mdot
.766 .28766 Mdot
.766 .28786 Mdot
.766 .28795 Mdot
.766 .28845 Mdot
.766 .28856 Mdot
.766 .28926 Mdot
.766 .28958 Mdot
.766 .28961 Mdot
.766 .29056 Mdot
.766 .29165 Mdot
.766 .2921 Mdot
.766 .29254 Mdot
.766 .2928 Mdot
.766 .29301 Mdot
.766 .29306 Mdot
.766 .29346 Mdot
.766 .29377 Mdot
.766 .29385 Mdot
.766 .29441 Mdot
.766 .29445 Mdot
.766 .29464 Mdot
.766 .29471 Mdot
.766 .29481 Mdot
.766 .29525 Mdot
.766 .29548 Mdot
.766 .29551 Mdot
.766 .29552 Mdot
.766 .2962 Mdot
.766 .29622 Mdot
.766 .29646 Mdot
.766 .29647 Mdot
.766 .29698 Mdot
.766 .29715 Mdot
.766 .29721 Mdot
.766 .29768 Mdot
.766 .29797 Mdot
.766 .29829 Mdot
.766 .2989 Mdot
.766 .30049 Mdot
.766 .30054 Mdot
.766 .30073 Mdot
.766 .30074 Mdot
.766 .30187 Mdot
.766 .30219 Mdot
.766 .30237 Mdot
.766 .3027 Mdot
.766 .3028 Mdot
.766 .30315 Mdot
.766 .30334 Mdot
.766 .30365 Mdot
.766 .30377 Mdot
.766 .3043 Mdot
.766 .30448 Mdot
.766 .30513 Mdot
.766 .3057 Mdot
.766 .30593 Mdot
.766 .3064 Mdot
.766 .30668 Mdot
.766 .30682 Mdot
.766 .307 Mdot
.766 .30717 Mdot
.766 .30732 Mdot
.766 .30733 Mdot
.766 .3075 Mdot
.766 .30762 Mdot
.766 .3079 Mdot
.766 .30806 Mdot
.766 .30816 Mdot
.766 .30849 Mdot
.766 .30877 Mdot
.766 .30897 Mdot
.766 .30936 Mdot
.766 .30947 Mdot
.766 .30948 Mdot
.766 .30956 Mdot
.766 .30965 Mdot
.766 .30968 Mdot
.766 .30983 Mdot
.766 .31074 Mdot
.766 .3112 Mdot
.766 .31132 Mdot
.766 .31149 Mdot
.766 .31187 Mdot
.766 .31269 Mdot
.766 .31271 Mdot
.766 .31284 Mdot
.766 .31328 Mdot
.766 .31426 Mdot
.766 .31435 Mdot
.766 .3144 Mdot
.766 .31519 Mdot
.766 .31538 Mdot
.766 .31564 Mdot
.766 .31567 Mdot
.766 .31591 Mdot
.766 .31608 Mdot
.766 .31624 Mdot
.766 .31661 Mdot
.766 .31676 Mdot
.766 .31707 Mdot
.766 .31709 Mdot
.766 .31715 Mdot
.766 .31751 Mdot
.766 .31765 Mdot
.766 .31855 Mdot
.766 .31858 Mdot
.766 .31901 Mdot
.766 .31909 Mdot
.766 .31915 Mdot
.766 .3196 Mdot
.766 .31962 Mdot
.766 .31969 Mdot
.766 .31972 Mdot
.766 .31974 Mdot
.766 .31977 Mdot
.766 .31986 Mdot
.766 .32085 Mdot
.766 .32098 Mdot
.766 .3211 Mdot
.766 .32134 Mdot
.766 .32143 Mdot
.766 .32179 Mdot
.766 .32218 Mdot
.766 .32222 Mdot
.766 .32275 Mdot
.766 .32277 Mdot
.766 .32315 Mdot
.766 .32454 Mdot
.766 .32456 Mdot
.766 .32524 Mdot
.766 .32569 Mdot
.766 .32623 Mdot
.766 .32673 Mdot
.766 .32711 Mdot
.766 .32767 Mdot
.766 .32798 Mdot
.766 .32806 Mdot
.766 .3283 Mdot
.766 .32831 Mdot
.766 .32869 Mdot
.766 .32876 Mdot
.766 .32877 Mdot
.766 .32908 Mdot
.766 .33011 Mdot
.766 .33024 Mdot
.766 .33051 Mdot
.766 .3308 Mdot
.766 .33109 Mdot
.766 .33136 Mdot
.766 .33273 Mdot
.766 .33281 Mdot
.766 .33285 Mdot
.766 .33359 Mdot
.766 .33376 Mdot
.766 .33395 Mdot
.766 .33406 Mdot
.766 .33408 Mdot
.766 .33441 Mdot
.766 .33481 Mdot
.766 .33486 Mdot
.766 .33526 Mdot
.766 .33622 Mdot
.766 .33656 Mdot
.766 .3367 Mdot
.766 .33777 Mdot
.766 .33796 Mdot
.766 .33816 Mdot
.766 .33818 Mdot
.766 .33835 Mdot
.766 .33848 Mdot
.766 .33852 Mdot
.766 .33876 Mdot
.766 .33877 Mdot
.766 .33888 Mdot
.766 .33921 Mdot
.766 .33922 Mdot
.766 .33923 Mdot
.766 .33952 Mdot
.766 .33953 Mdot
.766 .33963 Mdot
.766 .33963 Mdot
.766 .33985 Mdot
.766 .33992 Mdot
.766 .34015 Mdot
.766 .34027 Mdot
.766 .34041 Mdot
.766 .34067 Mdot
.766 .34134 Mdot
.766 .34137 Mdot
.766 .34145 Mdot
.766 .34207 Mdot
.766 .34229 Mdot
.766 .34248 Mdot
.766 .34256 Mdot
.766 .34269 Mdot
.766 .34274 Mdot
.766 .34305 Mdot
.766 .34386 Mdot
.766 .34398 Mdot
.766 .34404 Mdot
.766 .34412 Mdot
.766 .34419 Mdot
.766 .34425 Mdot
.766 .34426 Mdot
.766 .34438 Mdot
.766 .3445 Mdot
.766 .34457 Mdot
.766 .34461 Mdot
.766 .34476 Mdot
.766 .34487 Mdot
.766 .34513 Mdot
.766 .34517 Mdot
.766 .34517 Mdot
.766 .34525 Mdot
.766 .34533 Mdot
.766 .34571 Mdot
.766 .34591 Mdot
.766 .3462 Mdot
.766 .34654 Mdot
.766 .34655 Mdot
.766 .34661 Mdot
.766 .34679 Mdot
.766 .34721 Mdot
.766 .34725 Mdot
.766 .34727 Mdot
.766 .34761 Mdot
.766 .3478 Mdot
.766 .34781 Mdot
.766 .34792 Mdot
.766 .34799 Mdot
.766 .34805 Mdot
.766 .34821 Mdot
.766 .34842 Mdot
.766 .34865 Mdot
.766 .34904 Mdot
.766 .34905 Mdot
.766 .34923 Mdot
.766 .34927 Mdot
.766 .3493 Mdot
.766 .34949 Mdot
.766 .34954 Mdot
.766 .34955 Mdot
.766 .34956 Mdot
.766 .3496 Mdot
.766 .35002 Mdot
.766 .35013 Mdot
.766 .35023 Mdot
.766 .35042 Mdot
.766 .35059 Mdot
.766 .3506 Mdot
.766 .35084 Mdot
.766 .35159 Mdot
.766 .3516 Mdot
.766 .35208 Mdot
.766 .35226 Mdot
.766 .35253 Mdot
.766 .35269 Mdot
.766 .35306 Mdot
.766 .35309 Mdot
.766 .35319 Mdot
.766 .35336 Mdot
.766 .35339 Mdot
.766 .3534 Mdot
.766 .35397 Mdot
.766 .35426 Mdot
.766 .3545 Mdot
.766 .35512 Mdot
.766 .35513 Mdot
.766 .35545 Mdot
.766 .35552 Mdot
.766 .3556 Mdot
.766 .35565 Mdot
.766 .35597 Mdot
.766 .35616 Mdot
.766 .35657 Mdot
.766 .35677 Mdot
.766 .35723 Mdot
.766 .3574 Mdot
.766 .35748 Mdot
.766 .35753 Mdot
.766 .35755 Mdot
.766 .35765 Mdot
.766 .35802 Mdot
.766 .35811 Mdot
.766 .35846 Mdot
.766 .35876 Mdot
.766 .3588 Mdot
.766 .35915 Mdot
.766 .35933 Mdot
.766 .35935 Mdot
.766 .35997 Mdot
.766 .35999 Mdot
.766 .36005 Mdot
.766 .3601 Mdot
.766 .36021 Mdot
.766 .36025 Mdot
.766 .36036 Mdot
.766 .36042 Mdot
.766 .36045 Mdot
.766 .36061 Mdot
.766 .3607 Mdot
.766 .36097 Mdot
.766 .36107 Mdot
.766 .36125 Mdot
.766 .36142 Mdot
.766 .36158 Mdot
.766 .36168 Mdot
.766 .36187 Mdot
.766 .36203 Mdot
.766 .36213 Mdot
.766 .36224 Mdot
.766 .36227 Mdot
.766 .36262 Mdot
.766 .3627 Mdot
.766 .3628 Mdot
.766 .36352 Mdot
.766 .36359 Mdot
.766 .36389 Mdot
.766 .36413 Mdot
.766 .36425 Mdot
.766 .36436 Mdot
.766 .36483 Mdot
.766 .36506 Mdot
.766 .36524 Mdot
.766 .36532 Mdot
.766 .36552 Mdot
.766 .36559 Mdot
.766 .3657 Mdot
.766 .36617 Mdot
.766 .36619 Mdot
.766 .36669 Mdot
.766 .36681 Mdot
.766 .36686 Mdot
.766 .36688 Mdot
.766 .36696 Mdot
.766 .36711 Mdot
.766 .36723 Mdot
.766 .36731 Mdot
.766 .3675 Mdot
.766 .36757 Mdot
.766 .36761 Mdot
.766 .36782 Mdot
.766 .36789 Mdot
.766 .36851 Mdot
.766 .36856 Mdot
.766 .36876 Mdot
.766 .36908 Mdot
.766 .36933 Mdot
.766 .36978 Mdot
.766 .36992 Mdot
.766 .37003 Mdot
.766 .37006 Mdot
.766 .37033 Mdot
.766 .37035 Mdot
.766 .37043 Mdot
.766 .37057 Mdot
.766 .37068 Mdot
.766 .37087 Mdot
.766 .37093 Mdot
.766 .37097 Mdot
.766 .3711 Mdot
.766 .37111 Mdot
.766 .37143 Mdot
.766 .37143 Mdot
.766 .37157 Mdot
.766 .37163 Mdot
.766 .37174 Mdot
.766 .37183 Mdot
.766 .37183 Mdot
.766 .37204 Mdot
.766 .37205 Mdot
.766 .3722 Mdot
.766 .37249 Mdot
.766 .37254 Mdot
.766 .37255 Mdot
.766 .37273 Mdot
.766 .37275 Mdot
.766 .37282 Mdot
.766 .37291 Mdot
.766 .37321 Mdot
.766 .37337 Mdot
.766 .37358 Mdot
.766 .37371 Mdot
.766 .37374 Mdot
.766 .37414 Mdot
.766 .37419 Mdot
.766 .37433 Mdot
.766 .37436 Mdot
.766 .3744 Mdot
.766 .37457 Mdot
.766 .37465 Mdot
.766 .37475 Mdot
.766 .37482 Mdot
.766 .37493 Mdot
.766 .37526 Mdot
.766 .37527 Mdot
.766 .37564 Mdot
.766 .37615 Mdot
.766 .37645 Mdot
.766 .37652 Mdot
.766 .37747 Mdot
.766 .37754 Mdot
.766 .37759 Mdot
.766 .37791 Mdot
.766 .37797 Mdot
.766 .37808 Mdot
.766 .37837 Mdot
.766 .37848 Mdot
.766 .37866 Mdot
.766 .37884 Mdot
.766 .3789 Mdot
.766 .37902 Mdot
.766 .37906 Mdot
.766 .37913 Mdot
.766 .3793 Mdot
.766 .37932 Mdot
.766 .37972 Mdot
.766 .37974 Mdot
.766 .38008 Mdot
.766 .3801 Mdot
.766 .38059 Mdot
.766 .38083 Mdot
.766 .3809 Mdot
.766 .38091 Mdot
.766 .38099 Mdot
.766 .3811 Mdot
.766 .3814 Mdot
.766 .38154 Mdot
.766 .3818 Mdot
.766 .38193 Mdot
.766 .38217 Mdot
.766 .38222 Mdot
.766 .38289 Mdot
.766 .38304 Mdot
.766 .38323 Mdot
.766 .38361 Mdot
.766 .38361 Mdot
.766 .38363 Mdot
.766 .38374 Mdot
.766 .38383 Mdot
.766 .38407 Mdot
.766 .38417 Mdot
.766 .38447 Mdot
.766 .38528 Mdot
.766 .38543 Mdot
.766 .38555 Mdot
.766 .38567 Mdot
.766 .38574 Mdot
.766 .38609 Mdot
.766 .38613 Mdot
.766 .38628 Mdot
.766 .3863 Mdot
.766 .38632 Mdot
.766 .38645 Mdot
.766 .3867 Mdot
.766 .38699 Mdot
.766 .38709 Mdot
.766 .38714 Mdot
.766 .38718 Mdot
.766 .38725 Mdot
.766 .38739 Mdot
.766 .38764 Mdot
.766 .38792 Mdot
.766 .38808 Mdot
.766 .3885 Mdot
.766 .38862 Mdot
.766 .38887 Mdot
.766 .38892 Mdot
.766 .38901 Mdot
.766 .38917 Mdot
.766 .38925 Mdot
.766 .38941 Mdot
.766 .38949 Mdot
.766 .38957 Mdot
.766 .38961 Mdot
.766 .38971 Mdot
.766 .38975 Mdot
.766 .38983 Mdot
.766 .39056 Mdot
.766 .39059 Mdot
.766 .39068 Mdot
.766 .39086 Mdot
.766 .39141 Mdot
.766 .39146 Mdot
.766 .39191 Mdot
.766 .39208 Mdot
.766 .39217 Mdot
.766 .39225 Mdot
.766 .39245 Mdot
.766 .39259 Mdot
.766 .39259 Mdot
.766 .39287 Mdot
.766 .39316 Mdot
.766 .39332 Mdot
.766 .39334 Mdot
.766 .39343 Mdot
.766 .39354 Mdot
.766 .39355 Mdot
.766 .39368 Mdot
.766 .39381 Mdot
.766 .39451 Mdot
.766 .3946 Mdot
.766 .39482 Mdot
.766 .39544 Mdot
.766 .3957 Mdot
.766 .39574 Mdot
.766 .396 Mdot
.766 .39622 Mdot
.766 .39623 Mdot
.766 .3963 Mdot
.766 .39642 Mdot
.766 .39654 Mdot
.766 .39702 Mdot
.766 .39704 Mdot
.766 .39709 Mdot
.766 .39799 Mdot
.766 .39817 Mdot
.766 .39836 Mdot
.766 .39855 Mdot
.766 .39872 Mdot
.766 .3988 Mdot
.766 .39948 Mdot
.766 .39968 Mdot
.766 .39969 Mdot
.766 .39973 Mdot
.766 .39998 Mdot
.766 .39999 Mdot
.766 .40014 Mdot
.766 .4002 Mdot
.766 .4004 Mdot
.766 .40076 Mdot
.766 .40101 Mdot
.766 .40134 Mdot
.766 .40142 Mdot
.766 .40169 Mdot
.766 .40199 Mdot
.766 .40243 Mdot
.766 .40244 Mdot
.766 .40335 Mdot
.766 .4036 Mdot
.766 .40361 Mdot
.766 .40396 Mdot
.766 .40398 Mdot
.766 .40424 Mdot
.766 .40447 Mdot
.766 .40453 Mdot
.766 .40469 Mdot
.766 .40477 Mdot
.766 .40485 Mdot
.766 .4055 Mdot
.766 .40556 Mdot
.766 .40558 Mdot
.766 .40559 Mdot
.766 .40561 Mdot
.766 .40565 Mdot
.766 .40567 Mdot
.766 .40596 Mdot
.766 .406 Mdot
.766 .40605 Mdot
.766 .40633 Mdot
.766 .40635 Mdot
.766 .40694 Mdot
.766 .40703 Mdot
.766 .40727 Mdot
.766 .4073 Mdot
.766 .40732 Mdot
.766 .40752 Mdot
.766 .40762 Mdot
.766 .40786 Mdot
.766 .40796 Mdot
.766 .40807 Mdot
.766 .40823 Mdot
.766 .40825 Mdot
.766 .40842 Mdot
.766 .40855 Mdot
.766 .40906 Mdot
.766 .4091 Mdot
.766 .40916 Mdot
.766 .40979 Mdot
.766 .41008 Mdot
.766 .41017 Mdot
.766 .41018 Mdot
.766 .41071 Mdot
.766 .41096 Mdot
.766 .41107 Mdot
.766 .41115 Mdot
.766 .41145 Mdot
.766 .41204 Mdot
.766 .41214 Mdot
.766 .41216 Mdot
.766 .41222 Mdot
.766 .41228 Mdot
.766 .41228 Mdot
.766 .41235 Mdot
.766 .41261 Mdot
.766 .41274 Mdot
.766 .41292 Mdot
.766 .41314 Mdot
.766 .4132 Mdot
.766 .4133 Mdot
.766 .41349 Mdot
.766 .41356 Mdot
.766 .41368 Mdot
.766 .41368 Mdot
.766 .41378 Mdot
.766 .41389 Mdot
.766 .41401 Mdot
.766 .4141 Mdot
.766 .41428 Mdot
.766 .41459 Mdot
.766 .41474 Mdot
.766 .41511 Mdot
.766 .41554 Mdot
.766 .41565 Mdot
.766 .416 Mdot
.766 .41607 Mdot
.766 .41628 Mdot
.766 .41641 Mdot
.766 .41663 Mdot
.766 .4167 Mdot
.766 .41691 Mdot
.766 .41703 Mdot
.766 .41724 Mdot
.766 .41798 Mdot
.766 .41799 Mdot
.766 .4181 Mdot
.766 .41814 Mdot
.766 .41918 Mdot
.766 .41957 Mdot
.766 .41979 Mdot
.766 .41997 Mdot
.766 .42028 Mdot
.766 .42032 Mdot
.766 .42043 Mdot
.766 .42076 Mdot
.766 .42077 Mdot
.766 .42093 Mdot
.766 .42094 Mdot
.766 .42139 Mdot
.766 .42139 Mdot
.766 .42141 Mdot
.766 .42156 Mdot
.766 .42185 Mdot
.766 .42191 Mdot
.766 .42196 Mdot
.766 .42208 Mdot
.766 .42211 Mdot
.766 .42247 Mdot
.766 .42253 Mdot
.766 .42273 Mdot
.766 .42299 Mdot
.766 .42302 Mdot
.766 .42316 Mdot
.766 .42333 Mdot
.766 .42362 Mdot
.766 .42391 Mdot
.766 .42462 Mdot
.766 .42524 Mdot
.766 .42526 Mdot
.766 .42547 Mdot
.766 .42593 Mdot
.766 .426 Mdot
.766 .42633 Mdot
.766 .42639 Mdot
.766 .42652 Mdot
.766 .42694 Mdot
.766 .42746 Mdot
.766 .4276 Mdot
.766 .42807 Mdot
.766 .42815 Mdot
.766 .42876 Mdot
.766 .42904 Mdot
.766 .42922 Mdot
.766 .42928 Mdot
.766 .4293 Mdot
.766 .42947 Mdot
.766 .42976 Mdot
.766 .43003 Mdot
.766 .43033 Mdot
.766 .43065 Mdot
.766 .43116 Mdot
.766 .43121 Mdot
.766 .43133 Mdot
.766 .43188 Mdot
.766 .43286 Mdot
.766 .43317 Mdot
.766 .43331 Mdot
.766 .43343 Mdot
.766 .43385 Mdot
.766 .43408 Mdot
.766 .43424 Mdot
.766 .4343 Mdot
.766 .43474 Mdot
.766 .43515 Mdot
.766 .43531 Mdot
.766 .43535 Mdot
.766 .4358 Mdot
.766 .43585 Mdot
.766 .43693 Mdot
.766 .43732 Mdot
.766 .4374 Mdot
.766 .43742 Mdot
.766 .43752 Mdot
.766 .43811 Mdot
.766 .43813 Mdot
.766 .43849 Mdot
.766 .43861 Mdot
.766 .43898 Mdot
.766 .43909 Mdot
.766 .43967 Mdot
.766 .43995 Mdot
.766 .44035 Mdot
.766 .44053 Mdot
.766 .44074 Mdot
.766 .44106 Mdot
.766 .44114 Mdot
.766 .4413 Mdot
.766 .44176 Mdot
.766 .44213 Mdot
.766 .44222 Mdot
.766 .44235 Mdot
.766 .44282 Mdot
.766 .44321 Mdot
.766 .44327 Mdot
.766 .44356 Mdot
.766 .44367 Mdot
.766 .44382 Mdot
.766 .44385 Mdot
.766 .44389 Mdot
.766 .44449 Mdot
.766 .44485 Mdot
.766 .44489 Mdot
.766 .4449 Mdot
.766 .44595 Mdot
.766 .44598 Mdot
.766 .44602 Mdot
.766 .44635 Mdot
.766 .44636 Mdot
.766 .44659 Mdot
.766 .44662 Mdot
.766 .44714 Mdot
.766 .44741 Mdot
.766 .44745 Mdot
.766 .44749 Mdot
.766 .4475 Mdot
.766 .44809 Mdot
.766 .44822 Mdot
.766 .44865 Mdot
.766 .44866 Mdot
.766 .44879 Mdot
.766 .44915 Mdot
.766 .44916 Mdot
.766 .44934 Mdot
.766 .44953 Mdot
.766 .45009 Mdot
.766 .45106 Mdot
.766 .4512 Mdot
.766 .45125 Mdot
.766 .45128 Mdot
.766 .45132 Mdot
.766 .45143 Mdot
.766 .45146 Mdot
.766 .45214 Mdot
.766 .45224 Mdot
.766 .45236 Mdot
.766 .45252 Mdot
.766 .45261 Mdot
.766 .45289 Mdot
.766 .45291 Mdot
.766 .45301 Mdot
.766 .45306 Mdot
.766 .45445 Mdot
.766 .45463 Mdot
.766 .45466 Mdot
.766 .45513 Mdot
.766 .45521 Mdot
.766 .45529 Mdot
.766 .45533 Mdot
.766 .4554 Mdot
.766 .4558 Mdot
.766 .45591 Mdot
.766 .45603 Mdot
.766 .45606 Mdot
.766 .4566 Mdot
.766 .45661 Mdot
.766 .45685 Mdot
.766 .45689 Mdot
.766 .4571 Mdot
.766 .45737 Mdot
.766 .45747 Mdot
.766 .45752 Mdot
.766 .45754 Mdot
.766 .45792 Mdot
.766 .45822 Mdot
.766 .45837 Mdot
.766 .45864 Mdot
.766 .45942 Mdot
.766 .4595 Mdot
.766 .45964 Mdot
.766 .45964 Mdot
.766 .4605 Mdot
.766 .46086 Mdot
.766 .46114 Mdot
.766 .46157 Mdot
.766 .46181 Mdot
.766 .46201 Mdot
.766 .46202 Mdot
.766 .46204 Mdot
.766 .46223 Mdot
.766 .4625 Mdot
.766 .46276 Mdot
.766 .46298 Mdot
.766 .46299 Mdot
.766 .46327 Mdot
.766 .46329 Mdot
.766 .46344 Mdot
.766 .46388 Mdot
.766 .46388 Mdot
.766 .46412 Mdot
.766 .46414 Mdot
.766 .46427 Mdot
.766 .46433 Mdot
.766 .46479 Mdot
.766 .46503 Mdot
.766 .4652 Mdot
.766 .46551 Mdot
.766 .46612 Mdot
.766 .46629 Mdot
.766 .46629 Mdot
.766 .46641 Mdot
.766 .46641 Mdot
.766 .46656 Mdot
.766 .46661 Mdot
.768 .22496 Mdot
.768 .22502 Mdot
.768 .22519 Mdot
.768 .22523 Mdot
.768 .22666 Mdot
.768 .22675 Mdot
.768 .22681 Mdot
.768 .22696 Mdot
.768 .22709 Mdot
.768 .22719 Mdot
.768 .22805 Mdot
.768 .22808 Mdot
.768 .22831 Mdot
.768 .22855 Mdot
.768 .22916 Mdot
.768 .22965 Mdot
.768 .23015 Mdot
.768 .23036 Mdot
.768 .23137 Mdot
.768 .23182 Mdot
.768 .23218 Mdot
.768 .23236 Mdot
.768 .23237 Mdot
.768 .23331 Mdot
.768 .23334 Mdot
.768 .23364 Mdot
.768 .23411 Mdot
.768 .23423 Mdot
.768 .23493 Mdot
.768 .2354 Mdot
.768 .23607 Mdot
.768 .23638 Mdot
.768 .23653 Mdot
.768 .2371 Mdot
.768 .23758 Mdot
.768 .23848 Mdot
.768 .23856 Mdot
.768 .2393 Mdot
.768 .23969 Mdot
.768 .24005 Mdot
.768 .24015 Mdot
.768 .24043 Mdot
.768 .24047 Mdot
.768 .24051 Mdot
.768 .24063 Mdot
.768 .24073 Mdot
.768 .24135 Mdot
.768 .24205 Mdot
.768 .24235 Mdot
.768 .24246 Mdot
.768 .24264 Mdot
.768 .24286 Mdot
.768 .24307 Mdot
.768 .24324 Mdot
.768 .24328 Mdot
.768 .2433 Mdot
.768 .24388 Mdot
.768 .24391 Mdot
.768 .24393 Mdot
.768 .24441 Mdot
.768 .24486 Mdot
.768 .24627 Mdot
.768 .24659 Mdot
.768 .2467 Mdot
.768 .24792 Mdot
.768 .24827 Mdot
.768 .2492 Mdot
.768 .24987 Mdot
.768 .24998 Mdot
.768 .25025 Mdot
.768 .25026 Mdot
.768 .25052 Mdot
.768 .25088 Mdot
.768 .25094 Mdot
.768 .25105 Mdot
.768 .252 Mdot
.768 .2522 Mdot
.768 .25227 Mdot
.768 .25269 Mdot
.768 .25273 Mdot
.768 .25285 Mdot
.768 .25351 Mdot
.768 .25358 Mdot
.768 .25365 Mdot
.768 .25371 Mdot
.768 .254 Mdot
.768 .25416 Mdot
.768 .25432 Mdot
.768 .25456 Mdot
.768 .25471 Mdot
.768 .25486 Mdot
.768 .25499 Mdot
.768 .25523 Mdot
.768 .25573 Mdot
.768 .256 Mdot
.768 .25637 Mdot
.768 .25643 Mdot
.768 .25644 Mdot
.768 .2568 Mdot
.768 .2569 Mdot
.768 .25737 Mdot
.768 .2574 Mdot
.768 .25839 Mdot
.768 .25883 Mdot
.768 .25988 Mdot
.768 .26084 Mdot
.768 .26092 Mdot
.768 .26095 Mdot
.768 .26191 Mdot
.768 .26202 Mdot
.768 .26256 Mdot
.768 .26267 Mdot
.768 .26279 Mdot
.768 .26318 Mdot
.768 .26518 Mdot
.768 .26583 Mdot
.768 .26702 Mdot
.768 .26731 Mdot
.768 .26731 Mdot
.768 .26795 Mdot
.768 .26812 Mdot
.768 .26825 Mdot
.768 .26853 Mdot
.768 .26863 Mdot
.768 .26879 Mdot
.768 .26912 Mdot
.768 .26918 Mdot
.768 .26928 Mdot
.768 .26987 Mdot
.768 .27037 Mdot
.768 .27049 Mdot
.768 .2707 Mdot
.768 .27094 Mdot
.768 .27098 Mdot
.768 .27113 Mdot
.768 .27151 Mdot
.768 .27172 Mdot
.768 .27211 Mdot
.768 .2728 Mdot
.768 .27293 Mdot
.768 .27337 Mdot
.768 .27341 Mdot
.768 .27347 Mdot
.768 .27373 Mdot
.768 .27383 Mdot
.768 .27438 Mdot
.768 .27493 Mdot
.768 .27501 Mdot
.768 .27534 Mdot
.768 .27557 Mdot
.768 .27707 Mdot
.768 .27735 Mdot
.768 .27761 Mdot
.768 .27825 Mdot
.768 .27905 Mdot
.768 .27942 Mdot
.768 .27952 Mdot
.768 .28057 Mdot
.768 .28064 Mdot
.768 .28139 Mdot
.768 .2815 Mdot
.768 .28153 Mdot
.768 .28155 Mdot
.768 .28177 Mdot
.768 .28205 Mdot
.768 .28225 Mdot
.768 .28266 Mdot
.768 .28392 Mdot
.768 .28394 Mdot
.768 .28403 Mdot
.768 .28437 Mdot
.768 .28465 Mdot
.768 .2847 Mdot
.768 .2855 Mdot
.768 .2857 Mdot
.768 .28573 Mdot
.768 .28578 Mdot
.768 .28609 Mdot
.768 .28661 Mdot
.768 .28676 Mdot
.768 .28738 Mdot
.768 .28848 Mdot
.768 .28851 Mdot
.768 .28875 Mdot
.768 .28913 Mdot
.768 .28936 Mdot
.768 .28971 Mdot
.768 .28996 Mdot
.768 .29019 Mdot
.768 .2902 Mdot
.768 .2903 Mdot
.768 .29039 Mdot
.768 .29045 Mdot
.768 .29084 Mdot
.768 .29091 Mdot
.768 .29098 Mdot
.768 .29111 Mdot
.768 .29118 Mdot
.768 .29134 Mdot
.768 .2914 Mdot
.768 .29147 Mdot
.768 .29174 Mdot
.768 .29174 Mdot
.768 .29187 Mdot
.768 .29349 Mdot
.768 .29366 Mdot
.768 .29403 Mdot
.768 .29615 Mdot
.768 .2962 Mdot
.768 .29635 Mdot
.768 .29638 Mdot
.768 .29653 Mdot
.768 .29686 Mdot
.768 .29696 Mdot
.768 .29708 Mdot
.768 .29725 Mdot
.768 .29738 Mdot
.768 .29759 Mdot
.768 .29815 Mdot
.768 .29863 Mdot
.768 .29897 Mdot
.768 .29913 Mdot
.768 .29942 Mdot
.768 .29981 Mdot
.768 .30066 Mdot
.768 .30126 Mdot
.768 .30145 Mdot
.768 .30192 Mdot
.768 .30193 Mdot
.768 .30202 Mdot
.768 .3021 Mdot
.768 .3022 Mdot
.768 .30228 Mdot
.768 .30275 Mdot
.768 .30305 Mdot
.768 .30312 Mdot
.768 .30325 Mdot
.768 .30393 Mdot
.768 .30498 Mdot
.768 .30547 Mdot
.768 .30601 Mdot
.768 .30614 Mdot
.768 .30655 Mdot
.768 .30678 Mdot
.768 .30698 Mdot
.768 .30749 Mdot
.768 .30791 Mdot
.768 .30817 Mdot
.768 .30827 Mdot
.768 .30838 Mdot
.768 .30958 Mdot
.768 .30967 Mdot
.768 .3097 Mdot
.768 .3098 Mdot
.768 .31042 Mdot
.768 .31046 Mdot
.768 .31048 Mdot
.768 .31055 Mdot
.768 .31061 Mdot
.768 .31064 Mdot
.768 .31102 Mdot
.768 .31169 Mdot
.768 .31199 Mdot
.768 .31276 Mdot
.768 .31284 Mdot
.768 .31324 Mdot
.768 .31358 Mdot
.768 .31363 Mdot
.768 .31413 Mdot
.768 .31454 Mdot
.768 .3146 Mdot
.768 .31484 Mdot
.768 .31505 Mdot
.768 .31543 Mdot
.768 .31578 Mdot
.768 .31594 Mdot
.768 .3161 Mdot
.768 .31626 Mdot
.768 .31629 Mdot
.768 .31638 Mdot
.768 .31695 Mdot
.768 .31707 Mdot
.768 .31745 Mdot
.768 .31772 Mdot
.768 .31774 Mdot
.768 .31774 Mdot
.768 .31887 Mdot
.768 .31892 Mdot
.768 .31943 Mdot
.768 .32031 Mdot
.768 .32042 Mdot
.768 .32053 Mdot
.768 .32069 Mdot
.768 .32071 Mdot
.768 .32116 Mdot
.768 .32127 Mdot
.768 .32145 Mdot
.768 .32147 Mdot
.768 .32152 Mdot
.768 .32183 Mdot
.768 .32186 Mdot
.768 .32189 Mdot
.768 .32208 Mdot
.768 .32225 Mdot
.768 .32237 Mdot
.768 .32274 Mdot
.768 .32304 Mdot
.768 .32344 Mdot
.768 .32345 Mdot
.768 .32387 Mdot
.768 .32405 Mdot
.768 .3245 Mdot
.768 .32491 Mdot
.768 .32494 Mdot
.768 .32495 Mdot
.768 .32541 Mdot
.768 .32564 Mdot
.768 .32568 Mdot
.768 .32675 Mdot
.768 .32702 Mdot
.768 .32817 Mdot
.768 .32844 Mdot
.768 .32874 Mdot
.768 .32927 Mdot
.768 .32952 Mdot
.768 .32998 Mdot
.768 .33022 Mdot
.768 .33024 Mdot
.768 .33037 Mdot
.768 .33041 Mdot
.768 .33105 Mdot
.768 .33115 Mdot
.768 .33179 Mdot
.768 .33191 Mdot
.768 .33229 Mdot
.768 .33282 Mdot
.768 .33327 Mdot
.768 .33368 Mdot
.768 .33378 Mdot
.768 .33398 Mdot
.768 .33416 Mdot
.768 .3347 Mdot
.768 .33488 Mdot
.768 .335 Mdot
.768 .33545 Mdot
.768 .33561 Mdot
.768 .33583 Mdot
.768 .3359 Mdot
.768 .33616 Mdot
.768 .33662 Mdot
.768 .33664 Mdot
.768 .3369 Mdot
.768 .337 Mdot
.768 .33725 Mdot
.768 .33735 Mdot
.768 .3374 Mdot
.768 .33744 Mdot
.768 .33746 Mdot
.768 .33765 Mdot
.768 .33768 Mdot
.768 .33774 Mdot
.768 .33777 Mdot
.768 .33801 Mdot
.768 .33806 Mdot
.768 .33898 Mdot
.768 .33989 Mdot
.768 .33996 Mdot
.768 .34004 Mdot
.768 .34018 Mdot
.768 .34022 Mdot
.768 .34027 Mdot
.768 .3404 Mdot
.768 .34049 Mdot
.768 .34072 Mdot
.768 .34093 Mdot
.768 .34107 Mdot
.768 .34126 Mdot
.768 .34143 Mdot
.768 .34212 Mdot
.768 .34232 Mdot
.768 .34236 Mdot
.768 .3424 Mdot
.768 .34244 Mdot
.768 .34247 Mdot
.768 .34267 Mdot
.768 .3428 Mdot
.768 .34283 Mdot
.768 .34289 Mdot
.768 .34317 Mdot
.768 .34362 Mdot
.768 .34411 Mdot
.768 .34428 Mdot
.768 .34468 Mdot
.768 .34486 Mdot
.768 .34497 Mdot
.768 .34506 Mdot
.768 .3456 Mdot
.768 .34562 Mdot
.768 .34594 Mdot
.768 .34595 Mdot
.768 .346 Mdot
.768 .34618 Mdot
.768 .34692 Mdot
.768 .34695 Mdot
.768 .34712 Mdot
.768 .34726 Mdot
.768 .34749 Mdot
.768 .3477 Mdot
.768 .3478 Mdot
.768 .34805 Mdot
.768 .3482 Mdot
.768 .34833 Mdot
.768 .3484 Mdot
.768 .34874 Mdot
.768 .34902 Mdot
.768 .34903 Mdot
.768 .3495 Mdot
.768 .34974 Mdot
.768 .35016 Mdot
.768 .35029 Mdot
.768 .35048 Mdot
.768 .35052 Mdot
.768 .35061 Mdot
.768 .35063 Mdot
.768 .35077 Mdot
.768 .35078 Mdot
.768 .35094 Mdot
.768 .35099 Mdot
.768 .35145 Mdot
.768 .35162 Mdot
.768 .3517 Mdot
.768 .35189 Mdot
.768 .35206 Mdot
.768 .35228 Mdot
.768 .35239 Mdot
.768 .35284 Mdot
.768 .35296 Mdot
.768 .35345 Mdot
.768 .35369 Mdot
.768 .35391 Mdot
.768 .35402 Mdot
.768 .35432 Mdot
.768 .35432 Mdot
.768 .35438 Mdot
.768 .3544 Mdot
.768 .35467 Mdot
.768 .35471 Mdot
.768 .35498 Mdot
.768 .35503 Mdot
.768 .35519 Mdot
.768 .35542 Mdot
.768 .35561 Mdot
.768 .35578 Mdot
.768 .35582 Mdot
.768 .35591 Mdot
.768 .35598 Mdot
.768 .35629 Mdot
.768 .35634 Mdot
.768 .35653 Mdot
.768 .35669 Mdot
.768 .35703 Mdot
.768 .35704 Mdot
.768 .35715 Mdot
.768 .35719 Mdot
.768 .3573 Mdot
.768 .35734 Mdot
.768 .35736 Mdot
.768 .35738 Mdot
.768 .35752 Mdot
.768 .35803 Mdot
.768 .35842 Mdot
.768 .35854 Mdot
.768 .359 Mdot
.768 .35907 Mdot
.768 .35936 Mdot
.768 .35945 Mdot
.768 .35946 Mdot
.768 .35959 Mdot
.768 .35966 Mdot
.768 .35968 Mdot
.768 .36 Mdot
.768 .36028 Mdot
.768 .36045 Mdot
.768 .36061 Mdot
.768 .36084 Mdot
.768 .36098 Mdot
.768 .36108 Mdot
.768 .36139 Mdot
.768 .36141 Mdot
.768 .36148 Mdot
.768 .36154 Mdot
.768 .36172 Mdot
.768 .36177 Mdot
.768 .36187 Mdot
.768 .36277 Mdot
.768 .36282 Mdot
.768 .36303 Mdot
.768 .36331 Mdot
.768 .36357 Mdot
.768 .36371 Mdot
.768 .36391 Mdot
.768 .36436 Mdot
.768 .36453 Mdot
.768 .36456 Mdot
.768 .36456 Mdot
.768 .36481 Mdot
.768 .36515 Mdot
.768 .36517 Mdot
.768 .36521 Mdot
.768 .36547 Mdot
.768 .36554 Mdot
.768 .36573 Mdot
.768 .36579 Mdot
.768 .36582 Mdot
.768 .36583 Mdot
.768 .3661 Mdot
.768 .36651 Mdot
.768 .36671 Mdot
.768 .36677 Mdot
.768 .36679 Mdot
.768 .36694 Mdot
.768 .36753 Mdot
.768 .36769 Mdot
.768 .36811 Mdot
.768 .36822 Mdot
.768 .36887 Mdot
.768 .36929 Mdot
.768 .3697 Mdot
.768 .36988 Mdot
.768 .37038 Mdot
.768 .3707 Mdot
.768 .37087 Mdot
.768 .37105 Mdot
.768 .37292 Mdot
.768 .37345 Mdot
.768 .37357 Mdot
.768 .37384 Mdot
.768 .37411 Mdot
.768 .3746 Mdot
.768 .37488 Mdot
.768 .37537 Mdot
.768 .37564 Mdot
.768 .37591 Mdot
.768 .37609 Mdot
.768 .37628 Mdot
.768 .37649 Mdot
.768 .37652 Mdot
.768 .37691 Mdot
.768 .37692 Mdot
.768 .37746 Mdot
.768 .37756 Mdot
.768 .37773 Mdot
.768 .37791 Mdot
.768 .37808 Mdot
.768 .37873 Mdot
.768 .37898 Mdot
.768 .37918 Mdot
.768 .37949 Mdot
.768 .37959 Mdot
.768 .37989 Mdot
.768 .3801 Mdot
.768 .38015 Mdot
.768 .38023 Mdot
.768 .38024 Mdot
.768 .3803 Mdot
.768 .38049 Mdot
.768 .38054 Mdot
.768 .38117 Mdot
.768 .3815 Mdot
.768 .38159 Mdot
.768 .3816 Mdot
.768 .38161 Mdot
.768 .38164 Mdot
.768 .38171 Mdot
.768 .38174 Mdot
.768 .38182 Mdot
.768 .38204 Mdot
.768 .38214 Mdot
.768 .38226 Mdot
.768 .3825 Mdot
.768 .38255 Mdot
.768 .3826 Mdot
.768 .38263 Mdot
.768 .38274 Mdot
.768 .38312 Mdot
.768 .38315 Mdot
.768 .38335 Mdot
.768 .38353 Mdot
.768 .38354 Mdot
.768 .38358 Mdot
.768 .38358 Mdot
.768 .38378 Mdot
.768 .38385 Mdot
.768 .38415 Mdot
.768 .38454 Mdot
.768 .38484 Mdot
.768 .38491 Mdot
.768 .38505 Mdot
.768 .38534 Mdot
.768 .38545 Mdot
.768 .38588 Mdot
.768 .38589 Mdot
.768 .38598 Mdot
.768 .386 Mdot
.768 .38621 Mdot
.768 .38629 Mdot
.768 .38656 Mdot
.768 .38672 Mdot
.768 .38744 Mdot
.768 .38748 Mdot
.768 .38766 Mdot
.768 .38783 Mdot
.768 .38789 Mdot
.768 .38818 Mdot
.768 .38827 Mdot
.768 .38838 Mdot
.768 .3884 Mdot
.768 .38888 Mdot
.768 .389 Mdot
.768 .38904 Mdot
.768 .38925 Mdot
.768 .38961 Mdot
.768 .38967 Mdot
.768 .38985 Mdot
.768 .39011 Mdot
.768 .39055 Mdot
.768 .39102 Mdot
.768 .39106 Mdot
.768 .39116 Mdot
.768 .39129 Mdot
.768 .39137 Mdot
.768 .39139 Mdot
.768 .39152 Mdot
.768 .39197 Mdot
.768 .39208 Mdot
.768 .39276 Mdot
.768 .39279 Mdot
.768 .39288 Mdot
.768 .39293 Mdot
.768 .39297 Mdot
.768 .39357 Mdot
.768 .39436 Mdot
.768 .39441 Mdot
.768 .39456 Mdot
.768 .39457 Mdot
.768 .3946 Mdot
.768 .39463 Mdot
.768 .39469 Mdot
.768 .39486 Mdot
.768 .39492 Mdot
.768 .39509 Mdot
.768 .3951 Mdot
.768 .39541 Mdot
.768 .39557 Mdot
.768 .39562 Mdot
.768 .39576 Mdot
.768 .39587 Mdot
.768 .39616 Mdot
.768 .39624 Mdot
.768 .39636 Mdot
.768 .39671 Mdot
.768 .39682 Mdot
.768 .39695 Mdot
.768 .39702 Mdot
.768 .39728 Mdot
.768 .39757 Mdot
.768 .39792 Mdot
.768 .39817 Mdot
.768 .39825 Mdot
.768 .39866 Mdot
.768 .39873 Mdot
.768 .39915 Mdot
.768 .39917 Mdot
.768 .39926 Mdot
.768 .39927 Mdot
.768 .39943 Mdot
.768 .39973 Mdot
.768 .39989 Mdot
.768 .40024 Mdot
.768 .40043 Mdot
.768 .40061 Mdot
.768 .40135 Mdot
.768 .40153 Mdot
.768 .40222 Mdot
.768 .40225 Mdot
.768 .4024 Mdot
.768 .4027 Mdot
.768 .40271 Mdot
.768 .40273 Mdot
.768 .40299 Mdot
.768 .40328 Mdot
.768 .40341 Mdot
.768 .40368 Mdot
.768 .40369 Mdot
.768 .40394 Mdot
.768 .40414 Mdot
.768 .40438 Mdot
.768 .40446 Mdot
.768 .40457 Mdot
.768 .4047 Mdot
.768 .40471 Mdot
.768 .40473 Mdot
.768 .40493 Mdot
.768 .40497 Mdot
.768 .40498 Mdot
.768 .40509 Mdot
.768 .40517 Mdot
.768 .40546 Mdot
.768 .40548 Mdot
.768 .40558 Mdot
.768 .40565 Mdot
.768 .40572 Mdot
.768 .40629 Mdot
.768 .40663 Mdot
.768 .40666 Mdot
.768 .40739 Mdot
.768 .4074 Mdot
.768 .40741 Mdot
.768 .40759 Mdot
.768 .40783 Mdot
.768 .40791 Mdot
.768 .40828 Mdot
.768 .40834 Mdot
.768 .40836 Mdot
.768 .40846 Mdot
.768 .40856 Mdot
.768 .40867 Mdot
.768 .4089 Mdot
.768 .40915 Mdot
.768 .40928 Mdot
.768 .40944 Mdot
.768 .40948 Mdot
.768 .40975 Mdot
.768 .41007 Mdot
.768 .41011 Mdot
.768 .41033 Mdot
.768 .41059 Mdot
.768 .41064 Mdot
.768 .41114 Mdot
.768 .41133 Mdot
.768 .41177 Mdot
.768 .41202 Mdot
.768 .41204 Mdot
.768 .41208 Mdot
.768 .41212 Mdot
.768 .41214 Mdot
.768 .41216 Mdot
.768 .41257 Mdot
.768 .41263 Mdot
.768 .41265 Mdot
.768 .41271 Mdot
.768 .41349 Mdot
.768 .41356 Mdot
.768 .41363 Mdot
.768 .4138 Mdot
.768 .41407 Mdot
.768 .4144 Mdot
.768 .41453 Mdot
.768 .41468 Mdot
.768 .41495 Mdot
.768 .41503 Mdot
.768 .41539 Mdot
.768 .4157 Mdot
.768 .41639 Mdot
.768 .41683 Mdot
.768 .41692 Mdot
.768 .41696 Mdot
.768 .41716 Mdot
.768 .41746 Mdot
.768 .41751 Mdot
.768 .41758 Mdot
.768 .41763 Mdot
.768 .41769 Mdot
.768 .4177 Mdot
.768 .418 Mdot
.768 .41813 Mdot
.768 .41851 Mdot
.768 .41907 Mdot
.768 .41932 Mdot
.768 .41951 Mdot
.768 .41962 Mdot
.768 .41984 Mdot
.768 .42015 Mdot
.768 .42051 Mdot
.768 .42065 Mdot
.768 .42074 Mdot
.768 .42085 Mdot
.768 .42092 Mdot
.768 .42099 Mdot
.768 .4212 Mdot
.768 .4213 Mdot
.768 .42132 Mdot
.768 .42142 Mdot
.768 .42145 Mdot
.768 .42283 Mdot
.768 .42308 Mdot
.768 .42318 Mdot
.768 .42424 Mdot
.768 .42432 Mdot
.768 .42432 Mdot
.768 .4245 Mdot
.768 .42455 Mdot
.768 .42458 Mdot
.768 .42469 Mdot
.768 .42473 Mdot
.768 .42482 Mdot
.768 .42487 Mdot
.768 .42491 Mdot
.768 .42517 Mdot
.768 .4252 Mdot
.768 .42526 Mdot
.768 .42532 Mdot
.768 .42533 Mdot
.768 .42548 Mdot
.768 .42565 Mdot
.768 .42587 Mdot
.768 .42602 Mdot
.768 .42627 Mdot
.768 .42642 Mdot
.768 .42645 Mdot
.768 .42716 Mdot
.768 .42756 Mdot
.768 .42766 Mdot
.768 .428 Mdot
.768 .42821 Mdot
.768 .42824 Mdot
.768 .42825 Mdot
.768 .42839 Mdot
.768 .4289 Mdot
.768 .42894 Mdot
.768 .42912 Mdot
.768 .42934 Mdot
.768 .4294 Mdot
.768 .42942 Mdot
.768 .43024 Mdot
.768 .4305 Mdot
.768 .43063 Mdot
.768 .43081 Mdot
.768 .43095 Mdot
.768 .43097 Mdot
.768 .43099 Mdot
.768 .43106 Mdot
.768 .43155 Mdot
.768 .43159 Mdot
.768 .43228 Mdot
.768 .43234 Mdot
.768 .43258 Mdot
.768 .4331 Mdot
.768 .43353 Mdot
.768 .43369 Mdot
.768 .43387 Mdot
.768 .43485 Mdot
.768 .435 Mdot
.768 .43521 Mdot
.768 .43527 Mdot
.768 .43563 Mdot
.768 .43599 Mdot
.768 .43605 Mdot
.768 .43622 Mdot
.768 .43625 Mdot
.768 .43628 Mdot
.768 .43657 Mdot
.768 .43665 Mdot
.768 .4371 Mdot
.768 .43736 Mdot
.768 .4375 Mdot
.768 .43774 Mdot
.768 .43784 Mdot
.768 .43786 Mdot
.768 .43802 Mdot
.768 .43816 Mdot
.768 .43824 Mdot
.768 .43856 Mdot
.768 .43895 Mdot
.768 .43901 Mdot
.768 .43905 Mdot
.768 .43926 Mdot
.768 .43937 Mdot
.768 .43943 Mdot
.768 .43962 Mdot
.768 .4397 Mdot
.768 .43981 Mdot
.768 .44023 Mdot
.768 .44023 Mdot
.768 .44042 Mdot
.768 .44119 Mdot
.768 .44162 Mdot
.768 .44292 Mdot
.768 .44317 Mdot
.768 .44325 Mdot
.768 .44332 Mdot
.768 .44367 Mdot
.768 .44374 Mdot
.768 .44437 Mdot
.768 .44439 Mdot
.768 .44444 Mdot
.768 .44506 Mdot
.768 .44575 Mdot
.768 .44604 Mdot
.768 .44668 Mdot
.768 .4467 Mdot
.768 .447 Mdot
.768 .44707 Mdot
.768 .44731 Mdot
.768 .44731 Mdot
.768 .44735 Mdot
.768 .44759 Mdot
.768 .44777 Mdot
.768 .44809 Mdot
.768 .44825 Mdot
.768 .44833 Mdot
.768 .44843 Mdot
.768 .44853 Mdot
.768 .44869 Mdot
.768 .44879 Mdot
.768 .44889 Mdot
.768 .44908 Mdot
.768 .44912 Mdot
.768 .44917 Mdot
.768 .44921 Mdot
.768 .44964 Mdot
.768 .44972 Mdot
.768 .44975 Mdot
.768 .45002 Mdot
.768 .45007 Mdot
.768 .4502 Mdot
.768 .45081 Mdot
.768 .45089 Mdot
.768 .45092 Mdot
.768 .45116 Mdot
.768 .45133 Mdot
.768 .45134 Mdot
.768 .45151 Mdot
.768 .45158 Mdot
.768 .45202 Mdot
.768 .45263 Mdot
.768 .45285 Mdot
.768 .45364 Mdot
.768 .45372 Mdot
.768 .45393 Mdot
.768 .45484 Mdot
.768 .45514 Mdot
.768 .45545 Mdot
.768 .45546 Mdot
.768 .45548 Mdot
.768 .45586 Mdot
.768 .45587 Mdot
.768 .4559 Mdot
.768 .45601 Mdot
.768 .45614 Mdot
.768 .45629 Mdot
.768 .45641 Mdot
.768 .45648 Mdot
.768 .45667 Mdot
.768 .45713 Mdot
.768 .45753 Mdot
.768 .4576 Mdot
.768 .45767 Mdot
.768 .4577 Mdot
.768 .45773 Mdot
.768 .45791 Mdot
.768 .45797 Mdot
.768 .45821 Mdot
.768 .45846 Mdot
.768 .45895 Mdot
.768 .459 Mdot
.768 .45958 Mdot
.768 .4599 Mdot
.768 .46027 Mdot
.768 .46036 Mdot
.768 .46057 Mdot
.768 .461 Mdot
.768 .46131 Mdot
.768 .46176 Mdot
.768 .46184 Mdot
.768 .46215 Mdot
.768 .46234 Mdot
.768 .46236 Mdot
.768 .46298 Mdot
.768 .46298 Mdot
.768 .4631 Mdot
.768 .46333 Mdot
.768 .46363 Mdot
.768 .46428 Mdot
.768 .46442 Mdot
.768 .46474 Mdot
.768 .46506 Mdot
.768 .46546 Mdot
.768 .46562 Mdot
.768 .46577 Mdot
.768 .46579 Mdot
.768 .46635 Mdot
.768 .46641 Mdot
.768 .4665 Mdot
.768 .4666 Mdot
.768 .46664 Mdot
.768 .46669 Mdot
.768 .46763 Mdot
.768 .46765 Mdot
.768 .46776 Mdot
.768 .4678 Mdot
.77 .22395 Mdot
.77 .22419 Mdot
.77 .22434 Mdot
.77 .22438 Mdot
.77 .22471 Mdot
.77 .22502 Mdot
.77 .22524 Mdot
.77 .22543 Mdot
.77 .22576 Mdot
.77 .22596 Mdot
.77 .22612 Mdot
.77 .22651 Mdot
.77 .22759 Mdot
.77 .22759 Mdot
.77 .22813 Mdot
.77 .22837 Mdot
.77 .22859 Mdot
.77 .22867 Mdot
.77 .2293 Mdot
.77 .22936 Mdot
.77 .22949 Mdot
.77 .22993 Mdot
.77 .23039 Mdot
.77 .23119 Mdot
.77 .23151 Mdot
.77 .23181 Mdot
.77 .23259 Mdot
.77 .23306 Mdot
.77 .2331 Mdot
.77 .23327 Mdot
.77 .23332 Mdot
.77 .2334 Mdot
.77 .23361 Mdot
.77 .23387 Mdot
.77 .23424 Mdot
.77 .23544 Mdot
.77 .2356 Mdot
.77 .23582 Mdot
.77 .23601 Mdot
.77 .23621 Mdot
.77 .23637 Mdot
.77 .23697 Mdot
.77 .23768 Mdot
.77 .23783 Mdot
.77 .23786 Mdot
.77 .23795 Mdot
.77 .23827 Mdot
.77 .23827 Mdot
.77 .23842 Mdot
.77 .23851 Mdot
.77 .23883 Mdot
.77 .23898 Mdot
.77 .239 Mdot
.77 .23905 Mdot
.77 .23929 Mdot
.77 .23936 Mdot
.77 .24022 Mdot
.77 .241 Mdot
.77 .2419 Mdot
.77 .24215 Mdot
.77 .24235 Mdot
.77 .24261 Mdot
.77 .24282 Mdot
.77 .24291 Mdot
.77 .24295 Mdot
.77 .2431 Mdot
.77 .24403 Mdot
.77 .24464 Mdot
.77 .24506 Mdot
.77 .24568 Mdot
.77 .24651 Mdot
.77 .2471 Mdot
.77 .24775 Mdot
.77 .24777 Mdot
.77 .24896 Mdot
.77 .2491 Mdot
.77 .24954 Mdot
.77 .25022 Mdot
.77 .25094 Mdot
.77 .2513 Mdot
.77 .25139 Mdot
.77 .25181 Mdot
.77 .25214 Mdot
.77 .25233 Mdot
.77 .25274 Mdot
.77 .25312 Mdot
.77 .25326 Mdot
.77 .25359 Mdot
.77 .25401 Mdot
.77 .25402 Mdot
.77 .25404 Mdot
.77 .25453 Mdot
.77 .25459 Mdot
.77 .25471 Mdot
.77 .25498 Mdot
.77 .25547 Mdot
.77 .25552 Mdot
.77 .25571 Mdot
.77 .25606 Mdot
.77 .25653 Mdot
.77 .25689 Mdot
.77 .25698 Mdot
.77 .25707 Mdot
.77 .25757 Mdot
.77 .25829 Mdot
.77 .25849 Mdot
.77 .25874 Mdot
.77 .2588 Mdot
.77 .25925 Mdot
.77 .25957 Mdot
.77 .26052 Mdot
.77 .26166 Mdot
.77 .26206 Mdot
.77 .26241 Mdot
.77 .26282 Mdot
.77 .26302 Mdot
.77 .26331 Mdot
.77 .26353 Mdot
.77 .26397 Mdot
.77 .2641 Mdot
.77 .26438 Mdot
.77 .26453 Mdot
.77 .2646 Mdot
.77 .26517 Mdot
.77 .26572 Mdot
.77 .26616 Mdot
.77 .26647 Mdot
.77 .26705 Mdot
.77 .26786 Mdot
.77 .26794 Mdot
.77 .26893 Mdot
.77 .26937 Mdot
.77 .27014 Mdot
.77 .27019 Mdot
.77 .27065 Mdot
.77 .27073 Mdot
.77 .27094 Mdot
.77 .27106 Mdot
.77 .27168 Mdot
.77 .27172 Mdot
.77 .27242 Mdot
.77 .27243 Mdot
.77 .27312 Mdot
.77 .27319 Mdot
.77 .27334 Mdot
.77 .27348 Mdot
.77 .27354 Mdot
.77 .2737 Mdot
.77 .27383 Mdot
.77 .27446 Mdot
.77 .27454 Mdot
.77 .27462 Mdot
.77 .27562 Mdot
.77 .27568 Mdot
.77 .27602 Mdot
.77 .27615 Mdot
.77 .27688 Mdot
.77 .27715 Mdot
.77 .27734 Mdot
.77 .27771 Mdot
.77 .27835 Mdot
.77 .27859 Mdot
.77 .27866 Mdot
.77 .27892 Mdot
.77 .27908 Mdot
.77 .27933 Mdot
.77 .27945 Mdot
.77 .28051 Mdot
.77 .28059 Mdot
.77 .28066 Mdot
.77 .2807 Mdot
.77 .28223 Mdot
.77 .28248 Mdot
.77 .28266 Mdot
.77 .28334 Mdot
.77 .28391 Mdot
.77 .2843 Mdot
.77 .28483 Mdot
.77 .28565 Mdot
.77 .28567 Mdot
.77 .28618 Mdot
.77 .28692 Mdot
.77 .28763 Mdot
.77 .2878 Mdot
.77 .28822 Mdot
.77 .28828 Mdot
.77 .28867 Mdot
.77 .2887 Mdot
.77 .28882 Mdot
.77 .28915 Mdot
.77 .28946 Mdot
.77 .28972 Mdot
.77 .28986 Mdot
.77 .28989 Mdot
.77 .29062 Mdot
.77 .29107 Mdot
.77 .29165 Mdot
.77 .29178 Mdot
.77 .2922 Mdot
.77 .29244 Mdot
.77 .29253 Mdot
.77 .29265 Mdot
.77 .29271 Mdot
.77 .29289 Mdot
.77 .29299 Mdot
.77 .29311 Mdot
.77 .29337 Mdot
.77 .29368 Mdot
.77 .29416 Mdot
.77 .29491 Mdot
.77 .29541 Mdot
.77 .29562 Mdot
.77 .29565 Mdot
.77 .29569 Mdot
.77 .29619 Mdot
.77 .29627 Mdot
.77 .29629 Mdot
.77 .29666 Mdot
.77 .2969 Mdot
.77 .29691 Mdot
.77 .29728 Mdot
.77 .29744 Mdot
.77 .29762 Mdot
.77 .29801 Mdot
.77 .2982 Mdot
.77 .29898 Mdot
.77 .29955 Mdot
.77 .30042 Mdot
.77 .30086 Mdot
.77 .30111 Mdot
.77 .30151 Mdot
.77 .30157 Mdot
.77 .30159 Mdot
.77 .30163 Mdot
.77 .30183 Mdot
.77 .30308 Mdot
.77 .30324 Mdot
.77 .30324 Mdot
.77 .30344 Mdot
.77 .30355 Mdot
.77 .30355 Mdot
.77 .30368 Mdot
.77 .30372 Mdot
.77 .30434 Mdot
.77 .30441 Mdot
.77 .3045 Mdot
.77 .30524 Mdot
.77 .3054 Mdot
.77 .30551 Mdot
.77 .30574 Mdot
.77 .30594 Mdot
.77 .30627 Mdot
.77 .30639 Mdot
.77 .30687 Mdot
.77 .30706 Mdot
.77 .30725 Mdot
.77 .30772 Mdot
.77 .30782 Mdot
.77 .30805 Mdot
.77 .30805 Mdot
.77 .30851 Mdot
.77 .30867 Mdot
.77 .30874 Mdot
.77 .30882 Mdot
.77 .30904 Mdot
.77 .30942 Mdot
.77 .30958 Mdot
.77 .30991 Mdot
.77 .30999 Mdot
.77 .31013 Mdot
.77 .31026 Mdot
.77 .31043 Mdot
.77 .31177 Mdot
.77 .3118 Mdot
.77 .31207 Mdot
.77 .31209 Mdot
.77 .31286 Mdot
.77 .31367 Mdot
.77 .31374 Mdot
.77 .31376 Mdot
.77 .31379 Mdot
.77 .31385 Mdot
.77 .31466 Mdot
.77 .31472 Mdot
.77 .31481 Mdot
.77 .3153 Mdot
.77 .3156 Mdot
.77 .31566 Mdot
.77 .31591 Mdot
.77 .31609 Mdot
.77 .31618 Mdot
.77 .31628 Mdot
.77 .31667 Mdot
.77 .317 Mdot
.77 .31738 Mdot
.77 .31748 Mdot
.77 .31768 Mdot
.77 .31871 Mdot
.77 .31932 Mdot
.77 .31957 Mdot
.77 .31985 Mdot
.77 .32035 Mdot
.77 .3206 Mdot
.77 .32134 Mdot
.77 .32156 Mdot
.77 .3217 Mdot
.77 .32217 Mdot
.77 .32231 Mdot
.77 .32249 Mdot
.77 .32271 Mdot
.77 .32278 Mdot
.77 .3229 Mdot
.77 .32335 Mdot
.77 .32355 Mdot
.77 .32429 Mdot
.77 .32437 Mdot
.77 .32451 Mdot
.77 .32469 Mdot
.77 .32483 Mdot
.77 .32588 Mdot
.77 .3262 Mdot
.77 .32692 Mdot
.77 .32742 Mdot
.77 .32798 Mdot
.77 .32836 Mdot
.77 .32896 Mdot
.77 .32929 Mdot
.77 .32931 Mdot
.77 .32962 Mdot
.77 .32995 Mdot
.77 .33025 Mdot
.77 .33054 Mdot
.77 .33063 Mdot
.77 .33079 Mdot
.77 .33084 Mdot
.77 .33114 Mdot
.77 .33162 Mdot
.77 .33182 Mdot
.77 .33213 Mdot
.77 .33224 Mdot
.77 .33232 Mdot
.77 .33275 Mdot
.77 .33285 Mdot
.77 .33288 Mdot
.77 .33299 Mdot
.77 .33306 Mdot
.77 .33316 Mdot
.77 .33366 Mdot
.77 .33369 Mdot
.77 .33438 Mdot
.77 .33449 Mdot
.77 .33485 Mdot
.77 .33526 Mdot
.77 .33583 Mdot
.77 .33583 Mdot
.77 .33636 Mdot
.77 .33666 Mdot
.77 .33694 Mdot
.77 .3371 Mdot
.77 .33711 Mdot
.77 .3373 Mdot
.77 .33743 Mdot
.77 .33754 Mdot
.77 .3376 Mdot
.77 .33761 Mdot
.77 .33792 Mdot
.77 .33811 Mdot
.77 .33836 Mdot
.77 .33841 Mdot
.77 .33859 Mdot
.77 .33878 Mdot
.77 .33892 Mdot
.77 .33897 Mdot
.77 .33908 Mdot
.77 .33921 Mdot
.77 .33942 Mdot
.77 .33973 Mdot
.77 .34003 Mdot
.77 .34005 Mdot
.77 .34027 Mdot
.77 .3403 Mdot
.77 .34057 Mdot
.77 .34057 Mdot
.77 .34087 Mdot
.77 .34112 Mdot
.77 .34145 Mdot
.77 .34235 Mdot
.77 .34254 Mdot
.77 .34255 Mdot
.77 .34256 Mdot
.77 .34265 Mdot
.77 .34318 Mdot
.77 .34325 Mdot
.77 .34333 Mdot
.77 .34337 Mdot
.77 .34343 Mdot
.77 .34344 Mdot
.77 .34374 Mdot
.77 .34409 Mdot
.77 .34415 Mdot
.77 .3442 Mdot
.77 .3443 Mdot
.77 .34438 Mdot
.77 .34452 Mdot
.77 .34457 Mdot
.77 .34513 Mdot
.77 .34517 Mdot
.77 .34527 Mdot
.77 .34527 Mdot
.77 .34546 Mdot
.77 .34553 Mdot
.77 .3456 Mdot
.77 .34609 Mdot
.77 .34615 Mdot
.77 .34684 Mdot
.77 .34685 Mdot
.77 .3473 Mdot
.77 .34764 Mdot
.77 .34768 Mdot
.77 .34769 Mdot
.77 .34806 Mdot
.77 .34809 Mdot
.77 .34812 Mdot
.77 .34848 Mdot
.77 .34859 Mdot
.77 .3487 Mdot
.77 .34891 Mdot
.77 .34905 Mdot
.77 .34933 Mdot
.77 .34977 Mdot
.77 .35013 Mdot
.77 .35025 Mdot
.77 .35056 Mdot
.77 .35088 Mdot
.77 .35097 Mdot
.77 .35103 Mdot
.77 .35123 Mdot
.77 .35128 Mdot
.77 .35136 Mdot
.77 .35148 Mdot
.77 .35172 Mdot
.77 .35181 Mdot
.77 .35212 Mdot
.77 .35215 Mdot
.77 .35221 Mdot
.77 .35229 Mdot
.77 .35279 Mdot
.77 .35344 Mdot
.77 .35384 Mdot
.77 .35409 Mdot
.77 .35423 Mdot
.77 .35437 Mdot
.77 .35451 Mdot
.77 .35463 Mdot
.77 .35476 Mdot
.77 .35488 Mdot
.77 .35521 Mdot
.77 .35547 Mdot
.77 .35551 Mdot
.77 .35569 Mdot
.77 .35573 Mdot
.77 .35574 Mdot
.77 .35579 Mdot
.77 .35582 Mdot
.77 .35607 Mdot
.77 .35642 Mdot
.77 .35674 Mdot
.77 .35698 Mdot
.77 .35721 Mdot
.77 .35752 Mdot
.77 .35753 Mdot
.77 .35766 Mdot
.77 .35787 Mdot
.77 .35805 Mdot
.77 .35807 Mdot
.77 .35823 Mdot
.77 .35831 Mdot
.77 .35836 Mdot
.77 .3585 Mdot
.77 .35876 Mdot
.77 .35898 Mdot
.77 .35899 Mdot
.77 .35922 Mdot
.77 .35935 Mdot
.77 .35973 Mdot
.77 .35986 Mdot
.77 .36008 Mdot
.77 .36011 Mdot
.77 .36019 Mdot
.77 .3602 Mdot
.77 .3605 Mdot
.77 .36056 Mdot
.77 .36067 Mdot
.77 .36097 Mdot
.77 .36108 Mdot
.77 .36131 Mdot
.77 .36163 Mdot
.77 .36197 Mdot
.77 .36198 Mdot
.77 .36199 Mdot
.77 .36214 Mdot
.77 .36217 Mdot
.77 .36268 Mdot
.77 .36302 Mdot
.77 .3632 Mdot
.77 .36348 Mdot
.77 .36385 Mdot
.77 .36458 Mdot
.77 .36475 Mdot
.77 .36497 Mdot
.77 .36527 Mdot
.77 .3654 Mdot
.77 .36567 Mdot
.77 .366 Mdot
.77 .36613 Mdot
.77 .36619 Mdot
.77 .36636 Mdot
.77 .36643 Mdot
.77 .36739 Mdot
.77 .36763 Mdot
.77 .36773 Mdot
.77 .36786 Mdot
.77 .36801 Mdot
.77 .36808 Mdot
.77 .36831 Mdot
.77 .36864 Mdot
.77 .3688 Mdot
.77 .36945 Mdot
.77 .37039 Mdot
.77 .37056 Mdot
.77 .37058 Mdot
.77 .37068 Mdot
.77 .37082 Mdot
.77 .37168 Mdot
.77 .37174 Mdot
.77 .37213 Mdot
.77 .37259 Mdot
.77 .37284 Mdot
.77 .37344 Mdot
.77 .37353 Mdot
.77 .37359 Mdot
.77 .37361 Mdot
.77 .37485 Mdot
.77 .37507 Mdot
.77 .37522 Mdot
.77 .37526 Mdot
.77 .37545 Mdot
.77 .37551 Mdot
.77 .37567 Mdot
.77 .37634 Mdot
.77 .37696 Mdot
.77 .37739 Mdot
.77 .37796 Mdot
.77 .37821 Mdot
.77 .37851 Mdot
.77 .37873 Mdot
.77 .37906 Mdot
.77 .37908 Mdot
.77 .37918 Mdot
.77 .37919 Mdot
.77 .37941 Mdot
.77 .37962 Mdot
.77 .37977 Mdot
.77 .37984 Mdot
.77 .38015 Mdot
.77 .38034 Mdot
.77 .38064 Mdot
.77 .38127 Mdot
.77 .38162 Mdot
.77 .38173 Mdot
.77 .38185 Mdot
.77 .38199 Mdot
.77 .38207 Mdot
.77 .38208 Mdot
.77 .38228 Mdot
.77 .38258 Mdot
.77 .38279 Mdot
.77 .3832 Mdot
.77 .38323 Mdot
.77 .38324 Mdot
.77 .38327 Mdot
.77 .38341 Mdot
.77 .38387 Mdot
.77 .38403 Mdot
.77 .38412 Mdot
.77 .38421 Mdot
.77 .38431 Mdot
.77 .38447 Mdot
.77 .38473 Mdot
.77 .38547 Mdot
.77 .38556 Mdot
.77 .38558 Mdot
.77 .38584 Mdot
.77 .38616 Mdot
.77 .38639 Mdot
.77 .38659 Mdot
.77 .38688 Mdot
.77 .38711 Mdot
.77 .38739 Mdot
.77 .38767 Mdot
.77 .38781 Mdot
.77 .38795 Mdot
.77 .38818 Mdot
.77 .38822 Mdot
.77 .38846 Mdot
.77 .38847 Mdot
.77 .38849 Mdot
.77 .38871 Mdot
.77 .38901 Mdot
.77 .3895 Mdot
.77 .38982 Mdot
.77 .38986 Mdot
.77 .39003 Mdot
.77 .39012 Mdot
.77 .39048 Mdot
.77 .39052 Mdot
.77 .39061 Mdot
.77 .39066 Mdot
.77 .39076 Mdot
.77 .39122 Mdot
.77 .39123 Mdot
.77 .39129 Mdot
.77 .39135 Mdot
.77 .39139 Mdot
.77 .39173 Mdot
.77 .39179 Mdot
.77 .39193 Mdot
.77 .39251 Mdot
.77 .39273 Mdot
.77 .39308 Mdot
.77 .39308 Mdot
.77 .39326 Mdot
.77 .39342 Mdot
.77 .39383 Mdot
.77 .39405 Mdot
.77 .39412 Mdot
.77 .39425 Mdot
.77 .39448 Mdot
.77 .39452 Mdot
.77 .3948 Mdot
.77 .395 Mdot
.77 .39512 Mdot
.77 .39533 Mdot
.77 .39534 Mdot
.77 .39562 Mdot
.77 .39582 Mdot
.77 .39616 Mdot
.77 .39616 Mdot
.77 .39653 Mdot
.77 .3968 Mdot
.77 .39703 Mdot
.77 .3971 Mdot
.77 .39755 Mdot
.77 .39757 Mdot
.77 .39789 Mdot
.77 .39796 Mdot
.77 .39801 Mdot
.77 .39808 Mdot
.77 .3981 Mdot
.77 .39816 Mdot
.77 .39844 Mdot
.77 .39849 Mdot
.77 .39857 Mdot
.77 .39876 Mdot
.77 .39889 Mdot
.77 .39921 Mdot
.77 .3994 Mdot
.77 .39943 Mdot
.77 .39954 Mdot
.77 .3996 Mdot
.77 .39978 Mdot
.77 .39998 Mdot
.77 .40019 Mdot
.77 .4004 Mdot
.77 .40041 Mdot
.77 .40062 Mdot
.77 .40101 Mdot
.77 .40126 Mdot
.77 .40162 Mdot
.77 .40195 Mdot
.77 .40241 Mdot
.77 .40262 Mdot
.77 .4033 Mdot
.77 .40339 Mdot
.77 .40351 Mdot
.77 .4036 Mdot
.77 .40366 Mdot
.77 .40414 Mdot
.77 .40426 Mdot
.77 .40456 Mdot
.77 .40464 Mdot
.77 .40468 Mdot
.77 .40483 Mdot
.77 .40494 Mdot
.77 .40503 Mdot
.77 .40534 Mdot
.77 .40543 Mdot
.77 .40557 Mdot
.77 .40605 Mdot
.77 .40621 Mdot
.77 .40654 Mdot
.77 .40672 Mdot
.77 .40688 Mdot
.77 .40728 Mdot
.77 .40795 Mdot
.77 .40807 Mdot
.77 .40814 Mdot
.77 .40839 Mdot
.77 .4086 Mdot
.77 .40886 Mdot
.77 .40892 Mdot
.77 .40898 Mdot
.77 .4091 Mdot
.77 .40926 Mdot
.77 .4093 Mdot
.77 .40949 Mdot
.77 .40981 Mdot
.77 .40987 Mdot
.77 .40991 Mdot
.77 .41044 Mdot
.77 .41047 Mdot
.77 .41049 Mdot
.77 .41051 Mdot
.77 .41055 Mdot
.77 .41108 Mdot
.77 .41158 Mdot
.77 .41159 Mdot
.77 .41177 Mdot
.77 .41179 Mdot
.77 .41265 Mdot
.77 .41276 Mdot
.77 .41285 Mdot
.77 .41294 Mdot
.77 .41299 Mdot
.77 .41321 Mdot
.77 .41331 Mdot
.77 .41356 Mdot
.77 .4137 Mdot
.77 .41376 Mdot
.77 .4138 Mdot
.77 .41391 Mdot
.77 .4142 Mdot
.77 .4142 Mdot
.77 .41435 Mdot
.77 .41441 Mdot
.77 .41472 Mdot
.77 .41484 Mdot
.77 .41497 Mdot
.77 .41528 Mdot
.77 .41536 Mdot
.77 .41557 Mdot
.77 .4157 Mdot
.77 .41585 Mdot
.77 .41592 Mdot
.77 .41602 Mdot
.77 .41651 Mdot
.77 .41656 Mdot
.77 .41661 Mdot
.77 .41701 Mdot
.77 .41704 Mdot
.77 .41713 Mdot
.77 .41713 Mdot
.77 .41719 Mdot
.77 .41732 Mdot
.77 .41733 Mdot
.77 .41743 Mdot
.77 .41824 Mdot
.77 .41837 Mdot
.77 .4184 Mdot
.77 .41841 Mdot
.77 .41845 Mdot
.77 .4187 Mdot
.77 .41887 Mdot
.77 .41915 Mdot
.77 .41972 Mdot
.77 .42009 Mdot
.77 .4206 Mdot
.77 .42072 Mdot
.77 .42098 Mdot
.77 .42109 Mdot
.77 .42119 Mdot
.77 .42144 Mdot
.77 .42144 Mdot
.77 .42159 Mdot
.77 .42184 Mdot
.77 .42185 Mdot
.77 .4219 Mdot
.77 .42223 Mdot
.77 .42225 Mdot
.77 .42227 Mdot
.77 .42241 Mdot
.77 .42273 Mdot
.77 .42322 Mdot
.77 .42353 Mdot
.77 .42373 Mdot
.77 .4239 Mdot
.77 .42398 Mdot
.77 .42404 Mdot
.77 .42416 Mdot
.77 .4242 Mdot
.77 .42428 Mdot
.77 .42434 Mdot
.77 .42449 Mdot
.77 .42476 Mdot
.77 .42485 Mdot
.77 .42523 Mdot
.77 .42552 Mdot
.77 .42599 Mdot
.77 .42601 Mdot
.77 .42611 Mdot
.77 .42627 Mdot
.77 .42648 Mdot
.77 .42669 Mdot
.77 .42677 Mdot
.77 .42678 Mdot
.77 .42704 Mdot
.77 .42708 Mdot
.77 .42735 Mdot
.77 .42746 Mdot
.77 .42792 Mdot
.77 .4284 Mdot
.77 .42873 Mdot
.77 .42874 Mdot
.77 .42928 Mdot
.77 .42962 Mdot
.77 .42987 Mdot
.77 .43024 Mdot
.77 .43069 Mdot
.77 .4308 Mdot
.77 .43097 Mdot
.77 .43196 Mdot
.77 .43198 Mdot
.77 .43203 Mdot
.77 .43208 Mdot
.77 .43277 Mdot
.77 .43285 Mdot
.77 .43301 Mdot
.77 .43311 Mdot
.77 .43328 Mdot
.77 .43333 Mdot
.77 .43348 Mdot
.77 .4339 Mdot
.77 .43414 Mdot
.77 .43426 Mdot
.77 .43444 Mdot
.77 .43491 Mdot
.77 .435 Mdot
.77 .43522 Mdot
.77 .43526 Mdot
.77 .43591 Mdot
.77 .43596 Mdot
.77 .43601 Mdot
.77 .43642 Mdot
.77 .4365 Mdot
.77 .43661 Mdot
.77 .43665 Mdot
.77 .43674 Mdot
.77 .43684 Mdot
.77 .43688 Mdot
.77 .43733 Mdot
.77 .43734 Mdot
.77 .43779 Mdot
.77 .43782 Mdot
.77 .43822 Mdot
.77 .4383 Mdot
.77 .43843 Mdot
.77 .43848 Mdot
.77 .43879 Mdot
.77 .43882 Mdot
.77 .43932 Mdot
.77 .4396 Mdot
.77 .44024 Mdot
.77 .4403 Mdot
.77 .44083 Mdot
.77 .4412 Mdot
.77 .4414 Mdot
.77 .44169 Mdot
.77 .44205 Mdot
.77 .44242 Mdot
.77 .44246 Mdot
.77 .44255 Mdot
.77 .44274 Mdot
.77 .44283 Mdot
.77 .44311 Mdot
.77 .44325 Mdot
.77 .44344 Mdot
.77 .44357 Mdot
.77 .44384 Mdot
.77 .44407 Mdot
.77 .44433 Mdot
.77 .44506 Mdot
.77 .44568 Mdot
.77 .44589 Mdot
.77 .44618 Mdot
.77 .44622 Mdot
.77 .44639 Mdot
.77 .44651 Mdot
.77 .44698 Mdot
.77 .4473 Mdot
.77 .44736 Mdot
.77 .44742 Mdot
.77 .44765 Mdot
.77 .44796 Mdot
.77 .44819 Mdot
.77 .44831 Mdot
.77 .44835 Mdot
.77 .44866 Mdot
.77 .44884 Mdot
.77 .44891 Mdot
.77 .44895 Mdot
.77 .44928 Mdot
.77 .44929 Mdot
.77 .44929 Mdot
.77 .44956 Mdot
.77 .44978 Mdot
.77 .44987 Mdot
.77 .45012 Mdot
.77 .45038 Mdot
.77 .45051 Mdot
.77 .45072 Mdot
.77 .45099 Mdot
.77 .45105 Mdot
.77 .45128 Mdot
.77 .45176 Mdot
.77 .4522 Mdot
.77 .45248 Mdot
.77 .45257 Mdot
.77 .45335 Mdot
.77 .45335 Mdot
.77 .45378 Mdot
.77 .45416 Mdot
.77 .4547 Mdot
.77 .4551 Mdot
.77 .45537 Mdot
.77 .45577 Mdot
.77 .45638 Mdot
.77 .45648 Mdot
.77 .4565 Mdot
.77 .45656 Mdot
.77 .4567 Mdot
.77 .45686 Mdot
.77 .45699 Mdot
.77 .45716 Mdot
.77 .45774 Mdot
.77 .45825 Mdot
.77 .4588 Mdot
.77 .45885 Mdot
.77 .459 Mdot
.77 .45904 Mdot
.77 .45905 Mdot
.77 .45915 Mdot
.77 .45936 Mdot
.77 .45942 Mdot
.77 .45951 Mdot
.77 .45951 Mdot
.77 .45972 Mdot
.77 .45978 Mdot
.77 .4598 Mdot
.77 .4599 Mdot
.77 .46036 Mdot
.77 .46074 Mdot
.77 .46085 Mdot
.77 .46098 Mdot
.77 .46111 Mdot
.77 .46124 Mdot
.77 .46135 Mdot
.77 .46213 Mdot
.77 .46237 Mdot
.77 .46254 Mdot
.77 .46268 Mdot
.77 .46273 Mdot
.77 .46276 Mdot
.77 .46287 Mdot
.77 .4629 Mdot
.77 .4632 Mdot
.77 .46371 Mdot
.77 .4639 Mdot
.77 .46411 Mdot
.77 .46463 Mdot
.77 .46493 Mdot
.77 .46522 Mdot
.77 .4653 Mdot
.77 .46534 Mdot
.77 .46575 Mdot
.77 .4658 Mdot
.77 .46594 Mdot
.77 .4661 Mdot
.77 .46645 Mdot
.77 .46645 Mdot
.77 .46715 Mdot
.77 .4674 Mdot
.77 .46751 Mdot
.77 .46763 Mdot
.77 .46785 Mdot
.77 .46797 Mdot
.77 .46811 Mdot
.77 .46832 Mdot
.77 .46853 Mdot
.77 .46856 Mdot
.77 .46866 Mdot
.77 .46881 Mdot
.772 .22266 Mdot
.772 .22267 Mdot
.772 .22272 Mdot
.772 .2232 Mdot
.772 .22323 Mdot
.772 .2234 Mdot
.772 .22365 Mdot
.772 .22452 Mdot
.772 .22455 Mdot
.772 .2251 Mdot
.772 .22546 Mdot
.772 .22593 Mdot
.772 .22655 Mdot
.772 .22677 Mdot
.772 .22753 Mdot
.772 .22802 Mdot
.772 .22819 Mdot
.772 .2286 Mdot
.772 .22868 Mdot
.772 .22945 Mdot
.772 .22945 Mdot
.772 .22957 Mdot
.772 .23007 Mdot
.772 .23014 Mdot
.772 .23029 Mdot
.772 .2304 Mdot
.772 .2305 Mdot
.772 .23075 Mdot
.772 .23116 Mdot
.772 .23118 Mdot
.772 .23133 Mdot
.772 .23135 Mdot
.772 .23307 Mdot
.772 .23349 Mdot
.772 .23376 Mdot
.772 .2341 Mdot
.772 .23415 Mdot
.772 .23474 Mdot
.772 .23481 Mdot
.772 .23494 Mdot
.772 .23502 Mdot
.772 .23519 Mdot
.772 .23521 Mdot
.772 .23531 Mdot
.772 .23561 Mdot
.772 .23665 Mdot
.772 .23711 Mdot
.772 .23716 Mdot
.772 .23724 Mdot
.772 .23733 Mdot
.772 .23739 Mdot
.772 .2374 Mdot
.772 .23754 Mdot
.772 .23755 Mdot
.772 .23842 Mdot
.772 .2386 Mdot
.772 .23881 Mdot
.772 .23953 Mdot
.772 .23985 Mdot
.772 .23994 Mdot
.772 .24002 Mdot
.772 .24029 Mdot
.772 .24035 Mdot
.772 .24124 Mdot
.772 .24159 Mdot
.772 .24173 Mdot
.772 .24345 Mdot
.772 .24348 Mdot
.772 .24453 Mdot
.772 .24513 Mdot
.772 .24592 Mdot
.772 .24598 Mdot
.772 .24609 Mdot
.772 .24615 Mdot
.772 .24643 Mdot
.772 .24788 Mdot
.772 .24798 Mdot
.772 .24809 Mdot
.772 .24812 Mdot
.772 .24838 Mdot
.772 .24874 Mdot
.772 .24876 Mdot
.772 .24899 Mdot
.772 .24914 Mdot
.772 .24984 Mdot
.772 .25114 Mdot
.772 .2514 Mdot
.772 .25187 Mdot
.772 .252 Mdot
.772 .25355 Mdot
.772 .25386 Mdot
.772 .25388 Mdot
.772 .25405 Mdot
.772 .25497 Mdot
.772 .25518 Mdot
.772 .25558 Mdot
.772 .25679 Mdot
.772 .25679 Mdot
.772 .25685 Mdot
.772 .25761 Mdot
.772 .2577 Mdot
.772 .25927 Mdot
.772 .25964 Mdot
.772 .2599 Mdot
.772 .26026 Mdot
.772 .26087 Mdot
.772 .26126 Mdot
.772 .26135 Mdot
.772 .26145 Mdot
.772 .26165 Mdot
.772 .26203 Mdot
.772 .26223 Mdot
.772 .26252 Mdot
.772 .26292 Mdot
.772 .26295 Mdot
.772 .26335 Mdot
.772 .26443 Mdot
.772 .2647 Mdot
.772 .26486 Mdot
.772 .26507 Mdot
.772 .26518 Mdot
.772 .26568 Mdot
.772 .26595 Mdot
.772 .26607 Mdot
.772 .26622 Mdot
.772 .26624 Mdot
.772 .26731 Mdot
.772 .26754 Mdot
.772 .26789 Mdot
.772 .26802 Mdot
.772 .26825 Mdot
.772 .26837 Mdot
.772 .26858 Mdot
.772 .26885 Mdot
.772 .26893 Mdot
.772 .26908 Mdot
.772 .26919 Mdot
.772 .26993 Mdot
.772 .26999 Mdot
.772 .27026 Mdot
.772 .27041 Mdot
.772 .27044 Mdot
.772 .27089 Mdot
.772 .27102 Mdot
.772 .27154 Mdot
.772 .27167 Mdot
.772 .27169 Mdot
.772 .27209 Mdot
.772 .27246 Mdot
.772 .27271 Mdot
.772 .27293 Mdot
.772 .2733 Mdot
.772 .27355 Mdot
.772 .27362 Mdot
.772 .27417 Mdot
.772 .27434 Mdot
.772 .27455 Mdot
.772 .27465 Mdot
.772 .27533 Mdot
.772 .27559 Mdot
.772 .27572 Mdot
.772 .27574 Mdot
.772 .27618 Mdot
.772 .27725 Mdot
.772 .27756 Mdot
.772 .27771 Mdot
.772 .27892 Mdot
.772 .27995 Mdot
.772 .28014 Mdot
.772 .28052 Mdot
.772 .28076 Mdot
.772 .28175 Mdot
.772 .28203 Mdot
.772 .28219 Mdot
.772 .28225 Mdot
.772 .28239 Mdot
.772 .28357 Mdot
.772 .28404 Mdot
.772 .28459 Mdot
.772 .28462 Mdot
.772 .28468 Mdot
.772 .2848 Mdot
.772 .28522 Mdot
.772 .28532 Mdot
.772 .28656 Mdot
.772 .28669 Mdot
.772 .28732 Mdot
.772 .28733 Mdot
.772 .28749 Mdot
.772 .28782 Mdot
.772 .28798 Mdot
.772 .28821 Mdot
.772 .28835 Mdot
.772 .2885 Mdot
.772 .28902 Mdot
.772 .28903 Mdot
.772 .28935 Mdot
.772 .28956 Mdot
.772 .28976 Mdot
.772 .29018 Mdot
.772 .29046 Mdot
.772 .29131 Mdot
.772 .29131 Mdot
.772 .29138 Mdot
.772 .29143 Mdot
.772 .29154 Mdot
.772 .29175 Mdot
.772 .2918 Mdot
.772 .29188 Mdot
.772 .29195 Mdot
.772 .29287 Mdot
.772 .29307 Mdot
.772 .29323 Mdot
.772 .29332 Mdot
.772 .29356 Mdot
.772 .29489 Mdot
.772 .29527 Mdot
.772 .29578 Mdot
.772 .29603 Mdot
.772 .29642 Mdot
.772 .29663 Mdot
.772 .29728 Mdot
.772 .29864 Mdot
.772 .29865 Mdot
.772 .2988 Mdot
.772 .29891 Mdot
.772 .29901 Mdot
.772 .29973 Mdot
.772 .29976 Mdot
.772 .29983 Mdot
.772 .30086 Mdot
.772 .30087 Mdot
.772 .30159 Mdot
.772 .30231 Mdot
.772 .30238 Mdot
.772 .30251 Mdot
.772 .30335 Mdot
.772 .30341 Mdot
.772 .30347 Mdot
.772 .30372 Mdot
.772 .30416 Mdot
.772 .30428 Mdot
.772 .30432 Mdot
.772 .30433 Mdot
.772 .30493 Mdot
.772 .30595 Mdot
.772 .3062 Mdot
.772 .30645 Mdot
.772 .30648 Mdot
.772 .30669 Mdot
.772 .30674 Mdot
.772 .30706 Mdot
.772 .3071 Mdot
.772 .30796 Mdot
.772 .30841 Mdot
.772 .30857 Mdot
.772 .30917 Mdot
.772 .30956 Mdot
.772 .30958 Mdot
.772 .30981 Mdot
.772 .31003 Mdot
.772 .31004 Mdot
.772 .31012 Mdot
.772 .31058 Mdot
.772 .3106 Mdot
.772 .31118 Mdot
.772 .31153 Mdot
.772 .31185 Mdot
.772 .31205 Mdot
.772 .31212 Mdot
.772 .31265 Mdot
.772 .313 Mdot
.772 .31305 Mdot
.772 .31309 Mdot
.772 .31337 Mdot
.772 .31338 Mdot
.772 .31345 Mdot
.772 .31417 Mdot
.772 .31435 Mdot
.772 .31461 Mdot
.772 .31462 Mdot
.772 .31487 Mdot
.772 .3149 Mdot
.772 .31495 Mdot
.772 .31499 Mdot
.772 .31587 Mdot
.772 .31589 Mdot
.772 .31596 Mdot
.772 .31599 Mdot
.772 .31605 Mdot
.772 .31642 Mdot
.772 .31649 Mdot
.772 .31658 Mdot
.772 .31705 Mdot
.772 .3172 Mdot
.772 .31722 Mdot
.772 .3176 Mdot
.772 .31774 Mdot
.772 .31898 Mdot
.772 .31923 Mdot
.772 .31959 Mdot
.772 .31978 Mdot
.772 .32043 Mdot
.772 .32047 Mdot
.772 .32091 Mdot
.772 .3212 Mdot
.772 .32175 Mdot
.772 .32186 Mdot
.772 .32206 Mdot
.772 .32289 Mdot
.772 .3229 Mdot
.772 .32344 Mdot
.772 .32412 Mdot
.772 .32415 Mdot
.772 .32447 Mdot
.772 .32516 Mdot
.772 .32532 Mdot
.772 .32543 Mdot
.772 .32558 Mdot
.772 .326 Mdot
.772 .32604 Mdot
.772 .3264 Mdot
.772 .32669 Mdot
.772 .32671 Mdot
.772 .32687 Mdot
.772 .32733 Mdot
.772 .32854 Mdot
.772 .32863 Mdot
.772 .32878 Mdot
.772 .32883 Mdot
.772 .32898 Mdot
.772 .32907 Mdot
.772 .32918 Mdot
.772 .32928 Mdot
.772 .32932 Mdot
.772 .32966 Mdot
.772 .32977 Mdot
.772 .32985 Mdot
.772 .33009 Mdot
.772 .33031 Mdot
.772 .33054 Mdot
.772 .33069 Mdot
.772 .3308 Mdot
.772 .33115 Mdot
.772 .33148 Mdot
.772 .33161 Mdot
.772 .33201 Mdot
.772 .33225 Mdot
.772 .3329 Mdot
.772 .3334 Mdot
.772 .33384 Mdot
.772 .33392 Mdot
.772 .33486 Mdot
.772 .33555 Mdot
.772 .33578 Mdot
.772 .33579 Mdot
.772 .33587 Mdot
.772 .33605 Mdot
.772 .33609 Mdot
.772 .33661 Mdot
.772 .33666 Mdot
.772 .33693 Mdot
.772 .33693 Mdot
.772 .3373 Mdot
.772 .33742 Mdot
.772 .33765 Mdot
.772 .33778 Mdot
.772 .33787 Mdot
.772 .33795 Mdot
.772 .33813 Mdot
.772 .33825 Mdot
.772 .3386 Mdot
.772 .3386 Mdot
.772 .33865 Mdot
.772 .3387 Mdot
.772 .33879 Mdot
.772 .33881 Mdot
.772 .33884 Mdot
.772 .33934 Mdot
.772 .33941 Mdot
.772 .33954 Mdot
.772 .3401 Mdot
.772 .34026 Mdot
.772 .34058 Mdot
.772 .34075 Mdot
.772 .34083 Mdot
.772 .34111 Mdot
.772 .34168 Mdot
.772 .34174 Mdot
.772 .34179 Mdot
.772 .34214 Mdot
.772 .34218 Mdot
.772 .34261 Mdot
.772 .34261 Mdot
.772 .34291 Mdot
.772 .34324 Mdot
.772 .3433 Mdot
.772 .3437 Mdot
.772 .34399 Mdot
.772 .34404 Mdot
.772 .34406 Mdot
.772 .34432 Mdot
.772 .34495 Mdot
.772 .34497 Mdot
.772 .34508 Mdot
.772 .34521 Mdot
.772 .34558 Mdot
.772 .34626 Mdot
.772 .34627 Mdot
.772 .34636 Mdot
.772 .34645 Mdot
.772 .34649 Mdot
.772 .34669 Mdot
.772 .34708 Mdot
.772 .34722 Mdot
.772 .34733 Mdot
.772 .34756 Mdot
.772 .34774 Mdot
.772 .34786 Mdot
.772 .34789 Mdot
.772 .34819 Mdot
.772 .34827 Mdot
.772 .34838 Mdot
.772 .34849 Mdot
.772 .34852 Mdot
.772 .34854 Mdot
.772 .3489 Mdot
.772 .34891 Mdot
.772 .34894 Mdot
.772 .34916 Mdot
.772 .3492 Mdot
.772 .34947 Mdot
.772 .34963 Mdot
.772 .34969 Mdot
.772 .35084 Mdot
.772 .35142 Mdot
.772 .35185 Mdot
.772 .35237 Mdot
.772 .35238 Mdot
.772 .35251 Mdot
.772 .3528 Mdot
.772 .35287 Mdot
.772 .35291 Mdot
.772 .35298 Mdot
.772 .35345 Mdot
.772 .35352 Mdot
.772 .35426 Mdot
.772 .35434 Mdot
.772 .3544 Mdot
.772 .35444 Mdot
.772 .35449 Mdot
.772 .35455 Mdot
.772 .35474 Mdot
.772 .35477 Mdot
.772 .35487 Mdot
.772 .35506 Mdot
.772 .35512 Mdot
.772 .35517 Mdot
.772 .35532 Mdot
.772 .35545 Mdot
.772 .35551 Mdot
.772 .35567 Mdot
.772 .35578 Mdot
.772 .35626 Mdot
.772 .35739 Mdot
.772 .3581 Mdot
.772 .35817 Mdot
.772 .35824 Mdot
.772 .35829 Mdot
.772 .35844 Mdot
.772 .35844 Mdot
.772 .35853 Mdot
.772 .35854 Mdot
.772 .35875 Mdot
.772 .35878 Mdot
.772 .35927 Mdot
.772 .35934 Mdot
.772 .35973 Mdot
.772 .35994 Mdot
.772 .36012 Mdot
.772 .36025 Mdot
.772 .36039 Mdot
.772 .36058 Mdot
.772 .3607 Mdot
.772 .36072 Mdot
.772 .36111 Mdot
.772 .36121 Mdot
.772 .36137 Mdot
.772 .36175 Mdot
.772 .36183 Mdot
.772 .362 Mdot
.772 .36232 Mdot
.772 .36246 Mdot
.772 .36259 Mdot
.772 .36276 Mdot
.772 .363 Mdot
.772 .36307 Mdot
.772 .36309 Mdot
.772 .36357 Mdot
.772 .36421 Mdot
.772 .3644 Mdot
.772 .36447 Mdot
.772 .36501 Mdot
.772 .36504 Mdot
.772 .36507 Mdot
.772 .3651 Mdot
.772 .36522 Mdot
.772 .3656 Mdot
.772 .36668 Mdot
.772 .36676 Mdot
.772 .36711 Mdot
.772 .36714 Mdot
.772 .3673 Mdot
.772 .36766 Mdot
.772 .36771 Mdot
.772 .36788 Mdot
.772 .36792 Mdot
.772 .36815 Mdot
.772 .36858 Mdot
.772 .3687 Mdot
.772 .36891 Mdot
.772 .36918 Mdot
.772 .36926 Mdot
.772 .36953 Mdot
.772 .36954 Mdot
.772 .36977 Mdot
.772 .37022 Mdot
.772 .37041 Mdot
.772 .37048 Mdot
.772 .37083 Mdot
.772 .37107 Mdot
.772 .37115 Mdot
.772 .3717 Mdot
.772 .37178 Mdot
.772 .37196 Mdot
.772 .37206 Mdot
.772 .37209 Mdot
.772 .37249 Mdot
.772 .37321 Mdot
.772 .37382 Mdot
.772 .37388 Mdot
.772 .37403 Mdot
.772 .37431 Mdot
.772 .37443 Mdot
.772 .37472 Mdot
.772 .37487 Mdot
.772 .37505 Mdot
.772 .3751 Mdot
.772 .37527 Mdot
.772 .37541 Mdot
.772 .37549 Mdot
.772 .37577 Mdot
.772 .37605 Mdot
.772 .37609 Mdot
.772 .37632 Mdot
.772 .37642 Mdot
.772 .37644 Mdot
.772 .37667 Mdot
.772 .37672 Mdot
.772 .37742 Mdot
.772 .37774 Mdot
.772 .37777 Mdot
.772 .37778 Mdot
.772 .3782 Mdot
.772 .37832 Mdot
.772 .37873 Mdot
.772 .37906 Mdot
.772 .37926 Mdot
.772 .37975 Mdot
.772 .37991 Mdot
.772 .38016 Mdot
.772 .38026 Mdot
.772 .38033 Mdot
.772 .38059 Mdot
.772 .38067 Mdot
.772 .38089 Mdot
.772 .38109 Mdot
.772 .38122 Mdot
.772 .38148 Mdot
.772 .38152 Mdot
.772 .38206 Mdot
.772 .38219 Mdot
.772 .38347 Mdot
.772 .38385 Mdot
.772 .38396 Mdot
.772 .38399 Mdot
.772 .38425 Mdot
.772 .38444 Mdot
.772 .38462 Mdot
.772 .38467 Mdot
.772 .38471 Mdot
.772 .38477 Mdot
.772 .3856 Mdot
.772 .38567 Mdot
.772 .38571 Mdot
.772 .38599 Mdot
.772 .38599 Mdot
.772 .38661 Mdot
.772 .38698 Mdot
.772 .38772 Mdot
.772 .38776 Mdot
.772 .38787 Mdot
.772 .38823 Mdot
.772 .38847 Mdot
.772 .38848 Mdot
.772 .3885 Mdot
.772 .38857 Mdot
.772 .3887 Mdot
.772 .38891 Mdot
.772 .38941 Mdot
.772 .38967 Mdot
.772 .38975 Mdot
.772 .3898 Mdot
.772 .38988 Mdot
.772 .39038 Mdot
.772 .39063 Mdot
.772 .39078 Mdot
.772 .39138 Mdot
.772 .39142 Mdot
.772 .3916 Mdot
.772 .3919 Mdot
.772 .39211 Mdot
.772 .39231 Mdot
.772 .39231 Mdot
.772 .39259 Mdot
.772 .39287 Mdot
.772 .39292 Mdot
.772 .39328 Mdot
.772 .39352 Mdot
.772 .39362 Mdot
.772 .39383 Mdot
.772 .39438 Mdot
.772 .39443 Mdot
.772 .39475 Mdot
.772 .39477 Mdot
.772 .39479 Mdot
.772 .39491 Mdot
.772 .39491 Mdot
.772 .39514 Mdot
.772 .39521 Mdot
.772 .39533 Mdot
.772 .39538 Mdot
.772 .39544 Mdot
.772 .39553 Mdot
.772 .39567 Mdot
.772 .39599 Mdot
.772 .39653 Mdot
.772 .39656 Mdot
.772 .39688 Mdot
.772 .39733 Mdot
.772 .39794 Mdot
.772 .39799 Mdot
.772 .39827 Mdot
.772 .3986 Mdot
.772 .39902 Mdot
.772 .39918 Mdot
.772 .39943 Mdot
.772 .39952 Mdot
.772 .39973 Mdot
.772 .39996 Mdot
.772 .40003 Mdot
.772 .40013 Mdot
.772 .40028 Mdot
.772 .40042 Mdot
.772 .40058 Mdot
.772 .40063 Mdot
.772 .4007 Mdot
.772 .40092 Mdot
.772 .40095 Mdot
.772 .40101 Mdot
.772 .40108 Mdot
.772 .40114 Mdot
.772 .40123 Mdot
.772 .40127 Mdot
.772 .40136 Mdot
.772 .40143 Mdot
.772 .40221 Mdot
.772 .4025 Mdot
.772 .40261 Mdot
.772 .40262 Mdot
.772 .40281 Mdot
.772 .40304 Mdot
.772 .40307 Mdot
.772 .40334 Mdot
.772 .40344 Mdot
.772 .40351 Mdot
.772 .40361 Mdot
.772 .40406 Mdot
.772 .40427 Mdot
.772 .40428 Mdot
.772 .40472 Mdot
.772 .40507 Mdot
.772 .40508 Mdot
.772 .40562 Mdot
.772 .40575 Mdot
.772 .40582 Mdot
.772 .40617 Mdot
.772 .40636 Mdot
.772 .40665 Mdot
.772 .40668 Mdot
.772 .4071 Mdot
.772 .40722 Mdot
.772 .40745 Mdot
.772 .40762 Mdot
.772 .40841 Mdot
.772 .40851 Mdot
.772 .40875 Mdot
.772 .40877 Mdot
.772 .40886 Mdot
.772 .40917 Mdot
.772 .40923 Mdot
.772 .40927 Mdot
.772 .40951 Mdot
.772 .40955 Mdot
.772 .40957 Mdot
.772 .40962 Mdot
.772 .40963 Mdot
.772 .4102 Mdot
.772 .41022 Mdot
.772 .41026 Mdot
.772 .41027 Mdot
.772 .41044 Mdot
.772 .41045 Mdot
.772 .41061 Mdot
.772 .41073 Mdot
.772 .4112 Mdot
.772 .41124 Mdot
.772 .41125 Mdot
.772 .41143 Mdot
.772 .41145 Mdot
.772 .41149 Mdot
.772 .41171 Mdot
.772 .41206 Mdot
.772 .4121 Mdot
.772 .41223 Mdot
.772 .41244 Mdot
.772 .41267 Mdot
.772 .41304 Mdot
.772 .41305 Mdot
.772 .41336 Mdot
.772 .4134 Mdot
.772 .41341 Mdot
.772 .41356 Mdot
.772 .4137 Mdot
.772 .41371 Mdot
.772 .41397 Mdot
.772 .41436 Mdot
.772 .41446 Mdot
.772 .41475 Mdot
.772 .41531 Mdot
.772 .41533 Mdot
.772 .41554 Mdot
.772 .41558 Mdot
.772 .41571 Mdot
.772 .41573 Mdot
.772 .41589 Mdot
.772 .41605 Mdot
.772 .41671 Mdot
.772 .4171 Mdot
.772 .41711 Mdot
.772 .41714 Mdot
.772 .41722 Mdot
.772 .4175 Mdot
.772 .41766 Mdot
.772 .4177 Mdot
.772 .41774 Mdot
.772 .41828 Mdot
.772 .41837 Mdot
.772 .41841 Mdot
.772 .41888 Mdot
.772 .41935 Mdot
.772 .41935 Mdot
.772 .42002 Mdot
.772 .42006 Mdot
.772 .42008 Mdot
.772 .42055 Mdot
.772 .42062 Mdot
.772 .42069 Mdot
.772 .42078 Mdot
.772 .42079 Mdot
.772 .42167 Mdot
.772 .42209 Mdot
.772 .42223 Mdot
.772 .42248 Mdot
.772 .42264 Mdot
.772 .42297 Mdot
.772 .42322 Mdot
.772 .42408 Mdot
.772 .42424 Mdot
.772 .42429 Mdot
.772 .42439 Mdot
.772 .42453 Mdot
.772 .42512 Mdot
.772 .42516 Mdot
.772 .42522 Mdot
.772 .42525 Mdot
.772 .42539 Mdot
.772 .42546 Mdot
.772 .42549 Mdot
.772 .42553 Mdot
.772 .42554 Mdot
.772 .42608 Mdot
.772 .42627 Mdot
.772 .42654 Mdot
.772 .42667 Mdot
.772 .4268 Mdot
.772 .42701 Mdot
.772 .42702 Mdot
.772 .42736 Mdot
.772 .42746 Mdot
.772 .42754 Mdot
.772 .42769 Mdot
.772 .42779 Mdot
.772 .42801 Mdot
.772 .42811 Mdot
.772 .42812 Mdot
.772 .42853 Mdot
.772 .42861 Mdot
.772 .42942 Mdot
.772 .42948 Mdot
.772 .42975 Mdot
.772 .42983 Mdot
.772 .42987 Mdot
.772 .42989 Mdot
.772 .43025 Mdot
.772 .43055 Mdot
.772 .43131 Mdot
.772 .4314 Mdot
.772 .43144 Mdot
.772 .43154 Mdot
.772 .43173 Mdot
.772 .43237 Mdot
.772 .43252 Mdot
.772 .43277 Mdot
.772 .43289 Mdot
.772 .43356 Mdot
.772 .43434 Mdot
.772 .43444 Mdot
.772 .43464 Mdot
.772 .43534 Mdot
.772 .43562 Mdot
.772 .43564 Mdot
.772 .43572 Mdot
.772 .43589 Mdot
.772 .43633 Mdot
.772 .43639 Mdot
.772 .43653 Mdot
.772 .43664 Mdot
.772 .437 Mdot
.772 .43704 Mdot
.772 .4372 Mdot
.772 .43744 Mdot
.772 .43759 Mdot
.772 .43775 Mdot
.772 .43798 Mdot
.772 .43824 Mdot
.772 .43826 Mdot
.772 .43834 Mdot
.772 .43868 Mdot
.772 .43876 Mdot
.772 .43905 Mdot
.772 .43907 Mdot
.772 .43917 Mdot
.772 .43934 Mdot
.772 .43938 Mdot
.772 .43987 Mdot
.772 .43993 Mdot
.772 .44003 Mdot
.772 .44008 Mdot
.772 .44026 Mdot
.772 .44039 Mdot
.772 .44047 Mdot
.772 .44062 Mdot
.772 .4407 Mdot
.772 .44093 Mdot
.772 .44108 Mdot
.772 .44177 Mdot
.772 .44178 Mdot
.772 .44188 Mdot
.772 .44196 Mdot
.772 .44213 Mdot
.772 .44246 Mdot
.772 .44253 Mdot
.772 .44266 Mdot
.772 .44277 Mdot
.772 .44294 Mdot
.772 .44365 Mdot
.772 .4439 Mdot
.772 .44392 Mdot
.772 .44418 Mdot
.772 .44437 Mdot
.772 .4445 Mdot
.772 .44474 Mdot
.772 .44488 Mdot
.772 .44494 Mdot
.772 .445 Mdot
.772 .44525 Mdot
.772 .44565 Mdot
.772 .44588 Mdot
.772 .44605 Mdot
.772 .44629 Mdot
.772 .44731 Mdot
.772 .44736 Mdot
.772 .44785 Mdot
.772 .44789 Mdot
.772 .4479 Mdot
.772 .44868 Mdot
.772 .44894 Mdot
.772 .44907 Mdot
.772 .44967 Mdot
.772 .44978 Mdot
.772 .44979 Mdot
.772 .44999 Mdot
.772 .45099 Mdot
.772 .45108 Mdot
.772 .45138 Mdot
.772 .45155 Mdot
.772 .4524 Mdot
.772 .45285 Mdot
.772 .45309 Mdot
.772 .45311 Mdot
.772 .45334 Mdot
.772 .45351 Mdot
.772 .45353 Mdot
.772 .4536 Mdot
.772 .45366 Mdot
.772 .4546 Mdot
.772 .45478 Mdot
.772 .45482 Mdot
.772 .4549 Mdot
.772 .45493 Mdot
.772 .45544 Mdot
.772 .45584 Mdot
.772 .45652 Mdot
.772 .45653 Mdot
.772 .45765 Mdot
.772 .45774 Mdot
.772 .45796 Mdot
.772 .45854 Mdot
.772 .45858 Mdot
.772 .45875 Mdot
.772 .45881 Mdot
.772 .45887 Mdot
.772 .45907 Mdot
.772 .45954 Mdot
.772 .45968 Mdot
.772 .45979 Mdot
.772 .46035 Mdot
.772 .46036 Mdot
.772 .46045 Mdot
.772 .46046 Mdot
.772 .46049 Mdot
.772 .46056 Mdot
.772 .46061 Mdot
.772 .46064 Mdot
.772 .46094 Mdot
.772 .46161 Mdot
.772 .4618 Mdot
.772 .46187 Mdot
.772 .46189 Mdot
.772 .46199 Mdot
.772 .46205 Mdot
.772 .46213 Mdot
.772 .46217 Mdot
.772 .46256 Mdot
.772 .46259 Mdot
.772 .46281 Mdot
.772 .46298 Mdot
.772 .46326 Mdot
.772 .46437 Mdot
.772 .46438 Mdot
.772 .46448 Mdot
.772 .46449 Mdot
.772 .46476 Mdot
.772 .46492 Mdot
.772 .46498 Mdot
.772 .46506 Mdot
.772 .46515 Mdot
.772 .4652 Mdot
.772 .46552 Mdot
.772 .4656 Mdot
.772 .4656 Mdot
.772 .4661 Mdot
.772 .46615 Mdot
.772 .46642 Mdot
.772 .46653 Mdot
.772 .46684 Mdot
.772 .46733 Mdot
.772 .46748 Mdot
.772 .46788 Mdot
.772 .46819 Mdot
.772 .46842 Mdot
.772 .46877 Mdot
.772 .46879 Mdot
.772 .46936 Mdot
.772 .46952 Mdot
.772 .46963 Mdot
.772 .46965 Mdot
.772 .46996 Mdot
.772 .46999 Mdot
.772 .47 Mdot
.774 .22126 Mdot
.774 .22174 Mdot
.774 .22235 Mdot
.774 .22237 Mdot
.774 .22252 Mdot
.774 .22257 Mdot
.774 .22299 Mdot
.774 .22314 Mdot
.774 .22347 Mdot
.774 .22369 Mdot
.774 .22446 Mdot
.774 .22447 Mdot
.774 .22458 Mdot
.774 .22467 Mdot
.774 .22474 Mdot
.774 .22543 Mdot
.774 .22564 Mdot
.774 .2258 Mdot
.774 .22642 Mdot
.774 .22685 Mdot
.774 .22696 Mdot
.774 .22729 Mdot
.774 .22788 Mdot
.774 .22862 Mdot
.774 .22929 Mdot
.774 .22938 Mdot
.774 .22942 Mdot
.774 .22954 Mdot
.774 .23067 Mdot
.774 .23116 Mdot
.774 .23132 Mdot
.774 .23135 Mdot
.774 .23172 Mdot
.774 .23238 Mdot
.774 .23258 Mdot
.774 .23291 Mdot
.774 .23308 Mdot
.774 .23404 Mdot
.774 .2344 Mdot
.774 .23464 Mdot
.774 .23576 Mdot
.774 .23663 Mdot
.774 .23749 Mdot
.774 .23765 Mdot
.774 .23788 Mdot
.774 .23807 Mdot
.774 .23832 Mdot
.774 .23856 Mdot
.774 .23872 Mdot
.774 .23895 Mdot
.774 .23895 Mdot
.774 .23896 Mdot
.774 .239 Mdot
.774 .23921 Mdot
.774 .23927 Mdot
.774 .24008 Mdot
.774 .24042 Mdot
.774 .24059 Mdot
.774 .24063 Mdot
.774 .24086 Mdot
.774 .24159 Mdot
.774 .24161 Mdot
.774 .24266 Mdot
.774 .24284 Mdot
.774 .24293 Mdot
.774 .24325 Mdot
.774 .24329 Mdot
.774 .24344 Mdot
.774 .24351 Mdot
.774 .24366 Mdot
.774 .24391 Mdot
.774 .24461 Mdot
.774 .24483 Mdot
.774 .24519 Mdot
.774 .24536 Mdot
.774 .24688 Mdot
.774 .24743 Mdot
.774 .24748 Mdot
.774 .24818 Mdot
.774 .24888 Mdot
.774 .24905 Mdot
.774 .2498 Mdot
.774 .24984 Mdot
.774 .2509 Mdot
.774 .25116 Mdot
.774 .25137 Mdot
.774 .2516 Mdot
.774 .25165 Mdot
.774 .25186 Mdot
.774 .25205 Mdot
.774 .25231 Mdot
.774 .25233 Mdot
.774 .25242 Mdot
.774 .2527 Mdot
.774 .2532 Mdot
.774 .25342 Mdot
.774 .25368 Mdot
.774 .25401 Mdot
.774 .25419 Mdot
.774 .25451 Mdot
.774 .25507 Mdot
.774 .25512 Mdot
.774 .25534 Mdot
.774 .25568 Mdot
.774 .25603 Mdot
.774 .25624 Mdot
.774 .25762 Mdot
.774 .25827 Mdot
.774 .25862 Mdot
.774 .25955 Mdot
.774 .26003 Mdot
.774 .2603 Mdot
.774 .26077 Mdot
.774 .26099 Mdot
.774 .26175 Mdot
.774 .26208 Mdot
.774 .26229 Mdot
.774 .26277 Mdot
.774 .26281 Mdot
.774 .26282 Mdot
.774 .26343 Mdot
.774 .26395 Mdot
.774 .26397 Mdot
.774 .26413 Mdot
.774 .26454 Mdot
.774 .26527 Mdot
.774 .26637 Mdot
.774 .26773 Mdot
.774 .26815 Mdot
.774 .2686 Mdot
.774 .26864 Mdot
.774 .2688 Mdot
.774 .26887 Mdot
.774 .26957 Mdot
.774 .26962 Mdot
.774 .26973 Mdot
.774 .26988 Mdot
.774 .27048 Mdot
.774 .27073 Mdot
.774 .27098 Mdot
.774 .27142 Mdot
.774 .27155 Mdot
.774 .27165 Mdot
.774 .27173 Mdot
.774 .2718 Mdot
.774 .27194 Mdot
.774 .27249 Mdot
.774 .27375 Mdot
.774 .27417 Mdot
.774 .27418 Mdot
.774 .27451 Mdot
.774 .27451 Mdot
.774 .27458 Mdot
.774 .27543 Mdot
.774 .2758 Mdot
.774 .27584 Mdot
.774 .27603 Mdot
.774 .27648 Mdot
.774 .27653 Mdot
.774 .27759 Mdot
.774 .278 Mdot
.774 .27805 Mdot
.774 .27832 Mdot
.774 .27964 Mdot
.774 .27986 Mdot
.774 .27999 Mdot
.774 .2801 Mdot
.774 .28042 Mdot
.774 .281 Mdot
.774 .28103 Mdot
.774 .28137 Mdot
.774 .28154 Mdot
.774 .28158 Mdot
.774 .28219 Mdot
.774 .28225 Mdot
.774 .28229 Mdot
.774 .28416 Mdot
.774 .28446 Mdot
.774 .28448 Mdot
.774 .28455 Mdot
.774 .28508 Mdot
.774 .28527 Mdot
.774 .28659 Mdot
.774 .28678 Mdot
.774 .28686 Mdot
.774 .28688 Mdot
.774 .28703 Mdot
.774 .28741 Mdot
.774 .28755 Mdot
.774 .28826 Mdot
.774 .28849 Mdot
.774 .28854 Mdot
.774 .28857 Mdot
.774 .28861 Mdot
.774 .28899 Mdot
.774 .28941 Mdot
.774 .28945 Mdot
.774 .28948 Mdot
.774 .28977 Mdot
.774 .28979 Mdot
.774 .28986 Mdot
.774 .28988 Mdot
.774 .29127 Mdot
.774 .29204 Mdot
.774 .29229 Mdot
.774 .29229 Mdot
.774 .29231 Mdot
.774 .29251 Mdot
.774 .2926 Mdot
.774 .29274 Mdot
.774 .29306 Mdot
.774 .29315 Mdot
.774 .29334 Mdot
.774 .29346 Mdot
.774 .29405 Mdot
.774 .29527 Mdot
.774 .29541 Mdot
.774 .29589 Mdot
.774 .29597 Mdot
.774 .29631 Mdot
.774 .29652 Mdot
.774 .29667 Mdot
.774 .29668 Mdot
.774 .29679 Mdot
.774 .29695 Mdot
.774 .29707 Mdot
.774 .29726 Mdot
.774 .29804 Mdot
.774 .29869 Mdot
.774 .29894 Mdot
.774 .29958 Mdot
.774 .29965 Mdot
.774 .30035 Mdot
.774 .30046 Mdot
.774 .30059 Mdot
.774 .30063 Mdot
.774 .30071 Mdot
.774 .30115 Mdot
.774 .30157 Mdot
.774 .30178 Mdot
.774 .30215 Mdot
.774 .30223 Mdot
.774 .30225 Mdot
.774 .30235 Mdot
.774 .30262 Mdot
.774 .3027 Mdot
.774 .30279 Mdot
.774 .30322 Mdot
.774 .30415 Mdot
.774 .30477 Mdot
.774 .30499 Mdot
.774 .30527 Mdot
.774 .30542 Mdot
.774 .30543 Mdot
.774 .30571 Mdot
.774 .30618 Mdot
.774 .30623 Mdot
.774 .30625 Mdot
.774 .30726 Mdot
.774 .30774 Mdot
.774 .30789 Mdot
.774 .30818 Mdot
.774 .30821 Mdot
.774 .3083 Mdot
.774 .30862 Mdot
.774 .30909 Mdot
.774 .30917 Mdot
.774 .30964 Mdot
.774 .30996 Mdot
.774 .31021 Mdot
.774 .31028 Mdot
.774 .31048 Mdot
.774 .31054 Mdot
.774 .31068 Mdot
.774 .3111 Mdot
.774 .31114 Mdot
.774 .31159 Mdot
.774 .31191 Mdot
.774 .31209 Mdot
.774 .31227 Mdot
.774 .31252 Mdot
.774 .31283 Mdot
.774 .31311 Mdot
.774 .31389 Mdot
.774 .31448 Mdot
.774 .31469 Mdot
.774 .31509 Mdot
.774 .31534 Mdot
.774 .31581 Mdot
.774 .31653 Mdot
.774 .31688 Mdot
.774 .31698 Mdot
.774 .31714 Mdot
.774 .31714 Mdot
.774 .31728 Mdot
.774 .31775 Mdot
.774 .31784 Mdot
.774 .31794 Mdot
.774 .31825 Mdot
.774 .31895 Mdot
.774 .31901 Mdot
.774 .31911 Mdot
.774 .31921 Mdot
.774 .3195 Mdot
.774 .3196 Mdot
.774 .32068 Mdot
.774 .32099 Mdot
.774 .32128 Mdot
.774 .32167 Mdot
.774 .32168 Mdot
.774 .32223 Mdot
.774 .32242 Mdot
.774 .32253 Mdot
.774 .32276 Mdot
.774 .32318 Mdot
.774 .32329 Mdot
.774 .32363 Mdot
.774 .32387 Mdot
.774 .32389 Mdot
.774 .32427 Mdot
.774 .32435 Mdot
.774 .32493 Mdot
.774 .3252 Mdot
.774 .32574 Mdot
.774 .32757 Mdot
.774 .32758 Mdot
.774 .32765 Mdot
.774 .32782 Mdot
.774 .32858 Mdot
.774 .32915 Mdot
.774 .32932 Mdot
.774 .33005 Mdot
.774 .3303 Mdot
.774 .33051 Mdot
.774 .33069 Mdot
.774 .33074 Mdot
.774 .33166 Mdot
.774 .33184 Mdot
.774 .33198 Mdot
.774 .33201 Mdot
.774 .33282 Mdot
.774 .33327 Mdot
.774 .33344 Mdot
.774 .33346 Mdot
.774 .33357 Mdot
.774 .33421 Mdot
.774 .33427 Mdot
.774 .33445 Mdot
.774 .33469 Mdot
.774 .3347 Mdot
.774 .33518 Mdot
.774 .33521 Mdot
.774 .33601 Mdot
.774 .33613 Mdot
.774 .33614 Mdot
.774 .33617 Mdot
.774 .33639 Mdot
.774 .33647 Mdot
.774 .33702 Mdot
.774 .33713 Mdot
.774 .33736 Mdot
.774 .33742 Mdot
.774 .33772 Mdot
.774 .33784 Mdot
.774 .33786 Mdot
.774 .3382 Mdot
.774 .33822 Mdot
.774 .33823 Mdot
.774 .33835 Mdot
.774 .33839 Mdot
.774 .3394 Mdot
.774 .33941 Mdot
.774 .33949 Mdot
.774 .33959 Mdot
.774 .33972 Mdot
.774 .33984 Mdot
.774 .33989 Mdot
.774 .34013 Mdot
.774 .34064 Mdot
.774 .3409 Mdot
.774 .34093 Mdot
.774 .34116 Mdot
.774 .34123 Mdot
.774 .34123 Mdot
.774 .34128 Mdot
.774 .34148 Mdot
.774 .34207 Mdot
.774 .34218 Mdot
.774 .34244 Mdot
.774 .34247 Mdot
.774 .34276 Mdot
.774 .34281 Mdot
.774 .34288 Mdot
.774 .3431 Mdot
.774 .34327 Mdot
.774 .34351 Mdot
.774 .34356 Mdot
.774 .34371 Mdot
.774 .34374 Mdot
.774 .34378 Mdot
.774 .34435 Mdot
.774 .34461 Mdot
.774 .3447 Mdot
.774 .345 Mdot
.774 .3452 Mdot
.774 .34585 Mdot
.774 .34591 Mdot
.774 .34603 Mdot
.774 .34604 Mdot
.774 .34608 Mdot
.774 .34621 Mdot
.774 .34641 Mdot
.774 .34644 Mdot
.774 .34664 Mdot
.774 .34677 Mdot
.774 .34688 Mdot
.774 .34699 Mdot
.774 .34702 Mdot
.774 .34707 Mdot
.774 .34725 Mdot
.774 .34727 Mdot
.774 .34809 Mdot
.774 .34875 Mdot
.774 .34902 Mdot
.774 .34921 Mdot
.774 .3497 Mdot
.774 .34977 Mdot
.774 .35003 Mdot
.774 .35006 Mdot
.774 .3501 Mdot
.774 .35023 Mdot
.774 .35055 Mdot
.774 .35063 Mdot
.774 .35138 Mdot
.774 .3515 Mdot
.774 .35166 Mdot
.774 .3519 Mdot
.774 .35197 Mdot
.774 .35202 Mdot
.774 .35212 Mdot
.774 .35229 Mdot
.774 .35233 Mdot
.774 .35248 Mdot
.774 .35258 Mdot
.774 .35259 Mdot
.774 .35275 Mdot
.774 .35278 Mdot
.774 .35313 Mdot
.774 .35336 Mdot
.774 .35413 Mdot
.774 .35416 Mdot
.774 .35423 Mdot
.774 .35455 Mdot
.774 .35478 Mdot
.774 .35516 Mdot
.774 .35535 Mdot
.774 .35583 Mdot
.774 .3559 Mdot
.774 .35597 Mdot
.774 .35631 Mdot
.774 .3565 Mdot
.774 .35689 Mdot
.774 .35692 Mdot
.774 .35709 Mdot
.774 .3577 Mdot
.774 .35807 Mdot
.774 .35823 Mdot
.774 .35836 Mdot
.774 .35856 Mdot
.774 .35857 Mdot
.774 .35864 Mdot
.774 .35926 Mdot
.774 .35958 Mdot
.774 .3597 Mdot
.774 .35979 Mdot
.774 .35982 Mdot
.774 .36017 Mdot
.774 .36022 Mdot
.774 .36034 Mdot
.774 .36046 Mdot
.774 .36048 Mdot
.774 .36051 Mdot
.774 .36079 Mdot
.774 .36086 Mdot
.774 .36087 Mdot
.774 .36123 Mdot
.774 .3614 Mdot
.774 .36148 Mdot
.774 .36183 Mdot
.774 .36183 Mdot
.774 .36185 Mdot
.774 .3619 Mdot
.774 .36198 Mdot
.774 .362 Mdot
.774 .36208 Mdot
.774 .36214 Mdot
.774 .36223 Mdot
.774 .36233 Mdot
.774 .36268 Mdot
.774 .36296 Mdot
.774 .36353 Mdot
.774 .36358 Mdot
.774 .36411 Mdot
.774 .36437 Mdot
.774 .36444 Mdot
.774 .36446 Mdot
.774 .36456 Mdot
.774 .36456 Mdot
.774 .36464 Mdot
.774 .36479 Mdot
.774 .36522 Mdot
.774 .36592 Mdot
.774 .36595 Mdot
.774 .36612 Mdot
.774 .36637 Mdot
.774 .36644 Mdot
.774 .36685 Mdot
.774 .36705 Mdot
.774 .36757 Mdot
.774 .36786 Mdot
.774 .36787 Mdot
.774 .36799 Mdot
.774 .36848 Mdot
.774 .36852 Mdot
.774 .36855 Mdot
.774 .36878 Mdot
.774 .36889 Mdot
.774 .36913 Mdot
.774 .36952 Mdot
.774 .36956 Mdot
.774 .36983 Mdot
.774 .37021 Mdot
.774 .37031 Mdot
.774 .3706 Mdot
.774 .37094 Mdot
.774 .37149 Mdot
.774 .37164 Mdot
.774 .37176 Mdot
.774 .3741 Mdot
.774 .37496 Mdot
.774 .37503 Mdot
.774 .37527 Mdot
.774 .37545 Mdot
.774 .37569 Mdot
.774 .37612 Mdot
.774 .37654 Mdot
.774 .37707 Mdot
.774 .3772 Mdot
.774 .37746 Mdot
.774 .37751 Mdot
.774 .37767 Mdot
.774 .37826 Mdot
.774 .37863 Mdot
.774 .37868 Mdot
.774 .37868 Mdot
.774 .37875 Mdot
.774 .37935 Mdot
.774 .37971 Mdot
.774 .37989 Mdot
.774 .38025 Mdot
.774 .38028 Mdot
.774 .38033 Mdot
.774 .38034 Mdot
.774 .38072 Mdot
.774 .38106 Mdot
.774 .38111 Mdot
.774 .3813 Mdot
.774 .38131 Mdot
.774 .38141 Mdot
.774 .38148 Mdot
.774 .38176 Mdot
.774 .38182 Mdot
.774 .3821 Mdot
.774 .38251 Mdot
.774 .38255 Mdot
.774 .38256 Mdot
.774 .38269 Mdot
.774 .38287 Mdot
.774 .38311 Mdot
.774 .3835 Mdot
.774 .38362 Mdot
.774 .38389 Mdot
.774 .38401 Mdot
.774 .38423 Mdot
.774 .38427 Mdot
.774 .38432 Mdot
.774 .38463 Mdot
.774 .38515 Mdot
.774 .3854 Mdot
.774 .38542 Mdot
.774 .38592 Mdot
.774 .38606 Mdot
.774 .38629 Mdot
.774 .38642 Mdot
.774 .38642 Mdot
.774 .38658 Mdot
.774 .38661 Mdot
.774 .38672 Mdot
.774 .38678 Mdot
.774 .38686 Mdot
.774 .38712 Mdot
.774 .3872 Mdot
.774 .38773 Mdot
.774 .38794 Mdot
.774 .38802 Mdot
.774 .38828 Mdot
.774 .38859 Mdot
.774 .38889 Mdot
.774 .38932 Mdot
.774 .38986 Mdot
.774 .39003 Mdot
.774 .39017 Mdot
.774 .39026 Mdot
.774 .39038 Mdot
.774 .3904 Mdot
.774 .39053 Mdot
.774 .39062 Mdot
.774 .39064 Mdot
.774 .39065 Mdot
.774 .39073 Mdot
.774 .39119 Mdot
.774 .39132 Mdot
.774 .39157 Mdot
.774 .39174 Mdot
.774 .39213 Mdot
.774 .39215 Mdot
.774 .39225 Mdot
.774 .39228 Mdot
.774 .39269 Mdot
.774 .39273 Mdot
.774 .39276 Mdot
.774 .39295 Mdot
.774 .39314 Mdot
.774 .39321 Mdot
.774 .39372 Mdot
.774 .39375 Mdot
.774 .39379 Mdot
.774 .39394 Mdot
.774 .39413 Mdot
.774 .39446 Mdot
.774 .39462 Mdot
.774 .39487 Mdot
.774 .39559 Mdot
.774 .39561 Mdot
.774 .39569 Mdot
.774 .39571 Mdot
.774 .39594 Mdot
.774 .39602 Mdot
.774 .39621 Mdot
.774 .39647 Mdot
.774 .39704 Mdot
.774 .39712 Mdot
.774 .39764 Mdot
.774 .39797 Mdot
.774 .39798 Mdot
.774 .39825 Mdot
.774 .39828 Mdot
.774 .3987 Mdot
.774 .39877 Mdot
.774 .39879 Mdot
.774 .39889 Mdot
.774 .39918 Mdot
.774 .39971 Mdot
.774 .39973 Mdot
.774 .39982 Mdot
.774 .39993 Mdot
.774 .40052 Mdot
.774 .40056 Mdot
.774 .40068 Mdot
.774 .40081 Mdot
.774 .40098 Mdot
.774 .40144 Mdot
.774 .40155 Mdot
.774 .40192 Mdot
.774 .40241 Mdot
.774 .40252 Mdot
.774 .40257 Mdot
.774 .40257 Mdot
.774 .40376 Mdot
.774 .4041 Mdot
.774 .40428 Mdot
.774 .40465 Mdot
.774 .40471 Mdot
.774 .40495 Mdot
.774 .40497 Mdot
.774 .40512 Mdot
.774 .40534 Mdot
.774 .40541 Mdot
.774 .40568 Mdot
.774 .40583 Mdot
.774 .4059 Mdot
.774 .40602 Mdot
.774 .40638 Mdot
.774 .40639 Mdot
.774 .40664 Mdot
.774 .40682 Mdot
.774 .40703 Mdot
.774 .40773 Mdot
.774 .40779 Mdot
.774 .40797 Mdot
.774 .40804 Mdot
.774 .4081 Mdot
.774 .40814 Mdot
.774 .4086 Mdot
.774 .4088 Mdot
.774 .40886 Mdot
.774 .40892 Mdot
.774 .40923 Mdot
.774 .40931 Mdot
.774 .40931 Mdot
.774 .40942 Mdot
.774 .40948 Mdot
.774 .40971 Mdot
.774 .41017 Mdot
.774 .41048 Mdot
.774 .41064 Mdot
.774 .41089 Mdot
.774 .41103 Mdot
.774 .41141 Mdot
.774 .41192 Mdot
.774 .4121 Mdot
.774 .4123 Mdot
.774 .41246 Mdot
.774 .41258 Mdot
.774 .41269 Mdot
.774 .4129 Mdot
.774 .41319 Mdot
.774 .41322 Mdot
.774 .41349 Mdot
.774 .41357 Mdot
.774 .41361 Mdot
.774 .41374 Mdot
.774 .41379 Mdot
.774 .41395 Mdot
.774 .41416 Mdot
.774 .41446 Mdot
.774 .41451 Mdot
.774 .41482 Mdot
.774 .41502 Mdot
.774 .41508 Mdot
.774 .4151 Mdot
.774 .41529 Mdot
.774 .41539 Mdot
.774 .4157 Mdot
.774 .41635 Mdot
.774 .41636 Mdot
.774 .41639 Mdot
.774 .4167 Mdot
.774 .41687 Mdot
.774 .41688 Mdot
.774 .41698 Mdot
.774 .41716 Mdot
.774 .4173 Mdot
.774 .4177 Mdot
.774 .4183 Mdot
.774 .41858 Mdot
.774 .41864 Mdot
.774 .41869 Mdot
.774 .41887 Mdot
.774 .41893 Mdot
.774 .41894 Mdot
.774 .419 Mdot
.774 .41923 Mdot
.774 .41937 Mdot
.774 .41964 Mdot
.774 .41993 Mdot
.774 .41998 Mdot
.774 .42 Mdot
.774 .42009 Mdot
.774 .42016 Mdot
.774 .42061 Mdot
.774 .42066 Mdot
.774 .42107 Mdot
.774 .42123 Mdot
.774 .42165 Mdot
.774 .42215 Mdot
.774 .42228 Mdot
.774 .42235 Mdot
.774 .42246 Mdot
.774 .42253 Mdot
.774 .42254 Mdot
.774 .42264 Mdot
.774 .42277 Mdot
.774 .42299 Mdot
.774 .42304 Mdot
.774 .42344 Mdot
.774 .42423 Mdot
.774 .42461 Mdot
.774 .42468 Mdot
.774 .42481 Mdot
.774 .42487 Mdot
.774 .42508 Mdot
.774 .42517 Mdot
.774 .42522 Mdot
.774 .42535 Mdot
.774 .42536 Mdot
.774 .42537 Mdot
.774 .42553 Mdot
.774 .42603 Mdot
.774 .42692 Mdot
.774 .42693 Mdot
.774 .42698 Mdot
.774 .427 Mdot
.774 .42718 Mdot
.774 .4272 Mdot
.774 .42723 Mdot
.774 .4275 Mdot
.774 .42775 Mdot
.774 .42777 Mdot
.774 .42779 Mdot
.774 .42782 Mdot
.774 .42797 Mdot
.774 .42843 Mdot
.774 .42852 Mdot
.774 .42876 Mdot
.774 .42886 Mdot
.774 .42888 Mdot
.774 .42893 Mdot
.774 .42905 Mdot
.774 .4299 Mdot
.774 .43002 Mdot
.774 .43037 Mdot
.774 .43041 Mdot
.774 .43042 Mdot
.774 .43061 Mdot
.774 .43182 Mdot
.774 .43185 Mdot
.774 .43189 Mdot
.774 .43228 Mdot
.774 .43231 Mdot
.774 .43242 Mdot
.774 .43264 Mdot
.774 .43266 Mdot
.774 .43303 Mdot
.774 .43324 Mdot
.774 .43331 Mdot
.774 .43339 Mdot
.774 .43354 Mdot
.774 .43439 Mdot
.774 .43457 Mdot
.774 .4346 Mdot
.774 .43486 Mdot
.774 .43555 Mdot
.774 .43558 Mdot
.774 .43587 Mdot
.774 .43599 Mdot
.774 .43602 Mdot
.774 .43626 Mdot
.774 .43681 Mdot
.774 .43685 Mdot
.774 .43685 Mdot
.774 .43707 Mdot
.774 .43707 Mdot
.774 .43734 Mdot
.774 .43816 Mdot
.774 .43851 Mdot
.774 .4386 Mdot
.774 .43865 Mdot
.774 .4387 Mdot
.774 .43876 Mdot
.774 .43885 Mdot
.774 .43913 Mdot
.774 .43929 Mdot
.774 .43946 Mdot
.774 .43984 Mdot
.774 .43994 Mdot
.774 .44001 Mdot
.774 .44005 Mdot
.774 .4405 Mdot
.774 .44054 Mdot
.774 .44065 Mdot
.774 .44067 Mdot
.774 .44096 Mdot
.774 .44123 Mdot
.774 .44211 Mdot
.774 .44282 Mdot
.774 .44329 Mdot
.774 .44356 Mdot
.774 .44366 Mdot
.774 .44368 Mdot
.774 .44401 Mdot
.774 .4444 Mdot
.774 .44441 Mdot
.774 .44444 Mdot
.774 .44474 Mdot
.774 .44488 Mdot
.774 .4451 Mdot
.774 .44559 Mdot
.774 .44573 Mdot
.774 .44603 Mdot
.774 .44621 Mdot
.774 .44652 Mdot
.774 .44712 Mdot
.774 .44734 Mdot
.774 .44776 Mdot
.774 .44866 Mdot
.774 .44879 Mdot
.774 .44902 Mdot
.774 .44924 Mdot
.774 .44938 Mdot
.774 .44941 Mdot
.774 .44977 Mdot
.774 .44998 Mdot
.774 .45009 Mdot
.774 .45031 Mdot
.774 .45048 Mdot
.774 .45062 Mdot
.774 .45094 Mdot
.774 .45112 Mdot
.774 .45118 Mdot
.774 .4512 Mdot
.774 .45136 Mdot
.774 .45148 Mdot
.774 .45162 Mdot
.774 .45165 Mdot
.774 .4518 Mdot
.774 .45194 Mdot
.774 .4521 Mdot
.774 .45279 Mdot
.774 .45281 Mdot
.774 .4533 Mdot
.774 .45341 Mdot
.774 .45386 Mdot
.774 .45431 Mdot
.774 .45434 Mdot
.774 .4547 Mdot
.774 .45568 Mdot
.774 .45579 Mdot
.774 .45602 Mdot
.774 .45616 Mdot
.774 .45662 Mdot
.774 .45678 Mdot
.774 .45688 Mdot
.774 .45692 Mdot
.774 .45702 Mdot
.774 .45705 Mdot
.774 .45725 Mdot
.774 .45731 Mdot
.774 .45743 Mdot
.774 .45811 Mdot
.774 .45812 Mdot
.774 .45859 Mdot
.774 .45874 Mdot
.774 .45877 Mdot
.774 .45887 Mdot
.774 .45909 Mdot
.774 .45961 Mdot
.774 .45966 Mdot
.774 .45979 Mdot
.774 .45982 Mdot
.774 .45982 Mdot
.774 .45983 Mdot
.774 .45997 Mdot
.774 .46007 Mdot
.774 .46023 Mdot
.774 .46039 Mdot
.774 .46051 Mdot
.774 .46066 Mdot
.774 .46076 Mdot
.774 .46132 Mdot
.774 .46188 Mdot
.774 .46261 Mdot
.774 .46277 Mdot
.774 .463 Mdot
.774 .46361 Mdot
.774 .46373 Mdot
.774 .46394 Mdot
.774 .46407 Mdot
.774 .4645 Mdot
.774 .46473 Mdot
.774 .46475 Mdot
.774 .46486 Mdot
.774 .46517 Mdot
.774 .4659 Mdot
.774 .46598 Mdot
.774 .466 Mdot
.774 .46606 Mdot
.774 .46649 Mdot
.774 .46697 Mdot
.774 .46735 Mdot
.774 .46757 Mdot
.774 .46764 Mdot
.774 .46792 Mdot
.774 .46832 Mdot
.774 .46842 Mdot
.774 .46856 Mdot
.774 .469 Mdot
.774 .46905 Mdot
.774 .46911 Mdot
.774 .46918 Mdot
.774 .46918 Mdot
.774 .46968 Mdot
.774 .46983 Mdot
.774 .47003 Mdot
.774 .47013 Mdot
.774 .47041 Mdot
.774 .47044 Mdot
.774 .47053 Mdot
.774 .47054 Mdot
.774 .47094 Mdot
.774 .47125 Mdot
.776 .22008 Mdot
.776 .22024 Mdot
.776 .22031 Mdot
.776 .22067 Mdot
.776 .22104 Mdot
.776 .22127 Mdot
.776 .22228 Mdot
.776 .22294 Mdot
.776 .22419 Mdot
.776 .22431 Mdot
.776 .22438 Mdot
.776 .22447 Mdot
.776 .22461 Mdot
.776 .22537 Mdot
.776 .22538 Mdot
.776 .22558 Mdot
.776 .22558 Mdot
.776 .22591 Mdot
.776 .22659 Mdot
.776 .22713 Mdot
.776 .22731 Mdot
.776 .2277 Mdot
.776 .22799 Mdot
.776 .22892 Mdot
.776 .22933 Mdot
.776 .22936 Mdot
.776 .22998 Mdot
.776 .23011 Mdot
.776 .23019 Mdot
.776 .23081 Mdot
.776 .23138 Mdot
.776 .23143 Mdot
.776 .23181 Mdot
.776 .23194 Mdot
.776 .23207 Mdot
.776 .23247 Mdot
.776 .23311 Mdot
.776 .23348 Mdot
.776 .23374 Mdot
.776 .23376 Mdot
.776 .23404 Mdot
.776 .23409 Mdot
.776 .2342 Mdot
.776 .23442 Mdot
.776 .23506 Mdot
.776 .23649 Mdot
.776 .23684 Mdot
.776 .23692 Mdot
.776 .23705 Mdot
.776 .2377 Mdot
.776 .23825 Mdot
.776 .23989 Mdot
.776 .24037 Mdot
.776 .24078 Mdot
.776 .24185 Mdot
.776 .24284 Mdot
.776 .24294 Mdot
.776 .24304 Mdot
.776 .24313 Mdot
.776 .24328 Mdot
.776 .2433 Mdot
.776 .24368 Mdot
.776 .24382 Mdot
.776 .24478 Mdot
.776 .24573 Mdot
.776 .246 Mdot
.776 .24607 Mdot
.776 .24666 Mdot
.776 .24671 Mdot
.776 .247 Mdot
.776 .24791 Mdot
.776 .24836 Mdot
.776 .24862 Mdot
.776 .24898 Mdot
.776 .24901 Mdot
.776 .24908 Mdot
.776 .24945 Mdot
.776 .24976 Mdot
.776 .25024 Mdot
.776 .25069 Mdot
.776 .25078 Mdot
.776 .25095 Mdot
.776 .25173 Mdot
.776 .2524 Mdot
.776 .25262 Mdot
.776 .25364 Mdot
.776 .25365 Mdot
.776 .25376 Mdot
.776 .25381 Mdot
.776 .25502 Mdot
.776 .25602 Mdot
.776 .25649 Mdot
.776 .25754 Mdot
.776 .25772 Mdot
.776 .25784 Mdot
.776 .25793 Mdot
.776 .25839 Mdot
.776 .25874 Mdot
.776 .25903 Mdot
.776 .25941 Mdot
.776 .25984 Mdot
.776 .26015 Mdot
.776 .26047 Mdot
.776 .26067 Mdot
.776 .26071 Mdot
.776 .26112 Mdot
.776 .2613 Mdot
.776 .26153 Mdot
.776 .26167 Mdot
.776 .26174 Mdot
.776 .26179 Mdot
.776 .26247 Mdot
.776 .26263 Mdot
.776 .26267 Mdot
.776 .2629 Mdot
.776 .26291 Mdot
.776 .26315 Mdot
.776 .2636 Mdot
.776 .26406 Mdot
.776 .26424 Mdot
.776 .26495 Mdot
.776 .26515 Mdot
.776 .26517 Mdot
.776 .26534 Mdot
.776 .26543 Mdot
.776 .26614 Mdot
.776 .26655 Mdot
.776 .26677 Mdot
.776 .26706 Mdot
.776 .26727 Mdot
.776 .26742 Mdot
.776 .26808 Mdot
.776 .26827 Mdot
.776 .26839 Mdot
.776 .26943 Mdot
.776 .2699 Mdot
.776 .26998 Mdot
.776 .2702 Mdot
.776 .27074 Mdot
.776 .27133 Mdot
.776 .27246 Mdot
.776 .27247 Mdot
.776 .27259 Mdot
.776 .27263 Mdot
.776 .27281 Mdot
.776 .27314 Mdot
.776 .27318 Mdot
.776 .27334 Mdot
.776 .27337 Mdot
.776 .27379 Mdot
.776 .27478 Mdot
.776 .27483 Mdot
.776 .27535 Mdot
.776 .27592 Mdot
.776 .27618 Mdot
.776 .27638 Mdot
.776 .27702 Mdot
.776 .27707 Mdot
.776 .2773 Mdot
.776 .27763 Mdot
.776 .27788 Mdot
.776 .2787 Mdot
.776 .27888 Mdot
.776 .27909 Mdot
.776 .27921 Mdot
.776 .27953 Mdot
.776 .28016 Mdot
.776 .28059 Mdot
.776 .28126 Mdot
.776 .28145 Mdot
.776 .28146 Mdot
.776 .28148 Mdot
.776 .28157 Mdot
.776 .28168 Mdot
.776 .28195 Mdot
.776 .2826 Mdot
.776 .28278 Mdot
.776 .28301 Mdot
.776 .28327 Mdot
.776 .28332 Mdot
.776 .28333 Mdot
.776 .28333 Mdot
.776 .28333 Mdot
.776 .28333 Mdot
.776 .28333 Mdot
.776 .28333 Mdot
.776 .28333 Mdot
.776 .28335 Mdot
.776 .28346 Mdot
.776 .2841 Mdot
.776 .28411 Mdot
.776 .28464 Mdot
.776 .28509 Mdot
.776 .28517 Mdot
.776 .28525 Mdot
.776 .28593 Mdot
.776 .28664 Mdot
.776 .28729 Mdot
.776 .28754 Mdot
.776 .28756 Mdot
.776 .2877 Mdot
.776 .28777 Mdot
.776 .28779 Mdot
.776 .28784 Mdot
.776 .28784 Mdot
.776 .28831 Mdot
.776 .28887 Mdot
.776 .2889 Mdot
.776 .28993 Mdot
.776 .29029 Mdot
.776 .2908 Mdot
.776 .29096 Mdot
.776 .29171 Mdot
.776 .29192 Mdot
.776 .29199 Mdot
.776 .29238 Mdot
.776 .29247 Mdot
.776 .29255 Mdot
.776 .29272 Mdot
.776 .29282 Mdot
.776 .29308 Mdot
.776 .29326 Mdot
.776 .29341 Mdot
.776 .29353 Mdot
.776 .29387 Mdot
.776 .29396 Mdot
.776 .29403 Mdot
.776 .29447 Mdot
.776 .29508 Mdot
.776 .29645 Mdot
.776 .29677 Mdot
.776 .29684 Mdot
.776 .29706 Mdot
.776 .29726 Mdot
.776 .29757 Mdot
.776 .29759 Mdot
.776 .29784 Mdot
.776 .29841 Mdot
.776 .29853 Mdot
.776 .2988 Mdot
.776 .29894 Mdot
.776 .29973 Mdot
.776 .30006 Mdot
.776 .30055 Mdot
.776 .30099 Mdot
.776 .30116 Mdot
.776 .30136 Mdot
.776 .30254 Mdot
.776 .30277 Mdot
.776 .30337 Mdot
.776 .30363 Mdot
.776 .30379 Mdot
.776 .30391 Mdot
.776 .30402 Mdot
.776 .30418 Mdot
.776 .30472 Mdot
.776 .30487 Mdot
.776 .30513 Mdot
.776 .30542 Mdot
.776 .30548 Mdot
.776 .30592 Mdot
.776 .3063 Mdot
.776 .30642 Mdot
.776 .30659 Mdot
.776 .30688 Mdot
.776 .3073 Mdot
.776 .3073 Mdot
.776 .30738 Mdot
.776 .30776 Mdot
.776 .30788 Mdot
.776 .30867 Mdot
.776 .30909 Mdot
.776 .30919 Mdot
.776 .30949 Mdot
.776 .30952 Mdot
.776 .30959 Mdot
.776 .31005 Mdot
.776 .31099 Mdot
.776 .31156 Mdot
.776 .31159 Mdot
.776 .31169 Mdot
.776 .312 Mdot
.776 .31223 Mdot
.776 .31273 Mdot
.776 .31365 Mdot
.776 .31366 Mdot
.776 .314 Mdot
.776 .3145 Mdot
.776 .31473 Mdot
.776 .31479 Mdot
.776 .31495 Mdot
.776 .31548 Mdot
.776 .31562 Mdot
.776 .31567 Mdot
.776 .31676 Mdot
.776 .3168 Mdot
.776 .31712 Mdot
.776 .31735 Mdot
.776 .31926 Mdot
.776 .3193 Mdot
.776 .31938 Mdot
.776 .31944 Mdot
.776 .31945 Mdot
.776 .3196 Mdot
.776 .32006 Mdot
.776 .32057 Mdot
.776 .32084 Mdot
.776 .32136 Mdot
.776 .32166 Mdot
.776 .32185 Mdot
.776 .322 Mdot
.776 .32252 Mdot
.776 .32322 Mdot
.776 .32331 Mdot
.776 .32374 Mdot
.776 .32374 Mdot
.776 .32379 Mdot
.776 .32381 Mdot
.776 .32473 Mdot
.776 .32548 Mdot
.776 .32571 Mdot
.776 .32644 Mdot
.776 .32666 Mdot
.776 .32707 Mdot
.776 .3271 Mdot
.776 .32712 Mdot
.776 .32749 Mdot
.776 .32758 Mdot
.776 .32759 Mdot
.776 .32788 Mdot
.776 .32807 Mdot
.776 .32814 Mdot
.776 .32852 Mdot
.776 .32852 Mdot
.776 .32863 Mdot
.776 .32893 Mdot
.776 .32919 Mdot
.776 .32931 Mdot
.776 .3294 Mdot
.776 .32973 Mdot
.776 .32981 Mdot
.776 .32986 Mdot
.776 .3303 Mdot
.776 .33061 Mdot
.776 .33084 Mdot
.776 .33192 Mdot
.776 .33193 Mdot
.776 .33252 Mdot
.776 .33254 Mdot
.776 .33299 Mdot
.776 .3331 Mdot
.776 .33318 Mdot
.776 .33344 Mdot
.776 .33356 Mdot
.776 .3337 Mdot
.776 .3338 Mdot
.776 .33435 Mdot
.776 .33449 Mdot
.776 .33493 Mdot
.776 .33521 Mdot
.776 .33529 Mdot
.776 .33534 Mdot
.776 .33538 Mdot
.776 .33549 Mdot
.776 .33576 Mdot
.776 .33584 Mdot
.776 .33606 Mdot
.776 .33639 Mdot
.776 .33683 Mdot
.776 .33686 Mdot
.776 .33714 Mdot
.776 .33781 Mdot
.776 .33788 Mdot
.776 .33791 Mdot
.776 .33837 Mdot
.776 .33838 Mdot
.776 .33896 Mdot
.776 .33917 Mdot
.776 .33954 Mdot
.776 .33963 Mdot
.776 .33966 Mdot
.776 .33982 Mdot
.776 .33989 Mdot
.776 .33996 Mdot
.776 .34 Mdot
.776 .34011 Mdot
.776 .34025 Mdot
.776 .34044 Mdot
.776 .34048 Mdot
.776 .34094 Mdot
.776 .34164 Mdot
.776 .34167 Mdot
.776 .34185 Mdot
.776 .34198 Mdot
.776 .34198 Mdot
.776 .34249 Mdot
.776 .34255 Mdot
.776 .34287 Mdot
.776 .3434 Mdot
.776 .34355 Mdot
.776 .34414 Mdot
.776 .34439 Mdot
.776 .34449 Mdot
.776 .34466 Mdot
.776 .34472 Mdot
.776 .34495 Mdot
.776 .34501 Mdot
.776 .34512 Mdot
.776 .34524 Mdot
.776 .34526 Mdot
.776 .34544 Mdot
.776 .34565 Mdot
.776 .34572 Mdot
.776 .34584 Mdot
.776 .34602 Mdot
.776 .34697 Mdot
.776 .34716 Mdot
.776 .34755 Mdot
.776 .34779 Mdot
.776 .3478 Mdot
.776 .34784 Mdot
.776 .34797 Mdot
.776 .34827 Mdot
.776 .34865 Mdot
.776 .3488 Mdot
.776 .34901 Mdot
.776 .3491 Mdot
.776 .34913 Mdot
.776 .34947 Mdot
.776 .34995 Mdot
.776 .35009 Mdot
.776 .35019 Mdot
.776 .35098 Mdot
.776 .35103 Mdot
.776 .35106 Mdot
.776 .35106 Mdot
.776 .35152 Mdot
.776 .35164 Mdot
.776 .35186 Mdot
.776 .35206 Mdot
.776 .35267 Mdot
.776 .35284 Mdot
.776 .35286 Mdot
.776 .35287 Mdot
.776 .35357 Mdot
.776 .35366 Mdot
.776 .35424 Mdot
.776 .3544 Mdot
.776 .35444 Mdot
.776 .35456 Mdot
.776 .35464 Mdot
.776 .35467 Mdot
.776 .35483 Mdot
.776 .35483 Mdot
.776 .35487 Mdot
.776 .355 Mdot
.776 .3551 Mdot
.776 .35519 Mdot
.776 .35536 Mdot
.776 .35539 Mdot
.776 .35556 Mdot
.776 .3557 Mdot
.776 .35668 Mdot
.776 .3573 Mdot
.776 .35768 Mdot
.776 .35783 Mdot
.776 .35796 Mdot
.776 .35841 Mdot
.776 .35891 Mdot
.776 .35916 Mdot
.776 .3594 Mdot
.776 .35944 Mdot
.776 .35945 Mdot
.776 .35958 Mdot
.776 .35978 Mdot
.776 .36079 Mdot
.776 .36131 Mdot
.776 .36165 Mdot
.776 .36172 Mdot
.776 .36177 Mdot
.776 .36194 Mdot
.776 .36202 Mdot
.776 .36209 Mdot
.776 .36248 Mdot
.776 .36273 Mdot
.776 .36283 Mdot
.776 .36303 Mdot
.776 .36318 Mdot
.776 .36353 Mdot
.776 .36372 Mdot
.776 .36382 Mdot
.776 .36417 Mdot
.776 .36418 Mdot
.776 .36492 Mdot
.776 .36493 Mdot
.776 .36494 Mdot
.776 .36522 Mdot
.776 .36557 Mdot
.776 .36577 Mdot
.776 .36582 Mdot
.776 .36598 Mdot
.776 .36605 Mdot
.776 .36693 Mdot
.776 .36705 Mdot
.776 .36723 Mdot
.776 .36755 Mdot
.776 .36765 Mdot
.776 .36863 Mdot
.776 .36873 Mdot
.776 .36876 Mdot
.776 .36893 Mdot
.776 .36903 Mdot
.776 .36907 Mdot
.776 .36922 Mdot
.776 .36936 Mdot
.776 .36944 Mdot
.776 .36948 Mdot
.776 .36994 Mdot
.776 .37007 Mdot
.776 .37029 Mdot
.776 .37082 Mdot
.776 .37107 Mdot
.776 .37152 Mdot
.776 .37164 Mdot
.776 .37178 Mdot
.776 .37202 Mdot
.776 .37206 Mdot
.776 .37249 Mdot
.776 .37289 Mdot
.776 .3729 Mdot
.776 .37308 Mdot
.776 .37325 Mdot
.776 .37325 Mdot
.776 .37366 Mdot
.776 .37377 Mdot
.776 .37389 Mdot
.776 .3739 Mdot
.776 .37415 Mdot
.776 .37443 Mdot
.776 .37445 Mdot
.776 .3747 Mdot
.776 .37478 Mdot
.776 .37507 Mdot
.776 .37523 Mdot
.776 .37579 Mdot
.776 .37617 Mdot
.776 .37638 Mdot
.776 .37657 Mdot
.776 .37664 Mdot
.776 .37727 Mdot
.776 .37734 Mdot
.776 .37766 Mdot
.776 .37773 Mdot
.776 .3783 Mdot
.776 .37835 Mdot
.776 .37845 Mdot
.776 .37848 Mdot
.776 .37883 Mdot
.776 .37902 Mdot
.776 .37903 Mdot
.776 .37951 Mdot
.776 .37974 Mdot
.776 .3798 Mdot
.776 .37993 Mdot
.776 .38015 Mdot
.776 .38025 Mdot
.776 .38038 Mdot
.776 .38044 Mdot
.776 .3806 Mdot
.776 .38085 Mdot
.776 .3809 Mdot
.776 .38095 Mdot
.776 .38106 Mdot
.776 .38109 Mdot
.776 .38136 Mdot
.776 .38256 Mdot
.776 .38259 Mdot
.776 .38274 Mdot
.776 .38323 Mdot
.776 .38352 Mdot
.776 .3836 Mdot
.776 .3837 Mdot
.776 .38394 Mdot
.776 .38506 Mdot
.776 .38517 Mdot
.776 .38542 Mdot
.776 .3855 Mdot
.776 .38553 Mdot
.776 .38553 Mdot
.776 .38571 Mdot
.776 .38578 Mdot
.776 .38581 Mdot
.776 .38635 Mdot
.776 .38679 Mdot
.776 .3868 Mdot
.776 .38681 Mdot
.776 .38766 Mdot
.776 .38796 Mdot
.776 .38798 Mdot
.776 .38852 Mdot
.776 .38868 Mdot
.776 .38898 Mdot
.776 .38922 Mdot
.776 .38951 Mdot
.776 .38976 Mdot
.776 .38995 Mdot
.776 .39007 Mdot
.776 .39022 Mdot
.776 .3906 Mdot
.776 .39121 Mdot
.776 .39132 Mdot
.776 .39144 Mdot
.776 .39158 Mdot
.776 .39171 Mdot
.776 .39179 Mdot
.776 .39186 Mdot
.776 .3919 Mdot
.776 .39205 Mdot
.776 .39219 Mdot
.776 .39242 Mdot
.776 .3929 Mdot
.776 .39324 Mdot
.776 .39345 Mdot
.776 .3939 Mdot
.776 .39448 Mdot
.776 .3948 Mdot
.776 .39511 Mdot
.776 .39516 Mdot
.776 .39531 Mdot
.776 .39532 Mdot
.776 .39538 Mdot
.776 .39562 Mdot
.776 .39576 Mdot
.776 .39613 Mdot
.776 .39614 Mdot
.776 .39643 Mdot
.776 .3965 Mdot
.776 .39693 Mdot
.776 .39713 Mdot
.776 .39741 Mdot
.776 .39762 Mdot
.776 .39777 Mdot
.776 .39782 Mdot
.776 .39799 Mdot
.776 .39806 Mdot
.776 .39809 Mdot
.776 .39818 Mdot
.776 .39864 Mdot
.776 .39923 Mdot
.776 .39948 Mdot
.776 .39953 Mdot
.776 .3996 Mdot
.776 .3999 Mdot
.776 .39991 Mdot
.776 .40029 Mdot
.776 .40029 Mdot
.776 .40099 Mdot
.776 .40113 Mdot
.776 .40134 Mdot
.776 .40162 Mdot
.776 .40165 Mdot
.776 .4017 Mdot
.776 .40192 Mdot
.776 .40197 Mdot
.776 .40205 Mdot
.776 .40222 Mdot
.776 .40241 Mdot
.776 .40248 Mdot
.776 .40249 Mdot
.776 .40273 Mdot
.776 .40278 Mdot
.776 .4029 Mdot
.776 .40309 Mdot
.776 .40309 Mdot
.776 .40315 Mdot
.776 .40338 Mdot
.776 .4034 Mdot
.776 .40342 Mdot
.776 .40368 Mdot
.776 .40382 Mdot
.776 .40429 Mdot
.776 .40444 Mdot
.776 .40493 Mdot
.776 .40552 Mdot
.776 .40553 Mdot
.776 .40556 Mdot
.776 .40556 Mdot
.776 .40584 Mdot
.776 .4059 Mdot
.776 .40635 Mdot
.776 .40668 Mdot
.776 .40678 Mdot
.776 .40691 Mdot
.776 .4071 Mdot
.776 .40743 Mdot
.776 .40761 Mdot
.776 .40793 Mdot
.776 .40823 Mdot
.776 .40833 Mdot
.776 .40834 Mdot
.776 .40838 Mdot
.776 .40843 Mdot
.776 .40845 Mdot
.776 .40968 Mdot
.776 .40983 Mdot
.776 .41004 Mdot
.776 .41006 Mdot
.776 .41076 Mdot
.776 .41079 Mdot
.776 .41089 Mdot
.776 .41123 Mdot
.776 .41133 Mdot
.776 .41137 Mdot
.776 .41152 Mdot
.776 .41184 Mdot
.776 .41206 Mdot
.776 .41207 Mdot
.776 .41266 Mdot
.776 .41298 Mdot
.776 .41313 Mdot
.776 .41333 Mdot
.776 .41339 Mdot
.776 .41341 Mdot
.776 .41378 Mdot
.776 .41438 Mdot
.776 .41468 Mdot
.776 .41473 Mdot
.776 .41475 Mdot
.776 .41494 Mdot
.776 .415 Mdot
.776 .41527 Mdot
.776 .41578 Mdot
.776 .41586 Mdot
.776 .4161 Mdot
.776 .41616 Mdot
.776 .41616 Mdot
.776 .41643 Mdot
.776 .41662 Mdot
.776 .41672 Mdot
.776 .4168 Mdot
.776 .41705 Mdot
.776 .41733 Mdot
.776 .41737 Mdot
.776 .41755 Mdot
.776 .41772 Mdot
.776 .41782 Mdot
.776 .41817 Mdot
.776 .41827 Mdot
.776 .41834 Mdot
.776 .41842 Mdot
.776 .41852 Mdot
.776 .41869 Mdot
.776 .41907 Mdot
.776 .41922 Mdot
.776 .41998 Mdot
.776 .42011 Mdot
.776 .42022 Mdot
.776 .42051 Mdot
.776 .42082 Mdot
.776 .42103 Mdot
.776 .42154 Mdot
.776 .42163 Mdot
.776 .42181 Mdot
.776 .42189 Mdot
.776 .42225 Mdot
.776 .42242 Mdot
.776 .42242 Mdot
.776 .42262 Mdot
.776 .42275 Mdot
.776 .4229 Mdot
.776 .42294 Mdot
.776 .42315 Mdot
.776 .42403 Mdot
.776 .42442 Mdot
.776 .4247 Mdot
.776 .42475 Mdot
.776 .42481 Mdot
.776 .42503 Mdot
.776 .4251 Mdot
.776 .4252 Mdot
.776 .42532 Mdot
.776 .42549 Mdot
.776 .42555 Mdot
.776 .42566 Mdot
.776 .42571 Mdot
.776 .42577 Mdot
.776 .42602 Mdot
.776 .42607 Mdot
.776 .4262 Mdot
.776 .42669 Mdot
.776 .42679 Mdot
.776 .42711 Mdot
.776 .42735 Mdot
.776 .42801 Mdot
.776 .42803 Mdot
.776 .42839 Mdot
.776 .42869 Mdot
.776 .4287 Mdot
.776 .42873 Mdot
.776 .42874 Mdot
.776 .42879 Mdot
.776 .42888 Mdot
.776 .42889 Mdot
.776 .42905 Mdot
.776 .42947 Mdot
.776 .42993 Mdot
.776 .43037 Mdot
.776 .43041 Mdot
.776 .43047 Mdot
.776 .43076 Mdot
.776 .4311 Mdot
.776 .43111 Mdot
.776 .43152 Mdot
.776 .43159 Mdot
.776 .4316 Mdot
.776 .4316 Mdot
.776 .4316 Mdot
.776 .4316 Mdot
.776 .4316 Mdot
.776 .4316 Mdot
.776 .4316 Mdot
.776 .43161 Mdot
.776 .43164 Mdot
.776 .43181 Mdot
.776 .43195 Mdot
.776 .43207 Mdot
.776 .43249 Mdot
.776 .43266 Mdot
.776 .43273 Mdot
.776 .43279 Mdot
.776 .43281 Mdot
.776 .43281 Mdot
.776 .43293 Mdot
.776 .43337 Mdot
.776 .43364 Mdot
.776 .43405 Mdot
.776 .43426 Mdot
.776 .43433 Mdot
.776 .43447 Mdot
.776 .43458 Mdot
.776 .43511 Mdot
.776 .43528 Mdot
.776 .43549 Mdot
.776 .43564 Mdot
.776 .43567 Mdot
.776 .43608 Mdot
.776 .43621 Mdot
.776 .43637 Mdot
.776 .43674 Mdot
.776 .43708 Mdot
.776 .43711 Mdot
.776 .43775 Mdot
.776 .43802 Mdot
.776 .43804 Mdot
.776 .43814 Mdot
.776 .43817 Mdot
.776 .43838 Mdot
.776 .43849 Mdot
.776 .43852 Mdot
.776 .4386 Mdot
.776 .43861 Mdot
.776 .43933 Mdot
.776 .43972 Mdot
.776 .44006 Mdot
.776 .4402 Mdot
.776 .44025 Mdot
.776 .44056 Mdot
.776 .44122 Mdot
.776 .44131 Mdot
.776 .44143 Mdot
.776 .44185 Mdot
.776 .44195 Mdot
.776 .44209 Mdot
.776 .44227 Mdot
.776 .44241 Mdot
.776 .44268 Mdot
.776 .44314 Mdot
.776 .44319 Mdot
.776 .4433 Mdot
.776 .44332 Mdot
.776 .44344 Mdot
.776 .4439 Mdot
.776 .44402 Mdot
.776 .44431 Mdot
.776 .4446 Mdot
.776 .44476 Mdot
.776 .44477 Mdot
.776 .44492 Mdot
.776 .44494 Mdot
.776 .44504 Mdot
.776 .44548 Mdot
.776 .44551 Mdot
.776 .44556 Mdot
.776 .44565 Mdot
.776 .4458 Mdot
.776 .44591 Mdot
.776 .44618 Mdot
.776 .4462 Mdot
.776 .44633 Mdot
.776 .44654 Mdot
.776 .44673 Mdot
.776 .44701 Mdot
.776 .44726 Mdot
.776 .44744 Mdot
.776 .44767 Mdot
.776 .44796 Mdot
.776 .44802 Mdot
.776 .4481 Mdot
.776 .44822 Mdot
.776 .44889 Mdot
.776 .4492 Mdot
.776 .44984 Mdot
.776 .45062 Mdot
.776 .45066 Mdot
.776 .45073 Mdot
.776 .45073 Mdot
.776 .45139 Mdot
.776 .45153 Mdot
.776 .45196 Mdot
.776 .45246 Mdot
.776 .45257 Mdot
.776 .45263 Mdot
.776 .45292 Mdot
.776 .45323 Mdot
.776 .45343 Mdot
.776 .45367 Mdot
.776 .45371 Mdot
.776 .45373 Mdot
.776 .45397 Mdot
.776 .45413 Mdot
.776 .45442 Mdot
.776 .45501 Mdot
.776 .45519 Mdot
.776 .45523 Mdot
.776 .45561 Mdot
.776 .45566 Mdot
.776 .45583 Mdot
.776 .45644 Mdot
.776 .45706 Mdot
.776 .45715 Mdot
.776 .45739 Mdot
.776 .45741 Mdot
.776 .4575 Mdot
.776 .45756 Mdot
.776 .45762 Mdot
.776 .45769 Mdot
.776 .45833 Mdot
.776 .45902 Mdot
.776 .45928 Mdot
.776 .45959 Mdot
.776 .46065 Mdot
.776 .461 Mdot
.776 .46142 Mdot
.776 .4615 Mdot
.776 .46156 Mdot
.776 .46178 Mdot
.776 .46271 Mdot
.776 .46312 Mdot
.776 .46325 Mdot
.776 .46333 Mdot
.776 .46336 Mdot
.776 .46354 Mdot
.776 .46355 Mdot
.776 .46372 Mdot
.776 .46396 Mdot
.776 .46437 Mdot
.776 .46463 Mdot
.776 .46471 Mdot
.776 .4648 Mdot
.776 .46504 Mdot
.776 .46507 Mdot
.776 .46544 Mdot
.776 .46584 Mdot
.776 .46589 Mdot
.776 .46598 Mdot
.776 .46638 Mdot
.776 .46639 Mdot
.776 .46666 Mdot
.776 .46726 Mdot
.776 .46745 Mdot
.776 .4677 Mdot
.776 .46781 Mdot
.776 .46816 Mdot
.776 .4686 Mdot
.776 .46881 Mdot
.776 .46881 Mdot
.776 .46894 Mdot
.776 .46895 Mdot
.776 .46943 Mdot
.776 .46953 Mdot
.776 .46959 Mdot
.776 .46963 Mdot
.776 .46971 Mdot
.776 .47051 Mdot
.776 .47093 Mdot
.776 .47159 Mdot
.776 .47174 Mdot
.776 .47198 Mdot
.776 .4722 Mdot
.776 .47225 Mdot
.776 .47235 Mdot
.778 .21872 Mdot
.778 .21889 Mdot
.778 .21923 Mdot
.778 .21982 Mdot
.778 .22001 Mdot
.778 .22002 Mdot
.778 .22022 Mdot
.778 .2208 Mdot
.778 .22137 Mdot
.778 .22182 Mdot
.778 .22285 Mdot
.778 .22342 Mdot
.778 .22375 Mdot
.778 .22443 Mdot
.778 .22454 Mdot
.778 .22457 Mdot
.778 .22464 Mdot
.778 .22544 Mdot
.778 .22551 Mdot
.778 .22667 Mdot
.778 .22714 Mdot
.778 .22714 Mdot
.778 .22782 Mdot
.778 .22818 Mdot
.778 .22875 Mdot
.778 .22985 Mdot
.778 .2304 Mdot
.778 .23072 Mdot
.778 .23081 Mdot
.778 .23085 Mdot
.778 .23093 Mdot
.778 .23207 Mdot
.778 .23241 Mdot
.778 .23403 Mdot
.778 .23418 Mdot
.778 .2343 Mdot
.778 .23458 Mdot
.778 .23463 Mdot
.778 .23516 Mdot
.778 .23551 Mdot
.778 .23588 Mdot
.778 .23631 Mdot
.778 .2364 Mdot
.778 .23661 Mdot
.778 .23667 Mdot
.778 .23703 Mdot
.778 .23766 Mdot
.778 .23768 Mdot
.778 .23881 Mdot
.778 .23881 Mdot
.778 .23956 Mdot
.778 .23977 Mdot
.778 .23993 Mdot
.778 .24072 Mdot
.778 .24081 Mdot
.778 .24127 Mdot
.778 .24203 Mdot
.778 .24204 Mdot
.778 .2426 Mdot
.778 .243 Mdot
.778 .24372 Mdot
.778 .24379 Mdot
.778 .24383 Mdot
.778 .24504 Mdot
.778 .24506 Mdot
.778 .24511 Mdot
.778 .24571 Mdot
.778 .24629 Mdot
.778 .2464 Mdot
.778 .24668 Mdot
.778 .24684 Mdot
.778 .24721 Mdot
.778 .24738 Mdot
.778 .24774 Mdot
.778 .24807 Mdot
.778 .24884 Mdot
.778 .249 Mdot
.778 .24939 Mdot
.778 .24992 Mdot
.778 .25004 Mdot
.778 .25031 Mdot
.778 .25052 Mdot
.778 .25082 Mdot
.778 .2511 Mdot
.778 .25139 Mdot
.778 .25179 Mdot
.778 .25205 Mdot
.778 .25223 Mdot
.778 .25278 Mdot
.778 .25324 Mdot
.778 .25368 Mdot
.778 .25416 Mdot
.778 .25434 Mdot
.778 .25439 Mdot
.778 .2546 Mdot
.778 .25461 Mdot
.778 .25482 Mdot
.778 .25522 Mdot
.778 .25562 Mdot
.778 .25575 Mdot
.778 .25646 Mdot
.778 .25783 Mdot
.778 .25817 Mdot
.778 .2582 Mdot
.778 .2587 Mdot
.778 .25885 Mdot
.778 .26004 Mdot
.778 .26027 Mdot
.778 .26058 Mdot
.778 .26083 Mdot
.778 .26097 Mdot
.778 .26182 Mdot
.778 .26189 Mdot
.778 .26273 Mdot
.778 .26305 Mdot
.778 .26343 Mdot
.778 .26352 Mdot
.778 .26443 Mdot
.778 .26449 Mdot
.778 .26479 Mdot
.778 .26485 Mdot
.778 .26518 Mdot
.778 .26619 Mdot
.778 .26676 Mdot
.778 .26683 Mdot
.778 .26773 Mdot
.778 .26841 Mdot
.778 .26893 Mdot
.778 .26894 Mdot
.778 .26913 Mdot
.778 .26939 Mdot
.778 .26972 Mdot
.778 .27 Mdot
.778 .27038 Mdot
.778 .27064 Mdot
.778 .271 Mdot
.778 .27114 Mdot
.778 .27147 Mdot
.778 .27232 Mdot
.778 .27287 Mdot
.778 .27304 Mdot
.778 .27307 Mdot
.778 .2735 Mdot
.778 .27351 Mdot
.778 .27397 Mdot
.778 .2744 Mdot
.778 .27473 Mdot
.778 .27477 Mdot
.778 .27635 Mdot
.778 .27635 Mdot
.778 .27677 Mdot
.778 .27687 Mdot
.778 .27693 Mdot
.778 .27702 Mdot
.778 .27771 Mdot
.778 .27775 Mdot
.778 .27796 Mdot
.778 .27823 Mdot
.778 .2783 Mdot
.778 .27839 Mdot
.778 .27851 Mdot
.778 .27874 Mdot
.778 .2788 Mdot
.778 .27925 Mdot
.778 .27943 Mdot
.778 .2797 Mdot
.778 .27971 Mdot
.778 .28017 Mdot
.778 .28028 Mdot
.778 .28071 Mdot
.778 .28093 Mdot
.778 .28134 Mdot
.778 .28142 Mdot
.778 .2819 Mdot
.778 .28232 Mdot
.778 .28247 Mdot
.778 .28276 Mdot
.778 .28285 Mdot
.778 .28334 Mdot
.778 .28351 Mdot
.778 .28371 Mdot
.778 .28418 Mdot
.778 .28423 Mdot
.778 .28442 Mdot
.778 .28453 Mdot
.778 .28479 Mdot
.778 .285 Mdot
.778 .28559 Mdot
.778 .28563 Mdot
.778 .2858 Mdot
.778 .28581 Mdot
.778 .28648 Mdot
.778 .28698 Mdot
.778 .28716 Mdot
.778 .28747 Mdot
.778 .28816 Mdot
.778 .28843 Mdot
.778 .28868 Mdot
.778 .28879 Mdot
.778 .28974 Mdot
.778 .28976 Mdot
.778 .29 Mdot
.778 .29055 Mdot
.778 .29058 Mdot
.778 .2907 Mdot
.778 .2911 Mdot
.778 .29114 Mdot
.778 .29178 Mdot
.778 .29181 Mdot
.778 .29222 Mdot
.778 .29254 Mdot
.778 .29303 Mdot
.778 .2933 Mdot
.778 .29346 Mdot
.778 .29402 Mdot
.778 .29431 Mdot
.778 .29437 Mdot
.778 .29453 Mdot
.778 .2947 Mdot
.778 .29479 Mdot
.778 .29487 Mdot
.778 .2949 Mdot
.778 .29517 Mdot
.778 .29535 Mdot
.778 .29577 Mdot
.778 .29584 Mdot
.778 .29595 Mdot
.778 .29635 Mdot
.778 .29647 Mdot
.778 .29667 Mdot
.778 .29672 Mdot
.778 .29762 Mdot
.778 .29777 Mdot
.778 .29784 Mdot
.778 .298 Mdot
.778 .29818 Mdot
.778 .29822 Mdot
.778 .29846 Mdot
.778 .29874 Mdot
.778 .29924 Mdot
.778 .29925 Mdot
.778 .29958 Mdot
.778 .29975 Mdot
.778 .30178 Mdot
.778 .30179 Mdot
.778 .30205 Mdot
.778 .30231 Mdot
.778 .30282 Mdot
.778 .30304 Mdot
.778 .30306 Mdot
.778 .30317 Mdot
.778 .30396 Mdot
.778 .30456 Mdot
.778 .3046 Mdot
.778 .30501 Mdot
.778 .30613 Mdot
.778 .30613 Mdot
.778 .30716 Mdot
.778 .30719 Mdot
.778 .30725 Mdot
.778 .30767 Mdot
.778 .30851 Mdot
.778 .30899 Mdot
.778 .30908 Mdot
.778 .30979 Mdot
.778 .30985 Mdot
.778 .30999 Mdot
.778 .31024 Mdot
.778 .31032 Mdot
.778 .31064 Mdot
.778 .31106 Mdot
.778 .31149 Mdot
.778 .31186 Mdot
.778 .31219 Mdot
.778 .31256 Mdot
.778 .31259 Mdot
.778 .31307 Mdot
.778 .31354 Mdot
.778 .31369 Mdot
.778 .31393 Mdot
.778 .31461 Mdot
.778 .31474 Mdot
.778 .31478 Mdot
.778 .3153 Mdot
.778 .31611 Mdot
.778 .31617 Mdot
.778 .31672 Mdot
.778 .31687 Mdot
.778 .31705 Mdot
.778 .31718 Mdot
.778 .3172 Mdot
.778 .31808 Mdot
.778 .31808 Mdot
.778 .31839 Mdot
.778 .31848 Mdot
.778 .31855 Mdot
.778 .31887 Mdot
.778 .31891 Mdot
.778 .3191 Mdot
.778 .31941 Mdot
.778 .31941 Mdot
.778 .32011 Mdot
.778 .32067 Mdot
.778 .32068 Mdot
.778 .32133 Mdot
.778 .32191 Mdot
.778 .32222 Mdot
.778 .32229 Mdot
.778 .32245 Mdot
.778 .32283 Mdot
.778 .32316 Mdot
.778 .32328 Mdot
.778 .32385 Mdot
.778 .32442 Mdot
.778 .3246 Mdot
.778 .32608 Mdot
.778 .3263 Mdot
.778 .32695 Mdot
.778 .32707 Mdot
.778 .32724 Mdot
.778 .32796 Mdot
.778 .3281 Mdot
.778 .32867 Mdot
.778 .32897 Mdot
.778 .33003 Mdot
.778 .33031 Mdot
.778 .33052 Mdot
.778 .33053 Mdot
.778 .33085 Mdot
.778 .33112 Mdot
.778 .33138 Mdot
.778 .33143 Mdot
.778 .33157 Mdot
.778 .33215 Mdot
.778 .33222 Mdot
.778 .33241 Mdot
.778 .3326 Mdot
.778 .33278 Mdot
.778 .33294 Mdot
.778 .33383 Mdot
.778 .33386 Mdot
.778 .33415 Mdot
.778 .33417 Mdot
.778 .33425 Mdot
.778 .33436 Mdot
.778 .33443 Mdot
.778 .33448 Mdot
.778 .33457 Mdot
.778 .33479 Mdot
.778 .33497 Mdot
.778 .33539 Mdot
.778 .33548 Mdot
.778 .33565 Mdot
.778 .33612 Mdot
.778 .33624 Mdot
.778 .33627 Mdot
.778 .33647 Mdot
.778 .33682 Mdot
.778 .33684 Mdot
.778 .33697 Mdot
.778 .33716 Mdot
.778 .3374 Mdot
.778 .33742 Mdot
.778 .33749 Mdot
.778 .33777 Mdot
.778 .33818 Mdot
.778 .33858 Mdot
.778 .33872 Mdot
.778 .33913 Mdot
.778 .33945 Mdot
.778 .33947 Mdot
.778 .33952 Mdot
.778 .33997 Mdot
.778 .34027 Mdot
.778 .34048 Mdot
.778 .34103 Mdot
.778 .3412 Mdot
.778 .34124 Mdot
.778 .34125 Mdot
.778 .34136 Mdot
.778 .34161 Mdot
.778 .34185 Mdot
.778 .3419 Mdot
.778 .34198 Mdot
.778 .342 Mdot
.778 .34243 Mdot
.778 .3426 Mdot
.778 .34272 Mdot
.778 .34283 Mdot
.778 .34318 Mdot
.778 .34325 Mdot
.778 .34409 Mdot
.778 .34409 Mdot
.778 .3442 Mdot
.778 .34431 Mdot
.778 .34452 Mdot
.778 .34461 Mdot
.778 .34524 Mdot
.778 .34526 Mdot
.778 .34631 Mdot
.778 .34687 Mdot
.778 .3471 Mdot
.778 .3474 Mdot
.778 .34743 Mdot
.778 .34748 Mdot
.778 .34758 Mdot
.778 .34762 Mdot
.778 .34775 Mdot
.778 .3481 Mdot
.778 .34854 Mdot
.778 .34856 Mdot
.778 .34895 Mdot
.778 .34911 Mdot
.778 .34944 Mdot
.778 .34946 Mdot
.778 .35003 Mdot
.778 .35032 Mdot
.778 .3504 Mdot
.778 .35082 Mdot
.778 .35082 Mdot
.778 .35095 Mdot
.778 .35102 Mdot
.778 .35115 Mdot
.778 .35117 Mdot
.778 .35124 Mdot
.778 .35137 Mdot
.778 .35137 Mdot
.778 .35189 Mdot
.778 .3519 Mdot
.778 .35217 Mdot
.778 .3524 Mdot
.778 .35253 Mdot
.778 .35278 Mdot
.778 .35292 Mdot
.778 .35297 Mdot
.778 .35344 Mdot
.778 .35352 Mdot
.778 .35413 Mdot
.778 .35448 Mdot
.778 .35519 Mdot
.778 .35532 Mdot
.778 .35576 Mdot
.778 .35596 Mdot
.778 .3561 Mdot
.778 .35621 Mdot
.778 .35632 Mdot
.778 .3564 Mdot
.778 .35682 Mdot
.778 .3569 Mdot
.778 .35733 Mdot
.778 .35755 Mdot
.778 .35764 Mdot
.778 .35772 Mdot
.778 .3578 Mdot
.778 .35801 Mdot
.778 .35808 Mdot
.778 .35827 Mdot
.778 .35832 Mdot
.778 .3587 Mdot
.778 .3588 Mdot
.778 .35884 Mdot
.778 .35896 Mdot
.778 .35952 Mdot
.778 .35965 Mdot
.778 .35968 Mdot
.778 .35999 Mdot
.778 .36007 Mdot
.778 .36039 Mdot
.778 .36064 Mdot
.778 .36066 Mdot
.778 .3607 Mdot
.778 .36088 Mdot
.778 .36105 Mdot
.778 .36157 Mdot
.778 .36161 Mdot
.778 .36166 Mdot
.778 .36178 Mdot
.778 .36281 Mdot
.778 .36294 Mdot
.778 .36297 Mdot
.778 .36301 Mdot
.778 .36302 Mdot
.778 .36322 Mdot
.778 .36341 Mdot
.778 .36341 Mdot
.778 .36357 Mdot
.778 .36402 Mdot
.778 .36435 Mdot
.778 .36449 Mdot
.778 .36452 Mdot
.778 .36457 Mdot
.778 .3649 Mdot
.778 .36516 Mdot
.778 .36546 Mdot
.778 .36586 Mdot
.778 .3662 Mdot
.778 .36638 Mdot
.778 .36652 Mdot
.778 .36703 Mdot
.778 .36712 Mdot
.778 .36723 Mdot
.778 .36731 Mdot
.778 .36744 Mdot
.778 .36764 Mdot
.778 .36771 Mdot
.778 .36841 Mdot
.778 .36843 Mdot
.778 .3685 Mdot
.778 .36878 Mdot
.778 .3693 Mdot
.778 .36936 Mdot
.778 .36938 Mdot
.778 .36939 Mdot
.778 .36961 Mdot
.778 .3698 Mdot
.778 .36993 Mdot
.778 .36999 Mdot
.778 .3707 Mdot
.778 .37104 Mdot
.778 .37108 Mdot
.778 .37116 Mdot
.778 .37121 Mdot
.778 .37129 Mdot
.778 .37177 Mdot
.778 .372 Mdot
.778 .37201 Mdot
.778 .37211 Mdot
.778 .37226 Mdot
.778 .3728 Mdot
.778 .3731 Mdot
.778 .37314 Mdot
.778 .3732 Mdot
.778 .37342 Mdot
.778 .37414 Mdot
.778 .37454 Mdot
.778 .37489 Mdot
.778 .37499 Mdot
.778 .37505 Mdot
.778 .37506 Mdot
.778 .37521 Mdot
.778 .37551 Mdot
.778 .37565 Mdot
.778 .3759 Mdot
.778 .37635 Mdot
.778 .37648 Mdot
.778 .37659 Mdot
.778 .37674 Mdot
.778 .37674 Mdot
.778 .37676 Mdot
.778 .37713 Mdot
.778 .37731 Mdot
.778 .37782 Mdot
.778 .37786 Mdot
.778 .37799 Mdot
.778 .37807 Mdot
.778 .37819 Mdot
.778 .37825 Mdot
.778 .37878 Mdot
.778 .37901 Mdot
.778 .37926 Mdot
.778 .37987 Mdot
.778 .37989 Mdot
.778 .37998 Mdot
.778 .38019 Mdot
.778 .38048 Mdot
.778 .3807 Mdot
.778 .38083 Mdot
.778 .38084 Mdot
.778 .38087 Mdot
.778 .38088 Mdot
.778 .38097 Mdot
.778 .38129 Mdot
.778 .38163 Mdot
.778 .38177 Mdot
.778 .3821 Mdot
.778 .38221 Mdot
.778 .38232 Mdot
.778 .38235 Mdot
.778 .38252 Mdot
.778 .38298 Mdot
.778 .38344 Mdot
.778 .38354 Mdot
.778 .38361 Mdot
.778 .38385 Mdot
.778 .38401 Mdot
.778 .38405 Mdot
.778 .38419 Mdot
.778 .38429 Mdot
.778 .38435 Mdot
.778 .38449 Mdot
.778 .38514 Mdot
.778 .38528 Mdot
.778 .3855 Mdot
.778 .38578 Mdot
.778 .38586 Mdot
.778 .38632 Mdot
.778 .38655 Mdot
.778 .38694 Mdot
.778 .38729 Mdot
.778 .38741 Mdot
.778 .38757 Mdot
.778 .38765 Mdot
.778 .38781 Mdot
.778 .38798 Mdot
.778 .38798 Mdot
.778 .38832 Mdot
.778 .38832 Mdot
.778 .3884 Mdot
.778 .38845 Mdot
.778 .38867 Mdot
.778 .38894 Mdot
.778 .38918 Mdot
.778 .38956 Mdot
.778 .38977 Mdot
.778 .38987 Mdot
.778 .39013 Mdot
.778 .39014 Mdot
.778 .39042 Mdot
.778 .39073 Mdot
.778 .39075 Mdot
.778 .39082 Mdot
.778 .39085 Mdot
.778 .39087 Mdot
.778 .39106 Mdot
.778 .39266 Mdot
.778 .39286 Mdot
.778 .39293 Mdot
.778 .39299 Mdot
.778 .393 Mdot
.778 .39354 Mdot
.778 .39358 Mdot
.778 .3938 Mdot
.778 .39406 Mdot
.778 .39434 Mdot
.778 .39435 Mdot
.778 .39441 Mdot
.778 .39444 Mdot
.778 .39459 Mdot
.778 .39483 Mdot
.778 .39532 Mdot
.778 .39545 Mdot
.778 .39594 Mdot
.778 .39598 Mdot
.778 .39619 Mdot
.778 .39645 Mdot
.778 .3968 Mdot
.778 .39706 Mdot
.778 .39724 Mdot
.778 .39728 Mdot
.778 .39729 Mdot
.778 .39745 Mdot
.778 .39766 Mdot
.778 .39767 Mdot
.778 .39789 Mdot
.778 .39804 Mdot
.778 .39812 Mdot
.778 .39842 Mdot
.778 .39853 Mdot
.778 .39886 Mdot
.778 .39898 Mdot
.778 .39911 Mdot
.778 .39921 Mdot
.778 .39925 Mdot
.778 .39932 Mdot
.778 .39959 Mdot
.778 .40026 Mdot
.778 .40038 Mdot
.778 .40062 Mdot
.778 .40104 Mdot
.778 .40113 Mdot
.778 .40117 Mdot
.778 .40133 Mdot
.778 .40151 Mdot
.778 .40171 Mdot
.778 .40172 Mdot
.778 .40186 Mdot
.778 .40203 Mdot
.778 .40271 Mdot
.778 .40291 Mdot
.778 .40328 Mdot
.778 .40336 Mdot
.778 .40383 Mdot
.778 .40393 Mdot
.778 .40402 Mdot
.778 .40443 Mdot
.778 .40457 Mdot
.778 .40552 Mdot
.778 .40564 Mdot
.778 .406 Mdot
.778 .40637 Mdot
.778 .40645 Mdot
.778 .40666 Mdot
.778 .4069 Mdot
.778 .40701 Mdot
.778 .40705 Mdot
.778 .40725 Mdot
.778 .40762 Mdot
.778 .40804 Mdot
.778 .40805 Mdot
.778 .40841 Mdot
.778 .40886 Mdot
.778 .40886 Mdot
.778 .40906 Mdot
.778 .40918 Mdot
.778 .4092 Mdot
.778 .40941 Mdot
.778 .40946 Mdot
.778 .40951 Mdot
.778 .40971 Mdot
.778 .40971 Mdot
.778 .41028 Mdot
.778 .41029 Mdot
.778 .41038 Mdot
.778 .41049 Mdot
.778 .41059 Mdot
.778 .41094 Mdot
.778 .41098 Mdot
.778 .4115 Mdot
.778 .41184 Mdot
.778 .41186 Mdot
.778 .41194 Mdot
.778 .41238 Mdot
.778 .41253 Mdot
.778 .41263 Mdot
.778 .41293 Mdot
.778 .41324 Mdot
.778 .41326 Mdot
.778 .4135 Mdot
.778 .41371 Mdot
.778 .41395 Mdot
.778 .41422 Mdot
.778 .41449 Mdot
.778 .4147 Mdot
.778 .41475 Mdot
.778 .41491 Mdot
.778 .415 Mdot
.778 .41504 Mdot
.778 .4155 Mdot
.778 .41556 Mdot
.778 .41586 Mdot
.778 .41641 Mdot
.778 .41667 Mdot
.778 .41671 Mdot
.778 .41673 Mdot
.778 .41739 Mdot
.778 .41739 Mdot
.778 .41811 Mdot
.778 .41838 Mdot
.778 .4184 Mdot
.778 .41879 Mdot
.778 .41929 Mdot
.778 .41937 Mdot
.778 .41938 Mdot
.778 .41952 Mdot
.778 .41985 Mdot
.778 .42002 Mdot
.778 .42018 Mdot
.778 .42019 Mdot
.778 .4215 Mdot
.778 .4216 Mdot
.778 .42181 Mdot
.778 .42182 Mdot
.778 .42214 Mdot
.778 .42232 Mdot
.778 .42248 Mdot
.778 .4225 Mdot
.778 .42262 Mdot
.778 .42272 Mdot
.778 .42276 Mdot
.778 .42286 Mdot
.778 .42344 Mdot
.778 .42347 Mdot
.778 .4236 Mdot
.778 .42368 Mdot
.778 .42394 Mdot
.778 .424 Mdot
.778 .42405 Mdot
.778 .42432 Mdot
.778 .42444 Mdot
.778 .42461 Mdot
.778 .42463 Mdot
.778 .42468 Mdot
.778 .42474 Mdot
.778 .42485 Mdot
.778 .42495 Mdot
.778 .42499 Mdot
.778 .42518 Mdot
.778 .42554 Mdot
.778 .42564 Mdot
.778 .42581 Mdot
.778 .42613 Mdot
.778 .42634 Mdot
.778 .4266 Mdot
.778 .42662 Mdot
.778 .42703 Mdot
.778 .42705 Mdot
.778 .42731 Mdot
.778 .42739 Mdot
.778 .4274 Mdot
.778 .42776 Mdot
.778 .42791 Mdot
.778 .42793 Mdot
.778 .42854 Mdot
.778 .42861 Mdot
.778 .42877 Mdot
.778 .42894 Mdot
.778 .42939 Mdot
.778 .42958 Mdot
.778 .4297 Mdot
.778 .43002 Mdot
.778 .43045 Mdot
.778 .43046 Mdot
.778 .43057 Mdot
.778 .43059 Mdot
.778 .43097 Mdot
.778 .43111 Mdot
.778 .43127 Mdot
.778 .43135 Mdot
.778 .43147 Mdot
.778 .4315 Mdot
.778 .4318 Mdot
.778 .43193 Mdot
.778 .43204 Mdot
.778 .43236 Mdot
.778 .43241 Mdot
.778 .4326 Mdot
.778 .4327 Mdot
.778 .43296 Mdot
.778 .43328 Mdot
.778 .43332 Mdot
.778 .43359 Mdot
.778 .43373 Mdot
.778 .43401 Mdot
.778 .43408 Mdot
.778 .43437 Mdot
.778 .43438 Mdot
.778 .43455 Mdot
.778 .43467 Mdot
.778 .43495 Mdot
.778 .435 Mdot
.778 .43515 Mdot
.778 .43522 Mdot
.778 .43528 Mdot
.778 .43533 Mdot
.778 .4355 Mdot
.778 .43563 Mdot
.778 .43566 Mdot
.778 .4361 Mdot
.778 .43616 Mdot
.778 .4362 Mdot
.778 .43626 Mdot
.778 .43653 Mdot
.778 .43653 Mdot
.778 .43754 Mdot
.778 .43757 Mdot
.778 .43778 Mdot
.778 .43806 Mdot
.778 .43836 Mdot
.778 .43836 Mdot
.778 .43864 Mdot
.778 .43866 Mdot
.778 .43877 Mdot
.778 .43912 Mdot
.778 .43967 Mdot
.778 .43988 Mdot
.778 .43997 Mdot
.778 .4402 Mdot
.778 .44037 Mdot
.778 .44061 Mdot
.778 .44079 Mdot
.778 .44101 Mdot
.778 .44117 Mdot
.778 .44129 Mdot
.778 .4413 Mdot
.778 .44164 Mdot
.778 .44207 Mdot
.778 .44265 Mdot
.778 .44269 Mdot
.778 .44306 Mdot
.778 .44371 Mdot
.778 .44392 Mdot
.778 .44396 Mdot
.778 .44415 Mdot
.778 .44419 Mdot
.778 .44478 Mdot
.778 .44484 Mdot
.778 .44508 Mdot
.778 .44529 Mdot
.778 .44582 Mdot
.778 .44587 Mdot
.778 .44641 Mdot
.778 .44651 Mdot
.778 .44667 Mdot
.778 .44687 Mdot
.778 .44701 Mdot
.778 .44778 Mdot
.778 .44788 Mdot
.778 .44819 Mdot
.778 .44821 Mdot
.778 .44844 Mdot
.778 .44931 Mdot
.778 .44977 Mdot
.778 .44986 Mdot
.778 .45011 Mdot
.778 .45037 Mdot
.778 .45051 Mdot
.778 .45051 Mdot
.778 .45064 Mdot
.778 .45068 Mdot
.778 .45079 Mdot
.778 .4511 Mdot
.778 .45138 Mdot
.778 .45168 Mdot
.778 .45203 Mdot
.778 .45215 Mdot
.778 .45232 Mdot
.778 .45257 Mdot
.778 .45276 Mdot
.778 .45294 Mdot
.778 .45313 Mdot
.778 .45327 Mdot
.778 .45344 Mdot
.778 .45351 Mdot
.778 .45386 Mdot
.778 .45411 Mdot
.778 .45421 Mdot
.778 .4547 Mdot
.778 .45492 Mdot
.778 .45515 Mdot
.778 .45526 Mdot
.778 .4555 Mdot
.778 .4556 Mdot
.778 .45578 Mdot
.778 .45585 Mdot
.778 .45622 Mdot
.778 .45661 Mdot
.778 .45664 Mdot
.778 .45666 Mdot
.778 .45743 Mdot
.778 .45746 Mdot
.778 .4575 Mdot
.778 .45796 Mdot
.778 .45822 Mdot
.778 .45858 Mdot
.778 .45859 Mdot
.778 .45908 Mdot
.778 .45937 Mdot
.778 .45943 Mdot
.778 .45993 Mdot
.778 .46004 Mdot
.778 .46018 Mdot
.778 .46066 Mdot
.778 .46066 Mdot
.778 .46138 Mdot
.778 .4614 Mdot
.778 .4618 Mdot
.778 .46203 Mdot
.778 .46207 Mdot
.778 .46221 Mdot
.778 .46226 Mdot
.778 .46254 Mdot
.778 .46278 Mdot
.778 .46301 Mdot
.778 .46335 Mdot
.778 .46338 Mdot
.778 .46355 Mdot
.778 .46363 Mdot
.778 .46373 Mdot
.778 .46477 Mdot
.778 .46499 Mdot
.778 .46572 Mdot
.778 .46578 Mdot
.778 .4658 Mdot
.778 .46586 Mdot
.778 .46606 Mdot
.778 .46642 Mdot
.778 .46712 Mdot
.778 .46749 Mdot
.778 .46772 Mdot
.778 .46816 Mdot
.778 .46816 Mdot
.778 .46846 Mdot
.778 .4692 Mdot
.778 .46925 Mdot
.778 .46976 Mdot
.778 .46981 Mdot
.778 .46983 Mdot
.778 .4699 Mdot
.778 .47034 Mdot
.778 .47055 Mdot
.778 .47091 Mdot
.778 .47158 Mdot
.778 .47187 Mdot
.778 .47223 Mdot
.778 .47261 Mdot
.778 .47273 Mdot
.778 .47274 Mdot
.778 .47286 Mdot
.778 .47324 Mdot
.778 .47346 Mdot
.778 .47357 Mdot
.78 .21769 Mdot
.78 .21788 Mdot
.78 .21793 Mdot
.78 .21981 Mdot
.78 .22012 Mdot
.78 .22015 Mdot
.78 .22029 Mdot
.78 .22059 Mdot
.78 .2207 Mdot
.78 .22071 Mdot
.78 .22174 Mdot
.78 .22177 Mdot
.78 .22185 Mdot
.78 .22236 Mdot
.78 .22259 Mdot
.78 .22283 Mdot
.78 .22293 Mdot
.78 .22298 Mdot
.78 .22336 Mdot
.78 .22357 Mdot
.78 .2238 Mdot
.78 .22409 Mdot
.78 .22499 Mdot
.78 .22533 Mdot
.78 .22664 Mdot
.78 .22784 Mdot
.78 .22786 Mdot
.78 .22866 Mdot
.78 .22876 Mdot
.78 .22951 Mdot
.78 .22953 Mdot
.78 .22956 Mdot
.78 .22978 Mdot
.78 .23005 Mdot
.78 .23034 Mdot
.78 .23039 Mdot
.78 .23046 Mdot
.78 .23048 Mdot
.78 .23133 Mdot
.78 .23162 Mdot
.78 .2318 Mdot
.78 .23192 Mdot
.78 .232 Mdot
.78 .23249 Mdot
.78 .2332 Mdot
.78 .23329 Mdot
.78 .23346 Mdot
.78 .23346 Mdot
.78 .2337 Mdot
.78 .23383 Mdot
.78 .23396 Mdot
.78 .23413 Mdot
.78 .23446 Mdot
.78 .23458 Mdot
.78 .23473 Mdot
.78 .23676 Mdot
.78 .23723 Mdot
.78 .23724 Mdot
.78 .23754 Mdot
.78 .23767 Mdot
.78 .23805 Mdot
.78 .23822 Mdot
.78 .23834 Mdot
.78 .23849 Mdot
.78 .23853 Mdot
.78 .23855 Mdot
.78 .23861 Mdot
.78 .23924 Mdot
.78 .2396 Mdot
.78 .24004 Mdot
.78 .24052 Mdot
.78 .24089 Mdot
.78 .24137 Mdot
.78 .24347 Mdot
.78 .24411 Mdot
.78 .24451 Mdot
.78 .24494 Mdot
.78 .24559 Mdot
.78 .24638 Mdot
.78 .24655 Mdot
.78 .2466 Mdot
.78 .24685 Mdot
.78 .2472 Mdot
.78 .24751 Mdot
.78 .24828 Mdot
.78 .24896 Mdot
.78 .24905 Mdot
.78 .24918 Mdot
.78 .24948 Mdot
.78 .2505 Mdot
.78 .25069 Mdot
.78 .25079 Mdot
.78 .25177 Mdot
.78 .25214 Mdot
.78 .25254 Mdot
.78 .25263 Mdot
.78 .25302 Mdot
.78 .2533 Mdot
.78 .25391 Mdot
.78 .2542 Mdot
.78 .2549 Mdot
.78 .25515 Mdot
.78 .25561 Mdot
.78 .25575 Mdot
.78 .25603 Mdot
.78 .25631 Mdot
.78 .25707 Mdot
.78 .25709 Mdot
.78 .25728 Mdot
.78 .25742 Mdot
.78 .25762 Mdot
.78 .25831 Mdot
.78 .25852 Mdot
.78 .25892 Mdot
.78 .25893 Mdot
.78 .25896 Mdot
.78 .25936 Mdot
.78 .25972 Mdot
.78 .25978 Mdot
.78 .25999 Mdot
.78 .26 Mdot
.78 .26072 Mdot
.78 .26103 Mdot
.78 .26128 Mdot
.78 .26167 Mdot
.78 .26203 Mdot
.78 .26363 Mdot
.78 .26449 Mdot
.78 .26463 Mdot
.78 .26489 Mdot
.78 .26508 Mdot
.78 .26517 Mdot
.78 .2652 Mdot
.78 .26563 Mdot
.78 .26601 Mdot
.78 .26606 Mdot
.78 .26656 Mdot
.78 .26668 Mdot
.78 .26783 Mdot
.78 .26796 Mdot
.78 .26808 Mdot
.78 .26825 Mdot
.78 .26877 Mdot
.78 .26944 Mdot
.78 .26975 Mdot
.78 .26988 Mdot
.78 .26989 Mdot
.78 .27061 Mdot
.78 .27064 Mdot
.78 .27071 Mdot
.78 .27081 Mdot
.78 .2709 Mdot
.78 .27124 Mdot
.78 .2718 Mdot
.78 .27226 Mdot
.78 .27264 Mdot
.78 .27376 Mdot
.78 .27377 Mdot
.78 .27393 Mdot
.78 .27427 Mdot
.78 .27439 Mdot
.78 .27443 Mdot
.78 .27447 Mdot
.78 .27455 Mdot
.78 .27523 Mdot
.78 .27562 Mdot
.78 .2763 Mdot
.78 .27637 Mdot
.78 .27648 Mdot
.78 .27665 Mdot
.78 .27778 Mdot
.78 .27793 Mdot
.78 .27797 Mdot
.78 .2788 Mdot
.78 .27891 Mdot
.78 .27903 Mdot
.78 .27913 Mdot
.78 .27926 Mdot
.78 .27977 Mdot
.78 .28028 Mdot
.78 .28091 Mdot
.78 .28132 Mdot
.78 .28136 Mdot
.78 .28137 Mdot
.78 .28211 Mdot
.78 .28433 Mdot
.78 .28526 Mdot
.78 .28541 Mdot
.78 .28569 Mdot
.78 .28613 Mdot
.78 .28616 Mdot
.78 .28618 Mdot
.78 .28624 Mdot
.78 .28638 Mdot
.78 .28645 Mdot
.78 .28691 Mdot
.78 .28726 Mdot
.78 .28763 Mdot
.78 .28771 Mdot
.78 .28804 Mdot
.78 .2885 Mdot
.78 .28879 Mdot
.78 .28889 Mdot
.78 .28941 Mdot
.78 .28979 Mdot
.78 .28997 Mdot
.78 .29002 Mdot
.78 .2902 Mdot
.78 .29127 Mdot
.78 .29142 Mdot
.78 .29158 Mdot
.78 .29181 Mdot
.78 .2921 Mdot
.78 .29211 Mdot
.78 .29222 Mdot
.78 .29237 Mdot
.78 .29254 Mdot
.78 .29271 Mdot
.78 .2928 Mdot
.78 .29308 Mdot
.78 .29322 Mdot
.78 .2942 Mdot
.78 .29449 Mdot
.78 .29461 Mdot
.78 .29486 Mdot
.78 .29513 Mdot
.78 .29643 Mdot
.78 .29655 Mdot
.78 .29736 Mdot
.78 .29761 Mdot
.78 .29763 Mdot
.78 .29803 Mdot
.78 .29829 Mdot
.78 .29847 Mdot
.78 .2989 Mdot
.78 .30011 Mdot
.78 .30049 Mdot
.78 .3009 Mdot
.78 .30094 Mdot
.78 .30106 Mdot
.78 .30146 Mdot
.78 .30165 Mdot
.78 .30249 Mdot
.78 .30273 Mdot
.78 .30286 Mdot
.78 .30291 Mdot
.78 .30301 Mdot
.78 .30312 Mdot
.78 .30341 Mdot
.78 .30365 Mdot
.78 .30369 Mdot
.78 .30377 Mdot
.78 .30389 Mdot
.78 .30423 Mdot
.78 .30461 Mdot
.78 .30463 Mdot
.78 .30494 Mdot
.78 .30738 Mdot
.78 .30825 Mdot
.78 .3083 Mdot
.78 .30842 Mdot
.78 .30848 Mdot
.78 .30849 Mdot
.78 .30941 Mdot
.78 .3099 Mdot
.78 .31 Mdot
.78 .31077 Mdot
.78 .31114 Mdot
.78 .31156 Mdot
.78 .31158 Mdot
.78 .31161 Mdot
.78 .31182 Mdot
.78 .31192 Mdot
.78 .31205 Mdot
.78 .31207 Mdot
.78 .31223 Mdot
.78 .31232 Mdot
.78 .31241 Mdot
.78 .31253 Mdot
.78 .3129 Mdot
.78 .31304 Mdot
.78 .31358 Mdot
.78 .31407 Mdot
.78 .31408 Mdot
.78 .31441 Mdot
.78 .31477 Mdot
.78 .31487 Mdot
.78 .31498 Mdot
.78 .3151 Mdot
.78 .31512 Mdot
.78 .31515 Mdot
.78 .31578 Mdot
.78 .31631 Mdot
.78 .31638 Mdot
.78 .31659 Mdot
.78 .31679 Mdot
.78 .31684 Mdot
.78 .31793 Mdot
.78 .31806 Mdot
.78 .31811 Mdot
.78 .31827 Mdot
.78 .31839 Mdot
.78 .31847 Mdot
.78 .31847 Mdot
.78 .31876 Mdot
.78 .31909 Mdot
.78 .31943 Mdot
.78 .31963 Mdot
.78 .32076 Mdot
.78 .32169 Mdot
.78 .32189 Mdot
.78 .32216 Mdot
.78 .32247 Mdot
.78 .32275 Mdot
.78 .32279 Mdot
.78 .32338 Mdot
.78 .32346 Mdot
.78 .3235 Mdot
.78 .32391 Mdot
.78 .32406 Mdot
.78 .32422 Mdot
.78 .32442 Mdot
.78 .3253 Mdot
.78 .32548 Mdot
.78 .32554 Mdot
.78 .32566 Mdot
.78 .32577 Mdot
.78 .32608 Mdot
.78 .32609 Mdot
.78 .32623 Mdot
.78 .32684 Mdot
.78 .32686 Mdot
.78 .3272 Mdot
.78 .32771 Mdot
.78 .32878 Mdot
.78 .32913 Mdot
.78 .3293 Mdot
.78 .32941 Mdot
.78 .32976 Mdot
.78 .32978 Mdot
.78 .33003 Mdot
.78 .33056 Mdot
.78 .33068 Mdot
.78 .33117 Mdot
.78 .33129 Mdot
.78 .33135 Mdot
.78 .33165 Mdot
.78 .33166 Mdot
.78 .33173 Mdot
.78 .33191 Mdot
.78 .33232 Mdot
.78 .33294 Mdot
.78 .3332 Mdot
.78 .33355 Mdot
.78 .33401 Mdot
.78 .33406 Mdot
.78 .33459 Mdot
.78 .33466 Mdot
.78 .33467 Mdot
.78 .33501 Mdot
.78 .33511 Mdot
.78 .33515 Mdot
.78 .3352 Mdot
.78 .33541 Mdot
.78 .33562 Mdot
.78 .33588 Mdot
.78 .33605 Mdot
.78 .33606 Mdot
.78 .33607 Mdot
.78 .33637 Mdot
.78 .33767 Mdot
.78 .33773 Mdot
.78 .33784 Mdot
.78 .33804 Mdot
.78 .33813 Mdot
.78 .33815 Mdot
.78 .33835 Mdot
.78 .33864 Mdot
.78 .33867 Mdot
.78 .33881 Mdot
.78 .339 Mdot
.78 .33916 Mdot
.78 .33937 Mdot
.78 .33953 Mdot
.78 .3396 Mdot
.78 .3397 Mdot
.78 .3402 Mdot
.78 .34048 Mdot
.78 .34053 Mdot
.78 .34066 Mdot
.78 .34073 Mdot
.78 .34077 Mdot
.78 .34088 Mdot
.78 .34094 Mdot
.78 .34134 Mdot
.78 .34151 Mdot
.78 .34172 Mdot
.78 .34226 Mdot
.78 .34231 Mdot
.78 .34264 Mdot
.78 .34275 Mdot
.78 .34327 Mdot
.78 .34392 Mdot
.78 .34409 Mdot
.78 .34411 Mdot
.78 .34432 Mdot
.78 .3444 Mdot
.78 .34475 Mdot
.78 .3449 Mdot
.78 .34522 Mdot
.78 .34524 Mdot
.78 .34527 Mdot
.78 .34532 Mdot
.78 .34576 Mdot
.78 .34711 Mdot
.78 .34719 Mdot
.78 .34721 Mdot
.78 .34721 Mdot
.78 .34779 Mdot
.78 .34783 Mdot
.78 .3483 Mdot
.78 .34848 Mdot
.78 .34848 Mdot
.78 .34862 Mdot
.78 .34868 Mdot
.78 .34882 Mdot
.78 .34887 Mdot
.78 .34903 Mdot
.78 .34908 Mdot
.78 .3493 Mdot
.78 .34979 Mdot
.78 .34983 Mdot
.78 .34988 Mdot
.78 .34993 Mdot
.78 .34994 Mdot
.78 .35021 Mdot
.78 .35043 Mdot
.78 .35046 Mdot
.78 .35054 Mdot
.78 .35064 Mdot
.78 .35109 Mdot
.78 .35117 Mdot
.78 .35123 Mdot
.78 .35128 Mdot
.78 .35131 Mdot
.78 .35171 Mdot
.78 .35179 Mdot
.78 .35225 Mdot
.78 .35264 Mdot
.78 .35296 Mdot
.78 .35307 Mdot
.78 .35309 Mdot
.78 .35337 Mdot
.78 .35355 Mdot
.78 .35361 Mdot
.78 .35368 Mdot
.78 .35412 Mdot
.78 .35427 Mdot
.78 .35444 Mdot
.78 .35444 Mdot
.78 .35475 Mdot
.78 .35511 Mdot
.78 .35555 Mdot
.78 .3557 Mdot
.78 .35581 Mdot
.78 .35595 Mdot
.78 .35596 Mdot
.78 .35606 Mdot
.78 .35628 Mdot
.78 .35633 Mdot
.78 .35653 Mdot
.78 .35658 Mdot
.78 .35673 Mdot
.78 .35684 Mdot
.78 .35701 Mdot
.78 .35726 Mdot
.78 .35751 Mdot
.78 .3577 Mdot
.78 .35794 Mdot
.78 .35797 Mdot
.78 .35815 Mdot
.78 .35855 Mdot
.78 .35936 Mdot
.78 .35948 Mdot
.78 .35981 Mdot
.78 .36036 Mdot
.78 .36055 Mdot
.78 .36078 Mdot
.78 .36111 Mdot
.78 .36125 Mdot
.78 .36184 Mdot
.78 .36185 Mdot
.78 .36194 Mdot
.78 .36217 Mdot
.78 .36231 Mdot
.78 .36253 Mdot
.78 .36312 Mdot
.78 .36338 Mdot
.78 .36357 Mdot
.78 .36373 Mdot
.78 .36381 Mdot
.78 .36387 Mdot
.78 .36389 Mdot
.78 .36398 Mdot
.78 .36424 Mdot
.78 .36445 Mdot
.78 .36446 Mdot
.78 .36478 Mdot
.78 .36497 Mdot
.78 .36501 Mdot
.78 .36553 Mdot
.78 .36575 Mdot
.78 .36602 Mdot
.78 .36622 Mdot
.78 .36666 Mdot
.78 .36697 Mdot
.78 .36708 Mdot
.78 .36755 Mdot
.78 .36778 Mdot
.78 .36811 Mdot
.78 .36817 Mdot
.78 .3683 Mdot
.78 .36853 Mdot
.78 .36917 Mdot
.78 .36927 Mdot
.78 .37012 Mdot
.78 .37021 Mdot
.78 .37074 Mdot
.78 .37085 Mdot
.78 .37129 Mdot
.78 .37158 Mdot
.78 .37171 Mdot
.78 .37173 Mdot
.78 .37215 Mdot
.78 .37257 Mdot
.78 .37319 Mdot
.78 .3732 Mdot
.78 .37337 Mdot
.78 .37387 Mdot
.78 .37477 Mdot
.78 .37488 Mdot
.78 .37555 Mdot
.78 .37582 Mdot
.78 .37583 Mdot
.78 .37611 Mdot
.78 .37638 Mdot
.78 .37645 Mdot
.78 .3768 Mdot
.78 .37685 Mdot
.78 .3774 Mdot
.78 .37746 Mdot
.78 .37788 Mdot
.78 .37811 Mdot
.78 .37814 Mdot
.78 .37835 Mdot
.78 .3788 Mdot
.78 .37907 Mdot
.78 .37948 Mdot
.78 .37965 Mdot
.78 .38013 Mdot
.78 .38028 Mdot
.78 .38048 Mdot
.78 .38049 Mdot
.78 .38062 Mdot
.78 .38095 Mdot
.78 .38195 Mdot
.78 .3821 Mdot
.78 .38254 Mdot
.78 .38284 Mdot
.78 .38299 Mdot
.78 .38311 Mdot
.78 .38346 Mdot
.78 .38367 Mdot
.78 .38375 Mdot
.78 .38427 Mdot
.78 .38453 Mdot
.78 .38464 Mdot
.78 .3851 Mdot
.78 .38537 Mdot
.78 .38553 Mdot
.78 .38573 Mdot
.78 .38586 Mdot
.78 .38603 Mdot
.78 .38648 Mdot
.78 .3867 Mdot
.78 .3869 Mdot
.78 .38702 Mdot
.78 .38744 Mdot
.78 .38778 Mdot
.78 .38786 Mdot
.78 .38831 Mdot
.78 .3886 Mdot
.78 .38866 Mdot
.78 .38896 Mdot
.78 .38941 Mdot
.78 .38946 Mdot
.78 .38948 Mdot
.78 .38979 Mdot
.78 .3898 Mdot
.78 .3902 Mdot
.78 .39034 Mdot
.78 .39038 Mdot
.78 .39047 Mdot
.78 .39051 Mdot
.78 .3906 Mdot
.78 .39072 Mdot
.78 .39084 Mdot
.78 .39114 Mdot
.78 .39117 Mdot
.78 .39154 Mdot
.78 .3916 Mdot
.78 .39247 Mdot
.78 .39278 Mdot
.78 .3928 Mdot
.78 .39281 Mdot
.78 .39302 Mdot
.78 .39312 Mdot
.78 .39334 Mdot
.78 .39339 Mdot
.78 .39353 Mdot
.78 .39354 Mdot
.78 .39365 Mdot
.78 .39447 Mdot
.78 .39468 Mdot
.78 .39472 Mdot
.78 .39506 Mdot
.78 .39519 Mdot
.78 .39556 Mdot
.78 .39567 Mdot
.78 .39569 Mdot
.78 .39574 Mdot
.78 .39585 Mdot
.78 .39636 Mdot
.78 .3967 Mdot
.78 .39692 Mdot
.78 .39701 Mdot
.78 .39722 Mdot
.78 .39734 Mdot
.78 .39736 Mdot
.78 .39742 Mdot
.78 .39849 Mdot
.78 .39868 Mdot
.78 .39897 Mdot
.78 .3993 Mdot
.78 .39936 Mdot
.78 .39958 Mdot
.78 .39963 Mdot
.78 .39997 Mdot
.78 .4 Mdot
.78 .4003 Mdot
.78 .40052 Mdot
.78 .40069 Mdot
.78 .40108 Mdot
.78 .40135 Mdot
.78 .40151 Mdot
.78 .40174 Mdot
.78 .40182 Mdot
.78 .40214 Mdot
.78 .40221 Mdot
.78 .40255 Mdot
.78 .40271 Mdot
.78 .40273 Mdot
.78 .40295 Mdot
.78 .40302 Mdot
.78 .40313 Mdot
.78 .40335 Mdot
.78 .40404 Mdot
.78 .40437 Mdot
.78 .40458 Mdot
.78 .4046 Mdot
.78 .40499 Mdot
.78 .40508 Mdot
.78 .40508 Mdot
.78 .40528 Mdot
.78 .40536 Mdot
.78 .40543 Mdot
.78 .40547 Mdot
.78 .40559 Mdot
.78 .40615 Mdot
.78 .40628 Mdot
.78 .40638 Mdot
.78 .40648 Mdot
.78 .40674 Mdot
.78 .40676 Mdot
.78 .40681 Mdot
.78 .40719 Mdot
.78 .40722 Mdot
.78 .4074 Mdot
.78 .4076 Mdot
.78 .40777 Mdot
.78 .4079 Mdot
.78 .4085 Mdot
.78 .40922 Mdot
.78 .40934 Mdot
.78 .40957 Mdot
.78 .40978 Mdot
.78 .40996 Mdot
.78 .40997 Mdot
.78 .41002 Mdot
.78 .41009 Mdot
.78 .41019 Mdot
.78 .41023 Mdot
.78 .41031 Mdot
.78 .41101 Mdot
.78 .41104 Mdot
.78 .41117 Mdot
.78 .4113 Mdot
.78 .41135 Mdot
.78 .41169 Mdot
.78 .41209 Mdot
.78 .41211 Mdot
.78 .41212 Mdot
.78 .4122 Mdot
.78 .41227 Mdot
.78 .41234 Mdot
.78 .41256 Mdot
.78 .41278 Mdot
.78 .41278 Mdot
.78 .4131 Mdot
.78 .41344 Mdot
.78 .41353 Mdot
.78 .41377 Mdot
.78 .41385 Mdot
.78 .41391 Mdot
.78 .41396 Mdot
.78 .41406 Mdot
.78 .41408 Mdot
.78 .41416 Mdot
.78 .41423 Mdot
.78 .41436 Mdot
.78 .41438 Mdot
.78 .41439 Mdot
.78 .41466 Mdot
.78 .4149 Mdot
.78 .41539 Mdot
.78 .41546 Mdot
.78 .41577 Mdot
.78 .41636 Mdot
.78 .41637 Mdot
.78 .4164 Mdot
.78 .41648 Mdot
.78 .41651 Mdot
.78 .41707 Mdot
.78 .41863 Mdot
.78 .41883 Mdot
.78 .41885 Mdot
.78 .41909 Mdot
.78 .41931 Mdot
.78 .41939 Mdot
.78 .41944 Mdot
.78 .41947 Mdot
.78 .41962 Mdot
.78 .4198 Mdot
.78 .41987 Mdot
.78 .41994 Mdot
.78 .41997 Mdot
.78 .42005 Mdot
.78 .42021 Mdot
.78 .42074 Mdot
.78 .42087 Mdot
.78 .42113 Mdot
.78 .4212 Mdot
.78 .42123 Mdot
.78 .42149 Mdot
.78 .42173 Mdot
.78 .42251 Mdot
.78 .42278 Mdot
.78 .4229 Mdot
.78 .42307 Mdot
.78 .42332 Mdot
.78 .42333 Mdot
.78 .42349 Mdot
.78 .42401 Mdot
.78 .42409 Mdot
.78 .42492 Mdot
.78 .4251 Mdot
.78 .42526 Mdot
.78 .42533 Mdot
.78 .42539 Mdot
.78 .42552 Mdot
.78 .42615 Mdot
.78 .42624 Mdot
.78 .42642 Mdot
.78 .42647 Mdot
.78 .42658 Mdot
.78 .42669 Mdot
.78 .42679 Mdot
.78 .42686 Mdot
.78 .42686 Mdot
.78 .42705 Mdot
.78 .4272 Mdot
.78 .4273 Mdot
.78 .4274 Mdot
.78 .42808 Mdot
.78 .4282 Mdot
.78 .42823 Mdot
.78 .42835 Mdot
.78 .42859 Mdot
.78 .42892 Mdot
.78 .42899 Mdot
.78 .42917 Mdot
.78 .42947 Mdot
.78 .42968 Mdot
.78 .42973 Mdot
.78 .42997 Mdot
.78 .43019 Mdot
.78 .43049 Mdot
.78 .43053 Mdot
.78 .43062 Mdot
.78 .43066 Mdot
.78 .43068 Mdot
.78 .43069 Mdot
.78 .43098 Mdot
.78 .43116 Mdot
.78 .43125 Mdot
.78 .43185 Mdot
.78 .43327 Mdot
.78 .43375 Mdot
.78 .43375 Mdot
.78 .43378 Mdot
.78 .43404 Mdot
.78 .43445 Mdot
.78 .43477 Mdot
.78 .4351 Mdot
.78 .43518 Mdot
.78 .43524 Mdot
.78 .43532 Mdot
.78 .43539 Mdot
.78 .43592 Mdot
.78 .43595 Mdot
.78 .43605 Mdot
.78 .43677 Mdot
.78 .43688 Mdot
.78 .43695 Mdot
.78 .437 Mdot
.78 .43743 Mdot
.78 .43768 Mdot
.78 .43812 Mdot
.78 .43817 Mdot
.78 .43819 Mdot
.78 .43822 Mdot
.78 .4383 Mdot
.78 .43852 Mdot
.78 .43861 Mdot
.78 .43862 Mdot
.78 .43934 Mdot
.78 .43959 Mdot
.78 .43988 Mdot
.78 .44024 Mdot
.78 .44046 Mdot
.78 .44051 Mdot
.78 .44058 Mdot
.78 .44062 Mdot
.78 .44064 Mdot
.78 .44111 Mdot
.78 .44111 Mdot
.78 .4412 Mdot
.78 .44139 Mdot
.78 .44182 Mdot
.78 .44216 Mdot
.78 .44227 Mdot
.78 .44234 Mdot
.78 .44243 Mdot
.78 .44316 Mdot
.78 .44324 Mdot
.78 .44356 Mdot
.78 .44359 Mdot
.78 .44383 Mdot
.78 .44411 Mdot
.78 .44413 Mdot
.78 .44419 Mdot
.78 .44431 Mdot
.78 .44448 Mdot
.78 .44456 Mdot
.78 .44512 Mdot
.78 .44614 Mdot
.78 .44637 Mdot
.78 .44662 Mdot
.78 .44678 Mdot
.78 .44698 Mdot
.78 .44744 Mdot
.78 .44745 Mdot
.78 .44759 Mdot
.78 .44762 Mdot
.78 .44786 Mdot
.78 .44811 Mdot
.78 .44813 Mdot
.78 .44814 Mdot
.78 .44839 Mdot
.78 .44853 Mdot
.78 .44897 Mdot
.78 .4491 Mdot
.78 .44919 Mdot
.78 .44931 Mdot
.78 .44932 Mdot
.78 .44981 Mdot
.78 .44999 Mdot
.78 .45017 Mdot
.78 .45026 Mdot
.78 .45055 Mdot
.78 .45071 Mdot
.78 .45116 Mdot
.78 .45135 Mdot
.78 .45174 Mdot
.78 .45192 Mdot
.78 .45217 Mdot
.78 .45222 Mdot
.78 .45248 Mdot
.78 .45272 Mdot
.78 .45335 Mdot
.78 .45341 Mdot
.78 .45353 Mdot
.78 .45419 Mdot
.78 .45438 Mdot
.78 .45446 Mdot
.78 .45452 Mdot
.78 .45496 Mdot
.78 .45545 Mdot
.78 .45565 Mdot
.78 .45587 Mdot
.78 .45603 Mdot
.78 .45606 Mdot
.78 .45618 Mdot
.78 .45668 Mdot
.78 .45709 Mdot
.78 .45737 Mdot
.78 .45763 Mdot
.78 .45804 Mdot
.78 .45938 Mdot
.78 .45969 Mdot
.78 .45993 Mdot
.78 .46024 Mdot
.78 .46052 Mdot
.78 .46075 Mdot
.78 .46116 Mdot
.78 .4612 Mdot
.78 .46121 Mdot
.78 .46123 Mdot
.78 .46133 Mdot
.78 .46141 Mdot
.78 .46151 Mdot
.78 .46176 Mdot
.78 .46184 Mdot
.78 .46204 Mdot
.78 .46204 Mdot
.78 .46234 Mdot
.78 .46364 Mdot
.78 .46374 Mdot
.78 .46382 Mdot
.78 .46403 Mdot
.78 .46414 Mdot
.78 .46422 Mdot
.78 .4643 Mdot
.78 .46446 Mdot
.78 .46446 Mdot
.78 .46456 Mdot
.78 .46462 Mdot
.78 .46508 Mdot
.78 .46539 Mdot
.78 .46545 Mdot
.78 .46552 Mdot
.78 .46564 Mdot
.78 .46582 Mdot
.78 .46637 Mdot
.78 .46638 Mdot
.78 .46643 Mdot
.78 .46646 Mdot
.78 .46664 Mdot
.78 .46682 Mdot
.78 .46695 Mdot
.78 .46697 Mdot
.78 .46699 Mdot
.78 .46747 Mdot
.78 .46753 Mdot
.78 .46805 Mdot
.78 .46806 Mdot
.78 .46883 Mdot
.78 .46967 Mdot
.78 .46988 Mdot
.78 .47046 Mdot
.78 .47065 Mdot
.78 .4708 Mdot
.78 .47093 Mdot
.78 .47118 Mdot
.78 .47121 Mdot
.78 .47127 Mdot
.78 .47142 Mdot
.78 .47157 Mdot
.78 .4719 Mdot
.78 .47195 Mdot
.78 .47197 Mdot
.78 .47263 Mdot
.78 .47264 Mdot
.78 .47271 Mdot
.78 .4729 Mdot
.78 .47299 Mdot
.78 .47301 Mdot
.78 .47321 Mdot
.78 .47441 Mdot
.78 .47445 Mdot
.78 .47457 Mdot
.782 .216 Mdot
.782 .21684 Mdot
.782 .21754 Mdot
.782 .2179 Mdot
.782 .2182 Mdot
.782 .21908 Mdot
.782 .21923 Mdot
.782 .21952 Mdot
.782 .21978 Mdot
.782 .22099 Mdot
.782 .22099 Mdot
.782 .22145 Mdot
.782 .22196 Mdot
.782 .22234 Mdot
.782 .22271 Mdot
.782 .2229 Mdot
.782 .22298 Mdot
.782 .22306 Mdot
.782 .22333 Mdot
.782 .22376 Mdot
.782 .22405 Mdot
.782 .22442 Mdot
.782 .22616 Mdot
.782 .22653 Mdot
.782 .22751 Mdot
.782 .22783 Mdot
.782 .22824 Mdot
.782 .22827 Mdot
.782 .2285 Mdot
.782 .2286 Mdot
.782 .22936 Mdot
.782 .22984 Mdot
.782 .22997 Mdot
.782 .23043 Mdot
.782 .23055 Mdot
.782 .23164 Mdot
.782 .23221 Mdot
.782 .23276 Mdot
.782 .23332 Mdot
.782 .23347 Mdot
.782 .23356 Mdot
.782 .23418 Mdot
.782 .2344 Mdot
.782 .23448 Mdot
.782 .23463 Mdot
.782 .23472 Mdot
.782 .23558 Mdot
.782 .23574 Mdot
.782 .23591 Mdot
.782 .2364 Mdot
.782 .23646 Mdot
.782 .23678 Mdot
.782 .23732 Mdot
.782 .23741 Mdot
.782 .23833 Mdot
.782 .23838 Mdot
.782 .23847 Mdot
.782 .23875 Mdot
.782 .23877 Mdot
.782 .23904 Mdot
.782 .23946 Mdot
.782 .24005 Mdot
.782 .24017 Mdot
.782 .24077 Mdot
.782 .24096 Mdot
.782 .24096 Mdot
.782 .24118 Mdot
.782 .24139 Mdot
.782 .2425 Mdot
.782 .24253 Mdot
.782 .24441 Mdot
.782 .24449 Mdot
.782 .24464 Mdot
.782 .24493 Mdot
.782 .24516 Mdot
.782 .24618 Mdot
.782 .24663 Mdot
.782 .24665 Mdot
.782 .2467 Mdot
.782 .247 Mdot
.782 .24729 Mdot
.782 .24794 Mdot
.782 .24805 Mdot
.782 .24838 Mdot
.782 .24838 Mdot
.782 .24883 Mdot
.782 .24959 Mdot
.782 .25051 Mdot
.782 .25076 Mdot
.782 .25109 Mdot
.782 .25133 Mdot
.782 .2514 Mdot
.782 .25208 Mdot
.782 .25211 Mdot
.782 .25409 Mdot
.782 .25425 Mdot
.782 .2547 Mdot
.782 .25478 Mdot
.782 .2553 Mdot
.782 .25665 Mdot
.782 .25685 Mdot
.782 .25692 Mdot
.782 .25722 Mdot
.782 .2576 Mdot
.782 .25813 Mdot
.782 .25845 Mdot
.782 .25979 Mdot
.782 .26062 Mdot
.782 .26063 Mdot
.782 .26065 Mdot
.782 .26078 Mdot
.782 .26108 Mdot
.782 .2612 Mdot
.782 .26141 Mdot
.782 .26186 Mdot
.782 .26187 Mdot
.782 .26216 Mdot
.782 .26269 Mdot
.782 .26286 Mdot
.782 .26376 Mdot
.782 .26399 Mdot
.782 .26436 Mdot
.782 .26483 Mdot
.782 .26555 Mdot
.782 .26608 Mdot
.782 .26648 Mdot
.782 .26655 Mdot
.782 .26707 Mdot
.782 .26714 Mdot
.782 .26717 Mdot
.782 .26746 Mdot
.782 .26757 Mdot
.782 .26758 Mdot
.782 .26774 Mdot
.782 .26775 Mdot
.782 .26784 Mdot
.782 .26819 Mdot
.782 .2682 Mdot
.782 .26828 Mdot
.782 .26838 Mdot
.782 .26851 Mdot
.782 .2686 Mdot
.782 .26934 Mdot
.782 .27015 Mdot
.782 .27025 Mdot
.782 .27077 Mdot
.782 .271 Mdot
.782 .27162 Mdot
.782 .27227 Mdot
.782 .27248 Mdot
.782 .27258 Mdot
.782 .27266 Mdot
.782 .2727 Mdot
.782 .27277 Mdot
.782 .27428 Mdot
.782 .27511 Mdot
.782 .27528 Mdot
.782 .27579 Mdot
.782 .27615 Mdot
.782 .2764 Mdot
.782 .27654 Mdot
.782 .27672 Mdot
.782 .27717 Mdot
.782 .27722 Mdot
.782 .27783 Mdot
.782 .27793 Mdot
.782 .2782 Mdot
.782 .27825 Mdot
.782 .27882 Mdot
.782 .27903 Mdot
.782 .27919 Mdot
.782 .27934 Mdot
.782 .27973 Mdot
.782 .2798 Mdot
.782 .27991 Mdot
.782 .28001 Mdot
.782 .28002 Mdot
.782 .28008 Mdot
.782 .28015 Mdot
.782 .28076 Mdot
.782 .28201 Mdot
.782 .28218 Mdot
.782 .28265 Mdot
.782 .28316 Mdot
.782 .28344 Mdot
.782 .28347 Mdot
.782 .28359 Mdot
.782 .28419 Mdot
.782 .28495 Mdot
.782 .2852 Mdot
.782 .28582 Mdot
.782 .28646 Mdot
.782 .28648 Mdot
.782 .28664 Mdot
.782 .28716 Mdot
.782 .2875 Mdot
.782 .28814 Mdot
.782 .28823 Mdot
.782 .2883 Mdot
.782 .28845 Mdot
.782 .28849 Mdot
.782 .2886 Mdot
.782 .28872 Mdot
.782 .289 Mdot
.782 .28917 Mdot
.782 .28968 Mdot
.782 .29002 Mdot
.782 .29012 Mdot
.782 .29048 Mdot
.782 .29077 Mdot
.782 .29089 Mdot
.782 .29108 Mdot
.782 .29121 Mdot
.782 .29133 Mdot
.782 .29139 Mdot
.782 .29139 Mdot
.782 .2914 Mdot
.782 .29242 Mdot
.782 .29279 Mdot
.782 .29291 Mdot
.782 .29294 Mdot
.782 .29357 Mdot
.782 .29382 Mdot
.782 .29407 Mdot
.782 .29488 Mdot
.782 .29517 Mdot
.782 .2953 Mdot
.782 .29543 Mdot
.782 .29591 Mdot
.782 .29622 Mdot
.782 .2964 Mdot
.782 .2964 Mdot
.782 .29654 Mdot
.782 .29659 Mdot
.782 .29697 Mdot
.782 .2973 Mdot
.782 .29793 Mdot
.782 .29803 Mdot
.782 .29881 Mdot
.782 .29944 Mdot
.782 .30005 Mdot
.782 .30018 Mdot
.782 .30034 Mdot
.782 .30046 Mdot
.782 .30212 Mdot
.782 .3025 Mdot
.782 .30256 Mdot
.782 .30325 Mdot
.782 .30374 Mdot
.782 .30453 Mdot
.782 .30463 Mdot
.782 .30464 Mdot
.782 .30534 Mdot
.782 .3062 Mdot
.782 .30635 Mdot
.782 .30647 Mdot
.782 .30664 Mdot
.782 .30675 Mdot
.782 .3069 Mdot
.782 .30741 Mdot
.782 .30838 Mdot
.782 .30874 Mdot
.782 .30901 Mdot
.782 .3093 Mdot
.782 .30964 Mdot
.782 .31053 Mdot
.782 .31107 Mdot
.782 .31119 Mdot
.782 .3113 Mdot
.782 .31179 Mdot
.782 .31179 Mdot
.782 .31219 Mdot
.782 .31234 Mdot
.782 .31257 Mdot
.782 .31261 Mdot
.782 .31391 Mdot
.782 .31446 Mdot
.782 .31459 Mdot
.782 .3149 Mdot
.782 .31521 Mdot
.782 .31541 Mdot
.782 .31546 Mdot
.782 .3157 Mdot
.782 .31638 Mdot
.782 .31661 Mdot
.782 .31693 Mdot
.782 .31718 Mdot
.782 .31731 Mdot
.782 .31737 Mdot
.782 .3174 Mdot
.782 .31776 Mdot
.782 .31782 Mdot
.782 .31789 Mdot
.782 .31809 Mdot
.782 .31811 Mdot
.782 .31825 Mdot
.782 .31847 Mdot
.782 .3185 Mdot
.782 .31888 Mdot
.782 .3189 Mdot
.782 .31906 Mdot
.782 .31917 Mdot
.782 .31958 Mdot
.782 .31963 Mdot
.782 .31988 Mdot
.782 .31996 Mdot
.782 .32004 Mdot
.782 .32013 Mdot
.782 .3206 Mdot
.782 .3214 Mdot
.782 .32158 Mdot
.782 .32167 Mdot
.782 .32228 Mdot
.782 .32228 Mdot
.782 .3223 Mdot
.782 .32254 Mdot
.782 .32386 Mdot
.782 .32419 Mdot
.782 .3245 Mdot
.782 .32539 Mdot
.782 .32561 Mdot
.782 .32637 Mdot
.782 .32676 Mdot
.782 .32711 Mdot
.782 .32765 Mdot
.782 .32823 Mdot
.782 .3285 Mdot
.782 .32884 Mdot
.782 .32952 Mdot
.782 .33001 Mdot
.782 .33042 Mdot
.782 .33063 Mdot
.782 .33066 Mdot
.782 .33084 Mdot
.782 .33084 Mdot
.782 .33091 Mdot
.782 .33109 Mdot
.782 .33112 Mdot
.782 .33122 Mdot
.782 .33156 Mdot
.782 .33193 Mdot
.782 .33214 Mdot
.782 .33249 Mdot
.782 .33284 Mdot
.782 .33288 Mdot
.782 .33296 Mdot
.782 .33392 Mdot
.782 .33399 Mdot
.782 .33434 Mdot
.782 .3345 Mdot
.782 .33457 Mdot
.782 .33476 Mdot
.782 .33478 Mdot
.782 .33503 Mdot
.782 .33507 Mdot
.782 .33518 Mdot
.782 .33543 Mdot
.782 .33552 Mdot
.782 .33559 Mdot
.782 .33565 Mdot
.782 .33583 Mdot
.782 .33588 Mdot
.782 .33592 Mdot
.782 .33598 Mdot
.782 .33681 Mdot
.782 .337 Mdot
.782 .33732 Mdot
.782 .33733 Mdot
.782 .33763 Mdot
.782 .33794 Mdot
.782 .33804 Mdot
.782 .33829 Mdot
.782 .33856 Mdot
.782 .33856 Mdot
.782 .33884 Mdot
.782 .33898 Mdot
.782 .33928 Mdot
.782 .33943 Mdot
.782 .33987 Mdot
.782 .34001 Mdot
.782 .34032 Mdot
.782 .34045 Mdot
.782 .3405 Mdot
.782 .34055 Mdot
.782 .34057 Mdot
.782 .34057 Mdot
.782 .34099 Mdot
.782 .34121 Mdot
.782 .34167 Mdot
.782 .342 Mdot
.782 .34212 Mdot
.782 .34242 Mdot
.782 .34255 Mdot
.782 .34262 Mdot
.782 .34262 Mdot
.782 .3427 Mdot
.782 .34329 Mdot
.782 .34386 Mdot
.782 .34417 Mdot
.782 .34423 Mdot
.782 .34496 Mdot
.782 .34514 Mdot
.782 .34542 Mdot
.782 .34562 Mdot
.782 .34594 Mdot
.782 .34598 Mdot
.782 .34599 Mdot
.782 .34627 Mdot
.782 .34685 Mdot
.782 .34752 Mdot
.782 .34767 Mdot
.782 .34789 Mdot
.782 .34803 Mdot
.782 .34867 Mdot
.782 .34871 Mdot
.782 .34891 Mdot
.782 .34891 Mdot
.782 .34907 Mdot
.782 .34923 Mdot
.782 .34978 Mdot
.782 .35 Mdot
.782 .35019 Mdot
.782 .35031 Mdot
.782 .35039 Mdot
.782 .35041 Mdot
.782 .35051 Mdot
.782 .35117 Mdot
.782 .35135 Mdot
.782 .35138 Mdot
.782 .35141 Mdot
.782 .35149 Mdot
.782 .3515 Mdot
.782 .35189 Mdot
.782 .3521 Mdot
.782 .35212 Mdot
.782 .35229 Mdot
.782 .35251 Mdot
.782 .35295 Mdot
.782 .3532 Mdot
.782 .3532 Mdot
.782 .35321 Mdot
.782 .35398 Mdot
.782 .35411 Mdot
.782 .35447 Mdot
.782 .35487 Mdot
.782 .35517 Mdot
.782 .35574 Mdot
.782 .35588 Mdot
.782 .35636 Mdot
.782 .35661 Mdot
.782 .35663 Mdot
.782 .35673 Mdot
.782 .3568 Mdot
.782 .35682 Mdot
.782 .35686 Mdot
.782 .35699 Mdot
.782 .35796 Mdot
.782 .3583 Mdot
.782 .35843 Mdot
.782 .35847 Mdot
.782 .35864 Mdot
.782 .35867 Mdot
.782 .3588 Mdot
.782 .35914 Mdot
.782 .35922 Mdot
.782 .35975 Mdot
.782 .35986 Mdot
.782 .35986 Mdot
.782 .36003 Mdot
.782 .36015 Mdot
.782 .36039 Mdot
.782 .36065 Mdot
.782 .36067 Mdot
.782 .36068 Mdot
.782 .36143 Mdot
.782 .36149 Mdot
.782 .36152 Mdot
.782 .36152 Mdot
.782 .36202 Mdot
.782 .36215 Mdot
.782 .36288 Mdot
.782 .36289 Mdot
.782 .36301 Mdot
.782 .36325 Mdot
.782 .36358 Mdot
.782 .36367 Mdot
.782 .36409 Mdot
.782 .36444 Mdot
.782 .36453 Mdot
.782 .36466 Mdot
.782 .36474 Mdot
.782 .36509 Mdot
.782 .36511 Mdot
.782 .36514 Mdot
.782 .3654 Mdot
.782 .36556 Mdot
.782 .36574 Mdot
.782 .36584 Mdot
.782 .36584 Mdot
.782 .36585 Mdot
.782 .36621 Mdot
.782 .36636 Mdot
.782 .36665 Mdot
.782 .36694 Mdot
.782 .36713 Mdot
.782 .36724 Mdot
.782 .36732 Mdot
.782 .36827 Mdot
.782 .36852 Mdot
.782 .36856 Mdot
.782 .36856 Mdot
.782 .3689 Mdot
.782 .36923 Mdot
.782 .36924 Mdot
.782 .3695 Mdot
.782 .36995 Mdot
.782 .37008 Mdot
.782 .37012 Mdot
.782 .37029 Mdot
.782 .3707 Mdot
.782 .37083 Mdot
.782 .37097 Mdot
.782 .37101 Mdot
.782 .37122 Mdot
.782 .37158 Mdot
.782 .3725 Mdot
.782 .37283 Mdot
.782 .373 Mdot
.782 .37305 Mdot
.782 .37336 Mdot
.782 .37373 Mdot
.782 .37387 Mdot
.782 .37393 Mdot
.782 .37396 Mdot
.782 .37408 Mdot
.782 .37429 Mdot
.782 .37432 Mdot
.782 .37477 Mdot
.782 .375 Mdot
.782 .37504 Mdot
.782 .37513 Mdot
.782 .37537 Mdot
.782 .37556 Mdot
.782 .3756 Mdot
.782 .3757 Mdot
.782 .37591 Mdot
.782 .3765 Mdot
.782 .37673 Mdot
.782 .37698 Mdot
.782 .37707 Mdot
.782 .37733 Mdot
.782 .37744 Mdot
.782 .37746 Mdot
.782 .37755 Mdot
.782 .37783 Mdot
.782 .37801 Mdot
.782 .37846 Mdot
.782 .37928 Mdot
.782 .37947 Mdot
.782 .37966 Mdot
.782 .37984 Mdot
.782 .38017 Mdot
.782 .38017 Mdot
.782 .38017 Mdot
.782 .38024 Mdot
.782 .38046 Mdot
.782 .38066 Mdot
.782 .38088 Mdot
.782 .38129 Mdot
.782 .38156 Mdot
.782 .38162 Mdot
.782 .38183 Mdot
.782 .38206 Mdot
.782 .38253 Mdot
.782 .38294 Mdot
.782 .38296 Mdot
.782 .38347 Mdot
.782 .38349 Mdot
.782 .38389 Mdot
.782 .384 Mdot
.782 .384 Mdot
.782 .38407 Mdot
.782 .38441 Mdot
.782 .38446 Mdot
.782 .38478 Mdot
.782 .38488 Mdot
.782 .38594 Mdot
.782 .38595 Mdot
.782 .386 Mdot
.782 .38606 Mdot
.782 .38623 Mdot
.782 .38654 Mdot
.782 .38699 Mdot
.782 .38744 Mdot
.782 .38767 Mdot
.782 .38825 Mdot
.782 .38825 Mdot
.782 .38826 Mdot
.782 .38841 Mdot
.782 .38869 Mdot
.782 .38895 Mdot
.782 .3891 Mdot
.782 .38934 Mdot
.782 .38935 Mdot
.782 .3894 Mdot
.782 .38944 Mdot
.782 .38997 Mdot
.782 .39005 Mdot
.782 .3901 Mdot
.782 .39018 Mdot
.782 .3903 Mdot
.782 .39044 Mdot
.782 .391 Mdot
.782 .391 Mdot
.782 .39165 Mdot
.782 .39179 Mdot
.782 .39231 Mdot
.782 .39268 Mdot
.782 .39287 Mdot
.782 .39289 Mdot
.782 .3931 Mdot
.782 .39341 Mdot
.782 .39352 Mdot
.782 .39399 Mdot
.782 .39403 Mdot
.782 .39423 Mdot
.782 .39459 Mdot
.782 .39502 Mdot
.782 .39502 Mdot
.782 .39507 Mdot
.782 .39515 Mdot
.782 .39542 Mdot
.782 .39592 Mdot
.782 .39633 Mdot
.782 .39634 Mdot
.782 .39638 Mdot
.782 .39678 Mdot
.782 .39716 Mdot
.782 .39734 Mdot
.782 .39761 Mdot
.782 .39762 Mdot
.782 .39779 Mdot
.782 .39801 Mdot
.782 .39861 Mdot
.782 .39874 Mdot
.782 .39927 Mdot
.782 .3993 Mdot
.782 .39933 Mdot
.782 .39936 Mdot
.782 .39948 Mdot
.782 .39952 Mdot
.782 .39956 Mdot
.782 .39978 Mdot
.782 .39985 Mdot
.782 .40003 Mdot
.782 .40005 Mdot
.782 .40021 Mdot
.782 .40054 Mdot
.782 .40058 Mdot
.782 .40124 Mdot
.782 .40127 Mdot
.782 .40172 Mdot
.782 .40209 Mdot
.782 .40231 Mdot
.782 .40237 Mdot
.782 .40239 Mdot
.782 .40251 Mdot
.782 .40255 Mdot
.782 .40267 Mdot
.782 .40269 Mdot
.782 .40282 Mdot
.782 .40308 Mdot
.782 .40383 Mdot
.782 .40405 Mdot
.782 .40422 Mdot
.782 .40459 Mdot
.782 .40494 Mdot
.782 .40516 Mdot
.782 .40541 Mdot
.782 .4059 Mdot
.782 .40604 Mdot
.782 .4066 Mdot
.782 .4068 Mdot
.782 .40702 Mdot
.782 .40786 Mdot
.782 .40801 Mdot
.782 .40802 Mdot
.782 .40803 Mdot
.782 .40841 Mdot
.782 .40847 Mdot
.782 .40859 Mdot
.782 .4091 Mdot
.782 .4094 Mdot
.782 .40945 Mdot
.782 .40951 Mdot
.782 .40956 Mdot
.782 .40972 Mdot
.782 .40975 Mdot
.782 .41001 Mdot
.782 .41008 Mdot
.782 .41018 Mdot
.782 .4102 Mdot
.782 .41044 Mdot
.782 .41046 Mdot
.782 .4106 Mdot
.782 .41069 Mdot
.782 .4107 Mdot
.782 .41083 Mdot
.782 .41088 Mdot
.782 .41092 Mdot
.782 .41114 Mdot
.782 .41116 Mdot
.782 .4112 Mdot
.782 .41128 Mdot
.782 .41144 Mdot
.782 .41165 Mdot
.782 .4118 Mdot
.782 .41223 Mdot
.782 .41238 Mdot
.782 .41242 Mdot
.782 .41254 Mdot
.782 .41274 Mdot
.782 .41294 Mdot
.782 .41303 Mdot
.782 .41338 Mdot
.782 .41421 Mdot
.782 .41423 Mdot
.782 .41438 Mdot
.782 .41448 Mdot
.782 .41473 Mdot
.782 .41473 Mdot
.782 .41505 Mdot
.782 .41512 Mdot
.782 .41519 Mdot
.782 .41554 Mdot
.782 .41611 Mdot
.782 .41633 Mdot
.782 .41651 Mdot
.782 .41668 Mdot
.782 .41691 Mdot
.782 .41753 Mdot
.782 .41786 Mdot
.782 .41795 Mdot
.782 .41802 Mdot
.782 .41814 Mdot
.782 .41821 Mdot
.782 .41831 Mdot
.782 .41886 Mdot
.782 .41931 Mdot
.782 .41931 Mdot
.782 .41937 Mdot
.782 .41988 Mdot
.782 .42019 Mdot
.782 .42063 Mdot
.782 .42067 Mdot
.782 .42092 Mdot
.782 .42198 Mdot
.782 .42205 Mdot
.782 .42216 Mdot
.782 .42224 Mdot
.782 .42263 Mdot
.782 .42303 Mdot
.782 .42353 Mdot
.782 .42359 Mdot
.782 .424 Mdot
.782 .42421 Mdot
.782 .42445 Mdot
.782 .42448 Mdot
.782 .42457 Mdot
.782 .42457 Mdot
.782 .42469 Mdot
.782 .42489 Mdot
.782 .42519 Mdot
.782 .42528 Mdot
.782 .42536 Mdot
.782 .42554 Mdot
.782 .42606 Mdot
.782 .42622 Mdot
.782 .42638 Mdot
.782 .42678 Mdot
.782 .4268 Mdot
.782 .42688 Mdot
.782 .42712 Mdot
.782 .42777 Mdot
.782 .42777 Mdot
.782 .42778 Mdot
.782 .42781 Mdot
.782 .42789 Mdot
.782 .42798 Mdot
.782 .4281 Mdot
.782 .42817 Mdot
.782 .42836 Mdot
.782 .42859 Mdot
.782 .42865 Mdot
.782 .42887 Mdot
.782 .4292 Mdot
.782 .4293 Mdot
.782 .42948 Mdot
.782 .42956 Mdot
.782 .42963 Mdot
.782 .42966 Mdot
.782 .42975 Mdot
.782 .4298 Mdot
.782 .42986 Mdot
.782 .43026 Mdot
.782 .43048 Mdot
.782 .43081 Mdot
.782 .43092 Mdot
.782 .43093 Mdot
.782 .43134 Mdot
.782 .43173 Mdot
.782 .4319 Mdot
.782 .43238 Mdot
.782 .43276 Mdot
.782 .43284 Mdot
.782 .43286 Mdot
.782 .43303 Mdot
.782 .43336 Mdot
.782 .43366 Mdot
.782 .43377 Mdot
.782 .43457 Mdot
.782 .43496 Mdot
.782 .43501 Mdot
.782 .43504 Mdot
.782 .43505 Mdot
.782 .43511 Mdot
.782 .43519 Mdot
.782 .43523 Mdot
.782 .43548 Mdot
.782 .43558 Mdot
.782 .43568 Mdot
.782 .43582 Mdot
.782 .43618 Mdot
.782 .43621 Mdot
.782 .43638 Mdot
.782 .43645 Mdot
.782 .43683 Mdot
.782 .43687 Mdot
.782 .43716 Mdot
.782 .43727 Mdot
.782 .43736 Mdot
.782 .43752 Mdot
.782 .43775 Mdot
.782 .43808 Mdot
.782 .43818 Mdot
.782 .43872 Mdot
.782 .43968 Mdot
.782 .43972 Mdot
.782 .43975 Mdot
.782 .4398 Mdot
.782 .43987 Mdot
.782 .44 Mdot
.782 .44042 Mdot
.782 .44081 Mdot
.782 .44096 Mdot
.782 .44129 Mdot
.782 .44136 Mdot
.782 .44188 Mdot
.782 .44234 Mdot
.782 .4424 Mdot
.782 .44249 Mdot
.782 .44255 Mdot
.782 .4426 Mdot
.782 .44261 Mdot
.782 .44283 Mdot
.782 .44289 Mdot
.782 .4429 Mdot
.782 .443 Mdot
.782 .443 Mdot
.782 .44307 Mdot
.782 .44326 Mdot
.782 .44328 Mdot
.782 .44333 Mdot
.782 .44366 Mdot
.782 .4437 Mdot
.782 .44396 Mdot
.782 .4443 Mdot
.782 .44476 Mdot
.782 .44506 Mdot
.782 .44529 Mdot
.782 .44544 Mdot
.782 .44601 Mdot
.782 .44612 Mdot
.782 .44647 Mdot
.782 .44665 Mdot
.782 .44666 Mdot
.782 .44695 Mdot
.782 .44708 Mdot
.782 .44715 Mdot
.782 .44735 Mdot
.782 .44743 Mdot
.782 .44744 Mdot
.782 .44745 Mdot
.782 .44798 Mdot
.782 .44883 Mdot
.782 .44904 Mdot
.782 .44938 Mdot
.782 .44962 Mdot
.782 .44981 Mdot
.782 .44986 Mdot
.782 .44999 Mdot
.782 .45085 Mdot
.782 .45118 Mdot
.782 .45124 Mdot
.782 .45152 Mdot
.782 .45163 Mdot
.782 .45289 Mdot
.782 .45291 Mdot
.782 .45335 Mdot
.782 .45339 Mdot
.782 .45354 Mdot
.782 .45375 Mdot
.782 .45392 Mdot
.782 .4545 Mdot
.782 .45499 Mdot
.782 .45527 Mdot
.782 .45527 Mdot
.782 .45548 Mdot
.782 .45556 Mdot
.782 .45597 Mdot
.782 .45616 Mdot
.782 .45635 Mdot
.782 .45638 Mdot
.782 .45639 Mdot
.782 .45668 Mdot
.782 .45734 Mdot
.782 .45748 Mdot
.782 .45767 Mdot
.782 .45776 Mdot
.782 .45781 Mdot
.782 .45902 Mdot
.782 .45904 Mdot
.782 .45974 Mdot
.782 .45988 Mdot
.782 .46002 Mdot
.782 .46002 Mdot
.782 .46014 Mdot
.782 .46053 Mdot
.782 .4606 Mdot
.782 .46098 Mdot
.782 .46118 Mdot
.782 .46125 Mdot
.782 .46142 Mdot
.782 .46143 Mdot
.782 .46161 Mdot
.782 .46167 Mdot
.782 .4617 Mdot
.782 .46229 Mdot
.782 .46234 Mdot
.782 .46269 Mdot
.782 .4629 Mdot
.782 .46293 Mdot
.782 .46325 Mdot
.782 .46336 Mdot
.782 .46346 Mdot
.782 .46401 Mdot
.782 .46407 Mdot
.782 .46416 Mdot
.782 .46421 Mdot
.782 .46435 Mdot
.782 .46475 Mdot
.782 .46481 Mdot
.782 .4649 Mdot
.782 .46526 Mdot
.782 .46562 Mdot
.782 .46598 Mdot
.782 .46667 Mdot
.782 .46675 Mdot
.782 .46705 Mdot
.782 .46713 Mdot
.782 .46744 Mdot
.782 .46792 Mdot
.782 .46799 Mdot
.782 .46814 Mdot
.782 .46815 Mdot
.782 .46841 Mdot
.782 .46862 Mdot
.782 .46925 Mdot
.782 .46948 Mdot
.782 .47059 Mdot
.782 .47083 Mdot
.782 .47101 Mdot
.782 .47129 Mdot
.782 .47146 Mdot
.782 .47151 Mdot
.782 .47157 Mdot
.782 .47169 Mdot
.782 .47193 Mdot
.782 .47217 Mdot
.782 .4725 Mdot
.782 .47279 Mdot
.782 .47279 Mdot
.782 .47356 Mdot
.782 .47373 Mdot
.782 .47391 Mdot
.782 .47401 Mdot
.782 .47457 Mdot
.782 .47477 Mdot
.782 .47499 Mdot
.782 .47544 Mdot
.782 .47598 Mdot
.784 .21531 Mdot
.784 .21536 Mdot
.784 .21745 Mdot
.784 .21899 Mdot
.784 .21902 Mdot
.784 .21915 Mdot
.784 .21965 Mdot
.784 .21967 Mdot
.784 .21986 Mdot
.784 .22019 Mdot
.784 .2205 Mdot
.784 .22052 Mdot
.784 .22104 Mdot
.784 .22149 Mdot
.784 .22181 Mdot
.784 .22218 Mdot
.784 .22282 Mdot
.784 .22313 Mdot
.784 .22343 Mdot
.784 .22383 Mdot
.784 .22455 Mdot
.784 .2246 Mdot
.784 .22491 Mdot
.784 .22498 Mdot
.784 .22503 Mdot
.784 .22519 Mdot
.784 .22538 Mdot
.784 .22602 Mdot
.784 .22696 Mdot
.784 .22706 Mdot
.784 .22801 Mdot
.784 .22816 Mdot
.784 .22863 Mdot
.784 .22884 Mdot
.784 .22951 Mdot
.784 .23028 Mdot
.784 .23052 Mdot
.784 .23055 Mdot
.784 .23061 Mdot
.784 .23172 Mdot
.784 .23199 Mdot
.784 .23331 Mdot
.784 .23376 Mdot
.784 .23403 Mdot
.784 .2349 Mdot
.784 .23574 Mdot
.784 .23666 Mdot
.784 .23674 Mdot
.784 .23682 Mdot
.784 .23689 Mdot
.784 .23779 Mdot
.784 .23815 Mdot
.784 .23869 Mdot
.784 .23869 Mdot
.784 .23905 Mdot
.784 .23924 Mdot
.784 .23934 Mdot
.784 .23963 Mdot
.784 .23968 Mdot
.784 .24008 Mdot
.784 .2405 Mdot
.784 .24058 Mdot
.784 .24059 Mdot
.784 .24075 Mdot
.784 .24145 Mdot
.784 .24179 Mdot
.784 .24208 Mdot
.784 .24214 Mdot
.784 .24228 Mdot
.784 .24266 Mdot
.784 .2427 Mdot
.784 .24274 Mdot
.784 .24286 Mdot
.784 .2429 Mdot
.784 .24312 Mdot
.784 .24314 Mdot
.784 .24331 Mdot
.784 .24343 Mdot
.784 .24362 Mdot
.784 .24373 Mdot
.784 .24401 Mdot
.784 .24474 Mdot
.784 .24499 Mdot
.784 .2458 Mdot
.784 .24599 Mdot
.784 .2486 Mdot
.784 .249 Mdot
.784 .24923 Mdot
.784 .24931 Mdot
.784 .24955 Mdot
.784 .2496 Mdot
.784 .24964 Mdot
.784 .24967 Mdot
.784 .25011 Mdot
.784 .25026 Mdot
.784 .25027 Mdot
.784 .25058 Mdot
.784 .25133 Mdot
.784 .25221 Mdot
.784 .25242 Mdot
.784 .2533 Mdot
.784 .25335 Mdot
.784 .25356 Mdot
.784 .25374 Mdot
.784 .25424 Mdot
.784 .25454 Mdot
.784 .25505 Mdot
.784 .25587 Mdot
.784 .25656 Mdot
.784 .25687 Mdot
.784 .25694 Mdot
.784 .25717 Mdot
.784 .25758 Mdot
.784 .25778 Mdot
.784 .25779 Mdot
.784 .2591 Mdot
.784 .25964 Mdot
.784 .26079 Mdot
.784 .26136 Mdot
.784 .2626 Mdot
.784 .26262 Mdot
.784 .26281 Mdot
.784 .26387 Mdot
.784 .26397 Mdot
.784 .2649 Mdot
.784 .2651 Mdot
.784 .26519 Mdot
.784 .26523 Mdot
.784 .26535 Mdot
.784 .26623 Mdot
.784 .26648 Mdot
.784 .26676 Mdot
.784 .26834 Mdot
.784 .26876 Mdot
.784 .26932 Mdot
.784 .26978 Mdot
.784 .27086 Mdot
.784 .27173 Mdot
.784 .27184 Mdot
.784 .27207 Mdot
.784 .27236 Mdot
.784 .27241 Mdot
.784 .27265 Mdot
.784 .27271 Mdot
.784 .27278 Mdot
.784 .27306 Mdot
.784 .27365 Mdot
.784 .27466 Mdot
.784 .27484 Mdot
.784 .27544 Mdot
.784 .27568 Mdot
.784 .27587 Mdot
.784 .27603 Mdot
.784 .27616 Mdot
.784 .27619 Mdot
.784 .2768 Mdot
.784 .2768 Mdot
.784 .2769 Mdot
.784 .2769 Mdot
.784 .2774 Mdot
.784 .27761 Mdot
.784 .27814 Mdot
.784 .27874 Mdot
.784 .27932 Mdot
.784 .2794 Mdot
.784 .27989 Mdot
.784 .28013 Mdot
.784 .28056 Mdot
.784 .28094 Mdot
.784 .28111 Mdot
.784 .28142 Mdot
.784 .28262 Mdot
.784 .28269 Mdot
.784 .28284 Mdot
.784 .28311 Mdot
.784 .28358 Mdot
.784 .28382 Mdot
.784 .28404 Mdot
.784 .28437 Mdot
.784 .28468 Mdot
.784 .28475 Mdot
.784 .28482 Mdot
.784 .28492 Mdot
.784 .28524 Mdot
.784 .28615 Mdot
.784 .28617 Mdot
.784 .28639 Mdot
.784 .28643 Mdot
.784 .28722 Mdot
.784 .28764 Mdot
.784 .28781 Mdot
.784 .28845 Mdot
.784 .28857 Mdot
.784 .28867 Mdot
.784 .28902 Mdot
.784 .28909 Mdot
.784 .28921 Mdot
.784 .29065 Mdot
.784 .29088 Mdot
.784 .29157 Mdot
.784 .2921 Mdot
.784 .29235 Mdot
.784 .29273 Mdot
.784 .29342 Mdot
.784 .29391 Mdot
.784 .29393 Mdot
.784 .29429 Mdot
.784 .29437 Mdot
.784 .29516 Mdot
.784 .29516 Mdot
.784 .2954 Mdot
.784 .29542 Mdot
.784 .29545 Mdot
.784 .29558 Mdot
.784 .2969 Mdot
.784 .29698 Mdot
.784 .29731 Mdot
.784 .29741 Mdot
.784 .29771 Mdot
.784 .29786 Mdot
.784 .29807 Mdot
.784 .29816 Mdot
.784 .29822 Mdot
.784 .29841 Mdot
.784 .29846 Mdot
.784 .29849 Mdot
.784 .29875 Mdot
.784 .29913 Mdot
.784 .29946 Mdot
.784 .2996 Mdot
.784 .29972 Mdot
.784 .29987 Mdot
.784 .29987 Mdot
.784 .30009 Mdot
.784 .30024 Mdot
.784 .30066 Mdot
.784 .3007 Mdot
.784 .30107 Mdot
.784 .30141 Mdot
.784 .30176 Mdot
.784 .30187 Mdot
.784 .30259 Mdot
.784 .30271 Mdot
.784 .30316 Mdot
.784 .30329 Mdot
.784 .30388 Mdot
.784 .30396 Mdot
.784 .3046 Mdot
.784 .30502 Mdot
.784 .30528 Mdot
.784 .30536 Mdot
.784 .30547 Mdot
.784 .30562 Mdot
.784 .30591 Mdot
.784 .3062 Mdot
.784 .30632 Mdot
.784 .30705 Mdot
.784 .30739 Mdot
.784 .30753 Mdot
.784 .30761 Mdot
.784 .30787 Mdot
.784 .30788 Mdot
.784 .30936 Mdot
.784 .31001 Mdot
.784 .31089 Mdot
.784 .31158 Mdot
.784 .31179 Mdot
.784 .31213 Mdot
.784 .31213 Mdot
.784 .31253 Mdot
.784 .31266 Mdot
.784 .31281 Mdot
.784 .31332 Mdot
.784 .31379 Mdot
.784 .31395 Mdot
.784 .31397 Mdot
.784 .31475 Mdot
.784 .31518 Mdot
.784 .31524 Mdot
.784 .31579 Mdot
.784 .3162 Mdot
.784 .31621 Mdot
.784 .31733 Mdot
.784 .31876 Mdot
.784 .31879 Mdot
.784 .31975 Mdot
.784 .31991 Mdot
.784 .32009 Mdot
.784 .32029 Mdot
.784 .3203 Mdot
.784 .32036 Mdot
.784 .32078 Mdot
.784 .32114 Mdot
.784 .32116 Mdot
.784 .32122 Mdot
.784 .32133 Mdot
.784 .3214 Mdot
.784 .32145 Mdot
.784 .32157 Mdot
.784 .32355 Mdot
.784 .32372 Mdot
.784 .32384 Mdot
.784 .32396 Mdot
.784 .32417 Mdot
.784 .32436 Mdot
.784 .32466 Mdot
.784 .32557 Mdot
.784 .32565 Mdot
.784 .32585 Mdot
.784 .32618 Mdot
.784 .32651 Mdot
.784 .32679 Mdot
.784 .32692 Mdot
.784 .32695 Mdot
.784 .32721 Mdot
.784 .32729 Mdot
.784 .32805 Mdot
.784 .32925 Mdot
.784 .32926 Mdot
.784 .32933 Mdot
.784 .32976 Mdot
.784 .32981 Mdot
.784 .33027 Mdot
.784 .33032 Mdot
.784 .33198 Mdot
.784 .33261 Mdot
.784 .3331 Mdot
.784 .33333 Mdot
.784 .33336 Mdot
.784 .33339 Mdot
.784 .3335 Mdot
.784 .33374 Mdot
.784 .33423 Mdot
.784 .33476 Mdot
.784 .33478 Mdot
.784 .33502 Mdot
.784 .33507 Mdot
.784 .33507 Mdot
.784 .33527 Mdot
.784 .33605 Mdot
.784 .33608 Mdot
.784 .33638 Mdot
.784 .3369 Mdot
.784 .33739 Mdot
.784 .33742 Mdot
.784 .33748 Mdot
.784 .33759 Mdot
.784 .33778 Mdot
.784 .33788 Mdot
.784 .3381 Mdot
.784 .33823 Mdot
.784 .33826 Mdot
.784 .33833 Mdot
.784 .33884 Mdot
.784 .33892 Mdot
.784 .33894 Mdot
.784 .33943 Mdot
.784 .33976 Mdot
.784 .33981 Mdot
.784 .33985 Mdot
.784 .34002 Mdot
.784 .34075 Mdot
.784 .34103 Mdot
.784 .34135 Mdot
.784 .34151 Mdot
.784 .34198 Mdot
.784 .34214 Mdot
.784 .34217 Mdot
.784 .34261 Mdot
.784 .34266 Mdot
.784 .34341 Mdot
.784 .34359 Mdot
.784 .34367 Mdot
.784 .34374 Mdot
.784 .34381 Mdot
.784 .34384 Mdot
.784 .34385 Mdot
.784 .34411 Mdot
.784 .34424 Mdot
.784 .3443 Mdot
.784 .34435 Mdot
.784 .34441 Mdot
.784 .34441 Mdot
.784 .3445 Mdot
.784 .34474 Mdot
.784 .3449 Mdot
.784 .34503 Mdot
.784 .34518 Mdot
.784 .34522 Mdot
.784 .34551 Mdot
.784 .34556 Mdot
.784 .3458 Mdot
.784 .34604 Mdot
.784 .34607 Mdot
.784 .3465 Mdot
.784 .34687 Mdot
.784 .34747 Mdot
.784 .34752 Mdot
.784 .34767 Mdot
.784 .34827 Mdot
.784 .34889 Mdot
.784 .34917 Mdot
.784 .34925 Mdot
.784 .34939 Mdot
.784 .3494 Mdot
.784 .34956 Mdot
.784 .34967 Mdot
.784 .34988 Mdot
.784 .35013 Mdot
.784 .35014 Mdot
.784 .35046 Mdot
.784 .35066 Mdot
.784 .35088 Mdot
.784 .35105 Mdot
.784 .35151 Mdot
.784 .35209 Mdot
.784 .3521 Mdot
.784 .35249 Mdot
.784 .35256 Mdot
.784 .35271 Mdot
.784 .35272 Mdot
.784 .35274 Mdot
.784 .35306 Mdot
.784 .35307 Mdot
.784 .35309 Mdot
.784 .35314 Mdot
.784 .35318 Mdot
.784 .35323 Mdot
.784 .35411 Mdot
.784 .35437 Mdot
.784 .35486 Mdot
.784 .35489 Mdot
.784 .35497 Mdot
.784 .35511 Mdot
.784 .35524 Mdot
.784 .35536 Mdot
.784 .35541 Mdot
.784 .35556 Mdot
.784 .35587 Mdot
.784 .35636 Mdot
.784 .35657 Mdot
.784 .35747 Mdot
.784 .35792 Mdot
.784 .35802 Mdot
.784 .35804 Mdot
.784 .35809 Mdot
.784 .35818 Mdot
.784 .35838 Mdot
.784 .3586 Mdot
.784 .35872 Mdot
.784 .3597 Mdot
.784 .35983 Mdot
.784 .35987 Mdot
.784 .35996 Mdot
.784 .36002 Mdot
.784 .36005 Mdot
.784 .36026 Mdot
.784 .36063 Mdot
.784 .36065 Mdot
.784 .36067 Mdot
.784 .36104 Mdot
.784 .36128 Mdot
.784 .36212 Mdot
.784 .36219 Mdot
.784 .36229 Mdot
.784 .36229 Mdot
.784 .3624 Mdot
.784 .3625 Mdot
.784 .36272 Mdot
.784 .36285 Mdot
.784 .36297 Mdot
.784 .36299 Mdot
.784 .36309 Mdot
.784 .3632 Mdot
.784 .36337 Mdot
.784 .36377 Mdot
.784 .36409 Mdot
.784 .36449 Mdot
.784 .36455 Mdot
.784 .36462 Mdot
.784 .36466 Mdot
.784 .36475 Mdot
.784 .36507 Mdot
.784 .36523 Mdot
.784 .36565 Mdot
.784 .36581 Mdot
.784 .3659 Mdot
.784 .36591 Mdot
.784 .36604 Mdot
.784 .36647 Mdot
.784 .36657 Mdot
.784 .36677 Mdot
.784 .36679 Mdot
.784 .36687 Mdot
.784 .36693 Mdot
.784 .36706 Mdot
.784 .36738 Mdot
.784 .36747 Mdot
.784 .36802 Mdot
.784 .36806 Mdot
.784 .36809 Mdot
.784 .36821 Mdot
.784 .36834 Mdot
.784 .36874 Mdot
.784 .36879 Mdot
.784 .36887 Mdot
.784 .36888 Mdot
.784 .36897 Mdot
.784 .36914 Mdot
.784 .3698 Mdot
.784 .36988 Mdot
.784 .37024 Mdot
.784 .37053 Mdot
.784 .37072 Mdot
.784 .37074 Mdot
.784 .37076 Mdot
.784 .37099 Mdot
.784 .37116 Mdot
.784 .37123 Mdot
.784 .37132 Mdot
.784 .37154 Mdot
.784 .37162 Mdot
.784 .37166 Mdot
.784 .37174 Mdot
.784 .37213 Mdot
.784 .37214 Mdot
.784 .3722 Mdot
.784 .37226 Mdot
.784 .37244 Mdot
.784 .37251 Mdot
.784 .37285 Mdot
.784 .37288 Mdot
.784 .37315 Mdot
.784 .37322 Mdot
.784 .37323 Mdot
.784 .37333 Mdot
.784 .37361 Mdot
.784 .37364 Mdot
.784 .3738 Mdot
.784 .37424 Mdot
.784 .37425 Mdot
.784 .37539 Mdot
.784 .37579 Mdot
.784 .37603 Mdot
.784 .37604 Mdot
.784 .37673 Mdot
.784 .37699 Mdot
.784 .37703 Mdot
.784 .37706 Mdot
.784 .37735 Mdot
.784 .37746 Mdot
.784 .37762 Mdot
.784 .37764 Mdot
.784 .37776 Mdot
.784 .37817 Mdot
.784 .37822 Mdot
.784 .37875 Mdot
.784 .37886 Mdot
.784 .37915 Mdot
.784 .37924 Mdot
.784 .37933 Mdot
.784 .37936 Mdot
.784 .37997 Mdot
.784 .38009 Mdot
.784 .38014 Mdot
.784 .38028 Mdot
.784 .38062 Mdot
.784 .38076 Mdot
.784 .38087 Mdot
.784 .38114 Mdot
.784 .38144 Mdot
.784 .3815 Mdot
.784 .38153 Mdot
.784 .38157 Mdot
.784 .38186 Mdot
.784 .38207 Mdot
.784 .38232 Mdot
.784 .38243 Mdot
.784 .38256 Mdot
.784 .38288 Mdot
.784 .38294 Mdot
.784 .38301 Mdot
.784 .38301 Mdot
.784 .38307 Mdot
.784 .38312 Mdot
.784 .38381 Mdot
.784 .38404 Mdot
.784 .38405 Mdot
.784 .38407 Mdot
.784 .38431 Mdot
.784 .38444 Mdot
.784 .38446 Mdot
.784 .38456 Mdot
.784 .38458 Mdot
.784 .38466 Mdot
.784 .38529 Mdot
.784 .3855 Mdot
.784 .38569 Mdot
.784 .38572 Mdot
.784 .38573 Mdot
.784 .3858 Mdot
.784 .38666 Mdot
.784 .38679 Mdot
.784 .38711 Mdot
.784 .3873 Mdot
.784 .38743 Mdot
.784 .3875 Mdot
.784 .38759 Mdot
.784 .38773 Mdot
.784 .38775 Mdot
.784 .38806 Mdot
.784 .38823 Mdot
.784 .38882 Mdot
.784 .38889 Mdot
.784 .3889 Mdot
.784 .3891 Mdot
.784 .38912 Mdot
.784 .38922 Mdot
.784 .38926 Mdot
.784 .38951 Mdot
.784 .38951 Mdot
.784 .39018 Mdot
.784 .39029 Mdot
.784 .39043 Mdot
.784 .39076 Mdot
.784 .39093 Mdot
.784 .39106 Mdot
.784 .39113 Mdot
.784 .39123 Mdot
.784 .39132 Mdot
.784 .39156 Mdot
.784 .39195 Mdot
.784 .39246 Mdot
.784 .39285 Mdot
.784 .39308 Mdot
.784 .39335 Mdot
.784 .39353 Mdot
.784 .39368 Mdot
.784 .39371 Mdot
.784 .3939 Mdot
.784 .39392 Mdot
.784 .3941 Mdot
.784 .39442 Mdot
.784 .39445 Mdot
.784 .39452 Mdot
.784 .39461 Mdot
.784 .39477 Mdot
.784 .39478 Mdot
.784 .39488 Mdot
.784 .39494 Mdot
.784 .39505 Mdot
.784 .39553 Mdot
.784 .39584 Mdot
.784 .39586 Mdot
.784 .39636 Mdot
.784 .39675 Mdot
.784 .39732 Mdot
.784 .39735 Mdot
.784 .39738 Mdot
.784 .39791 Mdot
.784 .39797 Mdot
.784 .39829 Mdot
.784 .39834 Mdot
.784 .39844 Mdot
.784 .39858 Mdot
.784 .39864 Mdot
.784 .39876 Mdot
.784 .39883 Mdot
.784 .40037 Mdot
.784 .40056 Mdot
.784 .40056 Mdot
.784 .40091 Mdot
.784 .40122 Mdot
.784 .40137 Mdot
.784 .40144 Mdot
.784 .40146 Mdot
.784 .40148 Mdot
.784 .40163 Mdot
.784 .40234 Mdot
.784 .4034 Mdot
.784 .40343 Mdot
.784 .40373 Mdot
.784 .40375 Mdot
.784 .40408 Mdot
.784 .40485 Mdot
.784 .40533 Mdot
.784 .40538 Mdot
.784 .40555 Mdot
.784 .40557 Mdot
.784 .40565 Mdot
.784 .40583 Mdot
.784 .40604 Mdot
.784 .40625 Mdot
.784 .40638 Mdot
.784 .40643 Mdot
.784 .40701 Mdot
.784 .4072 Mdot
.784 .40732 Mdot
.784 .40746 Mdot
.784 .40753 Mdot
.784 .40761 Mdot
.784 .40771 Mdot
.784 .40898 Mdot
.784 .40906 Mdot
.784 .40909 Mdot
.784 .40913 Mdot
.784 .4092 Mdot
.784 .40924 Mdot
.784 .40926 Mdot
.784 .40948 Mdot
.784 .40975 Mdot
.784 .40979 Mdot
.784 .40979 Mdot
.784 .40992 Mdot
.784 .41004 Mdot
.784 .41014 Mdot
.784 .41075 Mdot
.784 .41077 Mdot
.784 .41168 Mdot
.784 .4124 Mdot
.784 .4124 Mdot
.784 .41267 Mdot
.784 .41302 Mdot
.784 .41305 Mdot
.784 .41333 Mdot
.784 .41383 Mdot
.784 .41384 Mdot
.784 .41394 Mdot
.784 .41424 Mdot
.784 .41457 Mdot
.784 .41466 Mdot
.784 .41475 Mdot
.784 .415 Mdot
.784 .415 Mdot
.784 .41522 Mdot
.784 .41535 Mdot
.784 .41579 Mdot
.784 .41635 Mdot
.784 .41677 Mdot
.784 .41771 Mdot
.784 .41772 Mdot
.784 .41788 Mdot
.784 .41793 Mdot
.784 .41802 Mdot
.784 .41824 Mdot
.784 .4187 Mdot
.784 .41878 Mdot
.784 .41897 Mdot
.784 .41915 Mdot
.784 .41924 Mdot
.784 .41932 Mdot
.784 .41937 Mdot
.784 .41953 Mdot
.784 .4198 Mdot
.784 .42021 Mdot
.784 .42026 Mdot
.784 .42064 Mdot
.784 .42072 Mdot
.784 .42101 Mdot
.784 .42108 Mdot
.784 .42154 Mdot
.784 .42161 Mdot
.784 .42184 Mdot
.784 .42205 Mdot
.784 .42229 Mdot
.784 .42231 Mdot
.784 .42259 Mdot
.784 .42268 Mdot
.784 .42282 Mdot
.784 .42282 Mdot
.784 .42291 Mdot
.784 .42299 Mdot
.784 .42308 Mdot
.784 .42329 Mdot
.784 .42354 Mdot
.784 .4237 Mdot
.784 .42372 Mdot
.784 .42375 Mdot
.784 .42387 Mdot
.784 .42391 Mdot
.784 .42397 Mdot
.784 .4241 Mdot
.784 .4242 Mdot
.784 .42439 Mdot
.784 .42445 Mdot
.784 .42466 Mdot
.784 .42471 Mdot
.784 .42555 Mdot
.784 .42564 Mdot
.784 .42566 Mdot
.784 .42567 Mdot
.784 .42582 Mdot
.784 .42582 Mdot
.784 .42633 Mdot
.784 .42638 Mdot
.784 .42661 Mdot
.784 .42662 Mdot
.784 .42693 Mdot
.784 .42737 Mdot
.784 .42761 Mdot
.784 .42777 Mdot
.784 .42811 Mdot
.784 .42855 Mdot
.784 .4287 Mdot
.784 .42962 Mdot
.784 .42969 Mdot
.784 .42974 Mdot
.784 .42996 Mdot
.784 .43003 Mdot
.784 .4301 Mdot
.784 .43051 Mdot
.784 .43062 Mdot
.784 .43089 Mdot
.784 .43139 Mdot
.784 .43142 Mdot
.784 .43155 Mdot
.784 .43157 Mdot
.784 .43215 Mdot
.784 .43235 Mdot
.784 .43242 Mdot
.784 .43246 Mdot
.784 .4325 Mdot
.784 .43271 Mdot
.784 .43291 Mdot
.784 .43305 Mdot
.784 .43321 Mdot
.784 .43351 Mdot
.784 .43368 Mdot
.784 .43378 Mdot
.784 .43382 Mdot
.784 .43458 Mdot
.784 .43479 Mdot
.784 .43489 Mdot
.784 .43513 Mdot
.784 .43541 Mdot
.784 .43556 Mdot
.784 .43588 Mdot
.784 .43592 Mdot
.784 .4363 Mdot
.784 .43667 Mdot
.784 .43702 Mdot
.784 .43715 Mdot
.784 .43747 Mdot
.784 .43747 Mdot
.784 .43753 Mdot
.784 .43753 Mdot
.784 .43792 Mdot
.784 .43794 Mdot
.784 .43802 Mdot
.784 .43813 Mdot
.784 .43824 Mdot
.784 .4384 Mdot
.784 .43878 Mdot
.784 .43889 Mdot
.784 .43954 Mdot
.784 .43992 Mdot
.784 .44009 Mdot
.784 .44014 Mdot
.784 .44018 Mdot
.784 .44033 Mdot
.784 .44036 Mdot
.784 .44055 Mdot
.784 .4407 Mdot
.784 .44076 Mdot
.784 .44132 Mdot
.784 .44201 Mdot
.784 .4423 Mdot
.784 .44266 Mdot
.784 .44292 Mdot
.784 .44393 Mdot
.784 .44411 Mdot
.784 .44427 Mdot
.784 .44483 Mdot
.784 .44491 Mdot
.784 .44494 Mdot
.784 .44499 Mdot
.784 .44512 Mdot
.784 .44571 Mdot
.784 .44578 Mdot
.784 .44645 Mdot
.784 .44657 Mdot
.784 .44659 Mdot
.784 .44738 Mdot
.784 .44774 Mdot
.784 .44847 Mdot
.784 .44882 Mdot
.784 .44965 Mdot
.784 .44966 Mdot
.784 .44979 Mdot
.784 .45005 Mdot
.784 .4502 Mdot
.784 .45024 Mdot
.784 .45044 Mdot
.784 .45088 Mdot
.784 .4514 Mdot
.784 .45173 Mdot
.784 .45192 Mdot
.784 .45224 Mdot
.784 .45236 Mdot
.784 .45249 Mdot
.784 .45252 Mdot
.784 .45308 Mdot
.784 .45321 Mdot
.784 .45378 Mdot
.784 .45425 Mdot
.784 .45445 Mdot
.784 .45446 Mdot
.784 .45456 Mdot
.784 .45484 Mdot
.784 .45485 Mdot
.784 .45488 Mdot
.784 .45491 Mdot
.784 .45506 Mdot
.784 .45512 Mdot
.784 .45526 Mdot
.784 .45552 Mdot
.784 .45718 Mdot
.784 .4573 Mdot
.784 .45782 Mdot
.784 .45798 Mdot
.784 .45844 Mdot
.784 .45863 Mdot
.784 .45869 Mdot
.784 .45882 Mdot
.784 .45889 Mdot
.784 .459 Mdot
.784 .45901 Mdot
.784 .45915 Mdot
.784 .45918 Mdot
.784 .45925 Mdot
.784 .45928 Mdot
.784 .45931 Mdot
.784 .45955 Mdot
.784 .45963 Mdot
.784 .45967 Mdot
.784 .45986 Mdot
.784 .46008 Mdot
.784 .46052 Mdot
.784 .46063 Mdot
.784 .46063 Mdot
.784 .46068 Mdot
.784 .46095 Mdot
.784 .4612 Mdot
.784 .46124 Mdot
.784 .46142 Mdot
.784 .46148 Mdot
.784 .46161 Mdot
.784 .46183 Mdot
.784 .46184 Mdot
.784 .46218 Mdot
.784 .46241 Mdot
.784 .46298 Mdot
.784 .46303 Mdot
.784 .46308 Mdot
.784 .46313 Mdot
.784 .46372 Mdot
.784 .46426 Mdot
.784 .46481 Mdot
.784 .46498 Mdot
.784 .46527 Mdot
.784 .46611 Mdot
.784 .46628 Mdot
.784 .46699 Mdot
.784 .46703 Mdot
.784 .46705 Mdot
.784 .4672 Mdot
.784 .46769 Mdot
.784 .46812 Mdot
.784 .46825 Mdot
.784 .46855 Mdot
.784 .46864 Mdot
.784 .46926 Mdot
.784 .46931 Mdot
.784 .46992 Mdot
.784 .47033 Mdot
.784 .47044 Mdot
.784 .47055 Mdot
.784 .47058 Mdot
.784 .47063 Mdot
.784 .47082 Mdot
.784 .47085 Mdot
.784 .47131 Mdot
.784 .47157 Mdot
.784 .47176 Mdot
.784 .47195 Mdot
.784 .47236 Mdot
.784 .4726 Mdot
.784 .4728 Mdot
.784 .47309 Mdot
.784 .47342 Mdot
.784 .47344 Mdot
.784 .47363 Mdot
.784 .47385 Mdot
.784 .47397 Mdot
.784 .47398 Mdot
.784 .4743 Mdot
.784 .47438 Mdot
.784 .4744 Mdot
.784 .47538 Mdot
.784 .47671 Mdot
.784 .47675 Mdot
.786 .2136 Mdot
.786 .21381 Mdot
.786 .21402 Mdot
.786 .21467 Mdot
.786 .2148 Mdot
.786 .2151 Mdot
.786 .21565 Mdot
.786 .21566 Mdot
.786 .21574 Mdot
.786 .21594 Mdot
.786 .21611 Mdot
.786 .21661 Mdot
.786 .21708 Mdot
.786 .21713 Mdot
.786 .21822 Mdot
.786 .21899 Mdot
.786 .21899 Mdot
.786 .22002 Mdot
.786 .22019 Mdot
.786 .22041 Mdot
.786 .22051 Mdot
.786 .22064 Mdot
.786 .22125 Mdot
.786 .22134 Mdot
.786 .22134 Mdot
.786 .22275 Mdot
.786 .22295 Mdot
.786 .22336 Mdot
.786 .22347 Mdot
.786 .22369 Mdot
.786 .2238 Mdot
.786 .22433 Mdot
.786 .22574 Mdot
.786 .22615 Mdot
.786 .22644 Mdot
.786 .22695 Mdot
.786 .22712 Mdot
.786 .22725 Mdot
.786 .22749 Mdot
.786 .22773 Mdot
.786 .22781 Mdot
.786 .2289 Mdot
.786 .22908 Mdot
.786 .22917 Mdot
.786 .22944 Mdot
.786 .22999 Mdot
.786 .23038 Mdot
.786 .23078 Mdot
.786 .23096 Mdot
.786 .23116 Mdot
.786 .23186 Mdot
.786 .23452 Mdot
.786 .23462 Mdot
.786 .23531 Mdot
.786 .23647 Mdot
.786 .23695 Mdot
.786 .23786 Mdot
.786 .23838 Mdot
.786 .23874 Mdot
.786 .23971 Mdot
.786 .23976 Mdot
.786 .23989 Mdot
.786 .24062 Mdot
.786 .24078 Mdot
.786 .2411 Mdot
.786 .24163 Mdot
.786 .24183 Mdot
.786 .24198 Mdot
.786 .24198 Mdot
.786 .24228 Mdot
.786 .24239 Mdot
.786 .24255 Mdot
.786 .24277 Mdot
.786 .24309 Mdot
.786 .24355 Mdot
.786 .2436 Mdot
.786 .24361 Mdot
.786 .24509 Mdot
.786 .24519 Mdot
.786 .2456 Mdot
.786 .24588 Mdot
.786 .24669 Mdot
.786 .24692 Mdot
.786 .24745 Mdot
.786 .24748 Mdot
.786 .24834 Mdot
.786 .2487 Mdot
.786 .24872 Mdot
.786 .24883 Mdot
.786 .24901 Mdot
.786 .24903 Mdot
.786 .24923 Mdot
.786 .25011 Mdot
.786 .25019 Mdot
.786 .25111 Mdot
.786 .25112 Mdot
.786 .25151 Mdot
.786 .25181 Mdot
.786 .25187 Mdot
.786 .254 Mdot
.786 .25467 Mdot
.786 .25494 Mdot
.786 .25503 Mdot
.786 .25589 Mdot
.786 .25598 Mdot
.786 .25672 Mdot
.786 .25676 Mdot
.786 .25685 Mdot
.786 .25719 Mdot
.786 .25767 Mdot
.786 .25788 Mdot
.786 .25801 Mdot
.786 .25846 Mdot
.786 .25856 Mdot
.786 .25879 Mdot
.786 .25917 Mdot
.786 .25922 Mdot
.786 .25947 Mdot
.786 .26019 Mdot
.786 .26081 Mdot
.786 .26086 Mdot
.786 .26101 Mdot
.786 .26108 Mdot
.786 .26149 Mdot
.786 .26192 Mdot
.786 .262 Mdot
.786 .26265 Mdot
.786 .26321 Mdot
.786 .26343 Mdot
.786 .2648 Mdot
.786 .26483 Mdot
.786 .26515 Mdot
.786 .26593 Mdot
.786 .26595 Mdot
.786 .26615 Mdot
.786 .2663 Mdot
.786 .26646 Mdot
.786 .2666 Mdot
.786 .26789 Mdot
.786 .26852 Mdot
.786 .26892 Mdot
.786 .26904 Mdot
.786 .2693 Mdot
.786 .26932 Mdot
.786 .26946 Mdot
.786 .26949 Mdot
.786 .26952 Mdot
.786 .27008 Mdot
.786 .27033 Mdot
.786 .27038 Mdot
.786 .27054 Mdot
.786 .27129 Mdot
.786 .27159 Mdot
.786 .27198 Mdot
.786 .27247 Mdot
.786 .2729 Mdot
.786 .27292 Mdot
.786 .27321 Mdot
.786 .27355 Mdot
.786 .27445 Mdot
.786 .27477 Mdot
.786 .27521 Mdot
.786 .27536 Mdot
.786 .27554 Mdot
.786 .27561 Mdot
.786 .27588 Mdot
.786 .27625 Mdot
.786 .27697 Mdot
.786 .27698 Mdot
.786 .27748 Mdot
.786 .27749 Mdot
.786 .27777 Mdot
.786 .27778 Mdot
.786 .27818 Mdot
.786 .27834 Mdot
.786 .27844 Mdot
.786 .27845 Mdot
.786 .27862 Mdot
.786 .27883 Mdot
.786 .27931 Mdot
.786 .28053 Mdot
.786 .28109 Mdot
.786 .28139 Mdot
.786 .28176 Mdot
.786 .28222 Mdot
.786 .28244 Mdot
.786 .28294 Mdot
.786 .28313 Mdot
.786 .28322 Mdot
.786 .28329 Mdot
.786 .28329 Mdot
.786 .28339 Mdot
.786 .28367 Mdot
.786 .28368 Mdot
.786 .28389 Mdot
.786 .28417 Mdot
.786 .28432 Mdot
.786 .28446 Mdot
.786 .2846 Mdot
.786 .28527 Mdot
.786 .28553 Mdot
.786 .28657 Mdot
.786 .2869 Mdot
.786 .28692 Mdot
.786 .28698 Mdot
.786 .28756 Mdot
.786 .28826 Mdot
.786 .28945 Mdot
.786 .28998 Mdot
.786 .29032 Mdot
.786 .2904 Mdot
.786 .29042 Mdot
.786 .29067 Mdot
.786 .29097 Mdot
.786 .29107 Mdot
.786 .29109 Mdot
.786 .29206 Mdot
.786 .29208 Mdot
.786 .29238 Mdot
.786 .29241 Mdot
.786 .29276 Mdot
.786 .2928 Mdot
.786 .29291 Mdot
.786 .29318 Mdot
.786 .29404 Mdot
.786 .29406 Mdot
.786 .29475 Mdot
.786 .2952 Mdot
.786 .29532 Mdot
.786 .29583 Mdot
.786 .29605 Mdot
.786 .29647 Mdot
.786 .29658 Mdot
.786 .29675 Mdot
.786 .29679 Mdot
.786 .29738 Mdot
.786 .29741 Mdot
.786 .2976 Mdot
.786 .29781 Mdot
.786 .29788 Mdot
.786 .29792 Mdot
.786 .29805 Mdot
.786 .29819 Mdot
.786 .2984 Mdot
.786 .29853 Mdot
.786 .2995 Mdot
.786 .30027 Mdot
.786 .30074 Mdot
.786 .30106 Mdot
.786 .30214 Mdot
.786 .3025 Mdot
.786 .30274 Mdot
.786 .30326 Mdot
.786 .30334 Mdot
.786 .30378 Mdot
.786 .30381 Mdot
.786 .304 Mdot
.786 .30406 Mdot
.786 .30413 Mdot
.786 .30433 Mdot
.786 .30519 Mdot
.786 .3054 Mdot
.786 .30553 Mdot
.786 .30558 Mdot
.786 .30583 Mdot
.786 .3064 Mdot
.786 .30668 Mdot
.786 .30673 Mdot
.786 .30735 Mdot
.786 .3081 Mdot
.786 .30851 Mdot
.786 .3087 Mdot
.786 .3087 Mdot
.786 .30909 Mdot
.786 .30936 Mdot
.786 .30987 Mdot
.786 .30995 Mdot
.786 .31035 Mdot
.786 .31047 Mdot
.786 .31073 Mdot
.786 .31081 Mdot
.786 .31108 Mdot
.786 .31128 Mdot
.786 .31173 Mdot
.786 .31205 Mdot
.786 .31246 Mdot
.786 .31253 Mdot
.786 .31262 Mdot
.786 .31296 Mdot
.786 .313 Mdot
.786 .31365 Mdot
.786 .31395 Mdot
.786 .31478 Mdot
.786 .31494 Mdot
.786 .31549 Mdot
.786 .31617 Mdot
.786 .31627 Mdot
.786 .3165 Mdot
.786 .31682 Mdot
.786 .31697 Mdot
.786 .31732 Mdot
.786 .31837 Mdot
.786 .31931 Mdot
.786 .31968 Mdot
.786 .32004 Mdot
.786 .32043 Mdot
.786 .32045 Mdot
.786 .3205 Mdot
.786 .3208 Mdot
.786 .32129 Mdot
.786 .32135 Mdot
.786 .32167 Mdot
.786 .32201 Mdot
.786 .32326 Mdot
.786 .32358 Mdot
.786 .32392 Mdot
.786 .32407 Mdot
.786 .32412 Mdot
.786 .3242 Mdot
.786 .32428 Mdot
.786 .32467 Mdot
.786 .32504 Mdot
.786 .32505 Mdot
.786 .3252 Mdot
.786 .32737 Mdot
.786 .3275 Mdot
.786 .3277 Mdot
.786 .32779 Mdot
.786 .32784 Mdot
.786 .32802 Mdot
.786 .32806 Mdot
.786 .32815 Mdot
.786 .32905 Mdot
.786 .32925 Mdot
.786 .32945 Mdot
.786 .32971 Mdot
.786 .33003 Mdot
.786 .33059 Mdot
.786 .33059 Mdot
.786 .33073 Mdot
.786 .33104 Mdot
.786 .33105 Mdot
.786 .33125 Mdot
.786 .33131 Mdot
.786 .33209 Mdot
.786 .33225 Mdot
.786 .3323 Mdot
.786 .33241 Mdot
.786 .33248 Mdot
.786 .33272 Mdot
.786 .33284 Mdot
.786 .33291 Mdot
.786 .33321 Mdot
.786 .33333 Mdot
.786 .33349 Mdot
.786 .33369 Mdot
.786 .33387 Mdot
.786 .33399 Mdot
.786 .33449 Mdot
.786 .33462 Mdot
.786 .33486 Mdot
.786 .33496 Mdot
.786 .33551 Mdot
.786 .33583 Mdot
.786 .33584 Mdot
.786 .33606 Mdot
.786 .3373 Mdot
.786 .33745 Mdot
.786 .33772 Mdot
.786 .33792 Mdot
.786 .33804 Mdot
.786 .33806 Mdot
.786 .33807 Mdot
.786 .33811 Mdot
.786 .33822 Mdot
.786 .33822 Mdot
.786 .33842 Mdot
.786 .33848 Mdot
.786 .33854 Mdot
.786 .33859 Mdot
.786 .33897 Mdot
.786 .33939 Mdot
.786 .33953 Mdot
.786 .33954 Mdot
.786 .33956 Mdot
.786 .33979 Mdot
.786 .34091 Mdot
.786 .34117 Mdot
.786 .34122 Mdot
.786 .34174 Mdot
.786 .34176 Mdot
.786 .34196 Mdot
.786 .34207 Mdot
.786 .3427 Mdot
.786 .34288 Mdot
.786 .34293 Mdot
.786 .34323 Mdot
.786 .3434 Mdot
.786 .34344 Mdot
.786 .34353 Mdot
.786 .34377 Mdot
.786 .34394 Mdot
.786 .34397 Mdot
.786 .34399 Mdot
.786 .34409 Mdot
.786 .34423 Mdot
.786 .34513 Mdot
.786 .34526 Mdot
.786 .34569 Mdot
.786 .34594 Mdot
.786 .34615 Mdot
.786 .34636 Mdot
.786 .34637 Mdot
.786 .34645 Mdot
.786 .34658 Mdot
.786 .34701 Mdot
.786 .34707 Mdot
.786 .34709 Mdot
.786 .34719 Mdot
.786 .34753 Mdot
.786 .34755 Mdot
.786 .34827 Mdot
.786 .34835 Mdot
.786 .34835 Mdot
.786 .34851 Mdot
.786 .34862 Mdot
.786 .34882 Mdot
.786 .34917 Mdot
.786 .3492 Mdot
.786 .34939 Mdot
.786 .34958 Mdot
.786 .3497 Mdot
.786 .35081 Mdot
.786 .3511 Mdot
.786 .35137 Mdot
.786 .35141 Mdot
.786 .35163 Mdot
.786 .3517 Mdot
.786 .35184 Mdot
.786 .35226 Mdot
.786 .35264 Mdot
.786 .3531 Mdot
.786 .35313 Mdot
.786 .3536 Mdot
.786 .35373 Mdot
.786 .35437 Mdot
.786 .35451 Mdot
.786 .35462 Mdot
.786 .35465 Mdot
.786 .35481 Mdot
.786 .35496 Mdot
.786 .35496 Mdot
.786 .35503 Mdot
.786 .35607 Mdot
.786 .35609 Mdot
.786 .35622 Mdot
.786 .35698 Mdot
.786 .35788 Mdot
.786 .35794 Mdot
.786 .35797 Mdot
.786 .35807 Mdot
.786 .35827 Mdot
.786 .35846 Mdot
.786 .35879 Mdot
.786 .35893 Mdot
.786 .35898 Mdot
.786 .35942 Mdot
.786 .36023 Mdot
.786 .36025 Mdot
.786 .36029 Mdot
.786 .3604 Mdot
.786 .36042 Mdot
.786 .36045 Mdot
.786 .36149 Mdot
.786 .36181 Mdot
.786 .36241 Mdot
.786 .36244 Mdot
.786 .36261 Mdot
.786 .36262 Mdot
.786 .36309 Mdot
.786 .36314 Mdot
.786 .36332 Mdot
.786 .36359 Mdot
.786 .36359 Mdot
.786 .36368 Mdot
.786 .36385 Mdot
.786 .36387 Mdot
.786 .36392 Mdot
.786 .36406 Mdot
.786 .36439 Mdot
.786 .36481 Mdot
.786 .3655 Mdot
.786 .36562 Mdot
.786 .36572 Mdot
.786 .36613 Mdot
.786 .36632 Mdot
.786 .36652 Mdot
.786 .36689 Mdot
.786 .36693 Mdot
.786 .36701 Mdot
.786 .36707 Mdot
.786 .3671 Mdot
.786 .36825 Mdot
.786 .36833 Mdot
.786 .36841 Mdot
.786 .36848 Mdot
.786 .36862 Mdot
.786 .36868 Mdot
.786 .36869 Mdot
.786 .36887 Mdot
.786 .36923 Mdot
.786 .36929 Mdot
.786 .36984 Mdot
.786 .37008 Mdot
.786 .3701 Mdot
.786 .37017 Mdot
.786 .37056 Mdot
.786 .3706 Mdot
.786 .37067 Mdot
.786 .37089 Mdot
.786 .37138 Mdot
.786 .37142 Mdot
.786 .37159 Mdot
.786 .37175 Mdot
.786 .37197 Mdot
.786 .37198 Mdot
.786 .37245 Mdot
.786 .37259 Mdot
.786 .37262 Mdot
.786 .37284 Mdot
.786 .37287 Mdot
.786 .37319 Mdot
.786 .37322 Mdot
.786 .37338 Mdot
.786 .37342 Mdot
.786 .37371 Mdot
.786 .37444 Mdot
.786 .37452 Mdot
.786 .37454 Mdot
.786 .37649 Mdot
.786 .37652 Mdot
.786 .37664 Mdot
.786 .37686 Mdot
.786 .37702 Mdot
.786 .37766 Mdot
.786 .37779 Mdot
.786 .37811 Mdot
.786 .37825 Mdot
.786 .37831 Mdot
.786 .37856 Mdot
.786 .37862 Mdot
.786 .37912 Mdot
.786 .37916 Mdot
.786 .37939 Mdot
.786 .37951 Mdot
.786 .37955 Mdot
.786 .37973 Mdot
.786 .37978 Mdot
.786 .38052 Mdot
.786 .38053 Mdot
.786 .38057 Mdot
.786 .38062 Mdot
.786 .38089 Mdot
.786 .38113 Mdot
.786 .38139 Mdot
.786 .38146 Mdot
.786 .38197 Mdot
.786 .38224 Mdot
.786 .38254 Mdot
.786 .38257 Mdot
.786 .38258 Mdot
.786 .38269 Mdot
.786 .38275 Mdot
.786 .38275 Mdot
.786 .38303 Mdot
.786 .38307 Mdot
.786 .38336 Mdot
.786 .38337 Mdot
.786 .38348 Mdot
.786 .3835 Mdot
.786 .38388 Mdot
.786 .38475 Mdot
.786 .38476 Mdot
.786 .38484 Mdot
.786 .38488 Mdot
.786 .3854 Mdot
.786 .38568 Mdot
.786 .38571 Mdot
.786 .3858 Mdot
.786 .38601 Mdot
.786 .38613 Mdot
.786 .38626 Mdot
.786 .38632 Mdot
.786 .38634 Mdot
.786 .38638 Mdot
.786 .38695 Mdot
.786 .38744 Mdot
.786 .38752 Mdot
.786 .38819 Mdot
.786 .38823 Mdot
.786 .38833 Mdot
.786 .38845 Mdot
.786 .38852 Mdot
.786 .3891 Mdot
.786 .38942 Mdot
.786 .38971 Mdot
.786 .39035 Mdot
.786 .39052 Mdot
.786 .3907 Mdot
.786 .39088 Mdot
.786 .39178 Mdot
.786 .39192 Mdot
.786 .39234 Mdot
.786 .39244 Mdot
.786 .39249 Mdot
.786 .39296 Mdot
.786 .39318 Mdot
.786 .39326 Mdot
.786 .39329 Mdot
.786 .39357 Mdot
.786 .3937 Mdot
.786 .39371 Mdot
.786 .39384 Mdot
.786 .39398 Mdot
.786 .39413 Mdot
.786 .39441 Mdot
.786 .39449 Mdot
.786 .39515 Mdot
.786 .39522 Mdot
.786 .39523 Mdot
.786 .39524 Mdot
.786 .39536 Mdot
.786 .39551 Mdot
.786 .39556 Mdot
.786 .39589 Mdot
.786 .39651 Mdot
.786 .39663 Mdot
.786 .39698 Mdot
.786 .39701 Mdot
.786 .39718 Mdot
.786 .39788 Mdot
.786 .39803 Mdot
.786 .39841 Mdot
.786 .39865 Mdot
.786 .39868 Mdot
.786 .39872 Mdot
.786 .39889 Mdot
.786 .39896 Mdot
.786 .39898 Mdot
.786 .399 Mdot
.786 .39907 Mdot
.786 .39947 Mdot
.786 .40026 Mdot
.786 .40061 Mdot
.786 .40096 Mdot
.786 .40103 Mdot
.786 .40126 Mdot
.786 .40158 Mdot
.786 .40165 Mdot
.786 .40177 Mdot
.786 .4019 Mdot
.786 .402 Mdot
.786 .40207 Mdot
.786 .40238 Mdot
.786 .40254 Mdot
.786 .40258 Mdot
.786 .40265 Mdot
.786 .40268 Mdot
.786 .40332 Mdot
.786 .40345 Mdot
.786 .40409 Mdot
.786 .40446 Mdot
.786 .40529 Mdot
.786 .40535 Mdot
.786 .40549 Mdot
.786 .40552 Mdot
.786 .4057 Mdot
.786 .40717 Mdot
.786 .40727 Mdot
.786 .40727 Mdot
.786 .4075 Mdot
.786 .40775 Mdot
.786 .4078 Mdot
.786 .40785 Mdot
.786 .40789 Mdot
.786 .40798 Mdot
.786 .4082 Mdot
.786 .4084 Mdot
.786 .4092 Mdot
.786 .40941 Mdot
.786 .40962 Mdot
.786 .40966 Mdot
.786 .40997 Mdot
.786 .41016 Mdot
.786 .41019 Mdot
.786 .4102 Mdot
.786 .41045 Mdot
.786 .41068 Mdot
.786 .41091 Mdot
.786 .41151 Mdot
.786 .41218 Mdot
.786 .4124 Mdot
.786 .4125 Mdot
.786 .4127 Mdot
.786 .41285 Mdot
.786 .41292 Mdot
.786 .41335 Mdot
.786 .41369 Mdot
.786 .4138 Mdot
.786 .41433 Mdot
.786 .41452 Mdot
.786 .41493 Mdot
.786 .41495 Mdot
.786 .41517 Mdot
.786 .41523 Mdot
.786 .41527 Mdot
.786 .41554 Mdot
.786 .41574 Mdot
.786 .41603 Mdot
.786 .41615 Mdot
.786 .41632 Mdot
.786 .41637 Mdot
.786 .41654 Mdot
.786 .41661 Mdot
.786 .41687 Mdot
.786 .41692 Mdot
.786 .41725 Mdot
.786 .41741 Mdot
.786 .41767 Mdot
.786 .41767 Mdot
.786 .41778 Mdot
.786 .41805 Mdot
.786 .41853 Mdot
.786 .41892 Mdot
.786 .41895 Mdot
.786 .41913 Mdot
.786 .41949 Mdot
.786 .41965 Mdot
.786 .41968 Mdot
.786 .41976 Mdot
.786 .4199 Mdot
.786 .42044 Mdot
.786 .42057 Mdot
.786 .42062 Mdot
.786 .42065 Mdot
.786 .42078 Mdot
.786 .4208 Mdot
.786 .42108 Mdot
.786 .42112 Mdot
.786 .42146 Mdot
.786 .42161 Mdot
.786 .42184 Mdot
.786 .42252 Mdot
.786 .42273 Mdot
.786 .42303 Mdot
.786 .42352 Mdot
.786 .42414 Mdot
.786 .42422 Mdot
.786 .42435 Mdot
.786 .42444 Mdot
.786 .42452 Mdot
.786 .42455 Mdot
.786 .42459 Mdot
.786 .42473 Mdot
.786 .42485 Mdot
.786 .42486 Mdot
.786 .42524 Mdot
.786 .42527 Mdot
.786 .42537 Mdot
.786 .42545 Mdot
.786 .42571 Mdot
.786 .42585 Mdot
.786 .42618 Mdot
.786 .42625 Mdot
.786 .42654 Mdot
.786 .42698 Mdot
.786 .42699 Mdot
.786 .42754 Mdot
.786 .42771 Mdot
.786 .42778 Mdot
.786 .4278 Mdot
.786 .42802 Mdot
.786 .42805 Mdot
.786 .42824 Mdot
.786 .42825 Mdot
.786 .42887 Mdot
.786 .42888 Mdot
.786 .42895 Mdot
.786 .42913 Mdot
.786 .42929 Mdot
.786 .4293 Mdot
.786 .42936 Mdot
.786 .42958 Mdot
.786 .42991 Mdot
.786 .43066 Mdot
.786 .43111 Mdot
.786 .43148 Mdot
.786 .43152 Mdot
.786 .43153 Mdot
.786 .43174 Mdot
.786 .4324 Mdot
.786 .43257 Mdot
.786 .433 Mdot
.786 .43308 Mdot
.786 .43317 Mdot
.786 .43327 Mdot
.786 .43345 Mdot
.786 .43358 Mdot
.786 .43359 Mdot
.786 .43376 Mdot
.786 .43383 Mdot
.786 .43383 Mdot
.786 .43388 Mdot
.786 .43393 Mdot
.786 .43405 Mdot
.786 .43437 Mdot
.786 .43451 Mdot
.786 .4348 Mdot
.786 .43504 Mdot
.786 .43523 Mdot
.786 .43559 Mdot
.786 .43636 Mdot
.786 .43666 Mdot
.786 .4368 Mdot
.786 .43691 Mdot
.786 .43691 Mdot
.786 .43698 Mdot
.786 .43708 Mdot
.786 .43734 Mdot
.786 .43734 Mdot
.786 .43752 Mdot
.786 .43753 Mdot
.786 .43785 Mdot
.786 .43785 Mdot
.786 .43831 Mdot
.786 .43854 Mdot
.786 .43871 Mdot
.786 .43876 Mdot
.786 .43888 Mdot
.786 .43897 Mdot
.786 .43925 Mdot
.786 .43945 Mdot
.786 .44002 Mdot
.786 .44024 Mdot
.786 .44042 Mdot
.786 .44044 Mdot
.786 .44071 Mdot
.786 .44103 Mdot
.786 .44127 Mdot
.786 .44146 Mdot
.786 .44194 Mdot
.786 .44204 Mdot
.786 .44207 Mdot
.786 .44223 Mdot
.786 .44259 Mdot
.786 .44261 Mdot
.786 .44263 Mdot
.786 .44272 Mdot
.786 .44273 Mdot
.786 .44289 Mdot
.786 .44297 Mdot
.786 .44323 Mdot
.786 .44363 Mdot
.786 .44445 Mdot
.786 .44454 Mdot
.786 .44464 Mdot
.786 .44473 Mdot
.786 .44486 Mdot
.786 .44488 Mdot
.786 .44537 Mdot
.786 .44557 Mdot
.786 .44559 Mdot
.786 .44646 Mdot
.786 .4466 Mdot
.786 .44696 Mdot
.786 .44737 Mdot
.786 .44742 Mdot
.786 .44769 Mdot
.786 .44796 Mdot
.786 .448 Mdot
.786 .4481 Mdot
.786 .44813 Mdot
.786 .44852 Mdot
.786 .44898 Mdot
.786 .44914 Mdot
.786 .44917 Mdot
.786 .44941 Mdot
.786 .44956 Mdot
.786 .44962 Mdot
.786 .44991 Mdot
.786 .44999 Mdot
.786 .45013 Mdot
.786 .45043 Mdot
.786 .45065 Mdot
.786 .4507 Mdot
.786 .45073 Mdot
.786 .4512 Mdot
.786 .45126 Mdot
.786 .45181 Mdot
.786 .45187 Mdot
.786 .45204 Mdot
.786 .45246 Mdot
.786 .45382 Mdot
.786 .45385 Mdot
.786 .45405 Mdot
.786 .45429 Mdot
.786 .4543 Mdot
.786 .45488 Mdot
.786 .45493 Mdot
.786 .4555 Mdot
.786 .45562 Mdot
.786 .45563 Mdot
.786 .45575 Mdot
.786 .45582 Mdot
.786 .45583 Mdot
.786 .45606 Mdot
.786 .45661 Mdot
.786 .45663 Mdot
.786 .45697 Mdot
.786 .45711 Mdot
.786 .45763 Mdot
.786 .45781 Mdot
.786 .45807 Mdot
.786 .45813 Mdot
.786 .45907 Mdot
.786 .45908 Mdot
.786 .45911 Mdot
.786 .4594 Mdot
.786 .4596 Mdot
.786 .45975 Mdot
.786 .45985 Mdot
.786 .45992 Mdot
.786 .46011 Mdot
.786 .46011 Mdot
.786 .4602 Mdot
.786 .46033 Mdot
.786 .46067 Mdot
.786 .46087 Mdot
.786 .46097 Mdot
.786 .46144 Mdot
.786 .46152 Mdot
.786 .46155 Mdot
.786 .46217 Mdot
.786 .4624 Mdot
.786 .46273 Mdot
.786 .46331 Mdot
.786 .46361 Mdot
.786 .46435 Mdot
.786 .46479 Mdot
.786 .46485 Mdot
.786 .46654 Mdot
.786 .46699 Mdot
.786 .46712 Mdot
.786 .46723 Mdot
.786 .46749 Mdot
.786 .46774 Mdot
.786 .46808 Mdot
.786 .46826 Mdot
.786 .46831 Mdot
.786 .46843 Mdot
.786 .46912 Mdot
.786 .46917 Mdot
.786 .46932 Mdot
.786 .46948 Mdot
.786 .46956 Mdot
.786 .46967 Mdot
.786 .46999 Mdot
.786 .47018 Mdot
.786 .47044 Mdot
.786 .47133 Mdot
.786 .47167 Mdot
.786 .47174 Mdot
.786 .47188 Mdot
.786 .47195 Mdot
.786 .47221 Mdot
.786 .47234 Mdot
.786 .47323 Mdot
.786 .47324 Mdot
.786 .47329 Mdot
.786 .47368 Mdot
.786 .47377 Mdot
.786 .47383 Mdot
.786 .47397 Mdot
.786 .47408 Mdot
.786 .47473 Mdot
.786 .47473 Mdot
.786 .47522 Mdot
.786 .47592 Mdot
.786 .47594 Mdot
.786 .47625 Mdot
.786 .47656 Mdot
.786 .47667 Mdot
.786 .4768 Mdot
.786 .47685 Mdot
.786 .47686 Mdot
.786 .47721 Mdot
.786 .4774 Mdot
.786 .47748 Mdot
.786 .47789 Mdot
.786 .47803 Mdot
.786 .47816 Mdot
.788 .21203 Mdot
.788 .21222 Mdot
.788 .21287 Mdot
.788 .21322 Mdot
.788 .21337 Mdot
.788 .21338 Mdot
.788 .21377 Mdot
.788 .21479 Mdot
.788 .21532 Mdot
.788 .21582 Mdot
.788 .2169 Mdot
.788 .21713 Mdot
.788 .21764 Mdot
.788 .21831 Mdot
.788 .21886 Mdot
.788 .21894 Mdot
.788 .21931 Mdot
.788 .21931 Mdot
.788 .21936 Mdot
.788 .2195 Mdot
.788 .21985 Mdot
.788 .21991 Mdot
.788 .22074 Mdot
.788 .22113 Mdot
.788 .22138 Mdot
.788 .22217 Mdot
.788 .2224 Mdot
.788 .22264 Mdot
.788 .22278 Mdot
.788 .22308 Mdot
.788 .2246 Mdot
.788 .22525 Mdot
.788 .22582 Mdot
.788 .22673 Mdot
.788 .2273 Mdot
.788 .22772 Mdot
.788 .22805 Mdot
.788 .22866 Mdot
.788 .22901 Mdot
.788 .22908 Mdot
.788 .2295 Mdot
.788 .2295 Mdot
.788 .22962 Mdot
.788 .22963 Mdot
.788 .22996 Mdot
.788 .23073 Mdot
.788 .23163 Mdot
.788 .23247 Mdot
.788 .2325 Mdot
.788 .23315 Mdot
.788 .2337 Mdot
.788 .23383 Mdot
.788 .2341 Mdot
.788 .23552 Mdot
.788 .23559 Mdot
.788 .23604 Mdot
.788 .23725 Mdot
.788 .23726 Mdot
.788 .23751 Mdot
.788 .23836 Mdot
.788 .23849 Mdot
.788 .23877 Mdot
.788 .23938 Mdot
.788 .23947 Mdot
.788 .24013 Mdot
.788 .24147 Mdot
.788 .24172 Mdot
.788 .24237 Mdot
.788 .24243 Mdot
.788 .24259 Mdot
.788 .24279 Mdot
.788 .24296 Mdot
.788 .24412 Mdot
.788 .24468 Mdot
.788 .24475 Mdot
.788 .24486 Mdot
.788 .24541 Mdot
.788 .24578 Mdot
.788 .24643 Mdot
.788 .24719 Mdot
.788 .24784 Mdot
.788 .24791 Mdot
.788 .24802 Mdot
.788 .24821 Mdot
.788 .24885 Mdot
.788 .24892 Mdot
.788 .24902 Mdot
.788 .24921 Mdot
.788 .24923 Mdot
.788 .24927 Mdot
.788 .25036 Mdot
.788 .25041 Mdot
.788 .25096 Mdot
.788 .25109 Mdot
.788 .25112 Mdot
.788 .25152 Mdot
.788 .25174 Mdot
.788 .25181 Mdot
.788 .252 Mdot
.788 .25229 Mdot
.788 .25308 Mdot
.788 .25312 Mdot
.788 .2536 Mdot
.788 .25444 Mdot
.788 .25462 Mdot
.788 .25481 Mdot
.788 .25549 Mdot
.788 .25553 Mdot
.788 .25561 Mdot
.788 .25619 Mdot
.788 .25644 Mdot
.788 .25645 Mdot
.788 .25674 Mdot
.788 .25678 Mdot
.788 .2568 Mdot
.788 .25699 Mdot
.788 .25716 Mdot
.788 .25761 Mdot
.788 .2577 Mdot
.788 .25795 Mdot
.788 .25834 Mdot
.788 .2587 Mdot
.788 .25911 Mdot
.788 .25961 Mdot
.788 .26009 Mdot
.788 .26057 Mdot
.788 .26081 Mdot
.788 .2611 Mdot
.788 .26187 Mdot
.788 .26235 Mdot
.788 .26247 Mdot
.788 .26295 Mdot
.788 .26301 Mdot
.788 .26382 Mdot
.788 .26422 Mdot
.788 .26443 Mdot
.788 .26494 Mdot
.788 .26534 Mdot
.788 .26571 Mdot
.788 .26613 Mdot
.788 .26637 Mdot
.788 .26644 Mdot
.788 .26743 Mdot
.788 .26779 Mdot
.788 .26852 Mdot
.788 .26854 Mdot
.788 .26907 Mdot
.788 .26973 Mdot
.788 .27004 Mdot
.788 .27036 Mdot
.788 .27052 Mdot
.788 .27061 Mdot
.788 .27151 Mdot
.788 .27159 Mdot
.788 .27174 Mdot
.788 .2718 Mdot
.788 .27184 Mdot
.788 .27201 Mdot
.788 .27256 Mdot
.788 .27271 Mdot
.788 .27309 Mdot
.788 .27316 Mdot
.788 .27318 Mdot
.788 .27318 Mdot
.788 .27336 Mdot
.788 .2735 Mdot
.788 .27413 Mdot
.788 .27476 Mdot
.788 .27613 Mdot
.788 .27654 Mdot
.788 .27655 Mdot
.788 .27664 Mdot
.788 .27723 Mdot
.788 .27771 Mdot
.788 .27804 Mdot
.788 .27828 Mdot
.788 .27858 Mdot
.788 .27931 Mdot
.788 .27968 Mdot
.788 .28002 Mdot
.788 .28005 Mdot
.788 .28024 Mdot
.788 .28024 Mdot
.788 .28024 Mdot
.788 .28078 Mdot
.788 .28078 Mdot
.788 .2808 Mdot
.788 .28193 Mdot
.788 .28216 Mdot
.788 .28238 Mdot
.788 .28336 Mdot
.788 .2836 Mdot
.788 .28364 Mdot
.788 .28364 Mdot
.788 .285 Mdot
.788 .285 Mdot
.788 .285 Mdot
.788 .28547 Mdot
.788 .28555 Mdot
.788 .28558 Mdot
.788 .28563 Mdot
.788 .28639 Mdot
.788 .28665 Mdot
.788 .28686 Mdot
.788 .28717 Mdot
.788 .28731 Mdot
.788 .288 Mdot
.788 .28815 Mdot
.788 .2886 Mdot
.788 .28912 Mdot
.788 .28955 Mdot
.788 .28986 Mdot
.788 .29007 Mdot
.788 .29046 Mdot
.788 .29083 Mdot
.788 .29123 Mdot
.788 .29126 Mdot
.788 .29151 Mdot
.788 .29173 Mdot
.788 .29212 Mdot
.788 .29247 Mdot
.788 .29288 Mdot
.788 .29309 Mdot
.788 .2936 Mdot
.788 .29388 Mdot
.788 .29389 Mdot
.788 .29394 Mdot
.788 .29416 Mdot
.788 .29418 Mdot
.788 .29464 Mdot
.788 .29479 Mdot
.788 .29505 Mdot
.788 .29517 Mdot
.788 .2952 Mdot
.788 .29546 Mdot
.788 .29576 Mdot
.788 .29617 Mdot
.788 .29644 Mdot
.788 .29716 Mdot
.788 .29723 Mdot
.788 .29731 Mdot
.788 .29738 Mdot
.788 .29776 Mdot
.788 .2986 Mdot
.788 .29885 Mdot
.788 .30016 Mdot
.788 .30073 Mdot
.788 .30084 Mdot
.788 .30172 Mdot
.788 .30208 Mdot
.788 .3024 Mdot
.788 .30253 Mdot
.788 .30253 Mdot
.788 .30258 Mdot
.788 .30275 Mdot
.788 .30292 Mdot
.788 .30317 Mdot
.788 .3033 Mdot
.788 .3037 Mdot
.788 .30406 Mdot
.788 .30544 Mdot
.788 .30553 Mdot
.788 .30585 Mdot
.788 .30595 Mdot
.788 .30611 Mdot
.788 .30647 Mdot
.788 .30669 Mdot
.788 .30686 Mdot
.788 .30709 Mdot
.788 .30736 Mdot
.788 .3085 Mdot
.788 .30892 Mdot
.788 .30907 Mdot
.788 .30914 Mdot
.788 .30954 Mdot
.788 .30962 Mdot
.788 .31011 Mdot
.788 .31032 Mdot
.788 .3111 Mdot
.788 .3113 Mdot
.788 .31174 Mdot
.788 .31183 Mdot
.788 .31256 Mdot
.788 .31271 Mdot
.788 .31273 Mdot
.788 .31279 Mdot
.788 .31295 Mdot
.788 .31405 Mdot
.788 .3141 Mdot
.788 .31423 Mdot
.788 .31484 Mdot
.788 .3151 Mdot
.788 .31592 Mdot
.788 .31661 Mdot
.788 .31681 Mdot
.788 .31801 Mdot
.788 .31802 Mdot
.788 .31828 Mdot
.788 .3185 Mdot
.788 .31926 Mdot
.788 .31945 Mdot
.788 .31993 Mdot
.788 .31994 Mdot
.788 .32004 Mdot
.788 .32038 Mdot
.788 .32043 Mdot
.788 .32082 Mdot
.788 .32109 Mdot
.788 .32173 Mdot
.788 .32199 Mdot
.788 .3227 Mdot
.788 .32292 Mdot
.788 .32299 Mdot
.788 .32337 Mdot
.788 .32427 Mdot
.788 .32463 Mdot
.788 .32467 Mdot
.788 .32475 Mdot
.788 .32477 Mdot
.788 .32568 Mdot
.788 .32576 Mdot
.788 .32587 Mdot
.788 .32598 Mdot
.788 .32632 Mdot
.788 .32685 Mdot
.788 .327 Mdot
.788 .32729 Mdot
.788 .32732 Mdot
.788 .32756 Mdot
.788 .32766 Mdot
.788 .32778 Mdot
.788 .3278 Mdot
.788 .3278 Mdot
.788 .32795 Mdot
.788 .32826 Mdot
.788 .32842 Mdot
.788 .32873 Mdot
.788 .32913 Mdot
.788 .32942 Mdot
.788 .33004 Mdot
.788 .33009 Mdot
.788 .3303 Mdot
.788 .33063 Mdot
.788 .33087 Mdot
.788 .33108 Mdot
.788 .33156 Mdot
.788 .33165 Mdot
.788 .33168 Mdot
.788 .33252 Mdot
.788 .33313 Mdot
.788 .33326 Mdot
.788 .33333 Mdot
.788 .33336 Mdot
.788 .33372 Mdot
.788 .33386 Mdot
.788 .33415 Mdot
.788 .33421 Mdot
.788 .33436 Mdot
.788 .33447 Mdot
.788 .33453 Mdot
.788 .33478 Mdot
.788 .33503 Mdot
.788 .33559 Mdot
.788 .33622 Mdot
.788 .33635 Mdot
.788 .33645 Mdot
.788 .33657 Mdot
.788 .33686 Mdot
.788 .33715 Mdot
.788 .33716 Mdot
.788 .33724 Mdot
.788 .33724 Mdot
.788 .33746 Mdot
.788 .33746 Mdot
.788 .33792 Mdot
.788 .33801 Mdot
.788 .3381 Mdot
.788 .3385 Mdot
.788 .33939 Mdot
.788 .33941 Mdot
.788 .33982 Mdot
.788 .33991 Mdot
.788 .34003 Mdot
.788 .34037 Mdot
.788 .34042 Mdot
.788 .34061 Mdot
.788 .34099 Mdot
.788 .3412 Mdot
.788 .3415 Mdot
.788 .34166 Mdot
.788 .34178 Mdot
.788 .34187 Mdot
.788 .34202 Mdot
.788 .34233 Mdot
.788 .34241 Mdot
.788 .34262 Mdot
.788 .34273 Mdot
.788 .34274 Mdot
.788 .34304 Mdot
.788 .3431 Mdot
.788 .3432 Mdot
.788 .34325 Mdot
.788 .34337 Mdot
.788 .34349 Mdot
.788 .34366 Mdot
.788 .34376 Mdot
.788 .34405 Mdot
.788 .34408 Mdot
.788 .34411 Mdot
.788 .34414 Mdot
.788 .34429 Mdot
.788 .34473 Mdot
.788 .34549 Mdot
.788 .34553 Mdot
.788 .34616 Mdot
.788 .34637 Mdot
.788 .34647 Mdot
.788 .34652 Mdot
.788 .34742 Mdot
.788 .34796 Mdot
.788 .34805 Mdot
.788 .34816 Mdot
.788 .34862 Mdot
.788 .34885 Mdot
.788 .34907 Mdot
.788 .34927 Mdot
.788 .34975 Mdot
.788 .34992 Mdot
.788 .34996 Mdot
.788 .35025 Mdot
.788 .35031 Mdot
.788 .35034 Mdot
.788 .35041 Mdot
.788 .35092 Mdot
.788 .35117 Mdot
.788 .35128 Mdot
.788 .35188 Mdot
.788 .35236 Mdot
.788 .35245 Mdot
.788 .35245 Mdot
.788 .35256 Mdot
.788 .35264 Mdot
.788 .35322 Mdot
.788 .35322 Mdot
.788 .3534 Mdot
.788 .35342 Mdot
.788 .35358 Mdot
.788 .35394 Mdot
.788 .35433 Mdot
.788 .35442 Mdot
.788 .3546 Mdot
.788 .35511 Mdot
.788 .35513 Mdot
.788 .35516 Mdot
.788 .35561 Mdot
.788 .35579 Mdot
.788 .35601 Mdot
.788 .35618 Mdot
.788 .3562 Mdot
.788 .35633 Mdot
.788 .35657 Mdot
.788 .35676 Mdot
.788 .35731 Mdot
.788 .3574 Mdot
.788 .35771 Mdot
.788 .3579 Mdot
.788 .35795 Mdot
.788 .35854 Mdot
.788 .35861 Mdot
.788 .35894 Mdot
.788 .35897 Mdot
.788 .35903 Mdot
.788 .35907 Mdot
.788 .3592 Mdot
.788 .35983 Mdot
.788 .36004 Mdot
.788 .36019 Mdot
.788 .36046 Mdot
.788 .36123 Mdot
.788 .36126 Mdot
.788 .36154 Mdot
.788 .3619 Mdot
.788 .36202 Mdot
.788 .36205 Mdot
.788 .3624 Mdot
.788 .36252 Mdot
.788 .3627 Mdot
.788 .36277 Mdot
.788 .36281 Mdot
.788 .36293 Mdot
.788 .36297 Mdot
.788 .36303 Mdot
.788 .36353 Mdot
.788 .3645 Mdot
.788 .36454 Mdot
.788 .36503 Mdot
.788 .36529 Mdot
.788 .36531 Mdot
.788 .36543 Mdot
.788 .36545 Mdot
.788 .36546 Mdot
.788 .36584 Mdot
.788 .36639 Mdot
.788 .36677 Mdot
.788 .36707 Mdot
.788 .36718 Mdot
.788 .36738 Mdot
.788 .36774 Mdot
.788 .36782 Mdot
.788 .36805 Mdot
.788 .36876 Mdot
.788 .36879 Mdot
.788 .36893 Mdot
.788 .36896 Mdot
.788 .36943 Mdot
.788 .36985 Mdot
.788 .36986 Mdot
.788 .36997 Mdot
.788 .37032 Mdot
.788 .37053 Mdot
.788 .37057 Mdot
.788 .37117 Mdot
.788 .37149 Mdot
.788 .37193 Mdot
.788 .37208 Mdot
.788 .37247 Mdot
.788 .37259 Mdot
.788 .37288 Mdot
.788 .37315 Mdot
.788 .37332 Mdot
.788 .37332 Mdot
.788 .37351 Mdot
.788 .37359 Mdot
.788 .37385 Mdot
.788 .37415 Mdot
.788 .37442 Mdot
.788 .37472 Mdot
.788 .37625 Mdot
.788 .37714 Mdot
.788 .37714 Mdot
.788 .37725 Mdot
.788 .37742 Mdot
.788 .3776 Mdot
.788 .37802 Mdot
.788 .3783 Mdot
.788 .3785 Mdot
.788 .37888 Mdot
.788 .37891 Mdot
.788 .37904 Mdot
.788 .37933 Mdot
.788 .37934 Mdot
.788 .37961 Mdot
.788 .3799 Mdot
.788 .38003 Mdot
.788 .38048 Mdot
.788 .38067 Mdot
.788 .3811 Mdot
.788 .38129 Mdot
.788 .38153 Mdot
.788 .38212 Mdot
.788 .38222 Mdot
.788 .38223 Mdot
.788 .3824 Mdot
.788 .38271 Mdot
.788 .38273 Mdot
.788 .38367 Mdot
.788 .38371 Mdot
.788 .38373 Mdot
.788 .38383 Mdot
.788 .38399 Mdot
.788 .38406 Mdot
.788 .38429 Mdot
.788 .38431 Mdot
.788 .38438 Mdot
.788 .38461 Mdot
.788 .38479 Mdot
.788 .38481 Mdot
.788 .38547 Mdot
.788 .3861 Mdot
.788 .38618 Mdot
.788 .3862 Mdot
.788 .38626 Mdot
.788 .38647 Mdot
.788 .38652 Mdot
.788 .38704 Mdot
.788 .38724 Mdot
.788 .3873 Mdot
.788 .38764 Mdot
.788 .38792 Mdot
.788 .388 Mdot
.788 .38812 Mdot
.788 .38826 Mdot
.788 .38837 Mdot
.788 .38868 Mdot
.788 .38869 Mdot
.788 .38901 Mdot
.788 .38913 Mdot
.788 .38918 Mdot
.788 .38966 Mdot
.788 .39026 Mdot
.788 .39038 Mdot
.788 .39044 Mdot
.788 .39112 Mdot
.788 .39119 Mdot
.788 .39172 Mdot
.788 .39174 Mdot
.788 .39177 Mdot
.788 .39196 Mdot
.788 .39198 Mdot
.788 .3924 Mdot
.788 .39253 Mdot
.788 .39281 Mdot
.788 .3931 Mdot
.788 .39317 Mdot
.788 .39323 Mdot
.788 .39417 Mdot
.788 .39424 Mdot
.788 .39437 Mdot
.788 .39477 Mdot
.788 .39528 Mdot
.788 .39555 Mdot
.788 .39565 Mdot
.788 .39567 Mdot
.788 .39569 Mdot
.788 .39571 Mdot
.788 .39589 Mdot
.788 .39596 Mdot
.788 .39606 Mdot
.788 .39614 Mdot
.788 .39622 Mdot
.788 .39625 Mdot
.788 .39635 Mdot
.788 .39654 Mdot
.788 .39655 Mdot
.788 .3968 Mdot
.788 .39709 Mdot
.788 .39715 Mdot
.788 .39733 Mdot
.788 .39752 Mdot
.788 .39765 Mdot
.788 .39789 Mdot
.788 .39805 Mdot
.788 .39834 Mdot
.788 .39839 Mdot
.788 .39867 Mdot
.788 .39923 Mdot
.788 .3996 Mdot
.788 .39989 Mdot
.788 .40003 Mdot
.788 .40027 Mdot
.788 .40059 Mdot
.788 .40068 Mdot
.788 .40143 Mdot
.788 .40159 Mdot
.788 .40179 Mdot
.788 .40186 Mdot
.788 .40195 Mdot
.788 .40199 Mdot
.788 .40218 Mdot
.788 .40251 Mdot
.788 .40255 Mdot
.788 .40263 Mdot
.788 .40302 Mdot
.788 .40356 Mdot
.788 .40363 Mdot
.788 .40394 Mdot
.788 .40422 Mdot
.788 .40443 Mdot
.788 .40457 Mdot
.788 .40499 Mdot
.788 .40518 Mdot
.788 .40543 Mdot
.788 .40573 Mdot
.788 .40593 Mdot
.788 .40603 Mdot
.788 .40611 Mdot
.788 .40632 Mdot
.788 .40634 Mdot
.788 .40662 Mdot
.788 .40696 Mdot
.788 .40724 Mdot
.788 .40731 Mdot
.788 .40794 Mdot
.788 .40795 Mdot
.788 .408 Mdot
.788 .40803 Mdot
.788 .40826 Mdot
.788 .40883 Mdot
.788 .40907 Mdot
.788 .40911 Mdot
.788 .40926 Mdot
.788 .4097 Mdot
.788 .40987 Mdot
.788 .41028 Mdot
.788 .41045 Mdot
.788 .4107 Mdot
.788 .41073 Mdot
.788 .41095 Mdot
.788 .41101 Mdot
.788 .41101 Mdot
.788 .41132 Mdot
.788 .41144 Mdot
.788 .41192 Mdot
.788 .41206 Mdot
.788 .41222 Mdot
.788 .41223 Mdot
.788 .41299 Mdot
.788 .41312 Mdot
.788 .41355 Mdot
.788 .41408 Mdot
.788 .41424 Mdot
.788 .41463 Mdot
.788 .41471 Mdot
.788 .41474 Mdot
.788 .41544 Mdot
.788 .41555 Mdot
.788 .41558 Mdot
.788 .41559 Mdot
.788 .41569 Mdot
.788 .41615 Mdot
.788 .41621 Mdot
.788 .41649 Mdot
.788 .41661 Mdot
.788 .41711 Mdot
.788 .41724 Mdot
.788 .41756 Mdot
.788 .41761 Mdot
.788 .41786 Mdot
.788 .4179 Mdot
.788 .418 Mdot
.788 .41826 Mdot
.788 .41899 Mdot
.788 .41916 Mdot
.788 .4193 Mdot
.788 .41942 Mdot
.788 .41956 Mdot
.788 .41978 Mdot
.788 .41988 Mdot
.788 .41995 Mdot
.788 .42015 Mdot
.788 .42021 Mdot
.788 .42108 Mdot
.788 .42131 Mdot
.788 .42157 Mdot
.788 .42165 Mdot
.788 .42181 Mdot
.788 .42191 Mdot
.788 .42202 Mdot
.788 .42205 Mdot
.788 .42205 Mdot
.788 .42214 Mdot
.788 .42234 Mdot
.788 .42257 Mdot
.788 .42313 Mdot
.788 .4232 Mdot
.788 .42356 Mdot
.788 .42439 Mdot
.788 .42455 Mdot
.788 .42508 Mdot
.788 .42532 Mdot
.788 .42537 Mdot
.788 .42542 Mdot
.788 .42546 Mdot
.788 .42592 Mdot
.788 .42609 Mdot
.788 .42635 Mdot
.788 .42654 Mdot
.788 .42671 Mdot
.788 .42672 Mdot
.788 .4268 Mdot
.788 .42696 Mdot
.788 .42706 Mdot
.788 .42735 Mdot
.788 .42736 Mdot
.788 .4275 Mdot
.788 .42754 Mdot
.788 .42755 Mdot
.788 .42772 Mdot
.788 .42805 Mdot
.788 .42818 Mdot
.788 .42844 Mdot
.788 .42866 Mdot
.788 .42891 Mdot
.788 .42905 Mdot
.788 .4292 Mdot
.788 .42922 Mdot
.788 .42948 Mdot
.788 .42971 Mdot
.788 .42996 Mdot
.788 .4301 Mdot
.788 .43029 Mdot
.788 .43057 Mdot
.788 .43089 Mdot
.788 .43118 Mdot
.788 .43127 Mdot
.788 .43171 Mdot
.788 .4318 Mdot
.788 .43199 Mdot
.788 .43213 Mdot
.788 .4323 Mdot
.788 .43277 Mdot
.788 .43281 Mdot
.788 .43283 Mdot
.788 .43288 Mdot
.788 .43317 Mdot
.788 .43318 Mdot
.788 .43318 Mdot
.788 .43404 Mdot
.788 .43404 Mdot
.788 .43406 Mdot
.788 .43421 Mdot
.788 .43484 Mdot
.788 .43498 Mdot
.788 .43512 Mdot
.788 .43584 Mdot
.788 .43585 Mdot
.788 .43585 Mdot
.788 .4362 Mdot
.788 .4362 Mdot
.788 .4362 Mdot
.788 .43632 Mdot
.788 .43634 Mdot
.788 .43655 Mdot
.788 .43679 Mdot
.788 .43725 Mdot
.788 .43744 Mdot
.788 .43759 Mdot
.788 .4378 Mdot
.788 .43811 Mdot
.788 .43848 Mdot
.788 .43854 Mdot
.788 .43855 Mdot
.788 .4388 Mdot
.788 .43967 Mdot
.788 .44007 Mdot
.788 .44047 Mdot
.788 .44056 Mdot
.788 .44068 Mdot
.788 .44068 Mdot
.788 .44069 Mdot
.788 .44073 Mdot
.788 .44098 Mdot
.788 .44107 Mdot
.788 .44142 Mdot
.788 .44153 Mdot
.788 .44155 Mdot
.788 .44159 Mdot
.788 .44168 Mdot
.788 .44174 Mdot
.788 .44231 Mdot
.788 .44237 Mdot
.788 .44247 Mdot
.788 .44267 Mdot
.788 .44287 Mdot
.788 .44328 Mdot
.788 .44362 Mdot
.788 .44363 Mdot
.788 .4441 Mdot
.788 .44433 Mdot
.788 .44495 Mdot
.788 .445 Mdot
.788 .44515 Mdot
.788 .44542 Mdot
.788 .44565 Mdot
.788 .44591 Mdot
.788 .44623 Mdot
.788 .44636 Mdot
.788 .44661 Mdot
.788 .44713 Mdot
.788 .44717 Mdot
.788 .44747 Mdot
.788 .44755 Mdot
.788 .44786 Mdot
.788 .44834 Mdot
.788 .44853 Mdot
.788 .44868 Mdot
.788 .44898 Mdot
.788 .44929 Mdot
.788 .4496 Mdot
.788 .44987 Mdot
.788 .45009 Mdot
.788 .45034 Mdot
.788 .4505 Mdot
.788 .45056 Mdot
.788 .45085 Mdot
.788 .45095 Mdot
.788 .45107 Mdot
.788 .45108 Mdot
.788 .45111 Mdot
.788 .45129 Mdot
.788 .4513 Mdot
.788 .45146 Mdot
.788 .45182 Mdot
.788 .45188 Mdot
.788 .4519 Mdot
.788 .45233 Mdot
.788 .45245 Mdot
.788 .45257 Mdot
.788 .4531 Mdot
.788 .45341 Mdot
.788 .45343 Mdot
.788 .45394 Mdot
.788 .45411 Mdot
.788 .45424 Mdot
.788 .45428 Mdot
.788 .45442 Mdot
.788 .45467 Mdot
.788 .45469 Mdot
.788 .45477 Mdot
.788 .45512 Mdot
.788 .45515 Mdot
.788 .45585 Mdot
.788 .45587 Mdot
.788 .45588 Mdot
.788 .456 Mdot
.788 .45607 Mdot
.788 .45612 Mdot
.788 .45652 Mdot
.788 .45664 Mdot
.788 .45671 Mdot
.788 .45676 Mdot
.788 .45717 Mdot
.788 .45765 Mdot
.788 .45806 Mdot
.788 .45829 Mdot
.788 .45865 Mdot
.788 .45872 Mdot
.788 .45876 Mdot
.788 .45912 Mdot
.788 .45986 Mdot
.788 .45996 Mdot
.788 .46009 Mdot
.788 .46019 Mdot
.788 .46022 Mdot
.788 .46064 Mdot
.788 .4608 Mdot
.788 .46165 Mdot
.788 .46207 Mdot
.788 .46212 Mdot
.788 .46251 Mdot
.788 .46269 Mdot
.788 .46277 Mdot
.788 .46331 Mdot
.788 .46347 Mdot
.788 .46348 Mdot
.788 .46424 Mdot
.788 .46453 Mdot
.788 .46457 Mdot
.788 .46548 Mdot
.788 .46565 Mdot
.788 .46573 Mdot
.788 .46608 Mdot
.788 .46649 Mdot
.788 .46651 Mdot
.788 .46704 Mdot
.788 .46761 Mdot
.788 .4681 Mdot
.788 .46831 Mdot
.788 .46832 Mdot
.788 .46839 Mdot
.788 .46839 Mdot
.788 .46866 Mdot
.788 .4687 Mdot
.788 .46893 Mdot
.788 .46932 Mdot
.788 .46952 Mdot
.788 .46979 Mdot
.788 .47015 Mdot
.788 .47073 Mdot
.788 .47109 Mdot
.788 .4715 Mdot
.788 .47247 Mdot
.788 .47266 Mdot
.788 .47274 Mdot
.788 .4729 Mdot
.788 .47304 Mdot
.788 .47354 Mdot
.788 .4737 Mdot
.788 .47395 Mdot
.788 .47448 Mdot
.788 .47451 Mdot
.788 .47474 Mdot
.788 .47483 Mdot
.788 .47486 Mdot
.788 .47486 Mdot
.788 .47509 Mdot
.788 .47514 Mdot
.788 .47549 Mdot
.788 .47592 Mdot
.788 .47624 Mdot
.788 .47639 Mdot
.788 .47707 Mdot
.788 .47739 Mdot
.788 .47772 Mdot
.788 .47838 Mdot
.788 .47862 Mdot
.788 .47863 Mdot
.788 .47872 Mdot
.788 .47895 Mdot
.788 .47936 Mdot
.788 .47948 Mdot
.79 .21155 Mdot
.79 .21274 Mdot
.79 .21334 Mdot
.79 .21409 Mdot
.79 .21475 Mdot
.79 .21492 Mdot
.79 .21582 Mdot
.79 .21586 Mdot
.79 .21619 Mdot
.79 .21678 Mdot
.79 .21697 Mdot
.79 .21709 Mdot
.79 .21711 Mdot
.79 .21723 Mdot
.79 .21752 Mdot
.79 .21791 Mdot
.79 .21797 Mdot
.79 .218 Mdot
.79 .21829 Mdot
.79 .21849 Mdot
.79 .21903 Mdot
.79 .21949 Mdot
.79 .21961 Mdot
.79 .21991 Mdot
.79 .21991 Mdot
.79 .22011 Mdot
.79 .2211 Mdot
.79 .22131 Mdot
.79 .22157 Mdot
.79 .22165 Mdot
.79 .22187 Mdot
.79 .22218 Mdot
.79 .2222 Mdot
.79 .22294 Mdot
.79 .2233 Mdot
.79 .22372 Mdot
.79 .22376 Mdot
.79 .22417 Mdot
.79 .22506 Mdot
.79 .22538 Mdot
.79 .22576 Mdot
.79 .2259 Mdot
.79 .22593 Mdot
.79 .22599 Mdot
.79 .22612 Mdot
.79 .22613 Mdot
.79 .22712 Mdot
.79 .22723 Mdot
.79 .22733 Mdot
.79 .22753 Mdot
.79 .22773 Mdot
.79 .22814 Mdot
.79 .22816 Mdot
.79 .22843 Mdot
.79 .22855 Mdot
.79 .2288 Mdot
.79 .22994 Mdot
.79 .23045 Mdot
.79 .23057 Mdot
.79 .23202 Mdot
.79 .23213 Mdot
.79 .23226 Mdot
.79 .23246 Mdot
.79 .23279 Mdot
.79 .23286 Mdot
.79 .2334 Mdot
.79 .23379 Mdot
.79 .23412 Mdot
.79 .23533 Mdot
.79 .23583 Mdot
.79 .23622 Mdot
.79 .23719 Mdot
.79 .23728 Mdot
.79 .23756 Mdot
.79 .23758 Mdot
.79 .23815 Mdot
.79 .23817 Mdot
.79 .23849 Mdot
.79 .23867 Mdot
.79 .23984 Mdot
.79 .23992 Mdot
.79 .23999 Mdot
.79 .24083 Mdot
.79 .24198 Mdot
.79 .24245 Mdot
.79 .24261 Mdot
.79 .24263 Mdot
.79 .24292 Mdot
.79 .24334 Mdot
.79 .24369 Mdot
.79 .24472 Mdot
.79 .2452 Mdot
.79 .24526 Mdot
.79 .24598 Mdot
.79 .2462 Mdot
.79 .24682 Mdot
.79 .24688 Mdot
.79 .24732 Mdot
.79 .24759 Mdot
.79 .24782 Mdot
.79 .24822 Mdot
.79 .24853 Mdot
.79 .24867 Mdot
.79 .24923 Mdot
.79 .24989 Mdot
.79 .25013 Mdot
.79 .25046 Mdot
.79 .25231 Mdot
.79 .25287 Mdot
.79 .2532 Mdot
.79 .25344 Mdot
.79 .25352 Mdot
.79 .25368 Mdot
.79 .25474 Mdot
.79 .25516 Mdot
.79 .25576 Mdot
.79 .25671 Mdot
.79 .25721 Mdot
.79 .25752 Mdot
.79 .25794 Mdot
.79 .25835 Mdot
.79 .25875 Mdot
.79 .25889 Mdot
.79 .25958 Mdot
.79 .25968 Mdot
.79 .2597 Mdot
.79 .25984 Mdot
.79 .25996 Mdot
.79 .26015 Mdot
.79 .26021 Mdot
.79 .26048 Mdot
.79 .26226 Mdot
.79 .26309 Mdot
.79 .26373 Mdot
.79 .26411 Mdot
.79 .26437 Mdot
.79 .26489 Mdot
.79 .26522 Mdot
.79 .26564 Mdot
.79 .26596 Mdot
.79 .26645 Mdot
.79 .26649 Mdot
.79 .26711 Mdot
.79 .26727 Mdot
.79 .26743 Mdot
.79 .26843 Mdot
.79 .26874 Mdot
.79 .26936 Mdot
.79 .26948 Mdot
.79 .26977 Mdot
.79 .27101 Mdot
.79 .27108 Mdot
.79 .27114 Mdot
.79 .27132 Mdot
.79 .27149 Mdot
.79 .27173 Mdot
.79 .27183 Mdot
.79 .27215 Mdot
.79 .27229 Mdot
.79 .2724 Mdot
.79 .27242 Mdot
.79 .27264 Mdot
.79 .27268 Mdot
.79 .27272 Mdot
.79 .27285 Mdot
.79 .27342 Mdot
.79 .27402 Mdot
.79 .27408 Mdot
.79 .2743 Mdot
.79 .27439 Mdot
.79 .27447 Mdot
.79 .27466 Mdot
.79 .27482 Mdot
.79 .27508 Mdot
.79 .27522 Mdot
.79 .27553 Mdot
.79 .27579 Mdot
.79 .2759 Mdot
.79 .27601 Mdot
.79 .27605 Mdot
.79 .27684 Mdot
.79 .27705 Mdot
.79 .27769 Mdot
.79 .27783 Mdot
.79 .27785 Mdot
.79 .27904 Mdot
.79 .2794 Mdot
.79 .27994 Mdot
.79 .2802 Mdot
.79 .28025 Mdot
.79 .2806 Mdot
.79 .2816 Mdot
.79 .28176 Mdot
.79 .28223 Mdot
.79 .2827 Mdot
.79 .28311 Mdot
.79 .28342 Mdot
.79 .28344 Mdot
.79 .28398 Mdot
.79 .28409 Mdot
.79 .28421 Mdot
.79 .28476 Mdot
.79 .28479 Mdot
.79 .28499 Mdot
.79 .28532 Mdot
.79 .2861 Mdot
.79 .28701 Mdot
.79 .2879 Mdot
.79 .2881 Mdot
.79 .28895 Mdot
.79 .28987 Mdot
.79 .28992 Mdot
.79 .28997 Mdot
.79 .28998 Mdot
.79 .29002 Mdot
.79 .2903 Mdot
.79 .29035 Mdot
.79 .29097 Mdot
.79 .29117 Mdot
.79 .29196 Mdot
.79 .29239 Mdot
.79 .29245 Mdot
.79 .29248 Mdot
.79 .29271 Mdot
.79 .29294 Mdot
.79 .29381 Mdot
.79 .29445 Mdot
.79 .29457 Mdot
.79 .29483 Mdot
.79 .29511 Mdot
.79 .29538 Mdot
.79 .29576 Mdot
.79 .29597 Mdot
.79 .29653 Mdot
.79 .2967 Mdot
.79 .29681 Mdot
.79 .29688 Mdot
.79 .29753 Mdot
.79 .29793 Mdot
.79 .2984 Mdot
.79 .29847 Mdot
.79 .2986 Mdot
.79 .29861 Mdot
.79 .29883 Mdot
.79 .29884 Mdot
.79 .29938 Mdot
.79 .29954 Mdot
.79 .30022 Mdot
.79 .30072 Mdot
.79 .30102 Mdot
.79 .30164 Mdot
.79 .30169 Mdot
.79 .30245 Mdot
.79 .30261 Mdot
.79 .30278 Mdot
.79 .30286 Mdot
.79 .30294 Mdot
.79 .30298 Mdot
.79 .30351 Mdot
.79 .30357 Mdot
.79 .30372 Mdot
.79 .30385 Mdot
.79 .30421 Mdot
.79 .30437 Mdot
.79 .305 Mdot
.79 .305 Mdot
.79 .30521 Mdot
.79 .30525 Mdot
.79 .30535 Mdot
.79 .30544 Mdot
.79 .30583 Mdot
.79 .30627 Mdot
.79 .30648 Mdot
.79 .30671 Mdot
.79 .30687 Mdot
.79 .30699 Mdot
.79 .30703 Mdot
.79 .30704 Mdot
.79 .30717 Mdot
.79 .3074 Mdot
.79 .30791 Mdot
.79 .30798 Mdot
.79 .31013 Mdot
.79 .31061 Mdot
.79 .31085 Mdot
.79 .31115 Mdot
.79 .31184 Mdot
.79 .31186 Mdot
.79 .3123 Mdot
.79 .3127 Mdot
.79 .31272 Mdot
.79 .31283 Mdot
.79 .31331 Mdot
.79 .31336 Mdot
.79 .31348 Mdot
.79 .31348 Mdot
.79 .31427 Mdot
.79 .31469 Mdot
.79 .31484 Mdot
.79 .31501 Mdot
.79 .31589 Mdot
.79 .31592 Mdot
.79 .31597 Mdot
.79 .31597 Mdot
.79 .31637 Mdot
.79 .31678 Mdot
.79 .31689 Mdot
.79 .31704 Mdot
.79 .3175 Mdot
.79 .31833 Mdot
.79 .31843 Mdot
.79 .31851 Mdot
.79 .31864 Mdot
.79 .31888 Mdot
.79 .31904 Mdot
.79 .31966 Mdot
.79 .3204 Mdot
.79 .32044 Mdot
.79 .3215 Mdot
.79 .32153 Mdot
.79 .32232 Mdot
.79 .32257 Mdot
.79 .32301 Mdot
.79 .32361 Mdot
.79 .32392 Mdot
.79 .32426 Mdot
.79 .32446 Mdot
.79 .32466 Mdot
.79 .325 Mdot
.79 .32523 Mdot
.79 .32549 Mdot
.79 .32572 Mdot
.79 .32681 Mdot
.79 .3276 Mdot
.79 .32784 Mdot
.79 .32855 Mdot
.79 .32871 Mdot
.79 .32888 Mdot
.79 .3296 Mdot
.79 .32962 Mdot
.79 .32973 Mdot
.79 .33078 Mdot
.79 .33103 Mdot
.79 .33119 Mdot
.79 .33163 Mdot
.79 .33193 Mdot
.79 .33212 Mdot
.79 .33214 Mdot
.79 .33245 Mdot
.79 .33252 Mdot
.79 .33292 Mdot
.79 .33304 Mdot
.79 .33334 Mdot
.79 .33345 Mdot
.79 .33395 Mdot
.79 .33398 Mdot
.79 .334 Mdot
.79 .33414 Mdot
.79 .33424 Mdot
.79 .33428 Mdot
.79 .33446 Mdot
.79 .33451 Mdot
.79 .33452 Mdot
.79 .33462 Mdot
.79 .33469 Mdot
.79 .33492 Mdot
.79 .33515 Mdot
.79 .33527 Mdot
.79 .33534 Mdot
.79 .33548 Mdot
.79 .33558 Mdot
.79 .33564 Mdot
.79 .33576 Mdot
.79 .33586 Mdot
.79 .33591 Mdot
.79 .33637 Mdot
.79 .33663 Mdot
.79 .33668 Mdot
.79 .33731 Mdot
.79 .33752 Mdot
.79 .33765 Mdot
.79 .33819 Mdot
.79 .33826 Mdot
.79 .33844 Mdot
.79 .33863 Mdot
.79 .33892 Mdot
.79 .33893 Mdot
.79 .33924 Mdot
.79 .33947 Mdot
.79 .33955 Mdot
.79 .33968 Mdot
.79 .34071 Mdot
.79 .3408 Mdot
.79 .3411 Mdot
.79 .34113 Mdot
.79 .3415 Mdot
.79 .34152 Mdot
.79 .34155 Mdot
.79 .34168 Mdot
.79 .34195 Mdot
.79 .34203 Mdot
.79 .34251 Mdot
.79 .34254 Mdot
.79 .34264 Mdot
.79 .34273 Mdot
.79 .34308 Mdot
.79 .34371 Mdot
.79 .34395 Mdot
.79 .34424 Mdot
.79 .34429 Mdot
.79 .34495 Mdot
.79 .345 Mdot
.79 .3451 Mdot
.79 .34565 Mdot
.79 .34585 Mdot
.79 .34622 Mdot
.79 .34624 Mdot
.79 .34661 Mdot
.79 .34674 Mdot
.79 .34705 Mdot
.79 .34731 Mdot
.79 .34757 Mdot
.79 .34765 Mdot
.79 .34771 Mdot
.79 .34774 Mdot
.79 .34816 Mdot
.79 .34836 Mdot
.79 .34838 Mdot
.79 .34843 Mdot
.79 .34853 Mdot
.79 .34873 Mdot
.79 .34876 Mdot
.79 .34981 Mdot
.79 .3503 Mdot
.79 .35031 Mdot
.79 .35049 Mdot
.79 .35065 Mdot
.79 .3507 Mdot
.79 .35089 Mdot
.79 .35091 Mdot
.79 .35096 Mdot
.79 .35128 Mdot
.79 .35145 Mdot
.79 .35151 Mdot
.79 .35157 Mdot
.79 .35193 Mdot
.79 .35194 Mdot
.79 .35196 Mdot
.79 .35233 Mdot
.79 .35239 Mdot
.79 .35257 Mdot
.79 .35298 Mdot
.79 .35303 Mdot
.79 .35313 Mdot
.79 .35319 Mdot
.79 .35373 Mdot
.79 .35418 Mdot
.79 .3546 Mdot
.79 .35478 Mdot
.79 .35514 Mdot
.79 .35536 Mdot
.79 .35544 Mdot
.79 .35558 Mdot
.79 .35577 Mdot
.79 .35672 Mdot
.79 .35706 Mdot
.79 .35742 Mdot
.79 .35743 Mdot
.79 .35805 Mdot
.79 .35823 Mdot
.79 .35835 Mdot
.79 .35843 Mdot
.79 .35844 Mdot
.79 .35875 Mdot
.79 .35896 Mdot
.79 .35916 Mdot
.79 .35928 Mdot
.79 .35939 Mdot
.79 .35977 Mdot
.79 .35984 Mdot
.79 .36023 Mdot
.79 .36086 Mdot
.79 .36137 Mdot
.79 .3614 Mdot
.79 .36203 Mdot
.79 .3622 Mdot
.79 .36236 Mdot
.79 .36264 Mdot
.79 .36282 Mdot
.79 .36317 Mdot
.79 .36328 Mdot
.79 .36393 Mdot
.79 .36408 Mdot
.79 .36408 Mdot
.79 .36429 Mdot
.79 .36451 Mdot
.79 .36467 Mdot
.79 .36469 Mdot
.79 .36493 Mdot
.79 .36552 Mdot
.79 .36595 Mdot
.79 .36617 Mdot
.79 .36622 Mdot
.79 .36637 Mdot
.79 .3668 Mdot
.79 .36684 Mdot
.79 .36687 Mdot
.79 .36727 Mdot
.79 .36744 Mdot
.79 .36765 Mdot
.79 .36774 Mdot
.79 .36777 Mdot
.79 .36828 Mdot
.79 .36842 Mdot
.79 .36856 Mdot
.79 .36857 Mdot
.79 .36897 Mdot
.79 .36918 Mdot
.79 .36953 Mdot
.79 .37041 Mdot
.79 .37048 Mdot
.79 .37054 Mdot
.79 .37066 Mdot
.79 .37123 Mdot
.79 .37131 Mdot
.79 .37141 Mdot
.79 .37147 Mdot
.79 .37198 Mdot
.79 .37235 Mdot
.79 .37266 Mdot
.79 .37297 Mdot
.79 .37303 Mdot
.79 .37327 Mdot
.79 .37379 Mdot
.79 .3741 Mdot
.79 .37417 Mdot
.79 .37454 Mdot
.79 .37479 Mdot
.79 .37482 Mdot
.79 .37491 Mdot
.79 .37524 Mdot
.79 .37527 Mdot
.79 .37557 Mdot
.79 .37583 Mdot
.79 .37594 Mdot
.79 .37612 Mdot
.79 .37629 Mdot
.79 .3765 Mdot
.79 .3767 Mdot
.79 .37718 Mdot
.79 .37722 Mdot
.79 .37774 Mdot
.79 .3779 Mdot
.79 .37793 Mdot
.79 .37813 Mdot
.79 .37833 Mdot
.79 .37888 Mdot
.79 .37892 Mdot
.79 .37898 Mdot
.79 .37903 Mdot
.79 .37951 Mdot
.79 .38011 Mdot
.79 .38033 Mdot
.79 .38047 Mdot
.79 .38072 Mdot
.79 .38081 Mdot
.79 .3813 Mdot
.79 .38144 Mdot
.79 .38154 Mdot
.79 .3818 Mdot
.79 .38224 Mdot
.79 .38238 Mdot
.79 .38265 Mdot
.79 .38302 Mdot
.79 .38319 Mdot
.79 .38329 Mdot
.79 .38343 Mdot
.79 .38356 Mdot
.79 .38366 Mdot
.79 .38414 Mdot
.79 .38436 Mdot
.79 .38447 Mdot
.79 .38465 Mdot
.79 .38475 Mdot
.79 .38486 Mdot
.79 .38525 Mdot
.79 .38625 Mdot
.79 .38629 Mdot
.79 .38667 Mdot
.79 .3868 Mdot
.79 .38714 Mdot
.79 .38719 Mdot
.79 .38777 Mdot
.79 .38778 Mdot
.79 .388 Mdot
.79 .38822 Mdot
.79 .38903 Mdot
.79 .38908 Mdot
.79 .38922 Mdot
.79 .38956 Mdot
.79 .38982 Mdot
.79 .39011 Mdot
.79 .39045 Mdot
.79 .39049 Mdot
.79 .39056 Mdot
.79 .391 Mdot
.79 .39125 Mdot
.79 .39148 Mdot
.79 .39152 Mdot
.79 .39156 Mdot
.79 .39189 Mdot
.79 .39191 Mdot
.79 .39203 Mdot
.79 .39228 Mdot
.79 .39259 Mdot
.79 .39351 Mdot
.79 .3939 Mdot
.79 .39392 Mdot
.79 .39396 Mdot
.79 .39417 Mdot
.79 .39454 Mdot
.79 .39462 Mdot
.79 .39485 Mdot
.79 .39486 Mdot
.79 .3951 Mdot
.79 .39557 Mdot
.79 .39612 Mdot
.79 .3963 Mdot
.79 .39685 Mdot
.79 .39707 Mdot
.79 .39713 Mdot
.79 .39757 Mdot
.79 .39784 Mdot
.79 .39785 Mdot
.79 .39811 Mdot
.79 .39835 Mdot
.79 .399 Mdot
.79 .39909 Mdot
.79 .39914 Mdot
.79 .39967 Mdot
.79 .39995 Mdot
.79 .40029 Mdot
.79 .4005 Mdot
.79 .40094 Mdot
.79 .40156 Mdot
.79 .4016 Mdot
.79 .40166 Mdot
.79 .40175 Mdot
.79 .4018 Mdot
.79 .40202 Mdot
.79 .40221 Mdot
.79 .40227 Mdot
.79 .40245 Mdot
.79 .40251 Mdot
.79 .4026 Mdot
.79 .40263 Mdot
.79 .40294 Mdot
.79 .40302 Mdot
.79 .40328 Mdot
.79 .40378 Mdot
.79 .40379 Mdot
.79 .40391 Mdot
.79 .4041 Mdot
.79 .40438 Mdot
.79 .40537 Mdot
.79 .40538 Mdot
.79 .40584 Mdot
.79 .40595 Mdot
.79 .4065 Mdot
.79 .40715 Mdot
.79 .40799 Mdot
.79 .40815 Mdot
.79 .4083 Mdot
.79 .40851 Mdot
.79 .40864 Mdot
.79 .40876 Mdot
.79 .40898 Mdot
.79 .40917 Mdot
.79 .40956 Mdot
.79 .40983 Mdot
.79 .40999 Mdot
.79 .41049 Mdot
.79 .41051 Mdot
.79 .41118 Mdot
.79 .41121 Mdot
.79 .41168 Mdot
.79 .41207 Mdot
.79 .41217 Mdot
.79 .41232 Mdot
.79 .4124 Mdot
.79 .41246 Mdot
.79 .41252 Mdot
.79 .41304 Mdot
.79 .41333 Mdot
.79 .41343 Mdot
.79 .4135 Mdot
.79 .41376 Mdot
.79 .41401 Mdot
.79 .41401 Mdot
.79 .41404 Mdot
.79 .41406 Mdot
.79 .41462 Mdot
.79 .41473 Mdot
.79 .41482 Mdot
.79 .41509 Mdot
.79 .41559 Mdot
.79 .41559 Mdot
.79 .41566 Mdot
.79 .41569 Mdot
.79 .416 Mdot
.79 .41607 Mdot
.79 .41608 Mdot
.79 .41633 Mdot
.79 .41661 Mdot
.79 .41662 Mdot
.79 .41706 Mdot
.79 .41725 Mdot
.79 .4174 Mdot
.79 .41771 Mdot
.79 .41907 Mdot
.79 .41911 Mdot
.79 .41943 Mdot
.79 .41958 Mdot
.79 .41966 Mdot
.79 .41967 Mdot
.79 .4197 Mdot
.79 .41977 Mdot
.79 .41987 Mdot
.79 .42002 Mdot
.79 .42015 Mdot
.79 .42043 Mdot
.79 .42068 Mdot
.79 .42073 Mdot
.79 .4208 Mdot
.79 .42082 Mdot
.79 .42095 Mdot
.79 .42096 Mdot
.79 .42135 Mdot
.79 .42145 Mdot
.79 .42168 Mdot
.79 .42176 Mdot
.79 .42186 Mdot
.79 .42189 Mdot
.79 .42223 Mdot
.79 .42226 Mdot
.79 .42231 Mdot
.79 .42236 Mdot
.79 .42247 Mdot
.79 .42257 Mdot
.79 .42305 Mdot
.79 .42308 Mdot
.79 .42347 Mdot
.79 .42366 Mdot
.79 .42398 Mdot
.79 .42441 Mdot
.79 .42451 Mdot
.79 .42485 Mdot
.79 .42486 Mdot
.79 .425 Mdot
.79 .425 Mdot
.79 .42509 Mdot
.79 .42513 Mdot
.79 .42543 Mdot
.79 .42568 Mdot
.79 .42609 Mdot
.79 .42613 Mdot
.79 .42621 Mdot
.79 .42632 Mdot
.79 .42667 Mdot
.79 .4268 Mdot
.79 .42704 Mdot
.79 .42721 Mdot
.79 .42739 Mdot
.79 .42755 Mdot
.79 .42763 Mdot
.79 .42804 Mdot
.79 .42859 Mdot
.79 .42873 Mdot
.79 .42888 Mdot
.79 .4289 Mdot
.79 .42894 Mdot
.79 .42921 Mdot
.79 .42971 Mdot
.79 .42983 Mdot
.79 .43022 Mdot
.79 .43026 Mdot
.79 .43043 Mdot
.79 .43046 Mdot
.79 .43046 Mdot
.79 .4305 Mdot
.79 .43053 Mdot
.79 .43111 Mdot
.79 .43117 Mdot
.79 .43165 Mdot
.79 .43178 Mdot
.79 .43234 Mdot
.79 .43291 Mdot
.79 .43341 Mdot
.79 .43362 Mdot
.79 .43374 Mdot
.79 .43376 Mdot
.79 .43411 Mdot
.79 .43419 Mdot
.79 .43426 Mdot
.79 .4346 Mdot
.79 .43461 Mdot
.79 .43481 Mdot
.79 .43506 Mdot
.79 .43537 Mdot
.79 .43566 Mdot
.79 .43576 Mdot
.79 .4364 Mdot
.79 .43662 Mdot
.79 .43665 Mdot
.79 .43682 Mdot
.79 .43716 Mdot
.79 .43739 Mdot
.79 .43814 Mdot
.79 .43815 Mdot
.79 .43824 Mdot
.79 .43864 Mdot
.79 .43877 Mdot
.79 .43927 Mdot
.79 .4393 Mdot
.79 .43937 Mdot
.79 .43944 Mdot
.79 .4396 Mdot
.79 .4398 Mdot
.79 .43989 Mdot
.79 .44005 Mdot
.79 .44016 Mdot
.79 .44027 Mdot
.79 .44033 Mdot
.79 .44039 Mdot
.79 .44052 Mdot
.79 .44056 Mdot
.79 .44094 Mdot
.79 .4413 Mdot
.79 .44139 Mdot
.79 .44141 Mdot
.79 .44144 Mdot
.79 .44157 Mdot
.79 .44159 Mdot
.79 .44166 Mdot
.79 .44175 Mdot
.79 .44195 Mdot
.79 .44201 Mdot
.79 .44216 Mdot
.79 .44227 Mdot
.79 .44238 Mdot
.79 .44242 Mdot
.79 .44246 Mdot
.79 .44325 Mdot
.79 .44343 Mdot
.79 .44351 Mdot
.79 .4439 Mdot
.79 .4441 Mdot
.79 .44473 Mdot
.79 .44483 Mdot
.79 .44493 Mdot
.79 .44533 Mdot
.79 .44535 Mdot
.79 .44566 Mdot
.79 .44613 Mdot
.79 .44634 Mdot
.79 .44667 Mdot
.79 .44683 Mdot
.79 .44708 Mdot
.79 .44748 Mdot
.79 .448 Mdot
.79 .44913 Mdot
.79 .4493 Mdot
.79 .44934 Mdot
.79 .44946 Mdot
.79 .44953 Mdot
.79 .44962 Mdot
.79 .44964 Mdot
.79 .4497 Mdot
.79 .45014 Mdot
.79 .45023 Mdot
.79 .45048 Mdot
.79 .45074 Mdot
.79 .451 Mdot
.79 .4512 Mdot
.79 .45151 Mdot
.79 .45211 Mdot
.79 .4525 Mdot
.79 .45276 Mdot
.79 .45343 Mdot
.79 .45354 Mdot
.79 .45359 Mdot
.79 .45374 Mdot
.79 .45395 Mdot
.79 .4543 Mdot
.79 .45547 Mdot
.79 .45568 Mdot
.79 .45583 Mdot
.79 .45625 Mdot
.79 .45661 Mdot
.79 .4567 Mdot
.79 .45689 Mdot
.79 .45714 Mdot
.79 .45729 Mdot
.79 .45746 Mdot
.79 .45773 Mdot
.79 .45778 Mdot
.79 .45817 Mdot
.79 .45831 Mdot
.79 .45876 Mdot
.79 .4588 Mdot
.79 .4591 Mdot
.79 .45976 Mdot
.79 .45998 Mdot
.79 .46025 Mdot
.79 .46043 Mdot
.79 .46044 Mdot
.79 .46054 Mdot
.79 .46084 Mdot
.79 .46157 Mdot
.79 .4621 Mdot
.79 .46214 Mdot
.79 .4622 Mdot
.79 .46293 Mdot
.79 .46305 Mdot
.79 .46325 Mdot
.79 .46326 Mdot
.79 .46362 Mdot
.79 .46364 Mdot
.79 .46381 Mdot
.79 .46387 Mdot
.79 .46449 Mdot
.79 .46473 Mdot
.79 .46505 Mdot
.79 .46581 Mdot
.79 .46602 Mdot
.79 .46627 Mdot
.79 .46661 Mdot
.79 .46665 Mdot
.79 .46687 Mdot
.79 .46699 Mdot
.79 .46707 Mdot
.79 .46714 Mdot
.79 .46806 Mdot
.79 .46814 Mdot
.79 .46846 Mdot
.79 .46918 Mdot
.79 .46934 Mdot
.79 .46941 Mdot
.79 .46959 Mdot
.79 .4696 Mdot
.79 .46986 Mdot
.79 .46998 Mdot
.79 .47011 Mdot
.79 .47017 Mdot
.79 .47025 Mdot
.79 .47087 Mdot
.79 .47088 Mdot
.79 .47096 Mdot
.79 .471 Mdot
.79 .47102 Mdot
.79 .47111 Mdot
.79 .47135 Mdot
.79 .47155 Mdot
.79 .47211 Mdot
.79 .47237 Mdot
.79 .47239 Mdot
.79 .47266 Mdot
.79 .47289 Mdot
.79 .47336 Mdot
.79 .47337 Mdot
.79 .47356 Mdot
.79 .4737 Mdot
.79 .47376 Mdot
.79 .47392 Mdot
.79 .47406 Mdot
.79 .47468 Mdot
.79 .4748 Mdot
.79 .47481 Mdot
.79 .475 Mdot
.79 .47507 Mdot
.79 .47537 Mdot
.79 .47571 Mdot
.79 .47583 Mdot
.79 .47601 Mdot
.79 .47603 Mdot
.79 .47607 Mdot
.79 .47632 Mdot
.79 .4765 Mdot
.79 .47658 Mdot
.79 .47659 Mdot
.79 .47667 Mdot
.79 .47679 Mdot
.79 .47716 Mdot
.79 .47737 Mdot
.79 .4774 Mdot
.79 .47797 Mdot
.79 .47807 Mdot
.79 .47849 Mdot
.79 .47896 Mdot
.79 .47934 Mdot
.79 .4801 Mdot
.792 .2093 Mdot
.792 .20951 Mdot
.792 .20979 Mdot
.792 .20991 Mdot
.792 .21066 Mdot
.792 .21075 Mdot
.792 .21104 Mdot
.792 .21162 Mdot
.792 .21177 Mdot
.792 .21296 Mdot
.792 .21466 Mdot
.792 .21531 Mdot
.792 .21568 Mdot
.792 .217 Mdot
.792 .21704 Mdot
.792 .21731 Mdot
.792 .21743 Mdot
.792 .21888 Mdot
.792 .21936 Mdot
.792 .21944 Mdot
.792 .21952 Mdot
.792 .22002 Mdot
.792 .22113 Mdot
.792 .22119 Mdot
.792 .22131 Mdot
.792 .22156 Mdot
.792 .22382 Mdot
.792 .22403 Mdot
.792 .22409 Mdot
.792 .22516 Mdot
.792 .22651 Mdot
.792 .22688 Mdot
.792 .22705 Mdot
.792 .22708 Mdot
.792 .22775 Mdot
.792 .22787 Mdot
.792 .22837 Mdot
.792 .22896 Mdot
.792 .23004 Mdot
.792 .23018 Mdot
.792 .23032 Mdot
.792 .23039 Mdot
.792 .23049 Mdot
.792 .23057 Mdot
.792 .23064 Mdot
.792 .23071 Mdot
.792 .23097 Mdot
.792 .2313 Mdot
.792 .2319 Mdot
.792 .23193 Mdot
.792 .23229 Mdot
.792 .23269 Mdot
.792 .23333 Mdot
.792 .23351 Mdot
.792 .23375 Mdot
.792 .23393 Mdot
.792 .23411 Mdot
.792 .2345 Mdot
.792 .23456 Mdot
.792 .23484 Mdot
.792 .23487 Mdot
.792 .23522 Mdot
.792 .23586 Mdot
.792 .23603 Mdot
.792 .2372 Mdot
.792 .23737 Mdot
.792 .23761 Mdot
.792 .23762 Mdot
.792 .23777 Mdot
.792 .23901 Mdot
.792 .23991 Mdot
.792 .2407 Mdot
.792 .24077 Mdot
.792 .24104 Mdot
.792 .24213 Mdot
.792 .24229 Mdot
.792 .24233 Mdot
.792 .24316 Mdot
.792 .24425 Mdot
.792 .24461 Mdot
.792 .24469 Mdot
.792 .24475 Mdot
.792 .24572 Mdot
.792 .24604 Mdot
.792 .2467 Mdot
.792 .24675 Mdot
.792 .24678 Mdot
.792 .2468 Mdot
.792 .24725 Mdot
.792 .24774 Mdot
.792 .24808 Mdot
.792 .24821 Mdot
.792 .24825 Mdot
.792 .24826 Mdot
.792 .24874 Mdot
.792 .24899 Mdot
.792 .24922 Mdot
.792 .24961 Mdot
.792 .25031 Mdot
.792 .25051 Mdot
.792 .25081 Mdot
.792 .25123 Mdot
.792 .25137 Mdot
.792 .25152 Mdot
.792 .25215 Mdot
.792 .25217 Mdot
.792 .25286 Mdot
.792 .25309 Mdot
.792 .25327 Mdot
.792 .25345 Mdot
.792 .25357 Mdot
.792 .25365 Mdot
.792 .25457 Mdot
.792 .2548 Mdot
.792 .25516 Mdot
.792 .25519 Mdot
.792 .25594 Mdot
.792 .2561 Mdot
.792 .25624 Mdot
.792 .25665 Mdot
.792 .25684 Mdot
.792 .25701 Mdot
.792 .25701 Mdot
.792 .25816 Mdot
.792 .25817 Mdot
.792 .25839 Mdot
.792 .25933 Mdot
.792 .25936 Mdot
.792 .25962 Mdot
.792 .26003 Mdot
.792 .26015 Mdot
.792 .2603 Mdot
.792 .26119 Mdot
.792 .26128 Mdot
.792 .26131 Mdot
.792 .26146 Mdot
.792 .2618 Mdot
.792 .26204 Mdot
.792 .26258 Mdot
.792 .26261 Mdot
.792 .26362 Mdot
.792 .26507 Mdot
.792 .26535 Mdot
.792 .26555 Mdot
.792 .26568 Mdot
.792 .26619 Mdot
.792 .26622 Mdot
.792 .26762 Mdot
.792 .26766 Mdot
.792 .26805 Mdot
.792 .26855 Mdot
.792 .26929 Mdot
.792 .26935 Mdot
.792 .26949 Mdot
.792 .27124 Mdot
.792 .27126 Mdot
.792 .27194 Mdot
.792 .27237 Mdot
.792 .27243 Mdot
.792 .27245 Mdot
.792 .27293 Mdot
.792 .27307 Mdot
.792 .27322 Mdot
.792 .27335 Mdot
.792 .27357 Mdot
.792 .27375 Mdot
.792 .27409 Mdot
.792 .27415 Mdot
.792 .27435 Mdot
.792 .27462 Mdot
.792 .27582 Mdot
.792 .27623 Mdot
.792 .27692 Mdot
.792 .27709 Mdot
.792 .27788 Mdot
.792 .27797 Mdot
.792 .27857 Mdot
.792 .27947 Mdot
.792 .27966 Mdot
.792 .27966 Mdot
.792 .27981 Mdot
.792 .27997 Mdot
.792 .28037 Mdot
.792 .28078 Mdot
.792 .28083 Mdot
.792 .28099 Mdot
.792 .28102 Mdot
.792 .28104 Mdot
.792 .2811 Mdot
.792 .28112 Mdot
.792 .28145 Mdot
.792 .28151 Mdot
.792 .28164 Mdot
.792 .28224 Mdot
.792 .28228 Mdot
.792 .2826 Mdot
.792 .28266 Mdot
.792 .28294 Mdot
.792 .28369 Mdot
.792 .28379 Mdot
.792 .28409 Mdot
.792 .28444 Mdot
.792 .28445 Mdot
.792 .28492 Mdot
.792 .28493 Mdot
.792 .28562 Mdot
.792 .2862 Mdot
.792 .28719 Mdot
.792 .28739 Mdot
.792 .28837 Mdot
.792 .28838 Mdot
.792 .28869 Mdot
.792 .28893 Mdot
.792 .28934 Mdot
.792 .2894 Mdot
.792 .28956 Mdot
.792 .29005 Mdot
.792 .2906 Mdot
.792 .2909 Mdot
.792 .29103 Mdot
.792 .29132 Mdot
.792 .29133 Mdot
.792 .29148 Mdot
.792 .29194 Mdot
.792 .29307 Mdot
.792 .29319 Mdot
.792 .2938 Mdot
.792 .2939 Mdot
.792 .29409 Mdot
.792 .29409 Mdot
.792 .29449 Mdot
.792 .29468 Mdot
.792 .29497 Mdot
.792 .2951 Mdot
.792 .29653 Mdot
.792 .2971 Mdot
.792 .29741 Mdot
.792 .29777 Mdot
.792 .29827 Mdot
.792 .29833 Mdot
.792 .29842 Mdot
.792 .29849 Mdot
.792 .29928 Mdot
.792 .29973 Mdot
.792 .2998 Mdot
.792 .29996 Mdot
.792 .30004 Mdot
.792 .30029 Mdot
.792 .30061 Mdot
.792 .30085 Mdot
.792 .30098 Mdot
.792 .30111 Mdot
.792 .30135 Mdot
.792 .30201 Mdot
.792 .30226 Mdot
.792 .30254 Mdot
.792 .30261 Mdot
.792 .30276 Mdot
.792 .30372 Mdot
.792 .30382 Mdot
.792 .30488 Mdot
.792 .30534 Mdot
.792 .30554 Mdot
.792 .30557 Mdot
.792 .30653 Mdot
.792 .30816 Mdot
.792 .30953 Mdot
.792 .30961 Mdot
.792 .30997 Mdot
.792 .31002 Mdot
.792 .31032 Mdot
.792 .31036 Mdot
.792 .31047 Mdot
.792 .3107 Mdot
.792 .31077 Mdot
.792 .31192 Mdot
.792 .31218 Mdot
.792 .31232 Mdot
.792 .31285 Mdot
.792 .31297 Mdot
.792 .31302 Mdot
.792 .3136 Mdot
.792 .31379 Mdot
.792 .3145 Mdot
.792 .31457 Mdot
.792 .31466 Mdot
.792 .31565 Mdot
.792 .3161 Mdot
.792 .31687 Mdot
.792 .31718 Mdot
.792 .31761 Mdot
.792 .3181 Mdot
.792 .31816 Mdot
.792 .31818 Mdot
.792 .31823 Mdot
.792 .31826 Mdot
.792 .31831 Mdot
.792 .3188 Mdot
.792 .31894 Mdot
.792 .31952 Mdot
.792 .31982 Mdot
.792 .31985 Mdot
.792 .31996 Mdot
.792 .31997 Mdot
.792 .32037 Mdot
.792 .32043 Mdot
.792 .32106 Mdot
.792 .32232 Mdot
.792 .32243 Mdot
.792 .32293 Mdot
.792 .32294 Mdot
.792 .32328 Mdot
.792 .32371 Mdot
.792 .32385 Mdot
.792 .32389 Mdot
.792 .32391 Mdot
.792 .32469 Mdot
.792 .3247 Mdot
.792 .32472 Mdot
.792 .3251 Mdot
.792 .32524 Mdot
.792 .32529 Mdot
.792 .32569 Mdot
.792 .32585 Mdot
.792 .32613 Mdot
.792 .32649 Mdot
.792 .32655 Mdot
.792 .32661 Mdot
.792 .32686 Mdot
.792 .32687 Mdot
.792 .32714 Mdot
.792 .32723 Mdot
.792 .3273 Mdot
.792 .32738 Mdot
.792 .32742 Mdot
.792 .32782 Mdot
.792 .32843 Mdot
.792 .32865 Mdot
.792 .32873 Mdot
.792 .32879 Mdot
.792 .32925 Mdot
.792 .32926 Mdot
.792 .32972 Mdot
.792 .32973 Mdot
.792 .33011 Mdot
.792 .3305 Mdot
.792 .33051 Mdot
.792 .33057 Mdot
.792 .3308 Mdot
.792 .33143 Mdot
.792 .33212 Mdot
.792 .33225 Mdot
.792 .33245 Mdot
.792 .33246 Mdot
.792 .33302 Mdot
.792 .33304 Mdot
.792 .3334 Mdot
.792 .33369 Mdot
.792 .33371 Mdot
.792 .33475 Mdot
.792 .33492 Mdot
.792 .33514 Mdot
.792 .3352 Mdot
.792 .33526 Mdot
.792 .3354 Mdot
.792 .33547 Mdot
.792 .33563 Mdot
.792 .33581 Mdot
.792 .33629 Mdot
.792 .33739 Mdot
.792 .33782 Mdot
.792 .33782 Mdot
.792 .33811 Mdot
.792 .33836 Mdot
.792 .3384 Mdot
.792 .33853 Mdot
.792 .33885 Mdot
.792 .33887 Mdot
.792 .33899 Mdot
.792 .33913 Mdot
.792 .33947 Mdot
.792 .33992 Mdot
.792 .3402 Mdot
.792 .34043 Mdot
.792 .3409 Mdot
.792 .34129 Mdot
.792 .3413 Mdot
.792 .34168 Mdot
.792 .3417 Mdot
.792 .34177 Mdot
.792 .34196 Mdot
.792 .34218 Mdot
.792 .34235 Mdot
.792 .34247 Mdot
.792 .34253 Mdot
.792 .34272 Mdot
.792 .34321 Mdot
.792 .34346 Mdot
.792 .3435 Mdot
.792 .34357 Mdot
.792 .34373 Mdot
.792 .34381 Mdot
.792 .34392 Mdot
.792 .34397 Mdot
.792 .34455 Mdot
.792 .34526 Mdot
.792 .34533 Mdot
.792 .34585 Mdot
.792 .34591 Mdot
.792 .34594 Mdot
.792 .34627 Mdot
.792 .34637 Mdot
.792 .34673 Mdot
.792 .34683 Mdot
.792 .34741 Mdot
.792 .34787 Mdot
.792 .34806 Mdot
.792 .34853 Mdot
.792 .34918 Mdot
.792 .34973 Mdot
.792 .34976 Mdot
.792 .34992 Mdot
.792 .35006 Mdot
.792 .35019 Mdot
.792 .35022 Mdot
.792 .35068 Mdot
.792 .35078 Mdot
.792 .35105 Mdot
.792 .3511 Mdot
.792 .35112 Mdot
.792 .35142 Mdot
.792 .35171 Mdot
.792 .35217 Mdot
.792 .35235 Mdot
.792 .35265 Mdot
.792 .35278 Mdot
.792 .35295 Mdot
.792 .35314 Mdot
.792 .35317 Mdot
.792 .35319 Mdot
.792 .35323 Mdot
.792 .35342 Mdot
.792 .35348 Mdot
.792 .35383 Mdot
.792 .35388 Mdot
.792 .35389 Mdot
.792 .35407 Mdot
.792 .35483 Mdot
.792 .35487 Mdot
.792 .35507 Mdot
.792 .35543 Mdot
.792 .35545 Mdot
.792 .35577 Mdot
.792 .35578 Mdot
.792 .35601 Mdot
.792 .35623 Mdot
.792 .35634 Mdot
.792 .35649 Mdot
.792 .35651 Mdot
.792 .35664 Mdot
.792 .35675 Mdot
.792 .35684 Mdot
.792 .35686 Mdot
.792 .35702 Mdot
.792 .35726 Mdot
.792 .3574 Mdot
.792 .35759 Mdot
.792 .35777 Mdot
.792 .35778 Mdot
.792 .35809 Mdot
.792 .35873 Mdot
.792 .35878 Mdot
.792 .35886 Mdot
.792 .35936 Mdot
.792 .35984 Mdot
.792 .35998 Mdot
.792 .36039 Mdot
.792 .36083 Mdot
.792 .361 Mdot
.792 .36129 Mdot
.792 .36141 Mdot
.792 .36166 Mdot
.792 .36195 Mdot
.792 .36204 Mdot
.792 .36223 Mdot
.792 .36286 Mdot
.792 .36288 Mdot
.792 .36295 Mdot
.792 .36325 Mdot
.792 .36326 Mdot
.792 .36336 Mdot
.792 .36339 Mdot
.792 .36343 Mdot
.792 .36368 Mdot
.792 .36397 Mdot
.792 .36399 Mdot
.792 .36455 Mdot
.792 .36501 Mdot
.792 .36527 Mdot
.792 .36553 Mdot
.792 .36576 Mdot
.792 .36588 Mdot
.792 .36642 Mdot
.792 .36691 Mdot
.792 .36696 Mdot
.792 .36703 Mdot
.792 .36712 Mdot
.792 .36713 Mdot
.792 .36714 Mdot
.792 .36738 Mdot
.792 .3674 Mdot
.792 .36741 Mdot
.792 .36778 Mdot
.792 .3678 Mdot
.792 .36803 Mdot
.792 .36844 Mdot
.792 .36865 Mdot
.792 .36881 Mdot
.792 .36895 Mdot
.792 .36939 Mdot
.792 .37 Mdot
.792 .37099 Mdot
.792 .37142 Mdot
.792 .37205 Mdot
.792 .37219 Mdot
.792 .3724 Mdot
.792 .37268 Mdot
.792 .37278 Mdot
.792 .37279 Mdot
.792 .37321 Mdot
.792 .37329 Mdot
.792 .37341 Mdot
.792 .37358 Mdot
.792 .37422 Mdot
.792 .37494 Mdot
.792 .37519 Mdot
.792 .37526 Mdot
.792 .37551 Mdot
.792 .37602 Mdot
.792 .37658 Mdot
.792 .3769 Mdot
.792 .37772 Mdot
.792 .37812 Mdot
.792 .37823 Mdot
.792 .3783 Mdot
.792 .37862 Mdot
.792 .37887 Mdot
.792 .379 Mdot
.792 .37909 Mdot
.792 .37976 Mdot
.792 .38063 Mdot
.792 .38077 Mdot
.792 .38104 Mdot
.792 .38113 Mdot
.792 .38123 Mdot
.792 .38137 Mdot
.792 .38202 Mdot
.792 .38203 Mdot
.792 .38219 Mdot
.792 .3822 Mdot
.792 .38226 Mdot
.792 .3823 Mdot
.792 .38233 Mdot
.792 .38264 Mdot
.792 .38298 Mdot
.792 .38306 Mdot
.792 .3832 Mdot
.792 .38382 Mdot
.792 .38419 Mdot
.792 .38437 Mdot
.792 .38457 Mdot
.792 .38463 Mdot
.792 .38464 Mdot
.792 .38488 Mdot
.792 .38541 Mdot
.792 .3858 Mdot
.792 .38617 Mdot
.792 .38645 Mdot
.792 .38679 Mdot
.792 .38741 Mdot
.792 .3879 Mdot
.792 .3881 Mdot
.792 .38822 Mdot
.792 .38833 Mdot
.792 .38858 Mdot
.792 .38869 Mdot
.792 .38891 Mdot
.792 .38936 Mdot
.792 .38957 Mdot
.792 .38958 Mdot
.792 .38981 Mdot
.792 .38994 Mdot
.792 .38996 Mdot
.792 .39055 Mdot
.792 .39056 Mdot
.792 .39059 Mdot
.792 .39081 Mdot
.792 .39085 Mdot
.792 .39097 Mdot
.792 .39099 Mdot
.792 .39101 Mdot
.792 .39115 Mdot
.792 .39126 Mdot
.792 .39133 Mdot
.792 .39193 Mdot
.792 .39211 Mdot
.792 .3923 Mdot
.792 .39258 Mdot
.792 .39287 Mdot
.792 .39297 Mdot
.792 .39306 Mdot
.792 .39316 Mdot
.792 .39318 Mdot
.792 .39353 Mdot
.792 .39394 Mdot
.792 .39435 Mdot
.792 .39464 Mdot
.792 .39501 Mdot
.792 .39507 Mdot
.792 .39559 Mdot
.792 .39563 Mdot
.792 .39596 Mdot
.792 .396 Mdot
.792 .39645 Mdot
.792 .39681 Mdot
.792 .39684 Mdot
.792 .39692 Mdot
.792 .39697 Mdot
.792 .39707 Mdot
.792 .39711 Mdot
.792 .39714 Mdot
.792 .39729 Mdot
.792 .39761 Mdot
.792 .39772 Mdot
.792 .39776 Mdot
.792 .39794 Mdot
.792 .39825 Mdot
.792 .3985 Mdot
.792 .39851 Mdot
.792 .39875 Mdot
.792 .39905 Mdot
.792 .3992 Mdot
.792 .39966 Mdot
.792 .40005 Mdot
.792 .40025 Mdot
.792 .40033 Mdot
.792 .40035 Mdot
.792 .4007 Mdot
.792 .4007 Mdot
.792 .40097 Mdot
.792 .40166 Mdot
.792 .40218 Mdot
.792 .40223 Mdot
.792 .40232 Mdot
.792 .40253 Mdot
.792 .40264 Mdot
.792 .40329 Mdot
.792 .40331 Mdot
.792 .40349 Mdot
.792 .40373 Mdot
.792 .40409 Mdot
.792 .40421 Mdot
.792 .4043 Mdot
.792 .40513 Mdot
.792 .40527 Mdot
.792 .40531 Mdot
.792 .40532 Mdot
.792 .40557 Mdot
.792 .4058 Mdot
.792 .40581 Mdot
.792 .4061 Mdot
.792 .40611 Mdot
.792 .4064 Mdot
.792 .40649 Mdot
.792 .40662 Mdot
.792 .40701 Mdot
.792 .40726 Mdot
.792 .40729 Mdot
.792 .40734 Mdot
.792 .40738 Mdot
.792 .40744 Mdot
.792 .40761 Mdot
.792 .40781 Mdot
.792 .40785 Mdot
.792 .40808 Mdot
.792 .40826 Mdot
.792 .40861 Mdot
.792 .40897 Mdot
.792 .40898 Mdot
.792 .40899 Mdot
.792 .40949 Mdot
.792 .40952 Mdot
.792 .4101 Mdot
.792 .41041 Mdot
.792 .41048 Mdot
.792 .41128 Mdot
.792 .41168 Mdot
.792 .41172 Mdot
.792 .41197 Mdot
.792 .41197 Mdot
.792 .41204 Mdot
.792 .41206 Mdot
.792 .41225 Mdot
.792 .41261 Mdot
.792 .41271 Mdot
.792 .41301 Mdot
.792 .41305 Mdot
.792 .41307 Mdot
.792 .41309 Mdot
.792 .41311 Mdot
.792 .41315 Mdot
.792 .41345 Mdot
.792 .41373 Mdot
.792 .41393 Mdot
.792 .41441 Mdot
.792 .41469 Mdot
.792 .41532 Mdot
.792 .41538 Mdot
.792 .41542 Mdot
.792 .41587 Mdot
.792 .41599 Mdot
.792 .41635 Mdot
.792 .41638 Mdot
.792 .41646 Mdot
.792 .4168 Mdot
.792 .41689 Mdot
.792 .41705 Mdot
.792 .41778 Mdot
.792 .41782 Mdot
.792 .41796 Mdot
.792 .41803 Mdot
.792 .41806 Mdot
.792 .41825 Mdot
.792 .41828 Mdot
.792 .41851 Mdot
.792 .41856 Mdot
.792 .41942 Mdot
.792 .42045 Mdot
.792 .42105 Mdot
.792 .42108 Mdot
.792 .4212 Mdot
.792 .4215 Mdot
.792 .42216 Mdot
.792 .42223 Mdot
.792 .42283 Mdot
.792 .42293 Mdot
.792 .42297 Mdot
.792 .42315 Mdot
.792 .4233 Mdot
.792 .42372 Mdot
.792 .42387 Mdot
.792 .42396 Mdot
.792 .42404 Mdot
.792 .42419 Mdot
.792 .42439 Mdot
.792 .42455 Mdot
.792 .4246 Mdot
.792 .4247 Mdot
.792 .42475 Mdot
.792 .42503 Mdot
.792 .42552 Mdot
.792 .42557 Mdot
.792 .42563 Mdot
.792 .42567 Mdot
.792 .42598 Mdot
.792 .42641 Mdot
.792 .42676 Mdot
.792 .42767 Mdot
.792 .42775 Mdot
.792 .42793 Mdot
.792 .42805 Mdot
.792 .42831 Mdot
.792 .42831 Mdot
.792 .42843 Mdot
.792 .42849 Mdot
.792 .42887 Mdot
.792 .42895 Mdot
.792 .42966 Mdot
.792 .42995 Mdot
.792 .43004 Mdot
.792 .43005 Mdot
.792 .43024 Mdot
.792 .43032 Mdot
.792 .43051 Mdot
.792 .43086 Mdot
.792 .43116 Mdot
.792 .43127 Mdot
.792 .4313 Mdot
.792 .43156 Mdot
.792 .43172 Mdot
.792 .43191 Mdot
.792 .43192 Mdot
.792 .43254 Mdot
.792 .43266 Mdot
.792 .43329 Mdot
.792 .43365 Mdot
.792 .43409 Mdot
.792 .43409 Mdot
.792 .43439 Mdot
.792 .43439 Mdot
.792 .43462 Mdot
.792 .43481 Mdot
.792 .43487 Mdot
.792 .43534 Mdot
.792 .43552 Mdot
.792 .43556 Mdot
.792 .43576 Mdot
.792 .43578 Mdot
.792 .43616 Mdot
.792 .43625 Mdot
.792 .43629 Mdot
.792 .43649 Mdot
.792 .4365 Mdot
.792 .43654 Mdot
.792 .43656 Mdot
.792 .43658 Mdot
.792 .43667 Mdot
.792 .43671 Mdot
.792 .43696 Mdot
.792 .43722 Mdot
.792 .43732 Mdot
.792 .43741 Mdot
.792 .43741 Mdot
.792 .43753 Mdot
.792 .4381 Mdot
.792 .43848 Mdot
.792 .43854 Mdot
.792 .43904 Mdot
.792 .43914 Mdot
.792 .43958 Mdot
.792 .43984 Mdot
.792 .4406 Mdot
.792 .44077 Mdot
.792 .44089 Mdot
.792 .44093 Mdot
.792 .44115 Mdot
.792 .44126 Mdot
.792 .4414 Mdot
.792 .44148 Mdot
.792 .44157 Mdot
.792 .44167 Mdot
.792 .44197 Mdot
.792 .44198 Mdot
.792 .44202 Mdot
.792 .44229 Mdot
.792 .44272 Mdot
.792 .44273 Mdot
.792 .44384 Mdot
.792 .44392 Mdot
.792 .44396 Mdot
.792 .44443 Mdot
.792 .44475 Mdot
.792 .44499 Mdot
.792 .44502 Mdot
.792 .4459 Mdot
.792 .44592 Mdot
.792 .44624 Mdot
.792 .44632 Mdot
.792 .44645 Mdot
.792 .44663 Mdot
.792 .44754 Mdot
.792 .44818 Mdot
.792 .4482 Mdot
.792 .44854 Mdot
.792 .44869 Mdot
.792 .4489 Mdot
.792 .449 Mdot
.792 .44902 Mdot
.792 .44908 Mdot
.792 .44964 Mdot
.792 .44973 Mdot
.792 .44981 Mdot
.792 .45007 Mdot
.792 .45023 Mdot
.792 .45025 Mdot
.792 .45084 Mdot
.792 .45098 Mdot
.792 .45099 Mdot
.792 .45172 Mdot
.792 .45172 Mdot
.792 .45182 Mdot
.792 .45194 Mdot
.792 .4522 Mdot
.792 .45229 Mdot
.792 .45239 Mdot
.792 .45286 Mdot
.792 .45288 Mdot
.792 .45311 Mdot
.792 .45326 Mdot
.792 .45384 Mdot
.792 .45389 Mdot
.792 .45396 Mdot
.792 .45408 Mdot
.792 .45419 Mdot
.792 .45434 Mdot
.792 .45477 Mdot
.792 .45478 Mdot
.792 .45518 Mdot
.792 .45527 Mdot
.792 .45536 Mdot
.792 .45563 Mdot
.792 .45582 Mdot
.792 .45594 Mdot
.792 .45638 Mdot
.792 .45663 Mdot
.792 .45678 Mdot
.792 .45694 Mdot
.792 .45724 Mdot
.792 .45724 Mdot
.792 .45727 Mdot
.792 .45735 Mdot
.792 .45757 Mdot
.792 .45787 Mdot
.792 .45816 Mdot
.792 .45817 Mdot
.792 .45819 Mdot
.792 .45822 Mdot
.792 .45864 Mdot
.792 .45884 Mdot
.792 .45945 Mdot
.792 .45949 Mdot
.792 .45954 Mdot
.792 .45977 Mdot
.792 .46045 Mdot
.792 .46098 Mdot
.792 .46101 Mdot
.792 .46111 Mdot
.792 .4618 Mdot
.792 .46196 Mdot
.792 .46201 Mdot
.792 .46251 Mdot
.792 .46308 Mdot
.792 .46386 Mdot
.792 .46395 Mdot
.792 .46396 Mdot
.792 .46411 Mdot
.792 .46422 Mdot
.792 .46496 Mdot
.792 .46507 Mdot
.792 .46547 Mdot
.792 .46569 Mdot
.792 .46571 Mdot
.792 .46589 Mdot
.792 .46592 Mdot
.792 .46617 Mdot
.792 .46629 Mdot
.792 .4664 Mdot
.792 .46655 Mdot
.792 .46666 Mdot
.792 .46707 Mdot
.792 .46732 Mdot
.792 .46755 Mdot
.792 .46757 Mdot
.792 .46795 Mdot
.792 .46815 Mdot
.792 .46831 Mdot
.792 .46836 Mdot
.792 .4684 Mdot
.792 .46845 Mdot
.792 .46852 Mdot
.792 .46856 Mdot
.792 .46865 Mdot
.792 .46874 Mdot
.792 .46943 Mdot
.792 .4698 Mdot
.792 .47011 Mdot
.792 .47018 Mdot
.792 .47061 Mdot
.792 .47063 Mdot
.792 .47074 Mdot
.792 .47097 Mdot
.792 .47182 Mdot
.792 .47249 Mdot
.792 .47254 Mdot
.792 .47266 Mdot
.792 .4741 Mdot
.792 .47425 Mdot
.792 .47433 Mdot
.792 .47436 Mdot
.792 .47507 Mdot
.792 .47538 Mdot
.792 .47544 Mdot
.792 .47548 Mdot
.792 .47579 Mdot
.792 .4767 Mdot
.792 .47678 Mdot
.792 .47695 Mdot
.792 .47697 Mdot
.792 .47781 Mdot
.792 .47804 Mdot
.792 .47845 Mdot
.792 .47953 Mdot
.792 .48027 Mdot
.792 .48037 Mdot
.792 .48074 Mdot
.792 .48092 Mdot
.792 .48097 Mdot
.792 .48145 Mdot
.792 .48153 Mdot
.792 .4817 Mdot
.792 .48183 Mdot
.794 .2083 Mdot
.794 .20844 Mdot
.794 .21016 Mdot
.794 .21055 Mdot
.794 .21086 Mdot
.794 .21087 Mdot
.794 .21099 Mdot
.794 .2112 Mdot
.794 .2115 Mdot
.794 .2117 Mdot
.794 .2117 Mdot
.794 .21219 Mdot
.794 .21382 Mdot
.794 .21522 Mdot
.794 .21526 Mdot
.794 .21531 Mdot
.794 .21637 Mdot
.794 .21643 Mdot
.794 .21672 Mdot
.794 .21674 Mdot
.794 .21738 Mdot
.794 .21745 Mdot
.794 .21756 Mdot
.794 .21957 Mdot
.794 .21983 Mdot
.794 .22103 Mdot
.794 .22108 Mdot
.794 .22116 Mdot
.794 .22134 Mdot
.794 .22147 Mdot
.794 .22235 Mdot
.794 .22239 Mdot
.794 .22245 Mdot
.794 .22256 Mdot
.794 .22267 Mdot
.794 .22284 Mdot
.794 .22339 Mdot
.794 .22353 Mdot
.794 .22508 Mdot
.794 .22519 Mdot
.794 .22554 Mdot
.794 .22625 Mdot
.794 .22633 Mdot
.794 .22711 Mdot
.794 .22816 Mdot
.794 .22893 Mdot
.794 .22904 Mdot
.794 .22924 Mdot
.794 .22938 Mdot
.794 .23008 Mdot
.794 .23015 Mdot
.794 .23071 Mdot
.794 .23072 Mdot
.794 .23084 Mdot
.794 .23129 Mdot
.794 .23137 Mdot
.794 .23198 Mdot
.794 .23204 Mdot
.794 .23215 Mdot
.794 .23224 Mdot
.794 .23225 Mdot
.794 .23344 Mdot
.794 .23347 Mdot
.794 .23493 Mdot
.794 .23592 Mdot
.794 .237 Mdot
.794 .23753 Mdot
.794 .23787 Mdot
.794 .23789 Mdot
.794 .23899 Mdot
.794 .23905 Mdot
.794 .23907 Mdot
.794 .23962 Mdot
.794 .24038 Mdot
.794 .24076 Mdot
.794 .24099 Mdot
.794 .24186 Mdot
.794 .24242 Mdot
.794 .243 Mdot
.794 .24354 Mdot
.794 .24371 Mdot
.794 .24394 Mdot
.794 .24462 Mdot
.794 .24473 Mdot
.794 .24489 Mdot
.794 .24526 Mdot
.794 .24561 Mdot
.794 .24649 Mdot
.794 .24663 Mdot
.794 .24695 Mdot
.794 .24759 Mdot
.794 .24778 Mdot
.794 .24808 Mdot
.794 .24837 Mdot
.794 .24843 Mdot
.794 .24844 Mdot
.794 .24864 Mdot
.794 .24868 Mdot
.794 .2493 Mdot
.794 .24935 Mdot
.794 .24952 Mdot
.794 .24985 Mdot
.794 .25018 Mdot
.794 .25047 Mdot
.794 .25067 Mdot
.794 .25068 Mdot
.794 .25161 Mdot
.794 .2517 Mdot
.794 .25174 Mdot
.794 .25187 Mdot
.794 .25261 Mdot
.794 .25261 Mdot
.794 .25265 Mdot
.794 .25267 Mdot
.794 .25283 Mdot
.794 .25339 Mdot
.794 .25415 Mdot
.794 .25437 Mdot
.794 .25449 Mdot
.794 .25465 Mdot
.794 .25474 Mdot
.794 .25552 Mdot
.794 .25552 Mdot
.794 .25588 Mdot
.794 .25596 Mdot
.794 .25601 Mdot
.794 .25639 Mdot
.794 .25683 Mdot
.794 .25717 Mdot
.794 .25719 Mdot
.794 .25726 Mdot
.794 .25797 Mdot
.794 .25861 Mdot
.794 .25868 Mdot
.794 .25913 Mdot
.794 .26117 Mdot
.794 .26125 Mdot
.794 .26173 Mdot
.794 .26173 Mdot
.794 .2625 Mdot
.794 .26412 Mdot
.794 .26553 Mdot
.794 .26562 Mdot
.794 .26679 Mdot
.794 .26694 Mdot
.794 .26694 Mdot
.794 .26714 Mdot
.794 .26855 Mdot
.794 .2687 Mdot
.794 .26887 Mdot
.794 .26935 Mdot
.794 .26937 Mdot
.794 .26977 Mdot
.794 .27031 Mdot
.794 .27043 Mdot
.794 .27044 Mdot
.794 .2708 Mdot
.794 .27116 Mdot
.794 .27135 Mdot
.794 .27136 Mdot
.794 .2714 Mdot
.794 .27142 Mdot
.794 .27156 Mdot
.794 .27163 Mdot
.794 .27174 Mdot
.794 .27199 Mdot
.794 .272 Mdot
.794 .27206 Mdot
.794 .27218 Mdot
.794 .2723 Mdot
.794 .27259 Mdot
.794 .27261 Mdot
.794 .27278 Mdot
.794 .27287 Mdot
.794 .27311 Mdot
.794 .274 Mdot
.794 .27492 Mdot
.794 .27537 Mdot
.794 .27542 Mdot
.794 .27569 Mdot
.794 .2757 Mdot
.794 .27616 Mdot
.794 .27631 Mdot
.794 .27835 Mdot
.794 .27946 Mdot
.794 .28004 Mdot
.794 .28036 Mdot
.794 .28101 Mdot
.794 .28169 Mdot
.794 .28249 Mdot
.794 .28274 Mdot
.794 .28341 Mdot
.794 .28376 Mdot
.794 .28396 Mdot
.794 .28397 Mdot
.794 .2842 Mdot
.794 .28421 Mdot
.794 .2843 Mdot
.794 .28438 Mdot
.794 .28443 Mdot
.794 .28453 Mdot
.794 .28487 Mdot
.794 .28525 Mdot
.794 .28544 Mdot
.794 .28673 Mdot
.794 .28677 Mdot
.794 .28733 Mdot
.794 .28847 Mdot
.794 .28948 Mdot
.794 .29005 Mdot
.794 .29008 Mdot
.794 .29022 Mdot
.794 .29054 Mdot
.794 .29128 Mdot
.794 .2918 Mdot
.794 .29189 Mdot
.794 .29189 Mdot
.794 .29225 Mdot
.794 .29229 Mdot
.794 .29274 Mdot
.794 .29345 Mdot
.794 .29346 Mdot
.794 .29357 Mdot
.794 .29388 Mdot
.794 .29414 Mdot
.794 .29426 Mdot
.794 .2948 Mdot
.794 .29501 Mdot
.794 .29506 Mdot
.794 .29533 Mdot
.794 .29542 Mdot
.794 .29549 Mdot
.794 .2957 Mdot
.794 .29615 Mdot
.794 .29659 Mdot
.794 .29729 Mdot
.794 .29773 Mdot
.794 .29787 Mdot
.794 .29808 Mdot
.794 .29851 Mdot
.794 .2989 Mdot
.794 .29948 Mdot
.794 .29997 Mdot
.794 .3 Mdot
.794 .30005 Mdot
.794 .30057 Mdot
.794 .30058 Mdot
.794 .3008 Mdot
.794 .30124 Mdot
.794 .30128 Mdot
.794 .30159 Mdot
.794 .302 Mdot
.794 .30231 Mdot
.794 .30234 Mdot
.794 .30262 Mdot
.794 .30277 Mdot
.794 .30281 Mdot
.794 .30342 Mdot
.794 .30369 Mdot
.794 .30376 Mdot
.794 .30389 Mdot
.794 .30424 Mdot
.794 .30429 Mdot
.794 .3044 Mdot
.794 .30441 Mdot
.794 .30489 Mdot
.794 .30579 Mdot
.794 .30626 Mdot
.794 .30668 Mdot
.794 .3067 Mdot
.794 .30672 Mdot
.794 .30811 Mdot
.794 .30819 Mdot
.794 .30839 Mdot
.794 .30844 Mdot
.794 .30857 Mdot
.794 .30941 Mdot
.794 .30946 Mdot
.794 .31067 Mdot
.794 .31095 Mdot
.794 .31108 Mdot
.794 .31128 Mdot
.794 .31148 Mdot
.794 .31212 Mdot
.794 .31316 Mdot
.794 .31327 Mdot
.794 .31328 Mdot
.794 .31353 Mdot
.794 .31356 Mdot
.794 .3144 Mdot
.794 .31503 Mdot
.794 .31552 Mdot
.794 .31554 Mdot
.794 .31558 Mdot
.794 .31591 Mdot
.794 .31823 Mdot
.794 .31829 Mdot
.794 .31857 Mdot
.794 .31887 Mdot
.794 .31905 Mdot
.794 .31908 Mdot
.794 .31932 Mdot
.794 .31943 Mdot
.794 .3199 Mdot
.794 .32166 Mdot
.794 .32212 Mdot
.794 .32213 Mdot
.794 .32235 Mdot
.794 .32265 Mdot
.794 .32289 Mdot
.794 .32346 Mdot
.794 .32444 Mdot
.794 .32473 Mdot
.794 .32507 Mdot
.794 .32559 Mdot
.794 .32571 Mdot
.794 .32585 Mdot
.794 .32585 Mdot
.794 .32619 Mdot
.794 .32621 Mdot
.794 .32628 Mdot
.794 .32641 Mdot
.794 .32654 Mdot
.794 .32673 Mdot
.794 .32674 Mdot
.794 .32716 Mdot
.794 .32721 Mdot
.794 .32752 Mdot
.794 .32753 Mdot
.794 .32781 Mdot
.794 .3282 Mdot
.794 .32831 Mdot
.794 .32835 Mdot
.794 .32865 Mdot
.794 .32866 Mdot
.794 .3288 Mdot
.794 .32883 Mdot
.794 .329 Mdot
.794 .32931 Mdot
.794 .32963 Mdot
.794 .32988 Mdot
.794 .33009 Mdot
.794 .3309 Mdot
.794 .33112 Mdot
.794 .33112 Mdot
.794 .33142 Mdot
.794 .33312 Mdot
.794 .33318 Mdot
.794 .33319 Mdot
.794 .33326 Mdot
.794 .33382 Mdot
.794 .33388 Mdot
.794 .33414 Mdot
.794 .33431 Mdot
.794 .33457 Mdot
.794 .33457 Mdot
.794 .33472 Mdot
.794 .33493 Mdot
.794 .33494 Mdot
.794 .33495 Mdot
.794 .33505 Mdot
.794 .33521 Mdot
.794 .33526 Mdot
.794 .33531 Mdot
.794 .3355 Mdot
.794 .33554 Mdot
.794 .33635 Mdot
.794 .33653 Mdot
.794 .33655 Mdot
.794 .33666 Mdot
.794 .33684 Mdot
.794 .33815 Mdot
.794 .33851 Mdot
.794 .33877 Mdot
.794 .33945 Mdot
.794 .33972 Mdot
.794 .33986 Mdot
.794 .33993 Mdot
.794 .34003 Mdot
.794 .34003 Mdot
.794 .34007 Mdot
.794 .3401 Mdot
.794 .34012 Mdot
.794 .34016 Mdot
.794 .3403 Mdot
.794 .34044 Mdot
.794 .34052 Mdot
.794 .34103 Mdot
.794 .34127 Mdot
.794 .34172 Mdot
.794 .34212 Mdot
.794 .34235 Mdot
.794 .34236 Mdot
.794 .34242 Mdot
.794 .34254 Mdot
.794 .34284 Mdot
.794 .34304 Mdot
.794 .34308 Mdot
.794 .34322 Mdot
.794 .34342 Mdot
.794 .34375 Mdot
.794 .34387 Mdot
.794 .34423 Mdot
.794 .34432 Mdot
.794 .34434 Mdot
.794 .34444 Mdot
.794 .34451 Mdot
.794 .34459 Mdot
.794 .34477 Mdot
.794 .34494 Mdot
.794 .34522 Mdot
.794 .34545 Mdot
.794 .34553 Mdot
.794 .3457 Mdot
.794 .34586 Mdot
.794 .34609 Mdot
.794 .3463 Mdot
.794 .34631 Mdot
.794 .34652 Mdot
.794 .34692 Mdot
.794 .34722 Mdot
.794 .34779 Mdot
.794 .34878 Mdot
.794 .34894 Mdot
.794 .34951 Mdot
.794 .34954 Mdot
.794 .34964 Mdot
.794 .34969 Mdot
.794 .35064 Mdot
.794 .35077 Mdot
.794 .3511 Mdot
.794 .35151 Mdot
.794 .35156 Mdot
.794 .35156 Mdot
.794 .35166 Mdot
.794 .35167 Mdot
.794 .35201 Mdot
.794 .35247 Mdot
.794 .35353 Mdot
.794 .35355 Mdot
.794 .35366 Mdot
.794 .35385 Mdot
.794 .35396 Mdot
.794 .354 Mdot
.794 .35419 Mdot
.794 .35488 Mdot
.794 .35507 Mdot
.794 .35537 Mdot
.794 .3556 Mdot
.794 .35599 Mdot
.794 .3561 Mdot
.794 .35644 Mdot
.794 .35654 Mdot
.794 .35655 Mdot
.794 .35672 Mdot
.794 .35682 Mdot
.794 .35706 Mdot
.794 .35732 Mdot
.794 .35748 Mdot
.794 .35754 Mdot
.794 .35772 Mdot
.794 .35773 Mdot
.794 .3578 Mdot
.794 .35792 Mdot
.794 .35804 Mdot
.794 .35864 Mdot
.794 .35864 Mdot
.794 .35876 Mdot
.794 .35945 Mdot
.794 .35971 Mdot
.794 .35973 Mdot
.794 .35983 Mdot
.794 .3599 Mdot
.794 .36 Mdot
.794 .36 Mdot
.794 .36006 Mdot
.794 .36015 Mdot
.794 .36016 Mdot
.794 .36028 Mdot
.794 .3603 Mdot
.794 .36156 Mdot
.794 .36167 Mdot
.794 .36194 Mdot
.794 .36204 Mdot
.794 .3621 Mdot
.794 .36217 Mdot
.794 .36218 Mdot
.794 .3622 Mdot
.794 .36227 Mdot
.794 .36236 Mdot
.794 .36266 Mdot
.794 .36284 Mdot
.794 .36309 Mdot
.794 .36364 Mdot
.794 .36369 Mdot
.794 .36384 Mdot
.794 .36432 Mdot
.794 .36435 Mdot
.794 .36442 Mdot
.794 .36448 Mdot
.794 .36594 Mdot
.794 .36598 Mdot
.794 .36674 Mdot
.794 .3671 Mdot
.794 .36753 Mdot
.794 .36771 Mdot
.794 .3685 Mdot
.794 .36854 Mdot
.794 .36868 Mdot
.794 .36903 Mdot
.794 .36909 Mdot
.794 .36911 Mdot
.794 .36931 Mdot
.794 .36997 Mdot
.794 .37011 Mdot
.794 .3702 Mdot
.794 .37021 Mdot
.794 .37086 Mdot
.794 .37095 Mdot
.794 .37099 Mdot
.794 .37114 Mdot
.794 .37121 Mdot
.794 .37153 Mdot
.794 .37155 Mdot
.794 .37181 Mdot
.794 .37186 Mdot
.794 .37307 Mdot
.794 .37346 Mdot
.794 .37353 Mdot
.794 .37367 Mdot
.794 .37404 Mdot
.794 .3741 Mdot
.794 .37413 Mdot
.794 .37453 Mdot
.794 .37467 Mdot
.794 .37542 Mdot
.794 .37569 Mdot
.794 .3759 Mdot
.794 .37631 Mdot
.794 .37723 Mdot
.794 .37736 Mdot
.794 .37801 Mdot
.794 .37809 Mdot
.794 .37834 Mdot
.794 .37837 Mdot
.794 .37872 Mdot
.794 .37877 Mdot
.794 .3798 Mdot
.794 .37997 Mdot
.794 .37998 Mdot
.794 .38018 Mdot
.794 .38023 Mdot
.794 .38082 Mdot
.794 .38082 Mdot
.794 .38088 Mdot
.794 .38096 Mdot
.794 .38138 Mdot
.794 .38156 Mdot
.794 .38178 Mdot
.794 .38189 Mdot
.794 .3825 Mdot
.794 .38277 Mdot
.794 .383 Mdot
.794 .3835 Mdot
.794 .38442 Mdot
.794 .3845 Mdot
.794 .38452 Mdot
.794 .38483 Mdot
.794 .38492 Mdot
.794 .38495 Mdot
.794 .3853 Mdot
.794 .38546 Mdot
.794 .38557 Mdot
.794 .38576 Mdot
.794 .38581 Mdot
.794 .38586 Mdot
.794 .38587 Mdot
.794 .38588 Mdot
.794 .38602 Mdot
.794 .38619 Mdot
.794 .38626 Mdot
.794 .38706 Mdot
.794 .38707 Mdot
.794 .38721 Mdot
.794 .38724 Mdot
.794 .38731 Mdot
.794 .38743 Mdot
.794 .38759 Mdot
.794 .3881 Mdot
.794 .38848 Mdot
.794 .38863 Mdot
.794 .3888 Mdot
.794 .38883 Mdot
.794 .38893 Mdot
.794 .38909 Mdot
.794 .38942 Mdot
.794 .38942 Mdot
.794 .38948 Mdot
.794 .3897 Mdot
.794 .38977 Mdot
.794 .39091 Mdot
.794 .39102 Mdot
.794 .39105 Mdot
.794 .39112 Mdot
.794 .39131 Mdot
.794 .39132 Mdot
.794 .39198 Mdot
.794 .39249 Mdot
.794 .3925 Mdot
.794 .39256 Mdot
.794 .39256 Mdot
.794 .39259 Mdot
.794 .39285 Mdot
.794 .39373 Mdot
.794 .39377 Mdot
.794 .39383 Mdot
.794 .39493 Mdot
.794 .39529 Mdot
.794 .39548 Mdot
.794 .39573 Mdot
.794 .39587 Mdot
.794 .39615 Mdot
.794 .39625 Mdot
.794 .39635 Mdot
.794 .39641 Mdot
.794 .39711 Mdot
.794 .39712 Mdot
.794 .39717 Mdot
.794 .3974 Mdot
.794 .39748 Mdot
.794 .39769 Mdot
.794 .39781 Mdot
.794 .3979 Mdot
.794 .39835 Mdot
.794 .3985 Mdot
.794 .39875 Mdot
.794 .39904 Mdot
.794 .39919 Mdot
.794 .39951 Mdot
.794 .39965 Mdot
.794 .39974 Mdot
.794 .39976 Mdot
.794 .39978 Mdot
.794 .39979 Mdot
.794 .39982 Mdot
.794 .39988 Mdot
.794 .39993 Mdot
.794 .40002 Mdot
.794 .40019 Mdot
.794 .40062 Mdot
.794 .40078 Mdot
.794 .401 Mdot
.794 .40202 Mdot
.794 .40214 Mdot
.794 .40279 Mdot
.794 .40282 Mdot
.794 .40285 Mdot
.794 .40302 Mdot
.794 .40303 Mdot
.794 .40317 Mdot
.794 .40326 Mdot
.794 .40326 Mdot
.794 .40342 Mdot
.794 .40353 Mdot
.794 .40369 Mdot
.794 .40373 Mdot
.794 .40413 Mdot
.794 .40524 Mdot
.794 .40543 Mdot
.794 .40543 Mdot
.794 .40608 Mdot
.794 .40621 Mdot
.794 .40637 Mdot
.794 .40657 Mdot
.794 .40676 Mdot
.794 .40687 Mdot
.794 .40689 Mdot
.794 .40698 Mdot
.794 .40698 Mdot
.794 .40718 Mdot
.794 .40727 Mdot
.794 .40751 Mdot
.794 .40792 Mdot
.794 .40819 Mdot
.794 .40832 Mdot
.794 .40848 Mdot
.794 .40875 Mdot
.794 .40875 Mdot
.794 .40891 Mdot
.794 .40946 Mdot
.794 .40964 Mdot
.794 .41025 Mdot
.794 .41061 Mdot
.794 .41076 Mdot
.794 .4111 Mdot
.794 .41139 Mdot
.794 .4125 Mdot
.794 .41279 Mdot
.794 .41286 Mdot
.794 .41301 Mdot
.794 .41303 Mdot
.794 .41315 Mdot
.794 .41333 Mdot
.794 .41351 Mdot
.794 .41355 Mdot
.794 .41501 Mdot
.794 .41521 Mdot
.794 .41524 Mdot
.794 .41525 Mdot
.794 .41556 Mdot
.794 .41596 Mdot
.794 .41649 Mdot
.794 .41651 Mdot
.794 .41667 Mdot
.794 .41667 Mdot
.794 .41674 Mdot
.794 .41739 Mdot
.794 .4178 Mdot
.794 .41793 Mdot
.794 .41805 Mdot
.794 .41813 Mdot
.794 .41831 Mdot
.794 .41907 Mdot
.794 .4191 Mdot
.794 .41963 Mdot
.794 .41971 Mdot
.794 .41974 Mdot
.794 .41987 Mdot
.794 .41992 Mdot
.794 .42061 Mdot
.794 .4208 Mdot
.794 .42081 Mdot
.794 .42082 Mdot
.794 .42108 Mdot
.794 .42138 Mdot
.794 .42195 Mdot
.794 .42225 Mdot
.794 .42226 Mdot
.794 .42233 Mdot
.794 .42236 Mdot
.794 .42258 Mdot
.794 .42266 Mdot
.794 .4227 Mdot
.794 .42287 Mdot
.794 .42326 Mdot
.794 .42329 Mdot
.794 .42338 Mdot
.794 .42355 Mdot
.794 .42357 Mdot
.794 .42377 Mdot
.794 .42403 Mdot
.794 .42422 Mdot
.794 .42425 Mdot
.794 .42452 Mdot
.794 .42467 Mdot
.794 .42467 Mdot
.794 .425 Mdot
.794 .42503 Mdot
.794 .42505 Mdot
.794 .42535 Mdot
.794 .42572 Mdot
.794 .42596 Mdot
.794 .42624 Mdot
.794 .42637 Mdot
.794 .42646 Mdot
.794 .42673 Mdot
.794 .42717 Mdot
.794 .42745 Mdot
.794 .42773 Mdot
.794 .42787 Mdot
.794 .42791 Mdot
.794 .42797 Mdot
.794 .42814 Mdot
.794 .42817 Mdot
.794 .4283 Mdot
.794 .42864 Mdot
.794 .42872 Mdot
.794 .42888 Mdot
.794 .42907 Mdot
.794 .42914 Mdot
.794 .42915 Mdot
.794 .4296 Mdot
.794 .42988 Mdot
.794 .42991 Mdot
.794 .43013 Mdot
.794 .43013 Mdot
.794 .43019 Mdot
.794 .43052 Mdot
.794 .43098 Mdot
.794 .43119 Mdot
.794 .43128 Mdot
.794 .4313 Mdot
.794 .43165 Mdot
.794 .43229 Mdot
.794 .43301 Mdot
.794 .43336 Mdot
.794 .43338 Mdot
.794 .43419 Mdot
.794 .43432 Mdot
.794 .43455 Mdot
.794 .43477 Mdot
.794 .43483 Mdot
.794 .43487 Mdot
.794 .43491 Mdot
.794 .43497 Mdot
.794 .43498 Mdot
.794 .43512 Mdot
.794 .43513 Mdot
.794 .43525 Mdot
.794 .43548 Mdot
.794 .4359 Mdot
.794 .43605 Mdot
.794 .43656 Mdot
.794 .43698 Mdot
.794 .43739 Mdot
.794 .4376 Mdot
.794 .43796 Mdot
.794 .43866 Mdot
.794 .43994 Mdot
.794 .44004 Mdot
.794 .44033 Mdot
.794 .44034 Mdot
.794 .4405 Mdot
.794 .44054 Mdot
.794 .44082 Mdot
.794 .4414 Mdot
.794 .44196 Mdot
.794 .44211 Mdot
.794 .44217 Mdot
.794 .44228 Mdot
.794 .44229 Mdot
.794 .44247 Mdot
.794 .44254 Mdot
.794 .44262 Mdot
.794 .44266 Mdot
.794 .44267 Mdot
.794 .44282 Mdot
.794 .44289 Mdot
.794 .44294 Mdot
.794 .44303 Mdot
.794 .44304 Mdot
.794 .44307 Mdot
.794 .44307 Mdot
.794 .44319 Mdot
.794 .44341 Mdot
.794 .44364 Mdot
.794 .44365 Mdot
.794 .44372 Mdot
.794 .44406 Mdot
.794 .44432 Mdot
.794 .44433 Mdot
.794 .44463 Mdot
.794 .44474 Mdot
.794 .44483 Mdot
.794 .44572 Mdot
.794 .44584 Mdot
.794 .44585 Mdot
.794 .44594 Mdot
.794 .44668 Mdot
.794 .44673 Mdot
.794 .44762 Mdot
.794 .44864 Mdot
.794 .44912 Mdot
.794 .44912 Mdot
.794 .44943 Mdot
.794 .44948 Mdot
.794 .45076 Mdot
.794 .45104 Mdot
.794 .45109 Mdot
.794 .45149 Mdot
.794 .45194 Mdot
.794 .45199 Mdot
.794 .452 Mdot
.794 .45221 Mdot
.794 .45249 Mdot
.794 .45273 Mdot
.794 .45276 Mdot
.794 .45281 Mdot
.794 .45304 Mdot
.794 .45304 Mdot
.794 .45353 Mdot
.794 .45359 Mdot
.794 .45369 Mdot
.794 .45376 Mdot
.794 .4539 Mdot
.794 .45438 Mdot
.794 .45473 Mdot
.794 .45483 Mdot
.794 .45484 Mdot
.794 .45487 Mdot
.794 .45487 Mdot
.794 .45533 Mdot
.794 .45541 Mdot
.794 .45544 Mdot
.794 .4555 Mdot
.794 .45609 Mdot
.794 .45609 Mdot
.794 .45622 Mdot
.794 .4564 Mdot
.794 .45661 Mdot
.794 .45681 Mdot
.794 .45693 Mdot
.794 .45695 Mdot
.794 .45734 Mdot
.794 .45737 Mdot
.794 .45749 Mdot
.794 .4575 Mdot
.794 .45754 Mdot
.794 .45772 Mdot
.794 .45791 Mdot
.794 .45803 Mdot
.794 .45843 Mdot
.794 .45863 Mdot
.794 .45873 Mdot
.794 .45928 Mdot
.794 .4595 Mdot
.794 .45973 Mdot
.794 .45983 Mdot
.794 .4599 Mdot
.794 .46033 Mdot
.794 .46047 Mdot
.794 .46058 Mdot
.794 .46092 Mdot
.794 .46129 Mdot
.794 .46164 Mdot
.794 .46219 Mdot
.794 .46233 Mdot
.794 .46257 Mdot
.794 .46305 Mdot
.794 .4634 Mdot
.794 .46341 Mdot
.794 .46345 Mdot
.794 .46414 Mdot
.794 .46415 Mdot
.794 .46437 Mdot
.794 .4647 Mdot
.794 .46538 Mdot
.794 .466 Mdot
.794 .46692 Mdot
.794 .46694 Mdot
.794 .46769 Mdot
.794 .4677 Mdot
.794 .46775 Mdot
.794 .46782 Mdot
.794 .46786 Mdot
.794 .46825 Mdot
.794 .4683 Mdot
.794 .46858 Mdot
.794 .46866 Mdot
.794 .46866 Mdot
.794 .46902 Mdot
.794 .46906 Mdot
.794 .4695 Mdot
.794 .46959 Mdot
.794 .46971 Mdot
.794 .46978 Mdot
.794 .47027 Mdot
.794 .47092 Mdot
.794 .47142 Mdot
.794 .47147 Mdot
.794 .47191 Mdot
.794 .47214 Mdot
.794 .4722 Mdot
.794 .47318 Mdot
.794 .47327 Mdot
.794 .47362 Mdot
.794 .47373 Mdot
.794 .47379 Mdot
.794 .47387 Mdot
.794 .4739 Mdot
.794 .47392 Mdot
.794 .47448 Mdot
.794 .47456 Mdot
.794 .47468 Mdot
.794 .47473 Mdot
.794 .47475 Mdot
.794 .47551 Mdot
.794 .47567 Mdot
.794 .47694 Mdot
.794 .47701 Mdot
.794 .47705 Mdot
.794 .47746 Mdot
.794 .47747 Mdot
.794 .47765 Mdot
.794 .47769 Mdot
.794 .47836 Mdot
.794 .47839 Mdot
.794 .47841 Mdot
.794 .4793 Mdot
.794 .48032 Mdot
.794 .48063 Mdot
.794 .48063 Mdot
.794 .48076 Mdot
.794 .48095 Mdot
.794 .48108 Mdot
.794 .48116 Mdot
.794 .48116 Mdot
.794 .48135 Mdot
.794 .4816 Mdot
.794 .48268 Mdot
.794 .48277 Mdot
.796 .20654 Mdot
.796 .2068 Mdot
.796 .20683 Mdot
.796 .20688 Mdot
.796 .20772 Mdot
.796 .20779 Mdot
.796 .2081 Mdot
.796 .21026 Mdot
.796 .21094 Mdot
.796 .21139 Mdot
.796 .21152 Mdot
.796 .2118 Mdot
.796 .21295 Mdot
.796 .21317 Mdot
.796 .21398 Mdot
.796 .21422 Mdot
.796 .21509 Mdot
.796 .21525 Mdot
.796 .2155 Mdot
.796 .21586 Mdot
.796 .21654 Mdot
.796 .21699 Mdot
.796 .2174 Mdot
.796 .21828 Mdot
.796 .21833 Mdot
.796 .21836 Mdot
.796 .21861 Mdot
.796 .21863 Mdot
.796 .21867 Mdot
.796 .21885 Mdot
.796 .21918 Mdot
.796 .21924 Mdot
.796 .21936 Mdot
.796 .21943 Mdot
.796 .21969 Mdot
.796 .2202 Mdot
.796 .22118 Mdot
.796 .22213 Mdot
.796 .22215 Mdot
.796 .22256 Mdot
.796 .22274 Mdot
.796 .22326 Mdot
.796 .22344 Mdot
.796 .22397 Mdot
.796 .22402 Mdot
.796 .22437 Mdot
.796 .22498 Mdot
.796 .22577 Mdot
.796 .22708 Mdot
.796 .22745 Mdot
.796 .22866 Mdot
.796 .22968 Mdot
.796 .23057 Mdot
.796 .23087 Mdot
.796 .23156 Mdot
.796 .23218 Mdot
.796 .23267 Mdot
.796 .2327 Mdot
.796 .23279 Mdot
.796 .23373 Mdot
.796 .23385 Mdot
.796 .23406 Mdot
.796 .23458 Mdot
.796 .23499 Mdot
.796 .23538 Mdot
.796 .23579 Mdot
.796 .23627 Mdot
.796 .23689 Mdot
.796 .23698 Mdot
.796 .23731 Mdot
.796 .23744 Mdot
.796 .23766 Mdot
.796 .23774 Mdot
.796 .23775 Mdot
.796 .23846 Mdot
.796 .23898 Mdot
.796 .23991 Mdot
.796 .24147 Mdot
.796 .24157 Mdot
.796 .24175 Mdot
.796 .24184 Mdot
.796 .24204 Mdot
.796 .24233 Mdot
.796 .24294 Mdot
.796 .24366 Mdot
.796 .24392 Mdot
.796 .24408 Mdot
.796 .24447 Mdot
.796 .2449 Mdot
.796 .2452 Mdot
.796 .24617 Mdot
.796 .24678 Mdot
.796 .24716 Mdot
.796 .24768 Mdot
.796 .24772 Mdot
.796 .24959 Mdot
.796 .24973 Mdot
.796 .24995 Mdot
.796 .24996 Mdot
.796 .25042 Mdot
.796 .25052 Mdot
.796 .25173 Mdot
.796 .25181 Mdot
.796 .25204 Mdot
.796 .25218 Mdot
.796 .25227 Mdot
.796 .2525 Mdot
.796 .25278 Mdot
.796 .2528 Mdot
.796 .25284 Mdot
.796 .25378 Mdot
.796 .25392 Mdot
.796 .25506 Mdot
.796 .25512 Mdot
.796 .2553 Mdot
.796 .25615 Mdot
.796 .25631 Mdot
.796 .25658 Mdot
.796 .25661 Mdot
.796 .25686 Mdot
.796 .25804 Mdot
.796 .25811 Mdot
.796 .25825 Mdot
.796 .2583 Mdot
.796 .25831 Mdot
.796 .25854 Mdot
.796 .25855 Mdot
.796 .25875 Mdot
.796 .2593 Mdot
.796 .25945 Mdot
.796 .25955 Mdot
.796 .25991 Mdot
.796 .26066 Mdot
.796 .26152 Mdot
.796 .26179 Mdot
.796 .2627 Mdot
.796 .2633 Mdot
.796 .26368 Mdot
.796 .26413 Mdot
.796 .26415 Mdot
.796 .2648 Mdot
.796 .26508 Mdot
.796 .26644 Mdot
.796 .26688 Mdot
.796 .26698 Mdot
.796 .26699 Mdot
.796 .26704 Mdot
.796 .26704 Mdot
.796 .26718 Mdot
.796 .26768 Mdot
.796 .26784 Mdot
.796 .26805 Mdot
.796 .26819 Mdot
.796 .26863 Mdot
.796 .26883 Mdot
.796 .26972 Mdot
.796 .2703 Mdot
.796 .27039 Mdot
.796 .27092 Mdot
.796 .27157 Mdot
.796 .27165 Mdot
.796 .27214 Mdot
.796 .2722 Mdot
.796 .27254 Mdot
.796 .27284 Mdot
.796 .27293 Mdot
.796 .27303 Mdot
.796 .27331 Mdot
.796 .2744 Mdot
.796 .27442 Mdot
.796 .27479 Mdot
.796 .27485 Mdot
.796 .27491 Mdot
.796 .27564 Mdot
.796 .2757 Mdot
.796 .27598 Mdot
.796 .2761 Mdot
.796 .2765 Mdot
.796 .27697 Mdot
.796 .2775 Mdot
.796 .27791 Mdot
.796 .27801 Mdot
.796 .27806 Mdot
.796 .27833 Mdot
.796 .27836 Mdot
.796 .27861 Mdot
.796 .27922 Mdot
.796 .27959 Mdot
.796 .28007 Mdot
.796 .28012 Mdot
.796 .28026 Mdot
.796 .2804 Mdot
.796 .28058 Mdot
.796 .28093 Mdot
.796 .28128 Mdot
.796 .28139 Mdot
.796 .28141 Mdot
.796 .28145 Mdot
.796 .28161 Mdot
.796 .28221 Mdot
.796 .28234 Mdot
.796 .28263 Mdot
.796 .28357 Mdot
.796 .2837 Mdot
.796 .28373 Mdot
.796 .28392 Mdot
.796 .28441 Mdot
.796 .28468 Mdot
.796 .28511 Mdot
.796 .28528 Mdot
.796 .28549 Mdot
.796 .28574 Mdot
.796 .28576 Mdot
.796 .2858 Mdot
.796 .28651 Mdot
.796 .28662 Mdot
.796 .28688 Mdot
.796 .28721 Mdot
.796 .28781 Mdot
.796 .28792 Mdot
.796 .28825 Mdot
.796 .28869 Mdot
.796 .28921 Mdot
.796 .28926 Mdot
.796 .28929 Mdot
.796 .28985 Mdot
.796 .29037 Mdot
.796 .29044 Mdot
.796 .29046 Mdot
.796 .29147 Mdot
.796 .29174 Mdot
.796 .29178 Mdot
.796 .29248 Mdot
.796 .29257 Mdot
.796 .29262 Mdot
.796 .29373 Mdot
.796 .29447 Mdot
.796 .29464 Mdot
.796 .29479 Mdot
.796 .29486 Mdot
.796 .29525 Mdot
.796 .2956 Mdot
.796 .29568 Mdot
.796 .29571 Mdot
.796 .29579 Mdot
.796 .29582 Mdot
.796 .29733 Mdot
.796 .29807 Mdot
.796 .29838 Mdot
.796 .29854 Mdot
.796 .29925 Mdot
.796 .29949 Mdot
.796 .29974 Mdot
.796 .30013 Mdot
.796 .30048 Mdot
.796 .30088 Mdot
.796 .30136 Mdot
.796 .3015 Mdot
.796 .30202 Mdot
.796 .30257 Mdot
.796 .30273 Mdot
.796 .30294 Mdot
.796 .30301 Mdot
.796 .30321 Mdot
.796 .30346 Mdot
.796 .30442 Mdot
.796 .30452 Mdot
.796 .3046 Mdot
.796 .30462 Mdot
.796 .30549 Mdot
.796 .30593 Mdot
.796 .30607 Mdot
.796 .30617 Mdot
.796 .30708 Mdot
.796 .30764 Mdot
.796 .30949 Mdot
.796 .30978 Mdot
.796 .30989 Mdot
.796 .30992 Mdot
.796 .31025 Mdot
.796 .31028 Mdot
.796 .3104 Mdot
.796 .31125 Mdot
.796 .31152 Mdot
.796 .3117 Mdot
.796 .31186 Mdot
.796 .3124 Mdot
.796 .31272 Mdot
.796 .31282 Mdot
.796 .31316 Mdot
.796 .31373 Mdot
.796 .31407 Mdot
.796 .31442 Mdot
.796 .31444 Mdot
.796 .31445 Mdot
.796 .31455 Mdot
.796 .31455 Mdot
.796 .31457 Mdot
.796 .31464 Mdot
.796 .31484 Mdot
.796 .31518 Mdot
.796 .31556 Mdot
.796 .31595 Mdot
.796 .31611 Mdot
.796 .31668 Mdot
.796 .31706 Mdot
.796 .31938 Mdot
.796 .3201 Mdot
.796 .3201 Mdot
.796 .32051 Mdot
.796 .32056 Mdot
.796 .32064 Mdot
.796 .32116 Mdot
.796 .32152 Mdot
.796 .32176 Mdot
.796 .32179 Mdot
.796 .32193 Mdot
.796 .32198 Mdot
.796 .3221 Mdot
.796 .3221 Mdot
.796 .32238 Mdot
.796 .32259 Mdot
.796 .32295 Mdot
.796 .3239 Mdot
.796 .32443 Mdot
.796 .32504 Mdot
.796 .32542 Mdot
.796 .32581 Mdot
.796 .32602 Mdot
.796 .32603 Mdot
.796 .3271 Mdot
.796 .32714 Mdot
.796 .32774 Mdot
.796 .32779 Mdot
.796 .32783 Mdot
.796 .32803 Mdot
.796 .32804 Mdot
.796 .32805 Mdot
.796 .32843 Mdot
.796 .32848 Mdot
.796 .32936 Mdot
.796 .32942 Mdot
.796 .32953 Mdot
.796 .32964 Mdot
.796 .33021 Mdot
.796 .33021 Mdot
.796 .3303 Mdot
.796 .33031 Mdot
.796 .33038 Mdot
.796 .3306 Mdot
.796 .33066 Mdot
.796 .33084 Mdot
.796 .33194 Mdot
.796 .33233 Mdot
.796 .33251 Mdot
.796 .33342 Mdot
.796 .33363 Mdot
.796 .33366 Mdot
.796 .33371 Mdot
.796 .33397 Mdot
.796 .33406 Mdot
.796 .33436 Mdot
.796 .33494 Mdot
.796 .33519 Mdot
.796 .33544 Mdot
.796 .33594 Mdot
.796 .33598 Mdot
.796 .33602 Mdot
.796 .33613 Mdot
.796 .33656 Mdot
.796 .33657 Mdot
.796 .33671 Mdot
.796 .33674 Mdot
.796 .33707 Mdot
.796 .33723 Mdot
.796 .33739 Mdot
.796 .33757 Mdot
.796 .33812 Mdot
.796 .33822 Mdot
.796 .33861 Mdot
.796 .3388 Mdot
.796 .33887 Mdot
.796 .33893 Mdot
.796 .33932 Mdot
.796 .33934 Mdot
.796 .3394 Mdot
.796 .33964 Mdot
.796 .33969 Mdot
.796 .34023 Mdot
.796 .34024 Mdot
.796 .34031 Mdot
.796 .34051 Mdot
.796 .34062 Mdot
.796 .34085 Mdot
.796 .34093 Mdot
.796 .34104 Mdot
.796 .34162 Mdot
.796 .34185 Mdot
.796 .34203 Mdot
.796 .3422 Mdot
.796 .3424 Mdot
.796 .34243 Mdot
.796 .34266 Mdot
.796 .34286 Mdot
.796 .34289 Mdot
.796 .3434 Mdot
.796 .34373 Mdot
.796 .34419 Mdot
.796 .34463 Mdot
.796 .34478 Mdot
.796 .34493 Mdot
.796 .34496 Mdot
.796 .34501 Mdot
.796 .34561 Mdot
.796 .3459 Mdot
.796 .34602 Mdot
.796 .34671 Mdot
.796 .34701 Mdot
.796 .34746 Mdot
.796 .34768 Mdot
.796 .34785 Mdot
.796 .34793 Mdot
.796 .34802 Mdot
.796 .3484 Mdot
.796 .34845 Mdot
.796 .34848 Mdot
.796 .34882 Mdot
.796 .34906 Mdot
.796 .34945 Mdot
.796 .35041 Mdot
.796 .35052 Mdot
.796 .35057 Mdot
.796 .3507 Mdot
.796 .35072 Mdot
.796 .3511 Mdot
.796 .35128 Mdot
.796 .35168 Mdot
.796 .35185 Mdot
.796 .35208 Mdot
.796 .35236 Mdot
.796 .3524 Mdot
.796 .35244 Mdot
.796 .35265 Mdot
.796 .3528 Mdot
.796 .35302 Mdot
.796 .35324 Mdot
.796 .35339 Mdot
.796 .35501 Mdot
.796 .35515 Mdot
.796 .35531 Mdot
.796 .35538 Mdot
.796 .35549 Mdot
.796 .3563 Mdot
.796 .35654 Mdot
.796 .35684 Mdot
.796 .35693 Mdot
.796 .35737 Mdot
.796 .35763 Mdot
.796 .35772 Mdot
.796 .35773 Mdot
.796 .35824 Mdot
.796 .35827 Mdot
.796 .35831 Mdot
.796 .35835 Mdot
.796 .35858 Mdot
.796 .35858 Mdot
.796 .35862 Mdot
.796 .35865 Mdot
.796 .35883 Mdot
.796 .35993 Mdot
.796 .36054 Mdot
.796 .36092 Mdot
.796 .36149 Mdot
.796 .3617 Mdot
.796 .36174 Mdot
.796 .36189 Mdot
.796 .3623 Mdot
.796 .36331 Mdot
.796 .36339 Mdot
.796 .3634 Mdot
.796 .36349 Mdot
.796 .36357 Mdot
.796 .36358 Mdot
.796 .36391 Mdot
.796 .36442 Mdot
.796 .36474 Mdot
.796 .36482 Mdot
.796 .36539 Mdot
.796 .36576 Mdot
.796 .36578 Mdot
.796 .36592 Mdot
.796 .36602 Mdot
.796 .36667 Mdot
.796 .36682 Mdot
.796 .36705 Mdot
.796 .36732 Mdot
.796 .36734 Mdot
.796 .36743 Mdot
.796 .36837 Mdot
.796 .36842 Mdot
.796 .36851 Mdot
.796 .36855 Mdot
.796 .36909 Mdot
.796 .3693 Mdot
.796 .3694 Mdot
.796 .36964 Mdot
.796 .36965 Mdot
.796 .36977 Mdot
.796 .36977 Mdot
.796 .36979 Mdot
.796 .37055 Mdot
.796 .37092 Mdot
.796 .37124 Mdot
.796 .37164 Mdot
.796 .37175 Mdot
.796 .37208 Mdot
.796 .37261 Mdot
.796 .37267 Mdot
.796 .37303 Mdot
.796 .37312 Mdot
.796 .37323 Mdot
.796 .37363 Mdot
.796 .37369 Mdot
.796 .37404 Mdot
.796 .37414 Mdot
.796 .37477 Mdot
.796 .3751 Mdot
.796 .37533 Mdot
.796 .37551 Mdot
.796 .37571 Mdot
.796 .37587 Mdot
.796 .37591 Mdot
.796 .37616 Mdot
.796 .37629 Mdot
.796 .37638 Mdot
.796 .37661 Mdot
.796 .3768 Mdot
.796 .37696 Mdot
.796 .37703 Mdot
.796 .37705 Mdot
.796 .37706 Mdot
.796 .37707 Mdot
.796 .37708 Mdot
.796 .3771 Mdot
.796 .37714 Mdot
.796 .37724 Mdot
.796 .3775 Mdot
.796 .37779 Mdot
.796 .37805 Mdot
.796 .37816 Mdot
.796 .37831 Mdot
.796 .37851 Mdot
.796 .37891 Mdot
.796 .37897 Mdot
.796 .37919 Mdot
.796 .37923 Mdot
.796 .37955 Mdot
.796 .37961 Mdot
.796 .37983 Mdot
.796 .37987 Mdot
.796 .3802 Mdot
.796 .38048 Mdot
.796 .38073 Mdot
.796 .38116 Mdot
.796 .38165 Mdot
.796 .38173 Mdot
.796 .38189 Mdot
.796 .38244 Mdot
.796 .38254 Mdot
.796 .38318 Mdot
.796 .38319 Mdot
.796 .38336 Mdot
.796 .3835 Mdot
.796 .38407 Mdot
.796 .38416 Mdot
.796 .38417 Mdot
.796 .38476 Mdot
.796 .38501 Mdot
.796 .38554 Mdot
.796 .3856 Mdot
.796 .38565 Mdot
.796 .38571 Mdot
.796 .38634 Mdot
.796 .38686 Mdot
.796 .38745 Mdot
.796 .38864 Mdot
.796 .38866 Mdot
.796 .38868 Mdot
.796 .38868 Mdot
.796 .38885 Mdot
.796 .38888 Mdot
.796 .38889 Mdot
.796 .38922 Mdot
.796 .38922 Mdot
.796 .38928 Mdot
.796 .38944 Mdot
.796 .38977 Mdot
.796 .38996 Mdot
.796 .39011 Mdot
.796 .39062 Mdot
.796 .39069 Mdot
.796 .39084 Mdot
.796 .39092 Mdot
.796 .39204 Mdot
.796 .39218 Mdot
.796 .39241 Mdot
.796 .39254 Mdot
.796 .39256 Mdot
.796 .39259 Mdot
.796 .39277 Mdot
.796 .39291 Mdot
.796 .39302 Mdot
.796 .39327 Mdot
.796 .39338 Mdot
.796 .39363 Mdot
.796 .39371 Mdot
.796 .39374 Mdot
.796 .39382 Mdot
.796 .39466 Mdot
.796 .39481 Mdot
.796 .39505 Mdot
.796 .39507 Mdot
.796 .39531 Mdot
.796 .39553 Mdot
.796 .39567 Mdot
.796 .39657 Mdot
.796 .39669 Mdot
.796 .3972 Mdot
.796 .39735 Mdot
.796 .39744 Mdot
.796 .39772 Mdot
.796 .39801 Mdot
.796 .39854 Mdot
.796 .39856 Mdot
.796 .39868 Mdot
.796 .39882 Mdot
.796 .39884 Mdot
.796 .39897 Mdot
.796 .39908 Mdot
.796 .39934 Mdot
.796 .39977 Mdot
.796 .39982 Mdot
.796 .4002 Mdot
.796 .40058 Mdot
.796 .40123 Mdot
.796 .40147 Mdot
.796 .40153 Mdot
.796 .40188 Mdot
.796 .40209 Mdot
.796 .40219 Mdot
.796 .40242 Mdot
.796 .40251 Mdot
.796 .40252 Mdot
.796 .40279 Mdot
.796 .40288 Mdot
.796 .4029 Mdot
.796 .40321 Mdot
.796 .40338 Mdot
.796 .40409 Mdot
.796 .40434 Mdot
.796 .40435 Mdot
.796 .40449 Mdot
.796 .40506 Mdot
.796 .40611 Mdot
.796 .40626 Mdot
.796 .40639 Mdot
.796 .40644 Mdot
.796 .4065 Mdot
.796 .4065 Mdot
.796 .40686 Mdot
.796 .40693 Mdot
.796 .407 Mdot
.796 .40704 Mdot
.796 .40762 Mdot
.796 .40786 Mdot
.796 .40787 Mdot
.796 .40802 Mdot
.796 .40806 Mdot
.796 .40843 Mdot
.796 .40913 Mdot
.796 .40927 Mdot
.796 .40951 Mdot
.796 .40975 Mdot
.796 .41013 Mdot
.796 .41046 Mdot
.796 .41106 Mdot
.796 .41142 Mdot
.796 .4116 Mdot
.796 .41171 Mdot
.796 .41179 Mdot
.796 .41181 Mdot
.796 .41196 Mdot
.796 .41218 Mdot
.796 .41285 Mdot
.796 .4133 Mdot
.796 .41476 Mdot
.796 .415 Mdot
.796 .41536 Mdot
.796 .41546 Mdot
.796 .4157 Mdot
.796 .41595 Mdot
.796 .41616 Mdot
.796 .41628 Mdot
.796 .41633 Mdot
.796 .41634 Mdot
.796 .41634 Mdot
.796 .4164 Mdot
.796 .41641 Mdot
.796 .41642 Mdot
.796 .41664 Mdot
.796 .41685 Mdot
.796 .41721 Mdot
.796 .41743 Mdot
.796 .41749 Mdot
.796 .41769 Mdot
.796 .41803 Mdot
.796 .41813 Mdot
.796 .41824 Mdot
.796 .41841 Mdot
.796 .41895 Mdot
.796 .41902 Mdot
.796 .41904 Mdot
.796 .41925 Mdot
.796 .41927 Mdot
.796 .41933 Mdot
.796 .41951 Mdot
.796 .42068 Mdot
.796 .42103 Mdot
.796 .4216 Mdot
.796 .42166 Mdot
.796 .42175 Mdot
.796 .42203 Mdot
.796 .42258 Mdot
.796 .42259 Mdot
.796 .42264 Mdot
.796 .4227 Mdot
.796 .42331 Mdot
.796 .42346 Mdot
.796 .42359 Mdot
.796 .42363 Mdot
.796 .42376 Mdot
.796 .42386 Mdot
.796 .42421 Mdot
.796 .42453 Mdot
.796 .42463 Mdot
.796 .42493 Mdot
.796 .42518 Mdot
.796 .4254 Mdot
.796 .42564 Mdot
.796 .4258 Mdot
.796 .42595 Mdot
.796 .42639 Mdot
.796 .42649 Mdot
.796 .42669 Mdot
.796 .42716 Mdot
.796 .4281 Mdot
.796 .42813 Mdot
.796 .42817 Mdot
.796 .42819 Mdot
.796 .42824 Mdot
.796 .42846 Mdot
.796 .42871 Mdot
.796 .42875 Mdot
.796 .42884 Mdot
.796 .42895 Mdot
.796 .42942 Mdot
.796 .43011 Mdot
.796 .43015 Mdot
.796 .4302 Mdot
.796 .43064 Mdot
.796 .43066 Mdot
.796 .43083 Mdot
.796 .43147 Mdot
.796 .43148 Mdot
.796 .43153 Mdot
.796 .43185 Mdot
.796 .43221 Mdot
.796 .43222 Mdot
.796 .43226 Mdot
.796 .43258 Mdot
.796 .43286 Mdot
.796 .43307 Mdot
.796 .43314 Mdot
.796 .43351 Mdot
.796 .43372 Mdot
.796 .43388 Mdot
.796 .43395 Mdot
.796 .4344 Mdot
.796 .43443 Mdot
.796 .43444 Mdot
.796 .4346 Mdot
.796 .43472 Mdot
.796 .43483 Mdot
.796 .4351 Mdot
.796 .43527 Mdot
.796 .43558 Mdot
.796 .4357 Mdot
.796 .43572 Mdot
.796 .4358 Mdot
.796 .43639 Mdot
.796 .43657 Mdot
.796 .43665 Mdot
.796 .43703 Mdot
.796 .43713 Mdot
.796 .43716 Mdot
.796 .43717 Mdot
.796 .43724 Mdot
.796 .43746 Mdot
.796 .43768 Mdot
.796 .43779 Mdot
.796 .43788 Mdot
.796 .43797 Mdot
.796 .438 Mdot
.796 .4383 Mdot
.796 .43853 Mdot
.796 .43892 Mdot
.796 .43907 Mdot
.796 .43909 Mdot
.796 .43926 Mdot
.796 .43929 Mdot
.796 .43935 Mdot
.796 .43961 Mdot
.796 .43995 Mdot
.796 .44024 Mdot
.796 .44049 Mdot
.796 .44057 Mdot
.796 .44074 Mdot
.796 .44078 Mdot
.796 .44124 Mdot
.796 .44128 Mdot
.796 .44132 Mdot
.796 .44154 Mdot
.796 .44156 Mdot
.796 .44225 Mdot
.796 .44242 Mdot
.796 .44248 Mdot
.796 .44254 Mdot
.796 .44273 Mdot
.796 .44294 Mdot
.796 .44298 Mdot
.796 .44328 Mdot
.796 .44334 Mdot
.796 .44375 Mdot
.796 .44408 Mdot
.796 .44414 Mdot
.796 .4445 Mdot
.796 .44506 Mdot
.796 .44518 Mdot
.796 .44546 Mdot
.796 .44555 Mdot
.796 .44568 Mdot
.796 .44578 Mdot
.796 .44609 Mdot
.796 .44618 Mdot
.796 .44618 Mdot
.796 .44621 Mdot
.796 .44622 Mdot
.796 .44629 Mdot
.796 .44656 Mdot
.796 .44741 Mdot
.796 .44759 Mdot
.796 .448 Mdot
.796 .44801 Mdot
.796 .4483 Mdot
.796 .44853 Mdot
.796 .44891 Mdot
.796 .44948 Mdot
.796 .44965 Mdot
.796 .45019 Mdot
.796 .45066 Mdot
.796 .45089 Mdot
.796 .45095 Mdot
.796 .45105 Mdot
.796 .45139 Mdot
.796 .45151 Mdot
.796 .45152 Mdot
.796 .45167 Mdot
.796 .45167 Mdot
.796 .45171 Mdot
.796 .45179 Mdot
.796 .45183 Mdot
.796 .45258 Mdot
.796 .45273 Mdot
.796 .45275 Mdot
.796 .45292 Mdot
.796 .45302 Mdot
.796 .45356 Mdot
.796 .45367 Mdot
.796 .45371 Mdot
.796 .45442 Mdot
.796 .45451 Mdot
.796 .4551 Mdot
.796 .45513 Mdot
.796 .45514 Mdot
.796 .45532 Mdot
.796 .45546 Mdot
.796 .45551 Mdot
.796 .4556 Mdot
.796 .45575 Mdot
.796 .4558 Mdot
.796 .45656 Mdot
.796 .45662 Mdot
.796 .45691 Mdot
.796 .45691 Mdot
.796 .45706 Mdot
.796 .45714 Mdot
.796 .45832 Mdot
.796 .45834 Mdot
.796 .45867 Mdot
.796 .45891 Mdot
.796 .45929 Mdot
.796 .4599 Mdot
.796 .46009 Mdot
.796 .46036 Mdot
.796 .4606 Mdot
.796 .46071 Mdot
.796 .46087 Mdot
.796 .46132 Mdot
.796 .46171 Mdot
.796 .46189 Mdot
.796 .46201 Mdot
.796 .46207 Mdot
.796 .46218 Mdot
.796 .46224 Mdot
.796 .46322 Mdot
.796 .46381 Mdot
.796 .46413 Mdot
.796 .46458 Mdot
.796 .46459 Mdot
.796 .46464 Mdot
.796 .46477 Mdot
.796 .46486 Mdot
.796 .46507 Mdot
.796 .46512 Mdot
.796 .46551 Mdot
.796 .46581 Mdot
.796 .46607 Mdot
.796 .46632 Mdot
.796 .46657 Mdot
.796 .4669 Mdot
.796 .46703 Mdot
.796 .4671 Mdot
.796 .4677 Mdot
.796 .46776 Mdot
.796 .46777 Mdot
.796 .46808 Mdot
.796 .46847 Mdot
.796 .4689 Mdot
.796 .46909 Mdot
.796 .46965 Mdot
.796 .47029 Mdot
.796 .47105 Mdot
.796 .47128 Mdot
.796 .4721 Mdot
.796 .4726 Mdot
.796 .47299 Mdot
.796 .4732 Mdot
.796 .47324 Mdot
.796 .47357 Mdot
.796 .47369 Mdot
.796 .47401 Mdot
.796 .47412 Mdot
.796 .47438 Mdot
.796 .47439 Mdot
.796 .47499 Mdot
.796 .4756 Mdot
.796 .47592 Mdot
.796 .47609 Mdot
.796 .47613 Mdot
.796 .47621 Mdot
.796 .47624 Mdot
.796 .47645 Mdot
.796 .47657 Mdot
.796 .47659 Mdot
.796 .4766 Mdot
.796 .47676 Mdot
.796 .47678 Mdot
.796 .47681 Mdot
.796 .47736 Mdot
.796 .47762 Mdot
.796 .4779 Mdot
.796 .47833 Mdot
.796 .47856 Mdot
.796 .47871 Mdot
.796 .47881 Mdot
.796 .47936 Mdot
.796 .47951 Mdot
.796 .48002 Mdot
.796 .48016 Mdot
.796 .48088 Mdot
.796 .48106 Mdot
.796 .48114 Mdot
.796 .48142 Mdot
.796 .48185 Mdot
.796 .4832 Mdot
.796 .4834 Mdot
.796 .48344 Mdot
.796 .48397 Mdot
.796 .484 Mdot
.796 .48402 Mdot
.796 .48419 Mdot
.798 .20538 Mdot
.798 .20557 Mdot
.798 .20615 Mdot
.798 .20649 Mdot
.798 .20708 Mdot
.798 .20755 Mdot
.798 .20771 Mdot
.798 .2078 Mdot
.798 .20791 Mdot
.798 .20926 Mdot
.798 .20975 Mdot
.798 .2101 Mdot
.798 .2104 Mdot
.798 .21066 Mdot
.798 .21098 Mdot
.798 .21244 Mdot
.798 .21347 Mdot
.798 .21669 Mdot
.798 .21698 Mdot
.798 .21747 Mdot
.798 .2176 Mdot
.798 .21785 Mdot
.798 .2186 Mdot
.798 .21951 Mdot
.798 .21966 Mdot
.798 .21999 Mdot
.798 .22002 Mdot
.798 .22014 Mdot
.798 .22018 Mdot
.798 .22058 Mdot
.798 .22138 Mdot
.798 .22161 Mdot
.798 .22216 Mdot
.798 .22237 Mdot
.798 .22323 Mdot
.798 .22351 Mdot
.798 .22363 Mdot
.798 .22399 Mdot
.798 .22473 Mdot
.798 .22476 Mdot
.798 .22573 Mdot
.798 .22653 Mdot
.798 .22693 Mdot
.798 .22795 Mdot
.798 .22864 Mdot
.798 .22901 Mdot
.798 .22918 Mdot
.798 .22935 Mdot
.798 .22941 Mdot
.798 .22954 Mdot
.798 .22992 Mdot
.798 .23062 Mdot
.798 .23177 Mdot
.798 .23221 Mdot
.798 .23311 Mdot
.798 .23316 Mdot
.798 .23388 Mdot
.798 .23546 Mdot
.798 .23555 Mdot
.798 .23592 Mdot
.798 .23614 Mdot
.798 .23619 Mdot
.798 .23749 Mdot
.798 .23756 Mdot
.798 .23759 Mdot
.798 .23776 Mdot
.798 .23787 Mdot
.798 .23794 Mdot
.798 .23813 Mdot
.798 .23822 Mdot
.798 .23849 Mdot
.798 .23891 Mdot
.798 .23894 Mdot
.798 .23933 Mdot
.798 .24023 Mdot
.798 .24227 Mdot
.798 .24269 Mdot
.798 .24282 Mdot
.798 .24291 Mdot
.798 .24291 Mdot
.798 .24314 Mdot
.798 .24323 Mdot
.798 .24332 Mdot
.798 .24422 Mdot
.798 .24444 Mdot
.798 .24452 Mdot
.798 .24496 Mdot
.798 .24562 Mdot
.798 .24594 Mdot
.798 .24642 Mdot
.798 .24643 Mdot
.798 .24666 Mdot
.798 .24727 Mdot
.798 .2473 Mdot
.798 .24785 Mdot
.798 .24838 Mdot
.798 .24863 Mdot
.798 .24904 Mdot
.798 .25013 Mdot
.798 .25015 Mdot
.798 .25035 Mdot
.798 .2509 Mdot
.798 .2513 Mdot
.798 .25141 Mdot
.798 .25164 Mdot
.798 .25189 Mdot
.798 .25257 Mdot
.798 .25258 Mdot
.798 .25259 Mdot
.798 .25336 Mdot
.798 .25374 Mdot
.798 .25397 Mdot
.798 .25441 Mdot
.798 .25481 Mdot
.798 .2553 Mdot
.798 .25541 Mdot
.798 .25543 Mdot
.798 .25662 Mdot
.798 .25669 Mdot
.798 .25681 Mdot
.798 .25718 Mdot
.798 .25725 Mdot
.798 .25737 Mdot
.798 .25806 Mdot
.798 .25846 Mdot
.798 .25871 Mdot
.798 .25909 Mdot
.798 .25976 Mdot
.798 .25983 Mdot
.798 .25984 Mdot
.798 .25995 Mdot
.798 .26008 Mdot
.798 .2601 Mdot
.798 .26056 Mdot
.798 .26058 Mdot
.798 .26077 Mdot
.798 .26109 Mdot
.798 .26147 Mdot
.798 .26156 Mdot
.798 .26159 Mdot
.798 .26186 Mdot
.798 .26203 Mdot
.798 .26267 Mdot
.798 .26312 Mdot
.798 .26347 Mdot
.798 .26375 Mdot
.798 .2648 Mdot
.798 .26485 Mdot
.798 .26501 Mdot
.798 .26623 Mdot
.798 .26624 Mdot
.798 .26629 Mdot
.798 .26634 Mdot
.798 .2674 Mdot
.798 .26823 Mdot
.798 .26837 Mdot
.798 .26849 Mdot
.798 .2688 Mdot
.798 .26931 Mdot
.798 .27037 Mdot
.798 .27042 Mdot
.798 .27091 Mdot
.798 .27122 Mdot
.798 .27161 Mdot
.798 .27177 Mdot
.798 .27302 Mdot
.798 .27338 Mdot
.798 .2736 Mdot
.798 .2744 Mdot
.798 .27442 Mdot
.798 .27462 Mdot
.798 .27496 Mdot
.798 .27571 Mdot
.798 .2758 Mdot
.798 .27609 Mdot
.798 .27633 Mdot
.798 .27662 Mdot
.798 .27663 Mdot
.798 .27685 Mdot
.798 .27753 Mdot
.798 .27763 Mdot
.798 .2778 Mdot
.798 .27832 Mdot
.798 .27834 Mdot
.798 .27836 Mdot
.798 .27878 Mdot
.798 .27936 Mdot
.798 .27965 Mdot
.798 .28036 Mdot
.798 .28115 Mdot
.798 .28145 Mdot
.798 .2819 Mdot
.798 .2822 Mdot
.798 .28241 Mdot
.798 .28242 Mdot
.798 .28282 Mdot
.798 .28367 Mdot
.798 .28474 Mdot
.798 .28478 Mdot
.798 .28484 Mdot
.798 .2856 Mdot
.798 .28562 Mdot
.798 .2861 Mdot
.798 .28617 Mdot
.798 .28619 Mdot
.798 .2866 Mdot
.798 .28671 Mdot
.798 .28685 Mdot
.798 .28702 Mdot
.798 .28804 Mdot
.798 .28817 Mdot
.798 .28858 Mdot
.798 .28867 Mdot
.798 .28883 Mdot
.798 .28915 Mdot
.798 .28918 Mdot
.798 .2894 Mdot
.798 .28987 Mdot
.798 .28992 Mdot
.798 .29011 Mdot
.798 .29027 Mdot
.798 .29044 Mdot
.798 .29053 Mdot
.798 .29098 Mdot
.798 .29125 Mdot
.798 .29148 Mdot
.798 .2934 Mdot
.798 .29359 Mdot
.798 .29372 Mdot
.798 .29415 Mdot
.798 .29427 Mdot
.798 .29462 Mdot
.798 .29478 Mdot
.798 .29482 Mdot
.798 .29662 Mdot
.798 .29676 Mdot
.798 .2968 Mdot
.798 .29687 Mdot
.798 .29688 Mdot
.798 .29742 Mdot
.798 .29752 Mdot
.798 .29771 Mdot
.798 .29833 Mdot
.798 .29961 Mdot
.798 .30003 Mdot
.798 .30017 Mdot
.798 .30105 Mdot
.798 .30121 Mdot
.798 .30152 Mdot
.798 .30192 Mdot
.798 .30235 Mdot
.798 .30285 Mdot
.798 .30293 Mdot
.798 .30355 Mdot
.798 .3037 Mdot
.798 .30372 Mdot
.798 .30397 Mdot
.798 .30432 Mdot
.798 .30496 Mdot
.798 .30507 Mdot
.798 .30732 Mdot
.798 .30744 Mdot
.798 .30766 Mdot
.798 .3078 Mdot
.798 .30856 Mdot
.798 .3086 Mdot
.798 .30866 Mdot
.798 .30908 Mdot
.798 .30988 Mdot
.798 .30995 Mdot
.798 .31018 Mdot
.798 .31054 Mdot
.798 .31087 Mdot
.798 .3114 Mdot
.798 .31185 Mdot
.798 .31265 Mdot
.798 .31306 Mdot
.798 .31462 Mdot
.798 .31468 Mdot
.798 .31478 Mdot
.798 .31549 Mdot
.798 .31561 Mdot
.798 .31563 Mdot
.798 .31616 Mdot
.798 .31625 Mdot
.798 .31689 Mdot
.798 .317 Mdot
.798 .31719 Mdot
.798 .31749 Mdot
.798 .31874 Mdot
.798 .31901 Mdot
.798 .31916 Mdot
.798 .31929 Mdot
.798 .31931 Mdot
.798 .31951 Mdot
.798 .32024 Mdot
.798 .32041 Mdot
.798 .32076 Mdot
.798 .32079 Mdot
.798 .32172 Mdot
.798 .32195 Mdot
.798 .32248 Mdot
.798 .32266 Mdot
.798 .32274 Mdot
.798 .32288 Mdot
.798 .32304 Mdot
.798 .32306 Mdot
.798 .32321 Mdot
.798 .32356 Mdot
.798 .32436 Mdot
.798 .32453 Mdot
.798 .32461 Mdot
.798 .3247 Mdot
.798 .32474 Mdot
.798 .32521 Mdot
.798 .32542 Mdot
.798 .32599 Mdot
.798 .32608 Mdot
.798 .32632 Mdot
.798 .32634 Mdot
.798 .32655 Mdot
.798 .32676 Mdot
.798 .32686 Mdot
.798 .32702 Mdot
.798 .32745 Mdot
.798 .32746 Mdot
.798 .32754 Mdot
.798 .32775 Mdot
.798 .32795 Mdot
.798 .32804 Mdot
.798 .32841 Mdot
.798 .32841 Mdot
.798 .32872 Mdot
.798 .32953 Mdot
.798 .33002 Mdot
.798 .33007 Mdot
.798 .33029 Mdot
.798 .33097 Mdot
.798 .33125 Mdot
.798 .33126 Mdot
.798 .3313 Mdot
.798 .33136 Mdot
.798 .33154 Mdot
.798 .33155 Mdot
.798 .33163 Mdot
.798 .33175 Mdot
.798 .3319 Mdot
.798 .33193 Mdot
.798 .33195 Mdot
.798 .33205 Mdot
.798 .33212 Mdot
.798 .33377 Mdot
.798 .33381 Mdot
.798 .33423 Mdot
.798 .33478 Mdot
.798 .33498 Mdot
.798 .3354 Mdot
.798 .33541 Mdot
.798 .3356 Mdot
.798 .33588 Mdot
.798 .33594 Mdot
.798 .33644 Mdot
.798 .33666 Mdot
.798 .33706 Mdot
.798 .33753 Mdot
.798 .33764 Mdot
.798 .33773 Mdot
.798 .33785 Mdot
.798 .33785 Mdot
.798 .3382 Mdot
.798 .33831 Mdot
.798 .33851 Mdot
.798 .33852 Mdot
.798 .33853 Mdot
.798 .33869 Mdot
.798 .33892 Mdot
.798 .33931 Mdot
.798 .33963 Mdot
.798 .33992 Mdot
.798 .34012 Mdot
.798 .34012 Mdot
.798 .34028 Mdot
.798 .34137 Mdot
.798 .34138 Mdot
.798 .34157 Mdot
.798 .3416 Mdot
.798 .34181 Mdot
.798 .34193 Mdot
.798 .34233 Mdot
.798 .34238 Mdot
.798 .34258 Mdot
.798 .34264 Mdot
.798 .34286 Mdot
.798 .34305 Mdot
.798 .34314 Mdot
.798 .3432 Mdot
.798 .34327 Mdot
.798 .34349 Mdot
.798 .34451 Mdot
.798 .34456 Mdot
.798 .34473 Mdot
.798 .34491 Mdot
.798 .3457 Mdot
.798 .34575 Mdot
.798 .34577 Mdot
.798 .3458 Mdot
.798 .34605 Mdot
.798 .34612 Mdot
.798 .34687 Mdot
.798 .34704 Mdot
.798 .34709 Mdot
.798 .34744 Mdot
.798 .3475 Mdot
.798 .34795 Mdot
.798 .34814 Mdot
.798 .34842 Mdot
.798 .34848 Mdot
.798 .34858 Mdot
.798 .34872 Mdot
.798 .3499 Mdot
.798 .34995 Mdot
.798 .35003 Mdot
.798 .35039 Mdot
.798 .3504 Mdot
.798 .35043 Mdot
.798 .35093 Mdot
.798 .35129 Mdot
.798 .3515 Mdot
.798 .35168 Mdot
.798 .35215 Mdot
.798 .35277 Mdot
.798 .35279 Mdot
.798 .35283 Mdot
.798 .35337 Mdot
.798 .3534 Mdot
.798 .35365 Mdot
.798 .3537 Mdot
.798 .35377 Mdot
.798 .35389 Mdot
.798 .35469 Mdot
.798 .35504 Mdot
.798 .35518 Mdot
.798 .35607 Mdot
.798 .35614 Mdot
.798 .35659 Mdot
.798 .35666 Mdot
.798 .35669 Mdot
.798 .35674 Mdot
.798 .357 Mdot
.798 .35727 Mdot
.798 .35736 Mdot
.798 .35757 Mdot
.798 .35803 Mdot
.798 .35818 Mdot
.798 .35818 Mdot
.798 .35918 Mdot
.798 .3593 Mdot
.798 .35934 Mdot
.798 .35941 Mdot
.798 .35941 Mdot
.798 .35949 Mdot
.798 .35961 Mdot
.798 .36028 Mdot
.798 .36046 Mdot
.798 .36076 Mdot
.798 .36092 Mdot
.798 .361 Mdot
.798 .36111 Mdot
.798 .36114 Mdot
.798 .36142 Mdot
.798 .3618 Mdot
.798 .36184 Mdot
.798 .36188 Mdot
.798 .36188 Mdot
.798 .36215 Mdot
.798 .36246 Mdot
.798 .36284 Mdot
.798 .36327 Mdot
.798 .36327 Mdot
.798 .36336 Mdot
.798 .36349 Mdot
.798 .36385 Mdot
.798 .36393 Mdot
.798 .3645 Mdot
.798 .36497 Mdot
.798 .36499 Mdot
.798 .36511 Mdot
.798 .36549 Mdot
.798 .36551 Mdot
.798 .36606 Mdot
.798 .3661 Mdot
.798 .36667 Mdot
.798 .36702 Mdot
.798 .36716 Mdot
.798 .36731 Mdot
.798 .36776 Mdot
.798 .36811 Mdot
.798 .36814 Mdot
.798 .36818 Mdot
.798 .36869 Mdot
.798 .36928 Mdot
.798 .36981 Mdot
.798 .36987 Mdot
.798 .37026 Mdot
.798 .37032 Mdot
.798 .37035 Mdot
.798 .37038 Mdot
.798 .37043 Mdot
.798 .37069 Mdot
.798 .37088 Mdot
.798 .37094 Mdot
.798 .37097 Mdot
.798 .37114 Mdot
.798 .37129 Mdot
.798 .37132 Mdot
.798 .37132 Mdot
.798 .37143 Mdot
.798 .3717 Mdot
.798 .37187 Mdot
.798 .37195 Mdot
.798 .37253 Mdot
.798 .37254 Mdot
.798 .37259 Mdot
.798 .37275 Mdot
.798 .3732 Mdot
.798 .37399 Mdot
.798 .37422 Mdot
.798 .37445 Mdot
.798 .37463 Mdot
.798 .37464 Mdot
.798 .37502 Mdot
.798 .37503 Mdot
.798 .37527 Mdot
.798 .3755 Mdot
.798 .37558 Mdot
.798 .37633 Mdot
.798 .37667 Mdot
.798 .37699 Mdot
.798 .37789 Mdot
.798 .3781 Mdot
.798 .37857 Mdot
.798 .37862 Mdot
.798 .37876 Mdot
.798 .37892 Mdot
.798 .37892 Mdot
.798 .37917 Mdot
.798 .37928 Mdot
.798 .37942 Mdot
.798 .37957 Mdot
.798 .38035 Mdot
.798 .38048 Mdot
.798 .38085 Mdot
.798 .38101 Mdot
.798 .38124 Mdot
.798 .38124 Mdot
.798 .38136 Mdot
.798 .38148 Mdot
.798 .38185 Mdot
.798 .38187 Mdot
.798 .38215 Mdot
.798 .38219 Mdot
.798 .38252 Mdot
.798 .38289 Mdot
.798 .38324 Mdot
.798 .38375 Mdot
.798 .38416 Mdot
.798 .38451 Mdot
.798 .38454 Mdot
.798 .38488 Mdot
.798 .38489 Mdot
.798 .38513 Mdot
.798 .3852 Mdot
.798 .38522 Mdot
.798 .38587 Mdot
.798 .38592 Mdot
.798 .38615 Mdot
.798 .38628 Mdot
.798 .38655 Mdot
.798 .38679 Mdot
.798 .38699 Mdot
.798 .38715 Mdot
.798 .38715 Mdot
.798 .38721 Mdot
.798 .38745 Mdot
.798 .38764 Mdot
.798 .38771 Mdot
.798 .38776 Mdot
.798 .38786 Mdot
.798 .38804 Mdot
.798 .38816 Mdot
.798 .38858 Mdot
.798 .38865 Mdot
.798 .3887 Mdot
.798 .3887 Mdot
.798 .38875 Mdot
.798 .38885 Mdot
.798 .38947 Mdot
.798 .38957 Mdot
.798 .39041 Mdot
.798 .39043 Mdot
.798 .39047 Mdot
.798 .3908 Mdot
.798 .39136 Mdot
.798 .39166 Mdot
.798 .39216 Mdot
.798 .39224 Mdot
.798 .39228 Mdot
.798 .39231 Mdot
.798 .39249 Mdot
.798 .39283 Mdot
.798 .39285 Mdot
.798 .39325 Mdot
.798 .39355 Mdot
.798 .39379 Mdot
.798 .39402 Mdot
.798 .39433 Mdot
.798 .39435 Mdot
.798 .39436 Mdot
.798 .39458 Mdot
.798 .39549 Mdot
.798 .39555 Mdot
.798 .39559 Mdot
.798 .3962 Mdot
.798 .39642 Mdot
.798 .39646 Mdot
.798 .39656 Mdot
.798 .39707 Mdot
.798 .39725 Mdot
.798 .39726 Mdot
.798 .39729 Mdot
.798 .3979 Mdot
.798 .39804 Mdot
.798 .39868 Mdot
.798 .39886 Mdot
.798 .3989 Mdot
.798 .39895 Mdot
.798 .39907 Mdot
.798 .39966 Mdot
.798 .39986 Mdot
.798 .4 Mdot
.798 .4 Mdot
.798 .40069 Mdot
.798 .40079 Mdot
.798 .40091 Mdot
.798 .4011 Mdot
.798 .40129 Mdot
.798 .40168 Mdot
.798 .40179 Mdot
.798 .4018 Mdot
.798 .40199 Mdot
.798 .40221 Mdot
.798 .40222 Mdot
.798 .40229 Mdot
.798 .40235 Mdot
.798 .40296 Mdot
.798 .4031 Mdot
.798 .40341 Mdot
.798 .40345 Mdot
.798 .40362 Mdot
.798 .40374 Mdot
.798 .40375 Mdot
.798 .40401 Mdot
.798 .40414 Mdot
.798 .40448 Mdot
.798 .40474 Mdot
.798 .40477 Mdot
.798 .4058 Mdot
.798 .40584 Mdot
.798 .40591 Mdot
.798 .40594 Mdot
.798 .40603 Mdot
.798 .40611 Mdot
.798 .40616 Mdot
.798 .40616 Mdot
.798 .40628 Mdot
.798 .40631 Mdot
.798 .40634 Mdot
.798 .40635 Mdot
.798 .40653 Mdot
.798 .40709 Mdot
.798 .40712 Mdot
.798 .40743 Mdot
.798 .40794 Mdot
.798 .40813 Mdot
.798 .40813 Mdot
.798 .40836 Mdot
.798 .40854 Mdot
.798 .40868 Mdot
.798 .40873 Mdot
.798 .4091 Mdot
.798 .40916 Mdot
.798 .40943 Mdot
.798 .40943 Mdot
.798 .40958 Mdot
.798 .41 Mdot
.798 .41043 Mdot
.798 .41045 Mdot
.798 .41051 Mdot
.798 .41056 Mdot
.798 .41066 Mdot
.798 .41116 Mdot
.798 .41139 Mdot
.798 .41149 Mdot
.798 .41173 Mdot
.798 .41217 Mdot
.798 .41292 Mdot
.798 .41314 Mdot
.798 .4137 Mdot
.798 .41384 Mdot
.798 .41392 Mdot
.798 .41419 Mdot
.798 .41497 Mdot
.798 .41516 Mdot
.798 .41528 Mdot
.798 .41535 Mdot
.798 .41575 Mdot
.798 .4158 Mdot
.798 .41614 Mdot
.798 .41614 Mdot
.798 .41623 Mdot
.798 .4163 Mdot
.798 .41667 Mdot
.798 .41673 Mdot
.798 .41676 Mdot
.798 .41775 Mdot
.798 .418 Mdot
.798 .4185 Mdot
.798 .41878 Mdot
.798 .41912 Mdot
.798 .41932 Mdot
.798 .41955 Mdot
.798 .41969 Mdot
.798 .41974 Mdot
.798 .42024 Mdot
.798 .4205 Mdot
.798 .42054 Mdot
.798 .42056 Mdot
.798 .42104 Mdot
.798 .42113 Mdot
.798 .42127 Mdot
.798 .42134 Mdot
.798 .42275 Mdot
.798 .42282 Mdot
.798 .42322 Mdot
.798 .42344 Mdot
.798 .4236 Mdot
.798 .42361 Mdot
.798 .42371 Mdot
.798 .42409 Mdot
.798 .42414 Mdot
.798 .42446 Mdot
.798 .42473 Mdot
.798 .42497 Mdot
.798 .42517 Mdot
.798 .42527 Mdot
.798 .42582 Mdot
.798 .42591 Mdot
.798 .42618 Mdot
.798 .42698 Mdot
.798 .42737 Mdot
.798 .42748 Mdot
.798 .42754 Mdot
.798 .42788 Mdot
.798 .42789 Mdot
.798 .42793 Mdot
.798 .42796 Mdot
.798 .42804 Mdot
.798 .42918 Mdot
.798 .4292 Mdot
.798 .4293 Mdot
.798 .42952 Mdot
.798 .42959 Mdot
.798 .42986 Mdot
.798 .42994 Mdot
.798 .43007 Mdot
.798 .43126 Mdot
.798 .43141 Mdot
.798 .43158 Mdot
.798 .43186 Mdot
.798 .43192 Mdot
.798 .43203 Mdot
.798 .43213 Mdot
.798 .43225 Mdot
.798 .43227 Mdot
.798 .43257 Mdot
.798 .43271 Mdot
.798 .43273 Mdot
.798 .43293 Mdot
.798 .43302 Mdot
.798 .43309 Mdot
.798 .43334 Mdot
.798 .43342 Mdot
.798 .43406 Mdot
.798 .43417 Mdot
.798 .43426 Mdot
.798 .43432 Mdot
.798 .43458 Mdot
.798 .43459 Mdot
.798 .43463 Mdot
.798 .43494 Mdot
.798 .43495 Mdot
.798 .43543 Mdot
.798 .43546 Mdot
.798 .43549 Mdot
.798 .43616 Mdot
.798 .43669 Mdot
.798 .43695 Mdot
.798 .43695 Mdot
.798 .43708 Mdot
.798 .43727 Mdot
.798 .43755 Mdot
.798 .43774 Mdot
.798 .43824 Mdot
.798 .43868 Mdot
.798 .43886 Mdot
.798 .43922 Mdot
.798 .43949 Mdot
.798 .4395 Mdot
.798 .43951 Mdot
.798 .43984 Mdot
.798 .43995 Mdot
.798 .44001 Mdot
.798 .44043 Mdot
.798 .44057 Mdot
.798 .44058 Mdot
.798 .44076 Mdot
.798 .44091 Mdot
.798 .44109 Mdot
.798 .44115 Mdot
.798 .44162 Mdot
.798 .44183 Mdot
.798 .44196 Mdot
.798 .44197 Mdot
.798 .44247 Mdot
.798 .44261 Mdot
.798 .44283 Mdot
.798 .44362 Mdot
.798 .44371 Mdot
.798 .44396 Mdot
.798 .44416 Mdot
.798 .44446 Mdot
.798 .44449 Mdot
.798 .44516 Mdot
.798 .44547 Mdot
.798 .44567 Mdot
.798 .44575 Mdot
.798 .44584 Mdot
.798 .44635 Mdot
.798 .44702 Mdot
.798 .44705 Mdot
.798 .44708 Mdot
.798 .44709 Mdot
.798 .44785 Mdot
.798 .44795 Mdot
.798 .44799 Mdot
.798 .44864 Mdot
.798 .44882 Mdot
.798 .44904 Mdot
.798 .44932 Mdot
.798 .44972 Mdot
.798 .44982 Mdot
.798 .45 Mdot
.798 .45001 Mdot
.798 .45007 Mdot
.798 .4503 Mdot
.798 .45051 Mdot
.798 .45063 Mdot
.798 .45064 Mdot
.798 .45093 Mdot
.798 .45094 Mdot
.798 .45102 Mdot
.798 .45109 Mdot
.798 .4511 Mdot
.798 .45114 Mdot
.798 .45156 Mdot
.798 .4518 Mdot
.798 .45195 Mdot
.798 .4522 Mdot
.798 .45264 Mdot
.798 .45272 Mdot
.798 .45276 Mdot
.798 .45299 Mdot
.798 .45306 Mdot
.798 .45311 Mdot
.798 .45385 Mdot
.798 .45387 Mdot
.798 .45394 Mdot
.798 .45424 Mdot
.798 .4545 Mdot
.798 .45477 Mdot
.798 .45491 Mdot
.798 .45515 Mdot
.798 .45564 Mdot
.798 .45564 Mdot
.798 .45565 Mdot
.798 .45607 Mdot
.798 .45623 Mdot
.798 .45637 Mdot
.798 .45644 Mdot
.798 .45669 Mdot
.798 .45703 Mdot
.798 .45716 Mdot
.798 .45718 Mdot
.798 .45786 Mdot
.798 .45811 Mdot
.798 .45827 Mdot
.798 .45861 Mdot
.798 .45895 Mdot
.798 .45897 Mdot
.798 .45935 Mdot
.798 .45949 Mdot
.798 .4595 Mdot
.798 .4598 Mdot
.798 .46 Mdot
.798 .46041 Mdot
.798 .46069 Mdot
.798 .46074 Mdot
.798 .46088 Mdot
.798 .46144 Mdot
.798 .4615 Mdot
.798 .46156 Mdot
.798 .4617 Mdot
.798 .4617 Mdot
.798 .46176 Mdot
.798 .46183 Mdot
.798 .4621 Mdot
.798 .46337 Mdot
.798 .46394 Mdot
.798 .46418 Mdot
.798 .4642 Mdot
.798 .46447 Mdot
.798 .46464 Mdot
.798 .46469 Mdot
.798 .46482 Mdot
.798 .46485 Mdot
.798 .46493 Mdot
.798 .46503 Mdot
.798 .46505 Mdot
.798 .4651 Mdot
.798 .46591 Mdot
.798 .46594 Mdot
.798 .46608 Mdot
.798 .46631 Mdot
.798 .46637 Mdot
.798 .46736 Mdot
.798 .46781 Mdot
.798 .46784 Mdot
.798 .4684 Mdot
.798 .46868 Mdot
.798 .4694 Mdot
.798 .46984 Mdot
.798 .47008 Mdot
.798 .47016 Mdot
.798 .4702 Mdot
.798 .4703 Mdot
.798 .4704 Mdot
.798 .47064 Mdot
.798 .47107 Mdot
.798 .47171 Mdot
.798 .47196 Mdot
.798 .47246 Mdot
.798 .47307 Mdot
.798 .47309 Mdot
.798 .47355 Mdot
.798 .47378 Mdot
.798 .47386 Mdot
.798 .47403 Mdot
.798 .47457 Mdot
.798 .4747 Mdot
.798 .47505 Mdot
.798 .47519 Mdot
.798 .47569 Mdot
.798 .47594 Mdot
.798 .47596 Mdot
.798 .47604 Mdot
.798 .47606 Mdot
.798 .47627 Mdot
.798 .47636 Mdot
.798 .47693 Mdot
.798 .4774 Mdot
.798 .47756 Mdot
.798 .47764 Mdot
.798 .47795 Mdot
.798 .47813 Mdot
.798 .48014 Mdot
.798 .48079 Mdot
.798 .48171 Mdot
.798 .4819 Mdot
.798 .48207 Mdot
.798 .48226 Mdot
.798 .48248 Mdot
.798 .48278 Mdot
.798 .48363 Mdot
.798 .4837 Mdot
.798 .48375 Mdot
.798 .48385 Mdot
.798 .48415 Mdot
.798 .48452 Mdot
.798 .48473 Mdot
.798 .4851 Mdot
.798 .48522 Mdot
.8 .20461 Mdot
.8 .20525 Mdot
.8 .20656 Mdot
.8 .20669 Mdot
.8 .20676 Mdot
.8 .20696 Mdot
.8 .20707 Mdot
.8 .20743 Mdot
.8 .20779 Mdot
.8 .20791 Mdot
.8 .20858 Mdot
.8 .20935 Mdot
.8 .20952 Mdot
.8 .20967 Mdot
.8 .21069 Mdot
.8 .21124 Mdot
.8 .21128 Mdot
.8 .21168 Mdot
.8 .21351 Mdot
.8 .21371 Mdot
.8 .21392 Mdot
.8 .21416 Mdot
.8 .21421 Mdot
.8 .21476 Mdot
.8 .21561 Mdot
.8 .21566 Mdot
.8 .21614 Mdot
.8 .21617 Mdot
.8 .21645 Mdot
.8 .21787 Mdot
.8 .21964 Mdot
.8 .22134 Mdot
.8 .22148 Mdot
.8 .22155 Mdot
.8 .22214 Mdot
.8 .22224 Mdot
.8 .22271 Mdot
.8 .22306 Mdot
.8 .22385 Mdot
.8 .22452 Mdot
.8 .22511 Mdot
.8 .22533 Mdot
.8 .22541 Mdot
.8 .22616 Mdot
.8 .22672 Mdot
.8 .22742 Mdot
.8 .22744 Mdot
.8 .22755 Mdot
.8 .22763 Mdot
.8 .22788 Mdot
.8 .22852 Mdot
.8 .22877 Mdot
.8 .22888 Mdot
.8 .22905 Mdot
.8 .22908 Mdot
.8 .22911 Mdot
.8 .22918 Mdot
.8 .22925 Mdot
.8 .22967 Mdot
.8 .23021 Mdot
.8 .23033 Mdot
.8 .23037 Mdot
.8 .23042 Mdot
.8 .23075 Mdot
.8 .23103 Mdot
.8 .23248 Mdot
.8 .2326 Mdot
.8 .2327 Mdot
.8 .23279 Mdot
.8 .23293 Mdot
.8 .23339 Mdot
.8 .23353 Mdot
.8 .23363 Mdot
.8 .23413 Mdot
.8 .23466 Mdot
.8 .23484 Mdot
.8 .23497 Mdot
.8 .23525 Mdot
.8 .2358 Mdot
.8 .23625 Mdot
.8 .23651 Mdot
.8 .23722 Mdot
.8 .23741 Mdot
.8 .23769 Mdot
.8 .23814 Mdot
.8 .23877 Mdot
.8 .23919 Mdot
.8 .23946 Mdot
.8 .23969 Mdot
.8 .23974 Mdot
.8 .24014 Mdot
.8 .24042 Mdot
.8 .2405 Mdot
.8 .24061 Mdot
.8 .24089 Mdot
.8 .24182 Mdot
.8 .24192 Mdot
.8 .24243 Mdot
.8 .24296 Mdot
.8 .24313 Mdot
.8 .2435 Mdot
.8 .24375 Mdot
.8 .24402 Mdot
.8 .24414 Mdot
.8 .24475 Mdot
.8 .24524 Mdot
.8 .24544 Mdot
.8 .24559 Mdot
.8 .24582 Mdot
.8 .24594 Mdot
.8 .24622 Mdot
.8 .24628 Mdot
.8 .24637 Mdot
.8 .24645 Mdot
.8 .2466 Mdot
.8 .2469 Mdot
.8 .24729 Mdot
.8 .24802 Mdot
.8 .24825 Mdot
.8 .2484 Mdot
.8 .25039 Mdot
.8 .25105 Mdot
.8 .25237 Mdot
.8 .25238 Mdot
.8 .25331 Mdot
.8 .25346 Mdot
.8 .2535 Mdot
.8 .25513 Mdot
.8 .25542 Mdot
.8 .25575 Mdot
.8 .25604 Mdot
.8 .25624 Mdot
.8 .2581 Mdot
.8 .25894 Mdot
.8 .25902 Mdot
.8 .25916 Mdot
.8 .25931 Mdot
.8 .25964 Mdot
.8 .25965 Mdot
.8 .25972 Mdot
.8 .25974 Mdot
.8 .25976 Mdot
.8 .26029 Mdot
.8 .26076 Mdot
.8 .26185 Mdot
.8 .26251 Mdot
.8 .26262 Mdot
.8 .26283 Mdot
.8 .26298 Mdot
.8 .26343 Mdot
.8 .26375 Mdot
.8 .26376 Mdot
.8 .26412 Mdot
.8 .2643 Mdot
.8 .26432 Mdot
.8 .26453 Mdot
.8 .26528 Mdot
.8 .26549 Mdot
.8 .26624 Mdot
.8 .26629 Mdot
.8 .26658 Mdot
.8 .26669 Mdot
.8 .26775 Mdot
.8 .26848 Mdot
.8 .26871 Mdot
.8 .2694 Mdot
.8 .26977 Mdot
.8 .26984 Mdot
.8 .27041 Mdot
.8 .27106 Mdot
.8 .2712 Mdot
.8 .27142 Mdot
.8 .27156 Mdot
.8 .27221 Mdot
.8 .27265 Mdot
.8 .27339 Mdot
.8 .2735 Mdot
.8 .2744 Mdot
.8 .27461 Mdot
.8 .27467 Mdot
.8 .27476 Mdot
.8 .27584 Mdot
.8 .27827 Mdot
.8 .28049 Mdot
.8 .28192 Mdot
.8 .282 Mdot
.8 .28268 Mdot
.8 .28311 Mdot
.8 .28331 Mdot
.8 .28396 Mdot
.8 .28422 Mdot
.8 .28431 Mdot
.8 .28517 Mdot
.8 .28519 Mdot
.8 .28646 Mdot
.8 .28665 Mdot
.8 .28733 Mdot
.8 .28773 Mdot
.8 .2891 Mdot
.8 .28918 Mdot
.8 .28929 Mdot
.8 .29017 Mdot
.8 .29138 Mdot
.8 .29292 Mdot
.8 .29295 Mdot
.8 .29317 Mdot
.8 .29332 Mdot
.8 .29387 Mdot
.8 .29398 Mdot
.8 .29422 Mdot
.8 .29469 Mdot
.8 .29473 Mdot
.8 .29525 Mdot
.8 .29554 Mdot
.8 .29565 Mdot
.8 .29617 Mdot
.8 .29645 Mdot
.8 .2968 Mdot
.8 .2973 Mdot
.8 .29797 Mdot
.8 .2982 Mdot
.8 .29833 Mdot
.8 .29838 Mdot
.8 .29918 Mdot
.8 .29948 Mdot
.8 .29964 Mdot
.8 .29992 Mdot
.8 .30018 Mdot
.8 .3003 Mdot
.8 .30035 Mdot
.8 .30063 Mdot
.8 .30114 Mdot
.8 .30117 Mdot
.8 .30126 Mdot
.8 .30149 Mdot
.8 .30175 Mdot
.8 .30206 Mdot
.8 .30242 Mdot
.8 .30408 Mdot
.8 .30475 Mdot
.8 .30495 Mdot
.8 .3053 Mdot
.8 .30553 Mdot
.8 .30571 Mdot
.8 .30666 Mdot
.8 .30667 Mdot
.8 .30729 Mdot
.8 .30735 Mdot
.8 .30741 Mdot
.8 .30771 Mdot
.8 .30797 Mdot
.8 .3083 Mdot
.8 .30842 Mdot
.8 .30902 Mdot
.8 .31013 Mdot
.8 .31089 Mdot
.8 .31094 Mdot
.8 .31105 Mdot
.8 .31123 Mdot
.8 .31137 Mdot
.8 .3125 Mdot
.8 .31289 Mdot
.8 .31361 Mdot
.8 .31377 Mdot
.8 .31388 Mdot
.8 .31442 Mdot
.8 .31463 Mdot
.8 .31476 Mdot
.8 .316 Mdot
.8 .31666 Mdot
.8 .31672 Mdot
.8 .31675 Mdot
.8 .31702 Mdot
.8 .3172 Mdot
.8 .31855 Mdot
.8 .31905 Mdot
.8 .31912 Mdot
.8 .31957 Mdot
.8 .31961 Mdot
.8 .31968 Mdot
.8 .31969 Mdot
.8 .3197 Mdot
.8 .31973 Mdot
.8 .32013 Mdot
.8 .32017 Mdot
.8 .32019 Mdot
.8 .32034 Mdot
.8 .32045 Mdot
.8 .3211 Mdot
.8 .32114 Mdot
.8 .32137 Mdot
.8 .32147 Mdot
.8 .32166 Mdot
.8 .32187 Mdot
.8 .32194 Mdot
.8 .32199 Mdot
.8 .32231 Mdot
.8 .32249 Mdot
.8 .32287 Mdot
.8 .32305 Mdot
.8 .32347 Mdot
.8 .32364 Mdot
.8 .32383 Mdot
.8 .32401 Mdot
.8 .32412 Mdot
.8 .32419 Mdot
.8 .3243 Mdot
.8 .3249 Mdot
.8 .32511 Mdot
.8 .32532 Mdot
.8 .32557 Mdot
.8 .32581 Mdot
.8 .326 Mdot
.8 .32614 Mdot
.8 .32627 Mdot
.8 .32638 Mdot
.8 .32641 Mdot
.8 .32653 Mdot
.8 .32665 Mdot
.8 .3268 Mdot
.8 .32709 Mdot
.8 .32718 Mdot
.8 .32723 Mdot
.8 .32827 Mdot
.8 .32878 Mdot
.8 .32879 Mdot
.8 .32915 Mdot
.8 .32921 Mdot
.8 .32986 Mdot
.8 .32998 Mdot
.8 .33102 Mdot
.8 .33135 Mdot
.8 .33138 Mdot
.8 .33144 Mdot
.8 .3315 Mdot
.8 .33162 Mdot
.8 .33163 Mdot
.8 .33166 Mdot
.8 .33167 Mdot
.8 .33188 Mdot
.8 .33249 Mdot
.8 .33279 Mdot
.8 .33287 Mdot
.8 .33311 Mdot
.8 .33323 Mdot
.8 .33323 Mdot
.8 .33338 Mdot
.8 .33344 Mdot
.8 .33345 Mdot
.8 .33354 Mdot
.8 .33383 Mdot
.8 .33391 Mdot
.8 .33434 Mdot
.8 .33438 Mdot
.8 .33479 Mdot
.8 .33558 Mdot
.8 .33561 Mdot
.8 .33583 Mdot
.8 .33614 Mdot
.8 .33623 Mdot
.8 .33653 Mdot
.8 .337 Mdot
.8 .33704 Mdot
.8 .3375 Mdot
.8 .33753 Mdot
.8 .33795 Mdot
.8 .33977 Mdot
.8 .34033 Mdot
.8 .34036 Mdot
.8 .34063 Mdot
.8 .34079 Mdot
.8 .34087 Mdot
.8 .34123 Mdot
.8 .34126 Mdot
.8 .3416 Mdot
.8 .34161 Mdot
.8 .3421 Mdot
.8 .34217 Mdot
.8 .34244 Mdot
.8 .3426 Mdot
.8 .34313 Mdot
.8 .34316 Mdot
.8 .34321 Mdot
.8 .34402 Mdot
.8 .34463 Mdot
.8 .34504 Mdot
.8 .34513 Mdot
.8 .34532 Mdot
.8 .34533 Mdot
.8 .34553 Mdot
.8 .34565 Mdot
.8 .34569 Mdot
.8 .34614 Mdot
.8 .34633 Mdot
.8 .3466 Mdot
.8 .34669 Mdot
.8 .34676 Mdot
.8 .34707 Mdot
.8 .34725 Mdot
.8 .34736 Mdot
.8 .34746 Mdot
.8 .34751 Mdot
.8 .34753 Mdot
.8 .34764 Mdot
.8 .34785 Mdot
.8 .34788 Mdot
.8 .34807 Mdot
.8 .34925 Mdot
.8 .34932 Mdot
.8 .34946 Mdot
.8 .35 Mdot
.8 .35024 Mdot
.8 .35026 Mdot
.8 .35029 Mdot
.8 .3504 Mdot
.8 .35051 Mdot
.8 .35063 Mdot
.8 .35135 Mdot
.8 .35166 Mdot
.8 .35171 Mdot
.8 .35178 Mdot
.8 .35183 Mdot
.8 .35227 Mdot
.8 .35243 Mdot
.8 .35277 Mdot
.8 .35302 Mdot
.8 .35364 Mdot
.8 .35392 Mdot
.8 .35393 Mdot
.8 .35404 Mdot
.8 .35505 Mdot
.8 .35508 Mdot
.8 .35509 Mdot
.8 .35525 Mdot
.8 .35528 Mdot
.8 .35534 Mdot
.8 .35538 Mdot
.8 .35574 Mdot
.8 .35578 Mdot
.8 .35632 Mdot
.8 .35681 Mdot
.8 .35684 Mdot
.8 .3572 Mdot
.8 .35728 Mdot
.8 .35738 Mdot
.8 .35747 Mdot
.8 .35765 Mdot
.8 .3577 Mdot
.8 .35775 Mdot
.8 .35786 Mdot
.8 .35797 Mdot
.8 .35801 Mdot
.8 .35803 Mdot
.8 .35864 Mdot
.8 .35951 Mdot
.8 .35969 Mdot
.8 .35975 Mdot
.8 .35976 Mdot
.8 .35984 Mdot
.8 .36037 Mdot
.8 .36043 Mdot
.8 .36049 Mdot
.8 .3608 Mdot
.8 .36082 Mdot
.8 .3613 Mdot
.8 .36139 Mdot
.8 .36166 Mdot
.8 .36205 Mdot
.8 .36222 Mdot
.8 .36314 Mdot
.8 .36326 Mdot
.8 .36333 Mdot
.8 .3635 Mdot
.8 .36351 Mdot
.8 .36364 Mdot
.8 .36384 Mdot
.8 .36386 Mdot
.8 .36424 Mdot
.8 .36425 Mdot
.8 .36459 Mdot
.8 .36482 Mdot
.8 .36498 Mdot
.8 .36502 Mdot
.8 .3651 Mdot
.8 .36524 Mdot
.8 .36541 Mdot
.8 .36549 Mdot
.8 .36563 Mdot
.8 .36578 Mdot
.8 .36585 Mdot
.8 .36596 Mdot
.8 .366 Mdot
.8 .36609 Mdot
.8 .36663 Mdot
.8 .36671 Mdot
.8 .36692 Mdot
.8 .36703 Mdot
.8 .36712 Mdot
.8 .36717 Mdot
.8 .36757 Mdot
.8 .36762 Mdot
.8 .36781 Mdot
.8 .36787 Mdot
.8 .368 Mdot
.8 .36846 Mdot
.8 .3685 Mdot
.8 .36891 Mdot
.8 .36898 Mdot
.8 .36916 Mdot
.8 .36939 Mdot
.8 .36959 Mdot
.8 .36977 Mdot
.8 .36984 Mdot
.8 .37005 Mdot
.8 .37006 Mdot
.8 .37073 Mdot
.8 .37102 Mdot
.8 .37134 Mdot
.8 .37148 Mdot
.8 .37163 Mdot
.8 .37169 Mdot
.8 .3722 Mdot
.8 .37233 Mdot
.8 .37248 Mdot
.8 .37282 Mdot
.8 .37287 Mdot
.8 .37297 Mdot
.8 .37315 Mdot
.8 .37321 Mdot
.8 .37363 Mdot
.8 .37388 Mdot
.8 .3739 Mdot
.8 .37431 Mdot
.8 .37434 Mdot
.8 .3745 Mdot
.8 .37467 Mdot
.8 .37475 Mdot
.8 .37476 Mdot
.8 .3754 Mdot
.8 .3757 Mdot
.8 .37584 Mdot
.8 .37586 Mdot
.8 .37597 Mdot
.8 .37615 Mdot
.8 .37649 Mdot
.8 .37659 Mdot
.8 .37702 Mdot
.8 .37727 Mdot
.8 .37808 Mdot
.8 .37824 Mdot
.8 .37857 Mdot
.8 .37896 Mdot
.8 .37906 Mdot
.8 .37965 Mdot
.8 .37981 Mdot
.8 .37991 Mdot
.8 .38019 Mdot
.8 .38036 Mdot
.8 .38065 Mdot
.8 .38077 Mdot
.8 .38083 Mdot
.8 .38086 Mdot
.8 .38107 Mdot
.8 .38117 Mdot
.8 .38157 Mdot
.8 .38161 Mdot
.8 .38179 Mdot
.8 .38259 Mdot
.8 .38259 Mdot
.8 .38272 Mdot
.8 .38277 Mdot
.8 .383 Mdot
.8 .38326 Mdot
.8 .38331 Mdot
.8 .38356 Mdot
.8 .38387 Mdot
.8 .38396 Mdot
.8 .38399 Mdot
.8 .38411 Mdot
.8 .38439 Mdot
.8 .38448 Mdot
.8 .38468 Mdot
.8 .38507 Mdot
.8 .38513 Mdot
.8 .38515 Mdot
.8 .38522 Mdot
.8 .38536 Mdot
.8 .38544 Mdot
.8 .38549 Mdot
.8 .3856 Mdot
.8 .38569 Mdot
.8 .38574 Mdot
.8 .38622 Mdot
.8 .38623 Mdot
.8 .38648 Mdot
.8 .38668 Mdot
.8 .38684 Mdot
.8 .38749 Mdot
.8 .38759 Mdot
.8 .38784 Mdot
.8 .38801 Mdot
.8 .38806 Mdot
.8 .38837 Mdot
.8 .38857 Mdot
.8 .38861 Mdot
.8 .38903 Mdot
.8 .39011 Mdot
.8 .39012 Mdot
.8 .39045 Mdot
.8 .39057 Mdot
.8 .39085 Mdot
.8 .39117 Mdot
.8 .39154 Mdot
.8 .39179 Mdot
.8 .39183 Mdot
.8 .39195 Mdot
.8 .3926 Mdot
.8 .39267 Mdot
.8 .39285 Mdot
.8 .39339 Mdot
.8 .39361 Mdot
.8 .3937 Mdot
.8 .39401 Mdot
.8 .39408 Mdot
.8 .39473 Mdot
.8 .39481 Mdot
.8 .39495 Mdot
.8 .39496 Mdot
.8 .39498 Mdot
.8 .39513 Mdot
.8 .39546 Mdot
.8 .3956 Mdot
.8 .39645 Mdot
.8 .39647 Mdot
.8 .3966 Mdot
.8 .39667 Mdot
.8 .39671 Mdot
.8 .39677 Mdot
.8 .39684 Mdot
.8 .39696 Mdot
.8 .3972 Mdot
.8 .39742 Mdot
.8 .39754 Mdot
.8 .39782 Mdot
.8 .39804 Mdot
.8 .39817 Mdot
.8 .39823 Mdot
.8 .39848 Mdot
.8 .39886 Mdot
.8 .39937 Mdot
.8 .3994 Mdot
.8 .39942 Mdot
.8 .39985 Mdot
.8 .40002 Mdot
.8 .40006 Mdot
.8 .40037 Mdot
.8 .40038 Mdot
.8 .40059 Mdot
.8 .40061 Mdot
.8 .40083 Mdot
.8 .40088 Mdot
.8 .40098 Mdot
.8 .40115 Mdot
.8 .40117 Mdot
.8 .40265 Mdot
.8 .40292 Mdot
.8 .40354 Mdot
.8 .40398 Mdot
.8 .40412 Mdot
.8 .40414 Mdot
.8 .40489 Mdot
.8 .40491 Mdot
.8 .40541 Mdot
.8 .40547 Mdot
.8 .40551 Mdot
.8 .4056 Mdot
.8 .40561 Mdot
.8 .40583 Mdot
.8 .40607 Mdot
.8 .40645 Mdot
.8 .40658 Mdot
.8 .40659 Mdot
.8 .40661 Mdot
.8 .40661 Mdot
.8 .40669 Mdot
.8 .40673 Mdot
.8 .40676 Mdot
.8 .40678 Mdot
.8 .40698 Mdot
.8 .40764 Mdot
.8 .40838 Mdot
.8 .40838 Mdot
.8 .40935 Mdot
.8 .40939 Mdot
.8 .40945 Mdot
.8 .40962 Mdot
.8 .40979 Mdot
.8 .40989 Mdot
.8 .40995 Mdot
.8 .41012 Mdot
.8 .41024 Mdot
.8 .41039 Mdot
.8 .41055 Mdot
.8 .41068 Mdot
.8 .41119 Mdot
.8 .41125 Mdot
.8 .4113 Mdot
.8 .41137 Mdot
.8 .4117 Mdot
.8 .41194 Mdot
.8 .41208 Mdot
.8 .41266 Mdot
.8 .41296 Mdot
.8 .41302 Mdot
.8 .41316 Mdot
.8 .41319 Mdot
.8 .41359 Mdot
.8 .41366 Mdot
.8 .41376 Mdot
.8 .41377 Mdot
.8 .41379 Mdot
.8 .41405 Mdot
.8 .41406 Mdot
.8 .41407 Mdot
.8 .41408 Mdot
.8 .41412 Mdot
.8 .41442 Mdot
.8 .41563 Mdot
.8 .41574 Mdot
.8 .41591 Mdot
.8 .41593 Mdot
.8 .41596 Mdot
.8 .41637 Mdot
.8 .41715 Mdot
.8 .41723 Mdot
.8 .41736 Mdot
.8 .4177 Mdot
.8 .41777 Mdot
.8 .41787 Mdot
.8 .41832 Mdot
.8 .41856 Mdot
.8 .41927 Mdot
.8 .41936 Mdot
.8 .41947 Mdot
.8 .41954 Mdot
.8 .41957 Mdot
.8 .42004 Mdot
.8 .42074 Mdot
.8 .42111 Mdot
.8 .42119 Mdot
.8 .42139 Mdot
.8 .42155 Mdot
.8 .42174 Mdot
.8 .42178 Mdot
.8 .42182 Mdot
.8 .4222 Mdot
.8 .42221 Mdot
.8 .42281 Mdot
.8 .42292 Mdot
.8 .42306 Mdot
.8 .42328 Mdot
.8 .42341 Mdot
.8 .42382 Mdot
.8 .42486 Mdot
.8 .42509 Mdot
.8 .42528 Mdot
.8 .42545 Mdot
.8 .42559 Mdot
.8 .42564 Mdot
.8 .42566 Mdot
.8 .42598 Mdot
.8 .42615 Mdot
.8 .42619 Mdot
.8 .42627 Mdot
.8 .42642 Mdot
.8 .4266 Mdot
.8 .4267 Mdot
.8 .42689 Mdot
.8 .42739 Mdot
.8 .42742 Mdot
.8 .4275 Mdot
.8 .42765 Mdot
.8 .42807 Mdot
.8 .42837 Mdot
.8 .42859 Mdot
.8 .42877 Mdot
.8 .42909 Mdot
.8 .42916 Mdot
.8 .42935 Mdot
.8 .42967 Mdot
.8 .42969 Mdot
.8 .42999 Mdot
.8 .43014 Mdot
.8 .43021 Mdot
.8 .43055 Mdot
.8 .43065 Mdot
.8 .43078 Mdot
.8 .4308 Mdot
.8 .43176 Mdot
.8 .43252 Mdot
.8 .43307 Mdot
.8 .43314 Mdot
.8 .43319 Mdot
.8 .43404 Mdot
.8 .43429 Mdot
.8 .43472 Mdot
.8 .43484 Mdot
.8 .43563 Mdot
.8 .43564 Mdot
.8 .43618 Mdot
.8 .43623 Mdot
.8 .4364 Mdot
.8 .43681 Mdot
.8 .43693 Mdot
.8 .4372 Mdot
.8 .43762 Mdot
.8 .43768 Mdot
.8 .43857 Mdot
.8 .43996 Mdot
.8 .44147 Mdot
.8 .44215 Mdot
.8 .44221 Mdot
.8 .44224 Mdot
.8 .44238 Mdot
.8 .44294 Mdot
.8 .44301 Mdot
.8 .44347 Mdot
.8 .44375 Mdot
.8 .44415 Mdot
.8 .44424 Mdot
.8 .44438 Mdot
.8 .44446 Mdot
.8 .44487 Mdot
.8 .44522 Mdot
.8 .44527 Mdot
.8 .4455 Mdot
.8 .44593 Mdot
.8 .44607 Mdot
.8 .44653 Mdot
.8 .4472 Mdot
.8 .44726 Mdot
.8 .44745 Mdot
.8 .44748 Mdot
.8 .44794 Mdot
.8 .44807 Mdot
.8 .44854 Mdot
.8 .44868 Mdot
.8 .44869 Mdot
.8 .4488 Mdot
.8 .44903 Mdot
.8 .44903 Mdot
.8 .44923 Mdot
.8 .44951 Mdot
.8 .4496 Mdot
.8 .44973 Mdot
.8 .44981 Mdot
.8 .45022 Mdot
.8 .4509 Mdot
.8 .45119 Mdot
.8 .45153 Mdot
.8 .45154 Mdot
.8 .45155 Mdot
.8 .45159 Mdot
.8 .4516 Mdot
.8 .4518 Mdot
.8 .4519 Mdot
.8 .45199 Mdot
.8 .45204 Mdot
.8 .45256 Mdot
.8 .45373 Mdot
.8 .45385 Mdot
.8 .45403 Mdot
.8 .45424 Mdot
.8 .45442 Mdot
.8 .45544 Mdot
.8 .45546 Mdot
.8 .45555 Mdot
.8 .45614 Mdot
.8 .45614 Mdot
.8 .45697 Mdot
.8 .45738 Mdot
.8 .45863 Mdot
.8 .45872 Mdot
.8 .45886 Mdot
.8 .45932 Mdot
.8 .45956 Mdot
.8 .45975 Mdot
.8 .45984 Mdot
.8 .4599 Mdot
.8 .45995 Mdot
.8 .45999 Mdot
.8 .46016 Mdot
.8 .46024 Mdot
.8 .46038 Mdot
.8 .46048 Mdot
.8 .4606 Mdot
.8 .46091 Mdot
.8 .46129 Mdot
.8 .46136 Mdot
.8 .46153 Mdot
.8 .46169 Mdot
.8 .46192 Mdot
.8 .46202 Mdot
.8 .46236 Mdot
.8 .46268 Mdot
.8 .46274 Mdot
.8 .46332 Mdot
.8 .46349 Mdot
.8 .46356 Mdot
.8 .46362 Mdot
.8 .46379 Mdot
.8 .46404 Mdot
.8 .46407 Mdot
.8 .46421 Mdot
.8 .46438 Mdot
.8 .46464 Mdot
.8 .46504 Mdot
.8 .46532 Mdot
.8 .4655 Mdot
.8 .46561 Mdot
.8 .46605 Mdot
.8 .46622 Mdot
.8 .4665 Mdot
.8 .46684 Mdot
.8 .46702 Mdot
.8 .4671 Mdot
.8 .46721 Mdot
.8 .46754 Mdot
.8 .46785 Mdot
.8 .46792 Mdot
.8 .46801 Mdot
.8 .46829 Mdot
.8 .46838 Mdot
.8 .46844 Mdot
.8 .4685 Mdot
.8 .46857 Mdot
.8 .46948 Mdot
.8 .46966 Mdot
.8 .46986 Mdot
.8 .46989 Mdot
.8 .46992 Mdot
.8 .46999 Mdot
.8 .47033 Mdot
.8 .47059 Mdot
.8 .47064 Mdot
.8 .47068 Mdot
.8 .4707 Mdot
.8 .47072 Mdot
.8 .47082 Mdot
.8 .47089 Mdot
.8 .47105 Mdot
.8 .47145 Mdot
.8 .47161 Mdot
.8 .47165 Mdot
.8 .47172 Mdot
.8 .47173 Mdot
.8 .47218 Mdot
.8 .47253 Mdot
.8 .47299 Mdot
.8 .47304 Mdot
.8 .47318 Mdot
.8 .47355 Mdot
.8 .47397 Mdot
.8 .47446 Mdot
.8 .47468 Mdot
.8 .47497 Mdot
.8 .47504 Mdot
.8 .47541 Mdot
.8 .47545 Mdot
.8 .47554 Mdot
.8 .4766 Mdot
.8 .4777 Mdot
.8 .47859 Mdot
.8 .47877 Mdot
.8 .47879 Mdot
.8 .47909 Mdot
.8 .47912 Mdot
.8 .47965 Mdot
.8 .47999 Mdot
.8 .48002 Mdot
.8 .48017 Mdot
.8 .48031 Mdot
.8 .48043 Mdot
.8 .48157 Mdot
.8 .48183 Mdot
.8 .48185 Mdot
.8 .4822 Mdot
.8 .48283 Mdot
.8 .48292 Mdot
.8 .48303 Mdot
.8 .48351 Mdot
.8 .48393 Mdot
.8 .484 Mdot
.8 .48423 Mdot
.8 .48445 Mdot
.8 .48452 Mdot
.8 .48465 Mdot
.8 .4847 Mdot
.8 .48478 Mdot
.8 .4856 Mdot
.8 .48599 Mdot
.802 .20236 Mdot
.802 .20314 Mdot
.802 .2033 Mdot
.802 .20417 Mdot
.802 .20509 Mdot
.802 .20558 Mdot
.802 .20639 Mdot
.802 .20668 Mdot
.802 .20794 Mdot
.802 .20803 Mdot
.802 .20811 Mdot
.802 .20814 Mdot
.802 .20816 Mdot
.802 .20823 Mdot
.802 .209 Mdot
.802 .20903 Mdot
.802 .21006 Mdot
.802 .21136 Mdot
.802 .21197 Mdot
.802 .21316 Mdot
.802 .21322 Mdot
.802 .21415 Mdot
.802 .21481 Mdot
.802 .21559 Mdot
.802 .21586 Mdot
.802 .21594 Mdot
.802 .21649 Mdot
.802 .2172 Mdot
.802 .21735 Mdot
.802 .21754 Mdot
.802 .21772 Mdot
.802 .21807 Mdot
.802 .21891 Mdot
.802 .21928 Mdot
.802 .22073 Mdot
.802 .22088 Mdot
.802 .22104 Mdot
.802 .22139 Mdot
.802 .22147 Mdot
.802 .22153 Mdot
.802 .22168 Mdot
.802 .22168 Mdot
.802 .2217 Mdot
.802 .22178 Mdot
.802 .22273 Mdot
.802 .22292 Mdot
.802 .22319 Mdot
.802 .2245 Mdot
.802 .22498 Mdot
.802 .22535 Mdot
.802 .22597 Mdot
.802 .22652 Mdot
.802 .22723 Mdot
.802 .22795 Mdot
.802 .22795 Mdot
.802 .22881 Mdot
.802 .22896 Mdot
.802 .22979 Mdot
.802 .23024 Mdot
.802 .23083 Mdot
.802 .23094 Mdot
.802 .23186 Mdot
.802 .23251 Mdot
.802 .23305 Mdot
.802 .23319 Mdot
.802 .23394 Mdot
.802 .23411 Mdot
.802 .23411 Mdot
.802 .23412 Mdot
.802 .23414 Mdot
.802 .23505 Mdot
.802 .23534 Mdot
.802 .23534 Mdot
.802 .23565 Mdot
.802 .23568 Mdot
.802 .23575 Mdot
.802 .23632 Mdot
.802 .23661 Mdot
.802 .23663 Mdot
.802 .23722 Mdot
.802 .23723 Mdot
.802 .23752 Mdot
.802 .23869 Mdot
.802 .23978 Mdot
.802 .2403 Mdot
.802 .24044 Mdot
.802 .24057 Mdot
.802 .24091 Mdot
.802 .24093 Mdot
.802 .24123 Mdot
.802 .24136 Mdot
.802 .2414 Mdot
.802 .24142 Mdot
.802 .24174 Mdot
.802 .24175 Mdot
.802 .24257 Mdot
.802 .24284 Mdot
.802 .24314 Mdot
.802 .24399 Mdot
.802 .244 Mdot
.802 .24401 Mdot
.802 .24417 Mdot
.802 .24419 Mdot
.802 .24434 Mdot
.802 .24434 Mdot
.802 .24491 Mdot
.802 .24507 Mdot
.802 .24574 Mdot
.802 .247 Mdot
.802 .2474 Mdot
.802 .24804 Mdot
.802 .24822 Mdot
.802 .2493 Mdot
.802 .2493 Mdot
.802 .24979 Mdot
.802 .2504 Mdot
.802 .25072 Mdot
.802 .25086 Mdot
.802 .25107 Mdot
.802 .25125 Mdot
.802 .25226 Mdot
.802 .25301 Mdot
.802 .25431 Mdot
.802 .25468 Mdot
.802 .25472 Mdot
.802 .2551 Mdot
.802 .25542 Mdot
.802 .25614 Mdot
.802 .25697 Mdot
.802 .25716 Mdot
.802 .2572 Mdot
.802 .25838 Mdot
.802 .25852 Mdot
.802 .25909 Mdot
.802 .25958 Mdot
.802 .25981 Mdot
.802 .26017 Mdot
.802 .2609 Mdot
.802 .26149 Mdot
.802 .26151 Mdot
.802 .26207 Mdot
.802 .26234 Mdot
.802 .26289 Mdot
.802 .26351 Mdot
.802 .26396 Mdot
.802 .26491 Mdot
.802 .26551 Mdot
.802 .26619 Mdot
.802 .26666 Mdot
.802 .26695 Mdot
.802 .26718 Mdot
.802 .26722 Mdot
.802 .26771 Mdot
.802 .2684 Mdot
.802 .26892 Mdot
.802 .26969 Mdot
.802 .27005 Mdot
.802 .27047 Mdot
.802 .27106 Mdot
.802 .27212 Mdot
.802 .27247 Mdot
.802 .27271 Mdot
.802 .27289 Mdot
.802 .27295 Mdot
.802 .27318 Mdot
.802 .27322 Mdot
.802 .27356 Mdot
.802 .27386 Mdot
.802 .2742 Mdot
.802 .27425 Mdot
.802 .27545 Mdot
.802 .27582 Mdot
.802 .27619 Mdot
.802 .27685 Mdot
.802 .27763 Mdot
.802 .27808 Mdot
.802 .2782 Mdot
.802 .27829 Mdot
.802 .27876 Mdot
.802 .27928 Mdot
.802 .27938 Mdot
.802 .27969 Mdot
.802 .28008 Mdot
.802 .28016 Mdot
.802 .28033 Mdot
.802 .28064 Mdot
.802 .28089 Mdot
.802 .28167 Mdot
.802 .28234 Mdot
.802 .28289 Mdot
.802 .28312 Mdot
.802 .28328 Mdot
.802 .28342 Mdot
.802 .28448 Mdot
.802 .2846 Mdot
.802 .28504 Mdot
.802 .28582 Mdot
.802 .2866 Mdot
.802 .28661 Mdot
.802 .28735 Mdot
.802 .28829 Mdot
.802 .28909 Mdot
.802 .28924 Mdot
.802 .2894 Mdot
.802 .29019 Mdot
.802 .29074 Mdot
.802 .29183 Mdot
.802 .29224 Mdot
.802 .29327 Mdot
.802 .29334 Mdot
.802 .29341 Mdot
.802 .29396 Mdot
.802 .29428 Mdot
.802 .29461 Mdot
.802 .29504 Mdot
.802 .29592 Mdot
.802 .29603 Mdot
.802 .29604 Mdot
.802 .29639 Mdot
.802 .29661 Mdot
.802 .29664 Mdot
.802 .29665 Mdot
.802 .29677 Mdot
.802 .29724 Mdot
.802 .29725 Mdot
.802 .29725 Mdot
.802 .29732 Mdot
.802 .29766 Mdot
.802 .29787 Mdot
.802 .29875 Mdot
.802 .3002 Mdot
.802 .30041 Mdot
.802 .30149 Mdot
.802 .3016 Mdot
.802 .30204 Mdot
.802 .30207 Mdot
.802 .30208 Mdot
.802 .30214 Mdot
.802 .30233 Mdot
.802 .30239 Mdot
.802 .30301 Mdot
.802 .30348 Mdot
.802 .3041 Mdot
.802 .30501 Mdot
.802 .30539 Mdot
.802 .30699 Mdot
.802 .30742 Mdot
.802 .30834 Mdot
.802 .30889 Mdot
.802 .30922 Mdot
.802 .30959 Mdot
.802 .31011 Mdot
.802 .31087 Mdot
.802 .31137 Mdot
.802 .31148 Mdot
.802 .31201 Mdot
.802 .31204 Mdot
.802 .31205 Mdot
.802 .31206 Mdot
.802 .31209 Mdot
.802 .31238 Mdot
.802 .3128 Mdot
.802 .3133 Mdot
.802 .31354 Mdot
.802 .31403 Mdot
.802 .31465 Mdot
.802 .31495 Mdot
.802 .31505 Mdot
.802 .31508 Mdot
.802 .31557 Mdot
.802 .31563 Mdot
.802 .3157 Mdot
.802 .31577 Mdot
.802 .31624 Mdot
.802 .31694 Mdot
.802 .3172 Mdot
.802 .31723 Mdot
.802 .31731 Mdot
.802 .31772 Mdot
.802 .31841 Mdot
.802 .3186 Mdot
.802 .31874 Mdot
.802 .31947 Mdot
.802 .31975 Mdot
.802 .31975 Mdot
.802 .32008 Mdot
.802 .32014 Mdot
.802 .32046 Mdot
.802 .32087 Mdot
.802 .32091 Mdot
.802 .32127 Mdot
.802 .32179 Mdot
.802 .32216 Mdot
.802 .32251 Mdot
.802 .32262 Mdot
.802 .32312 Mdot
.802 .32312 Mdot
.802 .32392 Mdot
.802 .32455 Mdot
.802 .32461 Mdot
.802 .32465 Mdot
.802 .3248 Mdot
.802 .32491 Mdot
.802 .32496 Mdot
.802 .32498 Mdot
.802 .32498 Mdot
.802 .32511 Mdot
.802 .32554 Mdot
.802 .32565 Mdot
.802 .32599 Mdot
.802 .32599 Mdot
.802 .32606 Mdot
.802 .32612 Mdot
.802 .32634 Mdot
.802 .3264 Mdot
.802 .32667 Mdot
.802 .32731 Mdot
.802 .32763 Mdot
.802 .32805 Mdot
.802 .32805 Mdot
.802 .32824 Mdot
.802 .32848 Mdot
.802 .3286 Mdot
.802 .32874 Mdot
.802 .32881 Mdot
.802 .32949 Mdot
.802 .33014 Mdot
.802 .33043 Mdot
.802 .33071 Mdot
.802 .33103 Mdot
.802 .33112 Mdot
.802 .33158 Mdot
.802 .33163 Mdot
.802 .33186 Mdot
.802 .33213 Mdot
.802 .33228 Mdot
.802 .33256 Mdot
.802 .33301 Mdot
.802 .33312 Mdot
.802 .33333 Mdot
.802 .33375 Mdot
.802 .33412 Mdot
.802 .33461 Mdot
.802 .335 Mdot
.802 .33501 Mdot
.802 .3352 Mdot
.802 .33547 Mdot
.802 .33567 Mdot
.802 .33692 Mdot
.802 .33715 Mdot
.802 .33722 Mdot
.802 .33724 Mdot
.802 .33733 Mdot
.802 .33735 Mdot
.802 .33748 Mdot
.802 .3376 Mdot
.802 .33775 Mdot
.802 .33821 Mdot
.802 .33836 Mdot
.802 .33928 Mdot
.802 .3395 Mdot
.802 .33974 Mdot
.802 .33986 Mdot
.802 .34004 Mdot
.802 .34023 Mdot
.802 .34033 Mdot
.802 .34089 Mdot
.802 .34126 Mdot
.802 .34172 Mdot
.802 .34194 Mdot
.802 .34224 Mdot
.802 .34255 Mdot
.802 .34284 Mdot
.802 .34351 Mdot
.802 .34363 Mdot
.802 .34415 Mdot
.802 .34458 Mdot
.802 .34474 Mdot
.802 .34516 Mdot
.802 .34541 Mdot
.802 .34566 Mdot
.802 .34622 Mdot
.802 .34635 Mdot
.802 .34644 Mdot
.802 .34645 Mdot
.802 .34668 Mdot
.802 .34668 Mdot
.802 .34671 Mdot
.802 .34685 Mdot
.802 .34783 Mdot
.802 .34792 Mdot
.802 .34838 Mdot
.802 .34855 Mdot
.802 .34856 Mdot
.802 .34856 Mdot
.802 .34859 Mdot
.802 .34866 Mdot
.802 .34868 Mdot
.802 .34911 Mdot
.802 .34985 Mdot
.802 .35064 Mdot
.802 .35121 Mdot
.802 .35134 Mdot
.802 .35148 Mdot
.802 .35198 Mdot
.802 .35242 Mdot
.802 .35243 Mdot
.802 .35244 Mdot
.802 .35245 Mdot
.802 .35257 Mdot
.802 .35293 Mdot
.802 .35302 Mdot
.802 .35345 Mdot
.802 .35356 Mdot
.802 .3536 Mdot
.802 .35362 Mdot
.802 .35381 Mdot
.802 .35383 Mdot
.802 .35407 Mdot
.802 .35445 Mdot
.802 .35464 Mdot
.802 .35491 Mdot
.802 .35504 Mdot
.802 .35532 Mdot
.802 .35543 Mdot
.802 .35558 Mdot
.802 .35602 Mdot
.802 .35622 Mdot
.802 .35674 Mdot
.802 .35674 Mdot
.802 .3573 Mdot
.802 .35746 Mdot
.802 .35747 Mdot
.802 .35768 Mdot
.802 .35773 Mdot
.802 .35786 Mdot
.802 .35786 Mdot
.802 .35812 Mdot
.802 .35837 Mdot
.802 .35866 Mdot
.802 .35873 Mdot
.802 .35882 Mdot
.802 .35887 Mdot
.802 .35892 Mdot
.802 .35895 Mdot
.802 .35969 Mdot
.802 .36003 Mdot
.802 .36005 Mdot
.802 .36014 Mdot
.802 .36024 Mdot
.802 .36041 Mdot
.802 .36071 Mdot
.802 .36136 Mdot
.802 .36136 Mdot
.802 .36144 Mdot
.802 .36154 Mdot
.802 .36222 Mdot
.802 .36226 Mdot
.802 .36237 Mdot
.802 .36261 Mdot
.802 .36302 Mdot
.802 .36339 Mdot
.802 .36379 Mdot
.802 .36406 Mdot
.802 .36492 Mdot
.802 .36514 Mdot
.802 .3658 Mdot
.802 .36635 Mdot
.802 .36662 Mdot
.802 .36663 Mdot
.802 .36663 Mdot
.802 .36664 Mdot
.802 .36667 Mdot
.802 .36744 Mdot
.802 .36771 Mdot
.802 .36776 Mdot
.802 .36813 Mdot
.802 .36813 Mdot
.802 .36814 Mdot
.802 .36836 Mdot
.802 .36859 Mdot
.802 .36859 Mdot
.802 .36868 Mdot
.802 .36877 Mdot
.802 .3691 Mdot
.802 .36915 Mdot
.802 .36926 Mdot
.802 .3693 Mdot
.802 .36953 Mdot
.802 .37002 Mdot
.802 .37017 Mdot
.802 .37019 Mdot
.802 .37024 Mdot
.802 .37024 Mdot
.802 .37055 Mdot
.802 .37058 Mdot
.802 .37062 Mdot
.802 .37064 Mdot
.802 .37066 Mdot
.802 .37067 Mdot
.802 .37109 Mdot
.802 .3711 Mdot
.802 .37113 Mdot
.802 .37161 Mdot
.802 .37163 Mdot
.802 .37194 Mdot
.802 .37196 Mdot
.802 .37209 Mdot
.802 .37255 Mdot
.802 .37333 Mdot
.802 .37397 Mdot
.802 .37407 Mdot
.802 .37409 Mdot
.802 .37424 Mdot
.802 .37424 Mdot
.802 .37445 Mdot
.802 .37469 Mdot
.802 .37478 Mdot
.802 .37497 Mdot
.802 .37504 Mdot
.802 .37518 Mdot
.802 .37519 Mdot
.802 .37572 Mdot
.802 .37572 Mdot
.802 .37595 Mdot
.802 .37655 Mdot
.802 .37661 Mdot
.802 .37661 Mdot
.802 .37669 Mdot
.802 .37679 Mdot
.802 .3769 Mdot
.802 .37692 Mdot
.802 .37697 Mdot
.802 .37698 Mdot
.802 .37718 Mdot
.802 .37728 Mdot
.802 .37753 Mdot
.802 .37753 Mdot
.802 .37756 Mdot
.802 .37767 Mdot
.802 .37775 Mdot
.802 .37779 Mdot
.802 .37789 Mdot
.802 .37794 Mdot
.802 .37805 Mdot
.802 .37823 Mdot
.802 .37826 Mdot
.802 .37832 Mdot
.802 .37834 Mdot
.802 .37839 Mdot
.802 .37848 Mdot
.802 .37864 Mdot
.802 .3787 Mdot
.802 .37883 Mdot
.802 .37886 Mdot
.802 .37888 Mdot
.802 .37901 Mdot
.802 .37906 Mdot
.802 .37906 Mdot
.802 .37947 Mdot
.802 .37961 Mdot
.802 .37994 Mdot
.802 .37995 Mdot
.802 .38004 Mdot
.802 .38008 Mdot
.802 .3802 Mdot
.802 .38025 Mdot
.802 .38041 Mdot
.802 .38054 Mdot
.802 .38054 Mdot
.802 .38063 Mdot
.802 .38064 Mdot
.802 .3811 Mdot
.802 .38159 Mdot
.802 .38196 Mdot
.802 .38197 Mdot
.802 .38247 Mdot
.802 .3825 Mdot
.802 .3825 Mdot
.802 .38277 Mdot
.802 .38279 Mdot
.802 .38282 Mdot
.802 .38283 Mdot
.802 .38303 Mdot
.802 .38303 Mdot
.802 .38306 Mdot
.802 .38316 Mdot
.802 .38347 Mdot
.802 .38361 Mdot
.802 .38395 Mdot
.802 .384 Mdot
.802 .3842 Mdot
.802 .38434 Mdot
.802 .38434 Mdot
.802 .38457 Mdot
.802 .38461 Mdot
.802 .38478 Mdot
.802 .38528 Mdot
.802 .38579 Mdot
.802 .38705 Mdot
.802 .3873 Mdot
.802 .38779 Mdot
.802 .38794 Mdot
.802 .388 Mdot
.802 .38803 Mdot
.802 .38852 Mdot
.802 .38856 Mdot
.802 .38897 Mdot
.802 .38926 Mdot
.802 .38933 Mdot
.802 .38938 Mdot
.802 .3894 Mdot
.802 .39007 Mdot
.802 .39008 Mdot
.802 .39012 Mdot
.802 .39015 Mdot
.802 .3902 Mdot
.802 .39025 Mdot
.802 .39075 Mdot
.802 .39075 Mdot
.802 .39083 Mdot
.802 .39086 Mdot
.802 .39099 Mdot
.802 .39099 Mdot
.802 .3911 Mdot
.802 .39177 Mdot
.802 .39189 Mdot
.802 .39226 Mdot
.802 .39233 Mdot
.802 .39251 Mdot
.802 .39259 Mdot
.802 .39275 Mdot
.802 .39311 Mdot
.802 .39326 Mdot
.802 .39327 Mdot
.802 .39339 Mdot
.802 .3934 Mdot
.802 .3935 Mdot
.802 .39377 Mdot
.802 .39382 Mdot
.802 .39412 Mdot
.802 .39413 Mdot
.802 .39413 Mdot
.802 .39414 Mdot
.802 .39472 Mdot
.802 .39481 Mdot
.802 .39525 Mdot
.802 .39574 Mdot
.802 .39648 Mdot
.802 .39653 Mdot
.802 .39654 Mdot
.802 .39654 Mdot
.802 .39655 Mdot
.802 .39695 Mdot
.802 .397 Mdot
.802 .39787 Mdot
.802 .39893 Mdot
.802 .39903 Mdot
.802 .39929 Mdot
.802 .39962 Mdot
.802 .39969 Mdot
.802 .40029 Mdot
.802 .40067 Mdot
.802 .40081 Mdot
.802 .4011 Mdot
.802 .40174 Mdot
.802 .40197 Mdot
.802 .40233 Mdot
.802 .403 Mdot
.802 .40329 Mdot
.802 .40338 Mdot
.802 .40355 Mdot
.802 .4036 Mdot
.802 .40362 Mdot
.802 .40366 Mdot
.802 .4047 Mdot
.802 .40487 Mdot
.802 .40499 Mdot
.802 .405 Mdot
.802 .40555 Mdot
.802 .40578 Mdot
.802 .40604 Mdot
.802 .40652 Mdot
.802 .4067 Mdot
.802 .40679 Mdot
.802 .40696 Mdot
.802 .4071 Mdot
.802 .40713 Mdot
.802 .40747 Mdot
.802 .40767 Mdot
.802 .40785 Mdot
.802 .40843 Mdot
.802 .40886 Mdot
.802 .4089 Mdot
.802 .40899 Mdot
.802 .40907 Mdot
.802 .40921 Mdot
.802 .40933 Mdot
.802 .40959 Mdot
.802 .40979 Mdot
.802 .41019 Mdot
.802 .41054 Mdot
.802 .41057 Mdot
.802 .41061 Mdot
.802 .41062 Mdot
.802 .41083 Mdot
.802 .4109 Mdot
.802 .41124 Mdot
.802 .41125 Mdot
.802 .41148 Mdot
.802 .41151 Mdot
.802 .4119 Mdot
.802 .4124 Mdot
.802 .41241 Mdot
.802 .41279 Mdot
.802 .41324 Mdot
.802 .41356 Mdot
.802 .41378 Mdot
.802 .41406 Mdot
.802 .41426 Mdot
.802 .41451 Mdot
.802 .41451 Mdot
.802 .41468 Mdot
.802 .41514 Mdot
.802 .41534 Mdot
.802 .41577 Mdot
.802 .41603 Mdot
.802 .41608 Mdot
.802 .4167 Mdot
.802 .41699 Mdot
.802 .41707 Mdot
.802 .41711 Mdot
.802 .41742 Mdot
.802 .41744 Mdot
.802 .4175 Mdot
.802 .41769 Mdot
.802 .41808 Mdot
.802 .41838 Mdot
.802 .41853 Mdot
.802 .41884 Mdot
.802 .4191 Mdot
.802 .41928 Mdot
.802 .4193 Mdot
.802 .41931 Mdot
.802 .41931 Mdot
.802 .41933 Mdot
.802 .41966 Mdot
.802 .41973 Mdot
.802 .42004 Mdot
.802 .42052 Mdot
.802 .42084 Mdot
.802 .42107 Mdot
.802 .42128 Mdot
.802 .42162 Mdot
.802 .42219 Mdot
.802 .42246 Mdot
.802 .42346 Mdot
.802 .4237 Mdot
.802 .42426 Mdot
.802 .42465 Mdot
.802 .42494 Mdot
.802 .42533 Mdot
.802 .42537 Mdot
.802 .42549 Mdot
.802 .42552 Mdot
.802 .42553 Mdot
.802 .42555 Mdot
.802 .42582 Mdot
.802 .42589 Mdot
.802 .42656 Mdot
.802 .4267 Mdot
.802 .4276 Mdot
.802 .42815 Mdot
.802 .42828 Mdot
.802 .42849 Mdot
.802 .42854 Mdot
.802 .42854 Mdot
.802 .42854 Mdot
.802 .42883 Mdot
.802 .42891 Mdot
.802 .42892 Mdot
.802 .42893 Mdot
.802 .42907 Mdot
.802 .42929 Mdot
.802 .42929 Mdot
.802 .42936 Mdot
.802 .42991 Mdot
.802 .43018 Mdot
.802 .43039 Mdot
.802 .43059 Mdot
.802 .43093 Mdot
.802 .43097 Mdot
.802 .43101 Mdot
.802 .43166 Mdot
.802 .43191 Mdot
.802 .43259 Mdot
.802 .43293 Mdot
.802 .43343 Mdot
.802 .43353 Mdot
.802 .43362 Mdot
.802 .43412 Mdot
.802 .43471 Mdot
.802 .43517 Mdot
.802 .43517 Mdot
.802 .43566 Mdot
.802 .43614 Mdot
.802 .43642 Mdot
.802 .43649 Mdot
.802 .43716 Mdot
.802 .43724 Mdot
.802 .43735 Mdot
.802 .43749 Mdot
.802 .43783 Mdot
.802 .43825 Mdot
.802 .43873 Mdot
.802 .43889 Mdot
.802 .43908 Mdot
.802 .43919 Mdot
.802 .43924 Mdot
.802 .43948 Mdot
.802 .43967 Mdot
.802 .43974 Mdot
.802 .44006 Mdot
.802 .44035 Mdot
.802 .44041 Mdot
.802 .44048 Mdot
.802 .44077 Mdot
.802 .44125 Mdot
.802 .44166 Mdot
.802 .44189 Mdot
.802 .44212 Mdot
.802 .44287 Mdot
.802 .4429 Mdot
.802 .44311 Mdot
.802 .4433 Mdot
.802 .44351 Mdot
.802 .44354 Mdot
.802 .44369 Mdot
.802 .44372 Mdot
.802 .44383 Mdot
.802 .44399 Mdot
.802 .4442 Mdot
.802 .44486 Mdot
.802 .44523 Mdot
.802 .44549 Mdot
.802 .44571 Mdot
.802 .4462 Mdot
.802 .44652 Mdot
.802 .44695 Mdot
.802 .44726 Mdot
.802 .44728 Mdot
.802 .44742 Mdot
.802 .4476 Mdot
.802 .4479 Mdot
.802 .44832 Mdot
.802 .4487 Mdot
.802 .44929 Mdot
.802 .44957 Mdot
.802 .44996 Mdot
.802 .4503 Mdot
.802 .45046 Mdot
.802 .45082 Mdot
.802 .45083 Mdot
.802 .4512 Mdot
.802 .45165 Mdot
.802 .45187 Mdot
.802 .45202 Mdot
.802 .45232 Mdot
.802 .45268 Mdot
.802 .45277 Mdot
.802 .4535 Mdot
.802 .45353 Mdot
.802 .45365 Mdot
.802 .45416 Mdot
.802 .45461 Mdot
.802 .45481 Mdot
.802 .45505 Mdot
.802 .45507 Mdot
.802 .4553 Mdot
.802 .45611 Mdot
.802 .45658 Mdot
.802 .45721 Mdot
.802 .45733 Mdot
.802 .45745 Mdot
.802 .45754 Mdot
.802 .45774 Mdot
.802 .45813 Mdot
.802 .45843 Mdot
.802 .45843 Mdot
.802 .4591 Mdot
.802 .45921 Mdot
.802 .45961 Mdot
.802 .45986 Mdot
.802 .46065 Mdot
.802 .46107 Mdot
.802 .46117 Mdot
.802 .46152 Mdot
.802 .46152 Mdot
.802 .46161 Mdot
.802 .46162 Mdot
.802 .46173 Mdot
.802 .46173 Mdot
.802 .46174 Mdot
.802 .46227 Mdot
.802 .46246 Mdot
.802 .46262 Mdot
.802 .46313 Mdot
.802 .46314 Mdot
.802 .46334 Mdot
.802 .46335 Mdot
.802 .46338 Mdot
.802 .46346 Mdot
.802 .46365 Mdot
.802 .46366 Mdot
.802 .46387 Mdot
.802 .46395 Mdot
.802 .46404 Mdot
.802 .46436 Mdot
.802 .46504 Mdot
.802 .46577 Mdot
.802 .46595 Mdot
.802 .46596 Mdot
.802 .46633 Mdot
.802 .46634 Mdot
.802 .46652 Mdot
.802 .46687 Mdot
.802 .46692 Mdot
.802 .46694 Mdot
.802 .46713 Mdot
.802 .46713 Mdot
.802 .46731 Mdot
.802 .46788 Mdot
.802 .46789 Mdot
.802 .4679 Mdot
.802 .4679 Mdot
.802 .46801 Mdot
.802 .46847 Mdot
.802 .46856 Mdot
.802 .4689 Mdot
.802 .4693 Mdot
.802 .46987 Mdot
.802 .46995 Mdot
.802 .47031 Mdot
.802 .47059 Mdot
.802 .47111 Mdot
.802 .4712 Mdot
.802 .47174 Mdot
.802 .47174 Mdot
.802 .47219 Mdot
.802 .47263 Mdot
.802 .47297 Mdot
.802 .47336 Mdot
.802 .47359 Mdot
.802 .47389 Mdot
.802 .47471 Mdot
.802 .47487 Mdot
.802 .47499 Mdot
.802 .47559 Mdot
.802 .47564 Mdot
.802 .47565 Mdot
.802 .47565 Mdot
.802 .47574 Mdot
.802 .47578 Mdot
.802 .47583 Mdot
.802 .47605 Mdot
.802 .47614 Mdot
.802 .47624 Mdot
.802 .47714 Mdot
.802 .47737 Mdot
.802 .4779 Mdot
.802 .47812 Mdot
.802 .47823 Mdot
.802 .47835 Mdot
.802 .47844 Mdot
.802 .47888 Mdot
.802 .47923 Mdot
.802 .47928 Mdot
.802 .47944 Mdot
.802 .47993 Mdot
.802 .48034 Mdot
.802 .48092 Mdot
.802 .48096 Mdot
.802 .4817 Mdot
.802 .48208 Mdot
.802 .48289 Mdot
.802 .48353 Mdot
.802 .48355 Mdot
.802 .48403 Mdot
.802 .48408 Mdot
.802 .48409 Mdot
.802 .48411 Mdot
.802 .48416 Mdot
.802 .48421 Mdot
.802 .485 Mdot
.802 .48518 Mdot
.802 .48568 Mdot
.802 .48599 Mdot
.802 .48657 Mdot
.802 .48711 Mdot
.802 .48721 Mdot
.802 .48769 Mdot
.804 .2009 Mdot
.804 .20111 Mdot
.804 .20121 Mdot
.804 .2017 Mdot
.804 .20293 Mdot
.804 .20428 Mdot
.804 .20448 Mdot
.804 .20511 Mdot
.804 .20567 Mdot
.804 .20618 Mdot
.804 .20647 Mdot
.804 .20682 Mdot
.804 .2071 Mdot
.804 .20711 Mdot
.804 .20777 Mdot
.804 .20832 Mdot
.804 .20896 Mdot
.804 .20924 Mdot
.804 .20948 Mdot
.804 .20995 Mdot
.804 .21038 Mdot
.804 .21107 Mdot
.804 .21162 Mdot
.804 .21163 Mdot
.804 .21206 Mdot
.804 .21273 Mdot
.804 .21289 Mdot
.804 .21333 Mdot
.804 .21357 Mdot
.804 .21406 Mdot
.804 .21448 Mdot
.804 .21477 Mdot
.804 .21526 Mdot
.804 .21537 Mdot
.804 .21569 Mdot
.804 .21577 Mdot
.804 .21588 Mdot
.804 .21652 Mdot
.804 .21766 Mdot
.804 .21879 Mdot
.804 .21899 Mdot
.804 .21938 Mdot
.804 .21994 Mdot
.804 .22025 Mdot
.804 .22046 Mdot
.804 .22076 Mdot
.804 .22195 Mdot
.804 .22225 Mdot
.804 .22362 Mdot
.804 .22373 Mdot
.804 .22429 Mdot
.804 .2246 Mdot
.804 .2249 Mdot
.804 .22551 Mdot
.804 .22609 Mdot
.804 .22621 Mdot
.804 .22626 Mdot
.804 .22683 Mdot
.804 .22692 Mdot
.804 .22695 Mdot
.804 .22729 Mdot
.804 .22771 Mdot
.804 .2279 Mdot
.804 .22815 Mdot
.804 .22822 Mdot
.804 .22897 Mdot
.804 .22936 Mdot
.804 .22955 Mdot
.804 .22958 Mdot
.804 .23185 Mdot
.804 .23187 Mdot
.804 .23189 Mdot
.804 .23204 Mdot
.804 .23208 Mdot
.804 .23399 Mdot
.804 .23451 Mdot
.804 .23518 Mdot
.804 .23635 Mdot
.804 .23666 Mdot
.804 .2368 Mdot
.804 .23781 Mdot
.804 .23788 Mdot
.804 .23823 Mdot
.804 .2384 Mdot
.804 .239 Mdot
.804 .23969 Mdot
.804 .23986 Mdot
.804 .23991 Mdot
.804 .24058 Mdot
.804 .24087 Mdot
.804 .24107 Mdot
.804 .24111 Mdot
.804 .24154 Mdot
.804 .24158 Mdot
.804 .2418 Mdot
.804 .24199 Mdot
.804 .24282 Mdot
.804 .24288 Mdot
.804 .24291 Mdot
.804 .24295 Mdot
.804 .24304 Mdot
.804 .24431 Mdot
.804 .24469 Mdot
.804 .24511 Mdot
.804 .24543 Mdot
.804 .24555 Mdot
.804 .24561 Mdot
.804 .24607 Mdot
.804 .24673 Mdot
.804 .24675 Mdot
.804 .24721 Mdot
.804 .24771 Mdot
.804 .24834 Mdot
.804 .24852 Mdot
.804 .24965 Mdot
.804 .24988 Mdot
.804 .2504 Mdot
.804 .25041 Mdot
.804 .25123 Mdot
.804 .25144 Mdot
.804 .25147 Mdot
.804 .25166 Mdot
.804 .25171 Mdot
.804 .25185 Mdot
.804 .25246 Mdot
.804 .25303 Mdot
.804 .25374 Mdot
.804 .25409 Mdot
.804 .25434 Mdot
.804 .25453 Mdot
.804 .25462 Mdot
.804 .25584 Mdot
.804 .25614 Mdot
.804 .25652 Mdot
.804 .25662 Mdot
.804 .25666 Mdot
.804 .25697 Mdot
.804 .25709 Mdot
.804 .25728 Mdot
.804 .25806 Mdot
.804 .25844 Mdot
.804 .25866 Mdot
.804 .25958 Mdot
.804 .25989 Mdot
.804 .25989 Mdot
.804 .2608 Mdot
.804 .2612 Mdot
.804 .26122 Mdot
.804 .26141 Mdot
.804 .2619 Mdot
.804 .26246 Mdot
.804 .26369 Mdot
.804 .2637 Mdot
.804 .2639 Mdot
.804 .26394 Mdot
.804 .26472 Mdot
.804 .26677 Mdot
.804 .26746 Mdot
.804 .26839 Mdot
.804 .26849 Mdot
.804 .26884 Mdot
.804 .26917 Mdot
.804 .26953 Mdot
.804 .26971 Mdot
.804 .26979 Mdot
.804 .2698 Mdot
.804 .27041 Mdot
.804 .27124 Mdot
.804 .27164 Mdot
.804 .27176 Mdot
.804 .27182 Mdot
.804 .27219 Mdot
.804 .27293 Mdot
.804 .27326 Mdot
.804 .27354 Mdot
.804 .27357 Mdot
.804 .27386 Mdot
.804 .27411 Mdot
.804 .27422 Mdot
.804 .27432 Mdot
.804 .27513 Mdot
.804 .27595 Mdot
.804 .27677 Mdot
.804 .27699 Mdot
.804 .27766 Mdot
.804 .27783 Mdot
.804 .27814 Mdot
.804 .27879 Mdot
.804 .28058 Mdot
.804 .28089 Mdot
.804 .28129 Mdot
.804 .28174 Mdot
.804 .28224 Mdot
.804 .28295 Mdot
.804 .28306 Mdot
.804 .28332 Mdot
.804 .2835 Mdot
.804 .28386 Mdot
.804 .28522 Mdot
.804 .28579 Mdot
.804 .28643 Mdot
.804 .2869 Mdot
.804 .28726 Mdot
.804 .28749 Mdot
.804 .28787 Mdot
.804 .28792 Mdot
.804 .28882 Mdot
.804 .28886 Mdot
.804 .28944 Mdot
.804 .28966 Mdot
.804 .2899 Mdot
.804 .29004 Mdot
.804 .29046 Mdot
.804 .29118 Mdot
.804 .29126 Mdot
.804 .29187 Mdot
.804 .29213 Mdot
.804 .29238 Mdot
.804 .2925 Mdot
.804 .29267 Mdot
.804 .29281 Mdot
.804 .2933 Mdot
.804 .29337 Mdot
.804 .29371 Mdot
.804 .29387 Mdot
.804 .29407 Mdot
.804 .29414 Mdot
.804 .2946 Mdot
.804 .29487 Mdot
.804 .29572 Mdot
.804 .29754 Mdot
.804 .29756 Mdot
.804 .29763 Mdot
.804 .29851 Mdot
.804 .29859 Mdot
.804 .29875 Mdot
.804 .29906 Mdot
.804 .29957 Mdot
.804 .30008 Mdot
.804 .30055 Mdot
.804 .30082 Mdot
.804 .30134 Mdot
.804 .30146 Mdot
.804 .30224 Mdot
.804 .30312 Mdot
.804 .30356 Mdot
.804 .30381 Mdot
.804 .30385 Mdot
.804 .30388 Mdot
.804 .30405 Mdot
.804 .30451 Mdot
.804 .30545 Mdot
.804 .30545 Mdot
.804 .30567 Mdot
.804 .3061 Mdot
.804 .30628 Mdot
.804 .30637 Mdot
.804 .30648 Mdot
.804 .30673 Mdot
.804 .30695 Mdot
.804 .3072 Mdot
.804 .3072 Mdot
.804 .30731 Mdot
.804 .30745 Mdot
.804 .30797 Mdot
.804 .30822 Mdot
.804 .30829 Mdot
.804 .30929 Mdot
.804 .30948 Mdot
.804 .3096 Mdot
.804 .30987 Mdot
.804 .31058 Mdot
.804 .31164 Mdot
.804 .31183 Mdot
.804 .31346 Mdot
.804 .31411 Mdot
.804 .31437 Mdot
.804 .31443 Mdot
.804 .3146 Mdot
.804 .31469 Mdot
.804 .31504 Mdot
.804 .31516 Mdot
.804 .31539 Mdot
.804 .31671 Mdot
.804 .31679 Mdot
.804 .31694 Mdot
.804 .31728 Mdot
.804 .31736 Mdot
.804 .31747 Mdot
.804 .31862 Mdot
.804 .31896 Mdot
.804 .31907 Mdot
.804 .31954 Mdot
.804 .31958 Mdot
.804 .3196 Mdot
.804 .31986 Mdot
.804 .31987 Mdot
.804 .32 Mdot
.804 .32016 Mdot
.804 .32023 Mdot
.804 .32036 Mdot
.804 .32087 Mdot
.804 .32177 Mdot
.804 .32178 Mdot
.804 .32259 Mdot
.804 .32279 Mdot
.804 .32305 Mdot
.804 .3235 Mdot
.804 .32362 Mdot
.804 .32407 Mdot
.804 .32409 Mdot
.804 .32423 Mdot
.804 .3243 Mdot
.804 .32486 Mdot
.804 .32488 Mdot
.804 .32514 Mdot
.804 .32534 Mdot
.804 .32551 Mdot
.804 .32561 Mdot
.804 .326 Mdot
.804 .32604 Mdot
.804 .32606 Mdot
.804 .32706 Mdot
.804 .32708 Mdot
.804 .32752 Mdot
.804 .3277 Mdot
.804 .3279 Mdot
.804 .32865 Mdot
.804 .32873 Mdot
.804 .32894 Mdot
.804 .32926 Mdot
.804 .32934 Mdot
.804 .32942 Mdot
.804 .32944 Mdot
.804 .33023 Mdot
.804 .33036 Mdot
.804 .33046 Mdot
.804 .33104 Mdot
.804 .33116 Mdot
.804 .3313 Mdot
.804 .33134 Mdot
.804 .33136 Mdot
.804 .3316 Mdot
.804 .33204 Mdot
.804 .33261 Mdot
.804 .33261 Mdot
.804 .33311 Mdot
.804 .33312 Mdot
.804 .33319 Mdot
.804 .33338 Mdot
.804 .33408 Mdot
.804 .33408 Mdot
.804 .33416 Mdot
.804 .33448 Mdot
.804 .33527 Mdot
.804 .33593 Mdot
.804 .33619 Mdot
.804 .3364 Mdot
.804 .33643 Mdot
.804 .33667 Mdot
.804 .337 Mdot
.804 .3372 Mdot
.804 .33722 Mdot
.804 .33736 Mdot
.804 .33778 Mdot
.804 .33789 Mdot
.804 .3379 Mdot
.804 .33801 Mdot
.804 .33815 Mdot
.804 .33819 Mdot
.804 .33913 Mdot
.804 .33922 Mdot
.804 .33948 Mdot
.804 .33954 Mdot
.804 .33967 Mdot
.804 .33991 Mdot
.804 .34073 Mdot
.804 .3408 Mdot
.804 .34088 Mdot
.804 .34106 Mdot
.804 .34153 Mdot
.804 .34167 Mdot
.804 .34188 Mdot
.804 .34287 Mdot
.804 .34305 Mdot
.804 .34319 Mdot
.804 .34328 Mdot
.804 .34343 Mdot
.804 .3438 Mdot
.804 .34381 Mdot
.804 .34403 Mdot
.804 .34412 Mdot
.804 .34421 Mdot
.804 .34443 Mdot
.804 .34471 Mdot
.804 .34474 Mdot
.804 .34497 Mdot
.804 .34522 Mdot
.804 .34534 Mdot
.804 .34555 Mdot
.804 .34569 Mdot
.804 .34575 Mdot
.804 .34603 Mdot
.804 .34717 Mdot
.804 .34717 Mdot
.804 .34754 Mdot
.804 .34795 Mdot
.804 .34833 Mdot
.804 .34843 Mdot
.804 .34864 Mdot
.804 .34868 Mdot
.804 .34932 Mdot
.804 .3495 Mdot
.804 .34962 Mdot
.804 .35023 Mdot
.804 .35031 Mdot
.804 .35048 Mdot
.804 .35058 Mdot
.804 .35063 Mdot
.804 .35072 Mdot
.804 .35081 Mdot
.804 .3509 Mdot
.804 .35095 Mdot
.804 .3512 Mdot
.804 .3513 Mdot
.804 .35133 Mdot
.804 .35171 Mdot
.804 .35179 Mdot
.804 .35183 Mdot
.804 .35221 Mdot
.804 .3527 Mdot
.804 .35332 Mdot
.804 .35368 Mdot
.804 .3538 Mdot
.804 .35394 Mdot
.804 .35398 Mdot
.804 .35458 Mdot
.804 .35461 Mdot
.804 .3548 Mdot
.804 .35488 Mdot
.804 .35532 Mdot
.804 .3558 Mdot
.804 .35585 Mdot
.804 .35592 Mdot
.804 .35594 Mdot
.804 .35599 Mdot
.804 .35654 Mdot
.804 .35721 Mdot
.804 .35752 Mdot
.804 .35773 Mdot
.804 .35774 Mdot
.804 .35792 Mdot
.804 .35802 Mdot
.804 .35883 Mdot
.804 .35923 Mdot
.804 .35931 Mdot
.804 .35943 Mdot
.804 .35986 Mdot
.804 .36012 Mdot
.804 .36017 Mdot
.804 .36023 Mdot
.804 .36034 Mdot
.804 .36073 Mdot
.804 .36092 Mdot
.804 .3613 Mdot
.804 .36221 Mdot
.804 .36251 Mdot
.804 .36339 Mdot
.804 .36341 Mdot
.804 .36346 Mdot
.804 .36387 Mdot
.804 .3639 Mdot
.804 .36393 Mdot
.804 .36418 Mdot
.804 .36423 Mdot
.804 .36431 Mdot
.804 .36491 Mdot
.804 .36515 Mdot
.804 .36518 Mdot
.804 .36522 Mdot
.804 .36542 Mdot
.804 .36551 Mdot
.804 .36579 Mdot
.804 .36581 Mdot
.804 .36636 Mdot
.804 .36651 Mdot
.804 .36681 Mdot
.804 .36695 Mdot
.804 .36719 Mdot
.804 .36726 Mdot
.804 .36731 Mdot
.804 .36758 Mdot
.804 .36764 Mdot
.804 .36781 Mdot
.804 .36782 Mdot
.804 .36797 Mdot
.804 .36815 Mdot
.804 .36874 Mdot
.804 .36893 Mdot
.804 .36923 Mdot
.804 .36972 Mdot
.804 .37045 Mdot
.804 .37045 Mdot
.804 .3711 Mdot
.804 .37137 Mdot
.804 .37161 Mdot
.804 .37183 Mdot
.804 .3723 Mdot
.804 .37263 Mdot
.804 .37299 Mdot
.804 .37322 Mdot
.804 .37332 Mdot
.804 .37334 Mdot
.804 .37342 Mdot
.804 .37346 Mdot
.804 .37356 Mdot
.804 .37357 Mdot
.804 .37401 Mdot
.804 .37411 Mdot
.804 .37413 Mdot
.804 .37425 Mdot
.804 .37434 Mdot
.804 .37435 Mdot
.804 .37441 Mdot
.804 .37478 Mdot
.804 .37536 Mdot
.804 .37537 Mdot
.804 .37572 Mdot
.804 .37608 Mdot
.804 .37621 Mdot
.804 .37647 Mdot
.804 .37674 Mdot
.804 .37678 Mdot
.804 .37684 Mdot
.804 .37687 Mdot
.804 .37687 Mdot
.804 .37704 Mdot
.804 .37727 Mdot
.804 .37754 Mdot
.804 .37785 Mdot
.804 .37791 Mdot
.804 .378 Mdot
.804 .37811 Mdot
.804 .37823 Mdot
.804 .37837 Mdot
.804 .37861 Mdot
.804 .37869 Mdot
.804 .37875 Mdot
.804 .37885 Mdot
.804 .37904 Mdot
.804 .37921 Mdot
.804 .37935 Mdot
.804 .37946 Mdot
.804 .37946 Mdot
.804 .37951 Mdot
.804 .37987 Mdot
.804 .37995 Mdot
.804 .38017 Mdot
.804 .38039 Mdot
.804 .38076 Mdot
.804 .38102 Mdot
.804 .38103 Mdot
.804 .38108 Mdot
.804 .38118 Mdot
.804 .38124 Mdot
.804 .38151 Mdot
.804 .3816 Mdot
.804 .38165 Mdot
.804 .38167 Mdot
.804 .38172 Mdot
.804 .38187 Mdot
.804 .38209 Mdot
.804 .3823 Mdot
.804 .38288 Mdot
.804 .38345 Mdot
.804 .38345 Mdot
.804 .3839 Mdot
.804 .3844 Mdot
.804 .38451 Mdot
.804 .38499 Mdot
.804 .38508 Mdot
.804 .38509 Mdot
.804 .3852 Mdot
.804 .38524 Mdot
.804 .38543 Mdot
.804 .38547 Mdot
.804 .38563 Mdot
.804 .38571 Mdot
.804 .3859 Mdot
.804 .38599 Mdot
.804 .38633 Mdot
.804 .38635 Mdot
.804 .38652 Mdot
.804 .38658 Mdot
.804 .3867 Mdot
.804 .38673 Mdot
.804 .38675 Mdot
.804 .38689 Mdot
.804 .38727 Mdot
.804 .3878 Mdot
.804 .38783 Mdot
.804 .38784 Mdot
.804 .38839 Mdot
.804 .38857 Mdot
.804 .38914 Mdot
.804 .38937 Mdot
.804 .3895 Mdot
.804 .38974 Mdot
.804 .38987 Mdot
.804 .3903 Mdot
.804 .39038 Mdot
.804 .39067 Mdot
.804 .39135 Mdot
.804 .39136 Mdot
.804 .39249 Mdot
.804 .39253 Mdot
.804 .39286 Mdot
.804 .39332 Mdot
.804 .39369 Mdot
.804 .39372 Mdot
.804 .3938 Mdot
.804 .3941 Mdot
.804 .39503 Mdot
.804 .39506 Mdot
.804 .39534 Mdot
.804 .39536 Mdot
.804 .39542 Mdot
.804 .39558 Mdot
.804 .39561 Mdot
.804 .39572 Mdot
.804 .3958 Mdot
.804 .39587 Mdot
.804 .39597 Mdot
.804 .39603 Mdot
.804 .3964 Mdot
.804 .39648 Mdot
.804 .39659 Mdot
.804 .39699 Mdot
.804 .39701 Mdot
.804 .3972 Mdot
.804 .3977 Mdot
.804 .39792 Mdot
.804 .39793 Mdot
.804 .39881 Mdot
.804 .39885 Mdot
.804 .39907 Mdot
.804 .39929 Mdot
.804 .39944 Mdot
.804 .39963 Mdot
.804 .39977 Mdot
.804 .39982 Mdot
.804 .39988 Mdot
.804 .40003 Mdot
.804 .40025 Mdot
.804 .40035 Mdot
.804 .40049 Mdot
.804 .40122 Mdot
.804 .40135 Mdot
.804 .40144 Mdot
.804 .40184 Mdot
.804 .40189 Mdot
.804 .40193 Mdot
.804 .40244 Mdot
.804 .40259 Mdot
.804 .40267 Mdot
.804 .40271 Mdot
.804 .40292 Mdot
.804 .40354 Mdot
.804 .40369 Mdot
.804 .40377 Mdot
.804 .40412 Mdot
.804 .40425 Mdot
.804 .40445 Mdot
.804 .4046 Mdot
.804 .40475 Mdot
.804 .40602 Mdot
.804 .40607 Mdot
.804 .40662 Mdot
.804 .40667 Mdot
.804 .40698 Mdot
.804 .40698 Mdot
.804 .40761 Mdot
.804 .40779 Mdot
.804 .40789 Mdot
.804 .40796 Mdot
.804 .40838 Mdot
.804 .40846 Mdot
.804 .40895 Mdot
.804 .40896 Mdot
.804 .40907 Mdot
.804 .40926 Mdot
.804 .40939 Mdot
.804 .41003 Mdot
.804 .41042 Mdot
.804 .41106 Mdot
.804 .41109 Mdot
.804 .41134 Mdot
.804 .4114 Mdot
.804 .4115 Mdot
.804 .41179 Mdot
.804 .4118 Mdot
.804 .41215 Mdot
.804 .41219 Mdot
.804 .41265 Mdot
.804 .41309 Mdot
.804 .41372 Mdot
.804 .4146 Mdot
.804 .41468 Mdot
.804 .41472 Mdot
.804 .41482 Mdot
.804 .41491 Mdot
.804 .41507 Mdot
.804 .41508 Mdot
.804 .4154 Mdot
.804 .41547 Mdot
.804 .41568 Mdot
.804 .4164 Mdot
.804 .41652 Mdot
.804 .41673 Mdot
.804 .41682 Mdot
.804 .41687 Mdot
.804 .41784 Mdot
.804 .41791 Mdot
.804 .41812 Mdot
.804 .41833 Mdot
.804 .41889 Mdot
.804 .4199 Mdot
.804 .42003 Mdot
.804 .42069 Mdot
.804 .42112 Mdot
.804 .42129 Mdot
.804 .42137 Mdot
.804 .42148 Mdot
.804 .4221 Mdot
.804 .42215 Mdot
.804 .4223 Mdot
.804 .42263 Mdot
.804 .42272 Mdot
.804 .42278 Mdot
.804 .42279 Mdot
.804 .42294 Mdot
.804 .42308 Mdot
.804 .42323 Mdot
.804 .4233 Mdot
.804 .42335 Mdot
.804 .42347 Mdot
.804 .42374 Mdot
.804 .42387 Mdot
.804 .42387 Mdot
.804 .42446 Mdot
.804 .42475 Mdot
.804 .42485 Mdot
.804 .42487 Mdot
.804 .42489 Mdot
.804 .42505 Mdot
.804 .42532 Mdot
.804 .42587 Mdot
.804 .42635 Mdot
.804 .42643 Mdot
.804 .42675 Mdot
.804 .42692 Mdot
.804 .42721 Mdot
.804 .42753 Mdot
.804 .42785 Mdot
.804 .42804 Mdot
.804 .42814 Mdot
.804 .42819 Mdot
.804 .42874 Mdot
.804 .42878 Mdot
.804 .42879 Mdot
.804 .42993 Mdot
.804 .43045 Mdot
.804 .43062 Mdot
.804 .4309 Mdot
.804 .43095 Mdot
.804 .43108 Mdot
.804 .43117 Mdot
.804 .43139 Mdot
.804 .43143 Mdot
.804 .43173 Mdot
.804 .43182 Mdot
.804 .43193 Mdot
.804 .432 Mdot
.804 .43215 Mdot
.804 .43232 Mdot
.804 .4327 Mdot
.804 .43274 Mdot
.804 .4332 Mdot
.804 .43345 Mdot
.804 .43355 Mdot
.804 .43369 Mdot
.804 .43383 Mdot
.804 .43419 Mdot
.804 .43421 Mdot
.804 .43478 Mdot
.804 .43481 Mdot
.804 .43504 Mdot
.804 .43518 Mdot
.804 .43541 Mdot
.804 .4357 Mdot
.804 .4361 Mdot
.804 .43645 Mdot
.804 .4373 Mdot
.804 .43752 Mdot
.804 .43763 Mdot
.804 .4378 Mdot
.804 .43786 Mdot
.804 .4383 Mdot
.804 .43862 Mdot
.804 .4389 Mdot
.804 .43903 Mdot
.804 .43914 Mdot
.804 .43934 Mdot
.804 .44045 Mdot
.804 .44086 Mdot
.804 .44105 Mdot
.804 .44116 Mdot
.804 .44157 Mdot
.804 .44171 Mdot
.804 .44222 Mdot
.804 .44273 Mdot
.804 .44323 Mdot
.804 .44329 Mdot
.804 .44336 Mdot
.804 .44352 Mdot
.804 .4437 Mdot
.804 .44372 Mdot
.804 .44389 Mdot
.804 .4441 Mdot
.804 .44456 Mdot
.804 .44479 Mdot
.804 .44482 Mdot
.804 .4449 Mdot
.804 .44515 Mdot
.804 .44566 Mdot
.804 .44604 Mdot
.804 .44605 Mdot
.804 .4461 Mdot
.804 .44621 Mdot
.804 .44644 Mdot
.804 .44664 Mdot
.804 .44686 Mdot
.804 .44692 Mdot
.804 .4475 Mdot
.804 .44793 Mdot
.804 .4492 Mdot
.804 .44969 Mdot
.804 .44971 Mdot
.804 .44984 Mdot
.804 .44984 Mdot
.804 .45061 Mdot
.804 .45095 Mdot
.804 .45126 Mdot
.804 .45138 Mdot
.804 .45139 Mdot
.804 .45164 Mdot
.804 .4522 Mdot
.804 .45221 Mdot
.804 .4524 Mdot
.804 .45297 Mdot
.804 .45311 Mdot
.804 .45334 Mdot
.804 .45383 Mdot
.804 .45395 Mdot
.804 .45402 Mdot
.804 .45421 Mdot
.804 .45424 Mdot
.804 .4543 Mdot
.804 .45454 Mdot
.804 .45473 Mdot
.804 .45548 Mdot
.804 .45554 Mdot
.804 .45566 Mdot
.804 .45581 Mdot
.804 .45603 Mdot
.804 .45647 Mdot
.804 .45682 Mdot
.804 .45721 Mdot
.804 .45729 Mdot
.804 .45733 Mdot
.804 .45744 Mdot
.804 .45746 Mdot
.804 .45759 Mdot
.804 .4581 Mdot
.804 .45811 Mdot
.804 .45843 Mdot
.804 .45857 Mdot
.804 .45928 Mdot
.804 .45939 Mdot
.804 .45978 Mdot
.804 .46009 Mdot
.804 .46038 Mdot
.804 .46039 Mdot
.804 .4608 Mdot
.804 .46109 Mdot
.804 .46112 Mdot
.804 .4612 Mdot
.804 .4614 Mdot
.804 .46166 Mdot
.804 .46189 Mdot
.804 .46268 Mdot
.804 .46274 Mdot
.804 .46277 Mdot
.804 .46278 Mdot
.804 .46282 Mdot
.804 .46334 Mdot
.804 .46346 Mdot
.804 .46359 Mdot
.804 .46362 Mdot
.804 .46389 Mdot
.804 .46391 Mdot
.804 .46403 Mdot
.804 .46421 Mdot
.804 .46463 Mdot
.804 .46466 Mdot
.804 .46477 Mdot
.804 .4652 Mdot
.804 .46557 Mdot
.804 .46567 Mdot
.804 .46589 Mdot
.804 .46594 Mdot
.804 .46657 Mdot
.804 .46665 Mdot
.804 .46684 Mdot
.804 .46757 Mdot
.804 .46799 Mdot
.804 .46831 Mdot
.804 .4695 Mdot
.804 .46952 Mdot
.804 .46962 Mdot
.804 .46963 Mdot
.804 .46964 Mdot
.804 .47105 Mdot
.804 .47107 Mdot
.804 .47119 Mdot
.804 .47144 Mdot
.804 .4719 Mdot
.804 .47194 Mdot
.804 .4721 Mdot
.804 .47222 Mdot
.804 .47248 Mdot
.804 .47269 Mdot
.804 .47271 Mdot
.804 .47276 Mdot
.804 .47312 Mdot
.804 .47315 Mdot
.804 .47322 Mdot
.804 .47359 Mdot
.804 .47396 Mdot
.804 .47415 Mdot
.804 .47434 Mdot
.804 .4747 Mdot
.804 .47476 Mdot
.804 .47561 Mdot
.804 .4758 Mdot
.804 .47654 Mdot
.804 .47673 Mdot
.804 .47686 Mdot
.804 .47705 Mdot
.804 .4774 Mdot
.804 .47764 Mdot
.804 .47776 Mdot
.804 .47847 Mdot
.804 .47918 Mdot
.804 .47958 Mdot
.804 .47964 Mdot
.804 .47969 Mdot
.804 .47989 Mdot
.804 .47996 Mdot
.804 .48027 Mdot
.804 .48045 Mdot
.804 .4807 Mdot
.804 .48101 Mdot
.804 .48116 Mdot
.804 .48143 Mdot
.804 .48154 Mdot
.804 .48195 Mdot
.804 .48222 Mdot
.804 .48222 Mdot
.804 .48256 Mdot
.804 .483 Mdot
.804 .48327 Mdot
.804 .48356 Mdot
.804 .4837 Mdot
.804 .48388 Mdot
.804 .48427 Mdot
.804 .48462 Mdot
.804 .48503 Mdot
.804 .48504 Mdot
.804 .48521 Mdot
.804 .48543 Mdot
.804 .48561 Mdot
.804 .48593 Mdot
.804 .48627 Mdot
.804 .48667 Mdot
.804 .48679 Mdot
.804 .48763 Mdot
.804 .48839 Mdot
.804 .4887 Mdot
.804 .48876 Mdot
.804 .48889 Mdot
.806 .1997 Mdot
.806 .19983 Mdot
.806 .2004 Mdot
.806 .2004 Mdot
.806 .20213 Mdot
.806 .20389 Mdot
.806 .20421 Mdot
.806 .20438 Mdot
.806 .20462 Mdot
.806 .20465 Mdot
.806 .2053 Mdot
.806 .20538 Mdot
.806 .20585 Mdot
.806 .20586 Mdot
.806 .20595 Mdot
.806 .20702 Mdot
.806 .20724 Mdot
.806 .20757 Mdot
.806 .20811 Mdot
.806 .20847 Mdot
.806 .20858 Mdot
.806 .21012 Mdot
.806 .21013 Mdot
.806 .21043 Mdot
.806 .21048 Mdot
.806 .21052 Mdot
.806 .21106 Mdot
.806 .21109 Mdot
.806 .21179 Mdot
.806 .21319 Mdot
.806 .21417 Mdot
.806 .21486 Mdot
.806 .21562 Mdot
.806 .2157 Mdot
.806 .21645 Mdot
.806 .21659 Mdot
.806 .21726 Mdot
.806 .21741 Mdot
.806 .21775 Mdot
.806 .22007 Mdot
.806 .22017 Mdot
.806 .22058 Mdot
.806 .2207 Mdot
.806 .22094 Mdot
.806 .22109 Mdot
.806 .22179 Mdot
.806 .22264 Mdot
.806 .22322 Mdot
.806 .22365 Mdot
.806 .22419 Mdot
.806 .22435 Mdot
.806 .22465 Mdot
.806 .22511 Mdot
.806 .22517 Mdot
.806 .2256 Mdot
.806 .22575 Mdot
.806 .22647 Mdot
.806 .22716 Mdot
.806 .22793 Mdot
.806 .22802 Mdot
.806 .22817 Mdot
.806 .22818 Mdot
.806 .22831 Mdot
.806 .22885 Mdot
.806 .22935 Mdot
.806 .23027 Mdot
.806 .23033 Mdot
.806 .23097 Mdot
.806 .23101 Mdot
.806 .23117 Mdot
.806 .23136 Mdot
.806 .23141 Mdot
.806 .23174 Mdot
.806 .232 Mdot
.806 .23208 Mdot
.806 .23247 Mdot
.806 .23259 Mdot
.806 .23272 Mdot
.806 .23334 Mdot
.806 .23337 Mdot
.806 .23346 Mdot
.806 .23362 Mdot
.806 .23374 Mdot
.806 .23533 Mdot
.806 .23536 Mdot
.806 .236 Mdot
.806 .23734 Mdot
.806 .23775 Mdot
.806 .23823 Mdot
.806 .23915 Mdot
.806 .23932 Mdot
.806 .23983 Mdot
.806 .24032 Mdot
.806 .24052 Mdot
.806 .24087 Mdot
.806 .24107 Mdot
.806 .24158 Mdot
.806 .24183 Mdot
.806 .242 Mdot
.806 .24205 Mdot
.806 .2421 Mdot
.806 .2428 Mdot
.806 .24284 Mdot
.806 .24377 Mdot
.806 .2438 Mdot
.806 .24428 Mdot
.806 .24476 Mdot
.806 .24524 Mdot
.806 .24569 Mdot
.806 .24578 Mdot
.806 .24631 Mdot
.806 .24649 Mdot
.806 .24682 Mdot
.806 .2469 Mdot
.806 .24713 Mdot
.806 .24847 Mdot
.806 .24892 Mdot
.806 .24917 Mdot
.806 .2493 Mdot
.806 .24948 Mdot
.806 .24959 Mdot
.806 .2496 Mdot
.806 .24988 Mdot
.806 .25051 Mdot
.806 .2511 Mdot
.806 .2512 Mdot
.806 .25126 Mdot
.806 .25134 Mdot
.806 .25245 Mdot
.806 .25251 Mdot
.806 .25271 Mdot
.806 .25288 Mdot
.806 .25313 Mdot
.806 .2537 Mdot
.806 .25515 Mdot
.806 .25527 Mdot
.806 .25659 Mdot
.806 .25684 Mdot
.806 .25796 Mdot
.806 .25799 Mdot
.806 .25822 Mdot
.806 .25848 Mdot
.806 .25972 Mdot
.806 .26008 Mdot
.806 .2602 Mdot
.806 .2603 Mdot
.806 .26101 Mdot
.806 .26124 Mdot
.806 .26147 Mdot
.806 .26241 Mdot
.806 .26384 Mdot
.806 .26408 Mdot
.806 .26659 Mdot
.806 .26727 Mdot
.806 .26735 Mdot
.806 .26798 Mdot
.806 .26808 Mdot
.806 .26818 Mdot
.806 .26837 Mdot
.806 .26904 Mdot
.806 .26939 Mdot
.806 .26975 Mdot
.806 .27027 Mdot
.806 .2704 Mdot
.806 .27073 Mdot
.806 .27095 Mdot
.806 .27109 Mdot
.806 .27178 Mdot
.806 .27345 Mdot
.806 .27353 Mdot
.806 .27418 Mdot
.806 .27423 Mdot
.806 .27424 Mdot
.806 .27447 Mdot
.806 .2746 Mdot
.806 .27462 Mdot
.806 .2749 Mdot
.806 .27516 Mdot
.806 .27525 Mdot
.806 .27596 Mdot
.806 .27633 Mdot
.806 .27727 Mdot
.806 .27742 Mdot
.806 .27772 Mdot
.806 .2778 Mdot
.806 .27829 Mdot
.806 .27832 Mdot
.806 .27839 Mdot
.806 .27876 Mdot
.806 .27896 Mdot
.806 .27901 Mdot
.806 .27908 Mdot
.806 .2796 Mdot
.806 .27966 Mdot
.806 .28044 Mdot
.806 .28057 Mdot
.806 .28073 Mdot
.806 .28083 Mdot
.806 .28113 Mdot
.806 .28177 Mdot
.806 .28209 Mdot
.806 .2823 Mdot
.806 .28235 Mdot
.806 .28255 Mdot
.806 .28308 Mdot
.806 .28319 Mdot
.806 .28347 Mdot
.806 .28538 Mdot
.806 .28592 Mdot
.806 .28623 Mdot
.806 .28627 Mdot
.806 .28689 Mdot
.806 .28708 Mdot
.806 .28752 Mdot
.806 .28873 Mdot
.806 .28895 Mdot
.806 .28921 Mdot
.806 .28963 Mdot
.806 .2902 Mdot
.806 .29031 Mdot
.806 .29035 Mdot
.806 .29042 Mdot
.806 .29057 Mdot
.806 .29074 Mdot
.806 .29135 Mdot
.806 .29138 Mdot
.806 .2915 Mdot
.806 .29177 Mdot
.806 .29291 Mdot
.806 .29319 Mdot
.806 .29323 Mdot
.806 .2933 Mdot
.806 .29339 Mdot
.806 .29407 Mdot
.806 .29502 Mdot
.806 .29554 Mdot
.806 .2958 Mdot
.806 .29652 Mdot
.806 .2969 Mdot
.806 .29708 Mdot
.806 .29718 Mdot
.806 .29774 Mdot
.806 .29829 Mdot
.806 .29861 Mdot
.806 .29865 Mdot
.806 .29954 Mdot
.806 .29991 Mdot
.806 .30002 Mdot
.806 .30008 Mdot
.806 .30029 Mdot
.806 .30046 Mdot
.806 .30128 Mdot
.806 .30134 Mdot
.806 .30167 Mdot
.806 .30275 Mdot
.806 .30301 Mdot
.806 .30306 Mdot
.806 .30367 Mdot
.806 .30394 Mdot
.806 .30432 Mdot
.806 .30486 Mdot
.806 .30549 Mdot
.806 .30609 Mdot
.806 .30614 Mdot
.806 .30661 Mdot
.806 .30669 Mdot
.806 .3071 Mdot
.806 .30714 Mdot
.806 .30736 Mdot
.806 .3076 Mdot
.806 .30777 Mdot
.806 .3079 Mdot
.806 .30924 Mdot
.806 .30946 Mdot
.806 .30951 Mdot
.806 .31016 Mdot
.806 .31082 Mdot
.806 .31123 Mdot
.806 .31168 Mdot
.806 .31178 Mdot
.806 .31207 Mdot
.806 .31225 Mdot
.806 .31291 Mdot
.806 .31312 Mdot
.806 .31389 Mdot
.806 .31401 Mdot
.806 .31403 Mdot
.806 .31405 Mdot
.806 .31426 Mdot
.806 .31427 Mdot
.806 .31601 Mdot
.806 .31604 Mdot
.806 .3167 Mdot
.806 .31683 Mdot
.806 .31776 Mdot
.806 .31792 Mdot
.806 .31797 Mdot
.806 .31838 Mdot
.806 .31871 Mdot
.806 .31966 Mdot
.806 .31969 Mdot
.806 .31991 Mdot
.806 .32018 Mdot
.806 .32045 Mdot
.806 .32084 Mdot
.806 .32084 Mdot
.806 .32089 Mdot
.806 .3213 Mdot
.806 .32167 Mdot
.806 .32192 Mdot
.806 .32193 Mdot
.806 .32199 Mdot
.806 .32207 Mdot
.806 .32209 Mdot
.806 .32234 Mdot
.806 .32254 Mdot
.806 .32259 Mdot
.806 .32283 Mdot
.806 .32284 Mdot
.806 .32294 Mdot
.806 .32298 Mdot
.806 .32361 Mdot
.806 .32453 Mdot
.806 .32471 Mdot
.806 .32507 Mdot
.806 .32513 Mdot
.806 .32552 Mdot
.806 .32559 Mdot
.806 .32573 Mdot
.806 .3258 Mdot
.806 .32618 Mdot
.806 .32647 Mdot
.806 .32684 Mdot
.806 .32685 Mdot
.806 .32704 Mdot
.806 .32722 Mdot
.806 .32741 Mdot
.806 .32758 Mdot
.806 .32782 Mdot
.806 .32814 Mdot
.806 .32892 Mdot
.806 .32909 Mdot
.806 .32944 Mdot
.806 .32966 Mdot
.806 .3297 Mdot
.806 .32973 Mdot
.806 .33021 Mdot
.806 .33028 Mdot
.806 .33035 Mdot
.806 .33122 Mdot
.806 .33127 Mdot
.806 .33178 Mdot
.806 .3323 Mdot
.806 .3324 Mdot
.806 .33298 Mdot
.806 .3332 Mdot
.806 .33357 Mdot
.806 .33366 Mdot
.806 .33457 Mdot
.806 .33466 Mdot
.806 .33562 Mdot
.806 .33589 Mdot
.806 .33616 Mdot
.806 .33624 Mdot
.806 .33657 Mdot
.806 .3367 Mdot
.806 .33722 Mdot
.806 .33736 Mdot
.806 .3383 Mdot
.806 .33855 Mdot
.806 .33857 Mdot
.806 .33871 Mdot
.806 .33872 Mdot
.806 .33892 Mdot
.806 .33923 Mdot
.806 .33937 Mdot
.806 .33991 Mdot
.806 .33994 Mdot
.806 .34013 Mdot
.806 .34014 Mdot
.806 .34017 Mdot
.806 .3404 Mdot
.806 .34065 Mdot
.806 .34095 Mdot
.806 .34122 Mdot
.806 .34147 Mdot
.806 .34169 Mdot
.806 .34177 Mdot
.806 .34202 Mdot
.806 .34285 Mdot
.806 .34318 Mdot
.806 .3432 Mdot
.806 .34351 Mdot
.806 .34368 Mdot
.806 .34433 Mdot
.806 .34471 Mdot
.806 .34475 Mdot
.806 .34485 Mdot
.806 .34532 Mdot
.806 .34575 Mdot
.806 .34588 Mdot
.806 .3459 Mdot
.806 .3462 Mdot
.806 .34657 Mdot
.806 .34677 Mdot
.806 .34686 Mdot
.806 .34714 Mdot
.806 .34729 Mdot
.806 .34736 Mdot
.806 .3474 Mdot
.806 .34783 Mdot
.806 .34795 Mdot
.806 .34796 Mdot
.806 .34849 Mdot
.806 .34851 Mdot
.806 .34859 Mdot
.806 .34897 Mdot
.806 .34954 Mdot
.806 .34966 Mdot
.806 .3499 Mdot
.806 .35014 Mdot
.806 .3506 Mdot
.806 .35083 Mdot
.806 .35084 Mdot
.806 .35106 Mdot
.806 .35123 Mdot
.806 .35147 Mdot
.806 .35152 Mdot
.806 .35214 Mdot
.806 .35239 Mdot
.806 .35265 Mdot
.806 .35298 Mdot
.806 .35301 Mdot
.806 .35313 Mdot
.806 .3532 Mdot
.806 .35383 Mdot
.806 .35387 Mdot
.806 .35397 Mdot
.806 .35397 Mdot
.806 .35464 Mdot
.806 .35466 Mdot
.806 .35491 Mdot
.806 .35538 Mdot
.806 .3554 Mdot
.806 .35568 Mdot
.806 .35606 Mdot
.806 .35614 Mdot
.806 .3565 Mdot
.806 .35668 Mdot
.806 .35682 Mdot
.806 .35692 Mdot
.806 .35695 Mdot
.806 .35708 Mdot
.806 .35716 Mdot
.806 .35718 Mdot
.806 .35731 Mdot
.806 .35757 Mdot
.806 .3583 Mdot
.806 .35841 Mdot
.806 .35856 Mdot
.806 .35881 Mdot
.806 .35882 Mdot
.806 .35903 Mdot
.806 .35961 Mdot
.806 .35981 Mdot
.806 .3599 Mdot
.806 .36071 Mdot
.806 .36126 Mdot
.806 .36178 Mdot
.806 .36219 Mdot
.806 .36229 Mdot
.806 .3624 Mdot
.806 .36261 Mdot
.806 .36322 Mdot
.806 .36332 Mdot
.806 .36338 Mdot
.806 .36346 Mdot
.806 .36358 Mdot
.806 .36363 Mdot
.806 .36385 Mdot
.806 .36392 Mdot
.806 .36394 Mdot
.806 .36403 Mdot
.806 .36456 Mdot
.806 .36497 Mdot
.806 .3651 Mdot
.806 .36511 Mdot
.806 .36523 Mdot
.806 .36529 Mdot
.806 .36554 Mdot
.806 .3657 Mdot
.806 .36574 Mdot
.806 .36592 Mdot
.806 .36614 Mdot
.806 .36671 Mdot
.806 .36693 Mdot
.806 .36714 Mdot
.806 .36718 Mdot
.806 .36733 Mdot
.806 .36755 Mdot
.806 .36759 Mdot
.806 .36778 Mdot
.806 .36795 Mdot
.806 .36855 Mdot
.806 .36887 Mdot
.806 .36895 Mdot
.806 .3692 Mdot
.806 .36925 Mdot
.806 .37029 Mdot
.806 .37035 Mdot
.806 .37039 Mdot
.806 .3704 Mdot
.806 .37045 Mdot
.806 .37054 Mdot
.806 .37064 Mdot
.806 .37142 Mdot
.806 .3715 Mdot
.806 .37206 Mdot
.806 .37281 Mdot
.806 .37295 Mdot
.806 .37305 Mdot
.806 .37353 Mdot
.806 .37358 Mdot
.806 .37377 Mdot
.806 .37424 Mdot
.806 .37448 Mdot
.806 .37486 Mdot
.806 .37499 Mdot
.806 .37502 Mdot
.806 .37513 Mdot
.806 .37553 Mdot
.806 .37557 Mdot
.806 .37567 Mdot
.806 .376 Mdot
.806 .37621 Mdot
.806 .3765 Mdot
.806 .37678 Mdot
.806 .37687 Mdot
.806 .37714 Mdot
.806 .37755 Mdot
.806 .3776 Mdot
.806 .37773 Mdot
.806 .37806 Mdot
.806 .37817 Mdot
.806 .37839 Mdot
.806 .37856 Mdot
.806 .37872 Mdot
.806 .37896 Mdot
.806 .37921 Mdot
.806 .37927 Mdot
.806 .37948 Mdot
.806 .37959 Mdot
.806 .37985 Mdot
.806 .38002 Mdot
.806 .38042 Mdot
.806 .38056 Mdot
.806 .38076 Mdot
.806 .38082 Mdot
.806 .38084 Mdot
.806 .38109 Mdot
.806 .38118 Mdot
.806 .38126 Mdot
.806 .3815 Mdot
.806 .38194 Mdot
.806 .38208 Mdot
.806 .38238 Mdot
.806 .38245 Mdot
.806 .38253 Mdot
.806 .383 Mdot
.806 .38335 Mdot
.806 .38388 Mdot
.806 .38394 Mdot
.806 .384 Mdot
.806 .38404 Mdot
.806 .3841 Mdot
.806 .38474 Mdot
.806 .38478 Mdot
.806 .38493 Mdot
.806 .38498 Mdot
.806 .38518 Mdot
.806 .38555 Mdot
.806 .3858 Mdot
.806 .38618 Mdot
.806 .38632 Mdot
.806 .38694 Mdot
.806 .38704 Mdot
.806 .3872 Mdot
.806 .38724 Mdot
.806 .38732 Mdot
.806 .38805 Mdot
.806 .38809 Mdot
.806 .38826 Mdot
.806 .38833 Mdot
.806 .38848 Mdot
.806 .38886 Mdot
.806 .38899 Mdot
.806 .38937 Mdot
.806 .3897 Mdot
.806 .3906 Mdot
.806 .39072 Mdot
.806 .39153 Mdot
.806 .39199 Mdot
.806 .39215 Mdot
.806 .39225 Mdot
.806 .39229 Mdot
.806 .39238 Mdot
.806 .39239 Mdot
.806 .39245 Mdot
.806 .39254 Mdot
.806 .39265 Mdot
.806 .39287 Mdot
.806 .39316 Mdot
.806 .39334 Mdot
.806 .39335 Mdot
.806 .3938 Mdot
.806 .39422 Mdot
.806 .39431 Mdot
.806 .3947 Mdot
.806 .39481 Mdot
.806 .39484 Mdot
.806 .39536 Mdot
.806 .39577 Mdot
.806 .39592 Mdot
.806 .39603 Mdot
.806 .39616 Mdot
.806 .39631 Mdot
.806 .3966 Mdot
.806 .39689 Mdot
.806 .39697 Mdot
.806 .39732 Mdot
.806 .39756 Mdot
.806 .39762 Mdot
.806 .39795 Mdot
.806 .39796 Mdot
.806 .39803 Mdot
.806 .39832 Mdot
.806 .39837 Mdot
.806 .39863 Mdot
.806 .39904 Mdot
.806 .39924 Mdot
.806 .39959 Mdot
.806 .39988 Mdot
.806 .39994 Mdot
.806 .39997 Mdot
.806 .4002 Mdot
.806 .40061 Mdot
.806 .40071 Mdot
.806 .4009 Mdot
.806 .40091 Mdot
.806 .40112 Mdot
.806 .40179 Mdot
.806 .40184 Mdot
.806 .4023 Mdot
.806 .40248 Mdot
.806 .40264 Mdot
.806 .40279 Mdot
.806 .40281 Mdot
.806 .40293 Mdot
.806 .40328 Mdot
.806 .40337 Mdot
.806 .40356 Mdot
.806 .40368 Mdot
.806 .40379 Mdot
.806 .40395 Mdot
.806 .40461 Mdot
.806 .40493 Mdot
.806 .40502 Mdot
.806 .40527 Mdot
.806 .40544 Mdot
.806 .4056 Mdot
.806 .40626 Mdot
.806 .40682 Mdot
.806 .40688 Mdot
.806 .4071 Mdot
.806 .40724 Mdot
.806 .40766 Mdot
.806 .40799 Mdot
.806 .4093 Mdot
.806 .40944 Mdot
.806 .40966 Mdot
.806 .40976 Mdot
.806 .41025 Mdot
.806 .41044 Mdot
.806 .41059 Mdot
.806 .4107 Mdot
.806 .41104 Mdot
.806 .41105 Mdot
.806 .41146 Mdot
.806 .4117 Mdot
.806 .41174 Mdot
.806 .41187 Mdot
.806 .41211 Mdot
.806 .41249 Mdot
.806 .41306 Mdot
.806 .41347 Mdot
.806 .41369 Mdot
.806 .41372 Mdot
.806 .41384 Mdot
.806 .414 Mdot
.806 .41406 Mdot
.806 .41411 Mdot
.806 .41426 Mdot
.806 .41449 Mdot
.806 .41477 Mdot
.806 .41535 Mdot
.806 .41549 Mdot
.806 .41609 Mdot
.806 .4163 Mdot
.806 .41656 Mdot
.806 .41659 Mdot
.806 .41668 Mdot
.806 .41734 Mdot
.806 .41775 Mdot
.806 .41777 Mdot
.806 .41885 Mdot
.806 .41886 Mdot
.806 .41901 Mdot
.806 .41908 Mdot
.806 .4201 Mdot
.806 .42021 Mdot
.806 .4204 Mdot
.806 .42045 Mdot
.806 .42073 Mdot
.806 .42099 Mdot
.806 .4214 Mdot
.806 .4218 Mdot
.806 .42183 Mdot
.806 .42197 Mdot
.806 .4228 Mdot
.806 .42288 Mdot
.806 .42299 Mdot
.806 .42314 Mdot
.806 .42327 Mdot
.806 .42329 Mdot
.806 .42355 Mdot
.806 .4236 Mdot
.806 .4239 Mdot
.806 .42392 Mdot
.806 .42429 Mdot
.806 .42469 Mdot
.806 .42502 Mdot
.806 .42526 Mdot
.806 .42542 Mdot
.806 .4258 Mdot
.806 .42584 Mdot
.806 .426 Mdot
.806 .42667 Mdot
.806 .42687 Mdot
.806 .42691 Mdot
.806 .42742 Mdot
.806 .42752 Mdot
.806 .42765 Mdot
.806 .42769 Mdot
.806 .42776 Mdot
.806 .42799 Mdot
.806 .42854 Mdot
.806 .42856 Mdot
.806 .42876 Mdot
.806 .4291 Mdot
.806 .42945 Mdot
.806 .42951 Mdot
.806 .42963 Mdot
.806 .42986 Mdot
.806 .43031 Mdot
.806 .43047 Mdot
.806 .43079 Mdot
.806 .43138 Mdot
.806 .4318 Mdot
.806 .43186 Mdot
.806 .4319 Mdot
.806 .43193 Mdot
.806 .4321 Mdot
.806 .4328 Mdot
.806 .43297 Mdot
.806 .43305 Mdot
.806 .43307 Mdot
.806 .43345 Mdot
.806 .43355 Mdot
.806 .43365 Mdot
.806 .43369 Mdot
.806 .43371 Mdot
.806 .43378 Mdot
.806 .43413 Mdot
.806 .4344 Mdot
.806 .43456 Mdot
.806 .4347 Mdot
.806 .43544 Mdot
.806 .43572 Mdot
.806 .43584 Mdot
.806 .43622 Mdot
.806 .43625 Mdot
.806 .43644 Mdot
.806 .43677 Mdot
.806 .43795 Mdot
.806 .43813 Mdot
.806 .4382 Mdot
.806 .43853 Mdot
.806 .43865 Mdot
.806 .43868 Mdot
.806 .43881 Mdot
.806 .43901 Mdot
.806 .43941 Mdot
.806 .4396 Mdot
.806 .43965 Mdot
.806 .43976 Mdot
.806 .43984 Mdot
.806 .44032 Mdot
.806 .44036 Mdot
.806 .44068 Mdot
.806 .44072 Mdot
.806 .44075 Mdot
.806 .44088 Mdot
.806 .44111 Mdot
.806 .44115 Mdot
.806 .44117 Mdot
.806 .44147 Mdot
.806 .44152 Mdot
.806 .44171 Mdot
.806 .4418 Mdot
.806 .44239 Mdot
.806 .44262 Mdot
.806 .44306 Mdot
.806 .44311 Mdot
.806 .44327 Mdot
.806 .44344 Mdot
.806 .44346 Mdot
.806 .44354 Mdot
.806 .44368 Mdot
.806 .44369 Mdot
.806 .44372 Mdot
.806 .44412 Mdot
.806 .44417 Mdot
.806 .44521 Mdot
.806 .44564 Mdot
.806 .44573 Mdot
.806 .44586 Mdot
.806 .44607 Mdot
.806 .44615 Mdot
.806 .44647 Mdot
.806 .44669 Mdot
.806 .44691 Mdot
.806 .44733 Mdot
.806 .44744 Mdot
.806 .4475 Mdot
.806 .44756 Mdot
.806 .44795 Mdot
.806 .44801 Mdot
.806 .44843 Mdot
.806 .44999 Mdot
.806 .45014 Mdot
.806 .45102 Mdot
.806 .4516 Mdot
.806 .45175 Mdot
.806 .45189 Mdot
.806 .45233 Mdot
.806 .45239 Mdot
.806 .45246 Mdot
.806 .45269 Mdot
.806 .45346 Mdot
.806 .45362 Mdot
.806 .45376 Mdot
.806 .45378 Mdot
.806 .45448 Mdot
.806 .45463 Mdot
.806 .45545 Mdot
.806 .45552 Mdot
.806 .45642 Mdot
.806 .45678 Mdot
.806 .45694 Mdot
.806 .45704 Mdot
.806 .45716 Mdot
.806 .4572 Mdot
.806 .45789 Mdot
.806 .45794 Mdot
.806 .45798 Mdot
.806 .45804 Mdot
.806 .4584 Mdot
.806 .45879 Mdot
.806 .45897 Mdot
.806 .45897 Mdot
.806 .45904 Mdot
.806 .45915 Mdot
.806 .45924 Mdot
.806 .45939 Mdot
.806 .45967 Mdot
.806 .4605 Mdot
.806 .46064 Mdot
.806 .46069 Mdot
.806 .4609 Mdot
.806 .46101 Mdot
.806 .46133 Mdot
.806 .46139 Mdot
.806 .46167 Mdot
.806 .46197 Mdot
.806 .46227 Mdot
.806 .46257 Mdot
.806 .46259 Mdot
.806 .46316 Mdot
.806 .46319 Mdot
.806 .46362 Mdot
.806 .46365 Mdot
.806 .46368 Mdot
.806 .46379 Mdot
.806 .46394 Mdot
.806 .46426 Mdot
.806 .46438 Mdot
.806 .4646 Mdot
.806 .46472 Mdot
.806 .46503 Mdot
.806 .46534 Mdot
.806 .46545 Mdot
.806 .46602 Mdot
.806 .46632 Mdot
.806 .46657 Mdot
.806 .46741 Mdot
.806 .4678 Mdot
.806 .46782 Mdot
.806 .46881 Mdot
.806 .46888 Mdot
.806 .46898 Mdot
.806 .46904 Mdot
.806 .46905 Mdot
.806 .46944 Mdot
.806 .46952 Mdot
.806 .46959 Mdot
.806 .46984 Mdot
.806 .46989 Mdot
.806 .47005 Mdot
.806 .47025 Mdot
.806 .47029 Mdot
.806 .4704 Mdot
.806 .4705 Mdot
.806 .47053 Mdot
.806 .47092 Mdot
.806 .47096 Mdot
.806 .47153 Mdot
.806 .47184 Mdot
.806 .47217 Mdot
.806 .47226 Mdot
.806 .47226 Mdot
.806 .47236 Mdot
.806 .47241 Mdot
.806 .47289 Mdot
.806 .47332 Mdot
.806 .47376 Mdot
.806 .47386 Mdot
.806 .47412 Mdot
.806 .47416 Mdot
.806 .47445 Mdot
.806 .47463 Mdot
.806 .47473 Mdot
.806 .47506 Mdot
.806 .47533 Mdot
.806 .47569 Mdot
.806 .47622 Mdot
.806 .47665 Mdot
.806 .47675 Mdot
.806 .47689 Mdot
.806 .47697 Mdot
.806 .47723 Mdot
.806 .47728 Mdot
.806 .47872 Mdot
.806 .47893 Mdot
.806 .47903 Mdot
.806 .47944 Mdot
.806 .47953 Mdot
.806 .48 Mdot
.806 .48005 Mdot
.806 .48052 Mdot
.806 .48095 Mdot
.806 .48155 Mdot
.806 .48242 Mdot
.806 .48286 Mdot
.806 .48288 Mdot
.806 .48321 Mdot
.806 .48324 Mdot
.806 .48327 Mdot
.806 .48345 Mdot
.806 .48346 Mdot
.806 .48441 Mdot
.806 .48449 Mdot
.806 .48471 Mdot
.806 .48504 Mdot
.806 .48525 Mdot
.806 .48538 Mdot
.806 .48605 Mdot
.806 .4861 Mdot
.806 .48611 Mdot
.806 .4864 Mdot
.806 .48645 Mdot
.806 .48685 Mdot
.806 .48687 Mdot
.806 .48702 Mdot
.806 .48712 Mdot
.806 .48732 Mdot
.806 .48775 Mdot
.806 .48841 Mdot
.806 .48949 Mdot
.806 .48949 Mdot
.806 .48984 Mdot
.806 .48992 Mdot
.808 .19796 Mdot
.808 .19815 Mdot
.808 .19819 Mdot
.808 .19827 Mdot
.808 .19829 Mdot
.808 .19882 Mdot
.808 .19919 Mdot
.808 .19937 Mdot
.808 .20076 Mdot
.808 .20155 Mdot
.808 .20173 Mdot
.808 .20207 Mdot
.808 .20233 Mdot
.808 .20239 Mdot
.808 .20299 Mdot
.808 .20313 Mdot
.808 .20352 Mdot
.808 .20386 Mdot
.808 .20387 Mdot
.808 .20408 Mdot
.808 .20439 Mdot
.808 .20486 Mdot
.808 .2057 Mdot
.808 .20583 Mdot
.808 .20595 Mdot
.808 .20668 Mdot
.808 .20709 Mdot
.808 .20832 Mdot
.808 .20835 Mdot
.808 .20889 Mdot
.808 .20959 Mdot
.808 .21045 Mdot
.808 .21064 Mdot
.808 .21099 Mdot
.808 .21122 Mdot
.808 .2117 Mdot
.808 .21225 Mdot
.808 .21257 Mdot
.808 .21318 Mdot
.808 .21321 Mdot
.808 .21323 Mdot
.808 .21325 Mdot
.808 .2133 Mdot
.808 .21334 Mdot
.808 .21358 Mdot
.808 .21549 Mdot
.808 .21588 Mdot
.808 .21663 Mdot
.808 .21667 Mdot
.808 .21709 Mdot
.808 .21749 Mdot
.808 .21759 Mdot
.808 .21788 Mdot
.808 .21811 Mdot
.808 .21824 Mdot
.808 .21827 Mdot
.808 .21829 Mdot
.808 .21848 Mdot
.808 .21863 Mdot
.808 .21892 Mdot
.808 .21916 Mdot
.808 .2192 Mdot
.808 .21921 Mdot
.808 .21937 Mdot
.808 .21945 Mdot
.808 .21953 Mdot
.808 .22072 Mdot
.808 .22198 Mdot
.808 .22256 Mdot
.808 .22329 Mdot
.808 .22419 Mdot
.808 .22504 Mdot
.808 .22518 Mdot
.808 .22539 Mdot
.808 .22564 Mdot
.808 .22564 Mdot
.808 .22566 Mdot
.808 .22567 Mdot
.808 .22586 Mdot
.808 .22628 Mdot
.808 .22631 Mdot
.808 .2264 Mdot
.808 .22658 Mdot
.808 .22664 Mdot
.808 .22784 Mdot
.808 .22789 Mdot
.808 .22789 Mdot
.808 .22792 Mdot
.808 .22848 Mdot
.808 .22869 Mdot
.808 .22934 Mdot
.808 .22937 Mdot
.808 .22958 Mdot
.808 .22983 Mdot
.808 .22987 Mdot
.808 .23033 Mdot
.808 .23103 Mdot
.808 .23149 Mdot
.808 .23294 Mdot
.808 .23328 Mdot
.808 .2334 Mdot
.808 .23395 Mdot
.808 .23447 Mdot
.808 .23555 Mdot
.808 .2364 Mdot
.808 .2366 Mdot
.808 .23683 Mdot
.808 .23721 Mdot
.808 .23755 Mdot
.808 .23928 Mdot
.808 .23929 Mdot
.808 .23958 Mdot
.808 .24071 Mdot
.808 .24256 Mdot
.808 .24275 Mdot
.808 .24304 Mdot
.808 .24309 Mdot
.808 .24337 Mdot
.808 .24368 Mdot
.808 .24372 Mdot
.808 .24411 Mdot
.808 .24427 Mdot
.808 .24447 Mdot
.808 .24458 Mdot
.808 .2446 Mdot
.808 .24469 Mdot
.808 .24544 Mdot
.808 .24631 Mdot
.808 .24658 Mdot
.808 .24686 Mdot
.808 .24809 Mdot
.808 .24823 Mdot
.808 .2483 Mdot
.808 .24855 Mdot
.808 .2487 Mdot
.808 .24955 Mdot
.808 .24961 Mdot
.808 .24983 Mdot
.808 .2504 Mdot
.808 .25041 Mdot
.808 .25129 Mdot
.808 .25162 Mdot
.808 .25195 Mdot
.808 .25203 Mdot
.808 .25302 Mdot
.808 .25306 Mdot
.808 .25347 Mdot
.808 .25425 Mdot
.808 .25446 Mdot
.808 .25465 Mdot
.808 .25572 Mdot
.808 .25611 Mdot
.808 .25669 Mdot
.808 .2567 Mdot
.808 .25686 Mdot
.808 .25817 Mdot
.808 .25819 Mdot
.808 .25849 Mdot
.808 .25873 Mdot
.808 .25873 Mdot
.808 .25911 Mdot
.808 .25942 Mdot
.808 .26024 Mdot
.808 .2607 Mdot
.808 .26105 Mdot
.808 .26117 Mdot
.808 .26168 Mdot
.808 .26206 Mdot
.808 .26241 Mdot
.808 .26271 Mdot
.808 .26281 Mdot
.808 .26367 Mdot
.808 .26451 Mdot
.808 .2649 Mdot
.808 .26497 Mdot
.808 .2651 Mdot
.808 .2652 Mdot
.808 .26529 Mdot
.808 .26547 Mdot
.808 .26567 Mdot
.808 .26579 Mdot
.808 .26591 Mdot
.808 .26594 Mdot
.808 .26616 Mdot
.808 .26668 Mdot
.808 .26691 Mdot
.808 .26691 Mdot
.808 .26707 Mdot
.808 .26802 Mdot
.808 .26872 Mdot
.808 .26973 Mdot
.808 .27003 Mdot
.808 .27092 Mdot
.808 .27102 Mdot
.808 .27125 Mdot
.808 .27147 Mdot
.808 .27154 Mdot
.808 .27253 Mdot
.808 .27313 Mdot
.808 .27357 Mdot
.808 .27455 Mdot
.808 .27473 Mdot
.808 .27606 Mdot
.808 .27637 Mdot
.808 .2765 Mdot
.808 .27765 Mdot
.808 .27955 Mdot
.808 .27971 Mdot
.808 .28084 Mdot
.808 .28107 Mdot
.808 .28145 Mdot
.808 .28147 Mdot
.808 .28214 Mdot
.808 .28279 Mdot
.808 .28316 Mdot
.808 .28359 Mdot
.808 .2836 Mdot
.808 .28446 Mdot
.808 .28479 Mdot
.808 .28483 Mdot
.808 .2856 Mdot
.808 .28577 Mdot
.808 .28635 Mdot
.808 .28644 Mdot
.808 .28656 Mdot
.808 .28657 Mdot
.808 .28736 Mdot
.808 .28799 Mdot
.808 .28892 Mdot
.808 .28907 Mdot
.808 .2892 Mdot
.808 .28954 Mdot
.808 .29019 Mdot
.808 .29037 Mdot
.808 .29043 Mdot
.808 .29111 Mdot
.808 .29144 Mdot
.808 .29173 Mdot
.808 .29177 Mdot
.808 .29195 Mdot
.808 .2921 Mdot
.808 .29211 Mdot
.808 .29325 Mdot
.808 .29482 Mdot
.808 .29678 Mdot
.808 .29742 Mdot
.808 .29759 Mdot
.808 .29816 Mdot
.808 .29818 Mdot
.808 .29873 Mdot
.808 .29877 Mdot
.808 .29878 Mdot
.808 .29902 Mdot
.808 .29925 Mdot
.808 .29992 Mdot
.808 .30136 Mdot
.808 .30149 Mdot
.808 .30151 Mdot
.808 .30185 Mdot
.808 .30199 Mdot
.808 .3021 Mdot
.808 .30214 Mdot
.808 .30247 Mdot
.808 .30377 Mdot
.808 .30378 Mdot
.808 .30379 Mdot
.808 .30454 Mdot
.808 .30477 Mdot
.808 .30661 Mdot
.808 .30736 Mdot
.808 .30749 Mdot
.808 .30764 Mdot
.808 .30769 Mdot
.808 .30908 Mdot
.808 .30949 Mdot
.808 .3095 Mdot
.808 .30977 Mdot
.808 .30984 Mdot
.808 .30986 Mdot
.808 .3101 Mdot
.808 .31024 Mdot
.808 .31084 Mdot
.808 .31114 Mdot
.808 .31122 Mdot
.808 .31135 Mdot
.808 .31145 Mdot
.808 .31147 Mdot
.808 .31203 Mdot
.808 .31212 Mdot
.808 .31223 Mdot
.808 .31241 Mdot
.808 .31273 Mdot
.808 .31283 Mdot
.808 .31311 Mdot
.808 .31327 Mdot
.808 .31374 Mdot
.808 .31375 Mdot
.808 .31396 Mdot
.808 .31422 Mdot
.808 .31456 Mdot
.808 .31476 Mdot
.808 .31503 Mdot
.808 .31524 Mdot
.808 .31537 Mdot
.808 .31563 Mdot
.808 .31564 Mdot
.808 .31566 Mdot
.808 .31575 Mdot
.808 .31648 Mdot
.808 .31663 Mdot
.808 .31694 Mdot
.808 .3171 Mdot
.808 .31749 Mdot
.808 .31754 Mdot
.808 .31756 Mdot
.808 .31763 Mdot
.808 .31769 Mdot
.808 .3178 Mdot
.808 .31791 Mdot
.808 .31797 Mdot
.808 .318 Mdot
.808 .31849 Mdot
.808 .31897 Mdot
.808 .31919 Mdot
.808 .31982 Mdot
.808 .3202 Mdot
.808 .32027 Mdot
.808 .32037 Mdot
.808 .32038 Mdot
.808 .32038 Mdot
.808 .32045 Mdot
.808 .32073 Mdot
.808 .32075 Mdot
.808 .32123 Mdot
.808 .32124 Mdot
.808 .32146 Mdot
.808 .32154 Mdot
.808 .32179 Mdot
.808 .32188 Mdot
.808 .32199 Mdot
.808 .32217 Mdot
.808 .32243 Mdot
.808 .32317 Mdot
.808 .3233 Mdot
.808 .32334 Mdot
.808 .32355 Mdot
.808 .32375 Mdot
.808 .32417 Mdot
.808 .32449 Mdot
.808 .32466 Mdot
.808 .3248 Mdot
.808 .32493 Mdot
.808 .3256 Mdot
.808 .3256 Mdot
.808 .32571 Mdot
.808 .32685 Mdot
.808 .32692 Mdot
.808 .32704 Mdot
.808 .32705 Mdot
.808 .32716 Mdot
.808 .3275 Mdot
.808 .32758 Mdot
.808 .32763 Mdot
.808 .32839 Mdot
.808 .3285 Mdot
.808 .32905 Mdot
.808 .32915 Mdot
.808 .32953 Mdot
.808 .32955 Mdot
.808 .32963 Mdot
.808 .32986 Mdot
.808 .33045 Mdot
.808 .33086 Mdot
.808 .33087 Mdot
.808 .33103 Mdot
.808 .33133 Mdot
.808 .33148 Mdot
.808 .33189 Mdot
.808 .33226 Mdot
.808 .33226 Mdot
.808 .33233 Mdot
.808 .33304 Mdot
.808 .33319 Mdot
.808 .33331 Mdot
.808 .33393 Mdot
.808 .33398 Mdot
.808 .33417 Mdot
.808 .33432 Mdot
.808 .33445 Mdot
.808 .33526 Mdot
.808 .3354 Mdot
.808 .33543 Mdot
.808 .33548 Mdot
.808 .33552 Mdot
.808 .33555 Mdot
.808 .33562 Mdot
.808 .3357 Mdot
.808 .33575 Mdot
.808 .33589 Mdot
.808 .33609 Mdot
.808 .33617 Mdot
.808 .33618 Mdot
.808 .33687 Mdot
.808 .33737 Mdot
.808 .33771 Mdot
.808 .33775 Mdot
.808 .33784 Mdot
.808 .33873 Mdot
.808 .3391 Mdot
.808 .33917 Mdot
.808 .3398 Mdot
.808 .34029 Mdot
.808 .34101 Mdot
.808 .34108 Mdot
.808 .34151 Mdot
.808 .3416 Mdot
.808 .34175 Mdot
.808 .34201 Mdot
.808 .34226 Mdot
.808 .3424 Mdot
.808 .34256 Mdot
.808 .34257 Mdot
.808 .34303 Mdot
.808 .3434 Mdot
.808 .34362 Mdot
.808 .34365 Mdot
.808 .3437 Mdot
.808 .3437 Mdot
.808 .344 Mdot
.808 .34424 Mdot
.808 .3446 Mdot
.808 .34471 Mdot
.808 .34509 Mdot
.808 .34516 Mdot
.808 .34518 Mdot
.808 .34544 Mdot
.808 .34557 Mdot
.808 .34568 Mdot
.808 .34569 Mdot
.808 .34576 Mdot
.808 .34583 Mdot
.808 .34761 Mdot
.808 .34836 Mdot
.808 .34838 Mdot
.808 .34856 Mdot
.808 .34882 Mdot
.808 .34942 Mdot
.808 .34942 Mdot
.808 .34955 Mdot
.808 .34961 Mdot
.808 .34965 Mdot
.808 .34979 Mdot
.808 .35029 Mdot
.808 .35029 Mdot
.808 .3503 Mdot
.808 .35059 Mdot
.808 .35167 Mdot
.808 .35172 Mdot
.808 .35177 Mdot
.808 .35179 Mdot
.808 .35259 Mdot
.808 .35262 Mdot
.808 .35262 Mdot
.808 .35277 Mdot
.808 .35323 Mdot
.808 .35411 Mdot
.808 .3546 Mdot
.808 .35468 Mdot
.808 .35483 Mdot
.808 .35484 Mdot
.808 .35484 Mdot
.808 .35516 Mdot
.808 .35539 Mdot
.808 .35556 Mdot
.808 .35557 Mdot
.808 .3556 Mdot
.808 .35562 Mdot
.808 .35566 Mdot
.808 .35592 Mdot
.808 .35661 Mdot
.808 .35665 Mdot
.808 .35679 Mdot
.808 .35706 Mdot
.808 .35709 Mdot
.808 .35719 Mdot
.808 .35722 Mdot
.808 .35744 Mdot
.808 .35777 Mdot
.808 .3581 Mdot
.808 .35829 Mdot
.808 .35865 Mdot
.808 .35913 Mdot
.808 .3592 Mdot
.808 .3592 Mdot
.808 .35925 Mdot
.808 .35938 Mdot
.808 .35972 Mdot
.808 .36001 Mdot
.808 .36015 Mdot
.808 .36016 Mdot
.808 .3605 Mdot
.808 .36155 Mdot
.808 .3616 Mdot
.808 .36186 Mdot
.808 .36193 Mdot
.808 .36199 Mdot
.808 .36235 Mdot
.808 .3624 Mdot
.808 .36259 Mdot
.808 .36296 Mdot
.808 .36315 Mdot
.808 .3633 Mdot
.808 .36333 Mdot
.808 .36382 Mdot
.808 .36427 Mdot
.808 .36477 Mdot
.808 .36503 Mdot
.808 .36558 Mdot
.808 .36639 Mdot
.808 .36737 Mdot
.808 .36754 Mdot
.808 .36777 Mdot
.808 .36782 Mdot
.808 .36784 Mdot
.808 .36791 Mdot
.808 .3681 Mdot
.808 .36811 Mdot
.808 .36863 Mdot
.808 .36865 Mdot
.808 .36868 Mdot
.808 .36899 Mdot
.808 .36905 Mdot
.808 .36984 Mdot
.808 .37006 Mdot
.808 .37016 Mdot
.808 .37076 Mdot
.808 .37097 Mdot
.808 .37158 Mdot
.808 .37171 Mdot
.808 .37182 Mdot
.808 .37188 Mdot
.808 .37258 Mdot
.808 .37296 Mdot
.808 .3731 Mdot
.808 .37328 Mdot
.808 .37365 Mdot
.808 .37427 Mdot
.808 .37482 Mdot
.808 .37513 Mdot
.808 .37514 Mdot
.808 .37594 Mdot
.808 .37637 Mdot
.808 .37762 Mdot
.808 .37762 Mdot
.808 .37793 Mdot
.808 .37809 Mdot
.808 .37992 Mdot
.808 .38088 Mdot
.808 .38115 Mdot
.808 .38164 Mdot
.808 .38165 Mdot
.808 .38291 Mdot
.808 .38323 Mdot
.808 .38366 Mdot
.808 .38369 Mdot
.808 .38376 Mdot
.808 .38423 Mdot
.808 .38435 Mdot
.808 .38472 Mdot
.808 .38479 Mdot
.808 .38541 Mdot
.808 .38564 Mdot
.808 .38566 Mdot
.808 .38567 Mdot
.808 .386 Mdot
.808 .38616 Mdot
.808 .38617 Mdot
.808 .3862 Mdot
.808 .38635 Mdot
.808 .38706 Mdot
.808 .38756 Mdot
.808 .38806 Mdot
.808 .38865 Mdot
.808 .38895 Mdot
.808 .38897 Mdot
.808 .38918 Mdot
.808 .38941 Mdot
.808 .38978 Mdot
.808 .38986 Mdot
.808 .39092 Mdot
.808 .39101 Mdot
.808 .39119 Mdot
.808 .3914 Mdot
.808 .39185 Mdot
.808 .39207 Mdot
.808 .39219 Mdot
.808 .39239 Mdot
.808 .3926 Mdot
.808 .39273 Mdot
.808 .39283 Mdot
.808 .3937 Mdot
.808 .39386 Mdot
.808 .3942 Mdot
.808 .39421 Mdot
.808 .3943 Mdot
.808 .39466 Mdot
.808 .39549 Mdot
.808 .39558 Mdot
.808 .39558 Mdot
.808 .3956 Mdot
.808 .39609 Mdot
.808 .39614 Mdot
.808 .39617 Mdot
.808 .39702 Mdot
.808 .39702 Mdot
.808 .39702 Mdot
.808 .39733 Mdot
.808 .39744 Mdot
.808 .39748 Mdot
.808 .39756 Mdot
.808 .39756 Mdot
.808 .39793 Mdot
.808 .39809 Mdot
.808 .3982 Mdot
.808 .39821 Mdot
.808 .39978 Mdot
.808 .39982 Mdot
.808 .39987 Mdot
.808 .40054 Mdot
.808 .4011 Mdot
.808 .4018 Mdot
.808 .40199 Mdot
.808 .40215 Mdot
.808 .4024 Mdot
.808 .40246 Mdot
.808 .40321 Mdot
.808 .40394 Mdot
.808 .40418 Mdot
.808 .40473 Mdot
.808 .40478 Mdot
.808 .4048 Mdot
.808 .40502 Mdot
.808 .40533 Mdot
.808 .40575 Mdot
.808 .40576 Mdot
.808 .40593 Mdot
.808 .40602 Mdot
.808 .40623 Mdot
.808 .40632 Mdot
.808 .4069 Mdot
.808 .407 Mdot
.808 .40712 Mdot
.808 .40753 Mdot
.808 .4076 Mdot
.808 .40814 Mdot
.808 .40818 Mdot
.808 .40866 Mdot
.808 .40904 Mdot
.808 .40905 Mdot
.808 .4093 Mdot
.808 .40966 Mdot
.808 .40985 Mdot
.808 .40987 Mdot
.808 .4101 Mdot
.808 .41016 Mdot
.808 .41057 Mdot
.808 .41112 Mdot
.808 .41133 Mdot
.808 .4114 Mdot
.808 .41141 Mdot
.808 .41148 Mdot
.808 .41153 Mdot
.808 .41223 Mdot
.808 .4123 Mdot
.808 .41279 Mdot
.808 .41288 Mdot
.808 .41298 Mdot
.808 .41319 Mdot
.808 .41372 Mdot
.808 .4138 Mdot
.808 .41426 Mdot
.808 .41442 Mdot
.808 .4146 Mdot
.808 .41466 Mdot
.808 .41481 Mdot
.808 .41486 Mdot
.808 .415 Mdot
.808 .4153 Mdot
.808 .41548 Mdot
.808 .41553 Mdot
.808 .41559 Mdot
.808 .41564 Mdot
.808 .4167 Mdot
.808 .41702 Mdot
.808 .41713 Mdot
.808 .41719 Mdot
.808 .41723 Mdot
.808 .41728 Mdot
.808 .41729 Mdot
.808 .41756 Mdot
.808 .41794 Mdot
.808 .41839 Mdot
.808 .41845 Mdot
.808 .41846 Mdot
.808 .41847 Mdot
.808 .41871 Mdot
.808 .41884 Mdot
.808 .41901 Mdot
.808 .41913 Mdot
.808 .41934 Mdot
.808 .4195 Mdot
.808 .41963 Mdot
.808 .41964 Mdot
.808 .41993 Mdot
.808 .42026 Mdot
.808 .42046 Mdot
.808 .42064 Mdot
.808 .42069 Mdot
.808 .42104 Mdot
.808 .42106 Mdot
.808 .4218 Mdot
.808 .42189 Mdot
.808 .42204 Mdot
.808 .42205 Mdot
.808 .42209 Mdot
.808 .42226 Mdot
.808 .42227 Mdot
.808 .42252 Mdot
.808 .42338 Mdot
.808 .42341 Mdot
.808 .4235 Mdot
.808 .42358 Mdot
.808 .42405 Mdot
.808 .42519 Mdot
.808 .42533 Mdot
.808 .42579 Mdot
.808 .4258 Mdot
.808 .42581 Mdot
.808 .42661 Mdot
.808 .42681 Mdot
.808 .42684 Mdot
.808 .42691 Mdot
.808 .427 Mdot
.808 .42721 Mdot
.808 .42722 Mdot
.808 .4273 Mdot
.808 .42819 Mdot
.808 .4286 Mdot
.808 .42875 Mdot
.808 .4289 Mdot
.808 .4289 Mdot
.808 .42892 Mdot
.808 .42927 Mdot
.808 .42928 Mdot
.808 .42963 Mdot
.808 .42974 Mdot
.808 .43013 Mdot
.808 .43134 Mdot
.808 .43232 Mdot
.808 .43302 Mdot
.808 .43303 Mdot
.808 .43312 Mdot
.808 .43323 Mdot
.808 .43326 Mdot
.808 .43344 Mdot
.808 .43364 Mdot
.808 .43407 Mdot
.808 .4341 Mdot
.808 .43421 Mdot
.808 .43461 Mdot
.808 .43482 Mdot
.808 .4349 Mdot
.808 .435 Mdot
.808 .43558 Mdot
.808 .43596 Mdot
.808 .43645 Mdot
.808 .43646 Mdot
.808 .43653 Mdot
.808 .43659 Mdot
.808 .43694 Mdot
.808 .43705 Mdot
.808 .43753 Mdot
.808 .43755 Mdot
.808 .43776 Mdot
.808 .43829 Mdot
.808 .43829 Mdot
.808 .43856 Mdot
.808 .43879 Mdot
.808 .43919 Mdot
.808 .43961 Mdot
.808 .43962 Mdot
.808 .43986 Mdot
.808 .44 Mdot
.808 .44069 Mdot
.808 .4408 Mdot
.808 .44197 Mdot
.808 .44268 Mdot
.808 .44276 Mdot
.808 .44295 Mdot
.808 .44378 Mdot
.808 .44389 Mdot
.808 .44449 Mdot
.808 .44477 Mdot
.808 .44514 Mdot
.808 .44575 Mdot
.808 .4458 Mdot
.808 .44593 Mdot
.808 .44607 Mdot
.808 .44613 Mdot
.808 .44669 Mdot
.808 .44687 Mdot
.808 .4475 Mdot
.808 .44793 Mdot
.808 .44852 Mdot
.808 .44862 Mdot
.808 .44862 Mdot
.808 .44876 Mdot
.808 .44908 Mdot
.808 .44922 Mdot
.808 .44924 Mdot
.808 .44931 Mdot
.808 .44938 Mdot
.808 .44951 Mdot
.808 .44962 Mdot
.808 .44967 Mdot
.808 .44974 Mdot
.808 .44981 Mdot
.808 .44986 Mdot
.808 .4501 Mdot
.808 .45062 Mdot
.808 .45115 Mdot
.808 .45121 Mdot
.808 .4514 Mdot
.808 .45162 Mdot
.808 .45186 Mdot
.808 .45217 Mdot
.808 .45224 Mdot
.808 .45246 Mdot
.808 .45275 Mdot
.808 .45325 Mdot
.808 .45344 Mdot
.808 .45368 Mdot
.808 .45368 Mdot
.808 .45383 Mdot
.808 .45401 Mdot
.808 .45403 Mdot
.808 .45484 Mdot
.808 .45494 Mdot
.808 .45494 Mdot
.808 .4553 Mdot
.808 .45554 Mdot
.808 .4562 Mdot
.808 .45632 Mdot
.808 .45645 Mdot
.808 .45693 Mdot
.808 .45719 Mdot
.808 .45721 Mdot
.808 .45783 Mdot
.808 .45787 Mdot
.808 .45808 Mdot
.808 .45828 Mdot
.808 .45883 Mdot
.808 .45883 Mdot
.808 .45919 Mdot
.808 .45932 Mdot
.808 .45936 Mdot
.808 .45989 Mdot
.808 .45998 Mdot
.808 .46013 Mdot
.808 .46018 Mdot
.808 .46026 Mdot
.808 .46102 Mdot
.808 .4612 Mdot
.808 .46137 Mdot
.808 .46191 Mdot
.808 .46237 Mdot
.808 .46242 Mdot
.808 .46244 Mdot
.808 .4625 Mdot
.808 .46263 Mdot
.808 .46273 Mdot
.808 .46297 Mdot
.808 .46299 Mdot
.808 .46318 Mdot
.808 .46336 Mdot
.808 .46339 Mdot
.808 .46356 Mdot
.808 .46369 Mdot
.808 .46483 Mdot
.808 .46553 Mdot
.808 .46571 Mdot
.808 .46571 Mdot
.808 .46678 Mdot
.808 .46699 Mdot
.808 .46723 Mdot
.808 .46737 Mdot
.808 .4675 Mdot
.808 .46802 Mdot
.808 .46869 Mdot
.808 .46901 Mdot
.808 .46936 Mdot
.808 .46943 Mdot
.808 .46964 Mdot
.808 .47053 Mdot
.808 .47082 Mdot
.808 .47125 Mdot
.808 .47154 Mdot
.808 .47156 Mdot
.808 .47172 Mdot
.808 .47185 Mdot
.808 .47186 Mdot
.808 .47227 Mdot
.808 .4724 Mdot
.808 .47275 Mdot
.808 .47276 Mdot
.808 .47277 Mdot
.808 .47279 Mdot
.808 .47353 Mdot
.808 .47357 Mdot
.808 .47369 Mdot
.808 .47374 Mdot
.808 .47376 Mdot
.808 .47402 Mdot
.808 .47414 Mdot
.808 .47414 Mdot
.808 .47416 Mdot
.808 .47416 Mdot
.808 .47431 Mdot
.808 .47444 Mdot
.808 .47453 Mdot
.808 .47505 Mdot
.808 .47561 Mdot
.808 .47606 Mdot
.808 .47642 Mdot
.808 .4772 Mdot
.808 .47794 Mdot
.808 .47798 Mdot
.808 .47803 Mdot
.808 .47813 Mdot
.808 .47814 Mdot
.808 .47817 Mdot
.808 .47831 Mdot
.808 .47849 Mdot
.808 .47858 Mdot
.808 .4787 Mdot
.808 .47872 Mdot
.808 .47873 Mdot
.808 .47882 Mdot
.808 .47896 Mdot
.808 .47914 Mdot
.808 .4792 Mdot
.808 .47945 Mdot
.808 .4797 Mdot
.808 .47973 Mdot
.808 .48019 Mdot
.808 .48043 Mdot
.808 .48162 Mdot
.808 .48176 Mdot
.808 .48179 Mdot
.808 .48182 Mdot
.808 .48183 Mdot
.808 .48185 Mdot
.808 .48187 Mdot
.808 .48224 Mdot
.808 .48244 Mdot
.808 .48278 Mdot
.808 .48308 Mdot
.808 .48322 Mdot
.808 .48344 Mdot
.808 .48355 Mdot
.808 .48409 Mdot
.808 .48452 Mdot
.808 .48485 Mdot
.808 .48487 Mdot
.808 .48563 Mdot
.808 .48589 Mdot
.808 .48634 Mdot
.808 .48642 Mdot
.808 .4865 Mdot
.808 .48701 Mdot
.808 .4873 Mdot
.808 .4875 Mdot
.808 .48763 Mdot
.808 .48763 Mdot
.808 .48785 Mdot
.808 .48809 Mdot
.808 .48817 Mdot
.808 .48854 Mdot
.808 .48858 Mdot
.808 .48874 Mdot
.808 .48895 Mdot
.808 .48906 Mdot
.808 .48955 Mdot
.808 .49041 Mdot
.808 .49052 Mdot
.808 .49075 Mdot
.808 .49108 Mdot
.808 .49109 Mdot
.808 .49114 Mdot
.808 .49117 Mdot
.808 .49128 Mdot
.81 .19776 Mdot
.81 .19785 Mdot
.81 .19786 Mdot
.81 .19854 Mdot
.81 .1995 Mdot
.81 .19966 Mdot
.81 .20036 Mdot
.81 .20074 Mdot
.81 .20078 Mdot
.81 .20081 Mdot
.81 .20093 Mdot
.81 .20136 Mdot
.81 .20211 Mdot
.81 .20329 Mdot
.81 .20371 Mdot
.81 .20379 Mdot
.81 .2039 Mdot
.81 .20396 Mdot
.81 .20415 Mdot
.81 .20416 Mdot
.81 .20682 Mdot
.81 .20686 Mdot
.81 .20709 Mdot
.81 .20719 Mdot
.81 .20736 Mdot
.81 .20776 Mdot
.81 .20778 Mdot
.81 .20822 Mdot
.81 .20846 Mdot
.81 .20981 Mdot
.81 .20998 Mdot
.81 .21144 Mdot
.81 .21173 Mdot
.81 .21208 Mdot
.81 .21304 Mdot
.81 .21305 Mdot
.81 .21323 Mdot
.81 .21336 Mdot
.81 .21385 Mdot
.81 .21411 Mdot
.81 .21451 Mdot
.81 .21482 Mdot
.81 .21521 Mdot
.81 .21567 Mdot
.81 .21593 Mdot
.81 .216 Mdot
.81 .21614 Mdot
.81 .21695 Mdot
.81 .21704 Mdot
.81 .21759 Mdot
.81 .21779 Mdot
.81 .21812 Mdot
.81 .2188 Mdot
.81 .21887 Mdot
.81 .21921 Mdot
.81 .21982 Mdot
.81 .22033 Mdot
.81 .22043 Mdot
.81 .22086 Mdot
.81 .22389 Mdot
.81 .22454 Mdot
.81 .22486 Mdot
.81 .22533 Mdot
.81 .22549 Mdot
.81 .22567 Mdot
.81 .226 Mdot
.81 .22625 Mdot
.81 .22649 Mdot
.81 .22676 Mdot
.81 .22703 Mdot
.81 .22726 Mdot
.81 .22732 Mdot
.81 .22755 Mdot
.81 .22759 Mdot
.81 .2284 Mdot
.81 .22948 Mdot
.81 .23002 Mdot
.81 .23029 Mdot
.81 .23059 Mdot
.81 .23066 Mdot
.81 .23128 Mdot
.81 .23139 Mdot
.81 .23141 Mdot
.81 .23158 Mdot
.81 .23176 Mdot
.81 .23231 Mdot
.81 .23293 Mdot
.81 .23352 Mdot
.81 .23383 Mdot
.81 .23515 Mdot
.81 .23602 Mdot
.81 .23608 Mdot
.81 .23677 Mdot
.81 .23706 Mdot
.81 .23744 Mdot
.81 .23764 Mdot
.81 .23776 Mdot
.81 .23808 Mdot
.81 .23852 Mdot
.81 .23857 Mdot
.81 .2389 Mdot
.81 .23905 Mdot
.81 .23921 Mdot
.81 .24006 Mdot
.81 .24008 Mdot
.81 .24025 Mdot
.81 .24049 Mdot
.81 .24054 Mdot
.81 .24057 Mdot
.81 .24121 Mdot
.81 .24156 Mdot
.81 .24174 Mdot
.81 .24222 Mdot
.81 .24224 Mdot
.81 .24246 Mdot
.81 .24288 Mdot
.81 .24296 Mdot
.81 .24297 Mdot
.81 .24352 Mdot
.81 .24391 Mdot
.81 .24484 Mdot
.81 .24589 Mdot
.81 .24643 Mdot
.81 .24716 Mdot
.81 .24725 Mdot
.81 .24769 Mdot
.81 .2477 Mdot
.81 .24775 Mdot
.81 .24813 Mdot
.81 .24842 Mdot
.81 .25101 Mdot
.81 .25112 Mdot
.81 .25129 Mdot
.81 .25161 Mdot
.81 .25186 Mdot
.81 .25199 Mdot
.81 .25234 Mdot
.81 .25311 Mdot
.81 .25432 Mdot
.81 .25601 Mdot
.81 .25633 Mdot
.81 .25639 Mdot
.81 .25752 Mdot
.81 .25807 Mdot
.81 .25855 Mdot
.81 .25911 Mdot
.81 .25971 Mdot
.81 .25979 Mdot
.81 .26013 Mdot
.81 .26126 Mdot
.81 .26137 Mdot
.81 .26141 Mdot
.81 .262 Mdot
.81 .26203 Mdot
.81 .26332 Mdot
.81 .26337 Mdot
.81 .2634 Mdot
.81 .26535 Mdot
.81 .26535 Mdot
.81 .26538 Mdot
.81 .26539 Mdot
.81 .26548 Mdot
.81 .26584 Mdot
.81 .26603 Mdot
.81 .26617 Mdot
.81 .26626 Mdot
.81 .26671 Mdot
.81 .26802 Mdot
.81 .26807 Mdot
.81 .26815 Mdot
.81 .26848 Mdot
.81 .26878 Mdot
.81 .26913 Mdot
.81 .26918 Mdot
.81 .26937 Mdot
.81 .2699 Mdot
.81 .27115 Mdot
.81 .27158 Mdot
.81 .27236 Mdot
.81 .27291 Mdot
.81 .27316 Mdot
.81 .27389 Mdot
.81 .27396 Mdot
.81 .27456 Mdot
.81 .27521 Mdot
.81 .27561 Mdot
.81 .27576 Mdot
.81 .27623 Mdot
.81 .27651 Mdot
.81 .27653 Mdot
.81 .27765 Mdot
.81 .27795 Mdot
.81 .278 Mdot
.81 .27809 Mdot
.81 .27853 Mdot
.81 .27924 Mdot
.81 .27948 Mdot
.81 .27963 Mdot
.81 .28013 Mdot
.81 .28041 Mdot
.81 .28195 Mdot
.81 .28235 Mdot
.81 .28334 Mdot
.81 .28338 Mdot
.81 .28339 Mdot
.81 .28414 Mdot
.81 .28465 Mdot
.81 .28467 Mdot
.81 .28489 Mdot
.81 .28537 Mdot
.81 .28553 Mdot
.81 .28577 Mdot
.81 .2868 Mdot
.81 .28682 Mdot
.81 .28695 Mdot
.81 .28805 Mdot
.81 .28848 Mdot
.81 .28853 Mdot
.81 .28881 Mdot
.81 .28984 Mdot
.81 .29009 Mdot
.81 .29011 Mdot
.81 .29012 Mdot
.81 .29028 Mdot
.81 .29156 Mdot
.81 .29171 Mdot
.81 .29219 Mdot
.81 .29284 Mdot
.81 .29378 Mdot
.81 .29417 Mdot
.81 .29428 Mdot
.81 .29454 Mdot
.81 .2949 Mdot
.81 .29619 Mdot
.81 .29632 Mdot
.81 .29633 Mdot
.81 .2966 Mdot
.81 .29675 Mdot
.81 .29706 Mdot
.81 .29747 Mdot
.81 .29829 Mdot
.81 .29858 Mdot
.81 .29882 Mdot
.81 .30054 Mdot
.81 .30074 Mdot
.81 .30097 Mdot
.81 .30183 Mdot
.81 .30214 Mdot
.81 .30219 Mdot
.81 .30264 Mdot
.81 .30276 Mdot
.81 .30291 Mdot
.81 .30332 Mdot
.81 .30369 Mdot
.81 .30449 Mdot
.81 .30533 Mdot
.81 .30555 Mdot
.81 .30559 Mdot
.81 .30568 Mdot
.81 .30685 Mdot
.81 .30777 Mdot
.81 .30842 Mdot
.81 .30911 Mdot
.81 .30914 Mdot
.81 .31029 Mdot
.81 .31055 Mdot
.81 .31091 Mdot
.81 .31124 Mdot
.81 .31139 Mdot
.81 .3114 Mdot
.81 .31141 Mdot
.81 .31146 Mdot
.81 .31191 Mdot
.81 .31236 Mdot
.81 .31252 Mdot
.81 .31259 Mdot
.81 .31261 Mdot
.81 .31269 Mdot
.81 .31269 Mdot
.81 .3137 Mdot
.81 .31391 Mdot
.81 .31407 Mdot
.81 .31424 Mdot
.81 .31433 Mdot
.81 .31484 Mdot
.81 .31546 Mdot
.81 .31558 Mdot
.81 .31608 Mdot
.81 .31615 Mdot
.81 .3162 Mdot
.81 .31638 Mdot
.81 .3169 Mdot
.81 .31707 Mdot
.81 .31718 Mdot
.81 .3176 Mdot
.81 .3178 Mdot
.81 .31788 Mdot
.81 .31801 Mdot
.81 .31827 Mdot
.81 .31829 Mdot
.81 .31889 Mdot
.81 .31905 Mdot
.81 .32021 Mdot
.81 .32046 Mdot
.81 .32076 Mdot
.81 .32089 Mdot
.81 .32101 Mdot
.81 .3212 Mdot
.81 .3213 Mdot
.81 .3214 Mdot
.81 .32149 Mdot
.81 .32151 Mdot
.81 .3216 Mdot
.81 .32162 Mdot
.81 .32254 Mdot
.81 .32276 Mdot
.81 .32302 Mdot
.81 .32314 Mdot
.81 .32342 Mdot
.81 .32365 Mdot
.81 .32388 Mdot
.81 .324 Mdot
.81 .32483 Mdot
.81 .32537 Mdot
.81 .32545 Mdot
.81 .32549 Mdot
.81 .32578 Mdot
.81 .3258 Mdot
.81 .32593 Mdot
.81 .32598 Mdot
.81 .32604 Mdot
.81 .32637 Mdot
.81 .32638 Mdot
.81 .32644 Mdot
.81 .32653 Mdot
.81 .32656 Mdot
.81 .32681 Mdot
.81 .32694 Mdot
.81 .32701 Mdot
.81 .32719 Mdot
.81 .32728 Mdot
.81 .32744 Mdot
.81 .32747 Mdot
.81 .32748 Mdot
.81 .32819 Mdot
.81 .32859 Mdot
.81 .32879 Mdot
.81 .32907 Mdot
.81 .32944 Mdot
.81 .33054 Mdot
.81 .33065 Mdot
.81 .33077 Mdot
.81 .33105 Mdot
.81 .3318 Mdot
.81 .33302 Mdot
.81 .33323 Mdot
.81 .33341 Mdot
.81 .33389 Mdot
.81 .33445 Mdot
.81 .33449 Mdot
.81 .33523 Mdot
.81 .33526 Mdot
.81 .33601 Mdot
.81 .33602 Mdot
.81 .33619 Mdot
.81 .33626 Mdot
.81 .33632 Mdot
.81 .33635 Mdot
.81 .33652 Mdot
.81 .33702 Mdot
.81 .33707 Mdot
.81 .3372 Mdot
.81 .33731 Mdot
.81 .33746 Mdot
.81 .33754 Mdot
.81 .33774 Mdot
.81 .33822 Mdot
.81 .33838 Mdot
.81 .33868 Mdot
.81 .33889 Mdot
.81 .33929 Mdot
.81 .33951 Mdot
.81 .33997 Mdot
.81 .34026 Mdot
.81 .34027 Mdot
.81 .34069 Mdot
.81 .3408 Mdot
.81 .34083 Mdot
.81 .34103 Mdot
.81 .34164 Mdot
.81 .34233 Mdot
.81 .34248 Mdot
.81 .34287 Mdot
.81 .34336 Mdot
.81 .34337 Mdot
.81 .34345 Mdot
.81 .3437 Mdot
.81 .34418 Mdot
.81 .34423 Mdot
.81 .34466 Mdot
.81 .34482 Mdot
.81 .34494 Mdot
.81 .34534 Mdot
.81 .34544 Mdot
.81 .34544 Mdot
.81 .34599 Mdot
.81 .34605 Mdot
.81 .34684 Mdot
.81 .34699 Mdot
.81 .34713 Mdot
.81 .34726 Mdot
.81 .34775 Mdot
.81 .34781 Mdot
.81 .34791 Mdot
.81 .34797 Mdot
.81 .34809 Mdot
.81 .34855 Mdot
.81 .34867 Mdot
.81 .34876 Mdot
.81 .34942 Mdot
.81 .34958 Mdot
.81 .34991 Mdot
.81 .35004 Mdot
.81 .35032 Mdot
.81 .35047 Mdot
.81 .35134 Mdot
.81 .35182 Mdot
.81 .35217 Mdot
.81 .35242 Mdot
.81 .35357 Mdot
.81 .35375 Mdot
.81 .35443 Mdot
.81 .35451 Mdot
.81 .35463 Mdot
.81 .35486 Mdot
.81 .35514 Mdot
.81 .35565 Mdot
.81 .35575 Mdot
.81 .35591 Mdot
.81 .35617 Mdot
.81 .35641 Mdot
.81 .35647 Mdot
.81 .357 Mdot
.81 .35712 Mdot
.81 .35741 Mdot
.81 .3578 Mdot
.81 .35788 Mdot
.81 .35822 Mdot
.81 .35831 Mdot
.81 .35835 Mdot
.81 .35867 Mdot
.81 .35888 Mdot
.81 .3589 Mdot
.81 .35892 Mdot
.81 .35903 Mdot
.81 .35904 Mdot
.81 .35913 Mdot
.81 .35928 Mdot
.81 .35933 Mdot
.81 .35947 Mdot
.81 .3595 Mdot
.81 .35957 Mdot
.81 .36018 Mdot
.81 .36043 Mdot
.81 .36089 Mdot
.81 .36179 Mdot
.81 .36235 Mdot
.81 .36263 Mdot
.81 .36264 Mdot
.81 .36303 Mdot
.81 .36332 Mdot
.81 .36333 Mdot
.81 .36348 Mdot
.81 .36351 Mdot
.81 .36377 Mdot
.81 .36395 Mdot
.81 .36418 Mdot
.81 .36444 Mdot
.81 .36455 Mdot
.81 .36476 Mdot
.81 .36554 Mdot
.81 .36573 Mdot
.81 .36576 Mdot
.81 .36604 Mdot
.81 .36622 Mdot
.81 .36633 Mdot
.81 .36652 Mdot
.81 .36675 Mdot
.81 .36717 Mdot
.81 .36722 Mdot
.81 .36747 Mdot
.81 .36771 Mdot
.81 .36804 Mdot
.81 .36822 Mdot
.81 .36844 Mdot
.81 .36877 Mdot
.81 .36895 Mdot
.81 .36909 Mdot
.81 .36918 Mdot
.81 .36969 Mdot
.81 .36995 Mdot
.81 .36998 Mdot
.81 .37011 Mdot
.81 .37041 Mdot
.81 .37045 Mdot
.81 .3707 Mdot
.81 .37143 Mdot
.81 .37144 Mdot
.81 .37165 Mdot
.81 .37166 Mdot
.81 .3718 Mdot
.81 .37182 Mdot
.81 .37187 Mdot
.81 .37275 Mdot
.81 .37308 Mdot
.81 .37322 Mdot
.81 .37333 Mdot
.81 .37334 Mdot
.81 .3734 Mdot
.81 .37366 Mdot
.81 .37389 Mdot
.81 .37444 Mdot
.81 .37464 Mdot
.81 .3748 Mdot
.81 .37492 Mdot
.81 .37501 Mdot
.81 .37513 Mdot
.81 .37529 Mdot
.81 .37541 Mdot
.81 .37553 Mdot
.81 .37586 Mdot
.81 .37592 Mdot
.81 .37604 Mdot
.81 .37605 Mdot
.81 .37615 Mdot
.81 .37651 Mdot
.81 .37657 Mdot
.81 .37659 Mdot
.81 .37705 Mdot
.81 .37728 Mdot
.81 .37736 Mdot
.81 .37771 Mdot
.81 .37779 Mdot
.81 .3779 Mdot
.81 .37794 Mdot
.81 .37814 Mdot
.81 .37822 Mdot
.81 .37836 Mdot
.81 .37839 Mdot
.81 .37857 Mdot
.81 .37901 Mdot
.81 .37907 Mdot
.81 .37977 Mdot
.81 .3798 Mdot
.81 .38008 Mdot
.81 .3802 Mdot
.81 .38029 Mdot
.81 .38046 Mdot
.81 .38056 Mdot
.81 .38061 Mdot
.81 .38101 Mdot
.81 .3813 Mdot
.81 .38135 Mdot
.81 .38157 Mdot
.81 .38164 Mdot
.81 .38171 Mdot
.81 .38203 Mdot
.81 .3821 Mdot
.81 .3822 Mdot
.81 .38227 Mdot
.81 .3824 Mdot
.81 .3825 Mdot
.81 .38297 Mdot
.81 .38311 Mdot
.81 .38327 Mdot
.81 .3833 Mdot
.81 .38347 Mdot
.81 .38367 Mdot
.81 .38421 Mdot
.81 .38426 Mdot
.81 .38434 Mdot
.81 .38435 Mdot
.81 .38448 Mdot
.81 .38449 Mdot
.81 .38493 Mdot
.81 .38509 Mdot
.81 .38511 Mdot
.81 .3853 Mdot
.81 .38538 Mdot
.81 .3854 Mdot
.81 .38593 Mdot
.81 .38601 Mdot
.81 .38613 Mdot
.81 .38633 Mdot
.81 .38658 Mdot
.81 .38678 Mdot
.81 .38693 Mdot
.81 .38712 Mdot
.81 .38737 Mdot
.81 .38751 Mdot
.81 .3877 Mdot
.81 .3886 Mdot
.81 .38896 Mdot
.81 .38921 Mdot
.81 .38939 Mdot
.81 .38948 Mdot
.81 .38949 Mdot
.81 .38967 Mdot
.81 .38991 Mdot
.81 .39009 Mdot
.81 .39043 Mdot
.81 .39128 Mdot
.81 .39143 Mdot
.81 .39186 Mdot
.81 .39195 Mdot
.81 .39198 Mdot
.81 .39214 Mdot
.81 .39215 Mdot
.81 .3922 Mdot
.81 .39221 Mdot
.81 .39223 Mdot
.81 .39256 Mdot
.81 .39258 Mdot
.81 .39285 Mdot
.81 .39332 Mdot
.81 .39376 Mdot
.81 .39416 Mdot
.81 .39423 Mdot
.81 .39471 Mdot
.81 .39493 Mdot
.81 .39498 Mdot
.81 .3954 Mdot
.81 .39622 Mdot
.81 .39637 Mdot
.81 .39659 Mdot
.81 .39689 Mdot
.81 .39742 Mdot
.81 .39752 Mdot
.81 .39769 Mdot
.81 .39777 Mdot
.81 .39797 Mdot
.81 .39807 Mdot
.81 .39848 Mdot
.81 .3986 Mdot
.81 .39889 Mdot
.81 .399 Mdot
.81 .3991 Mdot
.81 .3994 Mdot
.81 .39949 Mdot
.81 .39966 Mdot
.81 .40015 Mdot
.81 .40053 Mdot
.81 .40083 Mdot
.81 .40091 Mdot
.81 .40101 Mdot
.81 .40131 Mdot
.81 .40176 Mdot
.81 .40181 Mdot
.81 .40211 Mdot
.81 .40287 Mdot
.81 .40337 Mdot
.81 .40372 Mdot
.81 .4039 Mdot
.81 .40433 Mdot
.81 .4047 Mdot
.81 .40499 Mdot
.81 .40541 Mdot
.81 .40545 Mdot
.81 .40562 Mdot
.81 .40569 Mdot
.81 .40572 Mdot
.81 .40614 Mdot
.81 .40619 Mdot
.81 .40624 Mdot
.81 .40681 Mdot
.81 .40683 Mdot
.81 .40729 Mdot
.81 .40806 Mdot
.81 .40819 Mdot
.81 .40895 Mdot
.81 .40966 Mdot
.81 .40972 Mdot
.81 .4104 Mdot
.81 .41063 Mdot
.81 .4108 Mdot
.81 .41161 Mdot
.81 .41173 Mdot
.81 .41179 Mdot
.81 .4119 Mdot
.81 .41195 Mdot
.81 .41218 Mdot
.81 .41226 Mdot
.81 .4123 Mdot
.81 .4125 Mdot
.81 .41265 Mdot
.81 .41266 Mdot
.81 .41284 Mdot
.81 .41287 Mdot
.81 .41291 Mdot
.81 .41325 Mdot
.81 .41376 Mdot
.81 .41384 Mdot
.81 .41398 Mdot
.81 .41412 Mdot
.81 .41429 Mdot
.81 .41437 Mdot
.81 .41453 Mdot
.81 .41466 Mdot
.81 .4153 Mdot
.81 .41531 Mdot
.81 .41536 Mdot
.81 .41576 Mdot
.81 .41595 Mdot
.81 .41682 Mdot
.81 .41692 Mdot
.81 .4173 Mdot
.81 .41746 Mdot
.81 .41754 Mdot
.81 .41759 Mdot
.81 .41771 Mdot
.81 .41797 Mdot
.81 .41814 Mdot
.81 .41896 Mdot
.81 .41941 Mdot
.81 .41979 Mdot
.81 .41999 Mdot
.81 .42012 Mdot
.81 .42074 Mdot
.81 .42075 Mdot
.81 .42079 Mdot
.81 .4208 Mdot
.81 .42095 Mdot
.81 .42123 Mdot
.81 .4215 Mdot
.81 .42154 Mdot
.81 .42184 Mdot
.81 .42206 Mdot
.81 .42222 Mdot
.81 .42295 Mdot
.81 .42338 Mdot
.81 .42378 Mdot
.81 .42435 Mdot
.81 .42507 Mdot
.81 .42513 Mdot
.81 .42515 Mdot
.81 .42528 Mdot
.81 .42581 Mdot
.81 .4263 Mdot
.81 .42653 Mdot
.81 .42678 Mdot
.81 .42687 Mdot
.81 .42695 Mdot
.81 .42722 Mdot
.81 .42726 Mdot
.81 .42745 Mdot
.81 .42798 Mdot
.81 .42812 Mdot
.81 .42824 Mdot
.81 .42931 Mdot
.81 .42945 Mdot
.81 .42963 Mdot
.81 .43014 Mdot
.81 .43039 Mdot
.81 .43058 Mdot
.81 .43067 Mdot
.81 .43084 Mdot
.81 .43085 Mdot
.81 .43093 Mdot
.81 .43173 Mdot
.81 .43195 Mdot
.81 .43211 Mdot
.81 .43218 Mdot
.81 .43242 Mdot
.81 .433 Mdot
.81 .43339 Mdot
.81 .4337 Mdot
.81 .43379 Mdot
.81 .43457 Mdot
.81 .43468 Mdot
.81 .43468 Mdot
.81 .43469 Mdot
.81 .43485 Mdot
.81 .43548 Mdot
.81 .43566 Mdot
.81 .43569 Mdot
.81 .43595 Mdot
.81 .43663 Mdot
.81 .43671 Mdot
.81 .43672 Mdot
.81 .43736 Mdot
.81 .43751 Mdot
.81 .4376 Mdot
.81 .4379 Mdot
.81 .43804 Mdot
.81 .43805 Mdot
.81 .43836 Mdot
.81 .43883 Mdot
.81 .43884 Mdot
.81 .43886 Mdot
.81 .43947 Mdot
.81 .43972 Mdot
.81 .44067 Mdot
.81 .44084 Mdot
.81 .44115 Mdot
.81 .44124 Mdot
.81 .44139 Mdot
.81 .44183 Mdot
.81 .4421 Mdot
.81 .44215 Mdot
.81 .44219 Mdot
.81 .44237 Mdot
.81 .44306 Mdot
.81 .44307 Mdot
.81 .44325 Mdot
.81 .44354 Mdot
.81 .44363 Mdot
.81 .44388 Mdot
.81 .44428 Mdot
.81 .44465 Mdot
.81 .44469 Mdot
.81 .44514 Mdot
.81 .4453 Mdot
.81 .44563 Mdot
.81 .44612 Mdot
.81 .44638 Mdot
.81 .44715 Mdot
.81 .44748 Mdot
.81 .4476 Mdot
.81 .44763 Mdot
.81 .44785 Mdot
.81 .44804 Mdot
.81 .44823 Mdot
.81 .44829 Mdot
.81 .44832 Mdot
.81 .44912 Mdot
.81 .4494 Mdot
.81 .44946 Mdot
.81 .44955 Mdot
.81 .44966 Mdot
.81 .44989 Mdot
.81 .44994 Mdot
.81 .44995 Mdot
.81 .44996 Mdot
.81 .44997 Mdot
.81 .45117 Mdot
.81 .45119 Mdot
.81 .45122 Mdot
.81 .45201 Mdot
.81 .45204 Mdot
.81 .4524 Mdot
.81 .45242 Mdot
.81 .45249 Mdot
.81 .45318 Mdot
.81 .4534 Mdot
.81 .45344 Mdot
.81 .45382 Mdot
.81 .45416 Mdot
.81 .45446 Mdot
.81 .4548 Mdot
.81 .45549 Mdot
.81 .45553 Mdot
.81 .45573 Mdot
.81 .45677 Mdot
.81 .45752 Mdot
.81 .458 Mdot
.81 .45821 Mdot
.81 .45829 Mdot
.81 .45845 Mdot
.81 .45864 Mdot
.81 .45875 Mdot
.81 .45882 Mdot
.81 .46041 Mdot
.81 .46059 Mdot
.81 .46083 Mdot
.81 .46086 Mdot
.81 .46087 Mdot
.81 .46114 Mdot
.81 .46119 Mdot
.81 .46165 Mdot
.81 .46198 Mdot
.81 .46263 Mdot
.81 .4632 Mdot
.81 .46344 Mdot
.81 .46378 Mdot
.81 .46378 Mdot
.81 .46383 Mdot
.81 .46409 Mdot
.81 .46423 Mdot
.81 .46424 Mdot
.81 .46454 Mdot
.81 .46465 Mdot
.81 .46487 Mdot
.81 .46526 Mdot
.81 .46528 Mdot
.81 .46531 Mdot
.81 .46546 Mdot
.81 .46557 Mdot
.81 .46558 Mdot
.81 .4661 Mdot
.81 .4662 Mdot
.81 .46629 Mdot
.81 .4665 Mdot
.81 .46653 Mdot
.81 .4668 Mdot
.81 .46699 Mdot
.81 .46707 Mdot
.81 .46719 Mdot
.81 .46743 Mdot
.81 .46761 Mdot
.81 .46803 Mdot
.81 .46807 Mdot
.81 .46861 Mdot
.81 .46942 Mdot
.81 .46961 Mdot
.81 .46998 Mdot
.81 .47036 Mdot
.81 .4707 Mdot
.81 .47081 Mdot
.81 .47091 Mdot
.81 .47093 Mdot
.81 .471 Mdot
.81 .47138 Mdot
.81 .47142 Mdot
.81 .47161 Mdot
.81 .47177 Mdot
.81 .47211 Mdot
.81 .47277 Mdot
.81 .47327 Mdot
.81 .4733 Mdot
.81 .47344 Mdot
.81 .47348 Mdot
.81 .47362 Mdot
.81 .47379 Mdot
.81 .47395 Mdot
.81 .4741 Mdot
.81 .47425 Mdot
.81 .47446 Mdot
.81 .47457 Mdot
.81 .47467 Mdot
.81 .47496 Mdot
.81 .47516 Mdot
.81 .47556 Mdot
.81 .47743 Mdot
.81 .4777 Mdot
.81 .47776 Mdot
.81 .47807 Mdot
.81 .47845 Mdot
.81 .47866 Mdot
.81 .4787 Mdot
.81 .47912 Mdot
.81 .47932 Mdot
.81 .47945 Mdot
.81 .47979 Mdot
.81 .47984 Mdot
.81 .48034 Mdot
.81 .48042 Mdot
.81 .48047 Mdot
.81 .48063 Mdot
.81 .48092 Mdot
.81 .48116 Mdot
.81 .48135 Mdot
.81 .48159 Mdot
.81 .48176 Mdot
.81 .48206 Mdot
.81 .48214 Mdot
.81 .48225 Mdot
.81 .48225 Mdot
.81 .48285 Mdot
.81 .48306 Mdot
.81 .48324 Mdot
.81 .48414 Mdot
.81 .48425 Mdot
.81 .48508 Mdot
.81 .48523 Mdot
.81 .4855 Mdot
.81 .48552 Mdot
.81 .48576 Mdot
.81 .48586 Mdot
.81 .48593 Mdot
.81 .48607 Mdot
.81 .48609 Mdot
.81 .48774 Mdot
.81 .48774 Mdot
.81 .48786 Mdot
.81 .4879 Mdot
.81 .48797 Mdot
.81 .48801 Mdot
.81 .48827 Mdot
.81 .489 Mdot
.81 .48947 Mdot
.81 .48973 Mdot
.81 .4898 Mdot
.81 .48982 Mdot
.81 .48985 Mdot
.81 .49008 Mdot
.81 .49051 Mdot
.81 .49061 Mdot
.81 .4912 Mdot
.81 .49162 Mdot
.81 .49163 Mdot
.81 .49169 Mdot
.812 .19484 Mdot
.812 .19517 Mdot
.812 .19526 Mdot
.812 .19576 Mdot
.812 .19635 Mdot
.812 .1969 Mdot
.812 .197 Mdot
.812 .19719 Mdot
.812 .19737 Mdot
.812 .19759 Mdot
.812 .19806 Mdot
.812 .19843 Mdot
.812 .19876 Mdot
.812 .19918 Mdot
.812 .19945 Mdot
.812 .19954 Mdot
.812 .19992 Mdot
.812 .20013 Mdot
.812 .2005 Mdot
.812 .20054 Mdot
.812 .20093 Mdot
.812 .20131 Mdot
.812 .20176 Mdot
.812 .20192 Mdot
.812 .20193 Mdot
.812 .20215 Mdot
.812 .20342 Mdot
.812 .20373 Mdot
.812 .2043 Mdot
.812 .20434 Mdot
.812 .20462 Mdot
.812 .20478 Mdot
.812 .20486 Mdot
.812 .20514 Mdot
.812 .20645 Mdot
.812 .20655 Mdot
.812 .20665 Mdot
.812 .20692 Mdot
.812 .20719 Mdot
.812 .20744 Mdot
.812 .20811 Mdot
.812 .20826 Mdot
.812 .20841 Mdot
.812 .20848 Mdot
.812 .20917 Mdot
.812 .21011 Mdot
.812 .21053 Mdot
.812 .21073 Mdot
.812 .21103 Mdot
.812 .21248 Mdot
.812 .21258 Mdot
.812 .21276 Mdot
.812 .21295 Mdot
.812 .21441 Mdot
.812 .21443 Mdot
.812 .21544 Mdot
.812 .21607 Mdot
.812 .21689 Mdot
.812 .21772 Mdot
.812 .21801 Mdot
.812 .2187 Mdot
.812 .21874 Mdot
.812 .21964 Mdot
.812 .2202 Mdot
.812 .22025 Mdot
.812 .22051 Mdot
.812 .22208 Mdot
.812 .22213 Mdot
.812 .22214 Mdot
.812 .22267 Mdot
.812 .22321 Mdot
.812 .22401 Mdot
.812 .22404 Mdot
.812 .22422 Mdot
.812 .2249 Mdot
.812 .22512 Mdot
.812 .22559 Mdot
.812 .22645 Mdot
.812 .22703 Mdot
.812 .22786 Mdot
.812 .22839 Mdot
.812 .22842 Mdot
.812 .22873 Mdot
.812 .22877 Mdot
.812 .22887 Mdot
.812 .22905 Mdot
.812 .22941 Mdot
.812 .22956 Mdot
.812 .23024 Mdot
.812 .23061 Mdot
.812 .23094 Mdot
.812 .23119 Mdot
.812 .23126 Mdot
.812 .23141 Mdot
.812 .23187 Mdot
.812 .23249 Mdot
.812 .23456 Mdot
.812 .23468 Mdot
.812 .2349 Mdot
.812 .23532 Mdot
.812 .23577 Mdot
.812 .23642 Mdot
.812 .2369 Mdot
.812 .23732 Mdot
.812 .23794 Mdot
.812 .23809 Mdot
.812 .23839 Mdot
.812 .23849 Mdot
.812 .23852 Mdot
.812 .23892 Mdot
.812 .24011 Mdot
.812 .24123 Mdot
.812 .24127 Mdot
.812 .24131 Mdot
.812 .24231 Mdot
.812 .24271 Mdot
.812 .24462 Mdot
.812 .24472 Mdot
.812 .24489 Mdot
.812 .24518 Mdot
.812 .24536 Mdot
.812 .24585 Mdot
.812 .24645 Mdot
.812 .24647 Mdot
.812 .24677 Mdot
.812 .24743 Mdot
.812 .2478 Mdot
.812 .24946 Mdot
.812 .24958 Mdot
.812 .24975 Mdot
.812 .25001 Mdot
.812 .25002 Mdot
.812 .25059 Mdot
.812 .25131 Mdot
.812 .25217 Mdot
.812 .25287 Mdot
.812 .25309 Mdot
.812 .25332 Mdot
.812 .25363 Mdot
.812 .25374 Mdot
.812 .25379 Mdot
.812 .25381 Mdot
.812 .25385 Mdot
.812 .25396 Mdot
.812 .254 Mdot
.812 .25417 Mdot
.812 .25422 Mdot
.812 .25505 Mdot
.812 .25529 Mdot
.812 .25547 Mdot
.812 .25557 Mdot
.812 .25642 Mdot
.812 .25646 Mdot
.812 .2565 Mdot
.812 .25663 Mdot
.812 .25764 Mdot
.812 .25769 Mdot
.812 .25813 Mdot
.812 .25821 Mdot
.812 .25821 Mdot
.812 .25899 Mdot
.812 .25926 Mdot
.812 .25995 Mdot
.812 .261 Mdot
.812 .26127 Mdot
.812 .26192 Mdot
.812 .26222 Mdot
.812 .26223 Mdot
.812 .26246 Mdot
.812 .26249 Mdot
.812 .26389 Mdot
.812 .2642 Mdot
.812 .26433 Mdot
.812 .26513 Mdot
.812 .26533 Mdot
.812 .26558 Mdot
.812 .26584 Mdot
.812 .26593 Mdot
.812 .26619 Mdot
.812 .26702 Mdot
.812 .26738 Mdot
.812 .26751 Mdot
.812 .26758 Mdot
.812 .26808 Mdot
.812 .26821 Mdot
.812 .26843 Mdot
.812 .26911 Mdot
.812 .27022 Mdot
.812 .27034 Mdot
.812 .27102 Mdot
.812 .2714 Mdot
.812 .27203 Mdot
.812 .27212 Mdot
.812 .27219 Mdot
.812 .27225 Mdot
.812 .27332 Mdot
.812 .27426 Mdot
.812 .27465 Mdot
.812 .27486 Mdot
.812 .27501 Mdot
.812 .27526 Mdot
.812 .27583 Mdot
.812 .2761 Mdot
.812 .27659 Mdot
.812 .2766 Mdot
.812 .27771 Mdot
.812 .27779 Mdot
.812 .27806 Mdot
.812 .27814 Mdot
.812 .27828 Mdot
.812 .27888 Mdot
.812 .27899 Mdot
.812 .2792 Mdot
.812 .2793 Mdot
.812 .27935 Mdot
.812 .27958 Mdot
.812 .28039 Mdot
.812 .28067 Mdot
.812 .28081 Mdot
.812 .28111 Mdot
.812 .28188 Mdot
.812 .28193 Mdot
.812 .28212 Mdot
.812 .28214 Mdot
.812 .28264 Mdot
.812 .28278 Mdot
.812 .28404 Mdot
.812 .28415 Mdot
.812 .28501 Mdot
.812 .28537 Mdot
.812 .28567 Mdot
.812 .28567 Mdot
.812 .28627 Mdot
.812 .28632 Mdot
.812 .28633 Mdot
.812 .28671 Mdot
.812 .28677 Mdot
.812 .28687 Mdot
.812 .28718 Mdot
.812 .28728 Mdot
.812 .28761 Mdot
.812 .28796 Mdot
.812 .28828 Mdot
.812 .28899 Mdot
.812 .29054 Mdot
.812 .29072 Mdot
.812 .29078 Mdot
.812 .29208 Mdot
.812 .29315 Mdot
.812 .29359 Mdot
.812 .29375 Mdot
.812 .29393 Mdot
.812 .29418 Mdot
.812 .29459 Mdot
.812 .29464 Mdot
.812 .29583 Mdot
.812 .29653 Mdot
.812 .29659 Mdot
.812 .29685 Mdot
.812 .29698 Mdot
.812 .29718 Mdot
.812 .29804 Mdot
.812 .2983 Mdot
.812 .29863 Mdot
.812 .29863 Mdot
.812 .29894 Mdot
.812 .29915 Mdot
.812 .30008 Mdot
.812 .30102 Mdot
.812 .30188 Mdot
.812 .30283 Mdot
.812 .30301 Mdot
.812 .30367 Mdot
.812 .30426 Mdot
.812 .30461 Mdot
.812 .30501 Mdot
.812 .30525 Mdot
.812 .30529 Mdot
.812 .30593 Mdot
.812 .30611 Mdot
.812 .30644 Mdot
.812 .30701 Mdot
.812 .30707 Mdot
.812 .30724 Mdot
.812 .30739 Mdot
.812 .30753 Mdot
.812 .30777 Mdot
.812 .30791 Mdot
.812 .30795 Mdot
.812 .30874 Mdot
.812 .30891 Mdot
.812 .30957 Mdot
.812 .3097 Mdot
.812 .30986 Mdot
.812 .31005 Mdot
.812 .31027 Mdot
.812 .31051 Mdot
.812 .31059 Mdot
.812 .31074 Mdot
.812 .31092 Mdot
.812 .31106 Mdot
.812 .31118 Mdot
.812 .31134 Mdot
.812 .3117 Mdot
.812 .31184 Mdot
.812 .31238 Mdot
.812 .31247 Mdot
.812 .31307 Mdot
.812 .3133 Mdot
.812 .3134 Mdot
.812 .3135 Mdot
.812 .3136 Mdot
.812 .31417 Mdot
.812 .31428 Mdot
.812 .31447 Mdot
.812 .31473 Mdot
.812 .31484 Mdot
.812 .31487 Mdot
.812 .31549 Mdot
.812 .31565 Mdot
.812 .31584 Mdot
.812 .31642 Mdot
.812 .31649 Mdot
.812 .31712 Mdot
.812 .31712 Mdot
.812 .31775 Mdot
.812 .31806 Mdot
.812 .31848 Mdot
.812 .31874 Mdot
.812 .31876 Mdot
.812 .3191 Mdot
.812 .31933 Mdot
.812 .31943 Mdot
.812 .32002 Mdot
.812 .32005 Mdot
.812 .32005 Mdot
.812 .32084 Mdot
.812 .32118 Mdot
.812 .32168 Mdot
.812 .3219 Mdot
.812 .32243 Mdot
.812 .32256 Mdot
.812 .3226 Mdot
.812 .32267 Mdot
.812 .32312 Mdot
.812 .32326 Mdot
.812 .32339 Mdot
.812 .32348 Mdot
.812 .32351 Mdot
.812 .32374 Mdot
.812 .32397 Mdot
.812 .32488 Mdot
.812 .32505 Mdot
.812 .32604 Mdot
.812 .3261 Mdot
.812 .32621 Mdot
.812 .32626 Mdot
.812 .32641 Mdot
.812 .32686 Mdot
.812 .32729 Mdot
.812 .3273 Mdot
.812 .32769 Mdot
.812 .32785 Mdot
.812 .32857 Mdot
.812 .32878 Mdot
.812 .32904 Mdot
.812 .32926 Mdot
.812 .32927 Mdot
.812 .32939 Mdot
.812 .32964 Mdot
.812 .32978 Mdot
.812 .33045 Mdot
.812 .33052 Mdot
.812 .33062 Mdot
.812 .33062 Mdot
.812 .33084 Mdot
.812 .3317 Mdot
.812 .33187 Mdot
.812 .33199 Mdot
.812 .33203 Mdot
.812 .33205 Mdot
.812 .33206 Mdot
.812 .33207 Mdot
.812 .33213 Mdot
.812 .33219 Mdot
.812 .33272 Mdot
.812 .33305 Mdot
.812 .33351 Mdot
.812 .33353 Mdot
.812 .33369 Mdot
.812 .33412 Mdot
.812 .33478 Mdot
.812 .33488 Mdot
.812 .33513 Mdot
.812 .33525 Mdot
.812 .33533 Mdot
.812 .33588 Mdot
.812 .33599 Mdot
.812 .33605 Mdot
.812 .33635 Mdot
.812 .33643 Mdot
.812 .33652 Mdot
.812 .33665 Mdot
.812 .33707 Mdot
.812 .3372 Mdot
.812 .3376 Mdot
.812 .33786 Mdot
.812 .33833 Mdot
.812 .33897 Mdot
.812 .33903 Mdot
.812 .33905 Mdot
.812 .33945 Mdot
.812 .33996 Mdot
.812 .3407 Mdot
.812 .3407 Mdot
.812 .34115 Mdot
.812 .34128 Mdot
.812 .34156 Mdot
.812 .34172 Mdot
.812 .34174 Mdot
.812 .34183 Mdot
.812 .34214 Mdot
.812 .34224 Mdot
.812 .34229 Mdot
.812 .34241 Mdot
.812 .3427 Mdot
.812 .34272 Mdot
.812 .34299 Mdot
.812 .34304 Mdot
.812 .34352 Mdot
.812 .34389 Mdot
.812 .34402 Mdot
.812 .34414 Mdot
.812 .34436 Mdot
.812 .34439 Mdot
.812 .34456 Mdot
.812 .34459 Mdot
.812 .34471 Mdot
.812 .34487 Mdot
.812 .345 Mdot
.812 .34539 Mdot
.812 .34598 Mdot
.812 .34605 Mdot
.812 .34657 Mdot
.812 .34697 Mdot
.812 .34752 Mdot
.812 .34754 Mdot
.812 .34825 Mdot
.812 .34828 Mdot
.812 .34842 Mdot
.812 .3485 Mdot
.812 .34883 Mdot
.812 .34892 Mdot
.812 .34905 Mdot
.812 .34925 Mdot
.812 .3496 Mdot
.812 .34996 Mdot
.812 .35064 Mdot
.812 .35071 Mdot
.812 .35147 Mdot
.812 .35156 Mdot
.812 .35158 Mdot
.812 .35223 Mdot
.812 .35225 Mdot
.812 .35243 Mdot
.812 .35258 Mdot
.812 .35295 Mdot
.812 .35331 Mdot
.812 .35338 Mdot
.812 .35371 Mdot
.812 .35461 Mdot
.812 .35465 Mdot
.812 .35469 Mdot
.812 .35494 Mdot
.812 .35606 Mdot
.812 .35642 Mdot
.812 .35717 Mdot
.812 .35787 Mdot
.812 .35808 Mdot
.812 .35847 Mdot
.812 .35857 Mdot
.812 .35901 Mdot
.812 .35907 Mdot
.812 .35951 Mdot
.812 .35992 Mdot
.812 .36067 Mdot
.812 .36081 Mdot
.812 .36086 Mdot
.812 .36112 Mdot
.812 .36159 Mdot
.812 .36165 Mdot
.812 .36172 Mdot
.812 .36172 Mdot
.812 .36173 Mdot
.812 .36178 Mdot
.812 .36228 Mdot
.812 .36235 Mdot
.812 .36251 Mdot
.812 .3628 Mdot
.812 .36322 Mdot
.812 .36338 Mdot
.812 .36342 Mdot
.812 .36362 Mdot
.812 .36368 Mdot
.812 .36453 Mdot
.812 .36472 Mdot
.812 .365 Mdot
.812 .36533 Mdot
.812 .36577 Mdot
.812 .36587 Mdot
.812 .36621 Mdot
.812 .36626 Mdot
.812 .36639 Mdot
.812 .36646 Mdot
.812 .36648 Mdot
.812 .36663 Mdot
.812 .36678 Mdot
.812 .36738 Mdot
.812 .36759 Mdot
.812 .36787 Mdot
.812 .36787 Mdot
.812 .36817 Mdot
.812 .36824 Mdot
.812 .36838 Mdot
.812 .36851 Mdot
.812 .36877 Mdot
.812 .36951 Mdot
.812 .37031 Mdot
.812 .37151 Mdot
.812 .37174 Mdot
.812 .37194 Mdot
.812 .37229 Mdot
.812 .37257 Mdot
.812 .37274 Mdot
.812 .37297 Mdot
.812 .37298 Mdot
.812 .37362 Mdot
.812 .37371 Mdot
.812 .37477 Mdot
.812 .37489 Mdot
.812 .3752 Mdot
.812 .3753 Mdot
.812 .37531 Mdot
.812 .37542 Mdot
.812 .37545 Mdot
.812 .37555 Mdot
.812 .37593 Mdot
.812 .37623 Mdot
.812 .37715 Mdot
.812 .37724 Mdot
.812 .37748 Mdot
.812 .37797 Mdot
.812 .37812 Mdot
.812 .37818 Mdot
.812 .37836 Mdot
.812 .37882 Mdot
.812 .38076 Mdot
.812 .3815 Mdot
.812 .38226 Mdot
.812 .38255 Mdot
.812 .38257 Mdot
.812 .38264 Mdot
.812 .38264 Mdot
.812 .3827 Mdot
.812 .38289 Mdot
.812 .38368 Mdot
.812 .38408 Mdot
.812 .38422 Mdot
.812 .38432 Mdot
.812 .38497 Mdot
.812 .38572 Mdot
.812 .38621 Mdot
.812 .38682 Mdot
.812 .38699 Mdot
.812 .38703 Mdot
.812 .38721 Mdot
.812 .38722 Mdot
.812 .38739 Mdot
.812 .38789 Mdot
.812 .38808 Mdot
.812 .38808 Mdot
.812 .38824 Mdot
.812 .38851 Mdot
.812 .38898 Mdot
.812 .38927 Mdot
.812 .3898 Mdot
.812 .38996 Mdot
.812 .39008 Mdot
.812 .391 Mdot
.812 .391 Mdot
.812 .39105 Mdot
.812 .39108 Mdot
.812 .39138 Mdot
.812 .39157 Mdot
.812 .39165 Mdot
.812 .39212 Mdot
.812 .39264 Mdot
.812 .39268 Mdot
.812 .393 Mdot
.812 .39325 Mdot
.812 .39337 Mdot
.812 .39534 Mdot
.812 .39594 Mdot
.812 .39614 Mdot
.812 .39641 Mdot
.812 .39663 Mdot
.812 .39684 Mdot
.812 .39685 Mdot
.812 .39778 Mdot
.812 .39783 Mdot
.812 .39825 Mdot
.812 .39847 Mdot
.812 .39869 Mdot
.812 .3988 Mdot
.812 .39894 Mdot
.812 .39928 Mdot
.812 .3993 Mdot
.812 .39974 Mdot
.812 .40009 Mdot
.812 .40034 Mdot
.812 .40106 Mdot
.812 .4013 Mdot
.812 .40148 Mdot
.812 .40155 Mdot
.812 .40157 Mdot
.812 .40169 Mdot
.812 .40183 Mdot
.812 .4019 Mdot
.812 .40199 Mdot
.812 .40221 Mdot
.812 .40254 Mdot
.812 .40271 Mdot
.812 .40272 Mdot
.812 .4029 Mdot
.812 .40297 Mdot
.812 .403 Mdot
.812 .40306 Mdot
.812 .40325 Mdot
.812 .40331 Mdot
.812 .40342 Mdot
.812 .40359 Mdot
.812 .40367 Mdot
.812 .40395 Mdot
.812 .40441 Mdot
.812 .40472 Mdot
.812 .40502 Mdot
.812 .40541 Mdot
.812 .4057 Mdot
.812 .40586 Mdot
.812 .4061 Mdot
.812 .40619 Mdot
.812 .40652 Mdot
.812 .40658 Mdot
.812 .40685 Mdot
.812 .40725 Mdot
.812 .4073 Mdot
.812 .40738 Mdot
.812 .40753 Mdot
.812 .40759 Mdot
.812 .408 Mdot
.812 .40826 Mdot
.812 .40838 Mdot
.812 .40919 Mdot
.812 .40923 Mdot
.812 .40926 Mdot
.812 .40927 Mdot
.812 .40928 Mdot
.812 .40931 Mdot
.812 .40938 Mdot
.812 .40949 Mdot
.812 .41002 Mdot
.812 .41016 Mdot
.812 .41016 Mdot
.812 .41026 Mdot
.812 .41067 Mdot
.812 .41076 Mdot
.812 .41099 Mdot
.812 .41142 Mdot
.812 .41186 Mdot
.812 .41221 Mdot
.812 .41287 Mdot
.812 .41297 Mdot
.812 .41359 Mdot
.812 .41369 Mdot
.812 .41439 Mdot
.812 .41455 Mdot
.812 .41469 Mdot
.812 .41512 Mdot
.812 .4152 Mdot
.812 .41552 Mdot
.812 .41618 Mdot
.812 .41666 Mdot
.812 .41667 Mdot
.812 .41668 Mdot
.812 .41705 Mdot
.812 .41711 Mdot
.812 .41789 Mdot
.812 .41847 Mdot
.812 .41937 Mdot
.812 .41987 Mdot
.812 .4201 Mdot
.812 .42028 Mdot
.812 .4207 Mdot
.812 .42076 Mdot
.812 .42082 Mdot
.812 .42138 Mdot
.812 .42172 Mdot
.812 .42212 Mdot
.812 .42229 Mdot
.812 .42254 Mdot
.812 .42268 Mdot
.812 .42282 Mdot
.812 .42294 Mdot
.812 .42312 Mdot
.812 .42352 Mdot
.812 .42412 Mdot
.812 .42437 Mdot
.812 .42446 Mdot
.812 .42466 Mdot
.812 .4247 Mdot
.812 .42504 Mdot
.812 .42525 Mdot
.812 .42536 Mdot
.812 .42575 Mdot
.812 .42577 Mdot
.812 .42592 Mdot
.812 .42617 Mdot
.812 .42639 Mdot
.812 .42675 Mdot
.812 .42716 Mdot
.812 .42727 Mdot
.812 .42785 Mdot
.812 .42838 Mdot
.812 .42896 Mdot
.812 .42954 Mdot
.812 .42966 Mdot
.812 .42985 Mdot
.812 .42986 Mdot
.812 .43006 Mdot
.812 .43022 Mdot
.812 .43075 Mdot
.812 .43087 Mdot
.812 .43095 Mdot
.812 .43111 Mdot
.812 .43115 Mdot
.812 .43158 Mdot
.812 .43231 Mdot
.812 .43234 Mdot
.812 .4326 Mdot
.812 .43275 Mdot
.812 .43286 Mdot
.812 .43296 Mdot
.812 .43323 Mdot
.812 .43389 Mdot
.812 .43468 Mdot
.812 .43472 Mdot
.812 .43483 Mdot
.812 .43579 Mdot
.812 .43622 Mdot
.812 .43642 Mdot
.812 .43664 Mdot
.812 .43684 Mdot
.812 .4369 Mdot
.812 .4371 Mdot
.812 .43715 Mdot
.812 .43719 Mdot
.812 .43743 Mdot
.812 .43744 Mdot
.812 .43747 Mdot
.812 .43784 Mdot
.812 .43784 Mdot
.812 .43802 Mdot
.812 .43824 Mdot
.812 .43877 Mdot
.812 .43883 Mdot
.812 .43962 Mdot
.812 .4397 Mdot
.812 .44001 Mdot
.812 .44002 Mdot
.812 .44014 Mdot
.812 .44017 Mdot
.812 .44064 Mdot
.812 .44083 Mdot
.812 .44092 Mdot
.812 .44108 Mdot
.812 .44158 Mdot
.812 .44172 Mdot
.812 .44176 Mdot
.812 .44182 Mdot
.812 .44195 Mdot
.812 .44201 Mdot
.812 .44239 Mdot
.812 .44247 Mdot
.812 .44252 Mdot
.812 .44269 Mdot
.812 .44274 Mdot
.812 .44342 Mdot
.812 .44342 Mdot
.812 .44373 Mdot
.812 .44389 Mdot
.812 .44425 Mdot
.812 .4444 Mdot
.812 .44449 Mdot
.812 .44462 Mdot
.812 .44486 Mdot
.812 .44544 Mdot
.812 .44609 Mdot
.812 .44613 Mdot
.812 .44617 Mdot
.812 .44623 Mdot
.812 .44662 Mdot
.812 .44686 Mdot
.812 .44727 Mdot
.812 .44734 Mdot
.812 .44803 Mdot
.812 .44845 Mdot
.812 .44859 Mdot
.812 .44867 Mdot
.812 .44898 Mdot
.812 .44902 Mdot
.812 .4491 Mdot
.812 .44932 Mdot
.812 .44983 Mdot
.812 .44999 Mdot
.812 .45005 Mdot
.812 .4502 Mdot
.812 .45036 Mdot
.812 .45048 Mdot
.812 .45097 Mdot
.812 .45106 Mdot
.812 .45125 Mdot
.812 .45211 Mdot
.812 .45213 Mdot
.812 .45227 Mdot
.812 .45227 Mdot
.812 .45246 Mdot
.812 .45286 Mdot
.812 .45302 Mdot
.812 .45367 Mdot
.812 .45409 Mdot
.812 .45426 Mdot
.812 .45474 Mdot
.812 .45474 Mdot
.812 .45479 Mdot
.812 .45506 Mdot
.812 .45509 Mdot
.812 .45571 Mdot
.812 .45579 Mdot
.812 .45582 Mdot
.812 .45584 Mdot
.812 .45637 Mdot
.812 .45643 Mdot
.812 .45654 Mdot
.812 .45669 Mdot
.812 .4572 Mdot
.812 .45723 Mdot
.812 .45734 Mdot
.812 .45736 Mdot
.812 .45743 Mdot
.812 .45745 Mdot
.812 .45747 Mdot
.812 .45749 Mdot
.812 .45756 Mdot
.812 .45775 Mdot
.812 .4579 Mdot
.812 .45803 Mdot
.812 .45846 Mdot
.812 .45899 Mdot
.812 .45943 Mdot
.812 .45979 Mdot
.812 .45979 Mdot
.812 .45995 Mdot
.812 .46005 Mdot
.812 .46013 Mdot
.812 .46115 Mdot
.812 .46138 Mdot
.812 .46179 Mdot
.812 .46197 Mdot
.812 .46199 Mdot
.812 .46235 Mdot
.812 .46266 Mdot
.812 .46277 Mdot
.812 .46295 Mdot
.812 .46305 Mdot
.812 .46311 Mdot
.812 .46429 Mdot
.812 .46454 Mdot
.812 .46515 Mdot
.812 .46517 Mdot
.812 .4652 Mdot
.812 .46589 Mdot
.812 .46662 Mdot
.812 .46687 Mdot
.812 .46689 Mdot
.812 .46695 Mdot
.812 .46713 Mdot
.812 .46722 Mdot
.812 .4676 Mdot
.812 .46786 Mdot
.812 .46816 Mdot
.812 .46856 Mdot
.812 .46884 Mdot
.812 .4691 Mdot
.812 .46923 Mdot
.812 .46931 Mdot
.812 .47058 Mdot
.812 .47096 Mdot
.812 .47124 Mdot
.812 .47133 Mdot
.812 .47138 Mdot
.812 .47153 Mdot
.812 .47174 Mdot
.812 .47197 Mdot
.812 .47238 Mdot
.812 .47248 Mdot
.812 .4727 Mdot
.812 .47281 Mdot
.812 .47287 Mdot
.812 .4729 Mdot
.812 .47308 Mdot
.812 .47311 Mdot
.812 .47343 Mdot
.812 .47394 Mdot
.812 .4743 Mdot
.812 .47483 Mdot
.812 .47512 Mdot
.812 .47525 Mdot
.812 .47567 Mdot
.812 .47579 Mdot
.812 .4758 Mdot
.812 .4763 Mdot
.812 .47663 Mdot
.812 .47695 Mdot
.812 .47696 Mdot
.812 .47699 Mdot
.812 .47796 Mdot
.812 .47812 Mdot
.812 .47815 Mdot
.812 .47849 Mdot
.812 .47905 Mdot
.812 .47907 Mdot
.812 .47949 Mdot
.812 .47968 Mdot
.812 .48019 Mdot
.812 .48069 Mdot
.812 .48108 Mdot
.812 .4817 Mdot
.812 .48171 Mdot
.812 .48261 Mdot
.812 .48273 Mdot
.812 .48284 Mdot
.812 .4829 Mdot
.812 .48379 Mdot
.812 .48398 Mdot
.812 .4841 Mdot
.812 .48436 Mdot
.812 .48494 Mdot
.812 .48537 Mdot
.812 .48541 Mdot
.812 .4855 Mdot
.812 .48559 Mdot
.812 .48601 Mdot
.812 .48616 Mdot
.812 .48632 Mdot
.812 .48649 Mdot
.812 .48655 Mdot
.812 .48661 Mdot
.812 .48742 Mdot
.812 .48759 Mdot
.812 .48764 Mdot
.812 .48774 Mdot
.812 .48791 Mdot
.812 .48794 Mdot
.812 .48829 Mdot
.812 .48848 Mdot
.812 .48927 Mdot
.812 .48939 Mdot
.812 .4894 Mdot
.812 .4895 Mdot
.812 .48978 Mdot
.812 .49001 Mdot
.812 .49025 Mdot
.812 .49028 Mdot
.812 .4905 Mdot
.812 .49064 Mdot
.812 .49087 Mdot
.812 .49092 Mdot
.812 .49109 Mdot
.812 .49135 Mdot
.812 .49155 Mdot
.812 .49178 Mdot
.812 .49207 Mdot
.812 .49221 Mdot
.812 .49231 Mdot
.812 .49244 Mdot
.812 .49249 Mdot
.812 .49283 Mdot
.812 .49319 Mdot
.812 .49351 Mdot
.812 .49356 Mdot
.812 .49376 Mdot
.814 .1934 Mdot
.814 .19384 Mdot
.814 .19399 Mdot
.814 .19467 Mdot
.814 .1947 Mdot
.814 .19485 Mdot
.814 .19516 Mdot
.814 .19529 Mdot
.814 .19602 Mdot
.814 .19621 Mdot
.814 .19625 Mdot
.814 .19657 Mdot
.814 .19658 Mdot
.814 .19726 Mdot
.814 .19793 Mdot
.814 .19834 Mdot
.814 .19838 Mdot
.814 .19843 Mdot
.814 .19859 Mdot
.814 .1987 Mdot
.814 .19918 Mdot
.814 .19993 Mdot
.814 .2012 Mdot
.814 .2014 Mdot
.814 .20161 Mdot
.814 .20164 Mdot
.814 .20168 Mdot
.814 .2021 Mdot
.814 .20228 Mdot
.814 .20238 Mdot
.814 .20245 Mdot
.814 .20384 Mdot
.814 .20402 Mdot
.814 .2042 Mdot
.814 .20426 Mdot
.814 .2049 Mdot
.814 .20492 Mdot
.814 .20524 Mdot
.814 .20541 Mdot
.814 .20582 Mdot
.814 .20688 Mdot
.814 .20699 Mdot
.814 .207 Mdot
.814 .20727 Mdot
.814 .20748 Mdot
.814 .20797 Mdot
.814 .20802 Mdot
.814 .2092 Mdot
.814 .20921 Mdot
.814 .21034 Mdot
.814 .21055 Mdot
.814 .2107 Mdot
.814 .2109 Mdot
.814 .21152 Mdot
.814 .2128 Mdot
.814 .21286 Mdot
.814 .21339 Mdot
.814 .21362 Mdot
.814 .21383 Mdot
.814 .21401 Mdot
.814 .21433 Mdot
.814 .21499 Mdot
.814 .21524 Mdot
.814 .21578 Mdot
.814 .21619 Mdot
.814 .21621 Mdot
.814 .21628 Mdot
.814 .21639 Mdot
.814 .21675 Mdot
.814 .2168 Mdot
.814 .21708 Mdot
.814 .21742 Mdot
.814 .21759 Mdot
.814 .21794 Mdot
.814 .21807 Mdot
.814 .21825 Mdot
.814 .21886 Mdot
.814 .21891 Mdot
.814 .21934 Mdot
.814 .21954 Mdot
.814 .21965 Mdot
.814 .21982 Mdot
.814 .21985 Mdot
.814 .22006 Mdot
.814 .22018 Mdot
.814 .22055 Mdot
.814 .22086 Mdot
.814 .22091 Mdot
.814 .22117 Mdot
.814 .22128 Mdot
.814 .22148 Mdot
.814 .22159 Mdot
.814 .22178 Mdot
.814 .2227 Mdot
.814 .22405 Mdot
.814 .22415 Mdot
.814 .22492 Mdot
.814 .22492 Mdot
.814 .22517 Mdot
.814 .22544 Mdot
.814 .22563 Mdot
.814 .22701 Mdot
.814 .22761 Mdot
.814 .22765 Mdot
.814 .22785 Mdot
.814 .22796 Mdot
.814 .2282 Mdot
.814 .22837 Mdot
.814 .22882 Mdot
.814 .22912 Mdot
.814 .22916 Mdot
.814 .22942 Mdot
.814 .23 Mdot
.814 .23023 Mdot
.814 .23143 Mdot
.814 .23199 Mdot
.814 .23216 Mdot
.814 .23224 Mdot
.814 .2331 Mdot
.814 .23349 Mdot
.814 .23361 Mdot
.814 .2337 Mdot
.814 .23389 Mdot
.814 .23438 Mdot
.814 .23612 Mdot
.814 .2366 Mdot
.814 .23688 Mdot
.814 .23689 Mdot
.814 .23867 Mdot
.814 .23916 Mdot
.814 .23985 Mdot
.814 .24067 Mdot
.814 .24069 Mdot
.814 .24118 Mdot
.814 .24121 Mdot
.814 .24211 Mdot
.814 .24239 Mdot
.814 .24281 Mdot
.814 .24331 Mdot
.814 .24369 Mdot
.814 .24509 Mdot
.814 .24539 Mdot
.814 .24562 Mdot
.814 .24616 Mdot
.814 .24755 Mdot
.814 .24782 Mdot
.814 .24801 Mdot
.814 .24819 Mdot
.814 .24969 Mdot
.814 .25034 Mdot
.814 .25053 Mdot
.814 .25064 Mdot
.814 .2507 Mdot
.814 .25072 Mdot
.814 .25077 Mdot
.814 .25156 Mdot
.814 .2537 Mdot
.814 .25384 Mdot
.814 .25413 Mdot
.814 .25433 Mdot
.814 .25447 Mdot
.814 .25565 Mdot
.814 .25567 Mdot
.814 .2563 Mdot
.814 .25643 Mdot
.814 .25654 Mdot
.814 .25719 Mdot
.814 .25765 Mdot
.814 .25805 Mdot
.814 .25844 Mdot
.814 .25918 Mdot
.814 .25961 Mdot
.814 .26009 Mdot
.814 .2603 Mdot
.814 .26071 Mdot
.814 .26075 Mdot
.814 .26143 Mdot
.814 .26272 Mdot
.814 .26292 Mdot
.814 .26331 Mdot
.814 .26411 Mdot
.814 .26451 Mdot
.814 .26466 Mdot
.814 .26487 Mdot
.814 .26508 Mdot
.814 .26525 Mdot
.814 .26561 Mdot
.814 .26626 Mdot
.814 .26652 Mdot
.814 .26698 Mdot
.814 .26745 Mdot
.814 .26778 Mdot
.814 .26822 Mdot
.814 .26874 Mdot
.814 .26879 Mdot
.814 .26892 Mdot
.814 .26953 Mdot
.814 .26976 Mdot
.814 .26981 Mdot
.814 .2704 Mdot
.814 .27059 Mdot
.814 .27068 Mdot
.814 .27146 Mdot
.814 .27284 Mdot
.814 .27297 Mdot
.814 .27394 Mdot
.814 .27445 Mdot
.814 .27478 Mdot
.814 .27495 Mdot
.814 .27533 Mdot
.814 .2757 Mdot
.814 .27609 Mdot
.814 .2764 Mdot
.814 .27677 Mdot
.814 .27739 Mdot
.814 .27758 Mdot
.814 .27837 Mdot
.814 .27848 Mdot
.814 .27898 Mdot
.814 .2791 Mdot
.814 .28063 Mdot
.814 .28087 Mdot
.814 .28096 Mdot
.814 .28119 Mdot
.814 .28125 Mdot
.814 .28162 Mdot
.814 .28174 Mdot
.814 .28244 Mdot
.814 .283 Mdot
.814 .28331 Mdot
.814 .28345 Mdot
.814 .28353 Mdot
.814 .28444 Mdot
.814 .2847 Mdot
.814 .28544 Mdot
.814 .2859 Mdot
.814 .28619 Mdot
.814 .28664 Mdot
.814 .28677 Mdot
.814 .28693 Mdot
.814 .28812 Mdot
.814 .28844 Mdot
.814 .28901 Mdot
.814 .28977 Mdot
.814 .29071 Mdot
.814 .29104 Mdot
.814 .2913 Mdot
.814 .29242 Mdot
.814 .2926 Mdot
.814 .29338 Mdot
.814 .29448 Mdot
.814 .2947 Mdot
.814 .29533 Mdot
.814 .29578 Mdot
.814 .29587 Mdot
.814 .29655 Mdot
.814 .29664 Mdot
.814 .29668 Mdot
.814 .29676 Mdot
.814 .297 Mdot
.814 .29752 Mdot
.814 .29759 Mdot
.814 .2977 Mdot
.814 .29808 Mdot
.814 .29897 Mdot
.814 .29909 Mdot
.814 .2992 Mdot
.814 .2993 Mdot
.814 .29944 Mdot
.814 .29958 Mdot
.814 .2997 Mdot
.814 .29982 Mdot
.814 .29989 Mdot
.814 .30055 Mdot
.814 .30062 Mdot
.814 .30101 Mdot
.814 .30108 Mdot
.814 .30124 Mdot
.814 .30144 Mdot
.814 .30179 Mdot
.814 .30191 Mdot
.814 .30197 Mdot
.814 .30236 Mdot
.814 .30285 Mdot
.814 .30329 Mdot
.814 .30372 Mdot
.814 .30372 Mdot
.814 .30419 Mdot
.814 .30445 Mdot
.814 .305 Mdot
.814 .30534 Mdot
.814 .30561 Mdot
.814 .30633 Mdot
.814 .30656 Mdot
.814 .30657 Mdot
.814 .30659 Mdot
.814 .30674 Mdot
.814 .30768 Mdot
.814 .30772 Mdot
.814 .3078 Mdot
.814 .30782 Mdot
.814 .30797 Mdot
.814 .30848 Mdot
.814 .30849 Mdot
.814 .30869 Mdot
.814 .30897 Mdot
.814 .30968 Mdot
.814 .30988 Mdot
.814 .30993 Mdot
.814 .31019 Mdot
.814 .3102 Mdot
.814 .31026 Mdot
.814 .31038 Mdot
.814 .31077 Mdot
.814 .31079 Mdot
.814 .31117 Mdot
.814 .31161 Mdot
.814 .31189 Mdot
.814 .31217 Mdot
.814 .31273 Mdot
.814 .31299 Mdot
.814 .3131 Mdot
.814 .31313 Mdot
.814 .31365 Mdot
.814 .31372 Mdot
.814 .31381 Mdot
.814 .31406 Mdot
.814 .31418 Mdot
.814 .31424 Mdot
.814 .3148 Mdot
.814 .31484 Mdot
.814 .31484 Mdot
.814 .31503 Mdot
.814 .31523 Mdot
.814 .31618 Mdot
.814 .31624 Mdot
.814 .31631 Mdot
.814 .31705 Mdot
.814 .31725 Mdot
.814 .31734 Mdot
.814 .31786 Mdot
.814 .31831 Mdot
.814 .31834 Mdot
.814 .31852 Mdot
.814 .31854 Mdot
.814 .31864 Mdot
.814 .31897 Mdot
.814 .31902 Mdot
.814 .31909 Mdot
.814 .31934 Mdot
.814 .31961 Mdot
.814 .31968 Mdot
.814 .31977 Mdot
.814 .32007 Mdot
.814 .32023 Mdot
.814 .32035 Mdot
.814 .32077 Mdot
.814 .32128 Mdot
.814 .3216 Mdot
.814 .3216 Mdot
.814 .32262 Mdot
.814 .32291 Mdot
.814 .32308 Mdot
.814 .32319 Mdot
.814 .3232 Mdot
.814 .3233 Mdot
.814 .32427 Mdot
.814 .32433 Mdot
.814 .32437 Mdot
.814 .32484 Mdot
.814 .32488 Mdot
.814 .32499 Mdot
.814 .32517 Mdot
.814 .32583 Mdot
.814 .32612 Mdot
.814 .32612 Mdot
.814 .32724 Mdot
.814 .32755 Mdot
.814 .32756 Mdot
.814 .32774 Mdot
.814 .32775 Mdot
.814 .3282 Mdot
.814 .32854 Mdot
.814 .32922 Mdot
.814 .32933 Mdot
.814 .32941 Mdot
.814 .33014 Mdot
.814 .33024 Mdot
.814 .33032 Mdot
.814 .3312 Mdot
.814 .33131 Mdot
.814 .33133 Mdot
.814 .33134 Mdot
.814 .33136 Mdot
.814 .33166 Mdot
.814 .33252 Mdot
.814 .3327 Mdot
.814 .3332 Mdot
.814 .33344 Mdot
.814 .33353 Mdot
.814 .33378 Mdot
.814 .3341 Mdot
.814 .33425 Mdot
.814 .33453 Mdot
.814 .33487 Mdot
.814 .33511 Mdot
.814 .33512 Mdot
.814 .33538 Mdot
.814 .33654 Mdot
.814 .3366 Mdot
.814 .33668 Mdot
.814 .33676 Mdot
.814 .33682 Mdot
.814 .3372 Mdot
.814 .3373 Mdot
.814 .33747 Mdot
.814 .33794 Mdot
.814 .33816 Mdot
.814 .33854 Mdot
.814 .33884 Mdot
.814 .33887 Mdot
.814 .33916 Mdot
.814 .33969 Mdot
.814 .33973 Mdot
.814 .3401 Mdot
.814 .34048 Mdot
.814 .34062 Mdot
.814 .34077 Mdot
.814 .34117 Mdot
.814 .3414 Mdot
.814 .34147 Mdot
.814 .34177 Mdot
.814 .34205 Mdot
.814 .34271 Mdot
.814 .34275 Mdot
.814 .34283 Mdot
.814 .34286 Mdot
.814 .34304 Mdot
.814 .34352 Mdot
.814 .34363 Mdot
.814 .34372 Mdot
.814 .34416 Mdot
.814 .34472 Mdot
.814 .34489 Mdot
.814 .345 Mdot
.814 .34557 Mdot
.814 .34578 Mdot
.814 .34607 Mdot
.814 .34665 Mdot
.814 .34707 Mdot
.814 .34714 Mdot
.814 .34744 Mdot
.814 .34785 Mdot
.814 .34817 Mdot
.814 .34834 Mdot
.814 .34837 Mdot
.814 .34863 Mdot
.814 .34867 Mdot
.814 .34868 Mdot
.814 .34902 Mdot
.814 .34906 Mdot
.814 .34921 Mdot
.814 .34954 Mdot
.814 .34967 Mdot
.814 .34972 Mdot
.814 .34977 Mdot
.814 .34982 Mdot
.814 .34989 Mdot
.814 .35014 Mdot
.814 .35017 Mdot
.814 .35031 Mdot
.814 .35034 Mdot
.814 .3504 Mdot
.814 .35068 Mdot
.814 .35082 Mdot
.814 .35101 Mdot
.814 .35133 Mdot
.814 .35134 Mdot
.814 .35151 Mdot
.814 .35182 Mdot
.814 .35241 Mdot
.814 .35247 Mdot
.814 .35288 Mdot
.814 .35332 Mdot
.814 .35359 Mdot
.814 .35368 Mdot
.814 .35385 Mdot
.814 .35487 Mdot
.814 .35551 Mdot
.814 .35553 Mdot
.814 .35553 Mdot
.814 .35568 Mdot
.814 .35604 Mdot
.814 .35637 Mdot
.814 .35644 Mdot
.814 .35685 Mdot
.814 .35692 Mdot
.814 .35693 Mdot
.814 .35723 Mdot
.814 .35733 Mdot
.814 .35736 Mdot
.814 .35777 Mdot
.814 .35808 Mdot
.814 .35808 Mdot
.814 .35936 Mdot
.814 .35979 Mdot
.814 .36033 Mdot
.814 .3613 Mdot
.814 .36137 Mdot
.814 .3617 Mdot
.814 .36176 Mdot
.814 .36188 Mdot
.814 .36227 Mdot
.814 .36255 Mdot
.814 .36318 Mdot
.814 .36328 Mdot
.814 .36377 Mdot
.814 .3638 Mdot
.814 .36382 Mdot
.814 .36407 Mdot
.814 .36425 Mdot
.814 .36459 Mdot
.814 .36521 Mdot
.814 .36558 Mdot
.814 .36609 Mdot
.814 .36635 Mdot
.814 .36687 Mdot
.814 .36753 Mdot
.814 .36818 Mdot
.814 .36829 Mdot
.814 .36844 Mdot
.814 .36871 Mdot
.814 .36885 Mdot
.814 .36892 Mdot
.814 .3693 Mdot
.814 .36973 Mdot
.814 .36988 Mdot
.814 .37015 Mdot
.814 .37019 Mdot
.814 .37025 Mdot
.814 .37064 Mdot
.814 .37088 Mdot
.814 .37088 Mdot
.814 .37108 Mdot
.814 .37123 Mdot
.814 .37152 Mdot
.814 .37233 Mdot
.814 .37249 Mdot
.814 .37411 Mdot
.814 .37487 Mdot
.814 .37497 Mdot
.814 .37516 Mdot
.814 .37566 Mdot
.814 .37594 Mdot
.814 .37624 Mdot
.814 .3763 Mdot
.814 .3764 Mdot
.814 .37641 Mdot
.814 .37668 Mdot
.814 .37789 Mdot
.814 .37848 Mdot
.814 .37886 Mdot
.814 .37932 Mdot
.814 .37969 Mdot
.814 .38 Mdot
.814 .38012 Mdot
.814 .3803 Mdot
.814 .38049 Mdot
.814 .381 Mdot
.814 .38124 Mdot
.814 .3816 Mdot
.814 .38234 Mdot
.814 .38257 Mdot
.814 .38261 Mdot
.814 .38297 Mdot
.814 .38339 Mdot
.814 .38345 Mdot
.814 .38392 Mdot
.814 .38491 Mdot
.814 .3859 Mdot
.814 .38605 Mdot
.814 .38633 Mdot
.814 .38635 Mdot
.814 .38651 Mdot
.814 .38661 Mdot
.814 .38687 Mdot
.814 .3871 Mdot
.814 .38749 Mdot
.814 .38756 Mdot
.814 .38837 Mdot
.814 .38868 Mdot
.814 .38884 Mdot
.814 .38977 Mdot
.814 .39009 Mdot
.814 .39025 Mdot
.814 .39063 Mdot
.814 .39151 Mdot
.814 .39272 Mdot
.814 .39298 Mdot
.814 .39376 Mdot
.814 .39421 Mdot
.814 .39429 Mdot
.814 .39452 Mdot
.814 .39477 Mdot
.814 .39482 Mdot
.814 .39502 Mdot
.814 .39533 Mdot
.814 .39533 Mdot
.814 .39573 Mdot
.814 .39637 Mdot
.814 .39647 Mdot
.814 .39653 Mdot
.814 .39696 Mdot
.814 .39721 Mdot
.814 .39725 Mdot
.814 .39791 Mdot
.814 .39831 Mdot
.814 .39852 Mdot
.814 .39863 Mdot
.814 .39864 Mdot
.814 .3988 Mdot
.814 .39887 Mdot
.814 .3989 Mdot
.814 .39893 Mdot
.814 .39901 Mdot
.814 .3993 Mdot
.814 .39955 Mdot
.814 .39973 Mdot
.814 .4003 Mdot
.814 .40079 Mdot
.814 .40187 Mdot
.814 .40271 Mdot
.814 .40313 Mdot
.814 .40378 Mdot
.814 .40397 Mdot
.814 .40401 Mdot
.814 .40449 Mdot
.814 .40458 Mdot
.814 .40481 Mdot
.814 .40504 Mdot
.814 .40559 Mdot
.814 .40614 Mdot
.814 .40642 Mdot
.814 .40682 Mdot
.814 .40686 Mdot
.814 .40691 Mdot
.814 .40696 Mdot
.814 .407 Mdot
.814 .40771 Mdot
.814 .40787 Mdot
.814 .40802 Mdot
.814 .40823 Mdot
.814 .4084 Mdot
.814 .4089 Mdot
.814 .40935 Mdot
.814 .40947 Mdot
.814 .41 Mdot
.814 .41019 Mdot
.814 .41021 Mdot
.814 .41028 Mdot
.814 .41082 Mdot
.814 .41086 Mdot
.814 .41093 Mdot
.814 .4115 Mdot
.814 .41252 Mdot
.814 .41271 Mdot
.814 .4134 Mdot
.814 .4134 Mdot
.814 .41409 Mdot
.814 .41418 Mdot
.814 .41453 Mdot
.814 .41519 Mdot
.814 .41527 Mdot
.814 .41617 Mdot
.814 .41617 Mdot
.814 .41637 Mdot
.814 .41669 Mdot
.814 .41735 Mdot
.814 .41739 Mdot
.814 .41756 Mdot
.814 .41805 Mdot
.814 .41806 Mdot
.814 .41817 Mdot
.814 .41847 Mdot
.814 .41879 Mdot
.814 .41884 Mdot
.814 .41897 Mdot
.814 .41942 Mdot
.814 .4195 Mdot
.814 .42009 Mdot
.814 .42032 Mdot
.814 .42033 Mdot
.814 .42035 Mdot
.814 .42073 Mdot
.814 .42138 Mdot
.814 .4214 Mdot
.814 .42162 Mdot
.814 .42196 Mdot
.814 .42231 Mdot
.814 .42258 Mdot
.814 .42307 Mdot
.814 .42318 Mdot
.814 .42334 Mdot
.814 .42349 Mdot
.814 .42393 Mdot
.814 .42423 Mdot
.814 .42464 Mdot
.814 .42465 Mdot
.814 .4253 Mdot
.814 .4254 Mdot
.814 .42541 Mdot
.814 .42616 Mdot
.814 .42637 Mdot
.814 .42671 Mdot
.814 .42687 Mdot
.814 .42716 Mdot
.814 .42716 Mdot
.814 .42742 Mdot
.814 .42769 Mdot
.814 .42799 Mdot
.814 .42823 Mdot
.814 .42827 Mdot
.814 .42834 Mdot
.814 .42856 Mdot
.814 .42868 Mdot
.814 .42878 Mdot
.814 .42882 Mdot
.814 .42906 Mdot
.814 .4291 Mdot
.814 .42951 Mdot
.814 .42955 Mdot
.814 .42963 Mdot
.814 .4297 Mdot
.814 .42979 Mdot
.814 .42987 Mdot
.814 .42993 Mdot
.814 .43 Mdot
.814 .43007 Mdot
.814 .43062 Mdot
.814 .43086 Mdot
.814 .43092 Mdot
.814 .43096 Mdot
.814 .43128 Mdot
.814 .43143 Mdot
.814 .43148 Mdot
.814 .4315 Mdot
.814 .43156 Mdot
.814 .43198 Mdot
.814 .43203 Mdot
.814 .43231 Mdot
.814 .4327 Mdot
.814 .43284 Mdot
.814 .43351 Mdot
.814 .43399 Mdot
.814 .4341 Mdot
.814 .43478 Mdot
.814 .43495 Mdot
.814 .43515 Mdot
.814 .43572 Mdot
.814 .43619 Mdot
.814 .43654 Mdot
.814 .43674 Mdot
.814 .43747 Mdot
.814 .43757 Mdot
.814 .43765 Mdot
.814 .43793 Mdot
.814 .4381 Mdot
.814 .43838 Mdot
.814 .43884 Mdot
.814 .439 Mdot
.814 .43956 Mdot
.814 .43961 Mdot
.814 .4397 Mdot
.814 .43988 Mdot
.814 .44023 Mdot
.814 .44066 Mdot
.814 .44073 Mdot
.814 .44096 Mdot
.814 .441 Mdot
.814 .44114 Mdot
.814 .44119 Mdot
.814 .44134 Mdot
.814 .44228 Mdot
.814 .44236 Mdot
.814 .44266 Mdot
.814 .44273 Mdot
.814 .44321 Mdot
.814 .44333 Mdot
.814 .44371 Mdot
.814 .44394 Mdot
.814 .44413 Mdot
.814 .44436 Mdot
.814 .44459 Mdot
.814 .44483 Mdot
.814 .44493 Mdot
.814 .44513 Mdot
.814 .44545 Mdot
.814 .44605 Mdot
.814 .44612 Mdot
.814 .44697 Mdot
.814 .44745 Mdot
.814 .44751 Mdot
.814 .44763 Mdot
.814 .44799 Mdot
.814 .44802 Mdot
.814 .44816 Mdot
.814 .44853 Mdot
.814 .44861 Mdot
.814 .44864 Mdot
.814 .44896 Mdot
.814 .44923 Mdot
.814 .44944 Mdot
.814 .44973 Mdot
.814 .45001 Mdot
.814 .45017 Mdot
.814 .45056 Mdot
.814 .45079 Mdot
.814 .45089 Mdot
.814 .45102 Mdot
.814 .45115 Mdot
.814 .45124 Mdot
.814 .45149 Mdot
.814 .45198 Mdot
.814 .45222 Mdot
.814 .45234 Mdot
.814 .45313 Mdot
.814 .45355 Mdot
.814 .45358 Mdot
.814 .45383 Mdot
.814 .45396 Mdot
.814 .45425 Mdot
.814 .45451 Mdot
.814 .45497 Mdot
.814 .45521 Mdot
.814 .45546 Mdot
.814 .45574 Mdot
.814 .45614 Mdot
.814 .4562 Mdot
.814 .45628 Mdot
.814 .45667 Mdot
.814 .45668 Mdot
.814 .45741 Mdot
.814 .45749 Mdot
.814 .45762 Mdot
.814 .4578 Mdot
.814 .45788 Mdot
.814 .45919 Mdot
.814 .45968 Mdot
.814 .45971 Mdot
.814 .45972 Mdot
.814 .45976 Mdot
.814 .45983 Mdot
.814 .45994 Mdot
.814 .46035 Mdot
.814 .46126 Mdot
.814 .46138 Mdot
.814 .46149 Mdot
.814 .46166 Mdot
.814 .46251 Mdot
.814 .46284 Mdot
.814 .46299 Mdot
.814 .46317 Mdot
.814 .46403 Mdot
.814 .46426 Mdot
.814 .46457 Mdot
.814 .46483 Mdot
.814 .465 Mdot
.814 .46555 Mdot
.814 .46557 Mdot
.814 .46587 Mdot
.814 .46588 Mdot
.814 .46639 Mdot
.814 .46681 Mdot
.814 .46711 Mdot
.814 .46821 Mdot
.814 .46821 Mdot
.814 .46839 Mdot
.814 .46868 Mdot
.814 .46975 Mdot
.814 .47005 Mdot
.814 .47016 Mdot
.814 .47022 Mdot
.814 .47029 Mdot
.814 .47053 Mdot
.814 .47106 Mdot
.814 .47111 Mdot
.814 .47121 Mdot
.814 .47156 Mdot
.814 .4723 Mdot
.814 .47244 Mdot
.814 .4728 Mdot
.814 .47296 Mdot
.814 .47298 Mdot
.814 .47316 Mdot
.814 .47344 Mdot
.814 .47354 Mdot
.814 .47369 Mdot
.814 .47376 Mdot
.814 .47388 Mdot
.814 .47391 Mdot
.814 .47428 Mdot
.814 .47512 Mdot
.814 .47524 Mdot
.814 .47541 Mdot
.814 .47556 Mdot
.814 .47556 Mdot
.814 .47603 Mdot
.814 .47609 Mdot
.814 .47692 Mdot
.814 .47749 Mdot
.814 .4776 Mdot
.814 .47767 Mdot
.814 .47779 Mdot
.814 .47786 Mdot
.814 .47802 Mdot
.814 .47806 Mdot
.814 .47824 Mdot
.814 .47847 Mdot
.814 .47854 Mdot
.814 .47867 Mdot
.814 .47869 Mdot
.814 .4788 Mdot
.814 .47886 Mdot
.814 .47899 Mdot
.814 .47925 Mdot
.814 .47965 Mdot
.814 .47976 Mdot
.814 .47984 Mdot
.814 .48006 Mdot
.814 .48017 Mdot
.814 .48038 Mdot
.814 .48054 Mdot
.814 .48058 Mdot
.814 .4808 Mdot
.814 .48087 Mdot
.814 .48091 Mdot
.814 .48092 Mdot
.814 .48117 Mdot
.814 .48151 Mdot
.814 .48166 Mdot
.814 .48207 Mdot
.814 .48226 Mdot
.814 .48237 Mdot
.814 .4825 Mdot
.814 .48264 Mdot
.814 .48297 Mdot
.814 .483 Mdot
.814 .48379 Mdot
.814 .48417 Mdot
.814 .48429 Mdot
.814 .48439 Mdot
.814 .48451 Mdot
.814 .48521 Mdot
.814 .48522 Mdot
.814 .48594 Mdot
.814 .48597 Mdot
.814 .48627 Mdot
.814 .4864 Mdot
.814 .48657 Mdot
.814 .48657 Mdot
.814 .48664 Mdot
.814 .48729 Mdot
.814 .48754 Mdot
.814 .48765 Mdot
.814 .48784 Mdot
.814 .48786 Mdot
.814 .48825 Mdot
.814 .48829 Mdot
.814 .4884 Mdot
.814 .4885 Mdot
.814 .48936 Mdot
.814 .48941 Mdot
.814 .48947 Mdot
.814 .48958 Mdot
.814 .48984 Mdot
.814 .48986 Mdot
.814 .48988 Mdot
.814 .49 Mdot
.814 .49013 Mdot
.814 .49091 Mdot
.814 .49137 Mdot
.814 .49166 Mdot
.814 .49173 Mdot
.814 .49183 Mdot
.814 .49186 Mdot
.814 .49189 Mdot
.814 .49214 Mdot
.814 .49255 Mdot
.814 .49297 Mdot
.814 .49297 Mdot
.814 .49317 Mdot
.814 .49319 Mdot
.814 .49331 Mdot
.814 .49376 Mdot
.814 .49384 Mdot
.814 .49403 Mdot
.814 .49412 Mdot
.814 .49414 Mdot
.814 .49456 Mdot
.814 .49465 Mdot
.814 .49492 Mdot
.816 .19192 Mdot
.816 .19203 Mdot
.816 .19238 Mdot
.816 .19242 Mdot
.816 .19247 Mdot
.816 .19248 Mdot
.816 .19302 Mdot
.816 .19307 Mdot
.816 .19311 Mdot
.816 .19314 Mdot
.816 .1932 Mdot
.816 .19321 Mdot
.816 .19346 Mdot
.816 .19365 Mdot
.816 .19402 Mdot
.816 .19423 Mdot
.816 .19519 Mdot
.816 .19545 Mdot
.816 .1955 Mdot
.816 .19573 Mdot
.816 .19601 Mdot
.816 .19629 Mdot
.816 .19723 Mdot
.816 .19737 Mdot
.816 .19817 Mdot
.816 .19819 Mdot
.816 .19888 Mdot
.816 .19939 Mdot
.816 .19956 Mdot
.816 .19977 Mdot
.816 .19999 Mdot
.816 .2 Mdot
.816 .20018 Mdot
.816 .20021 Mdot
.816 .2006 Mdot
.816 .20111 Mdot
.816 .20156 Mdot
.816 .20167 Mdot
.816 .20172 Mdot
.816 .20197 Mdot
.816 .20205 Mdot
.816 .20211 Mdot
.816 .20227 Mdot
.816 .2025 Mdot
.816 .20287 Mdot
.816 .20363 Mdot
.816 .20374 Mdot
.816 .20397 Mdot
.816 .20434 Mdot
.816 .20448 Mdot
.816 .20465 Mdot
.816 .20486 Mdot
.816 .2049 Mdot
.816 .20509 Mdot
.816 .2053 Mdot
.816 .20651 Mdot
.816 .20674 Mdot
.816 .2068 Mdot
.816 .20696 Mdot
.816 .20714 Mdot
.816 .20725 Mdot
.816 .20769 Mdot
.816 .20795 Mdot
.816 .2082 Mdot
.816 .20823 Mdot
.816 .20893 Mdot
.816 .20908 Mdot
.816 .20947 Mdot
.816 .20969 Mdot
.816 .21013 Mdot
.816 .21022 Mdot
.816 .21058 Mdot
.816 .21153 Mdot
.816 .21159 Mdot
.816 .21186 Mdot
.816 .21234 Mdot
.816 .21237 Mdot
.816 .21245 Mdot
.816 .21253 Mdot
.816 .21271 Mdot
.816 .21306 Mdot
.816 .21372 Mdot
.816 .21421 Mdot
.816 .21425 Mdot
.816 .21473 Mdot
.816 .21567 Mdot
.816 .21621 Mdot
.816 .21643 Mdot
.816 .21644 Mdot
.816 .2167 Mdot
.816 .2177 Mdot
.816 .21837 Mdot
.816 .21839 Mdot
.816 .21877 Mdot
.816 .21884 Mdot
.816 .21907 Mdot
.816 .21914 Mdot
.816 .21961 Mdot
.816 .21986 Mdot
.816 .22017 Mdot
.816 .22051 Mdot
.816 .22077 Mdot
.816 .22116 Mdot
.816 .2212 Mdot
.816 .22127 Mdot
.816 .22148 Mdot
.816 .22228 Mdot
.816 .22245 Mdot
.816 .22322 Mdot
.816 .22406 Mdot
.816 .22612 Mdot
.816 .22662 Mdot
.816 .22737 Mdot
.816 .22749 Mdot
.816 .2276 Mdot
.816 .22786 Mdot
.816 .2279 Mdot
.816 .22842 Mdot
.816 .22885 Mdot
.816 .22975 Mdot
.816 .23047 Mdot
.816 .23106 Mdot
.816 .23152 Mdot
.816 .23158 Mdot
.816 .23159 Mdot
.816 .2318 Mdot
.816 .23235 Mdot
.816 .2326 Mdot
.816 .23271 Mdot
.816 .23277 Mdot
.816 .23287 Mdot
.816 .23302 Mdot
.816 .2334 Mdot
.816 .23343 Mdot
.816 .2337 Mdot
.816 .23461 Mdot
.816 .23507 Mdot
.816 .23591 Mdot
.816 .23656 Mdot
.816 .23667 Mdot
.816 .2385 Mdot
.816 .23882 Mdot
.816 .23991 Mdot
.816 .24029 Mdot
.816 .24044 Mdot
.816 .24055 Mdot
.816 .24087 Mdot
.816 .24117 Mdot
.816 .24182 Mdot
.816 .24264 Mdot
.816 .24286 Mdot
.816 .24313 Mdot
.816 .24391 Mdot
.816 .24478 Mdot
.816 .24502 Mdot
.816 .24565 Mdot
.816 .24615 Mdot
.816 .24724 Mdot
.816 .24737 Mdot
.816 .24741 Mdot
.816 .24788 Mdot
.816 .248 Mdot
.816 .24827 Mdot
.816 .24878 Mdot
.816 .24922 Mdot
.816 .24934 Mdot
.816 .25015 Mdot
.816 .2504 Mdot
.816 .25105 Mdot
.816 .25226 Mdot
.816 .25248 Mdot
.816 .25277 Mdot
.816 .25314 Mdot
.816 .25358 Mdot
.816 .25372 Mdot
.816 .25562 Mdot
.816 .25601 Mdot
.816 .25632 Mdot
.816 .25692 Mdot
.816 .25756 Mdot
.816 .25889 Mdot
.816 .2596 Mdot
.816 .25972 Mdot
.816 .25987 Mdot
.816 .26042 Mdot
.816 .26056 Mdot
.816 .26167 Mdot
.816 .26172 Mdot
.816 .26196 Mdot
.816 .26203 Mdot
.816 .26289 Mdot
.816 .26298 Mdot
.816 .26315 Mdot
.816 .26366 Mdot
.816 .26402 Mdot
.816 .26431 Mdot
.816 .26457 Mdot
.816 .26468 Mdot
.816 .26524 Mdot
.816 .26537 Mdot
.816 .26554 Mdot
.816 .26571 Mdot
.816 .26597 Mdot
.816 .26604 Mdot
.816 .26683 Mdot
.816 .26761 Mdot
.816 .26836 Mdot
.816 .26868 Mdot
.816 .27122 Mdot
.816 .27176 Mdot
.816 .27177 Mdot
.816 .27292 Mdot
.816 .27337 Mdot
.816 .27354 Mdot
.816 .27502 Mdot
.816 .27514 Mdot
.816 .27563 Mdot
.816 .27614 Mdot
.816 .27927 Mdot
.816 .2797 Mdot
.816 .2797 Mdot
.816 .28126 Mdot
.816 .28188 Mdot
.816 .28204 Mdot
.816 .28261 Mdot
.816 .283 Mdot
.816 .28303 Mdot
.816 .28336 Mdot
.816 .28391 Mdot
.816 .28396 Mdot
.816 .28417 Mdot
.816 .28422 Mdot
.816 .28528 Mdot
.816 .2855 Mdot
.816 .28817 Mdot
.816 .28852 Mdot
.816 .28862 Mdot
.816 .2895 Mdot
.816 .28983 Mdot
.816 .29016 Mdot
.816 .29142 Mdot
.816 .29152 Mdot
.816 .29288 Mdot
.816 .29292 Mdot
.816 .29316 Mdot
.816 .29348 Mdot
.816 .29411 Mdot
.816 .29434 Mdot
.816 .2945 Mdot
.816 .29478 Mdot
.816 .29547 Mdot
.816 .29598 Mdot
.816 .29617 Mdot
.816 .29633 Mdot
.816 .29684 Mdot
.816 .29793 Mdot
.816 .29868 Mdot
.816 .2987 Mdot
.816 .29928 Mdot
.816 .3 Mdot
.816 .30047 Mdot
.816 .30076 Mdot
.816 .30111 Mdot
.816 .30129 Mdot
.816 .30149 Mdot
.816 .30187 Mdot
.816 .30197 Mdot
.816 .30357 Mdot
.816 .30376 Mdot
.816 .30392 Mdot
.816 .30396 Mdot
.816 .30403 Mdot
.816 .30409 Mdot
.816 .3042 Mdot
.816 .30466 Mdot
.816 .30474 Mdot
.816 .30481 Mdot
.816 .30482 Mdot
.816 .30496 Mdot
.816 .30501 Mdot
.816 .30515 Mdot
.816 .30571 Mdot
.816 .30579 Mdot
.816 .30585 Mdot
.816 .3059 Mdot
.816 .306 Mdot
.816 .30602 Mdot
.816 .30606 Mdot
.816 .30623 Mdot
.816 .30642 Mdot
.816 .30673 Mdot
.816 .30706 Mdot
.816 .30733 Mdot
.816 .30768 Mdot
.816 .30804 Mdot
.816 .30815 Mdot
.816 .30834 Mdot
.816 .30845 Mdot
.816 .30889 Mdot
.816 .30903 Mdot
.816 .30919 Mdot
.816 .3092 Mdot
.816 .30923 Mdot
.816 .30925 Mdot
.816 .30949 Mdot
.816 .30951 Mdot
.816 .30968 Mdot
.816 .30975 Mdot
.816 .30992 Mdot
.816 .30992 Mdot
.816 .31013 Mdot
.816 .31017 Mdot
.816 .31029 Mdot
.816 .31058 Mdot
.816 .31104 Mdot
.816 .31114 Mdot
.816 .31176 Mdot
.816 .31207 Mdot
.816 .31252 Mdot
.816 .31258 Mdot
.816 .31274 Mdot
.816 .31275 Mdot
.816 .31281 Mdot
.816 .31283 Mdot
.816 .31352 Mdot
.816 .31382 Mdot
.816 .31411 Mdot
.816 .31415 Mdot
.816 .31449 Mdot
.816 .31528 Mdot
.816 .31573 Mdot
.816 .31584 Mdot
.816 .3161 Mdot
.816 .31616 Mdot
.816 .3163 Mdot
.816 .31639 Mdot
.816 .31655 Mdot
.816 .31658 Mdot
.816 .31672 Mdot
.816 .31708 Mdot
.816 .3171 Mdot
.816 .3172 Mdot
.816 .31739 Mdot
.816 .31745 Mdot
.816 .31765 Mdot
.816 .31808 Mdot
.816 .31883 Mdot
.816 .31892 Mdot
.816 .31902 Mdot
.816 .31964 Mdot
.816 .31965 Mdot
.816 .31979 Mdot
.816 .31982 Mdot
.816 .31991 Mdot
.816 .31993 Mdot
.816 .3202 Mdot
.816 .32032 Mdot
.816 .32045 Mdot
.816 .32055 Mdot
.816 .32073 Mdot
.816 .32081 Mdot
.816 .32111 Mdot
.816 .32118 Mdot
.816 .32178 Mdot
.816 .32274 Mdot
.816 .32302 Mdot
.816 .32311 Mdot
.816 .32321 Mdot
.816 .32358 Mdot
.816 .32419 Mdot
.816 .32441 Mdot
.816 .32458 Mdot
.816 .3246 Mdot
.816 .32469 Mdot
.816 .32499 Mdot
.816 .32503 Mdot
.816 .32509 Mdot
.816 .32514 Mdot
.816 .3253 Mdot
.816 .3254 Mdot
.816 .32574 Mdot
.816 .3272 Mdot
.816 .32732 Mdot
.816 .32773 Mdot
.816 .32793 Mdot
.816 .32809 Mdot
.816 .3282 Mdot
.816 .32845 Mdot
.816 .32876 Mdot
.816 .32884 Mdot
.816 .32894 Mdot
.816 .32965 Mdot
.816 .33008 Mdot
.816 .33048 Mdot
.816 .33053 Mdot
.816 .33055 Mdot
.816 .33072 Mdot
.816 .33106 Mdot
.816 .33127 Mdot
.816 .33158 Mdot
.816 .33167 Mdot
.816 .33191 Mdot
.816 .33237 Mdot
.816 .33245 Mdot
.816 .33256 Mdot
.816 .3327 Mdot
.816 .33286 Mdot
.816 .33292 Mdot
.816 .33363 Mdot
.816 .33378 Mdot
.816 .33436 Mdot
.816 .33486 Mdot
.816 .33512 Mdot
.816 .3359 Mdot
.816 .33592 Mdot
.816 .33601 Mdot
.816 .33646 Mdot
.816 .33665 Mdot
.816 .33689 Mdot
.816 .33699 Mdot
.816 .33703 Mdot
.816 .33724 Mdot
.816 .33729 Mdot
.816 .33742 Mdot
.816 .33754 Mdot
.816 .33784 Mdot
.816 .33841 Mdot
.816 .33853 Mdot
.816 .33949 Mdot
.816 .3403 Mdot
.816 .34036 Mdot
.816 .34092 Mdot
.816 .34096 Mdot
.816 .34114 Mdot
.816 .34133 Mdot
.816 .34251 Mdot
.816 .34267 Mdot
.816 .34267 Mdot
.816 .34349 Mdot
.816 .34355 Mdot
.816 .34391 Mdot
.816 .34392 Mdot
.816 .34404 Mdot
.816 .34427 Mdot
.816 .34435 Mdot
.816 .34476 Mdot
.816 .34485 Mdot
.816 .34598 Mdot
.816 .34635 Mdot
.816 .3466 Mdot
.816 .34707 Mdot
.816 .34711 Mdot
.816 .34773 Mdot
.816 .34784 Mdot
.816 .34808 Mdot
.816 .34823 Mdot
.816 .34833 Mdot
.816 .34859 Mdot
.816 .34878 Mdot
.816 .34886 Mdot
.816 .34891 Mdot
.816 .34911 Mdot
.816 .34952 Mdot
.816 .3498 Mdot
.816 .34981 Mdot
.816 .35002 Mdot
.816 .35029 Mdot
.816 .35047 Mdot
.816 .35058 Mdot
.816 .35078 Mdot
.816 .35085 Mdot
.816 .351 Mdot
.816 .35163 Mdot
.816 .3517 Mdot
.816 .35181 Mdot
.816 .35187 Mdot
.816 .35216 Mdot
.816 .35218 Mdot
.816 .35223 Mdot
.816 .35263 Mdot
.816 .35295 Mdot
.816 .35331 Mdot
.816 .35347 Mdot
.816 .35363 Mdot
.816 .35375 Mdot
.816 .35375 Mdot
.816 .35376 Mdot
.816 .35386 Mdot
.816 .35402 Mdot
.816 .35411 Mdot
.816 .35448 Mdot
.816 .35499 Mdot
.816 .35508 Mdot
.816 .35511 Mdot
.816 .35548 Mdot
.816 .3562 Mdot
.816 .35636 Mdot
.816 .35652 Mdot
.816 .35675 Mdot
.816 .35692 Mdot
.816 .35778 Mdot
.816 .35788 Mdot
.816 .35808 Mdot
.816 .35822 Mdot
.816 .35953 Mdot
.816 .35973 Mdot
.816 .36055 Mdot
.816 .36078 Mdot
.816 .36112 Mdot
.816 .36176 Mdot
.816 .36196 Mdot
.816 .36203 Mdot
.816 .36215 Mdot
.816 .36245 Mdot
.816 .36257 Mdot
.816 .36263 Mdot
.816 .36348 Mdot
.816 .36405 Mdot
.816 .36415 Mdot
.816 .36418 Mdot
.816 .3642 Mdot
.816 .36476 Mdot
.816 .36566 Mdot
.816 .36631 Mdot
.816 .36683 Mdot
.816 .3671 Mdot
.816 .3677 Mdot
.816 .36779 Mdot
.816 .36854 Mdot
.816 .36861 Mdot
.816 .36864 Mdot
.816 .36866 Mdot
.816 .36899 Mdot
.816 .36918 Mdot
.816 .36936 Mdot
.816 .36939 Mdot
.816 .36977 Mdot
.816 .36988 Mdot
.816 .3699 Mdot
.816 .37031 Mdot
.816 .37043 Mdot
.816 .37047 Mdot
.816 .37048 Mdot
.816 .37052 Mdot
.816 .37057 Mdot
.816 .37075 Mdot
.816 .37097 Mdot
.816 .37098 Mdot
.816 .3716 Mdot
.816 .37166 Mdot
.816 .3721 Mdot
.816 .37264 Mdot
.816 .37311 Mdot
.816 .37358 Mdot
.816 .37434 Mdot
.816 .3744 Mdot
.816 .37519 Mdot
.816 .37571 Mdot
.816 .37605 Mdot
.816 .37633 Mdot
.816 .37634 Mdot
.816 .37649 Mdot
.816 .37674 Mdot
.816 .37677 Mdot
.816 .37694 Mdot
.816 .37774 Mdot
.816 .37896 Mdot
.816 .37901 Mdot
.816 .37994 Mdot
.816 .37996 Mdot
.816 .38031 Mdot
.816 .38045 Mdot
.816 .38066 Mdot
.816 .38088 Mdot
.816 .38146 Mdot
.816 .38149 Mdot
.816 .38223 Mdot
.816 .38285 Mdot
.816 .383 Mdot
.816 .38309 Mdot
.816 .3831 Mdot
.816 .38327 Mdot
.816 .3838 Mdot
.816 .38428 Mdot
.816 .38507 Mdot
.816 .38536 Mdot
.816 .38638 Mdot
.816 .38666 Mdot
.816 .38669 Mdot
.816 .38672 Mdot
.816 .38705 Mdot
.816 .38712 Mdot
.816 .38735 Mdot
.816 .38737 Mdot
.816 .38748 Mdot
.816 .38783 Mdot
.816 .38839 Mdot
.816 .38876 Mdot
.816 .38924 Mdot
.816 .39019 Mdot
.816 .39053 Mdot
.816 .39057 Mdot
.816 .39062 Mdot
.816 .39161 Mdot
.816 .39186 Mdot
.816 .39242 Mdot
.816 .39263 Mdot
.816 .39339 Mdot
.816 .3942 Mdot
.816 .39428 Mdot
.816 .39441 Mdot
.816 .39447 Mdot
.816 .39499 Mdot
.816 .3951 Mdot
.816 .39524 Mdot
.816 .39543 Mdot
.816 .39587 Mdot
.816 .3961 Mdot
.816 .39612 Mdot
.816 .39649 Mdot
.816 .39671 Mdot
.816 .39677 Mdot
.816 .39687 Mdot
.816 .39693 Mdot
.816 .39694 Mdot
.816 .39701 Mdot
.816 .3972 Mdot
.816 .39743 Mdot
.816 .39762 Mdot
.816 .39787 Mdot
.816 .3979 Mdot
.816 .39809 Mdot
.816 .39871 Mdot
.816 .39876 Mdot
.816 .39894 Mdot
.816 .39905 Mdot
.816 .39935 Mdot
.816 .39936 Mdot
.816 .3999 Mdot
.816 .39994 Mdot
.816 .39998 Mdot
.816 .4001 Mdot
.816 .40041 Mdot
.816 .40132 Mdot
.816 .40147 Mdot
.816 .40239 Mdot
.816 .40244 Mdot
.816 .40274 Mdot
.816 .40288 Mdot
.816 .40322 Mdot
.816 .40372 Mdot
.816 .40382 Mdot
.816 .40454 Mdot
.816 .40477 Mdot
.816 .4048 Mdot
.816 .40626 Mdot
.816 .40718 Mdot
.816 .40721 Mdot
.816 .40726 Mdot
.816 .40741 Mdot
.816 .40787 Mdot
.816 .40835 Mdot
.816 .40851 Mdot
.816 .40973 Mdot
.816 .40983 Mdot
.816 .40999 Mdot
.816 .41004 Mdot
.816 .41052 Mdot
.816 .41071 Mdot
.816 .41084 Mdot
.816 .41104 Mdot
.816 .41115 Mdot
.816 .4122 Mdot
.816 .41276 Mdot
.816 .41313 Mdot
.816 .4132 Mdot
.816 .41437 Mdot
.816 .41446 Mdot
.816 .41456 Mdot
.816 .41479 Mdot
.816 .41481 Mdot
.816 .41571 Mdot
.816 .41593 Mdot
.816 .41693 Mdot
.816 .41717 Mdot
.816 .41749 Mdot
.816 .41766 Mdot
.816 .41774 Mdot
.816 .41783 Mdot
.816 .41822 Mdot
.816 .41833 Mdot
.816 .41906 Mdot
.816 .41933 Mdot
.816 .41971 Mdot
.816 .41973 Mdot
.816 .41988 Mdot
.816 .41997 Mdot
.816 .42017 Mdot
.816 .42023 Mdot
.816 .42099 Mdot
.816 .4214 Mdot
.816 .42159 Mdot
.816 .42201 Mdot
.816 .42206 Mdot
.816 .42206 Mdot
.816 .4222 Mdot
.816 .42248 Mdot
.816 .42266 Mdot
.816 .42304 Mdot
.816 .42357 Mdot
.816 .42364 Mdot
.816 .42379 Mdot
.816 .42379 Mdot
.816 .42404 Mdot
.816 .42406 Mdot
.816 .42421 Mdot
.816 .42423 Mdot
.816 .42424 Mdot
.816 .42434 Mdot
.816 .42442 Mdot
.816 .42469 Mdot
.816 .42476 Mdot
.816 .42488 Mdot
.816 .42494 Mdot
.816 .42554 Mdot
.816 .42605 Mdot
.816 .42616 Mdot
.816 .42671 Mdot
.816 .4268 Mdot
.816 .42683 Mdot
.816 .4273 Mdot
.816 .4274 Mdot
.816 .42744 Mdot
.816 .42757 Mdot
.816 .42769 Mdot
.816 .42866 Mdot
.816 .42872 Mdot
.816 .42896 Mdot
.816 .42908 Mdot
.816 .42919 Mdot
.816 .4294 Mdot
.816 .42958 Mdot
.816 .42987 Mdot
.816 .43031 Mdot
.816 .43067 Mdot
.816 .43068 Mdot
.816 .43114 Mdot
.816 .43181 Mdot
.816 .43212 Mdot
.816 .43222 Mdot
.816 .43234 Mdot
.816 .43264 Mdot
.816 .43307 Mdot
.816 .43324 Mdot
.816 .43334 Mdot
.816 .43348 Mdot
.816 .43387 Mdot
.816 .43406 Mdot
.816 .43421 Mdot
.816 .43423 Mdot
.816 .43507 Mdot
.816 .43513 Mdot
.816 .4359 Mdot
.816 .4361 Mdot
.816 .4363 Mdot
.816 .43684 Mdot
.816 .4369 Mdot
.816 .43712 Mdot
.816 .43875 Mdot
.816 .43889 Mdot
.816 .43954 Mdot
.816 .43957 Mdot
.816 .4397 Mdot
.816 .43973 Mdot
.816 .44007 Mdot
.816 .44027 Mdot
.816 .44029 Mdot
.816 .44053 Mdot
.816 .44088 Mdot
.816 .44098 Mdot
.816 .44135 Mdot
.816 .44231 Mdot
.816 .44231 Mdot
.816 .44257 Mdot
.816 .44449 Mdot
.816 .4448 Mdot
.816 .4451 Mdot
.816 .44518 Mdot
.816 .44608 Mdot
.816 .44619 Mdot
.816 .44647 Mdot
.816 .44717 Mdot
.816 .44718 Mdot
.816 .4475 Mdot
.816 .44906 Mdot
.816 .44926 Mdot
.816 .44972 Mdot
.816 .4502 Mdot
.816 .45068 Mdot
.816 .45072 Mdot
.816 .45088 Mdot
.816 .45099 Mdot
.816 .45109 Mdot
.816 .45117 Mdot
.816 .45151 Mdot
.816 .45158 Mdot
.816 .45174 Mdot
.816 .45191 Mdot
.816 .45214 Mdot
.816 .45245 Mdot
.816 .45256 Mdot
.816 .45261 Mdot
.816 .45314 Mdot
.816 .45318 Mdot
.816 .45332 Mdot
.816 .45336 Mdot
.816 .45404 Mdot
.816 .45412 Mdot
.816 .45446 Mdot
.816 .45455 Mdot
.816 .45463 Mdot
.816 .45506 Mdot
.816 .45587 Mdot
.816 .45627 Mdot
.816 .45664 Mdot
.816 .45682 Mdot
.816 .45706 Mdot
.816 .45823 Mdot
.816 .45831 Mdot
.816 .45858 Mdot
.816 .45881 Mdot
.816 .45899 Mdot
.816 .45912 Mdot
.816 .45987 Mdot
.816 .46026 Mdot
.816 .46042 Mdot
.816 .46091 Mdot
.816 .46099 Mdot
.816 .46125 Mdot
.816 .46157 Mdot
.816 .46173 Mdot
.816 .46181 Mdot
.816 .4621 Mdot
.816 .46212 Mdot
.816 .4622 Mdot
.816 .46287 Mdot
.816 .46317 Mdot
.816 .46356 Mdot
.816 .4637 Mdot
.816 .46424 Mdot
.816 .46472 Mdot
.816 .46488 Mdot
.816 .46502 Mdot
.816 .46552 Mdot
.816 .46592 Mdot
.816 .4661 Mdot
.816 .4663 Mdot
.816 .46637 Mdot
.816 .46646 Mdot
.816 .46669 Mdot
.816 .46736 Mdot
.816 .46755 Mdot
.816 .46868 Mdot
.816 .46874 Mdot
.816 .46914 Mdot
.816 .46965 Mdot
.816 .46994 Mdot
.816 .4705 Mdot
.816 .47066 Mdot
.816 .47068 Mdot
.816 .47091 Mdot
.816 .471 Mdot
.816 .47107 Mdot
.816 .4711 Mdot
.816 .47117 Mdot
.816 .47132 Mdot
.816 .47166 Mdot
.816 .47179 Mdot
.816 .4718 Mdot
.816 .47183 Mdot
.816 .47211 Mdot
.816 .47247 Mdot
.816 .47292 Mdot
.816 .47347 Mdot
.816 .47373 Mdot
.816 .47405 Mdot
.816 .47407 Mdot
.816 .47423 Mdot
.816 .4743 Mdot
.816 .47438 Mdot
.816 .47483 Mdot
.816 .47514 Mdot
.816 .47641 Mdot
.816 .47692 Mdot
.816 .47739 Mdot
.816 .47749 Mdot
.816 .47798 Mdot
.816 .47811 Mdot
.816 .47815 Mdot
.816 .47818 Mdot
.816 .47842 Mdot
.816 .47858 Mdot
.816 .47878 Mdot
.816 .47897 Mdot
.816 .47913 Mdot
.816 .47942 Mdot
.816 .47946 Mdot
.816 .4796 Mdot
.816 .47965 Mdot
.816 .47988 Mdot
.816 .47989 Mdot
.816 .4803 Mdot
.816 .48091 Mdot
.816 .48107 Mdot
.816 .48108 Mdot
.816 .48121 Mdot
.816 .48154 Mdot
.816 .48212 Mdot
.816 .48241 Mdot
.816 .48244 Mdot
.816 .48274 Mdot
.816 .48314 Mdot
.816 .48336 Mdot
.816 .48347 Mdot
.816 .48352 Mdot
.816 .48356 Mdot
.816 .48388 Mdot
.816 .48405 Mdot
.816 .48408 Mdot
.816 .48466 Mdot
.816 .48488 Mdot
.816 .48494 Mdot
.816 .48521 Mdot
.816 .48534 Mdot
.816 .48558 Mdot
.816 .48567 Mdot
.816 .4861 Mdot
.816 .48612 Mdot
.816 .48627 Mdot
.816 .48643 Mdot
.816 .4867 Mdot
.816 .48677 Mdot
.816 .48688 Mdot
.816 .48698 Mdot
.816 .48702 Mdot
.816 .48715 Mdot
.816 .4879 Mdot
.816 .48803 Mdot
.816 .48815 Mdot
.816 .48817 Mdot
.816 .4883 Mdot
.816 .4884 Mdot
.816 .48848 Mdot
.816 .48871 Mdot
.816 .48885 Mdot
.816 .48892 Mdot
.816 .48939 Mdot
.816 .48961 Mdot
.816 .48975 Mdot
.816 .48985 Mdot
.816 .48989 Mdot
.816 .48994 Mdot
.816 .49009 Mdot
.816 .49012 Mdot
.816 .49019 Mdot
.816 .49046 Mdot
.816 .49078 Mdot
.816 .49101 Mdot
.816 .49104 Mdot
.816 .49115 Mdot
.816 .49115 Mdot
.816 .49129 Mdot
.816 .49141 Mdot
.816 .49152 Mdot
.816 .49183 Mdot
.816 .49225 Mdot
.816 .49227 Mdot
.816 .49275 Mdot
.816 .49284 Mdot
.816 .49342 Mdot
.816 .49359 Mdot
.816 .49376 Mdot
.816 .4939 Mdot
.816 .49393 Mdot
.816 .49409 Mdot
.816 .49468 Mdot
.816 .49481 Mdot
.816 .49504 Mdot
.816 .49516 Mdot
.816 .49531 Mdot
.816 .49531 Mdot
.816 .49535 Mdot
.816 .49537 Mdot
.816 .49539 Mdot
.816 .49542 Mdot
.816 .49576 Mdot
.816 .49576 Mdot
.816 .49579 Mdot
.816 .49582 Mdot
.816 .49603 Mdot
.816 .49609 Mdot
.818 .19072 Mdot
.818 .19137 Mdot
.818 .19155 Mdot
.818 .19208 Mdot
.818 .1921 Mdot
.818 .19254 Mdot
.818 .19258 Mdot
.818 .19284 Mdot
.818 .19301 Mdot
.818 .19323 Mdot
.818 .1937 Mdot
.818 .19375 Mdot
.818 .19375 Mdot
.818 .19379 Mdot
.818 .19442 Mdot
.818 .19446 Mdot
.818 .19479 Mdot
.818 .19494 Mdot
.818 .19529 Mdot
.818 .19541 Mdot
.818 .19579 Mdot
.818 .1958 Mdot
.818 .19594 Mdot
.818 .19595 Mdot
.818 .19614 Mdot
.818 .19669 Mdot
.818 .19709 Mdot
.818 .19748 Mdot
.818 .19769 Mdot
.818 .1977 Mdot
.818 .19824 Mdot
.818 .19913 Mdot
.818 .19917 Mdot
.818 .1994 Mdot
.818 .19946 Mdot
.818 .19987 Mdot
.818 .19991 Mdot
.818 .20026 Mdot
.818 .20108 Mdot
.818 .20113 Mdot
.818 .20126 Mdot
.818 .20207 Mdot
.818 .20211 Mdot
.818 .20263 Mdot
.818 .2028 Mdot
.818 .20298 Mdot
.818 .20318 Mdot
.818 .20327 Mdot
.818 .20344 Mdot
.818 .20383 Mdot
.818 .20447 Mdot
.818 .20511 Mdot
.818 .20556 Mdot
.818 .20618 Mdot
.818 .20635 Mdot
.818 .20709 Mdot
.818 .20835 Mdot
.818 .20854 Mdot
.818 .20861 Mdot
.818 .20922 Mdot
.818 .20923 Mdot
.818 .20957 Mdot
.818 .20972 Mdot
.818 .2098 Mdot
.818 .20985 Mdot
.818 .21015 Mdot
.818 .21093 Mdot
.818 .21099 Mdot
.818 .21149 Mdot
.818 .21162 Mdot
.818 .21167 Mdot
.818 .21179 Mdot
.818 .21202 Mdot
.818 .21229 Mdot
.818 .21331 Mdot
.818 .21446 Mdot
.818 .21523 Mdot
.818 .2155 Mdot
.818 .21566 Mdot
.818 .21613 Mdot
.818 .21643 Mdot
.818 .21689 Mdot
.818 .21694 Mdot
.818 .21715 Mdot
.818 .21722 Mdot
.818 .21768 Mdot
.818 .21768 Mdot
.818 .2195 Mdot
.818 .21994 Mdot
.818 .2204 Mdot
.818 .22123 Mdot
.818 .22143 Mdot
.818 .22152 Mdot
.818 .22242 Mdot
.818 .22266 Mdot
.818 .22284 Mdot
.818 .2237 Mdot
.818 .22383 Mdot
.818 .22439 Mdot
.818 .22443 Mdot
.818 .22479 Mdot
.818 .22503 Mdot
.818 .22521 Mdot
.818 .22609 Mdot
.818 .22652 Mdot
.818 .22662 Mdot
.818 .22726 Mdot
.818 .22751 Mdot
.818 .22777 Mdot
.818 .22804 Mdot
.818 .22824 Mdot
.818 .22854 Mdot
.818 .22862 Mdot
.818 .22896 Mdot
.818 .23176 Mdot
.818 .23285 Mdot
.818 .23364 Mdot
.818 .23453 Mdot
.818 .23508 Mdot
.818 .23509 Mdot
.818 .23516 Mdot
.818 .23543 Mdot
.818 .23654 Mdot
.818 .23683 Mdot
.818 .23824 Mdot
.818 .2385 Mdot
.818 .23923 Mdot
.818 .23986 Mdot
.818 .24 Mdot
.818 .24012 Mdot
.818 .24019 Mdot
.818 .24033 Mdot
.818 .24059 Mdot
.818 .2409 Mdot
.818 .24137 Mdot
.818 .24186 Mdot
.818 .24274 Mdot
.818 .24321 Mdot
.818 .24416 Mdot
.818 .2442 Mdot
.818 .24494 Mdot
.818 .24595 Mdot
.818 .24611 Mdot
.818 .24736 Mdot
.818 .24776 Mdot
.818 .24828 Mdot
.818 .24872 Mdot
.818 .24874 Mdot
.818 .24883 Mdot
.818 .24953 Mdot
.818 .24957 Mdot
.818 .24986 Mdot
.818 .25043 Mdot
.818 .25108 Mdot
.818 .2515 Mdot
.818 .25173 Mdot
.818 .25254 Mdot
.818 .25258 Mdot
.818 .25283 Mdot
.818 .25288 Mdot
.818 .25307 Mdot
.818 .25339 Mdot
.818 .25408 Mdot
.818 .25475 Mdot
.818 .25477 Mdot
.818 .25507 Mdot
.818 .25531 Mdot
.818 .25565 Mdot
.818 .25567 Mdot
.818 .25658 Mdot
.818 .25664 Mdot
.818 .25781 Mdot
.818 .25793 Mdot
.818 .25806 Mdot
.818 .25821 Mdot
.818 .25863 Mdot
.818 .25887 Mdot
.818 .25919 Mdot
.818 .25978 Mdot
.818 .25993 Mdot
.818 .26006 Mdot
.818 .26028 Mdot
.818 .26037 Mdot
.818 .26064 Mdot
.818 .26148 Mdot
.818 .26236 Mdot
.818 .26236 Mdot
.818 .26249 Mdot
.818 .26291 Mdot
.818 .26306 Mdot
.818 .26329 Mdot
.818 .26379 Mdot
.818 .26386 Mdot
.818 .2645 Mdot
.818 .26465 Mdot
.818 .26472 Mdot
.818 .26481 Mdot
.818 .26481 Mdot
.818 .266 Mdot
.818 .26783 Mdot
.818 .26862 Mdot
.818 .26882 Mdot
.818 .26931 Mdot
.818 .26946 Mdot
.818 .26979 Mdot
.818 .27044 Mdot
.818 .27207 Mdot
.818 .27273 Mdot
.818 .27287 Mdot
.818 .2729 Mdot
.818 .27307 Mdot
.818 .27313 Mdot
.818 .27423 Mdot
.818 .27436 Mdot
.818 .27464 Mdot
.818 .27504 Mdot
.818 .27524 Mdot
.818 .27549 Mdot
.818 .27667 Mdot
.818 .27806 Mdot
.818 .27837 Mdot
.818 .27878 Mdot
.818 .27887 Mdot
.818 .28003 Mdot
.818 .28021 Mdot
.818 .28046 Mdot
.818 .28076 Mdot
.818 .28192 Mdot
.818 .2826 Mdot
.818 .2828 Mdot
.818 .28313 Mdot
.818 .28371 Mdot
.818 .28377 Mdot
.818 .2841 Mdot
.818 .28419 Mdot
.818 .28496 Mdot
.818 .2853 Mdot
.818 .28615 Mdot
.818 .28627 Mdot
.818 .28635 Mdot
.818 .28636 Mdot
.818 .28726 Mdot
.818 .28759 Mdot
.818 .28789 Mdot
.818 .28806 Mdot
.818 .28826 Mdot
.818 .28841 Mdot
.818 .28887 Mdot
.818 .28893 Mdot
.818 .28931 Mdot
.818 .28959 Mdot
.818 .2896 Mdot
.818 .29093 Mdot
.818 .29103 Mdot
.818 .29109 Mdot
.818 .29544 Mdot
.818 .29555 Mdot
.818 .29563 Mdot
.818 .2972 Mdot
.818 .29757 Mdot
.818 .29806 Mdot
.818 .29848 Mdot
.818 .29882 Mdot
.818 .2995 Mdot
.818 .29967 Mdot
.818 .29977 Mdot
.818 .30008 Mdot
.818 .30031 Mdot
.818 .30151 Mdot
.818 .30161 Mdot
.818 .30174 Mdot
.818 .302 Mdot
.818 .30242 Mdot
.818 .30265 Mdot
.818 .30373 Mdot
.818 .30402 Mdot
.818 .30488 Mdot
.818 .30491 Mdot
.818 .30506 Mdot
.818 .30512 Mdot
.818 .30563 Mdot
.818 .3057 Mdot
.818 .306 Mdot
.818 .30613 Mdot
.818 .30641 Mdot
.818 .30643 Mdot
.818 .30676 Mdot
.818 .30704 Mdot
.818 .30734 Mdot
.818 .30754 Mdot
.818 .30761 Mdot
.818 .30762 Mdot
.818 .30767 Mdot
.818 .30767 Mdot
.818 .30782 Mdot
.818 .30871 Mdot
.818 .30877 Mdot
.818 .30932 Mdot
.818 .30957 Mdot
.818 .31014 Mdot
.818 .31033 Mdot
.818 .31034 Mdot
.818 .3105 Mdot
.818 .31052 Mdot
.818 .31076 Mdot
.818 .31094 Mdot
.818 .31096 Mdot
.818 .31096 Mdot
.818 .31097 Mdot
.818 .31121 Mdot
.818 .31122 Mdot
.818 .31135 Mdot
.818 .3114 Mdot
.818 .31153 Mdot
.818 .31221 Mdot
.818 .31243 Mdot
.818 .31243 Mdot
.818 .31307 Mdot
.818 .31309 Mdot
.818 .31324 Mdot
.818 .31372 Mdot
.818 .31406 Mdot
.818 .31408 Mdot
.818 .3144 Mdot
.818 .31458 Mdot
.818 .31472 Mdot
.818 .31496 Mdot
.818 .3152 Mdot
.818 .3156 Mdot
.818 .31594 Mdot
.818 .31641 Mdot
.818 .31648 Mdot
.818 .31651 Mdot
.818 .31674 Mdot
.818 .31687 Mdot
.818 .31692 Mdot
.818 .31695 Mdot
.818 .31709 Mdot
.818 .31738 Mdot
.818 .31758 Mdot
.818 .31763 Mdot
.818 .3177 Mdot
.818 .31826 Mdot
.818 .31869 Mdot
.818 .31898 Mdot
.818 .31914 Mdot
.818 .31943 Mdot
.818 .3196 Mdot
.818 .3197 Mdot
.818 .3199 Mdot
.818 .32074 Mdot
.818 .32122 Mdot
.818 .3213 Mdot
.818 .32167 Mdot
.818 .32176 Mdot
.818 .32215 Mdot
.818 .3224 Mdot
.818 .32242 Mdot
.818 .32256 Mdot
.818 .32264 Mdot
.818 .32271 Mdot
.818 .32304 Mdot
.818 .3232 Mdot
.818 .32324 Mdot
.818 .32348 Mdot
.818 .32357 Mdot
.818 .32367 Mdot
.818 .32399 Mdot
.818 .32411 Mdot
.818 .32516 Mdot
.818 .32557 Mdot
.818 .32619 Mdot
.818 .3264 Mdot
.818 .3264 Mdot
.818 .32643 Mdot
.818 .32653 Mdot
.818 .32694 Mdot
.818 .32705 Mdot
.818 .32758 Mdot
.818 .32768 Mdot
.818 .32795 Mdot
.818 .32818 Mdot
.818 .32824 Mdot
.818 .32828 Mdot
.818 .32857 Mdot
.818 .32875 Mdot
.818 .32893 Mdot
.818 .32926 Mdot
.818 .32944 Mdot
.818 .3315 Mdot
.818 .33154 Mdot
.818 .33181 Mdot
.818 .33192 Mdot
.818 .33238 Mdot
.818 .33253 Mdot
.818 .33262 Mdot
.818 .33292 Mdot
.818 .33294 Mdot
.818 .3335 Mdot
.818 .33375 Mdot
.818 .33375 Mdot
.818 .33387 Mdot
.818 .33396 Mdot
.818 .33408 Mdot
.818 .33445 Mdot
.818 .33489 Mdot
.818 .33494 Mdot
.818 .33499 Mdot
.818 .33504 Mdot
.818 .33541 Mdot
.818 .33573 Mdot
.818 .33581 Mdot
.818 .33585 Mdot
.818 .33595 Mdot
.818 .33659 Mdot
.818 .33664 Mdot
.818 .33685 Mdot
.818 .33694 Mdot
.818 .33713 Mdot
.818 .33715 Mdot
.818 .33739 Mdot
.818 .33745 Mdot
.818 .33751 Mdot
.818 .33751 Mdot
.818 .33795 Mdot
.818 .33901 Mdot
.818 .33924 Mdot
.818 .33961 Mdot
.818 .34022 Mdot
.818 .34047 Mdot
.818 .34052 Mdot
.818 .34059 Mdot
.818 .34107 Mdot
.818 .34118 Mdot
.818 .3414 Mdot
.818 .3415 Mdot
.818 .34194 Mdot
.818 .34246 Mdot
.818 .34257 Mdot
.818 .34276 Mdot
.818 .34319 Mdot
.818 .34326 Mdot
.818 .34335 Mdot
.818 .34346 Mdot
.818 .34423 Mdot
.818 .34457 Mdot
.818 .34459 Mdot
.818 .34471 Mdot
.818 .34548 Mdot
.818 .34553 Mdot
.818 .34555 Mdot
.818 .34556 Mdot
.818 .34589 Mdot
.818 .34602 Mdot
.818 .34613 Mdot
.818 .34619 Mdot
.818 .34676 Mdot
.818 .34677 Mdot
.818 .34727 Mdot
.818 .3473 Mdot
.818 .34899 Mdot
.818 .34902 Mdot
.818 .34974 Mdot
.818 .35021 Mdot
.818 .35047 Mdot
.818 .35053 Mdot
.818 .35068 Mdot
.818 .35122 Mdot
.818 .35126 Mdot
.818 .3513 Mdot
.818 .3514 Mdot
.818 .35254 Mdot
.818 .35257 Mdot
.818 .3529 Mdot
.818 .35306 Mdot
.818 .35329 Mdot
.818 .35352 Mdot
.818 .35357 Mdot
.818 .35452 Mdot
.818 .35475 Mdot
.818 .35491 Mdot
.818 .35521 Mdot
.818 .3553 Mdot
.818 .35604 Mdot
.818 .35616 Mdot
.818 .35661 Mdot
.818 .35682 Mdot
.818 .35698 Mdot
.818 .35715 Mdot
.818 .35722 Mdot
.818 .35764 Mdot
.818 .35775 Mdot
.818 .35781 Mdot
.818 .3584 Mdot
.818 .35878 Mdot
.818 .35908 Mdot
.818 .3595 Mdot
.818 .36052 Mdot
.818 .36053 Mdot
.818 .36057 Mdot
.818 .36096 Mdot
.818 .36099 Mdot
.818 .36122 Mdot
.818 .36139 Mdot
.818 .36244 Mdot
.818 .36284 Mdot
.818 .36327 Mdot
.818 .36339 Mdot
.818 .36369 Mdot
.818 .36371 Mdot
.818 .36388 Mdot
.818 .36405 Mdot
.818 .36453 Mdot
.818 .36467 Mdot
.818 .36523 Mdot
.818 .36568 Mdot
.818 .36577 Mdot
.818 .36579 Mdot
.818 .36582 Mdot
.818 .36604 Mdot
.818 .36612 Mdot
.818 .36731 Mdot
.818 .36731 Mdot
.818 .36767 Mdot
.818 .36791 Mdot
.818 .36833 Mdot
.818 .36897 Mdot
.818 .36941 Mdot
.818 .36959 Mdot
.818 .3698 Mdot
.818 .37029 Mdot
.818 .37131 Mdot
.818 .37159 Mdot
.818 .37194 Mdot
.818 .37201 Mdot
.818 .37219 Mdot
.818 .37288 Mdot
.818 .37326 Mdot
.818 .37343 Mdot
.818 .37434 Mdot
.818 .37452 Mdot
.818 .37524 Mdot
.818 .37525 Mdot
.818 .37533 Mdot
.818 .37536 Mdot
.818 .3758 Mdot
.818 .3758 Mdot
.818 .37594 Mdot
.818 .37603 Mdot
.818 .37642 Mdot
.818 .37659 Mdot
.818 .37691 Mdot
.818 .3773 Mdot
.818 .37756 Mdot
.818 .37763 Mdot
.818 .37809 Mdot
.818 .37898 Mdot
.818 .37903 Mdot
.818 .37963 Mdot
.818 .38018 Mdot
.818 .38041 Mdot
.818 .38061 Mdot
.818 .38077 Mdot
.818 .38083 Mdot
.818 .38093 Mdot
.818 .38103 Mdot
.818 .38129 Mdot
.818 .38162 Mdot
.818 .38199 Mdot
.818 .38202 Mdot
.818 .38289 Mdot
.818 .38305 Mdot
.818 .38328 Mdot
.818 .38348 Mdot
.818 .38359 Mdot
.818 .38383 Mdot
.818 .38388 Mdot
.818 .38396 Mdot
.818 .38425 Mdot
.818 .38475 Mdot
.818 .38541 Mdot
.818 .38552 Mdot
.818 .38617 Mdot
.818 .38629 Mdot
.818 .38632 Mdot
.818 .38671 Mdot
.818 .38734 Mdot
.818 .38776 Mdot
.818 .38787 Mdot
.818 .38814 Mdot
.818 .38853 Mdot
.818 .38879 Mdot
.818 .38893 Mdot
.818 .38915 Mdot
.818 .38916 Mdot
.818 .38988 Mdot
.818 .38993 Mdot
.818 .39007 Mdot
.818 .39008 Mdot
.818 .39009 Mdot
.818 .39015 Mdot
.818 .39125 Mdot
.818 .39137 Mdot
.818 .39155 Mdot
.818 .39302 Mdot
.818 .39304 Mdot
.818 .39328 Mdot
.818 .39331 Mdot
.818 .39393 Mdot
.818 .39507 Mdot
.818 .39532 Mdot
.818 .39537 Mdot
.818 .39547 Mdot
.818 .39597 Mdot
.818 .39605 Mdot
.818 .3965 Mdot
.818 .39683 Mdot
.818 .39755 Mdot
.818 .39758 Mdot
.818 .39773 Mdot
.818 .39818 Mdot
.818 .39888 Mdot
.818 .39894 Mdot
.818 .39897 Mdot
.818 .39932 Mdot
.818 .39941 Mdot
.818 .39961 Mdot
.818 .40033 Mdot
.818 .40035 Mdot
.818 .40138 Mdot
.818 .40141 Mdot
.818 .40206 Mdot
.818 .4021 Mdot
.818 .40245 Mdot
.818 .40247 Mdot
.818 .40304 Mdot
.818 .40306 Mdot
.818 .4038 Mdot
.818 .40386 Mdot
.818 .40428 Mdot
.818 .40435 Mdot
.818 .40466 Mdot
.818 .40499 Mdot
.818 .40513 Mdot
.818 .40519 Mdot
.818 .40549 Mdot
.818 .40553 Mdot
.818 .40556 Mdot
.818 .40571 Mdot
.818 .40631 Mdot
.818 .40646 Mdot
.818 .40737 Mdot
.818 .40741 Mdot
.818 .40744 Mdot
.818 .40759 Mdot
.818 .40793 Mdot
.818 .40832 Mdot
.818 .40839 Mdot
.818 .40866 Mdot
.818 .40888 Mdot
.818 .40891 Mdot
.818 .40894 Mdot
.818 .40897 Mdot
.818 .40947 Mdot
.818 .40967 Mdot
.818 .41036 Mdot
.818 .41041 Mdot
.818 .41051 Mdot
.818 .41102 Mdot
.818 .41241 Mdot
.818 .41261 Mdot
.818 .41273 Mdot
.818 .41283 Mdot
.818 .41301 Mdot
.818 .41307 Mdot
.818 .41338 Mdot
.818 .41344 Mdot
.818 .41376 Mdot
.818 .41408 Mdot
.818 .41414 Mdot
.818 .41416 Mdot
.818 .41416 Mdot
.818 .41467 Mdot
.818 .41564 Mdot
.818 .41583 Mdot
.818 .41589 Mdot
.818 .41609 Mdot
.818 .41646 Mdot
.818 .41651 Mdot
.818 .4166 Mdot
.818 .417 Mdot
.818 .41705 Mdot
.818 .41762 Mdot
.818 .41842 Mdot
.818 .4186 Mdot
.818 .4187 Mdot
.818 .41887 Mdot
.818 .41955 Mdot
.818 .41968 Mdot
.818 .41985 Mdot
.818 .41995 Mdot
.818 .42007 Mdot
.818 .42021 Mdot
.818 .42056 Mdot
.818 .42076 Mdot
.818 .42101 Mdot
.818 .4213 Mdot
.818 .42139 Mdot
.818 .42149 Mdot
.818 .4222 Mdot
.818 .42231 Mdot
.818 .4227 Mdot
.818 .42284 Mdot
.818 .42333 Mdot
.818 .42336 Mdot
.818 .4236 Mdot
.818 .42361 Mdot
.818 .42372 Mdot
.818 .42387 Mdot
.818 .42388 Mdot
.818 .42398 Mdot
.818 .42552 Mdot
.818 .42561 Mdot
.818 .42581 Mdot
.818 .42599 Mdot
.818 .42637 Mdot
.818 .42663 Mdot
.818 .42717 Mdot
.818 .42721 Mdot
.818 .42882 Mdot
.818 .42908 Mdot
.818 .42923 Mdot
.818 .42931 Mdot
.818 .42938 Mdot
.818 .43011 Mdot
.818 .43025 Mdot
.818 .43044 Mdot
.818 .4305 Mdot
.818 .43061 Mdot
.818 .43102 Mdot
.818 .43123 Mdot
.818 .43148 Mdot
.818 .43179 Mdot
.818 .43201 Mdot
.818 .43297 Mdot
.818 .43302 Mdot
.818 .43309 Mdot
.818 .43575 Mdot
.818 .43578 Mdot
.818 .43584 Mdot
.818 .43666 Mdot
.818 .43666 Mdot
.818 .43683 Mdot
.818 .43706 Mdot
.818 .4371 Mdot
.818 .43738 Mdot
.818 .43748 Mdot
.818 .4376 Mdot
.818 .4377 Mdot
.818 .43788 Mdot
.818 .43809 Mdot
.818 .43863 Mdot
.818 .43864 Mdot
.818 .43869 Mdot
.818 .43876 Mdot
.818 .43928 Mdot
.818 .43949 Mdot
.818 .43996 Mdot
.818 .44001 Mdot
.818 .44022 Mdot
.818 .44026 Mdot
.818 .44061 Mdot
.818 .44081 Mdot
.818 .44094 Mdot
.818 .44135 Mdot
.818 .44206 Mdot
.818 .44224 Mdot
.818 .4424 Mdot
.818 .44251 Mdot
.818 .44322 Mdot
.818 .44327 Mdot
.818 .44352 Mdot
.818 .44371 Mdot
.818 .44456 Mdot
.818 .44528 Mdot
.818 .44543 Mdot
.818 .44555 Mdot
.818 .4458 Mdot
.818 .44597 Mdot
.818 .44605 Mdot
.818 .44672 Mdot
.818 .44676 Mdot
.818 .44687 Mdot
.818 .44688 Mdot
.818 .44696 Mdot
.818 .44737 Mdot
.818 .44836 Mdot
.818 .44877 Mdot
.818 .44896 Mdot
.818 .44906 Mdot
.818 .44935 Mdot
.818 .44948 Mdot
.818 .44996 Mdot
.818 .45108 Mdot
.818 .45181 Mdot
.818 .45181 Mdot
.818 .45186 Mdot
.818 .4519 Mdot
.818 .452 Mdot
.818 .45239 Mdot
.818 .45243 Mdot
.818 .45274 Mdot
.818 .45288 Mdot
.818 .45297 Mdot
.818 .45323 Mdot
.818 .4533 Mdot
.818 .45331 Mdot
.818 .45384 Mdot
.818 .45435 Mdot
.818 .45452 Mdot
.818 .45458 Mdot
.818 .45471 Mdot
.818 .45479 Mdot
.818 .45488 Mdot
.818 .45525 Mdot
.818 .45544 Mdot
.818 .45558 Mdot
.818 .45584 Mdot
.818 .45593 Mdot
.818 .45601 Mdot
.818 .45609 Mdot
.818 .4568 Mdot
.818 .45684 Mdot
.818 .4574 Mdot
.818 .45741 Mdot
.818 .45762 Mdot
.818 .45776 Mdot
.818 .45795 Mdot
.818 .45796 Mdot
.818 .45837 Mdot
.818 .45879 Mdot
.818 .45898 Mdot
.818 .4591 Mdot
.818 .45913 Mdot
.818 .45929 Mdot
.818 .45931 Mdot
.818 .4598 Mdot
.818 .45994 Mdot
.818 .4602 Mdot
.818 .46059 Mdot
.818 .46095 Mdot
.818 .46112 Mdot
.818 .46114 Mdot
.818 .46158 Mdot
.818 .46163 Mdot
.818 .46164 Mdot
.818 .46191 Mdot
.818 .46223 Mdot
.818 .46247 Mdot
.818 .46324 Mdot
.818 .46334 Mdot
.818 .46395 Mdot
.818 .46441 Mdot
.818 .46443 Mdot
.818 .46501 Mdot
.818 .4653 Mdot
.818 .46584 Mdot
.818 .46614 Mdot
.818 .46643 Mdot
.818 .46661 Mdot
.818 .46677 Mdot
.818 .46686 Mdot
.818 .4669 Mdot
.818 .46697 Mdot
.818 .46706 Mdot
.818 .46744 Mdot
.818 .46789 Mdot
.818 .46805 Mdot
.818 .46891 Mdot
.818 .46909 Mdot
.818 .46977 Mdot
.818 .46993 Mdot
.818 .46998 Mdot
.818 .46998 Mdot
.818 .47031 Mdot
.818 .47134 Mdot
.818 .47201 Mdot
.818 .47372 Mdot
.818 .47393 Mdot
.818 .47398 Mdot
.818 .47416 Mdot
.818 .47429 Mdot
.818 .47445 Mdot
.818 .47461 Mdot
.818 .47476 Mdot
.818 .47515 Mdot
.818 .47522 Mdot
.818 .47547 Mdot
.818 .47601 Mdot
.818 .47613 Mdot
.818 .47627 Mdot
.818 .47649 Mdot
.818 .47651 Mdot
.818 .47686 Mdot
.818 .47694 Mdot
.818 .47746 Mdot
.818 .47757 Mdot
.818 .47772 Mdot
.818 .47827 Mdot
.818 .47833 Mdot
.818 .47845 Mdot
.818 .47895 Mdot
.818 .47923 Mdot
.818 .4795 Mdot
.818 .48062 Mdot
.818 .48062 Mdot
.818 .4809 Mdot
.818 .48094 Mdot
.818 .48107 Mdot
.818 .4811 Mdot
.818 .48138 Mdot
.818 .48156 Mdot
.818 .48185 Mdot
.818 .48195 Mdot
.818 .48211 Mdot
.818 .48258 Mdot
.818 .48329 Mdot
.818 .48391 Mdot
.818 .48408 Mdot
.818 .48422 Mdot
.818 .48429 Mdot
.818 .48432 Mdot
.818 .4844 Mdot
.818 .48471 Mdot
.818 .48474 Mdot
.818 .48522 Mdot
.818 .4854 Mdot
.818 .48544 Mdot
.818 .48548 Mdot
.818 .48557 Mdot
.818 .48578 Mdot
.818 .48579 Mdot
.818 .48616 Mdot
.818 .4862 Mdot
.818 .48632 Mdot
.818 .48709 Mdot
.818 .48754 Mdot
.818 .48765 Mdot
.818 .48802 Mdot
.818 .4883 Mdot
.818 .48869 Mdot
.818 .48908 Mdot
.818 .48932 Mdot
.818 .48942 Mdot
.818 .48948 Mdot
.818 .4896 Mdot
.818 .48971 Mdot
.818 .48981 Mdot
.818 .49013 Mdot
.818 .49016 Mdot
.818 .49065 Mdot
.818 .49073 Mdot
.818 .49076 Mdot
.818 .49127 Mdot
.818 .49148 Mdot
.818 .4915 Mdot
.818 .49176 Mdot
.818 .49179 Mdot
.818 .49193 Mdot
.818 .49196 Mdot
.818 .4925 Mdot
.818 .49283 Mdot
.818 .49283 Mdot
.818 .49296 Mdot
.818 .4932 Mdot
.818 .49345 Mdot
.818 .49378 Mdot
.818 .4939 Mdot
.818 .4939 Mdot
.818 .49399 Mdot
.818 .494 Mdot
.818 .49423 Mdot
.818 .4943 Mdot
.818 .49451 Mdot
.818 .4946 Mdot
.818 .49481 Mdot
.818 .49483 Mdot
.818 .49522 Mdot
.818 .49524 Mdot
.818 .49524 Mdot
.818 .49527 Mdot
.818 .49556 Mdot
.818 .49569 Mdot
.818 .4958 Mdot
.818 .49596 Mdot
.818 .49598 Mdot
.818 .49625 Mdot
.818 .49627 Mdot
.818 .49659 Mdot
.818 .4967 Mdot
.818 .4971 Mdot
.82 .18938 Mdot
.82 .18975 Mdot
.82 .19007 Mdot
.82 .19019 Mdot
.82 .19039 Mdot
.82 .1912 Mdot
.82 .19157 Mdot
.82 .19179 Mdot
.82 .19241 Mdot
.82 .19288 Mdot
.82 .19301 Mdot
.82 .19324 Mdot
.82 .19326 Mdot
.82 .19378 Mdot
.82 .19405 Mdot
.82 .19428 Mdot
.82 .1947 Mdot
.82 .19478 Mdot
.82 .19557 Mdot
.82 .19581 Mdot
.82 .19637 Mdot
.82 .19644 Mdot
.82 .19676 Mdot
.82 .19708 Mdot
.82 .19743 Mdot
.82 .19744 Mdot
.82 .19847 Mdot
.82 .19847 Mdot
.82 .1987 Mdot
.82 .19988 Mdot
.82 .20031 Mdot
.82 .20044 Mdot
.82 .20073 Mdot
.82 .2012 Mdot
.82 .20141 Mdot
.82 .20142 Mdot
.82 .20148 Mdot
.82 .20217 Mdot
.82 .20243 Mdot
.82 .20277 Mdot
.82 .20344 Mdot
.82 .2038 Mdot
.82 .20515 Mdot
.82 .20582 Mdot
.82 .206 Mdot
.82 .20603 Mdot
.82 .20668 Mdot
.82 .20688 Mdot
.82 .20705 Mdot
.82 .20707 Mdot
.82 .20735 Mdot
.82 .20738 Mdot
.82 .20751 Mdot
.82 .20826 Mdot
.82 .20878 Mdot
.82 .21007 Mdot
.82 .21019 Mdot
.82 .2102 Mdot
.82 .21042 Mdot
.82 .21084 Mdot
.82 .21108 Mdot
.82 .21122 Mdot
.82 .21152 Mdot
.82 .21164 Mdot
.82 .21184 Mdot
.82 .21221 Mdot
.82 .21225 Mdot
.82 .2131 Mdot
.82 .21416 Mdot
.82 .21473 Mdot
.82 .21531 Mdot
.82 .216 Mdot
.82 .21616 Mdot
.82 .21762 Mdot
.82 .21786 Mdot
.82 .21806 Mdot
.82 .21809 Mdot
.82 .21814 Mdot
.82 .21818 Mdot
.82 .21873 Mdot
.82 .219 Mdot
.82 .21902 Mdot
.82 .21921 Mdot
.82 .2193 Mdot
.82 .21993 Mdot
.82 .22047 Mdot
.82 .2206 Mdot
.82 .2208 Mdot
.82 .22125 Mdot
.82 .22141 Mdot
.82 .22164 Mdot
.82 .22234 Mdot
.82 .22295 Mdot
.82 .22297 Mdot
.82 .22351 Mdot
.82 .22386 Mdot
.82 .2242 Mdot
.82 .22444 Mdot
.82 .22485 Mdot
.82 .22497 Mdot
.82 .22541 Mdot
.82 .22611 Mdot
.82 .22649 Mdot
.82 .22673 Mdot
.82 .22691 Mdot
.82 .22738 Mdot
.82 .22779 Mdot
.82 .22795 Mdot
.82 .22962 Mdot
.82 .23026 Mdot
.82 .23059 Mdot
.82 .23114 Mdot
.82 .23143 Mdot
.82 .23149 Mdot
.82 .23269 Mdot
.82 .23383 Mdot
.82 .23439 Mdot
.82 .23497 Mdot
.82 .2353 Mdot
.82 .2355 Mdot
.82 .23557 Mdot
.82 .23603 Mdot
.82 .23766 Mdot
.82 .23789 Mdot
.82 .23845 Mdot
.82 .23861 Mdot
.82 .23905 Mdot
.82 .23908 Mdot
.82 .23925 Mdot
.82 .23936 Mdot
.82 .23958 Mdot
.82 .23993 Mdot
.82 .24057 Mdot
.82 .24196 Mdot
.82 .24208 Mdot
.82 .24222 Mdot
.82 .24227 Mdot
.82 .24245 Mdot
.82 .24265 Mdot
.82 .24299 Mdot
.82 .24313 Mdot
.82 .24371 Mdot
.82 .24387 Mdot
.82 .24395 Mdot
.82 .24463 Mdot
.82 .24467 Mdot
.82 .2452 Mdot
.82 .24533 Mdot
.82 .24534 Mdot
.82 .2459 Mdot
.82 .24658 Mdot
.82 .24743 Mdot
.82 .24801 Mdot
.82 .2492 Mdot
.82 .24921 Mdot
.82 .24957 Mdot
.82 .25152 Mdot
.82 .25231 Mdot
.82 .25293 Mdot
.82 .25297 Mdot
.82 .25339 Mdot
.82 .25372 Mdot
.82 .25485 Mdot
.82 .25499 Mdot
.82 .25551 Mdot
.82 .25565 Mdot
.82 .25586 Mdot
.82 .25592 Mdot
.82 .256 Mdot
.82 .25643 Mdot
.82 .25719 Mdot
.82 .25729 Mdot
.82 .25771 Mdot
.82 .25776 Mdot
.82 .25783 Mdot
.82 .2579 Mdot
.82 .25872 Mdot
.82 .25939 Mdot
.82 .25954 Mdot
.82 .25963 Mdot
.82 .25972 Mdot
.82 .2598 Mdot
.82 .26006 Mdot
.82 .26058 Mdot
.82 .26065 Mdot
.82 .2608 Mdot
.82 .26164 Mdot
.82 .26184 Mdot
.82 .26228 Mdot
.82 .26359 Mdot
.82 .2641 Mdot
.82 .2644 Mdot
.82 .26498 Mdot
.82 .26665 Mdot
.82 .26679 Mdot
.82 .26733 Mdot
.82 .26792 Mdot
.82 .26882 Mdot
.82 .26914 Mdot
.82 .26997 Mdot
.82 .27054 Mdot
.82 .27066 Mdot
.82 .27123 Mdot
.82 .27129 Mdot
.82 .27275 Mdot
.82 .27374 Mdot
.82 .27423 Mdot
.82 .27452 Mdot
.82 .27486 Mdot
.82 .27521 Mdot
.82 .27773 Mdot
.82 .27851 Mdot
.82 .27905 Mdot
.82 .27954 Mdot
.82 .28031 Mdot
.82 .28053 Mdot
.82 .28161 Mdot
.82 .28257 Mdot
.82 .28335 Mdot
.82 .28348 Mdot
.82 .28403 Mdot
.82 .28426 Mdot
.82 .28474 Mdot
.82 .28492 Mdot
.82 .28559 Mdot
.82 .28713 Mdot
.82 .28771 Mdot
.82 .28824 Mdot
.82 .28897 Mdot
.82 .2897 Mdot
.82 .29047 Mdot
.82 .29104 Mdot
.82 .29156 Mdot
.82 .29216 Mdot
.82 .29234 Mdot
.82 .29244 Mdot
.82 .29256 Mdot
.82 .29277 Mdot
.82 .29298 Mdot
.82 .29385 Mdot
.82 .29419 Mdot
.82 .29431 Mdot
.82 .29538 Mdot
.82 .29555 Mdot
.82 .29571 Mdot
.82 .29656 Mdot
.82 .29669 Mdot
.82 .29751 Mdot
.82 .2976 Mdot
.82 .29766 Mdot
.82 .2979 Mdot
.82 .29795 Mdot
.82 .29815 Mdot
.82 .29882 Mdot
.82 .29883 Mdot
.82 .30069 Mdot
.82 .30102 Mdot
.82 .30116 Mdot
.82 .30123 Mdot
.82 .30144 Mdot
.82 .30153 Mdot
.82 .30169 Mdot
.82 .30177 Mdot
.82 .30177 Mdot
.82 .30229 Mdot
.82 .30249 Mdot
.82 .30277 Mdot
.82 .30281 Mdot
.82 .30283 Mdot
.82 .30308 Mdot
.82 .30364 Mdot
.82 .30415 Mdot
.82 .30428 Mdot
.82 .30453 Mdot
.82 .30465 Mdot
.82 .30475 Mdot
.82 .30511 Mdot
.82 .30544 Mdot
.82 .30613 Mdot
.82 .30652 Mdot
.82 .30691 Mdot
.82 .30712 Mdot
.82 .30721 Mdot
.82 .3075 Mdot
.82 .30753 Mdot
.82 .30777 Mdot
.82 .30816 Mdot
.82 .30821 Mdot
.82 .30838 Mdot
.82 .30883 Mdot
.82 .30913 Mdot
.82 .30921 Mdot
.82 .30988 Mdot
.82 .31002 Mdot
.82 .31014 Mdot
.82 .3107 Mdot
.82 .31132 Mdot
.82 .31133 Mdot
.82 .31152 Mdot
.82 .31171 Mdot
.82 .31251 Mdot
.82 .31263 Mdot
.82 .31275 Mdot
.82 .31288 Mdot
.82 .31326 Mdot
.82 .31335 Mdot
.82 .31379 Mdot
.82 .314 Mdot
.82 .31411 Mdot
.82 .31436 Mdot
.82 .31436 Mdot
.82 .31438 Mdot
.82 .316 Mdot
.82 .31607 Mdot
.82 .31607 Mdot
.82 .31639 Mdot
.82 .31645 Mdot
.82 .31646 Mdot
.82 .31758 Mdot
.82 .31801 Mdot
.82 .31812 Mdot
.82 .31839 Mdot
.82 .3191 Mdot
.82 .31931 Mdot
.82 .31953 Mdot
.82 .31978 Mdot
.82 .31984 Mdot
.82 .32038 Mdot
.82 .32047 Mdot
.82 .32055 Mdot
.82 .32059 Mdot
.82 .3208 Mdot
.82 .3209 Mdot
.82 .32091 Mdot
.82 .32098 Mdot
.82 .32101 Mdot
.82 .32157 Mdot
.82 .32214 Mdot
.82 .32237 Mdot
.82 .32238 Mdot
.82 .32257 Mdot
.82 .32292 Mdot
.82 .32307 Mdot
.82 .32312 Mdot
.82 .32328 Mdot
.82 .32354 Mdot
.82 .32377 Mdot
.82 .32416 Mdot
.82 .32423 Mdot
.82 .32482 Mdot
.82 .32485 Mdot
.82 .32541 Mdot
.82 .32552 Mdot
.82 .32599 Mdot
.82 .32703 Mdot
.82 .32792 Mdot
.82 .32813 Mdot
.82 .32819 Mdot
.82 .32836 Mdot
.82 .32843 Mdot
.82 .32847 Mdot
.82 .32855 Mdot
.82 .32868 Mdot
.82 .32943 Mdot
.82 .32948 Mdot
.82 .32953 Mdot
.82 .32955 Mdot
.82 .32962 Mdot
.82 .32982 Mdot
.82 .32987 Mdot
.82 .33009 Mdot
.82 .33014 Mdot
.82 .33017 Mdot
.82 .33044 Mdot
.82 .33064 Mdot
.82 .33069 Mdot
.82 .33069 Mdot
.82 .3309 Mdot
.82 .33147 Mdot
.82 .33213 Mdot
.82 .33213 Mdot
.82 .33299 Mdot
.82 .33328 Mdot
.82 .33351 Mdot
.82 .33353 Mdot
.82 .33368 Mdot
.82 .33423 Mdot
.82 .33428 Mdot
.82 .33453 Mdot
.82 .3346 Mdot
.82 .33462 Mdot
.82 .33482 Mdot
.82 .3351 Mdot
.82 .33529 Mdot
.82 .33531 Mdot
.82 .33534 Mdot
.82 .33566 Mdot
.82 .33597 Mdot
.82 .336 Mdot
.82 .33607 Mdot
.82 .33616 Mdot
.82 .33636 Mdot
.82 .33638 Mdot
.82 .33644 Mdot
.82 .33675 Mdot
.82 .33699 Mdot
.82 .33748 Mdot
.82 .33766 Mdot
.82 .33799 Mdot
.82 .33861 Mdot
.82 .33867 Mdot
.82 .33942 Mdot
.82 .33954 Mdot
.82 .34006 Mdot
.82 .34011 Mdot
.82 .34032 Mdot
.82 .34125 Mdot
.82 .34143 Mdot
.82 .34154 Mdot
.82 .3418 Mdot
.82 .34273 Mdot
.82 .34302 Mdot
.82 .34323 Mdot
.82 .34341 Mdot
.82 .34369 Mdot
.82 .34377 Mdot
.82 .34483 Mdot
.82 .34508 Mdot
.82 .34534 Mdot
.82 .34541 Mdot
.82 .34623 Mdot
.82 .34644 Mdot
.82 .34691 Mdot
.82 .34718 Mdot
.82 .34747 Mdot
.82 .34768 Mdot
.82 .34787 Mdot
.82 .3482 Mdot
.82 .34825 Mdot
.82 .34833 Mdot
.82 .3484 Mdot
.82 .3489 Mdot
.82 .3493 Mdot
.82 .34936 Mdot
.82 .34974 Mdot
.82 .34978 Mdot
.82 .35009 Mdot
.82 .35012 Mdot
.82 .35014 Mdot
.82 .35023 Mdot
.82 .35033 Mdot
.82 .35058 Mdot
.82 .35127 Mdot
.82 .35139 Mdot
.82 .35155 Mdot
.82 .35158 Mdot
.82 .35164 Mdot
.82 .35167 Mdot
.82 .35204 Mdot
.82 .35216 Mdot
.82 .35237 Mdot
.82 .3527 Mdot
.82 .35304 Mdot
.82 .35344 Mdot
.82 .35369 Mdot
.82 .3539 Mdot
.82 .35405 Mdot
.82 .35406 Mdot
.82 .35478 Mdot
.82 .35523 Mdot
.82 .35567 Mdot
.82 .35598 Mdot
.82 .35622 Mdot
.82 .35626 Mdot
.82 .35635 Mdot
.82 .35696 Mdot
.82 .35713 Mdot
.82 .35771 Mdot
.82 .35827 Mdot
.82 .35839 Mdot
.82 .35863 Mdot
.82 .35867 Mdot
.82 .35903 Mdot
.82 .35933 Mdot
.82 .35954 Mdot
.82 .36025 Mdot
.82 .36046 Mdot
.82 .3605 Mdot
.82 .3614 Mdot
.82 .36196 Mdot
.82 .36197 Mdot
.82 .362 Mdot
.82 .36203 Mdot
.82 .36233 Mdot
.82 .36243 Mdot
.82 .36271 Mdot
.82 .36348 Mdot
.82 .36376 Mdot
.82 .36385 Mdot
.82 .36388 Mdot
.82 .36396 Mdot
.82 .36415 Mdot
.82 .36439 Mdot
.82 .36442 Mdot
.82 .36446 Mdot
.82 .36456 Mdot
.82 .36572 Mdot
.82 .36593 Mdot
.82 .36635 Mdot
.82 .36701 Mdot
.82 .36715 Mdot
.82 .36729 Mdot
.82 .3679 Mdot
.82 .3682 Mdot
.82 .36828 Mdot
.82 .36846 Mdot
.82 .36856 Mdot
.82 .36874 Mdot
.82 .36919 Mdot
.82 .36937 Mdot
.82 .36965 Mdot
.82 .36966 Mdot
.82 .36973 Mdot
.82 .37012 Mdot
.82 .37021 Mdot
.82 .37023 Mdot
.82 .37036 Mdot
.82 .37073 Mdot
.82 .37106 Mdot
.82 .37111 Mdot
.82 .37171 Mdot
.82 .37183 Mdot
.82 .37219 Mdot
.82 .37272 Mdot
.82 .37296 Mdot
.82 .37351 Mdot
.82 .37406 Mdot
.82 .37475 Mdot
.82 .37479 Mdot
.82 .37495 Mdot
.82 .37498 Mdot
.82 .37502 Mdot
.82 .37593 Mdot
.82 .37603 Mdot
.82 .37647 Mdot
.82 .3765 Mdot
.82 .3768 Mdot
.82 .37691 Mdot
.82 .37745 Mdot
.82 .37768 Mdot
.82 .37772 Mdot
.82 .37805 Mdot
.82 .37814 Mdot
.82 .37834 Mdot
.82 .37881 Mdot
.82 .37888 Mdot
.82 .37891 Mdot
.82 .37928 Mdot
.82 .37991 Mdot
.82 .38007 Mdot
.82 .38035 Mdot
.82 .38049 Mdot
.82 .38072 Mdot
.82 .38164 Mdot
.82 .3819 Mdot
.82 .382 Mdot
.82 .38238 Mdot
.82 .38261 Mdot
.82 .38262 Mdot
.82 .38267 Mdot
.82 .38295 Mdot
.82 .38308 Mdot
.82 .38313 Mdot
.82 .38333 Mdot
.82 .3835 Mdot
.82 .38407 Mdot
.82 .38436 Mdot
.82 .38498 Mdot
.82 .38502 Mdot
.82 .38512 Mdot
.82 .38514 Mdot
.82 .3859 Mdot
.82 .38623 Mdot
.82 .38638 Mdot
.82 .38693 Mdot
.82 .387 Mdot
.82 .38736 Mdot
.82 .3874 Mdot
.82 .38759 Mdot
.82 .38782 Mdot
.82 .38791 Mdot
.82 .38821 Mdot
.82 .38825 Mdot
.82 .38843 Mdot
.82 .38853 Mdot
.82 .38892 Mdot
.82 .38898 Mdot
.82 .38909 Mdot
.82 .38932 Mdot
.82 .38969 Mdot
.82 .38986 Mdot
.82 .39027 Mdot
.82 .39052 Mdot
.82 .39065 Mdot
.82 .39136 Mdot
.82 .39142 Mdot
.82 .39146 Mdot
.82 .39172 Mdot
.82 .39177 Mdot
.82 .39179 Mdot
.82 .39185 Mdot
.82 .39272 Mdot
.82 .39292 Mdot
.82 .39293 Mdot
.82 .39294 Mdot
.82 .39383 Mdot
.82 .39386 Mdot
.82 .39473 Mdot
.82 .39498 Mdot
.82 .39512 Mdot
.82 .39599 Mdot
.82 .39636 Mdot
.82 .39659 Mdot
.82 .39678 Mdot
.82 .39732 Mdot
.82 .39777 Mdot
.82 .39786 Mdot
.82 .39838 Mdot
.82 .39899 Mdot
.82 .39922 Mdot
.82 .39924 Mdot
.82 .39927 Mdot
.82 .39929 Mdot
.82 .39939 Mdot
.82 .39988 Mdot
.82 .40004 Mdot
.82 .40015 Mdot
.82 .40016 Mdot
.82 .40063 Mdot
.82 .40091 Mdot
.82 .40165 Mdot
.82 .40195 Mdot
.82 .40212 Mdot
.82 .4024 Mdot
.82 .40254 Mdot
.82 .40304 Mdot
.82 .40308 Mdot
.82 .40403 Mdot
.82 .40426 Mdot
.82 .40437 Mdot
.82 .40449 Mdot
.82 .40539 Mdot
.82 .40546 Mdot
.82 .40557 Mdot
.82 .40614 Mdot
.82 .40627 Mdot
.82 .40661 Mdot
.82 .40669 Mdot
.82 .4085 Mdot
.82 .40854 Mdot
.82 .40867 Mdot
.82 .40873 Mdot
.82 .40877 Mdot
.82 .40879 Mdot
.82 .40918 Mdot
.82 .40949 Mdot
.82 .40961 Mdot
.82 .40963 Mdot
.82 .40967 Mdot
.82 .40982 Mdot
.82 .40985 Mdot
.82 .41018 Mdot
.82 .41028 Mdot
.82 .41029 Mdot
.82 .41043 Mdot
.82 .41113 Mdot
.82 .41154 Mdot
.82 .41201 Mdot
.82 .41216 Mdot
.82 .41238 Mdot
.82 .41254 Mdot
.82 .41266 Mdot
.82 .4127 Mdot
.82 .41275 Mdot
.82 .41278 Mdot
.82 .41323 Mdot
.82 .41331 Mdot
.82 .41343 Mdot
.82 .41354 Mdot
.82 .4137 Mdot
.82 .41488 Mdot
.82 .41516 Mdot
.82 .41523 Mdot
.82 .41557 Mdot
.82 .41599 Mdot
.82 .41623 Mdot
.82 .41637 Mdot
.82 .41653 Mdot
.82 .41666 Mdot
.82 .41675 Mdot
.82 .41708 Mdot
.82 .41709 Mdot
.82 .41757 Mdot
.82 .41793 Mdot
.82 .41804 Mdot
.82 .41817 Mdot
.82 .41824 Mdot
.82 .41829 Mdot
.82 .41863 Mdot
.82 .41882 Mdot
.82 .41968 Mdot
.82 .41974 Mdot
.82 .42001 Mdot
.82 .42069 Mdot
.82 .42073 Mdot
.82 .42097 Mdot
.82 .42197 Mdot
.82 .42212 Mdot
.82 .42219 Mdot
.82 .42258 Mdot
.82 .42287 Mdot
.82 .42309 Mdot
.82 .4237 Mdot
.82 .42382 Mdot
.82 .4242 Mdot
.82 .42454 Mdot
.82 .42515 Mdot
.82 .42572 Mdot
.82 .42575 Mdot
.82 .42599 Mdot
.82 .42633 Mdot
.82 .42675 Mdot
.82 .42741 Mdot
.82 .42789 Mdot
.82 .42796 Mdot
.82 .42811 Mdot
.82 .4285 Mdot
.82 .42885 Mdot
.82 .429 Mdot
.82 .42904 Mdot
.82 .42965 Mdot
.82 .4297 Mdot
.82 .42979 Mdot
.82 .42985 Mdot
.82 .42997 Mdot
.82 .4301 Mdot
.82 .4303 Mdot
.82 .43143 Mdot
.82 .43145 Mdot
.82 .43185 Mdot
.82 .43198 Mdot
.82 .432 Mdot
.82 .43215 Mdot
.82 .43219 Mdot
.82 .43224 Mdot
.82 .43274 Mdot
.82 .43282 Mdot
.82 .43334 Mdot
.82 .43343 Mdot
.82 .43354 Mdot
.82 .43419 Mdot
.82 .43427 Mdot
.82 .43447 Mdot
.82 .435 Mdot
.82 .43513 Mdot
.82 .43526 Mdot
.82 .43534 Mdot
.82 .4354 Mdot
.82 .4355 Mdot
.82 .43587 Mdot
.82 .43619 Mdot
.82 .43653 Mdot
.82 .437 Mdot
.82 .43745 Mdot
.82 .43789 Mdot
.82 .43822 Mdot
.82 .43857 Mdot
.82 .43951 Mdot
.82 .43992 Mdot
.82 .44003 Mdot
.82 .44032 Mdot
.82 .44046 Mdot
.82 .4408 Mdot
.82 .44087 Mdot
.82 .44135 Mdot
.82 .44193 Mdot
.82 .4426 Mdot
.82 .44273 Mdot
.82 .4432 Mdot
.82 .4435 Mdot
.82 .44383 Mdot
.82 .44431 Mdot
.82 .44584 Mdot
.82 .44605 Mdot
.82 .44626 Mdot
.82 .44644 Mdot
.82 .44674 Mdot
.82 .44734 Mdot
.82 .44823 Mdot
.82 .44827 Mdot
.82 .44861 Mdot
.82 .44869 Mdot
.82 .44903 Mdot
.82 .44954 Mdot
.82 .44974 Mdot
.82 .45028 Mdot
.82 .45065 Mdot
.82 .45097 Mdot
.82 .45106 Mdot
.82 .45208 Mdot
.82 .45243 Mdot
.82 .45262 Mdot
.82 .45293 Mdot
.82 .45372 Mdot
.82 .45399 Mdot
.82 .45411 Mdot
.82 .45463 Mdot
.82 .45472 Mdot
.82 .45476 Mdot
.82 .45508 Mdot
.82 .45524 Mdot
.82 .45528 Mdot
.82 .45534 Mdot
.82 .45539 Mdot
.82 .45548 Mdot
.82 .4559 Mdot
.82 .4564 Mdot
.82 .45643 Mdot
.82 .45648 Mdot
.82 .45651 Mdot
.82 .45676 Mdot
.82 .45683 Mdot
.82 .45729 Mdot
.82 .45755 Mdot
.82 .4576 Mdot
.82 .45764 Mdot
.82 .45776 Mdot
.82 .45785 Mdot
.82 .45817 Mdot
.82 .45825 Mdot
.82 .45894 Mdot
.82 .45914 Mdot
.82 .4594 Mdot
.82 .45942 Mdot
.82 .4598 Mdot
.82 .46028 Mdot
.82 .46147 Mdot
.82 .46169 Mdot
.82 .4617 Mdot
.82 .46242 Mdot
.82 .46278 Mdot
.82 .4633 Mdot
.82 .46371 Mdot
.82 .46405 Mdot
.82 .46406 Mdot
.82 .46414 Mdot
.82 .46446 Mdot
.82 .46449 Mdot
.82 .4649 Mdot
.82 .46495 Mdot
.82 .46505 Mdot
.82 .4654 Mdot
.82 .46548 Mdot
.82 .46569 Mdot
.82 .46581 Mdot
.82 .46592 Mdot
.82 .46596 Mdot
.82 .46604 Mdot
.82 .46611 Mdot
.82 .46696 Mdot
.82 .46735 Mdot
.82 .46756 Mdot
.82 .4677 Mdot
.82 .46777 Mdot
.82 .46787 Mdot
.82 .46789 Mdot
.82 .46816 Mdot
.82 .46825 Mdot
.82 .46859 Mdot
.82 .46873 Mdot
.82 .46973 Mdot
.82 .47001 Mdot
.82 .47005 Mdot
.82 .47018 Mdot
.82 .47038 Mdot
.82 .47073 Mdot
.82 .47107 Mdot
.82 .47177 Mdot
.82 .4725 Mdot
.82 .47254 Mdot
.82 .47271 Mdot
.82 .47305 Mdot
.82 .47325 Mdot
.82 .47364 Mdot
.82 .47466 Mdot
.82 .47476 Mdot
.82 .47501 Mdot
.82 .47529 Mdot
.82 .4754 Mdot
.82 .47555 Mdot
.82 .47578 Mdot
.82 .47621 Mdot
.82 .47647 Mdot
.82 .47655 Mdot
.82 .47679 Mdot
.82 .47694 Mdot
.82 .47715 Mdot
.82 .47737 Mdot
.82 .47769 Mdot
.82 .47771 Mdot
.82 .47807 Mdot
.82 .47851 Mdot
.82 .47864 Mdot
.82 .47874 Mdot
.82 .47901 Mdot
.82 .47914 Mdot
.82 .47922 Mdot
.82 .47955 Mdot
.82 .47993 Mdot
.82 .47998 Mdot
.82 .4801 Mdot
.82 .48012 Mdot
.82 .48028 Mdot
.82 .48061 Mdot
.82 .48064 Mdot
.82 .48067 Mdot
.82 .48069 Mdot
.82 .48081 Mdot
.82 .48096 Mdot
.82 .48185 Mdot
.82 .48194 Mdot
.82 .48236 Mdot
.82 .48272 Mdot
.82 .48307 Mdot
.82 .48371 Mdot
.82 .48423 Mdot
.82 .48425 Mdot
.82 .48448 Mdot
.82 .4846 Mdot
.82 .48467 Mdot
.82 .48485 Mdot
.82 .48494 Mdot
.82 .48509 Mdot
.82 .48535 Mdot
.82 .48548 Mdot
.82 .48549 Mdot
.82 .48556 Mdot
.82 .48634 Mdot
.82 .48666 Mdot
.82 .48712 Mdot
.82 .4872 Mdot
.82 .48722 Mdot
.82 .48739 Mdot
.82 .4874 Mdot
.82 .4875 Mdot
.82 .48763 Mdot
.82 .48802 Mdot
.82 .48804 Mdot
.82 .48815 Mdot
.82 .48856 Mdot
.82 .48938 Mdot
.82 .4896 Mdot
.82 .49001 Mdot
.82 .49022 Mdot
.82 .49038 Mdot
.82 .4908 Mdot
.82 .49083 Mdot
.82 .49084 Mdot
.82 .49097 Mdot
.82 .49125 Mdot
.82 .49143 Mdot
.82 .49151 Mdot
.82 .49177 Mdot
.82 .49249 Mdot
.82 .49263 Mdot
.82 .49263 Mdot
.82 .49326 Mdot
.82 .49327 Mdot
.82 .49348 Mdot
.82 .49368 Mdot
.82 .49387 Mdot
.82 .49391 Mdot
.82 .49425 Mdot
.82 .4944 Mdot
.82 .49488 Mdot
.82 .49493 Mdot
.82 .49518 Mdot
.82 .49532 Mdot
.82 .49549 Mdot
.82 .49581 Mdot
.82 .49582 Mdot
.82 .49596 Mdot
.82 .49604 Mdot
.82 .49633 Mdot
.82 .49684 Mdot
.82 .49707 Mdot
.82 .49756 Mdot
.82 .49768 Mdot
.82 .49776 Mdot
.82 .49795 Mdot
.82 .49818 Mdot
.822 .18767 Mdot
.822 .18792 Mdot
.822 .18871 Mdot
.822 .1888 Mdot
.822 .18887 Mdot
.822 .18969 Mdot
.822 .18992 Mdot
.822 .19037 Mdot
.822 .19041 Mdot
.822 .19056 Mdot
.822 .19065 Mdot
.822 .19083 Mdot
.822 .1915 Mdot
.822 .19156 Mdot
.822 .19234 Mdot
.822 .19234 Mdot
.822 .19283 Mdot
.822 .19287 Mdot
.822 .19302 Mdot
.822 .1932 Mdot
.822 .19321 Mdot
.822 .1934 Mdot
.822 .19346 Mdot
.822 .19361 Mdot
.822 .19402 Mdot
.822 .19448 Mdot
.822 .19482 Mdot
.822 .19493 Mdot
.822 .19538 Mdot
.822 .19538 Mdot
.822 .1955 Mdot
.822 .19555 Mdot
.822 .19599 Mdot
.822 .19609 Mdot
.822 .19611 Mdot
.822 .19679 Mdot
.822 .19681 Mdot
.822 .1972 Mdot
.822 .19795 Mdot
.822 .19861 Mdot
.822 .19885 Mdot
.822 .1991 Mdot
.822 .19911 Mdot
.822 .19918 Mdot
.822 .19919 Mdot
.822 .19964 Mdot
.822 .19982 Mdot
.822 .20007 Mdot
.822 .20072 Mdot
.822 .20091 Mdot
.822 .20106 Mdot
.822 .2015 Mdot
.822 .202 Mdot
.822 .20209 Mdot
.822 .2026 Mdot
.822 .20277 Mdot
.822 .20287 Mdot
.822 .20327 Mdot
.822 .20367 Mdot
.822 .20395 Mdot
.822 .2041 Mdot
.822 .20423 Mdot
.822 .20425 Mdot
.822 .20464 Mdot
.822 .20464 Mdot
.822 .20507 Mdot
.822 .20614 Mdot
.822 .20709 Mdot
.822 .20717 Mdot
.822 .20721 Mdot
.822 .20778 Mdot
.822 .20826 Mdot
.822 .20901 Mdot
.822 .20938 Mdot
.822 .20944 Mdot
.822 .20968 Mdot
.822 .20974 Mdot
.822 .20976 Mdot
.822 .20999 Mdot
.822 .21079 Mdot
.822 .21111 Mdot
.822 .2115 Mdot
.822 .21179 Mdot
.822 .21239 Mdot
.822 .21257 Mdot
.822 .21269 Mdot
.822 .2128 Mdot
.822 .21312 Mdot
.822 .21368 Mdot
.822 .21447 Mdot
.822 .21503 Mdot
.822 .21544 Mdot
.822 .21612 Mdot
.822 .21656 Mdot
.822 .21665 Mdot
.822 .21673 Mdot
.822 .21725 Mdot
.822 .21744 Mdot
.822 .21746 Mdot
.822 .21809 Mdot
.822 .21812 Mdot
.822 .22003 Mdot
.822 .22089 Mdot
.822 .22141 Mdot
.822 .22227 Mdot
.822 .22241 Mdot
.822 .22266 Mdot
.822 .22315 Mdot
.822 .22418 Mdot
.822 .22466 Mdot
.822 .22493 Mdot
.822 .2257 Mdot
.822 .22613 Mdot
.822 .22628 Mdot
.822 .22638 Mdot
.822 .2279 Mdot
.822 .22879 Mdot
.822 .22942 Mdot
.822 .22968 Mdot
.822 .23002 Mdot
.822 .23013 Mdot
.822 .23019 Mdot
.822 .23038 Mdot
.822 .23092 Mdot
.822 .23161 Mdot
.822 .23182 Mdot
.822 .23194 Mdot
.822 .23216 Mdot
.822 .23219 Mdot
.822 .23226 Mdot
.822 .23253 Mdot
.822 .2327 Mdot
.822 .234 Mdot
.822 .23401 Mdot
.822 .23427 Mdot
.822 .23545 Mdot
.822 .23572 Mdot
.822 .23592 Mdot
.822 .23597 Mdot
.822 .23602 Mdot
.822 .23797 Mdot
.822 .23824 Mdot
.822 .23927 Mdot
.822 .24011 Mdot
.822 .24049 Mdot
.822 .24051 Mdot
.822 .24065 Mdot
.822 .2408 Mdot
.822 .24174 Mdot
.822 .24177 Mdot
.822 .24263 Mdot
.822 .24284 Mdot
.822 .2436 Mdot
.822 .24368 Mdot
.822 .24383 Mdot
.822 .24421 Mdot
.822 .24436 Mdot
.822 .2448 Mdot
.822 .24487 Mdot
.822 .24522 Mdot
.822 .24543 Mdot
.822 .24596 Mdot
.822 .24617 Mdot
.822 .24681 Mdot
.822 .24739 Mdot
.822 .24776 Mdot
.822 .24794 Mdot
.822 .24831 Mdot
.822 .2484 Mdot
.822 .24881 Mdot
.822 .24895 Mdot
.822 .24978 Mdot
.822 .24994 Mdot
.822 .25006 Mdot
.822 .25303 Mdot
.822 .25341 Mdot
.822 .25393 Mdot
.822 .25414 Mdot
.822 .25505 Mdot
.822 .25532 Mdot
.822 .25586 Mdot
.822 .25589 Mdot
.822 .25638 Mdot
.822 .25641 Mdot
.822 .25657 Mdot
.822 .25665 Mdot
.822 .25672 Mdot
.822 .25698 Mdot
.822 .25778 Mdot
.822 .25825 Mdot
.822 .25857 Mdot
.822 .25933 Mdot
.822 .26059 Mdot
.822 .26133 Mdot
.822 .26212 Mdot
.822 .26232 Mdot
.822 .26256 Mdot
.822 .26275 Mdot
.822 .26341 Mdot
.822 .26352 Mdot
.822 .26408 Mdot
.822 .26447 Mdot
.822 .26527 Mdot
.822 .26578 Mdot
.822 .26644 Mdot
.822 .2668 Mdot
.822 .26723 Mdot
.822 .2679 Mdot
.822 .26796 Mdot
.822 .26844 Mdot
.822 .26923 Mdot
.822 .26976 Mdot
.822 .27027 Mdot
.822 .27064 Mdot
.822 .27165 Mdot
.822 .27279 Mdot
.822 .27388 Mdot
.822 .27418 Mdot
.822 .27486 Mdot
.822 .27732 Mdot
.822 .27768 Mdot
.822 .28014 Mdot
.822 .2803 Mdot
.822 .28152 Mdot
.822 .28196 Mdot
.822 .28307 Mdot
.822 .28335 Mdot
.822 .28347 Mdot
.822 .28415 Mdot
.822 .28499 Mdot
.822 .28696 Mdot
.822 .28711 Mdot
.822 .28714 Mdot
.822 .28735 Mdot
.822 .28749 Mdot
.822 .2877 Mdot
.822 .28889 Mdot
.822 .28958 Mdot
.822 .29004 Mdot
.822 .29018 Mdot
.822 .29087 Mdot
.822 .29097 Mdot
.822 .2919 Mdot
.822 .29234 Mdot
.822 .29292 Mdot
.822 .2932 Mdot
.822 .29378 Mdot
.822 .29387 Mdot
.822 .29391 Mdot
.822 .29437 Mdot
.822 .2953 Mdot
.822 .29673 Mdot
.822 .29832 Mdot
.822 .29886 Mdot
.822 .29906 Mdot
.822 .29946 Mdot
.822 .30017 Mdot
.822 .30032 Mdot
.822 .30043 Mdot
.822 .30076 Mdot
.822 .30091 Mdot
.822 .30103 Mdot
.822 .30144 Mdot
.822 .30214 Mdot
.822 .30237 Mdot
.822 .3024 Mdot
.822 .30275 Mdot
.822 .3033 Mdot
.822 .3035 Mdot
.822 .30356 Mdot
.822 .30366 Mdot
.822 .30381 Mdot
.822 .30396 Mdot
.822 .30406 Mdot
.822 .30425 Mdot
.822 .30428 Mdot
.822 .30446 Mdot
.822 .30475 Mdot
.822 .30509 Mdot
.822 .30535 Mdot
.822 .30545 Mdot
.822 .30553 Mdot
.822 .30606 Mdot
.822 .30621 Mdot
.822 .30668 Mdot
.822 .30673 Mdot
.822 .30673 Mdot
.822 .30744 Mdot
.822 .30754 Mdot
.822 .3076 Mdot
.822 .30785 Mdot
.822 .30785 Mdot
.822 .30814 Mdot
.822 .30816 Mdot
.822 .30848 Mdot
.822 .30851 Mdot
.822 .30857 Mdot
.822 .30882 Mdot
.822 .30916 Mdot
.822 .3092 Mdot
.822 .30949 Mdot
.822 .30958 Mdot
.822 .31026 Mdot
.822 .31056 Mdot
.822 .31064 Mdot
.822 .31081 Mdot
.822 .31098 Mdot
.822 .31172 Mdot
.822 .31174 Mdot
.822 .31186 Mdot
.822 .31193 Mdot
.822 .31201 Mdot
.822 .31216 Mdot
.822 .31233 Mdot
.822 .31246 Mdot
.822 .3125 Mdot
.822 .31273 Mdot
.822 .31289 Mdot
.822 .31293 Mdot
.822 .31293 Mdot
.822 .31319 Mdot
.822 .31361 Mdot
.822 .31405 Mdot
.822 .31407 Mdot
.822 .31407 Mdot
.822 .31424 Mdot
.822 .3144 Mdot
.822 .31471 Mdot
.822 .31477 Mdot
.822 .3154 Mdot
.822 .31594 Mdot
.822 .31595 Mdot
.822 .31609 Mdot
.822 .31625 Mdot
.822 .31704 Mdot
.822 .31743 Mdot
.822 .31771 Mdot
.822 .31784 Mdot
.822 .31787 Mdot
.822 .31798 Mdot
.822 .31798 Mdot
.822 .31807 Mdot
.822 .31874 Mdot
.822 .31903 Mdot
.822 .31911 Mdot
.822 .31944 Mdot
.822 .31973 Mdot
.822 .32009 Mdot
.822 .3205 Mdot
.822 .32056 Mdot
.822 .32076 Mdot
.822 .32083 Mdot
.822 .32084 Mdot
.822 .32107 Mdot
.822 .32179 Mdot
.822 .3221 Mdot
.822 .3223 Mdot
.822 .32261 Mdot
.822 .32276 Mdot
.822 .32294 Mdot
.822 .32332 Mdot
.822 .3235 Mdot
.822 .3236 Mdot
.822 .32388 Mdot
.822 .32404 Mdot
.822 .32413 Mdot
.822 .3247 Mdot
.822 .32526 Mdot
.822 .32536 Mdot
.822 .32554 Mdot
.822 .32581 Mdot
.822 .32607 Mdot
.822 .32615 Mdot
.822 .32627 Mdot
.822 .32628 Mdot
.822 .32631 Mdot
.822 .32641 Mdot
.822 .32695 Mdot
.822 .32696 Mdot
.822 .32759 Mdot
.822 .32767 Mdot
.822 .32768 Mdot
.822 .3277 Mdot
.822 .3289 Mdot
.822 .32936 Mdot
.822 .32941 Mdot
.822 .32947 Mdot
.822 .32983 Mdot
.822 .33015 Mdot
.822 .33022 Mdot
.822 .33053 Mdot
.822 .33059 Mdot
.822 .33073 Mdot
.822 .33079 Mdot
.822 .33095 Mdot
.822 .33098 Mdot
.822 .33111 Mdot
.822 .33118 Mdot
.822 .33138 Mdot
.822 .33146 Mdot
.822 .33211 Mdot
.822 .33249 Mdot
.822 .33279 Mdot
.822 .33285 Mdot
.822 .3329 Mdot
.822 .334 Mdot
.822 .33413 Mdot
.822 .33433 Mdot
.822 .33474 Mdot
.822 .33484 Mdot
.822 .33504 Mdot
.822 .33505 Mdot
.822 .33523 Mdot
.822 .3353 Mdot
.822 .33533 Mdot
.822 .33536 Mdot
.822 .33546 Mdot
.822 .33575 Mdot
.822 .33679 Mdot
.822 .33707 Mdot
.822 .33736 Mdot
.822 .33752 Mdot
.822 .33759 Mdot
.822 .33784 Mdot
.822 .33808 Mdot
.822 .33823 Mdot
.822 .33852 Mdot
.822 .33871 Mdot
.822 .33896 Mdot
.822 .3395 Mdot
.822 .33952 Mdot
.822 .3397 Mdot
.822 .33999 Mdot
.822 .34019 Mdot
.822 .34037 Mdot
.822 .34051 Mdot
.822 .34089 Mdot
.822 .34131 Mdot
.822 .34182 Mdot
.822 .34298 Mdot
.822 .34312 Mdot
.822 .34403 Mdot
.822 .34409 Mdot
.822 .3447 Mdot
.822 .34511 Mdot
.822 .34526 Mdot
.822 .34582 Mdot
.822 .34655 Mdot
.822 .34662 Mdot
.822 .34669 Mdot
.822 .34674 Mdot
.822 .34682 Mdot
.822 .34726 Mdot
.822 .34752 Mdot
.822 .34769 Mdot
.822 .348 Mdot
.822 .34803 Mdot
.822 .34838 Mdot
.822 .34854 Mdot
.822 .34886 Mdot
.822 .34907 Mdot
.822 .34911 Mdot
.822 .34929 Mdot
.822 .35075 Mdot
.822 .35153 Mdot
.822 .35191 Mdot
.822 .35226 Mdot
.822 .35273 Mdot
.822 .35287 Mdot
.822 .35303 Mdot
.822 .35313 Mdot
.822 .35326 Mdot
.822 .35342 Mdot
.822 .35367 Mdot
.822 .35385 Mdot
.822 .35428 Mdot
.822 .35452 Mdot
.822 .35476 Mdot
.822 .35478 Mdot
.822 .35528 Mdot
.822 .35576 Mdot
.822 .35594 Mdot
.822 .356 Mdot
.822 .35616 Mdot
.822 .35626 Mdot
.822 .35641 Mdot
.822 .35658 Mdot
.822 .3567 Mdot
.822 .35733 Mdot
.822 .35739 Mdot
.822 .35793 Mdot
.822 .35845 Mdot
.822 .35867 Mdot
.822 .35898 Mdot
.822 .35905 Mdot
.822 .35908 Mdot
.822 .35955 Mdot
.822 .35962 Mdot
.822 .35986 Mdot
.822 .36 Mdot
.822 .3603 Mdot
.822 .36072 Mdot
.822 .36105 Mdot
.822 .36109 Mdot
.822 .36158 Mdot
.822 .36162 Mdot
.822 .36207 Mdot
.822 .36224 Mdot
.822 .36228 Mdot
.822 .36253 Mdot
.822 .36256 Mdot
.822 .36269 Mdot
.822 .36276 Mdot
.822 .36339 Mdot
.822 .36395 Mdot
.822 .36434 Mdot
.822 .36444 Mdot
.822 .36449 Mdot
.822 .36499 Mdot
.822 .3652 Mdot
.822 .36537 Mdot
.822 .36563 Mdot
.822 .36579 Mdot
.822 .366 Mdot
.822 .36666 Mdot
.822 .36769 Mdot
.822 .36806 Mdot
.822 .36812 Mdot
.822 .36862 Mdot
.822 .36867 Mdot
.822 .36886 Mdot
.822 .36895 Mdot
.822 .36927 Mdot
.822 .37015 Mdot
.822 .37088 Mdot
.822 .37094 Mdot
.822 .37103 Mdot
.822 .37114 Mdot
.822 .3713 Mdot
.822 .37164 Mdot
.822 .37183 Mdot
.822 .37209 Mdot
.822 .37219 Mdot
.822 .37225 Mdot
.822 .37235 Mdot
.822 .37281 Mdot
.822 .373 Mdot
.822 .37308 Mdot
.822 .3732 Mdot
.822 .37341 Mdot
.822 .37357 Mdot
.822 .37384 Mdot
.822 .37398 Mdot
.822 .37434 Mdot
.822 .3744 Mdot
.822 .37483 Mdot
.822 .37521 Mdot
.822 .37524 Mdot
.822 .37542 Mdot
.822 .37566 Mdot
.822 .3776 Mdot
.822 .37769 Mdot
.822 .37805 Mdot
.822 .37838 Mdot
.822 .37846 Mdot
.822 .37853 Mdot
.822 .37869 Mdot
.822 .37906 Mdot
.822 .38049 Mdot
.822 .38063 Mdot
.822 .3812 Mdot
.822 .38175 Mdot
.822 .3821 Mdot
.822 .38219 Mdot
.822 .38306 Mdot
.822 .38328 Mdot
.822 .38389 Mdot
.822 .38527 Mdot
.822 .38563 Mdot
.822 .38589 Mdot
.822 .38593 Mdot
.822 .38615 Mdot
.822 .38623 Mdot
.822 .38639 Mdot
.822 .38649 Mdot
.822 .38662 Mdot
.822 .38674 Mdot
.822 .38729 Mdot
.822 .38787 Mdot
.822 .38794 Mdot
.822 .388 Mdot
.822 .38803 Mdot
.822 .38941 Mdot
.822 .38975 Mdot
.822 .391 Mdot
.822 .39113 Mdot
.822 .39123 Mdot
.822 .39138 Mdot
.822 .39162 Mdot
.822 .39192 Mdot
.822 .39195 Mdot
.822 .39201 Mdot
.822 .39225 Mdot
.822 .39259 Mdot
.822 .39297 Mdot
.822 .3931 Mdot
.822 .39329 Mdot
.822 .39339 Mdot
.822 .39366 Mdot
.822 .39398 Mdot
.822 .39401 Mdot
.822 .39421 Mdot
.822 .39465 Mdot
.822 .39488 Mdot
.822 .39492 Mdot
.822 .39523 Mdot
.822 .39527 Mdot
.822 .39546 Mdot
.822 .3956 Mdot
.822 .39591 Mdot
.822 .39628 Mdot
.822 .39666 Mdot
.822 .39683 Mdot
.822 .39693 Mdot
.822 .39709 Mdot
.822 .39723 Mdot
.822 .39752 Mdot
.822 .39783 Mdot
.822 .39784 Mdot
.822 .39813 Mdot
.822 .39839 Mdot
.822 .39865 Mdot
.822 .39875 Mdot
.822 .39883 Mdot
.822 .39889 Mdot
.822 .39898 Mdot
.822 .39907 Mdot
.822 .39957 Mdot
.822 .3998 Mdot
.822 .40028 Mdot
.822 .40117 Mdot
.822 .40143 Mdot
.822 .40162 Mdot
.822 .40172 Mdot
.822 .40224 Mdot
.822 .4024 Mdot
.822 .40271 Mdot
.822 .40279 Mdot
.822 .40362 Mdot
.822 .40371 Mdot
.822 .40433 Mdot
.822 .40602 Mdot
.822 .40651 Mdot
.822 .40711 Mdot
.822 .40712 Mdot
.822 .40745 Mdot
.822 .40771 Mdot
.822 .40798 Mdot
.822 .40813 Mdot
.822 .40832 Mdot
.822 .40842 Mdot
.822 .40877 Mdot
.822 .40958 Mdot
.822 .40967 Mdot
.822 .40983 Mdot
.822 .40983 Mdot
.822 .41027 Mdot
.822 .41047 Mdot
.822 .41116 Mdot
.822 .4112 Mdot
.822 .41139 Mdot
.822 .41201 Mdot
.822 .41206 Mdot
.822 .41232 Mdot
.822 .41242 Mdot
.822 .41245 Mdot
.822 .41254 Mdot
.822 .41257 Mdot
.822 .41276 Mdot
.822 .41281 Mdot
.822 .413 Mdot
.822 .41322 Mdot
.822 .41329 Mdot
.822 .41356 Mdot
.822 .4143 Mdot
.822 .41431 Mdot
.822 .41436 Mdot
.822 .41508 Mdot
.822 .41517 Mdot
.822 .41524 Mdot
.822 .41561 Mdot
.822 .41578 Mdot
.822 .41647 Mdot
.822 .41685 Mdot
.822 .41696 Mdot
.822 .41719 Mdot
.822 .41758 Mdot
.822 .4177 Mdot
.822 .41847 Mdot
.822 .41852 Mdot
.822 .41864 Mdot
.822 .41893 Mdot
.822 .41915 Mdot
.822 .41952 Mdot
.822 .42015 Mdot
.822 .42038 Mdot
.822 .42126 Mdot
.822 .42136 Mdot
.822 .42145 Mdot
.822 .42178 Mdot
.822 .42216 Mdot
.822 .42239 Mdot
.822 .42248 Mdot
.822 .42259 Mdot
.822 .42287 Mdot
.822 .42312 Mdot
.822 .42328 Mdot
.822 .42355 Mdot
.822 .42357 Mdot
.822 .42364 Mdot
.822 .42375 Mdot
.822 .42393 Mdot
.822 .42467 Mdot
.822 .42472 Mdot
.822 .42532 Mdot
.822 .42555 Mdot
.822 .42557 Mdot
.822 .42597 Mdot
.822 .42637 Mdot
.822 .42662 Mdot
.822 .42708 Mdot
.822 .42737 Mdot
.822 .42746 Mdot
.822 .42778 Mdot
.822 .42805 Mdot
.822 .42826 Mdot
.822 .42843 Mdot
.822 .42854 Mdot
.822 .42868 Mdot
.822 .42892 Mdot
.822 .42914 Mdot
.822 .42969 Mdot
.822 .42984 Mdot
.822 .43027 Mdot
.822 .43088 Mdot
.822 .43095 Mdot
.822 .43105 Mdot
.822 .43184 Mdot
.822 .43217 Mdot
.822 .43314 Mdot
.822 .43401 Mdot
.822 .43457 Mdot
.822 .43485 Mdot
.822 .43488 Mdot
.822 .43493 Mdot
.822 .43528 Mdot
.822 .43545 Mdot
.822 .43581 Mdot
.822 .43607 Mdot
.822 .43664 Mdot
.822 .4367 Mdot
.822 .43712 Mdot
.822 .43721 Mdot
.822 .43749 Mdot
.822 .43791 Mdot
.822 .43863 Mdot
.822 .43876 Mdot
.822 .43884 Mdot
.822 .43897 Mdot
.822 .43899 Mdot
.822 .43908 Mdot
.822 .44028 Mdot
.822 .44079 Mdot
.822 .4412 Mdot
.822 .44128 Mdot
.822 .44145 Mdot
.822 .44212 Mdot
.822 .44239 Mdot
.822 .44313 Mdot
.822 .44322 Mdot
.822 .44472 Mdot
.822 .44494 Mdot
.822 .44644 Mdot
.822 .44685 Mdot
.822 .44703 Mdot
.822 .4477 Mdot
.822 .44839 Mdot
.822 .44901 Mdot
.822 .44923 Mdot
.822 .44954 Mdot
.822 .44986 Mdot
.822 .45034 Mdot
.822 .45064 Mdot
.822 .45067 Mdot
.822 .45108 Mdot
.822 .45134 Mdot
.822 .45156 Mdot
.822 .45196 Mdot
.822 .45227 Mdot
.822 .45276 Mdot
.822 .453 Mdot
.822 .45334 Mdot
.822 .4534 Mdot
.822 .45381 Mdot
.822 .45392 Mdot
.822 .45407 Mdot
.822 .45419 Mdot
.822 .45467 Mdot
.822 .45512 Mdot
.822 .45589 Mdot
.822 .45635 Mdot
.822 .45654 Mdot
.822 .45683 Mdot
.822 .45731 Mdot
.822 .45747 Mdot
.822 .45752 Mdot
.822 .45757 Mdot
.822 .45766 Mdot
.822 .45768 Mdot
.822 .45798 Mdot
.822 .45799 Mdot
.822 .45833 Mdot
.822 .45849 Mdot
.822 .45904 Mdot
.822 .45917 Mdot
.822 .45949 Mdot
.822 .45972 Mdot
.822 .46152 Mdot
.822 .4616 Mdot
.822 .46169 Mdot
.822 .4622 Mdot
.822 .46228 Mdot
.822 .46253 Mdot
.822 .46259 Mdot
.822 .46282 Mdot
.822 .46293 Mdot
.822 .46315 Mdot
.822 .4635 Mdot
.822 .46389 Mdot
.822 .46402 Mdot
.822 .46434 Mdot
.822 .46447 Mdot
.822 .46468 Mdot
.822 .46473 Mdot
.822 .46499 Mdot
.822 .46508 Mdot
.822 .46531 Mdot
.822 .46541 Mdot
.822 .46545 Mdot
.822 .46592 Mdot
.822 .46604 Mdot
.822 .46656 Mdot
.822 .46659 Mdot
.822 .46716 Mdot
.822 .46725 Mdot
.822 .46733 Mdot
.822 .46734 Mdot
.822 .46757 Mdot
.822 .46809 Mdot
.822 .46871 Mdot
.822 .46888 Mdot
.822 .47007 Mdot
.822 .4701 Mdot
.822 .47012 Mdot
.822 .47025 Mdot
.822 .47041 Mdot
.822 .47113 Mdot
.822 .47129 Mdot
.822 .47129 Mdot
.822 .47208 Mdot
.822 .47219 Mdot
.822 .47235 Mdot
.822 .47239 Mdot
.822 .47241 Mdot
.822 .47255 Mdot
.822 .47262 Mdot
.822 .47274 Mdot
.822 .47317 Mdot
.822 .47349 Mdot
.822 .47361 Mdot
.822 .47365 Mdot
.822 .47372 Mdot
.822 .47392 Mdot
.822 .47408 Mdot
.822 .47446 Mdot
.822 .475 Mdot
.822 .47593 Mdot
.822 .47599 Mdot
.822 .47608 Mdot
.822 .47634 Mdot
.822 .47681 Mdot
.822 .47698 Mdot
.822 .47726 Mdot
.822 .47789 Mdot
.822 .47819 Mdot
.822 .47834 Mdot
.822 .47843 Mdot
.822 .47895 Mdot
.822 .47927 Mdot
.822 .47979 Mdot
.822 .48095 Mdot
.822 .48097 Mdot
.822 .48135 Mdot
.822 .48137 Mdot
.822 .48148 Mdot
.822 .4818 Mdot
.822 .48185 Mdot
.822 .4819 Mdot
.822 .48217 Mdot
.822 .48259 Mdot
.822 .48283 Mdot
.822 .48317 Mdot
.822 .48365 Mdot
.822 .484 Mdot
.822 .48419 Mdot
.822 .48426 Mdot
.822 .48433 Mdot
.822 .48444 Mdot
.822 .4848 Mdot
.822 .48498 Mdot
.822 .48522 Mdot
.822 .48541 Mdot
.822 .4859 Mdot
.822 .48604 Mdot
.822 .48605 Mdot
.822 .48609 Mdot
.822 .48623 Mdot
.822 .48627 Mdot
.822 .48649 Mdot
.822 .48695 Mdot
.822 .48724 Mdot
.822 .48759 Mdot
.822 .48761 Mdot
.822 .48766 Mdot
.822 .48824 Mdot
.822 .48889 Mdot
.822 .48915 Mdot
.822 .48915 Mdot
.822 .48939 Mdot
.822 .4894 Mdot
.822 .48948 Mdot
.822 .48957 Mdot
.822 .48974 Mdot
.822 .48999 Mdot
.822 .49023 Mdot
.822 .49029 Mdot
.822 .49039 Mdot
.822 .4907 Mdot
.822 .49076 Mdot
.822 .49106 Mdot
.822 .49133 Mdot
.822 .49142 Mdot
.822 .49154 Mdot
.822 .49193 Mdot
.822 .49208 Mdot
.822 .49219 Mdot
.822 .49247 Mdot
.822 .49247 Mdot
.822 .49251 Mdot
.822 .49252 Mdot
.822 .49268 Mdot
.822 .49282 Mdot
.822 .49322 Mdot
.822 .49368 Mdot
.822 .49392 Mdot
.822 .49393 Mdot
.822 .49434 Mdot
.822 .49435 Mdot
.822 .49441 Mdot
.822 .49468 Mdot
.822 .49471 Mdot
.822 .49478 Mdot
.822 .49479 Mdot
.822 .49506 Mdot
.822 .49512 Mdot
.822 .49533 Mdot
.822 .49561 Mdot
.822 .49586 Mdot
.822 .49595 Mdot
.822 .49599 Mdot
.822 .4961 Mdot
.822 .49611 Mdot
.822 .49622 Mdot
.822 .49631 Mdot
.822 .49634 Mdot
.822 .49663 Mdot
.822 .49663 Mdot
.822 .49711 Mdot
.822 .49714 Mdot
.822 .49755 Mdot
.822 .49766 Mdot
.822 .49771 Mdot
.822 .49781 Mdot
.822 .49783 Mdot
.822 .49811 Mdot
.822 .49825 Mdot
.822 .49874 Mdot
.822 .49879 Mdot
.822 .49884 Mdot
.822 .49932 Mdot
.822 .49947 Mdot
.824 .18595 Mdot
.824 .18596 Mdot
.824 .18854 Mdot
.824 .18856 Mdot
.824 .18914 Mdot
.824 .18915 Mdot
.824 .18923 Mdot
.824 .18937 Mdot
.824 .18969 Mdot
.824 .18969 Mdot
.824 .1901 Mdot
.824 .19042 Mdot
.824 .19053 Mdot
.824 .19068 Mdot
.824 .19075 Mdot
.824 .19086 Mdot
.824 .19108 Mdot
.824 .19155 Mdot
.824 .1917 Mdot
.824 .19171 Mdot
.824 .19194 Mdot
.824 .19243 Mdot
.824 .19295 Mdot
.824 .19297 Mdot
.824 .19373 Mdot
.824 .19374 Mdot
.824 .19476 Mdot
.824 .19481 Mdot
.824 .19502 Mdot
.824 .19518 Mdot
.824 .19547 Mdot
.824 .19576 Mdot
.824 .1958 Mdot
.824 .19626 Mdot
.824 .1964 Mdot
.824 .19726 Mdot
.824 .1973 Mdot
.824 .19759 Mdot
.824 .19786 Mdot
.824 .1986 Mdot
.824 .19907 Mdot
.824 .19926 Mdot
.824 .19941 Mdot
.824 .20007 Mdot
.824 .20028 Mdot
.824 .20057 Mdot
.824 .20087 Mdot
.824 .20172 Mdot
.824 .20186 Mdot
.824 .20193 Mdot
.824 .20199 Mdot
.824 .20199 Mdot
.824 .20209 Mdot
.824 .20253 Mdot
.824 .20284 Mdot
.824 .20323 Mdot
.824 .20381 Mdot
.824 .20381 Mdot
.824 .20426 Mdot
.824 .20432 Mdot
.824 .20442 Mdot
.824 .20524 Mdot
.824 .20556 Mdot
.824 .20588 Mdot
.824 .20622 Mdot
.824 .20627 Mdot
.824 .2068 Mdot
.824 .20774 Mdot
.824 .20889 Mdot
.824 .20898 Mdot
.824 .20928 Mdot
.824 .20951 Mdot
.824 .20956 Mdot
.824 .20983 Mdot
.824 .20989 Mdot
.824 .2107 Mdot
.824 .21133 Mdot
.824 .21149 Mdot
.824 .21226 Mdot
.824 .21432 Mdot
.824 .21523 Mdot
.824 .21549 Mdot
.824 .21653 Mdot
.824 .21766 Mdot
.824 .2179 Mdot
.824 .21894 Mdot
.824 .22052 Mdot
.824 .22057 Mdot
.824 .22104 Mdot
.824 .22107 Mdot
.824 .22167 Mdot
.824 .22173 Mdot
.824 .22233 Mdot
.824 .22262 Mdot
.824 .2229 Mdot
.824 .2229 Mdot
.824 .22331 Mdot
.824 .22333 Mdot
.824 .22531 Mdot
.824 .22593 Mdot
.824 .22613 Mdot
.824 .22665 Mdot
.824 .2267 Mdot
.824 .22671 Mdot
.824 .22704 Mdot
.824 .22821 Mdot
.824 .2283 Mdot
.824 .22843 Mdot
.824 .22862 Mdot
.824 .22866 Mdot
.824 .22886 Mdot
.824 .22917 Mdot
.824 .22922 Mdot
.824 .22971 Mdot
.824 .23084 Mdot
.824 .23106 Mdot
.824 .23107 Mdot
.824 .23109 Mdot
.824 .23308 Mdot
.824 .23331 Mdot
.824 .23355 Mdot
.824 .23377 Mdot
.824 .23426 Mdot
.824 .23474 Mdot
.824 .23549 Mdot
.824 .23625 Mdot
.824 .23627 Mdot
.824 .23637 Mdot
.824 .23673 Mdot
.824 .2373 Mdot
.824 .23743 Mdot
.824 .23777 Mdot
.824 .2379 Mdot
.824 .23887 Mdot
.824 .2397 Mdot
.824 .24008 Mdot
.824 .24019 Mdot
.824 .24031 Mdot
.824 .24106 Mdot
.824 .2415 Mdot
.824 .24172 Mdot
.824 .24185 Mdot
.824 .24185 Mdot
.824 .24206 Mdot
.824 .24214 Mdot
.824 .2431 Mdot
.824 .2431 Mdot
.824 .24348 Mdot
.824 .24397 Mdot
.824 .24401 Mdot
.824 .24444 Mdot
.824 .24478 Mdot
.824 .24716 Mdot
.824 .2476 Mdot
.824 .24862 Mdot
.824 .24889 Mdot
.824 .24942 Mdot
.824 .24981 Mdot
.824 .25047 Mdot
.824 .25061 Mdot
.824 .25117 Mdot
.824 .25162 Mdot
.824 .25221 Mdot
.824 .25241 Mdot
.824 .25342 Mdot
.824 .25378 Mdot
.824 .25417 Mdot
.824 .25455 Mdot
.824 .25493 Mdot
.824 .25554 Mdot
.824 .25621 Mdot
.824 .25654 Mdot
.824 .25679 Mdot
.824 .25703 Mdot
.824 .25719 Mdot
.824 .25752 Mdot
.824 .25799 Mdot
.824 .25826 Mdot
.824 .25855 Mdot
.824 .25901 Mdot
.824 .26061 Mdot
.824 .26142 Mdot
.824 .26189 Mdot
.824 .2619 Mdot
.824 .26227 Mdot
.824 .26266 Mdot
.824 .26312 Mdot
.824 .26329 Mdot
.824 .26343 Mdot
.824 .26357 Mdot
.824 .26454 Mdot
.824 .26471 Mdot
.824 .26506 Mdot
.824 .26544 Mdot
.824 .26731 Mdot
.824 .26886 Mdot
.824 .26887 Mdot
.824 .26896 Mdot
.824 .26968 Mdot
.824 .2699 Mdot
.824 .26997 Mdot
.824 .26997 Mdot
.824 .27072 Mdot
.824 .27146 Mdot
.824 .27167 Mdot
.824 .27198 Mdot
.824 .27246 Mdot
.824 .27346 Mdot
.824 .27376 Mdot
.824 .27434 Mdot
.824 .27457 Mdot
.824 .27459 Mdot
.824 .27546 Mdot
.824 .2767 Mdot
.824 .27702 Mdot
.824 .2778 Mdot
.824 .27809 Mdot
.824 .27883 Mdot
.824 .2797 Mdot
.824 .28053 Mdot
.824 .28107 Mdot
.824 .28112 Mdot
.824 .28118 Mdot
.824 .28124 Mdot
.824 .28187 Mdot
.824 .28216 Mdot
.824 .2833 Mdot
.824 .28342 Mdot
.824 .28426 Mdot
.824 .28526 Mdot
.824 .28628 Mdot
.824 .28695 Mdot
.824 .28711 Mdot
.824 .28799 Mdot
.824 .28827 Mdot
.824 .28907 Mdot
.824 .28912 Mdot
.824 .28968 Mdot
.824 .29057 Mdot
.824 .29075 Mdot
.824 .29113 Mdot
.824 .29169 Mdot
.824 .29303 Mdot
.824 .29372 Mdot
.824 .29374 Mdot
.824 .29393 Mdot
.824 .29406 Mdot
.824 .29409 Mdot
.824 .29453 Mdot
.824 .29486 Mdot
.824 .29493 Mdot
.824 .29648 Mdot
.824 .29672 Mdot
.824 .29673 Mdot
.824 .29691 Mdot
.824 .29692 Mdot
.824 .29751 Mdot
.824 .29798 Mdot
.824 .29878 Mdot
.824 .29997 Mdot
.824 .30084 Mdot
.824 .30096 Mdot
.824 .30117 Mdot
.824 .30121 Mdot
.824 .30198 Mdot
.824 .30217 Mdot
.824 .30219 Mdot
.824 .30232 Mdot
.824 .30255 Mdot
.824 .30308 Mdot
.824 .30308 Mdot
.824 .30343 Mdot
.824 .30355 Mdot
.824 .30375 Mdot
.824 .30379 Mdot
.824 .30427 Mdot
.824 .30445 Mdot
.824 .3047 Mdot
.824 .30482 Mdot
.824 .30499 Mdot
.824 .30537 Mdot
.824 .30586 Mdot
.824 .30603 Mdot
.824 .30604 Mdot
.824 .30615 Mdot
.824 .30639 Mdot
.824 .30641 Mdot
.824 .30679 Mdot
.824 .30707 Mdot
.824 .30745 Mdot
.824 .30759 Mdot
.824 .30785 Mdot
.824 .30801 Mdot
.824 .30828 Mdot
.824 .30845 Mdot
.824 .30847 Mdot
.824 .30848 Mdot
.824 .30974 Mdot
.824 .30974 Mdot
.824 .31069 Mdot
.824 .3107 Mdot
.824 .311 Mdot
.824 .31112 Mdot
.824 .31127 Mdot
.824 .31142 Mdot
.824 .31148 Mdot
.824 .31151 Mdot
.824 .31163 Mdot
.824 .31186 Mdot
.824 .31186 Mdot
.824 .31213 Mdot
.824 .31232 Mdot
.824 .31261 Mdot
.824 .31308 Mdot
.824 .31314 Mdot
.824 .31359 Mdot
.824 .3139 Mdot
.824 .31392 Mdot
.824 .31413 Mdot
.824 .31464 Mdot
.824 .31501 Mdot
.824 .31523 Mdot
.824 .31554 Mdot
.824 .31562 Mdot
.824 .31565 Mdot
.824 .31568 Mdot
.824 .3161 Mdot
.824 .31648 Mdot
.824 .3165 Mdot
.824 .31654 Mdot
.824 .31696 Mdot
.824 .31776 Mdot
.824 .31833 Mdot
.824 .31841 Mdot
.824 .31853 Mdot
.824 .31885 Mdot
.824 .31909 Mdot
.824 .31915 Mdot
.824 .32019 Mdot
.824 .32052 Mdot
.824 .321 Mdot
.824 .3215 Mdot
.824 .32289 Mdot
.824 .32313 Mdot
.824 .32324 Mdot
.824 .32334 Mdot
.824 .32335 Mdot
.824 .3235 Mdot
.824 .3235 Mdot
.824 .32423 Mdot
.824 .32472 Mdot
.824 .32474 Mdot
.824 .32475 Mdot
.824 .32538 Mdot
.824 .32545 Mdot
.824 .32554 Mdot
.824 .32585 Mdot
.824 .32627 Mdot
.824 .32635 Mdot
.824 .32635 Mdot
.824 .32709 Mdot
.824 .32718 Mdot
.824 .32727 Mdot
.824 .32735 Mdot
.824 .32753 Mdot
.824 .32798 Mdot
.824 .32827 Mdot
.824 .3283 Mdot
.824 .32844 Mdot
.824 .32869 Mdot
.824 .32887 Mdot
.824 .32923 Mdot
.824 .32953 Mdot
.824 .32967 Mdot
.824 .32975 Mdot
.824 .33003 Mdot
.824 .33019 Mdot
.824 .33032 Mdot
.824 .3304 Mdot
.824 .33043 Mdot
.824 .33078 Mdot
.824 .33078 Mdot
.824 .33092 Mdot
.824 .3311 Mdot
.824 .33128 Mdot
.824 .33281 Mdot
.824 .33291 Mdot
.824 .33325 Mdot
.824 .3335 Mdot
.824 .33355 Mdot
.824 .33375 Mdot
.824 .33392 Mdot
.824 .33421 Mdot
.824 .33458 Mdot
.824 .33471 Mdot
.824 .33486 Mdot
.824 .335 Mdot
.824 .33536 Mdot
.824 .33561 Mdot
.824 .33573 Mdot
.824 .33582 Mdot
.824 .33591 Mdot
.824 .33626 Mdot
.824 .33636 Mdot
.824 .33647 Mdot
.824 .33664 Mdot
.824 .3377 Mdot
.824 .3377 Mdot
.824 .33784 Mdot
.824 .33798 Mdot
.824 .33868 Mdot
.824 .33874 Mdot
.824 .33901 Mdot
.824 .34027 Mdot
.824 .34027 Mdot
.824 .3403 Mdot
.824 .34065 Mdot
.824 .34067 Mdot
.824 .34068 Mdot
.824 .34095 Mdot
.824 .34122 Mdot
.824 .34142 Mdot
.824 .34196 Mdot
.824 .34207 Mdot
.824 .34228 Mdot
.824 .34237 Mdot
.824 .34315 Mdot
.824 .34327 Mdot
.824 .34356 Mdot
.824 .34367 Mdot
.824 .34426 Mdot
.824 .34456 Mdot
.824 .34476 Mdot
.824 .34478 Mdot
.824 .34517 Mdot
.824 .34558 Mdot
.824 .3463 Mdot
.824 .34668 Mdot
.824 .34699 Mdot
.824 .34731 Mdot
.824 .34771 Mdot
.824 .34826 Mdot
.824 .34833 Mdot
.824 .34847 Mdot
.824 .34917 Mdot
.824 .34955 Mdot
.824 .34956 Mdot
.824 .34984 Mdot
.824 .34987 Mdot
.824 .35081 Mdot
.824 .35099 Mdot
.824 .35128 Mdot
.824 .35172 Mdot
.824 .35204 Mdot
.824 .35246 Mdot
.824 .353 Mdot
.824 .35304 Mdot
.824 .35313 Mdot
.824 .35389 Mdot
.824 .35396 Mdot
.824 .35447 Mdot
.824 .35462 Mdot
.824 .35475 Mdot
.824 .35478 Mdot
.824 .35567 Mdot
.824 .35567 Mdot
.824 .35578 Mdot
.824 .35588 Mdot
.824 .35601 Mdot
.824 .35686 Mdot
.824 .35726 Mdot
.824 .35734 Mdot
.824 .3578 Mdot
.824 .35781 Mdot
.824 .35848 Mdot
.824 .35851 Mdot
.824 .36084 Mdot
.824 .3611 Mdot
.824 .36125 Mdot
.824 .36177 Mdot
.824 .36203 Mdot
.824 .36214 Mdot
.824 .36215 Mdot
.824 .36266 Mdot
.824 .36279 Mdot
.824 .36294 Mdot
.824 .36307 Mdot
.824 .36307 Mdot
.824 .36312 Mdot
.824 .36398 Mdot
.824 .36407 Mdot
.824 .36409 Mdot
.824 .36416 Mdot
.824 .36422 Mdot
.824 .36433 Mdot
.824 .36462 Mdot
.824 .36496 Mdot
.824 .36516 Mdot
.824 .36567 Mdot
.824 .36572 Mdot
.824 .36656 Mdot
.824 .36657 Mdot
.824 .3667 Mdot
.824 .36671 Mdot
.824 .36671 Mdot
.824 .36681 Mdot
.824 .36691 Mdot
.824 .36722 Mdot
.824 .3673 Mdot
.824 .36733 Mdot
.824 .36762 Mdot
.824 .36767 Mdot
.824 .36803 Mdot
.824 .36814 Mdot
.824 .36822 Mdot
.824 .36903 Mdot
.824 .3693 Mdot
.824 .3695 Mdot
.824 .36953 Mdot
.824 .37008 Mdot
.824 .37009 Mdot
.824 .37044 Mdot
.824 .37089 Mdot
.824 .37105 Mdot
.824 .37125 Mdot
.824 .37126 Mdot
.824 .3713 Mdot
.824 .37185 Mdot
.824 .37223 Mdot
.824 .37236 Mdot
.824 .37282 Mdot
.824 .37413 Mdot
.824 .37423 Mdot
.824 .37429 Mdot
.824 .37457 Mdot
.824 .37462 Mdot
.824 .3748 Mdot
.824 .37491 Mdot
.824 .37495 Mdot
.824 .37536 Mdot
.824 .37573 Mdot
.824 .37593 Mdot
.824 .37625 Mdot
.824 .37633 Mdot
.824 .37653 Mdot
.824 .37665 Mdot
.824 .37678 Mdot
.824 .37732 Mdot
.824 .37819 Mdot
.824 .37838 Mdot
.824 .37854 Mdot
.824 .37903 Mdot
.824 .37907 Mdot
.824 .37928 Mdot
.824 .37981 Mdot
.824 .37984 Mdot
.824 .37995 Mdot
.824 .38 Mdot
.824 .38059 Mdot
.824 .38083 Mdot
.824 .38084 Mdot
.824 .38092 Mdot
.824 .38117 Mdot
.824 .3815 Mdot
.824 .38153 Mdot
.824 .38174 Mdot
.824 .38211 Mdot
.824 .38231 Mdot
.824 .38246 Mdot
.824 .38251 Mdot
.824 .38252 Mdot
.824 .38305 Mdot
.824 .38346 Mdot
.824 .38359 Mdot
.824 .38361 Mdot
.824 .38401 Mdot
.824 .38412 Mdot
.824 .38498 Mdot
.824 .38506 Mdot
.824 .38525 Mdot
.824 .3853 Mdot
.824 .38549 Mdot
.824 .38611 Mdot
.824 .38618 Mdot
.824 .38629 Mdot
.824 .38649 Mdot
.824 .38652 Mdot
.824 .38658 Mdot
.824 .38738 Mdot
.824 .38766 Mdot
.824 .38774 Mdot
.824 .38797 Mdot
.824 .38846 Mdot
.824 .38882 Mdot
.824 .38903 Mdot
.824 .38904 Mdot
.824 .38938 Mdot
.824 .38939 Mdot
.824 .38952 Mdot
.824 .39029 Mdot
.824 .39051 Mdot
.824 .39071 Mdot
.824 .39103 Mdot
.824 .39109 Mdot
.824 .39109 Mdot
.824 .39117 Mdot
.824 .39169 Mdot
.824 .39172 Mdot
.824 .39203 Mdot
.824 .39215 Mdot
.824 .39253 Mdot
.824 .3926 Mdot
.824 .39264 Mdot
.824 .3933 Mdot
.824 .3933 Mdot
.824 .39338 Mdot
.824 .39355 Mdot
.824 .39385 Mdot
.824 .39386 Mdot
.824 .39393 Mdot
.824 .3944 Mdot
.824 .39449 Mdot
.824 .39465 Mdot
.824 .39682 Mdot
.824 .39758 Mdot
.824 .39779 Mdot
.824 .39779 Mdot
.824 .39842 Mdot
.824 .39851 Mdot
.824 .39933 Mdot
.824 .39938 Mdot
.824 .39941 Mdot
.824 .39974 Mdot
.824 .39999 Mdot
.824 .40018 Mdot
.824 .40063 Mdot
.824 .40073 Mdot
.824 .40131 Mdot
.824 .40132 Mdot
.824 .4015 Mdot
.824 .40216 Mdot
.824 .40224 Mdot
.824 .40228 Mdot
.824 .40262 Mdot
.824 .40306 Mdot
.824 .40324 Mdot
.824 .40347 Mdot
.824 .40439 Mdot
.824 .4044 Mdot
.824 .40453 Mdot
.824 .40471 Mdot
.824 .40514 Mdot
.824 .40531 Mdot
.824 .40538 Mdot
.824 .40586 Mdot
.824 .40591 Mdot
.824 .40604 Mdot
.824 .40611 Mdot
.824 .40644 Mdot
.824 .40655 Mdot
.824 .40672 Mdot
.824 .40689 Mdot
.824 .40689 Mdot
.824 .4069 Mdot
.824 .40711 Mdot
.824 .40713 Mdot
.824 .4081 Mdot
.824 .40852 Mdot
.824 .40861 Mdot
.824 .40869 Mdot
.824 .40934 Mdot
.824 .40944 Mdot
.824 .40978 Mdot
.824 .40996 Mdot
.824 .41033 Mdot
.824 .41058 Mdot
.824 .41081 Mdot
.824 .41099 Mdot
.824 .41109 Mdot
.824 .41121 Mdot
.824 .41124 Mdot
.824 .41139 Mdot
.824 .4116 Mdot
.824 .41269 Mdot
.824 .4128 Mdot
.824 .41289 Mdot
.824 .41289 Mdot
.824 .4131 Mdot
.824 .41325 Mdot
.824 .41334 Mdot
.824 .41356 Mdot
.824 .41365 Mdot
.824 .41405 Mdot
.824 .41431 Mdot
.824 .41439 Mdot
.824 .41442 Mdot
.824 .41459 Mdot
.824 .41486 Mdot
.824 .41502 Mdot
.824 .41563 Mdot
.824 .41588 Mdot
.824 .41607 Mdot
.824 .41613 Mdot
.824 .41655 Mdot
.824 .41657 Mdot
.824 .41731 Mdot
.824 .41995 Mdot
.824 .42039 Mdot
.824 .42044 Mdot
.824 .42128 Mdot
.824 .42155 Mdot
.824 .42157 Mdot
.824 .42205 Mdot
.824 .42207 Mdot
.824 .42232 Mdot
.824 .42246 Mdot
.824 .42268 Mdot
.824 .42312 Mdot
.824 .42332 Mdot
.824 .42409 Mdot
.824 .42437 Mdot
.824 .42451 Mdot
.824 .4246 Mdot
.824 .42473 Mdot
.824 .42482 Mdot
.824 .42489 Mdot
.824 .42508 Mdot
.824 .42508 Mdot
.824 .42643 Mdot
.824 .42655 Mdot
.824 .42671 Mdot
.824 .42681 Mdot
.824 .42705 Mdot
.824 .42728 Mdot
.824 .4279 Mdot
.824 .42791 Mdot
.824 .42801 Mdot
.824 .42927 Mdot
.824 .42941 Mdot
.824 .42948 Mdot
.824 .43037 Mdot
.824 .43099 Mdot
.824 .43106 Mdot
.824 .43159 Mdot
.824 .43231 Mdot
.824 .4328 Mdot
.824 .43308 Mdot
.824 .43355 Mdot
.824 .43356 Mdot
.824 .43371 Mdot
.824 .43464 Mdot
.824 .43469 Mdot
.824 .43489 Mdot
.824 .43515 Mdot
.824 .43517 Mdot
.824 .43525 Mdot
.824 .43537 Mdot
.824 .43538 Mdot
.824 .4358 Mdot
.824 .43661 Mdot
.824 .43695 Mdot
.824 .43718 Mdot
.824 .43729 Mdot
.824 .43783 Mdot
.824 .43817 Mdot
.824 .4382 Mdot
.824 .43868 Mdot
.824 .43885 Mdot
.824 .43939 Mdot
.824 .43948 Mdot
.824 .43989 Mdot
.824 .44051 Mdot
.824 .44112 Mdot
.824 .44163 Mdot
.824 .4417 Mdot
.824 .44239 Mdot
.824 .44257 Mdot
.824 .44295 Mdot
.824 .44299 Mdot
.824 .44302 Mdot
.824 .44305 Mdot
.824 .44338 Mdot
.824 .44389 Mdot
.824 .44442 Mdot
.824 .44486 Mdot
.824 .44504 Mdot
.824 .44551 Mdot
.824 .44571 Mdot
.824 .44646 Mdot
.824 .44699 Mdot
.824 .447 Mdot
.824 .44714 Mdot
.824 .44749 Mdot
.824 .44767 Mdot
.824 .44828 Mdot
.824 .44857 Mdot
.824 .44876 Mdot
.824 .44889 Mdot
.824 .44933 Mdot
.824 .44979 Mdot
.824 .44979 Mdot
.824 .44983 Mdot
.824 .44997 Mdot
.824 .4504 Mdot
.824 .45046 Mdot
.824 .45046 Mdot
.824 .45141 Mdot
.824 .45254 Mdot
.824 .45277 Mdot
.824 .45298 Mdot
.824 .45309 Mdot
.824 .45368 Mdot
.824 .45376 Mdot
.824 .45384 Mdot
.824 .45394 Mdot
.824 .45423 Mdot
.824 .45446 Mdot
.824 .45469 Mdot
.824 .4547 Mdot
.824 .45498 Mdot
.824 .45547 Mdot
.824 .45644 Mdot
.824 .45672 Mdot
.824 .4569 Mdot
.824 .45706 Mdot
.824 .45734 Mdot
.824 .45755 Mdot
.824 .45764 Mdot
.824 .45779 Mdot
.824 .45794 Mdot
.824 .45814 Mdot
.824 .45855 Mdot
.824 .45892 Mdot
.824 .45915 Mdot
.824 .45938 Mdot
.824 .45962 Mdot
.824 .45983 Mdot
.824 .46044 Mdot
.824 .46057 Mdot
.824 .46092 Mdot
.824 .4612 Mdot
.824 .46154 Mdot
.824 .46162 Mdot
.824 .46202 Mdot
.824 .46226 Mdot
.824 .46258 Mdot
.824 .46275 Mdot
.824 .46336 Mdot
.824 .46363 Mdot
.824 .46508 Mdot
.824 .46528 Mdot
.824 .46554 Mdot
.824 .46556 Mdot
.824 .46586 Mdot
.824 .46609 Mdot
.824 .4661 Mdot
.824 .46667 Mdot
.824 .46673 Mdot
.824 .46685 Mdot
.824 .46685 Mdot
.824 .46693 Mdot
.824 .46707 Mdot
.824 .46733 Mdot
.824 .46779 Mdot
.824 .46786 Mdot
.824 .46793 Mdot
.824 .46816 Mdot
.824 .46866 Mdot
.824 .46925 Mdot
.824 .46933 Mdot
.824 .46954 Mdot
.824 .46962 Mdot
.824 .46996 Mdot
.824 .47018 Mdot
.824 .47024 Mdot
.824 .47025 Mdot
.824 .47072 Mdot
.824 .47116 Mdot
.824 .47146 Mdot
.824 .47175 Mdot
.824 .47189 Mdot
.824 .47204 Mdot
.824 .47218 Mdot
.824 .47338 Mdot
.824 .4734 Mdot
.824 .4734 Mdot
.824 .47353 Mdot
.824 .47422 Mdot
.824 .47452 Mdot
.824 .47455 Mdot
.824 .47474 Mdot
.824 .47485 Mdot
.824 .47488 Mdot
.824 .475 Mdot
.824 .47507 Mdot
.824 .47513 Mdot
.824 .47584 Mdot
.824 .47604 Mdot
.824 .47605 Mdot
.824 .47608 Mdot
.824 .47639 Mdot
.824 .47652 Mdot
.824 .47689 Mdot
.824 .47809 Mdot
.824 .4781 Mdot
.824 .47835 Mdot
.824 .47835 Mdot
.824 .47852 Mdot
.824 .4787 Mdot
.824 .47906 Mdot
.824 .4791 Mdot
.824 .47947 Mdot
.824 .47948 Mdot
.824 .47977 Mdot
.824 .47979 Mdot
.824 .48075 Mdot
.824 .48139 Mdot
.824 .48153 Mdot
.824 .48222 Mdot
.824 .48285 Mdot
.824 .48301 Mdot
.824 .48356 Mdot
.824 .48481 Mdot
.824 .48527 Mdot
.824 .48537 Mdot
.824 .48575 Mdot
.824 .48625 Mdot
.824 .48628 Mdot
.824 .48645 Mdot
.824 .48648 Mdot
.824 .48661 Mdot
.824 .4868 Mdot
.824 .48685 Mdot
.824 .48755 Mdot
.824 .48812 Mdot
.824 .48844 Mdot
.824 .48847 Mdot
.824 .48868 Mdot
.824 .48887 Mdot
.824 .48907 Mdot
.824 .48957 Mdot
.824 .48963 Mdot
.824 .48966 Mdot
.824 .48993 Mdot
.824 .48993 Mdot
.824 .49029 Mdot
.824 .49052 Mdot
.824 .49071 Mdot
.824 .49098 Mdot
.824 .49104 Mdot
.824 .49104 Mdot
.824 .49108 Mdot
.824 .49112 Mdot
.824 .49121 Mdot
.824 .49172 Mdot
.824 .4919 Mdot
.824 .49208 Mdot
.824 .4922 Mdot
.824 .49261 Mdot
.824 .49269 Mdot
.824 .49281 Mdot
.824 .4931 Mdot
.824 .49355 Mdot
.824 .49371 Mdot
.824 .49388 Mdot
.824 .49391 Mdot
.824 .49443 Mdot
.824 .49452 Mdot
.824 .4948 Mdot
.824 .49482 Mdot
.824 .49499 Mdot
.824 .49517 Mdot
.824 .49527 Mdot
.824 .4954 Mdot
.824 .49543 Mdot
.824 .49605 Mdot
.824 .49605 Mdot
.824 .49651 Mdot
.824 .49653 Mdot
.824 .49684 Mdot
.824 .49714 Mdot
.824 .49728 Mdot
.824 .49728 Mdot
.824 .49737 Mdot
.824 .49766 Mdot
.824 .4978 Mdot
.824 .49786 Mdot
.824 .49791 Mdot
.824 .498 Mdot
.824 .49806 Mdot
.824 .49826 Mdot
.824 .4985 Mdot
.824 .4985 Mdot
.824 .4987 Mdot
.824 .49878 Mdot
.824 .49883 Mdot
.824 .49884 Mdot
.824 .49919 Mdot
.824 .4992 Mdot
.824 .50077 Mdot
.824 .50077 Mdot
.826 .18446 Mdot
.826 .18462 Mdot
.826 .18488 Mdot
.826 .18499 Mdot
.826 .18507 Mdot
.826 .18543 Mdot
.826 .18565 Mdot
.826 .18589 Mdot
.826 .18603 Mdot
.826 .1863 Mdot
.826 .18655 Mdot
.826 .18681 Mdot
.826 .1871 Mdot
.826 .18735 Mdot
.826 .18768 Mdot
.826 .18804 Mdot
.826 .18841 Mdot
.826 .18862 Mdot
.826 .18875 Mdot
.826 .18952 Mdot
.826 .19065 Mdot
.826 .19121 Mdot
.826 .19147 Mdot
.826 .19168 Mdot
.826 .19187 Mdot
.826 .19232 Mdot
.826 .19244 Mdot
.826 .19312 Mdot
.826 .19335 Mdot
.826 .1934 Mdot
.826 .19363 Mdot
.826 .19419 Mdot
.826 .19614 Mdot
.826 .19618 Mdot
.826 .19657 Mdot
.826 .19721 Mdot
.826 .19739 Mdot
.826 .19761 Mdot
.826 .19871 Mdot
.826 .19917 Mdot
.826 .2004 Mdot
.826 .20122 Mdot
.826 .20199 Mdot
.826 .20202 Mdot
.826 .20202 Mdot
.826 .20244 Mdot
.826 .20248 Mdot
.826 .20272 Mdot
.826 .20284 Mdot
.826 .20296 Mdot
.826 .20357 Mdot
.826 .20384 Mdot
.826 .20396 Mdot
.826 .2047 Mdot
.826 .20527 Mdot
.826 .20579 Mdot
.826 .20626 Mdot
.826 .20676 Mdot
.826 .20764 Mdot
.826 .20788 Mdot
.826 .20879 Mdot
.826 .20885 Mdot
.826 .20924 Mdot
.826 .20953 Mdot
.826 .20993 Mdot
.826 .2102 Mdot
.826 .21037 Mdot
.826 .21083 Mdot
.826 .21086 Mdot
.826 .21103 Mdot
.826 .21167 Mdot
.826 .21212 Mdot
.826 .21218 Mdot
.826 .21232 Mdot
.826 .21346 Mdot
.826 .21387 Mdot
.826 .21402 Mdot
.826 .21426 Mdot
.826 .2146 Mdot
.826 .21491 Mdot
.826 .21538 Mdot
.826 .21574 Mdot
.826 .2164 Mdot
.826 .21645 Mdot
.826 .21651 Mdot
.826 .21675 Mdot
.826 .21694 Mdot
.826 .21695 Mdot
.826 .21731 Mdot
.826 .21743 Mdot
.826 .2176 Mdot
.826 .21798 Mdot
.826 .21832 Mdot
.826 .21841 Mdot
.826 .21847 Mdot
.826 .21869 Mdot
.826 .21926 Mdot
.826 .21965 Mdot
.826 .22012 Mdot
.826 .22037 Mdot
.826 .22066 Mdot
.826 .22095 Mdot
.826 .22129 Mdot
.826 .22134 Mdot
.826 .22165 Mdot
.826 .22189 Mdot
.826 .22217 Mdot
.826 .22257 Mdot
.826 .22312 Mdot
.826 .22331 Mdot
.826 .2235 Mdot
.826 .22358 Mdot
.826 .2237 Mdot
.826 .22374 Mdot
.826 .22402 Mdot
.826 .22454 Mdot
.826 .22548 Mdot
.826 .2256 Mdot
.826 .22579 Mdot
.826 .22678 Mdot
.826 .22689 Mdot
.826 .22722 Mdot
.826 .22734 Mdot
.826 .22741 Mdot
.826 .22745 Mdot
.826 .22763 Mdot
.826 .22794 Mdot
.826 .22931 Mdot
.826 .23028 Mdot
.826 .23069 Mdot
.826 .23085 Mdot
.826 .23192 Mdot
.826 .23207 Mdot
.826 .23248 Mdot
.826 .23309 Mdot
.826 .23331 Mdot
.826 .23519 Mdot
.826 .23538 Mdot
.826 .23579 Mdot
.826 .23759 Mdot
.826 .23767 Mdot
.826 .23832 Mdot
.826 .23835 Mdot
.826 .23836 Mdot
.826 .23941 Mdot
.826 .23978 Mdot
.826 .23986 Mdot
.826 .2406 Mdot
.826 .24072 Mdot
.826 .24074 Mdot
.826 .24136 Mdot
.826 .24201 Mdot
.826 .24209 Mdot
.826 .24211 Mdot
.826 .24282 Mdot
.826 .24425 Mdot
.826 .245 Mdot
.826 .24509 Mdot
.826 .24511 Mdot
.826 .24829 Mdot
.826 .24844 Mdot
.826 .24876 Mdot
.826 .24904 Mdot
.826 .25006 Mdot
.826 .25015 Mdot
.826 .25018 Mdot
.826 .25044 Mdot
.826 .2508 Mdot
.826 .25165 Mdot
.826 .25237 Mdot
.826 .25292 Mdot
.826 .25304 Mdot
.826 .25341 Mdot
.826 .25407 Mdot
.826 .25424 Mdot
.826 .25429 Mdot
.826 .25438 Mdot
.826 .25447 Mdot
.826 .25452 Mdot
.826 .25454 Mdot
.826 .25471 Mdot
.826 .25509 Mdot
.826 .2556 Mdot
.826 .2557 Mdot
.826 .25599 Mdot
.826 .25629 Mdot
.826 .25635 Mdot
.826 .25757 Mdot
.826 .25795 Mdot
.826 .25905 Mdot
.826 .25939 Mdot
.826 .25973 Mdot
.826 .26027 Mdot
.826 .26061 Mdot
.826 .26124 Mdot
.826 .26127 Mdot
.826 .26137 Mdot
.826 .2621 Mdot
.826 .26253 Mdot
.826 .26329 Mdot
.826 .26345 Mdot
.826 .26357 Mdot
.826 .26385 Mdot
.826 .26402 Mdot
.826 .26412 Mdot
.826 .26435 Mdot
.826 .26476 Mdot
.826 .26496 Mdot
.826 .26725 Mdot
.826 .26749 Mdot
.826 .26832 Mdot
.826 .26863 Mdot
.826 .26901 Mdot
.826 .26928 Mdot
.826 .26953 Mdot
.826 .27016 Mdot
.826 .2703 Mdot
.826 .27132 Mdot
.826 .27317 Mdot
.826 .27443 Mdot
.826 .27529 Mdot
.826 .27713 Mdot
.826 .27781 Mdot
.826 .27818 Mdot
.826 .27891 Mdot
.826 .28045 Mdot
.826 .28055 Mdot
.826 .28075 Mdot
.826 .28186 Mdot
.826 .2823 Mdot
.826 .28343 Mdot
.826 .28397 Mdot
.826 .28398 Mdot
.826 .28402 Mdot
.826 .28533 Mdot
.826 .28546 Mdot
.826 .28555 Mdot
.826 .2856 Mdot
.826 .28619 Mdot
.826 .28625 Mdot
.826 .28855 Mdot
.826 .28879 Mdot
.826 .28902 Mdot
.826 .28907 Mdot
.826 .29014 Mdot
.826 .29098 Mdot
.826 .29105 Mdot
.826 .29182 Mdot
.826 .29219 Mdot
.826 .29264 Mdot
.826 .2932 Mdot
.826 .29382 Mdot
.826 .29392 Mdot
.826 .29397 Mdot
.826 .29461 Mdot
.826 .29514 Mdot
.826 .29533 Mdot
.826 .2954 Mdot
.826 .29567 Mdot
.826 .29582 Mdot
.826 .29592 Mdot
.826 .29601 Mdot
.826 .29614 Mdot
.826 .29637 Mdot
.826 .29674 Mdot
.826 .2971 Mdot
.826 .29718 Mdot
.826 .2972 Mdot
.826 .29723 Mdot
.826 .29736 Mdot
.826 .29749 Mdot
.826 .2976 Mdot
.826 .29773 Mdot
.826 .29789 Mdot
.826 .29817 Mdot
.826 .29831 Mdot
.826 .29859 Mdot
.826 .29886 Mdot
.826 .29901 Mdot
.826 .29943 Mdot
.826 .29948 Mdot
.826 .2995 Mdot
.826 .2999 Mdot
.826 .30014 Mdot
.826 .30045 Mdot
.826 .30106 Mdot
.826 .30147 Mdot
.826 .30165 Mdot
.826 .30201 Mdot
.826 .30222 Mdot
.826 .30249 Mdot
.826 .3032 Mdot
.826 .3035 Mdot
.826 .30442 Mdot
.826 .30534 Mdot
.826 .30536 Mdot
.826 .30628 Mdot
.826 .30638 Mdot
.826 .30646 Mdot
.826 .30671 Mdot
.826 .30692 Mdot
.826 .30699 Mdot
.826 .30707 Mdot
.826 .30737 Mdot
.826 .30778 Mdot
.826 .30807 Mdot
.826 .30811 Mdot
.826 .30832 Mdot
.826 .30867 Mdot
.826 .30896 Mdot
.826 .30906 Mdot
.826 .30941 Mdot
.826 .30944 Mdot
.826 .30976 Mdot
.826 .30981 Mdot
.826 .30991 Mdot
.826 .31011 Mdot
.826 .31019 Mdot
.826 .31028 Mdot
.826 .31052 Mdot
.826 .31062 Mdot
.826 .31081 Mdot
.826 .31094 Mdot
.826 .3112 Mdot
.826 .31223 Mdot
.826 .31263 Mdot
.826 .31303 Mdot
.826 .31332 Mdot
.826 .31419 Mdot
.826 .31443 Mdot
.826 .31449 Mdot
.826 .31457 Mdot
.826 .31514 Mdot
.826 .31559 Mdot
.826 .31618 Mdot
.826 .31619 Mdot
.826 .31634 Mdot
.826 .31636 Mdot
.826 .31645 Mdot
.826 .31649 Mdot
.826 .31653 Mdot
.826 .31676 Mdot
.826 .31686 Mdot
.826 .31757 Mdot
.826 .31825 Mdot
.826 .31867 Mdot
.826 .31869 Mdot
.826 .31884 Mdot
.826 .31909 Mdot
.826 .31919 Mdot
.826 .31942 Mdot
.826 .31943 Mdot
.826 .31973 Mdot
.826 .32059 Mdot
.826 .32068 Mdot
.826 .32091 Mdot
.826 .32146 Mdot
.826 .32148 Mdot
.826 .32159 Mdot
.826 .32166 Mdot
.826 .32184 Mdot
.826 .32251 Mdot
.826 .32282 Mdot
.826 .32291 Mdot
.826 .32313 Mdot
.826 .32327 Mdot
.826 .32392 Mdot
.826 .32409 Mdot
.826 .32413 Mdot
.826 .32415 Mdot
.826 .32444 Mdot
.826 .32483 Mdot
.826 .3249 Mdot
.826 .32526 Mdot
.826 .3253 Mdot
.826 .32549 Mdot
.826 .32551 Mdot
.826 .32569 Mdot
.826 .32654 Mdot
.826 .3267 Mdot
.826 .32715 Mdot
.826 .32735 Mdot
.826 .32765 Mdot
.826 .32856 Mdot
.826 .32922 Mdot
.826 .32949 Mdot
.826 .3295 Mdot
.826 .32951 Mdot
.826 .32989 Mdot
.826 .33003 Mdot
.826 .33005 Mdot
.826 .33038 Mdot
.826 .33087 Mdot
.826 .33088 Mdot
.826 .33114 Mdot
.826 .33167 Mdot
.826 .33194 Mdot
.826 .33197 Mdot
.826 .33198 Mdot
.826 .33332 Mdot
.826 .33342 Mdot
.826 .33383 Mdot
.826 .33437 Mdot
.826 .33464 Mdot
.826 .33484 Mdot
.826 .33489 Mdot
.826 .33502 Mdot
.826 .33526 Mdot
.826 .33533 Mdot
.826 .33534 Mdot
.826 .33543 Mdot
.826 .3355 Mdot
.826 .33564 Mdot
.826 .33582 Mdot
.826 .33586 Mdot
.826 .33607 Mdot
.826 .3361 Mdot
.826 .33655 Mdot
.826 .33669 Mdot
.826 .33721 Mdot
.826 .33733 Mdot
.826 .33766 Mdot
.826 .33789 Mdot
.826 .3379 Mdot
.826 .33794 Mdot
.826 .3382 Mdot
.826 .33836 Mdot
.826 .3387 Mdot
.826 .33874 Mdot
.826 .33891 Mdot
.826 .33903 Mdot
.826 .33918 Mdot
.826 .33925 Mdot
.826 .34009 Mdot
.826 .34018 Mdot
.826 .3406 Mdot
.826 .34074 Mdot
.826 .34083 Mdot
.826 .34093 Mdot
.826 .34116 Mdot
.826 .34272 Mdot
.826 .34304 Mdot
.826 .34371 Mdot
.826 .34396 Mdot
.826 .34436 Mdot
.826 .34493 Mdot
.826 .34504 Mdot
.826 .34544 Mdot
.826 .34561 Mdot
.826 .34602 Mdot
.826 .34622 Mdot
.826 .34624 Mdot
.826 .34672 Mdot
.826 .34676 Mdot
.826 .3468 Mdot
.826 .34682 Mdot
.826 .34705 Mdot
.826 .3479 Mdot
.826 .34798 Mdot
.826 .34809 Mdot
.826 .34848 Mdot
.826 .34879 Mdot
.826 .34881 Mdot
.826 .34939 Mdot
.826 .3496 Mdot
.826 .34983 Mdot
.826 .34988 Mdot
.826 .35051 Mdot
.826 .3506 Mdot
.826 .35106 Mdot
.826 .35107 Mdot
.826 .35112 Mdot
.826 .35121 Mdot
.826 .35132 Mdot
.826 .35147 Mdot
.826 .35167 Mdot
.826 .35188 Mdot
.826 .35263 Mdot
.826 .353 Mdot
.826 .35327 Mdot
.826 .35371 Mdot
.826 .35405 Mdot
.826 .35446 Mdot
.826 .35465 Mdot
.826 .35494 Mdot
.826 .35541 Mdot
.826 .35567 Mdot
.826 .3558 Mdot
.826 .35598 Mdot
.826 .35605 Mdot
.826 .35657 Mdot
.826 .35672 Mdot
.826 .35697 Mdot
.826 .35743 Mdot
.826 .35781 Mdot
.826 .35808 Mdot
.826 .35809 Mdot
.826 .35823 Mdot
.826 .35853 Mdot
.826 .35894 Mdot
.826 .35899 Mdot
.826 .35909 Mdot
.826 .35921 Mdot
.826 .35932 Mdot
.826 .35963 Mdot
.826 .35976 Mdot
.826 .35996 Mdot
.826 .36003 Mdot
.826 .36009 Mdot
.826 .36049 Mdot
.826 .36057 Mdot
.826 .36062 Mdot
.826 .36086 Mdot
.826 .36105 Mdot
.826 .36135 Mdot
.826 .36222 Mdot
.826 .3628 Mdot
.826 .3629 Mdot
.826 .3629 Mdot
.826 .36309 Mdot
.826 .3634 Mdot
.826 .36381 Mdot
.826 .36478 Mdot
.826 .36504 Mdot
.826 .36522 Mdot
.826 .36523 Mdot
.826 .36553 Mdot
.826 .36577 Mdot
.826 .36598 Mdot
.826 .36609 Mdot
.826 .36615 Mdot
.826 .36645 Mdot
.826 .36681 Mdot
.826 .36697 Mdot
.826 .3688 Mdot
.826 .36903 Mdot
.826 .36923 Mdot
.826 .3708 Mdot
.826 .37082 Mdot
.826 .37151 Mdot
.826 .37177 Mdot
.826 .37212 Mdot
.826 .37249 Mdot
.826 .37254 Mdot
.826 .37288 Mdot
.826 .37327 Mdot
.826 .37337 Mdot
.826 .37343 Mdot
.826 .37354 Mdot
.826 .37369 Mdot
.826 .37374 Mdot
.826 .37379 Mdot
.826 .37411 Mdot
.826 .37446 Mdot
.826 .37489 Mdot
.826 .3751 Mdot
.826 .37547 Mdot
.826 .37583 Mdot
.826 .37599 Mdot
.826 .3761 Mdot
.826 .37852 Mdot
.826 .37894 Mdot
.826 .37898 Mdot
.826 .379 Mdot
.826 .37909 Mdot
.826 .37911 Mdot
.826 .37925 Mdot
.826 .37994 Mdot
.826 .38086 Mdot
.826 .38108 Mdot
.826 .38291 Mdot
.826 .38304 Mdot
.826 .3841 Mdot
.826 .38411 Mdot
.826 .38417 Mdot
.826 .38418 Mdot
.826 .38446 Mdot
.826 .38592 Mdot
.826 .38599 Mdot
.826 .38653 Mdot
.826 .38665 Mdot
.826 .38713 Mdot
.826 .38735 Mdot
.826 .38738 Mdot
.826 .38754 Mdot
.826 .38757 Mdot
.826 .38763 Mdot
.826 .38787 Mdot
.826 .38808 Mdot
.826 .38811 Mdot
.826 .38833 Mdot
.826 .38913 Mdot
.826 .3902 Mdot
.826 .39034 Mdot
.826 .39037 Mdot
.826 .39154 Mdot
.826 .39232 Mdot
.826 .39251 Mdot
.826 .39277 Mdot
.826 .39336 Mdot
.826 .39391 Mdot
.826 .39397 Mdot
.826 .39432 Mdot
.826 .39503 Mdot
.826 .39515 Mdot
.826 .39529 Mdot
.826 .39533 Mdot
.826 .39561 Mdot
.826 .39615 Mdot
.826 .39622 Mdot
.826 .39631 Mdot
.826 .39656 Mdot
.826 .39674 Mdot
.826 .39683 Mdot
.826 .397 Mdot
.826 .39765 Mdot
.826 .39821 Mdot
.826 .39829 Mdot
.826 .3989 Mdot
.826 .39947 Mdot
.826 .3999 Mdot
.826 .40058 Mdot
.826 .40083 Mdot
.826 .40104 Mdot
.826 .40108 Mdot
.826 .40136 Mdot
.826 .40183 Mdot
.826 .4035 Mdot
.826 .40366 Mdot
.826 .40368 Mdot
.826 .40371 Mdot
.826 .404 Mdot
.826 .40413 Mdot
.826 .40438 Mdot
.826 .40472 Mdot
.826 .40613 Mdot
.826 .40733 Mdot
.826 .40741 Mdot
.826 .40767 Mdot
.826 .40823 Mdot
.826 .40827 Mdot
.826 .40844 Mdot
.826 .40877 Mdot
.826 .40886 Mdot
.826 .40904 Mdot
.826 .40905 Mdot
.826 .40939 Mdot
.826 .40978 Mdot
.826 .41014 Mdot
.826 .41028 Mdot
.826 .4103 Mdot
.826 .41042 Mdot
.826 .4105 Mdot
.826 .41059 Mdot
.826 .41064 Mdot
.826 .41079 Mdot
.826 .41087 Mdot
.826 .4109 Mdot
.826 .41102 Mdot
.826 .41118 Mdot
.826 .41182 Mdot
.826 .41263 Mdot
.826 .41265 Mdot
.826 .41282 Mdot
.826 .41329 Mdot
.826 .4133 Mdot
.826 .41379 Mdot
.826 .41381 Mdot
.826 .41389 Mdot
.826 .41413 Mdot
.826 .41414 Mdot
.826 .4143 Mdot
.826 .41525 Mdot
.826 .41592 Mdot
.826 .41655 Mdot
.826 .4167 Mdot
.826 .41719 Mdot
.826 .41751 Mdot
.826 .4179 Mdot
.826 .41799 Mdot
.826 .41812 Mdot
.826 .41836 Mdot
.826 .41877 Mdot
.826 .41888 Mdot
.826 .41892 Mdot
.826 .41899 Mdot
.826 .41933 Mdot
.826 .41947 Mdot
.826 .41953 Mdot
.826 .42005 Mdot
.826 .42023 Mdot
.826 .42037 Mdot
.826 .42043 Mdot
.826 .42058 Mdot
.826 .42067 Mdot
.826 .42094 Mdot
.826 .42135 Mdot
.826 .42184 Mdot
.826 .42198 Mdot
.826 .42203 Mdot
.826 .42209 Mdot
.826 .42209 Mdot
.826 .42219 Mdot
.826 .42255 Mdot
.826 .42317 Mdot
.826 .4234 Mdot
.826 .42392 Mdot
.826 .4241 Mdot
.826 .42434 Mdot
.826 .42459 Mdot
.826 .42537 Mdot
.826 .42544 Mdot
.826 .42556 Mdot
.826 .42562 Mdot
.826 .42582 Mdot
.826 .42587 Mdot
.826 .42608 Mdot
.826 .42629 Mdot
.826 .4265 Mdot
.826 .42656 Mdot
.826 .42674 Mdot
.826 .42711 Mdot
.826 .42728 Mdot
.826 .42776 Mdot
.826 .4278 Mdot
.826 .42807 Mdot
.826 .42812 Mdot
.826 .42875 Mdot
.826 .42931 Mdot
.826 .43005 Mdot
.826 .43048 Mdot
.826 .4311 Mdot
.826 .4319 Mdot
.826 .4323 Mdot
.826 .43233 Mdot
.826 .43268 Mdot
.826 .43301 Mdot
.826 .43326 Mdot
.826 .43344 Mdot
.826 .43359 Mdot
.826 .43366 Mdot
.826 .43368 Mdot
.826 .4337 Mdot
.826 .43418 Mdot
.826 .43446 Mdot
.826 .43461 Mdot
.826 .43481 Mdot
.826 .43525 Mdot
.826 .43564 Mdot
.826 .43566 Mdot
.826 .43573 Mdot
.826 .4361 Mdot
.826 .43644 Mdot
.826 .43671 Mdot
.826 .43694 Mdot
.826 .43741 Mdot
.826 .43745 Mdot
.826 .43796 Mdot
.826 .43861 Mdot
.826 .43863 Mdot
.826 .43877 Mdot
.826 .43892 Mdot
.826 .44031 Mdot
.826 .4407 Mdot
.826 .44073 Mdot
.826 .44079 Mdot
.826 .44087 Mdot
.826 .44166 Mdot
.826 .44168 Mdot
.826 .44169 Mdot
.826 .44202 Mdot
.826 .4427 Mdot
.826 .44297 Mdot
.826 .44364 Mdot
.826 .44376 Mdot
.826 .44382 Mdot
.826 .44475 Mdot
.826 .44519 Mdot
.826 .44542 Mdot
.826 .44583 Mdot
.826 .44694 Mdot
.826 .44747 Mdot
.826 .44823 Mdot
.826 .44935 Mdot
.826 .44997 Mdot
.826 .45005 Mdot
.826 .45043 Mdot
.826 .45058 Mdot
.826 .45075 Mdot
.826 .45098 Mdot
.826 .45117 Mdot
.826 .45167 Mdot
.826 .45181 Mdot
.826 .4532 Mdot
.826 .45332 Mdot
.826 .45357 Mdot
.826 .4537 Mdot
.826 .45377 Mdot
.826 .45387 Mdot
.826 .45404 Mdot
.826 .45411 Mdot
.826 .45421 Mdot
.826 .45467 Mdot
.826 .45493 Mdot
.826 .45537 Mdot
.826 .45543 Mdot
.826 .45545 Mdot
.826 .45583 Mdot
.826 .45604 Mdot
.826 .45637 Mdot
.826 .45657 Mdot
.826 .45677 Mdot
.826 .45744 Mdot
.826 .45767 Mdot
.826 .45841 Mdot
.826 .45845 Mdot
.826 .45863 Mdot
.826 .4588 Mdot
.826 .45886 Mdot
.826 .45917 Mdot
.826 .45941 Mdot
.826 .45951 Mdot
.826 .45952 Mdot
.826 .45955 Mdot
.826 .4596 Mdot
.826 .45965 Mdot
.826 .45969 Mdot
.826 .45979 Mdot
.826 .46019 Mdot
.826 .46041 Mdot
.826 .46049 Mdot
.826 .46082 Mdot
.826 .46126 Mdot
.826 .46177 Mdot
.826 .46199 Mdot
.826 .46214 Mdot
.826 .46216 Mdot
.826 .46222 Mdot
.826 .46283 Mdot
.826 .463 Mdot
.826 .4632 Mdot
.826 .46329 Mdot
.826 .46521 Mdot
.826 .46523 Mdot
.826 .46528 Mdot
.826 .46573 Mdot
.826 .4666 Mdot
.826 .46703 Mdot
.826 .46704 Mdot
.826 .46709 Mdot
.826 .46748 Mdot
.826 .46786 Mdot
.826 .46787 Mdot
.826 .46794 Mdot
.826 .46839 Mdot
.826 .46844 Mdot
.826 .46866 Mdot
.826 .4693 Mdot
.826 .4693 Mdot
.826 .46932 Mdot
.826 .46972 Mdot
.826 .46976 Mdot
.826 .47085 Mdot
.826 .47111 Mdot
.826 .47122 Mdot
.826 .47236 Mdot
.826 .47249 Mdot
.826 .47286 Mdot
.826 .47311 Mdot
.826 .4732 Mdot
.826 .47384 Mdot
.826 .47394 Mdot
.826 .47419 Mdot
.826 .47478 Mdot
.826 .47561 Mdot
.826 .4758 Mdot
.826 .47591 Mdot
.826 .47593 Mdot
.826 .47597 Mdot
.826 .47604 Mdot
.826 .47624 Mdot
.826 .47631 Mdot
.826 .47691 Mdot
.826 .47702 Mdot
.826 .47709 Mdot
.826 .47766 Mdot
.826 .47798 Mdot
.826 .47815 Mdot
.826 .47817 Mdot
.826 .47825 Mdot
.826 .47829 Mdot
.826 .47841 Mdot
.826 .47853 Mdot
.826 .47886 Mdot
.826 .4791 Mdot
.826 .47927 Mdot
.826 .47941 Mdot
.826 .4796 Mdot
.826 .47963 Mdot
.826 .47984 Mdot
.826 .48001 Mdot
.826 .48019 Mdot
.826 .48034 Mdot
.826 .48063 Mdot
.826 .48086 Mdot
.826 .48121 Mdot
.826 .48134 Mdot
.826 .48138 Mdot
.826 .48143 Mdot
.826 .48164 Mdot
.826 .48187 Mdot
.826 .48197 Mdot
.826 .48204 Mdot
.826 .48226 Mdot
.826 .48227 Mdot
.826 .48238 Mdot
.826 .48252 Mdot
.826 .48256 Mdot
.826 .48259 Mdot
.826 .48299 Mdot
.826 .48321 Mdot
.826 .48349 Mdot
.826 .48368 Mdot
.826 .48389 Mdot
.826 .48404 Mdot
.826 .48413 Mdot
.826 .48437 Mdot
.826 .48506 Mdot
.826 .48515 Mdot
.826 .48518 Mdot
.826 .48545 Mdot
.826 .48584 Mdot
.826 .48595 Mdot
.826 .48596 Mdot
.826 .48624 Mdot
.826 .48634 Mdot
.826 .48651 Mdot
.826 .48675 Mdot
.826 .48692 Mdot
.826 .48716 Mdot
.826 .4872 Mdot
.826 .48775 Mdot
.826 .4879 Mdot
.826 .48843 Mdot
.826 .48873 Mdot
.826 .48901 Mdot
.826 .48933 Mdot
.826 .48968 Mdot
.826 .49012 Mdot
.826 .4902 Mdot
.826 .49036 Mdot
.826 .49073 Mdot
.826 .4908 Mdot
.826 .49087 Mdot
.826 .49102 Mdot
.826 .49105 Mdot
.826 .49129 Mdot
.826 .4913 Mdot
.826 .49132 Mdot
.826 .49178 Mdot
.826 .49228 Mdot
.826 .49302 Mdot
.826 .4933 Mdot
.826 .49397 Mdot
.826 .4941 Mdot
.826 .49421 Mdot
.826 .49459 Mdot
.826 .49483 Mdot
.826 .49486 Mdot
.826 .49604 Mdot
.826 .49638 Mdot
.826 .49651 Mdot
.826 .49655 Mdot
.826 .49668 Mdot
.826 .49709 Mdot
.826 .49717 Mdot
.826 .49744 Mdot
.826 .49755 Mdot
.826 .49768 Mdot
.826 .49784 Mdot
.826 .49818 Mdot
.826 .49886 Mdot
.826 .49933 Mdot
.826 .49941 Mdot
.826 .49954 Mdot
.826 .49976 Mdot
.826 .49998 Mdot
.826 .50018 Mdot
.826 .50033 Mdot
.826 .50051 Mdot
.826 .50066 Mdot
.826 .50081 Mdot
.826 .50097 Mdot
.826 .50106 Mdot
.826 .50121 Mdot
.826 .50134 Mdot
.826 .50156 Mdot
.826 .50161 Mdot
.826 .50168 Mdot
.826 .50183 Mdot
.826 .50192 Mdot
.828 .18292 Mdot
.828 .18316 Mdot
.828 .18438 Mdot
.828 .18521 Mdot
.828 .18558 Mdot
.828 .18559 Mdot
.828 .18588 Mdot
.828 .18608 Mdot
.828 .18624 Mdot
.828 .18637 Mdot
.828 .18718 Mdot
.828 .18743 Mdot
.828 .18763 Mdot
.828 .18777 Mdot
.828 .18832 Mdot
.828 .18843 Mdot
.828 .18875 Mdot
.828 .18883 Mdot
.828 .18961 Mdot
.828 .1902 Mdot
.828 .19045 Mdot
.828 .19076 Mdot
.828 .19151 Mdot
.828 .19222 Mdot
.828 .19222 Mdot
.828 .19275 Mdot
.828 .19361 Mdot
.828 .19435 Mdot
.828 .19477 Mdot
.828 .1954 Mdot
.828 .19609 Mdot
.828 .19626 Mdot
.828 .1967 Mdot
.828 .19746 Mdot
.828 .19749 Mdot
.828 .19826 Mdot
.828 .19859 Mdot
.828 .19915 Mdot
.828 .19971 Mdot
.828 .20025 Mdot
.828 .20036 Mdot
.828 .20098 Mdot
.828 .20136 Mdot
.828 .20217 Mdot
.828 .20279 Mdot
.828 .20306 Mdot
.828 .20325 Mdot
.828 .2033 Mdot
.828 .20357 Mdot
.828 .20358 Mdot
.828 .2037 Mdot
.828 .20385 Mdot
.828 .20411 Mdot
.828 .20447 Mdot
.828 .20525 Mdot
.828 .20578 Mdot
.828 .20617 Mdot
.828 .20645 Mdot
.828 .20734 Mdot
.828 .20736 Mdot
.828 .2075 Mdot
.828 .20819 Mdot
.828 .20848 Mdot
.828 .20848 Mdot
.828 .20871 Mdot
.828 .20884 Mdot
.828 .20956 Mdot
.828 .21139 Mdot
.828 .21215 Mdot
.828 .21274 Mdot
.828 .21347 Mdot
.828 .21387 Mdot
.828 .2139 Mdot
.828 .21393 Mdot
.828 .21408 Mdot
.828 .21436 Mdot
.828 .21438 Mdot
.828 .2153 Mdot
.828 .21545 Mdot
.828 .2155 Mdot
.828 .21571 Mdot
.828 .21576 Mdot
.828 .2164 Mdot
.828 .2169 Mdot
.828 .21742 Mdot
.828 .21828 Mdot
.828 .2183 Mdot
.828 .21953 Mdot
.828 .21971 Mdot
.828 .21973 Mdot
.828 .22067 Mdot
.828 .22105 Mdot
.828 .2212 Mdot
.828 .22141 Mdot
.828 .22211 Mdot
.828 .22268 Mdot
.828 .22333 Mdot
.828 .22341 Mdot
.828 .22365 Mdot
.828 .22466 Mdot
.828 .2248 Mdot
.828 .22494 Mdot
.828 .2251 Mdot
.828 .22524 Mdot
.828 .22548 Mdot
.828 .22657 Mdot
.828 .22664 Mdot
.828 .22671 Mdot
.828 .2276 Mdot
.828 .22782 Mdot
.828 .22793 Mdot
.828 .22913 Mdot
.828 .2298 Mdot
.828 .23003 Mdot
.828 .23024 Mdot
.828 .23089 Mdot
.828 .23092 Mdot
.828 .23127 Mdot
.828 .23149 Mdot
.828 .2315 Mdot
.828 .23195 Mdot
.828 .23207 Mdot
.828 .23262 Mdot
.828 .23272 Mdot
.828 .23394 Mdot
.828 .23411 Mdot
.828 .2343 Mdot
.828 .23532 Mdot
.828 .23553 Mdot
.828 .23555 Mdot
.828 .2356 Mdot
.828 .23636 Mdot
.828 .23749 Mdot
.828 .23808 Mdot
.828 .23856 Mdot
.828 .23893 Mdot
.828 .23909 Mdot
.828 .23952 Mdot
.828 .24037 Mdot
.828 .24045 Mdot
.828 .24104 Mdot
.828 .2412 Mdot
.828 .24124 Mdot
.828 .2415 Mdot
.828 .24179 Mdot
.828 .24185 Mdot
.828 .2419 Mdot
.828 .24303 Mdot
.828 .24329 Mdot
.828 .24369 Mdot
.828 .24448 Mdot
.828 .24454 Mdot
.828 .24459 Mdot
.828 .24552 Mdot
.828 .24604 Mdot
.828 .24614 Mdot
.828 .24674 Mdot
.828 .24751 Mdot
.828 .24758 Mdot
.828 .24779 Mdot
.828 .2485 Mdot
.828 .2486 Mdot
.828 .24866 Mdot
.828 .2487 Mdot
.828 .24909 Mdot
.828 .24933 Mdot
.828 .24936 Mdot
.828 .2512 Mdot
.828 .25246 Mdot
.828 .25376 Mdot
.828 .25378 Mdot
.828 .25467 Mdot
.828 .25476 Mdot
.828 .25479 Mdot
.828 .2548 Mdot
.828 .25518 Mdot
.828 .2553 Mdot
.828 .25539 Mdot
.828 .25554 Mdot
.828 .25555 Mdot
.828 .25586 Mdot
.828 .25642 Mdot
.828 .25868 Mdot
.828 .26002 Mdot
.828 .26057 Mdot
.828 .26068 Mdot
.828 .26155 Mdot
.828 .26261 Mdot
.828 .26265 Mdot
.828 .26276 Mdot
.828 .26293 Mdot
.828 .26415 Mdot
.828 .26509 Mdot
.828 .26599 Mdot
.828 .26618 Mdot
.828 .2664 Mdot
.828 .2667 Mdot
.828 .26697 Mdot
.828 .26754 Mdot
.828 .2683 Mdot
.828 .26864 Mdot
.828 .26898 Mdot
.828 .26906 Mdot
.828 .27024 Mdot
.828 .27042 Mdot
.828 .27161 Mdot
.828 .27313 Mdot
.828 .27403 Mdot
.828 .27457 Mdot
.828 .27641 Mdot
.828 .27823 Mdot
.828 .27825 Mdot
.828 .27838 Mdot
.828 .2785 Mdot
.828 .27909 Mdot
.828 .2792 Mdot
.828 .27928 Mdot
.828 .28046 Mdot
.828 .28052 Mdot
.828 .28056 Mdot
.828 .28058 Mdot
.828 .28128 Mdot
.828 .28304 Mdot
.828 .28344 Mdot
.828 .28474 Mdot
.828 .28541 Mdot
.828 .28551 Mdot
.828 .28565 Mdot
.828 .28636 Mdot
.828 .28658 Mdot
.828 .28662 Mdot
.828 .28681 Mdot
.828 .28719 Mdot
.828 .28838 Mdot
.828 .28866 Mdot
.828 .28921 Mdot
.828 .28974 Mdot
.828 .29043 Mdot
.828 .29045 Mdot
.828 .29097 Mdot
.828 .29176 Mdot
.828 .29201 Mdot
.828 .29254 Mdot
.828 .29326 Mdot
.828 .29334 Mdot
.828 .29367 Mdot
.828 .29369 Mdot
.828 .29412 Mdot
.828 .2942 Mdot
.828 .29436 Mdot
.828 .29442 Mdot
.828 .29487 Mdot
.828 .2949 Mdot
.828 .29534 Mdot
.828 .29568 Mdot
.828 .29573 Mdot
.828 .29587 Mdot
.828 .29629 Mdot
.828 .29706 Mdot
.828 .29766 Mdot
.828 .29768 Mdot
.828 .29777 Mdot
.828 .29816 Mdot
.828 .29827 Mdot
.828 .29834 Mdot
.828 .29835 Mdot
.828 .2985 Mdot
.828 .29876 Mdot
.828 .29898 Mdot
.828 .29992 Mdot
.828 .30023 Mdot
.828 .30031 Mdot
.828 .30032 Mdot
.828 .30067 Mdot
.828 .30073 Mdot
.828 .30106 Mdot
.828 .3013 Mdot
.828 .30149 Mdot
.828 .30178 Mdot
.828 .3021 Mdot
.828 .30221 Mdot
.828 .30229 Mdot
.828 .30239 Mdot
.828 .30262 Mdot
.828 .30291 Mdot
.828 .30305 Mdot
.828 .30392 Mdot
.828 .30434 Mdot
.828 .30477 Mdot
.828 .30483 Mdot
.828 .30509 Mdot
.828 .30531 Mdot
.828 .30574 Mdot
.828 .30624 Mdot
.828 .30748 Mdot
.828 .30767 Mdot
.828 .30799 Mdot
.828 .30808 Mdot
.828 .30848 Mdot
.828 .30866 Mdot
.828 .30867 Mdot
.828 .3088 Mdot
.828 .3091 Mdot
.828 .30955 Mdot
.828 .30976 Mdot
.828 .31084 Mdot
.828 .31097 Mdot
.828 .31102 Mdot
.828 .31147 Mdot
.828 .31153 Mdot
.828 .31177 Mdot
.828 .31188 Mdot
.828 .31219 Mdot
.828 .31241 Mdot
.828 .3125 Mdot
.828 .31262 Mdot
.828 .31289 Mdot
.828 .31315 Mdot
.828 .31334 Mdot
.828 .31393 Mdot
.828 .31478 Mdot
.828 .31507 Mdot
.828 .31535 Mdot
.828 .31567 Mdot
.828 .31588 Mdot
.828 .31608 Mdot
.828 .31612 Mdot
.828 .31717 Mdot
.828 .31729 Mdot
.828 .31734 Mdot
.828 .31739 Mdot
.828 .31749 Mdot
.828 .31824 Mdot
.828 .31866 Mdot
.828 .31897 Mdot
.828 .31921 Mdot
.828 .32014 Mdot
.828 .32106 Mdot
.828 .32122 Mdot
.828 .32156 Mdot
.828 .32164 Mdot
.828 .32197 Mdot
.828 .32215 Mdot
.828 .32265 Mdot
.828 .32266 Mdot
.828 .32317 Mdot
.828 .32318 Mdot
.828 .32379 Mdot
.828 .32425 Mdot
.828 .32461 Mdot
.828 .32508 Mdot
.828 .32514 Mdot
.828 .32567 Mdot
.828 .32617 Mdot
.828 .32661 Mdot
.828 .32694 Mdot
.828 .32701 Mdot
.828 .32725 Mdot
.828 .32726 Mdot
.828 .32747 Mdot
.828 .32747 Mdot
.828 .32768 Mdot
.828 .32788 Mdot
.828 .32792 Mdot
.828 .32836 Mdot
.828 .32849 Mdot
.828 .32886 Mdot
.828 .32895 Mdot
.828 .32925 Mdot
.828 .32987 Mdot
.828 .33004 Mdot
.828 .33024 Mdot
.828 .3304 Mdot
.828 .33071 Mdot
.828 .33095 Mdot
.828 .33102 Mdot
.828 .33112 Mdot
.828 .33122 Mdot
.828 .33124 Mdot
.828 .33126 Mdot
.828 .33168 Mdot
.828 .33177 Mdot
.828 .33192 Mdot
.828 .33223 Mdot
.828 .33225 Mdot
.828 .33331 Mdot
.828 .33334 Mdot
.828 .33341 Mdot
.828 .33367 Mdot
.828 .33371 Mdot
.828 .33373 Mdot
.828 .33397 Mdot
.828 .33404 Mdot
.828 .33511 Mdot
.828 .33559 Mdot
.828 .33559 Mdot
.828 .33592 Mdot
.828 .33596 Mdot
.828 .33597 Mdot
.828 .33611 Mdot
.828 .33615 Mdot
.828 .33618 Mdot
.828 .33624 Mdot
.828 .33624 Mdot
.828 .33656 Mdot
.828 .33738 Mdot
.828 .33787 Mdot
.828 .33807 Mdot
.828 .33843 Mdot
.828 .33938 Mdot
.828 .33972 Mdot
.828 .34005 Mdot
.828 .34041 Mdot
.828 .34061 Mdot
.828 .3416 Mdot
.828 .34167 Mdot
.828 .3421 Mdot
.828 .34265 Mdot
.828 .34318 Mdot
.828 .34385 Mdot
.828 .34451 Mdot
.828 .34452 Mdot
.828 .34457 Mdot
.828 .34461 Mdot
.828 .34486 Mdot
.828 .34489 Mdot
.828 .34533 Mdot
.828 .34535 Mdot
.828 .34537 Mdot
.828 .34562 Mdot
.828 .34641 Mdot
.828 .34688 Mdot
.828 .34713 Mdot
.828 .34717 Mdot
.828 .34722 Mdot
.828 .34748 Mdot
.828 .34756 Mdot
.828 .34757 Mdot
.828 .34764 Mdot
.828 .34821 Mdot
.828 .34831 Mdot
.828 .34852 Mdot
.828 .34871 Mdot
.828 .34896 Mdot
.828 .34944 Mdot
.828 .34954 Mdot
.828 .34973 Mdot
.828 .35002 Mdot
.828 .35015 Mdot
.828 .35031 Mdot
.828 .3504 Mdot
.828 .35058 Mdot
.828 .35059 Mdot
.828 .35089 Mdot
.828 .35094 Mdot
.828 .35164 Mdot
.828 .35182 Mdot
.828 .35184 Mdot
.828 .35254 Mdot
.828 .35256 Mdot
.828 .3531 Mdot
.828 .35329 Mdot
.828 .35388 Mdot
.828 .35419 Mdot
.828 .35421 Mdot
.828 .35536 Mdot
.828 .3554 Mdot
.828 .35554 Mdot
.828 .35566 Mdot
.828 .35577 Mdot
.828 .35601 Mdot
.828 .3564 Mdot
.828 .35665 Mdot
.828 .35698 Mdot
.828 .35701 Mdot
.828 .35705 Mdot
.828 .35724 Mdot
.828 .35732 Mdot
.828 .35817 Mdot
.828 .35824 Mdot
.828 .35833 Mdot
.828 .35875 Mdot
.828 .3591 Mdot
.828 .36019 Mdot
.828 .36031 Mdot
.828 .36034 Mdot
.828 .36071 Mdot
.828 .3609 Mdot
.828 .36129 Mdot
.828 .36142 Mdot
.828 .36159 Mdot
.828 .36181 Mdot
.828 .36239 Mdot
.828 .36239 Mdot
.828 .36262 Mdot
.828 .36284 Mdot
.828 .36311 Mdot
.828 .36334 Mdot
.828 .36341 Mdot
.828 .36365 Mdot
.828 .36374 Mdot
.828 .36376 Mdot
.828 .36384 Mdot
.828 .36486 Mdot
.828 .36555 Mdot
.828 .36557 Mdot
.828 .36566 Mdot
.828 .36567 Mdot
.828 .36578 Mdot
.828 .36626 Mdot
.828 .36633 Mdot
.828 .36646 Mdot
.828 .36681 Mdot
.828 .36705 Mdot
.828 .36726 Mdot
.828 .36762 Mdot
.828 .3678 Mdot
.828 .36868 Mdot
.828 .36882 Mdot
.828 .36899 Mdot
.828 .36909 Mdot
.828 .36937 Mdot
.828 .36965 Mdot
.828 .36976 Mdot
.828 .36979 Mdot
.828 .37014 Mdot
.828 .37048 Mdot
.828 .37058 Mdot
.828 .3709 Mdot
.828 .37101 Mdot
.828 .37103 Mdot
.828 .37128 Mdot
.828 .37162 Mdot
.828 .37264 Mdot
.828 .3727 Mdot
.828 .37275 Mdot
.828 .37287 Mdot
.828 .37323 Mdot
.828 .37332 Mdot
.828 .37369 Mdot
.828 .37372 Mdot
.828 .37445 Mdot
.828 .37466 Mdot
.828 .3752 Mdot
.828 .37557 Mdot
.828 .37566 Mdot
.828 .37573 Mdot
.828 .3764 Mdot
.828 .37661 Mdot
.828 .37664 Mdot
.828 .37669 Mdot
.828 .37681 Mdot
.828 .3769 Mdot
.828 .37764 Mdot
.828 .37775 Mdot
.828 .37785 Mdot
.828 .37803 Mdot
.828 .37834 Mdot
.828 .37915 Mdot
.828 .38004 Mdot
.828 .38039 Mdot
.828 .3804 Mdot
.828 .38041 Mdot
.828 .38049 Mdot
.828 .38076 Mdot
.828 .38177 Mdot
.828 .38363 Mdot
.828 .38386 Mdot
.828 .38461 Mdot
.828 .38539 Mdot
.828 .38552 Mdot
.828 .38597 Mdot
.828 .38602 Mdot
.828 .3861 Mdot
.828 .38613 Mdot
.828 .38614 Mdot
.828 .38627 Mdot
.828 .38672 Mdot
.828 .38699 Mdot
.828 .38819 Mdot
.828 .3884 Mdot
.828 .38854 Mdot
.828 .38951 Mdot
.828 .38952 Mdot
.828 .38978 Mdot
.828 .38984 Mdot
.828 .39005 Mdot
.828 .39028 Mdot
.828 .39035 Mdot
.828 .39051 Mdot
.828 .39069 Mdot
.828 .39075 Mdot
.828 .39085 Mdot
.828 .39093 Mdot
.828 .39191 Mdot
.828 .39206 Mdot
.828 .39227 Mdot
.828 .39235 Mdot
.828 .39239 Mdot
.828 .39275 Mdot
.828 .39281 Mdot
.828 .39323 Mdot
.828 .39386 Mdot
.828 .3939 Mdot
.828 .39397 Mdot
.828 .39412 Mdot
.828 .39473 Mdot
.828 .39508 Mdot
.828 .39521 Mdot
.828 .39531 Mdot
.828 .39539 Mdot
.828 .39563 Mdot
.828 .39597 Mdot
.828 .39692 Mdot
.828 .39718 Mdot
.828 .39724 Mdot
.828 .39779 Mdot
.828 .39784 Mdot
.828 .39795 Mdot
.828 .398 Mdot
.828 .39858 Mdot
.828 .39879 Mdot
.828 .39886 Mdot
.828 .39895 Mdot
.828 .39897 Mdot
.828 .40023 Mdot
.828 .40034 Mdot
.828 .40066 Mdot
.828 .40068 Mdot
.828 .40122 Mdot
.828 .40164 Mdot
.828 .40167 Mdot
.828 .40185 Mdot
.828 .40186 Mdot
.828 .40203 Mdot
.828 .40212 Mdot
.828 .4022 Mdot
.828 .40237 Mdot
.828 .40255 Mdot
.828 .40284 Mdot
.828 .40311 Mdot
.828 .40323 Mdot
.828 .40329 Mdot
.828 .40369 Mdot
.828 .40373 Mdot
.828 .40392 Mdot
.828 .40438 Mdot
.828 .40485 Mdot
.828 .40502 Mdot
.828 .40529 Mdot
.828 .40552 Mdot
.828 .40633 Mdot
.828 .40698 Mdot
.828 .40729 Mdot
.828 .40788 Mdot
.828 .40822 Mdot
.828 .40842 Mdot
.828 .40863 Mdot
.828 .4092 Mdot
.828 .40941 Mdot
.828 .40953 Mdot
.828 .41033 Mdot
.828 .41052 Mdot
.828 .41052 Mdot
.828 .41057 Mdot
.828 .4106 Mdot
.828 .41069 Mdot
.828 .41071 Mdot
.828 .41185 Mdot
.828 .41207 Mdot
.828 .41223 Mdot
.828 .41227 Mdot
.828 .41229 Mdot
.828 .41293 Mdot
.828 .41313 Mdot
.828 .41328 Mdot
.828 .41353 Mdot
.828 .41354 Mdot
.828 .41355 Mdot
.828 .41367 Mdot
.828 .41371 Mdot
.828 .41386 Mdot
.828 .41405 Mdot
.828 .41426 Mdot
.828 .41437 Mdot
.828 .41474 Mdot
.828 .41497 Mdot
.828 .4152 Mdot
.828 .41557 Mdot
.828 .41594 Mdot
.828 .41595 Mdot
.828 .4169 Mdot
.828 .41726 Mdot
.828 .41754 Mdot
.828 .41776 Mdot
.828 .41841 Mdot
.828 .41872 Mdot
.828 .41873 Mdot
.828 .41934 Mdot
.828 .41938 Mdot
.828 .41959 Mdot
.828 .42095 Mdot
.828 .42139 Mdot
.828 .42185 Mdot
.828 .42196 Mdot
.828 .42204 Mdot
.828 .42267 Mdot
.828 .42282 Mdot
.828 .42294 Mdot
.828 .42348 Mdot
.828 .42435 Mdot
.828 .42446 Mdot
.828 .42479 Mdot
.828 .42485 Mdot
.828 .42491 Mdot
.828 .42523 Mdot
.828 .4253 Mdot
.828 .42544 Mdot
.828 .42548 Mdot
.828 .42575 Mdot
.828 .42586 Mdot
.828 .42651 Mdot
.828 .42691 Mdot
.828 .42709 Mdot
.828 .42728 Mdot
.828 .42752 Mdot
.828 .42758 Mdot
.828 .42777 Mdot
.828 .42933 Mdot
.828 .42948 Mdot
.828 .42952 Mdot
.828 .43004 Mdot
.828 .43082 Mdot
.828 .43102 Mdot
.828 .43113 Mdot
.828 .43133 Mdot
.828 .4315 Mdot
.828 .432 Mdot
.828 .43221 Mdot
.828 .43226 Mdot
.828 .43245 Mdot
.828 .4334 Mdot
.828 .43341 Mdot
.828 .43345 Mdot
.828 .43375 Mdot
.828 .43465 Mdot
.828 .4349 Mdot
.828 .43498 Mdot
.828 .43522 Mdot
.828 .43548 Mdot
.828 .4355 Mdot
.828 .43578 Mdot
.828 .43581 Mdot
.828 .4359 Mdot
.828 .43596 Mdot
.828 .43621 Mdot
.828 .43642 Mdot
.828 .43691 Mdot
.828 .43723 Mdot
.828 .43738 Mdot
.828 .43786 Mdot
.828 .43817 Mdot
.828 .43818 Mdot
.828 .4386 Mdot
.828 .43892 Mdot
.828 .43925 Mdot
.828 .43942 Mdot
.828 .44014 Mdot
.828 .44037 Mdot
.828 .44048 Mdot
.828 .44051 Mdot
.828 .44064 Mdot
.828 .44107 Mdot
.828 .44116 Mdot
.828 .44122 Mdot
.828 .44162 Mdot
.828 .4424 Mdot
.828 .44265 Mdot
.828 .44371 Mdot
.828 .44413 Mdot
.828 .44414 Mdot
.828 .44417 Mdot
.828 .4442 Mdot
.828 .44492 Mdot
.828 .44497 Mdot
.828 .44503 Mdot
.828 .44539 Mdot
.828 .44546 Mdot
.828 .44554 Mdot
.828 .44555 Mdot
.828 .44665 Mdot
.828 .44776 Mdot
.828 .44809 Mdot
.828 .44863 Mdot
.828 .44955 Mdot
.828 .45026 Mdot
.828 .45038 Mdot
.828 .45109 Mdot
.828 .45114 Mdot
.828 .45134 Mdot
.828 .45155 Mdot
.828 .452 Mdot
.828 .45235 Mdot
.828 .45251 Mdot
.828 .4527 Mdot
.828 .45283 Mdot
.828 .45294 Mdot
.828 .45349 Mdot
.828 .45405 Mdot
.828 .45479 Mdot
.828 .45489 Mdot
.828 .45496 Mdot
.828 .45498 Mdot
.828 .45562 Mdot
.828 .45615 Mdot
.828 .45622 Mdot
.828 .45654 Mdot
.828 .45735 Mdot
.828 .45872 Mdot
.828 .45906 Mdot
.828 .45925 Mdot
.828 .45925 Mdot
.828 .45934 Mdot
.828 .45939 Mdot
.828 .45947 Mdot
.828 .4597 Mdot
.828 .45971 Mdot
.828 .45972 Mdot
.828 .45978 Mdot
.828 .46032 Mdot
.828 .46033 Mdot
.828 .46111 Mdot
.828 .46187 Mdot
.828 .46288 Mdot
.828 .46298 Mdot
.828 .463 Mdot
.828 .46315 Mdot
.828 .46338 Mdot
.828 .46341 Mdot
.828 .46344 Mdot
.828 .4635 Mdot
.828 .46393 Mdot
.828 .46406 Mdot
.828 .4641 Mdot
.828 .46456 Mdot
.828 .46493 Mdot
.828 .46499 Mdot
.828 .4653 Mdot
.828 .46586 Mdot
.828 .46589 Mdot
.828 .46593 Mdot
.828 .46641 Mdot
.828 .46665 Mdot
.828 .4668 Mdot
.828 .46749 Mdot
.828 .46752 Mdot
.828 .46756 Mdot
.828 .46773 Mdot
.828 .46789 Mdot
.828 .46791 Mdot
.828 .46801 Mdot
.828 .46836 Mdot
.828 .46841 Mdot
.828 .46893 Mdot
.828 .46919 Mdot
.828 .46928 Mdot
.828 .46951 Mdot
.828 .4698 Mdot
.828 .47015 Mdot
.828 .47083 Mdot
.828 .4713 Mdot
.828 .47132 Mdot
.828 .47133 Mdot
.828 .47146 Mdot
.828 .47208 Mdot
.828 .4722 Mdot
.828 .4723 Mdot
.828 .47303 Mdot
.828 .47309 Mdot
.828 .47342 Mdot
.828 .4735 Mdot
.828 .47377 Mdot
.828 .47378 Mdot
.828 .47391 Mdot
.828 .47412 Mdot
.828 .47414 Mdot
.828 .47453 Mdot
.828 .47466 Mdot
.828 .47479 Mdot
.828 .4752 Mdot
.828 .47592 Mdot
.828 .47599 Mdot
.828 .47612 Mdot
.828 .47666 Mdot
.828 .4767 Mdot
.828 .47675 Mdot
.828 .47741 Mdot
.828 .47755 Mdot
.828 .47763 Mdot
.828 .47773 Mdot
.828 .47781 Mdot
.828 .4779 Mdot
.828 .47851 Mdot
.828 .47865 Mdot
.828 .4787 Mdot
.828 .4791 Mdot
.828 .47944 Mdot
.828 .47986 Mdot
.828 .47999 Mdot
.828 .48008 Mdot
.828 .48031 Mdot
.828 .48088 Mdot
.828 .48089 Mdot
.828 .481 Mdot
.828 .48174 Mdot
.828 .48175 Mdot
.828 .48227 Mdot
.828 .48258 Mdot
.828 .48289 Mdot
.828 .48328 Mdot
.828 .4833 Mdot
.828 .48343 Mdot
.828 .48346 Mdot
.828 .48355 Mdot
.828 .4841 Mdot
.828 .48412 Mdot
.828 .48429 Mdot
.828 .48438 Mdot
.828 .4844 Mdot
.828 .48442 Mdot
.828 .48466 Mdot
.828 .4851 Mdot
.828 .48545 Mdot
.828 .48591 Mdot
.828 .48702 Mdot
.828 .48745 Mdot
.828 .48753 Mdot
.828 .48767 Mdot
.828 .48767 Mdot
.828 .48784 Mdot
.828 .48826 Mdot
.828 .48835 Mdot
.828 .48836 Mdot
.828 .4889 Mdot
.828 .48906 Mdot
.828 .4893 Mdot
.828 .48962 Mdot
.828 .49009 Mdot
.828 .49031 Mdot
.828 .49047 Mdot
.828 .49055 Mdot
.828 .49063 Mdot
.828 .49063 Mdot
.828 .4908 Mdot
.828 .49083 Mdot
.828 .49095 Mdot
.828 .4911 Mdot
.828 .49148 Mdot
.828 .49197 Mdot
.828 .4922 Mdot
.828 .49257 Mdot
.828 .49264 Mdot
.828 .49297 Mdot
.828 .4933 Mdot
.828 .49364 Mdot
.828 .49384 Mdot
.828 .49431 Mdot
.828 .49433 Mdot
.828 .49479 Mdot
.828 .49505 Mdot
.828 .49515 Mdot
.828 .49557 Mdot
.828 .49595 Mdot
.828 .4962 Mdot
.828 .49665 Mdot
.828 .49717 Mdot
.828 .49749 Mdot
.828 .49749 Mdot
.828 .49792 Mdot
.828 .49837 Mdot
.828 .49856 Mdot
.828 .49871 Mdot
.828 .49907 Mdot
.828 .49954 Mdot
.828 .49959 Mdot
.828 .49978 Mdot
.828 .49984 Mdot
.828 .50017 Mdot
.828 .50026 Mdot
.828 .50038 Mdot
.828 .50053 Mdot
.828 .50102 Mdot
.828 .5011 Mdot
.828 .5012 Mdot
.828 .50132 Mdot
.828 .50149 Mdot
.828 .5015 Mdot
.828 .50172 Mdot
.828 .50222 Mdot
.828 .50296 Mdot
.828 .5031 Mdot
.83 .18174 Mdot
.83 .18203 Mdot
.83 .18398 Mdot
.83 .18451 Mdot
.83 .18484 Mdot
.83 .18512 Mdot
.83 .18574 Mdot
.83 .18644 Mdot
.83 .18647 Mdot
.83 .18663 Mdot
.83 .1871 Mdot
.83 .18735 Mdot
.83 .18763 Mdot
.83 .18784 Mdot
.83 .18856 Mdot
.83 .18877 Mdot
.83 .18894 Mdot
.83 .18903 Mdot
.83 .18904 Mdot
.83 .18946 Mdot
.83 .18961 Mdot
.83 .19026 Mdot
.83 .19034 Mdot
.83 .19042 Mdot
.83 .1907 Mdot
.83 .19107 Mdot
.83 .19142 Mdot
.83 .19169 Mdot
.83 .1923 Mdot
.83 .19327 Mdot
.83 .19356 Mdot
.83 .19386 Mdot
.83 .19402 Mdot
.83 .19471 Mdot
.83 .19566 Mdot
.83 .19585 Mdot
.83 .19607 Mdot
.83 .19662 Mdot
.83 .19663 Mdot
.83 .19667 Mdot
.83 .19682 Mdot
.83 .19693 Mdot
.83 .197 Mdot
.83 .19712 Mdot
.83 .19786 Mdot
.83 .19791 Mdot
.83 .19829 Mdot
.83 .19885 Mdot
.83 .19991 Mdot
.83 .19992 Mdot
.83 .20043 Mdot
.83 .20043 Mdot
.83 .20048 Mdot
.83 .20065 Mdot
.83 .20074 Mdot
.83 .20133 Mdot
.83 .20162 Mdot
.83 .20163 Mdot
.83 .20185 Mdot
.83 .20215 Mdot
.83 .20217 Mdot
.83 .20267 Mdot
.83 .20271 Mdot
.83 .20306 Mdot
.83 .20309 Mdot
.83 .20438 Mdot
.83 .20442 Mdot
.83 .2049 Mdot
.83 .20552 Mdot
.83 .20609 Mdot
.83 .20629 Mdot
.83 .20633 Mdot
.83 .20655 Mdot
.83 .2076 Mdot
.83 .20767 Mdot
.83 .20792 Mdot
.83 .20806 Mdot
.83 .20826 Mdot
.83 .20839 Mdot
.83 .20853 Mdot
.83 .20949 Mdot
.83 .20975 Mdot
.83 .20976 Mdot
.83 .20996 Mdot
.83 .21063 Mdot
.83 .21163 Mdot
.83 .21173 Mdot
.83 .21213 Mdot
.83 .21257 Mdot
.83 .21292 Mdot
.83 .21311 Mdot
.83 .21317 Mdot
.83 .21441 Mdot
.83 .2145 Mdot
.83 .21455 Mdot
.83 .21527 Mdot
.83 .21549 Mdot
.83 .21554 Mdot
.83 .21587 Mdot
.83 .21588 Mdot
.83 .2163 Mdot
.83 .21685 Mdot
.83 .21721 Mdot
.83 .21735 Mdot
.83 .21745 Mdot
.83 .21775 Mdot
.83 .21786 Mdot
.83 .21787 Mdot
.83 .21809 Mdot
.83 .21888 Mdot
.83 .21889 Mdot
.83 .21928 Mdot
.83 .21969 Mdot
.83 .21977 Mdot
.83 .21979 Mdot
.83 .21985 Mdot
.83 .22028 Mdot
.83 .22094 Mdot
.83 .22102 Mdot
.83 .22186 Mdot
.83 .22199 Mdot
.83 .22275 Mdot
.83 .22329 Mdot
.83 .22336 Mdot
.83 .22435 Mdot
.83 .22572 Mdot
.83 .22581 Mdot
.83 .22611 Mdot
.83 .22644 Mdot
.83 .22713 Mdot
.83 .2273 Mdot
.83 .22769 Mdot
.83 .2281 Mdot
.83 .22824 Mdot
.83 .22831 Mdot
.83 .22869 Mdot
.83 .22972 Mdot
.83 .22992 Mdot
.83 .23002 Mdot
.83 .23003 Mdot
.83 .23025 Mdot
.83 .23046 Mdot
.83 .23068 Mdot
.83 .23132 Mdot
.83 .23221 Mdot
.83 .23303 Mdot
.83 .2332 Mdot
.83 .2336 Mdot
.83 .23425 Mdot
.83 .23473 Mdot
.83 .23515 Mdot
.83 .23594 Mdot
.83 .23613 Mdot
.83 .23833 Mdot
.83 .23956 Mdot
.83 .23968 Mdot
.83 .24116 Mdot
.83 .24294 Mdot
.83 .24378 Mdot
.83 .2438 Mdot
.83 .24425 Mdot
.83 .2444 Mdot
.83 .24467 Mdot
.83 .24487 Mdot
.83 .24586 Mdot
.83 .24597 Mdot
.83 .2469 Mdot
.83 .24719 Mdot
.83 .24767 Mdot
.83 .24767 Mdot
.83 .24795 Mdot
.83 .24801 Mdot
.83 .24809 Mdot
.83 .24831 Mdot
.83 .25066 Mdot
.83 .25095 Mdot
.83 .25098 Mdot
.83 .25166 Mdot
.83 .25185 Mdot
.83 .25215 Mdot
.83 .25238 Mdot
.83 .25278 Mdot
.83 .25319 Mdot
.83 .25369 Mdot
.83 .25427 Mdot
.83 .25494 Mdot
.83 .25596 Mdot
.83 .25622 Mdot
.83 .25624 Mdot
.83 .25647 Mdot
.83 .25687 Mdot
.83 .25715 Mdot
.83 .25798 Mdot
.83 .25837 Mdot
.83 .25928 Mdot
.83 .25931 Mdot
.83 .25959 Mdot
.83 .26049 Mdot
.83 .26053 Mdot
.83 .26114 Mdot
.83 .26144 Mdot
.83 .26148 Mdot
.83 .26203 Mdot
.83 .26237 Mdot
.83 .26406 Mdot
.83 .26408 Mdot
.83 .26453 Mdot
.83 .26473 Mdot
.83 .26637 Mdot
.83 .26683 Mdot
.83 .2672 Mdot
.83 .26784 Mdot
.83 .26814 Mdot
.83 .26912 Mdot
.83 .26919 Mdot
.83 .26955 Mdot
.83 .26978 Mdot
.83 .27137 Mdot
.83 .2716 Mdot
.83 .27182 Mdot
.83 .27182 Mdot
.83 .27298 Mdot
.83 .27323 Mdot
.83 .27339 Mdot
.83 .27364 Mdot
.83 .27439 Mdot
.83 .27473 Mdot
.83 .275 Mdot
.83 .27538 Mdot
.83 .27575 Mdot
.83 .27588 Mdot
.83 .27615 Mdot
.83 .27681 Mdot
.83 .27689 Mdot
.83 .27755 Mdot
.83 .27777 Mdot
.83 .27849 Mdot
.83 .27871 Mdot
.83 .27963 Mdot
.83 .28057 Mdot
.83 .28125 Mdot
.83 .28169 Mdot
.83 .28184 Mdot
.83 .28213 Mdot
.83 .28224 Mdot
.83 .28238 Mdot
.83 .28247 Mdot
.83 .28413 Mdot
.83 .28439 Mdot
.83 .28548 Mdot
.83 .28557 Mdot
.83 .28558 Mdot
.83 .28575 Mdot
.83 .28619 Mdot
.83 .28676 Mdot
.83 .28682 Mdot
.83 .28698 Mdot
.83 .28848 Mdot
.83 .28852 Mdot
.83 .29045 Mdot
.83 .29119 Mdot
.83 .29182 Mdot
.83 .29198 Mdot
.83 .29246 Mdot
.83 .29282 Mdot
.83 .29297 Mdot
.83 .29303 Mdot
.83 .29328 Mdot
.83 .29462 Mdot
.83 .29494 Mdot
.83 .29525 Mdot
.83 .29551 Mdot
.83 .29569 Mdot
.83 .2957 Mdot
.83 .29573 Mdot
.83 .29602 Mdot
.83 .29654 Mdot
.83 .29658 Mdot
.83 .29711 Mdot
.83 .29712 Mdot
.83 .29733 Mdot
.83 .29759 Mdot
.83 .29761 Mdot
.83 .29764 Mdot
.83 .29809 Mdot
.83 .29812 Mdot
.83 .29831 Mdot
.83 .29862 Mdot
.83 .29865 Mdot
.83 .29933 Mdot
.83 .29978 Mdot
.83 .29983 Mdot
.83 .29988 Mdot
.83 .30009 Mdot
.83 .30059 Mdot
.83 .30087 Mdot
.83 .3011 Mdot
.83 .30127 Mdot
.83 .30128 Mdot
.83 .30175 Mdot
.83 .30176 Mdot
.83 .3021 Mdot
.83 .30228 Mdot
.83 .30229 Mdot
.83 .30329 Mdot
.83 .30365 Mdot
.83 .30392 Mdot
.83 .30396 Mdot
.83 .30403 Mdot
.83 .30408 Mdot
.83 .3041 Mdot
.83 .3041 Mdot
.83 .30445 Mdot
.83 .3048 Mdot
.83 .30504 Mdot
.83 .3051 Mdot
.83 .30567 Mdot
.83 .30599 Mdot
.83 .30612 Mdot
.83 .30625 Mdot
.83 .30635 Mdot
.83 .30638 Mdot
.83 .30641 Mdot
.83 .30664 Mdot
.83 .3067 Mdot
.83 .30685 Mdot
.83 .30689 Mdot
.83 .30695 Mdot
.83 .30747 Mdot
.83 .30805 Mdot
.83 .3085 Mdot
.83 .30869 Mdot
.83 .3094 Mdot
.83 .3095 Mdot
.83 .31102 Mdot
.83 .31112 Mdot
.83 .3116 Mdot
.83 .31161 Mdot
.83 .31167 Mdot
.83 .31184 Mdot
.83 .31203 Mdot
.83 .3121 Mdot
.83 .31237 Mdot
.83 .31254 Mdot
.83 .3135 Mdot
.83 .31408 Mdot
.83 .31418 Mdot
.83 .31501 Mdot
.83 .31509 Mdot
.83 .3154 Mdot
.83 .31576 Mdot
.83 .3159 Mdot
.83 .31649 Mdot
.83 .31649 Mdot
.83 .31667 Mdot
.83 .31667 Mdot
.83 .31669 Mdot
.83 .31675 Mdot
.83 .31679 Mdot
.83 .317 Mdot
.83 .31719 Mdot
.83 .3173 Mdot
.83 .31749 Mdot
.83 .3175 Mdot
.83 .31873 Mdot
.83 .31882 Mdot
.83 .3189 Mdot
.83 .31928 Mdot
.83 .31939 Mdot
.83 .31944 Mdot
.83 .31996 Mdot
.83 .32006 Mdot
.83 .32013 Mdot
.83 .32038 Mdot
.83 .32092 Mdot
.83 .32121 Mdot
.83 .32214 Mdot
.83 .32216 Mdot
.83 .32243 Mdot
.83 .32263 Mdot
.83 .32276 Mdot
.83 .32296 Mdot
.83 .323 Mdot
.83 .323 Mdot
.83 .32308 Mdot
.83 .32337 Mdot
.83 .32352 Mdot
.83 .32372 Mdot
.83 .32412 Mdot
.83 .3245 Mdot
.83 .32497 Mdot
.83 .325 Mdot
.83 .32536 Mdot
.83 .32585 Mdot
.83 .32588 Mdot
.83 .32599 Mdot
.83 .32671 Mdot
.83 .32677 Mdot
.83 .32679 Mdot
.83 .3273 Mdot
.83 .32738 Mdot
.83 .32741 Mdot
.83 .3275 Mdot
.83 .32765 Mdot
.83 .32788 Mdot
.83 .3285 Mdot
.83 .32857 Mdot
.83 .32871 Mdot
.83 .32912 Mdot
.83 .32927 Mdot
.83 .32956 Mdot
.83 .32963 Mdot
.83 .33043 Mdot
.83 .33146 Mdot
.83 .3321 Mdot
.83 .33241 Mdot
.83 .33273 Mdot
.83 .3328 Mdot
.83 .33316 Mdot
.83 .33354 Mdot
.83 .33394 Mdot
.83 .33397 Mdot
.83 .33405 Mdot
.83 .3349 Mdot
.83 .33502 Mdot
.83 .33533 Mdot
.83 .33544 Mdot
.83 .33553 Mdot
.83 .33567 Mdot
.83 .33582 Mdot
.83 .336 Mdot
.83 .33621 Mdot
.83 .33645 Mdot
.83 .33683 Mdot
.83 .33692 Mdot
.83 .33803 Mdot
.83 .33804 Mdot
.83 .33847 Mdot
.83 .33849 Mdot
.83 .33881 Mdot
.83 .33903 Mdot
.83 .33915 Mdot
.83 .33977 Mdot
.83 .33993 Mdot
.83 .34001 Mdot
.83 .3406 Mdot
.83 .34077 Mdot
.83 .34114 Mdot
.83 .34124 Mdot
.83 .3416 Mdot
.83 .34176 Mdot
.83 .34242 Mdot
.83 .34258 Mdot
.83 .343 Mdot
.83 .34309 Mdot
.83 .34315 Mdot
.83 .34374 Mdot
.83 .34387 Mdot
.83 .34405 Mdot
.83 .34415 Mdot
.83 .34442 Mdot
.83 .34474 Mdot
.83 .34508 Mdot
.83 .34541 Mdot
.83 .34622 Mdot
.83 .34632 Mdot
.83 .34636 Mdot
.83 .34644 Mdot
.83 .34705 Mdot
.83 .34714 Mdot
.83 .34754 Mdot
.83 .34764 Mdot
.83 .348 Mdot
.83 .34808 Mdot
.83 .34863 Mdot
.83 .34864 Mdot
.83 .34934 Mdot
.83 .35026 Mdot
.83 .35037 Mdot
.83 .35086 Mdot
.83 .35097 Mdot
.83 .35108 Mdot
.83 .35118 Mdot
.83 .35125 Mdot
.83 .35136 Mdot
.83 .35176 Mdot
.83 .35184 Mdot
.83 .35194 Mdot
.83 .35195 Mdot
.83 .35212 Mdot
.83 .35212 Mdot
.83 .35232 Mdot
.83 .35276 Mdot
.83 .35321 Mdot
.83 .35327 Mdot
.83 .35345 Mdot
.83 .35364 Mdot
.83 .35364 Mdot
.83 .35425 Mdot
.83 .35427 Mdot
.83 .3543 Mdot
.83 .35442 Mdot
.83 .35498 Mdot
.83 .35511 Mdot
.83 .35513 Mdot
.83 .35522 Mdot
.83 .35524 Mdot
.83 .35596 Mdot
.83 .35622 Mdot
.83 .35681 Mdot
.83 .35704 Mdot
.83 .3571 Mdot
.83 .35717 Mdot
.83 .35858 Mdot
.83 .35879 Mdot
.83 .35879 Mdot
.83 .35915 Mdot
.83 .35966 Mdot
.83 .35985 Mdot
.83 .36005 Mdot
.83 .3604 Mdot
.83 .3605 Mdot
.83 .36095 Mdot
.83 .36107 Mdot
.83 .36114 Mdot
.83 .36156 Mdot
.83 .36272 Mdot
.83 .36279 Mdot
.83 .36284 Mdot
.83 .36323 Mdot
.83 .36338 Mdot
.83 .36498 Mdot
.83 .36513 Mdot
.83 .36516 Mdot
.83 .36563 Mdot
.83 .36581 Mdot
.83 .36617 Mdot
.83 .36697 Mdot
.83 .36733 Mdot
.83 .3676 Mdot
.83 .36778 Mdot
.83 .36826 Mdot
.83 .36893 Mdot
.83 .36904 Mdot
.83 .36917 Mdot
.83 .36929 Mdot
.83 .36962 Mdot
.83 .36988 Mdot
.83 .36992 Mdot
.83 .37006 Mdot
.83 .37162 Mdot
.83 .37196 Mdot
.83 .37212 Mdot
.83 .37214 Mdot
.83 .3725 Mdot
.83 .37256 Mdot
.83 .37285 Mdot
.83 .37321 Mdot
.83 .37414 Mdot
.83 .37427 Mdot
.83 .37446 Mdot
.83 .37476 Mdot
.83 .37575 Mdot
.83 .37581 Mdot
.83 .37669 Mdot
.83 .37711 Mdot
.83 .3774 Mdot
.83 .37786 Mdot
.83 .37807 Mdot
.83 .37817 Mdot
.83 .37914 Mdot
.83 .37994 Mdot
.83 .38032 Mdot
.83 .38064 Mdot
.83 .38117 Mdot
.83 .38195 Mdot
.83 .38227 Mdot
.83 .38392 Mdot
.83 .38444 Mdot
.83 .38573 Mdot
.83 .38591 Mdot
.83 .38662 Mdot
.83 .38715 Mdot
.83 .38778 Mdot
.83 .38796 Mdot
.83 .38815 Mdot
.83 .38911 Mdot
.83 .39062 Mdot
.83 .39072 Mdot
.83 .39088 Mdot
.83 .39123 Mdot
.83 .39199 Mdot
.83 .39248 Mdot
.83 .39318 Mdot
.83 .39356 Mdot
.83 .39464 Mdot
.83 .39473 Mdot
.83 .39496 Mdot
.83 .395 Mdot
.83 .39574 Mdot
.83 .39599 Mdot
.83 .39637 Mdot
.83 .39643 Mdot
.83 .39677 Mdot
.83 .39688 Mdot
.83 .39718 Mdot
.83 .3974 Mdot
.83 .39842 Mdot
.83 .3986 Mdot
.83 .39895 Mdot
.83 .39955 Mdot
.83 .40004 Mdot
.83 .40013 Mdot
.83 .40014 Mdot
.83 .40062 Mdot
.83 .40073 Mdot
.83 .40077 Mdot
.83 .40103 Mdot
.83 .40142 Mdot
.83 .40142 Mdot
.83 .40159 Mdot
.83 .40188 Mdot
.83 .40199 Mdot
.83 .40211 Mdot
.83 .40248 Mdot
.83 .40418 Mdot
.83 .40442 Mdot
.83 .40448 Mdot
.83 .40491 Mdot
.83 .40546 Mdot
.83 .40566 Mdot
.83 .40587 Mdot
.83 .40606 Mdot
.83 .40639 Mdot
.83 .40686 Mdot
.83 .40691 Mdot
.83 .40717 Mdot
.83 .40797 Mdot
.83 .40804 Mdot
.83 .40826 Mdot
.83 .40836 Mdot
.83 .40872 Mdot
.83 .40886 Mdot
.83 .40923 Mdot
.83 .40931 Mdot
.83 .40991 Mdot
.83 .41058 Mdot
.83 .41063 Mdot
.83 .41124 Mdot
.83 .41142 Mdot
.83 .41153 Mdot
.83 .41231 Mdot
.83 .41236 Mdot
.83 .41237 Mdot
.83 .41262 Mdot
.83 .41348 Mdot
.83 .41518 Mdot
.83 .41528 Mdot
.83 .41552 Mdot
.83 .41561 Mdot
.83 .41565 Mdot
.83 .41602 Mdot
.83 .41616 Mdot
.83 .41626 Mdot
.83 .41637 Mdot
.83 .4167 Mdot
.83 .41716 Mdot
.83 .41829 Mdot
.83 .41853 Mdot
.83 .41899 Mdot
.83 .41911 Mdot
.83 .41919 Mdot
.83 .41931 Mdot
.83 .42004 Mdot
.83 .42022 Mdot
.83 .42069 Mdot
.83 .42074 Mdot
.83 .42079 Mdot
.83 .42114 Mdot
.83 .42121 Mdot
.83 .42144 Mdot
.83 .42229 Mdot
.83 .42271 Mdot
.83 .42277 Mdot
.83 .42289 Mdot
.83 .42289 Mdot
.83 .42324 Mdot
.83 .42378 Mdot
.83 .42428 Mdot
.83 .42434 Mdot
.83 .42526 Mdot
.83 .42557 Mdot
.83 .42569 Mdot
.83 .42579 Mdot
.83 .42583 Mdot
.83 .42618 Mdot
.83 .42716 Mdot
.83 .42759 Mdot
.83 .42863 Mdot
.83 .42867 Mdot
.83 .42878 Mdot
.83 .42882 Mdot
.83 .42896 Mdot
.83 .42899 Mdot
.83 .42921 Mdot
.83 .4294 Mdot
.83 .42975 Mdot
.83 .43014 Mdot
.83 .43035 Mdot
.83 .43039 Mdot
.83 .43043 Mdot
.83 .43144 Mdot
.83 .43144 Mdot
.83 .43176 Mdot
.83 .43205 Mdot
.83 .43216 Mdot
.83 .43246 Mdot
.83 .43289 Mdot
.83 .43322 Mdot
.83 .43363 Mdot
.83 .43384 Mdot
.83 .43395 Mdot
.83 .43397 Mdot
.83 .43424 Mdot
.83 .43426 Mdot
.83 .43443 Mdot
.83 .43456 Mdot
.83 .4349 Mdot
.83 .43522 Mdot
.83 .43539 Mdot
.83 .43541 Mdot
.83 .43552 Mdot
.83 .43568 Mdot
.83 .43587 Mdot
.83 .43606 Mdot
.83 .43687 Mdot
.83 .43702 Mdot
.83 .43706 Mdot
.83 .43714 Mdot
.83 .43775 Mdot
.83 .43813 Mdot
.83 .43857 Mdot
.83 .43974 Mdot
.83 .43976 Mdot
.83 .44066 Mdot
.83 .44076 Mdot
.83 .44079 Mdot
.83 .44114 Mdot
.83 .4414 Mdot
.83 .44151 Mdot
.83 .44151 Mdot
.83 .44157 Mdot
.83 .44223 Mdot
.83 .44238 Mdot
.83 .44338 Mdot
.83 .44343 Mdot
.83 .44352 Mdot
.83 .44358 Mdot
.83 .44376 Mdot
.83 .44385 Mdot
.83 .44411 Mdot
.83 .44453 Mdot
.83 .44509 Mdot
.83 .44565 Mdot
.83 .44578 Mdot
.83 .44621 Mdot
.83 .44634 Mdot
.83 .44674 Mdot
.83 .44679 Mdot
.83 .44719 Mdot
.83 .44735 Mdot
.83 .44742 Mdot
.83 .44765 Mdot
.83 .44788 Mdot
.83 .44804 Mdot
.83 .44825 Mdot
.83 .4487 Mdot
.83 .44885 Mdot
.83 .44895 Mdot
.83 .4491 Mdot
.83 .4498 Mdot
.83 .4498 Mdot
.83 .44993 Mdot
.83 .45007 Mdot
.83 .45102 Mdot
.83 .45116 Mdot
.83 .45138 Mdot
.83 .45142 Mdot
.83 .45201 Mdot
.83 .45219 Mdot
.83 .45258 Mdot
.83 .4528 Mdot
.83 .45294 Mdot
.83 .45308 Mdot
.83 .45406 Mdot
.83 .45419 Mdot
.83 .45446 Mdot
.83 .45447 Mdot
.83 .45549 Mdot
.83 .45569 Mdot
.83 .45603 Mdot
.83 .45605 Mdot
.83 .45659 Mdot
.83 .45662 Mdot
.83 .45716 Mdot
.83 .45733 Mdot
.83 .45735 Mdot
.83 .4579 Mdot
.83 .45813 Mdot
.83 .45863 Mdot
.83 .4588 Mdot
.83 .45904 Mdot
.83 .45918 Mdot
.83 .45919 Mdot
.83 .45935 Mdot
.83 .45997 Mdot
.83 .46037 Mdot
.83 .46072 Mdot
.83 .46102 Mdot
.83 .46126 Mdot
.83 .46151 Mdot
.83 .46164 Mdot
.83 .46183 Mdot
.83 .46194 Mdot
.83 .46235 Mdot
.83 .46237 Mdot
.83 .46254 Mdot
.83 .46396 Mdot
.83 .46409 Mdot
.83 .46414 Mdot
.83 .46418 Mdot
.83 .46434 Mdot
.83 .46434 Mdot
.83 .46463 Mdot
.83 .46481 Mdot
.83 .46537 Mdot
.83 .46543 Mdot
.83 .46603 Mdot
.83 .46615 Mdot
.83 .46631 Mdot
.83 .46641 Mdot
.83 .46667 Mdot
.83 .46669 Mdot
.83 .46719 Mdot
.83 .46826 Mdot
.83 .46916 Mdot
.83 .46923 Mdot
.83 .46997 Mdot
.83 .47129 Mdot
.83 .47141 Mdot
.83 .47189 Mdot
.83 .47214 Mdot
.83 .47243 Mdot
.83 .47282 Mdot
.83 .47306 Mdot
.83 .47317 Mdot
.83 .47366 Mdot
.83 .47419 Mdot
.83 .47458 Mdot
.83 .47471 Mdot
.83 .47484 Mdot
.83 .47497 Mdot
.83 .47498 Mdot
.83 .47504 Mdot
.83 .47516 Mdot
.83 .47578 Mdot
.83 .476 Mdot
.83 .47605 Mdot
.83 .47613 Mdot
.83 .47638 Mdot
.83 .47662 Mdot
.83 .47672 Mdot
.83 .47714 Mdot
.83 .47733 Mdot
.83 .47751 Mdot
.83 .47757 Mdot
.83 .47839 Mdot
.83 .47899 Mdot
.83 .47903 Mdot
.83 .47936 Mdot
.83 .47981 Mdot
.83 .47989 Mdot
.83 .4804 Mdot
.83 .48045 Mdot
.83 .48084 Mdot
.83 .4811 Mdot
.83 .48114 Mdot
.83 .48115 Mdot
.83 .4812 Mdot
.83 .48144 Mdot
.83 .48168 Mdot
.83 .48168 Mdot
.83 .48216 Mdot
.83 .4823 Mdot
.83 .4823 Mdot
.83 .48236 Mdot
.83 .48255 Mdot
.83 .48261 Mdot
.83 .48269 Mdot
.83 .48291 Mdot
.83 .48324 Mdot
.83 .4835 Mdot
.83 .4835 Mdot
.83 .4837 Mdot
.83 .48373 Mdot
.83 .48386 Mdot
.83 .48429 Mdot
.83 .48432 Mdot
.83 .48438 Mdot
.83 .48513 Mdot
.83 .48516 Mdot
.83 .48528 Mdot
.83 .48549 Mdot
.83 .48576 Mdot
.83 .48599 Mdot
.83 .48605 Mdot
.83 .48666 Mdot
.83 .48706 Mdot
.83 .48718 Mdot
.83 .48719 Mdot
.83 .48734 Mdot
.83 .48792 Mdot
.83 .48801 Mdot
.83 .48808 Mdot
.83 .4882 Mdot
.83 .48829 Mdot
.83 .48844 Mdot
.83 .48848 Mdot
.83 .48911 Mdot
.83 .48925 Mdot
.83 .48927 Mdot
.83 .48939 Mdot
.83 .48973 Mdot
.83 .49011 Mdot
.83 .4904 Mdot
.83 .49042 Mdot
.83 .4912 Mdot
.83 .49121 Mdot
.83 .49143 Mdot
.83 .49145 Mdot
.83 .49176 Mdot
.83 .49177 Mdot
.83 .49195 Mdot
.83 .49208 Mdot
.83 .49209 Mdot
.83 .49226 Mdot
.83 .49261 Mdot
.83 .49267 Mdot
.83 .49277 Mdot
.83 .4928 Mdot
.83 .4928 Mdot
.83 .49311 Mdot
.83 .49311 Mdot
.83 .49375 Mdot
.83 .49409 Mdot
.83 .49432 Mdot
.83 .49435 Mdot
.83 .4948 Mdot
.83 .49487 Mdot
.83 .49491 Mdot
.83 .49498 Mdot
.83 .49507 Mdot
.83 .49509 Mdot
.83 .4951 Mdot
.83 .49543 Mdot
.83 .49556 Mdot
.83 .49567 Mdot
.83 .49625 Mdot
.83 .49666 Mdot
.83 .49676 Mdot
.83 .49694 Mdot
.83 .49711 Mdot
.83 .4977 Mdot
.83 .49807 Mdot
.83 .49823 Mdot
.83 .49844 Mdot
.83 .49866 Mdot
.83 .49883 Mdot
.83 .49888 Mdot
.83 .49893 Mdot
.83 .49932 Mdot
.83 .49941 Mdot
.83 .49966 Mdot
.83 .49967 Mdot
.83 .49973 Mdot
.83 .49982 Mdot
.83 .49995 Mdot
.83 .50039 Mdot
.83 .50051 Mdot
.83 .50068 Mdot
.83 .50083 Mdot
.83 .50112 Mdot
.83 .50121 Mdot
.83 .50123 Mdot
.83 .50165 Mdot
.83 .50202 Mdot
.83 .50219 Mdot
.83 .50239 Mdot
.83 .50271 Mdot
.83 .50388 Mdot
.83 .50406 Mdot
.832 .18013 Mdot
.832 .1804 Mdot
.832 .18054 Mdot
.832 .1811 Mdot
.832 .18159 Mdot
.832 .18181 Mdot
.832 .18306 Mdot
.832 .18343 Mdot
.832 .18405 Mdot
.832 .18431 Mdot
.832 .18489 Mdot
.832 .18489 Mdot
.832 .18499 Mdot
.832 .1851 Mdot
.832 .18544 Mdot
.832 .18657 Mdot
.832 .18658 Mdot
.832 .18672 Mdot
.832 .18682 Mdot
.832 .18698 Mdot
.832 .18749 Mdot
.832 .18753 Mdot
.832 .18755 Mdot
.832 .18791 Mdot
.832 .1881 Mdot
.832 .18956 Mdot
.832 .18965 Mdot
.832 .18968 Mdot
.832 .19028 Mdot
.832 .19043 Mdot
.832 .19048 Mdot
.832 .1908 Mdot
.832 .19085 Mdot
.832 .19117 Mdot
.832 .19182 Mdot
.832 .19188 Mdot
.832 .19273 Mdot
.832 .193 Mdot
.832 .19358 Mdot
.832 .19434 Mdot
.832 .19489 Mdot
.832 .1953 Mdot
.832 .19579 Mdot
.832 .19716 Mdot
.832 .19733 Mdot
.832 .19756 Mdot
.832 .19803 Mdot
.832 .19828 Mdot
.832 .19842 Mdot
.832 .19873 Mdot
.832 .19876 Mdot
.832 .19923 Mdot
.832 .2001 Mdot
.832 .20018 Mdot
.832 .20034 Mdot
.832 .20169 Mdot
.832 .20271 Mdot
.832 .20343 Mdot
.832 .20347 Mdot
.832 .20383 Mdot
.832 .20393 Mdot
.832 .20395 Mdot
.832 .20426 Mdot
.832 .20457 Mdot
.832 .2046 Mdot
.832 .2052 Mdot
.832 .20531 Mdot
.832 .20532 Mdot
.832 .20603 Mdot
.832 .2075 Mdot
.832 .20861 Mdot
.832 .2093 Mdot
.832 .20934 Mdot
.832 .2098 Mdot
.832 .20987 Mdot
.832 .21071 Mdot
.832 .21086 Mdot
.832 .2114 Mdot
.832 .21174 Mdot
.832 .21189 Mdot
.832 .21195 Mdot
.832 .21234 Mdot
.832 .21235 Mdot
.832 .21244 Mdot
.832 .21292 Mdot
.832 .21298 Mdot
.832 .21299 Mdot
.832 .21396 Mdot
.832 .21435 Mdot
.832 .21504 Mdot
.832 .21542 Mdot
.832 .21556 Mdot
.832 .21574 Mdot
.832 .21621 Mdot
.832 .21641 Mdot
.832 .21702 Mdot
.832 .2174 Mdot
.832 .21815 Mdot
.832 .21906 Mdot
.832 .21907 Mdot
.832 .21987 Mdot
.832 .22038 Mdot
.832 .22077 Mdot
.832 .22144 Mdot
.832 .22337 Mdot
.832 .22349 Mdot
.832 .22433 Mdot
.832 .22552 Mdot
.832 .22568 Mdot
.832 .22654 Mdot
.832 .22726 Mdot
.832 .22757 Mdot
.832 .22813 Mdot
.832 .22818 Mdot
.832 .22826 Mdot
.832 .22906 Mdot
.832 .2294 Mdot
.832 .22979 Mdot
.832 .23063 Mdot
.832 .23069 Mdot
.832 .23207 Mdot
.832 .23216 Mdot
.832 .23217 Mdot
.832 .23235 Mdot
.832 .2324 Mdot
.832 .23253 Mdot
.832 .23302 Mdot
.832 .23313 Mdot
.832 .23376 Mdot
.832 .23422 Mdot
.832 .23426 Mdot
.832 .23464 Mdot
.832 .2347 Mdot
.832 .23477 Mdot
.832 .23618 Mdot
.832 .23672 Mdot
.832 .23763 Mdot
.832 .23774 Mdot
.832 .2384 Mdot
.832 .23909 Mdot
.832 .23955 Mdot
.832 .24026 Mdot
.832 .24053 Mdot
.832 .24076 Mdot
.832 .24102 Mdot
.832 .24103 Mdot
.832 .24108 Mdot
.832 .24164 Mdot
.832 .24173 Mdot
.832 .24192 Mdot
.832 .24283 Mdot
.832 .24434 Mdot
.832 .24537 Mdot
.832 .24567 Mdot
.832 .24572 Mdot
.832 .24583 Mdot
.832 .24642 Mdot
.832 .24727 Mdot
.832 .24783 Mdot
.832 .24805 Mdot
.832 .24886 Mdot
.832 .24902 Mdot
.832 .24918 Mdot
.832 .24925 Mdot
.832 .24939 Mdot
.832 .2498 Mdot
.832 .24992 Mdot
.832 .25111 Mdot
.832 .25219 Mdot
.832 .25248 Mdot
.832 .25368 Mdot
.832 .25448 Mdot
.832 .25472 Mdot
.832 .25554 Mdot
.832 .25575 Mdot
.832 .25624 Mdot
.832 .25674 Mdot
.832 .2582 Mdot
.832 .25825 Mdot
.832 .25938 Mdot
.832 .25939 Mdot
.832 .25957 Mdot
.832 .26023 Mdot
.832 .26033 Mdot
.832 .26042 Mdot
.832 .26122 Mdot
.832 .26126 Mdot
.832 .26142 Mdot
.832 .26143 Mdot
.832 .26162 Mdot
.832 .2617 Mdot
.832 .26182 Mdot
.832 .26197 Mdot
.832 .26203 Mdot
.832 .26432 Mdot
.832 .26516 Mdot
.832 .26522 Mdot
.832 .26528 Mdot
.832 .2659 Mdot
.832 .2666 Mdot
.832 .26707 Mdot
.832 .26787 Mdot
.832 .26873 Mdot
.832 .26907 Mdot
.832 .26956 Mdot
.832 .27063 Mdot
.832 .27136 Mdot
.832 .27162 Mdot
.832 .2718 Mdot
.832 .27181 Mdot
.832 .27188 Mdot
.832 .27265 Mdot
.832 .27339 Mdot
.832 .27342 Mdot
.832 .27345 Mdot
.832 .27346 Mdot
.832 .27389 Mdot
.832 .27584 Mdot
.832 .2761 Mdot
.832 .27638 Mdot
.832 .27641 Mdot
.832 .27783 Mdot
.832 .27877 Mdot
.832 .27879 Mdot
.832 .27911 Mdot
.832 .27996 Mdot
.832 .28002 Mdot
.832 .28009 Mdot
.832 .28016 Mdot
.832 .28016 Mdot
.832 .28023 Mdot
.832 .28059 Mdot
.832 .2809 Mdot
.832 .28131 Mdot
.832 .28185 Mdot
.832 .28221 Mdot
.832 .28228 Mdot
.832 .28267 Mdot
.832 .28296 Mdot
.832 .28349 Mdot
.832 .28436 Mdot
.832 .28456 Mdot
.832 .28458 Mdot
.832 .2847 Mdot
.832 .28507 Mdot
.832 .28579 Mdot
.832 .28583 Mdot
.832 .28585 Mdot
.832 .28596 Mdot
.832 .28762 Mdot
.832 .2878 Mdot
.832 .28823 Mdot
.832 .28908 Mdot
.832 .28997 Mdot
.832 .29042 Mdot
.832 .29064 Mdot
.832 .29073 Mdot
.832 .29076 Mdot
.832 .29126 Mdot
.832 .29128 Mdot
.832 .29159 Mdot
.832 .29214 Mdot
.832 .29216 Mdot
.832 .29218 Mdot
.832 .29239 Mdot
.832 .2925 Mdot
.832 .29276 Mdot
.832 .29307 Mdot
.832 .29386 Mdot
.832 .2939 Mdot
.832 .29484 Mdot
.832 .29498 Mdot
.832 .29546 Mdot
.832 .29546 Mdot
.832 .29642 Mdot
.832 .29649 Mdot
.832 .29673 Mdot
.832 .29677 Mdot
.832 .29691 Mdot
.832 .29765 Mdot
.832 .29768 Mdot
.832 .29785 Mdot
.832 .29788 Mdot
.832 .29789 Mdot
.832 .29805 Mdot
.832 .2981 Mdot
.832 .29823 Mdot
.832 .29881 Mdot
.832 .29897 Mdot
.832 .30017 Mdot
.832 .30068 Mdot
.832 .30069 Mdot
.832 .30092 Mdot
.832 .30093 Mdot
.832 .30111 Mdot
.832 .30136 Mdot
.832 .30173 Mdot
.832 .30222 Mdot
.832 .30228 Mdot
.832 .30231 Mdot
.832 .30262 Mdot
.832 .3028 Mdot
.832 .30291 Mdot
.832 .30297 Mdot
.832 .30323 Mdot
.832 .30439 Mdot
.832 .30466 Mdot
.832 .30528 Mdot
.832 .30566 Mdot
.832 .3058 Mdot
.832 .30585 Mdot
.832 .30686 Mdot
.832 .3071 Mdot
.832 .30719 Mdot
.832 .30773 Mdot
.832 .3078 Mdot
.832 .3081 Mdot
.832 .30833 Mdot
.832 .30917 Mdot
.832 .30942 Mdot
.832 .30952 Mdot
.832 .31002 Mdot
.832 .3104 Mdot
.832 .31048 Mdot
.832 .31093 Mdot
.832 .31138 Mdot
.832 .31159 Mdot
.832 .31163 Mdot
.832 .31179 Mdot
.832 .3122 Mdot
.832 .31225 Mdot
.832 .31235 Mdot
.832 .31255 Mdot
.832 .31255 Mdot
.832 .31268 Mdot
.832 .31275 Mdot
.832 .31328 Mdot
.832 .31331 Mdot
.832 .31332 Mdot
.832 .31361 Mdot
.832 .31374 Mdot
.832 .31386 Mdot
.832 .3141 Mdot
.832 .31442 Mdot
.832 .31452 Mdot
.832 .3152 Mdot
.832 .31535 Mdot
.832 .31553 Mdot
.832 .31602 Mdot
.832 .31609 Mdot
.832 .31634 Mdot
.832 .3166 Mdot
.832 .3183 Mdot
.832 .31843 Mdot
.832 .31859 Mdot
.832 .31893 Mdot
.832 .31897 Mdot
.832 .31897 Mdot
.832 .31976 Mdot
.832 .32016 Mdot
.832 .32041 Mdot
.832 .32061 Mdot
.832 .32092 Mdot
.832 .32097 Mdot
.832 .32137 Mdot
.832 .32174 Mdot
.832 .32209 Mdot
.832 .32223 Mdot
.832 .3232 Mdot
.832 .32333 Mdot
.832 .3236 Mdot
.832 .32423 Mdot
.832 .32479 Mdot
.832 .32584 Mdot
.832 .32626 Mdot
.832 .32755 Mdot
.832 .32767 Mdot
.832 .32867 Mdot
.832 .32873 Mdot
.832 .3288 Mdot
.832 .32902 Mdot
.832 .32924 Mdot
.832 .32941 Mdot
.832 .32956 Mdot
.832 .32958 Mdot
.832 .32961 Mdot
.832 .33012 Mdot
.832 .33064 Mdot
.832 .33068 Mdot
.832 .33092 Mdot
.832 .33133 Mdot
.832 .33169 Mdot
.832 .33187 Mdot
.832 .33187 Mdot
.832 .33188 Mdot
.832 .33209 Mdot
.832 .33212 Mdot
.832 .33219 Mdot
.832 .33252 Mdot
.832 .33306 Mdot
.832 .33381 Mdot
.832 .33412 Mdot
.832 .3344 Mdot
.832 .33475 Mdot
.832 .33489 Mdot
.832 .33508 Mdot
.832 .33551 Mdot
.832 .336 Mdot
.832 .33681 Mdot
.832 .33736 Mdot
.832 .33807 Mdot
.832 .3385 Mdot
.832 .33856 Mdot
.832 .33884 Mdot
.832 .33887 Mdot
.832 .33918 Mdot
.832 .33933 Mdot
.832 .33945 Mdot
.832 .34058 Mdot
.832 .34085 Mdot
.832 .3411 Mdot
.832 .34127 Mdot
.832 .34187 Mdot
.832 .34199 Mdot
.832 .34217 Mdot
.832 .34256 Mdot
.832 .34282 Mdot
.832 .34292 Mdot
.832 .34298 Mdot
.832 .34357 Mdot
.832 .34357 Mdot
.832 .34358 Mdot
.832 .34373 Mdot
.832 .34444 Mdot
.832 .34453 Mdot
.832 .34464 Mdot
.832 .34465 Mdot
.832 .34516 Mdot
.832 .3455 Mdot
.832 .34562 Mdot
.832 .346 Mdot
.832 .34603 Mdot
.832 .34616 Mdot
.832 .34627 Mdot
.832 .34641 Mdot
.832 .34661 Mdot
.832 .34677 Mdot
.832 .3469 Mdot
.832 .34701 Mdot
.832 .3472 Mdot
.832 .34764 Mdot
.832 .34805 Mdot
.832 .34805 Mdot
.832 .34809 Mdot
.832 .34869 Mdot
.832 .34891 Mdot
.832 .34922 Mdot
.832 .34982 Mdot
.832 .35001 Mdot
.832 .35002 Mdot
.832 .35034 Mdot
.832 .35034 Mdot
.832 .35046 Mdot
.832 .35095 Mdot
.832 .35096 Mdot
.832 .35135 Mdot
.832 .35187 Mdot
.832 .35198 Mdot
.832 .352 Mdot
.832 .35232 Mdot
.832 .35239 Mdot
.832 .35248 Mdot
.832 .35322 Mdot
.832 .35379 Mdot
.832 .35475 Mdot
.832 .35485 Mdot
.832 .35609 Mdot
.832 .35648 Mdot
.832 .35678 Mdot
.832 .35692 Mdot
.832 .35695 Mdot
.832 .35735 Mdot
.832 .35759 Mdot
.832 .3577 Mdot
.832 .35775 Mdot
.832 .35798 Mdot
.832 .35826 Mdot
.832 .35837 Mdot
.832 .35871 Mdot
.832 .35877 Mdot
.832 .36061 Mdot
.832 .36088 Mdot
.832 .36191 Mdot
.832 .36212 Mdot
.832 .36352 Mdot
.832 .36373 Mdot
.832 .36433 Mdot
.832 .36448 Mdot
.832 .36475 Mdot
.832 .36477 Mdot
.832 .36479 Mdot
.832 .36538 Mdot
.832 .36549 Mdot
.832 .36559 Mdot
.832 .36577 Mdot
.832 .36583 Mdot
.832 .36617 Mdot
.832 .36646 Mdot
.832 .36719 Mdot
.832 .36731 Mdot
.832 .36782 Mdot
.832 .36807 Mdot
.832 .3684 Mdot
.832 .36869 Mdot
.832 .3689 Mdot
.832 .36921 Mdot
.832 .36964 Mdot
.832 .36978 Mdot
.832 .36979 Mdot
.832 .36983 Mdot
.832 .36993 Mdot
.832 .37005 Mdot
.832 .37052 Mdot
.832 .37116 Mdot
.832 .37123 Mdot
.832 .37139 Mdot
.832 .37157 Mdot
.832 .3719 Mdot
.832 .37194 Mdot
.832 .37206 Mdot
.832 .37209 Mdot
.832 .37259 Mdot
.832 .37388 Mdot
.832 .374 Mdot
.832 .3741 Mdot
.832 .3742 Mdot
.832 .37425 Mdot
.832 .37439 Mdot
.832 .37515 Mdot
.832 .37618 Mdot
.832 .3764 Mdot
.832 .37645 Mdot
.832 .37655 Mdot
.832 .37656 Mdot
.832 .37678 Mdot
.832 .37685 Mdot
.832 .37694 Mdot
.832 .37706 Mdot
.832 .37717 Mdot
.832 .37797 Mdot
.832 .37816 Mdot
.832 .37889 Mdot
.832 .37901 Mdot
.832 .37919 Mdot
.832 .3792 Mdot
.832 .37996 Mdot
.832 .37998 Mdot
.832 .38003 Mdot
.832 .38068 Mdot
.832 .38078 Mdot
.832 .38089 Mdot
.832 .3817 Mdot
.832 .38205 Mdot
.832 .3828 Mdot
.832 .38307 Mdot
.832 .38317 Mdot
.832 .3832 Mdot
.832 .38323 Mdot
.832 .38325 Mdot
.832 .38331 Mdot
.832 .38347 Mdot
.832 .38392 Mdot
.832 .38413 Mdot
.832 .38517 Mdot
.832 .38564 Mdot
.832 .38575 Mdot
.832 .38582 Mdot
.832 .38692 Mdot
.832 .38709 Mdot
.832 .38729 Mdot
.832 .38745 Mdot
.832 .38807 Mdot
.832 .38853 Mdot
.832 .38861 Mdot
.832 .38864 Mdot
.832 .38883 Mdot
.832 .38991 Mdot
.832 .38993 Mdot
.832 .39002 Mdot
.832 .39022 Mdot
.832 .39043 Mdot
.832 .39047 Mdot
.832 .39085 Mdot
.832 .39129 Mdot
.832 .3913 Mdot
.832 .39138 Mdot
.832 .39164 Mdot
.832 .39195 Mdot
.832 .39232 Mdot
.832 .39247 Mdot
.832 .39278 Mdot
.832 .39329 Mdot
.832 .39347 Mdot
.832 .39367 Mdot
.832 .39382 Mdot
.832 .39394 Mdot
.832 .3943 Mdot
.832 .39431 Mdot
.832 .39432 Mdot
.832 .39448 Mdot
.832 .39457 Mdot
.832 .39494 Mdot
.832 .39665 Mdot
.832 .39681 Mdot
.832 .39791 Mdot
.832 .39815 Mdot
.832 .39822 Mdot
.832 .39839 Mdot
.832 .39853 Mdot
.832 .39856 Mdot
.832 .39877 Mdot
.832 .39903 Mdot
.832 .39911 Mdot
.832 .39929 Mdot
.832 .40027 Mdot
.832 .40091 Mdot
.832 .40169 Mdot
.832 .40175 Mdot
.832 .40179 Mdot
.832 .40198 Mdot
.832 .40206 Mdot
.832 .40261 Mdot
.832 .40262 Mdot
.832 .40291 Mdot
.832 .40298 Mdot
.832 .40318 Mdot
.832 .4033 Mdot
.832 .40433 Mdot
.832 .40435 Mdot
.832 .4046 Mdot
.832 .40486 Mdot
.832 .40498 Mdot
.832 .40513 Mdot
.832 .40522 Mdot
.832 .40534 Mdot
.832 .4055 Mdot
.832 .40557 Mdot
.832 .40559 Mdot
.832 .40582 Mdot
.832 .40589 Mdot
.832 .40609 Mdot
.832 .40653 Mdot
.832 .40705 Mdot
.832 .4074 Mdot
.832 .40789 Mdot
.832 .40807 Mdot
.832 .40843 Mdot
.832 .40884 Mdot
.832 .40969 Mdot
.832 .40987 Mdot
.832 .40989 Mdot
.832 .41035 Mdot
.832 .41111 Mdot
.832 .4116 Mdot
.832 .41215 Mdot
.832 .41227 Mdot
.832 .41235 Mdot
.832 .41256 Mdot
.832 .41273 Mdot
.832 .41291 Mdot
.832 .41369 Mdot
.832 .41389 Mdot
.832 .41393 Mdot
.832 .41395 Mdot
.832 .41408 Mdot
.832 .4144 Mdot
.832 .41465 Mdot
.832 .41545 Mdot
.832 .41566 Mdot
.832 .4158 Mdot
.832 .41601 Mdot
.832 .41661 Mdot
.832 .41745 Mdot
.832 .41833 Mdot
.832 .41867 Mdot
.832 .41987 Mdot
.832 .41996 Mdot
.832 .42039 Mdot
.832 .42084 Mdot
.832 .42183 Mdot
.832 .42186 Mdot
.832 .42215 Mdot
.832 .42325 Mdot
.832 .42341 Mdot
.832 .42357 Mdot
.832 .4239 Mdot
.832 .42401 Mdot
.832 .42456 Mdot
.832 .42476 Mdot
.832 .4249 Mdot
.832 .42497 Mdot
.832 .42523 Mdot
.832 .42523 Mdot
.832 .42525 Mdot
.832 .42557 Mdot
.832 .42561 Mdot
.832 .42569 Mdot
.832 .42569 Mdot
.832 .42587 Mdot
.832 .4259 Mdot
.832 .42615 Mdot
.832 .42624 Mdot
.832 .42627 Mdot
.832 .42693 Mdot
.832 .42698 Mdot
.832 .42721 Mdot
.832 .42772 Mdot
.832 .42836 Mdot
.832 .43006 Mdot
.832 .43043 Mdot
.832 .4306 Mdot
.832 .43145 Mdot
.832 .43155 Mdot
.832 .43166 Mdot
.832 .43219 Mdot
.832 .43268 Mdot
.832 .43313 Mdot
.832 .43385 Mdot
.832 .43437 Mdot
.832 .43452 Mdot
.832 .43463 Mdot
.832 .43464 Mdot
.832 .43517 Mdot
.832 .4352 Mdot
.832 .43539 Mdot
.832 .43596 Mdot
.832 .43625 Mdot
.832 .4369 Mdot
.832 .43692 Mdot
.832 .4374 Mdot
.832 .43774 Mdot
.832 .43793 Mdot
.832 .43794 Mdot
.832 .43796 Mdot
.832 .43847 Mdot
.832 .43849 Mdot
.832 .43879 Mdot
.832 .43881 Mdot
.832 .43979 Mdot
.832 .44031 Mdot
.832 .44056 Mdot
.832 .44067 Mdot
.832 .44167 Mdot
.832 .44174 Mdot
.832 .44175 Mdot
.832 .44177 Mdot
.832 .4422 Mdot
.832 .44243 Mdot
.832 .4425 Mdot
.832 .44251 Mdot
.832 .44263 Mdot
.832 .44315 Mdot
.832 .44347 Mdot
.832 .44365 Mdot
.832 .44388 Mdot
.832 .44392 Mdot
.832 .44414 Mdot
.832 .44447 Mdot
.832 .44471 Mdot
.832 .4449 Mdot
.832 .44511 Mdot
.832 .44516 Mdot
.832 .44516 Mdot
.832 .4452 Mdot
.832 .44524 Mdot
.832 .44527 Mdot
.832 .44578 Mdot
.832 .44598 Mdot
.832 .44599 Mdot
.832 .44655 Mdot
.832 .44741 Mdot
.832 .44742 Mdot
.832 .44759 Mdot
.832 .44775 Mdot
.832 .44892 Mdot
.832 .44918 Mdot
.832 .44919 Mdot
.832 .44921 Mdot
.832 .44922 Mdot
.832 .44967 Mdot
.832 .45013 Mdot
.832 .45018 Mdot
.832 .45018 Mdot
.832 .45029 Mdot
.832 .45044 Mdot
.832 .45088 Mdot
.832 .45152 Mdot
.832 .45182 Mdot
.832 .45202 Mdot
.832 .45254 Mdot
.832 .45302 Mdot
.832 .45331 Mdot
.832 .45373 Mdot
.832 .4541 Mdot
.832 .45414 Mdot
.832 .45417 Mdot
.832 .45467 Mdot
.832 .45605 Mdot
.832 .45609 Mdot
.832 .45618 Mdot
.832 .45625 Mdot
.832 .4563 Mdot
.832 .45641 Mdot
.832 .45642 Mdot
.832 .45651 Mdot
.832 .45654 Mdot
.832 .45702 Mdot
.832 .45707 Mdot
.832 .45713 Mdot
.832 .45753 Mdot
.832 .45764 Mdot
.832 .45765 Mdot
.832 .45832 Mdot
.832 .45835 Mdot
.832 .45923 Mdot
.832 .45953 Mdot
.832 .45983 Mdot
.832 .45995 Mdot
.832 .46044 Mdot
.832 .46059 Mdot
.832 .46107 Mdot
.832 .46179 Mdot
.832 .46196 Mdot
.832 .46262 Mdot
.832 .46333 Mdot
.832 .4634 Mdot
.832 .46364 Mdot
.832 .46373 Mdot
.832 .46377 Mdot
.832 .46387 Mdot
.832 .46397 Mdot
.832 .46445 Mdot
.832 .46459 Mdot
.832 .46492 Mdot
.832 .46543 Mdot
.832 .46579 Mdot
.832 .46585 Mdot
.832 .46588 Mdot
.832 .46606 Mdot
.832 .46668 Mdot
.832 .46759 Mdot
.832 .46814 Mdot
.832 .46825 Mdot
.832 .4683 Mdot
.832 .46864 Mdot
.832 .46867 Mdot
.832 .46867 Mdot
.832 .46883 Mdot
.832 .46897 Mdot
.832 .46913 Mdot
.832 .46956 Mdot
.832 .46984 Mdot
.832 .47025 Mdot
.832 .47065 Mdot
.832 .47072 Mdot
.832 .47126 Mdot
.832 .47159 Mdot
.832 .47243 Mdot
.832 .47247 Mdot
.832 .47251 Mdot
.832 .47274 Mdot
.832 .47277 Mdot
.832 .47304 Mdot
.832 .47342 Mdot
.832 .47349 Mdot
.832 .47378 Mdot
.832 .47386 Mdot
.832 .47389 Mdot
.832 .474 Mdot
.832 .474 Mdot
.832 .47405 Mdot
.832 .47488 Mdot
.832 .47492 Mdot
.832 .47543 Mdot
.832 .47566 Mdot
.832 .47586 Mdot
.832 .47635 Mdot
.832 .47639 Mdot
.832 .47642 Mdot
.832 .47676 Mdot
.832 .47694 Mdot
.832 .47738 Mdot
.832 .47789 Mdot
.832 .47799 Mdot
.832 .47871 Mdot
.832 .47921 Mdot
.832 .47929 Mdot
.832 .48044 Mdot
.832 .48085 Mdot
.832 .48108 Mdot
.832 .48139 Mdot
.832 .48187 Mdot
.832 .48187 Mdot
.832 .48242 Mdot
.832 .48287 Mdot
.832 .4831 Mdot
.832 .48346 Mdot
.832 .48359 Mdot
.832 .48387 Mdot
.832 .48398 Mdot
.832 .48406 Mdot
.832 .48429 Mdot
.832 .48471 Mdot
.832 .48494 Mdot
.832 .48552 Mdot
.832 .48553 Mdot
.832 .48556 Mdot
.832 .48585 Mdot
.832 .48591 Mdot
.832 .48591 Mdot
.832 .48615 Mdot
.832 .48618 Mdot
.832 .48628 Mdot
.832 .48648 Mdot
.832 .4868 Mdot
.832 .48689 Mdot
.832 .4874 Mdot
.832 .48744 Mdot
.832 .48772 Mdot
.832 .48774 Mdot
.832 .48815 Mdot
.832 .48882 Mdot
.832 .48971 Mdot
.832 .49013 Mdot
.832 .49014 Mdot
.832 .4902 Mdot
.832 .49057 Mdot
.832 .49058 Mdot
.832 .49077 Mdot
.832 .49095 Mdot
.832 .49097 Mdot
.832 .49103 Mdot
.832 .49124 Mdot
.832 .49127 Mdot
.832 .4917 Mdot
.832 .49231 Mdot
.832 .49312 Mdot
.832 .49322 Mdot
.832 .49327 Mdot
.832 .49379 Mdot
.832 .49407 Mdot
.832 .49409 Mdot
.832 .49428 Mdot
.832 .49437 Mdot
.832 .49451 Mdot
.832 .4948 Mdot
.832 .49493 Mdot
.832 .49504 Mdot
.832 .49586 Mdot
.832 .49616 Mdot
.832 .4964 Mdot
.832 .49673 Mdot
.832 .49719 Mdot
.832 .49754 Mdot
.832 .4977 Mdot
.832 .49821 Mdot
.832 .49824 Mdot
.832 .49864 Mdot
.832 .49883 Mdot
.832 .49886 Mdot
.832 .49905 Mdot
.832 .49908 Mdot
.832 .49917 Mdot
.832 .49953 Mdot
.832 .49955 Mdot
.832 .4996 Mdot
.832 .50048 Mdot
.832 .50059 Mdot
.832 .50081 Mdot
.832 .50082 Mdot
.832 .50084 Mdot
.832 .50115 Mdot
.832 .50125 Mdot
.832 .50131 Mdot
.832 .5014 Mdot
.832 .5014 Mdot
.832 .50208 Mdot
.832 .50229 Mdot
.832 .50235 Mdot
.832 .50241 Mdot
.832 .50241 Mdot
.832 .50276 Mdot
.832 .50291 Mdot
.832 .50329 Mdot
.832 .50351 Mdot
.832 .50426 Mdot
.832 .5044 Mdot
.832 .50468 Mdot
.832 .50503 Mdot
.832 .50511 Mdot
.832 .50527 Mdot
.834 .17807 Mdot
.834 .17819 Mdot
.834 .17854 Mdot
.834 .17946 Mdot
.834 .17967 Mdot
.834 .17973 Mdot
.834 .1804 Mdot
.834 .18071 Mdot
.834 .18091 Mdot
.834 .18112 Mdot
.834 .1821 Mdot
.834 .18226 Mdot
.834 .18277 Mdot
.834 .18283 Mdot
.834 .18327 Mdot
.834 .18449 Mdot
.834 .18479 Mdot
.834 .18515 Mdot
.834 .18529 Mdot
.834 .18545 Mdot
.834 .18639 Mdot
.834 .1864 Mdot
.834 .18719 Mdot
.834 .1872 Mdot
.834 .18732 Mdot
.834 .18775 Mdot
.834 .1888 Mdot
.834 .18895 Mdot
.834 .18922 Mdot
.834 .18957 Mdot
.834 .18977 Mdot
.834 .19018 Mdot
.834 .19055 Mdot
.834 .19069 Mdot
.834 .1909 Mdot
.834 .19095 Mdot
.834 .19159 Mdot
.834 .19353 Mdot
.834 .19365 Mdot
.834 .19404 Mdot
.834 .19489 Mdot
.834 .195 Mdot
.834 .19527 Mdot
.834 .19529 Mdot
.834 .19538 Mdot
.834 .19577 Mdot
.834 .19578 Mdot
.834 .19698 Mdot
.834 .19758 Mdot
.834 .19762 Mdot
.834 .1977 Mdot
.834 .19776 Mdot
.834 .19831 Mdot
.834 .19836 Mdot
.834 .19872 Mdot
.834 .1988 Mdot
.834 .19958 Mdot
.834 .19966 Mdot
.834 .20001 Mdot
.834 .20061 Mdot
.834 .2008 Mdot
.834 .20203 Mdot
.834 .20206 Mdot
.834 .20322 Mdot
.834 .20426 Mdot
.834 .2044 Mdot
.834 .20598 Mdot
.834 .20619 Mdot
.834 .20645 Mdot
.834 .20656 Mdot
.834 .20683 Mdot
.834 .20719 Mdot
.834 .20739 Mdot
.834 .20781 Mdot
.834 .2085 Mdot
.834 .20888 Mdot
.834 .20918 Mdot
.834 .20938 Mdot
.834 .20948 Mdot
.834 .20961 Mdot
.834 .20992 Mdot
.834 .21033 Mdot
.834 .21089 Mdot
.834 .21127 Mdot
.834 .21139 Mdot
.834 .21165 Mdot
.834 .21236 Mdot
.834 .21259 Mdot
.834 .21319 Mdot
.834 .21496 Mdot
.834 .21526 Mdot
.834 .21565 Mdot
.834 .21656 Mdot
.834 .21675 Mdot
.834 .21725 Mdot
.834 .21746 Mdot
.834 .21754 Mdot
.834 .21817 Mdot
.834 .21846 Mdot
.834 .21859 Mdot
.834 .21888 Mdot
.834 .2191 Mdot
.834 .2198 Mdot
.834 .22003 Mdot
.834 .22029 Mdot
.834 .22092 Mdot
.834 .22124 Mdot
.834 .22159 Mdot
.834 .22197 Mdot
.834 .22242 Mdot
.834 .22362 Mdot
.834 .22453 Mdot
.834 .22497 Mdot
.834 .22572 Mdot
.834 .22575 Mdot
.834 .22653 Mdot
.834 .22666 Mdot
.834 .2268 Mdot
.834 .22688 Mdot
.834 .22707 Mdot
.834 .22749 Mdot
.834 .22754 Mdot
.834 .22814 Mdot
.834 .22843 Mdot
.834 .22874 Mdot
.834 .229 Mdot
.834 .22965 Mdot
.834 .22981 Mdot
.834 .22985 Mdot
.834 .23139 Mdot
.834 .23219 Mdot
.834 .23298 Mdot
.834 .23317 Mdot
.834 .23327 Mdot
.834 .23329 Mdot
.834 .23373 Mdot
.834 .23425 Mdot
.834 .23456 Mdot
.834 .23575 Mdot
.834 .23698 Mdot
.834 .2375 Mdot
.834 .23765 Mdot
.834 .23775 Mdot
.834 .23791 Mdot
.834 .23827 Mdot
.834 .23827 Mdot
.834 .23849 Mdot
.834 .23868 Mdot
.834 .23976 Mdot
.834 .23983 Mdot
.834 .24013 Mdot
.834 .24066 Mdot
.834 .24116 Mdot
.834 .24223 Mdot
.834 .24276 Mdot
.834 .24317 Mdot
.834 .24499 Mdot
.834 .24546 Mdot
.834 .24592 Mdot
.834 .24597 Mdot
.834 .24709 Mdot
.834 .24718 Mdot
.834 .24721 Mdot
.834 .24721 Mdot
.834 .24765 Mdot
.834 .24859 Mdot
.834 .24889 Mdot
.834 .24892 Mdot
.834 .24917 Mdot
.834 .2506 Mdot
.834 .25149 Mdot
.834 .25153 Mdot
.834 .25154 Mdot
.834 .25246 Mdot
.834 .2529 Mdot
.834 .2529 Mdot
.834 .25324 Mdot
.834 .25345 Mdot
.834 .25368 Mdot
.834 .25424 Mdot
.834 .25494 Mdot
.834 .2552 Mdot
.834 .25592 Mdot
.834 .25666 Mdot
.834 .25717 Mdot
.834 .25837 Mdot
.834 .25846 Mdot
.834 .259 Mdot
.834 .25947 Mdot
.834 .25955 Mdot
.834 .25985 Mdot
.834 .26077 Mdot
.834 .26121 Mdot
.834 .26143 Mdot
.834 .26145 Mdot
.834 .26184 Mdot
.834 .26204 Mdot
.834 .26208 Mdot
.834 .26245 Mdot
.834 .26326 Mdot
.834 .2633 Mdot
.834 .26505 Mdot
.834 .26506 Mdot
.834 .26518 Mdot
.834 .26682 Mdot
.834 .26778 Mdot
.834 .26784 Mdot
.834 .26893 Mdot
.834 .26897 Mdot
.834 .26927 Mdot
.834 .2695 Mdot
.834 .2701 Mdot
.834 .27036 Mdot
.834 .27074 Mdot
.834 .2713 Mdot
.834 .27244 Mdot
.834 .2726 Mdot
.834 .27284 Mdot
.834 .27316 Mdot
.834 .27458 Mdot
.834 .27467 Mdot
.834 .27487 Mdot
.834 .27498 Mdot
.834 .27552 Mdot
.834 .27563 Mdot
.834 .27572 Mdot
.834 .27578 Mdot
.834 .27639 Mdot
.834 .27843 Mdot
.834 .27973 Mdot
.834 .27973 Mdot
.834 .28041 Mdot
.834 .28061 Mdot
.834 .28084 Mdot
.834 .28127 Mdot
.834 .28172 Mdot
.834 .28232 Mdot
.834 .28252 Mdot
.834 .28414 Mdot
.834 .28435 Mdot
.834 .28484 Mdot
.834 .28489 Mdot
.834 .28645 Mdot
.834 .28663 Mdot
.834 .2872 Mdot
.834 .28739 Mdot
.834 .2875 Mdot
.834 .28752 Mdot
.834 .28791 Mdot
.834 .28798 Mdot
.834 .28806 Mdot
.834 .28824 Mdot
.834 .2895 Mdot
.834 .28985 Mdot
.834 .28986 Mdot
.834 .28989 Mdot
.834 .28996 Mdot
.834 .29053 Mdot
.834 .29108 Mdot
.834 .2911 Mdot
.834 .29116 Mdot
.834 .29139 Mdot
.834 .29148 Mdot
.834 .29159 Mdot
.834 .29192 Mdot
.834 .29193 Mdot
.834 .29208 Mdot
.834 .29215 Mdot
.834 .29228 Mdot
.834 .29392 Mdot
.834 .29405 Mdot
.834 .29418 Mdot
.834 .29452 Mdot
.834 .2947 Mdot
.834 .29495 Mdot
.834 .29503 Mdot
.834 .29513 Mdot
.834 .29528 Mdot
.834 .29551 Mdot
.834 .29554 Mdot
.834 .29579 Mdot
.834 .29586 Mdot
.834 .29644 Mdot
.834 .29729 Mdot
.834 .29737 Mdot
.834 .29772 Mdot
.834 .2979 Mdot
.834 .29825 Mdot
.834 .29841 Mdot
.834 .29862 Mdot
.834 .29901 Mdot
.834 .29916 Mdot
.834 .29923 Mdot
.834 .29949 Mdot
.834 .30107 Mdot
.834 .30108 Mdot
.834 .30153 Mdot
.834 .30194 Mdot
.834 .30225 Mdot
.834 .30228 Mdot
.834 .3024 Mdot
.834 .30242 Mdot
.834 .30262 Mdot
.834 .3029 Mdot
.834 .30334 Mdot
.834 .30351 Mdot
.834 .30365 Mdot
.834 .30484 Mdot
.834 .30508 Mdot
.834 .30516 Mdot
.834 .30534 Mdot
.834 .30549 Mdot
.834 .30569 Mdot
.834 .30578 Mdot
.834 .30584 Mdot
.834 .30637 Mdot
.834 .3067 Mdot
.834 .30715 Mdot
.834 .30728 Mdot
.834 .30739 Mdot
.834 .30783 Mdot
.834 .30801 Mdot
.834 .30825 Mdot
.834 .3086 Mdot
.834 .30867 Mdot
.834 .3091 Mdot
.834 .30912 Mdot
.834 .30953 Mdot
.834 .3097 Mdot
.834 .30974 Mdot
.834 .31019 Mdot
.834 .31054 Mdot
.834 .31065 Mdot
.834 .3112 Mdot
.834 .31141 Mdot
.834 .31229 Mdot
.834 .31235 Mdot
.834 .31269 Mdot
.834 .31297 Mdot
.834 .31298 Mdot
.834 .31318 Mdot
.834 .31383 Mdot
.834 .31418 Mdot
.834 .31433 Mdot
.834 .31525 Mdot
.834 .3153 Mdot
.834 .31544 Mdot
.834 .31578 Mdot
.834 .31589 Mdot
.834 .31592 Mdot
.834 .31606 Mdot
.834 .31671 Mdot
.834 .31672 Mdot
.834 .31675 Mdot
.834 .31743 Mdot
.834 .31758 Mdot
.834 .3178 Mdot
.834 .31874 Mdot
.834 .31911 Mdot
.834 .31916 Mdot
.834 .31973 Mdot
.834 .31981 Mdot
.834 .31994 Mdot
.834 .32003 Mdot
.834 .32063 Mdot
.834 .32088 Mdot
.834 .32095 Mdot
.834 .32103 Mdot
.834 .32129 Mdot
.834 .32163 Mdot
.834 .32177 Mdot
.834 .32232 Mdot
.834 .32307 Mdot
.834 .3232 Mdot
.834 .32378 Mdot
.834 .32421 Mdot
.834 .32478 Mdot
.834 .3251 Mdot
.834 .32564 Mdot
.834 .32607 Mdot
.834 .3264 Mdot
.834 .32655 Mdot
.834 .32682 Mdot
.834 .32683 Mdot
.834 .32716 Mdot
.834 .32721 Mdot
.834 .32769 Mdot
.834 .32915 Mdot
.834 .3297 Mdot
.834 .33 Mdot
.834 .33043 Mdot
.834 .33087 Mdot
.834 .33106 Mdot
.834 .33111 Mdot
.834 .33121 Mdot
.834 .33133 Mdot
.834 .33237 Mdot
.834 .3331 Mdot
.834 .33375 Mdot
.834 .33392 Mdot
.834 .33409 Mdot
.834 .3341 Mdot
.834 .33454 Mdot
.834 .33455 Mdot
.834 .3347 Mdot
.834 .33515 Mdot
.834 .33516 Mdot
.834 .33577 Mdot
.834 .33608 Mdot
.834 .3361 Mdot
.834 .3361 Mdot
.834 .33643 Mdot
.834 .33659 Mdot
.834 .33659 Mdot
.834 .33671 Mdot
.834 .33679 Mdot
.834 .33732 Mdot
.834 .33742 Mdot
.834 .33794 Mdot
.834 .33859 Mdot
.834 .33896 Mdot
.834 .33909 Mdot
.834 .33942 Mdot
.834 .33958 Mdot
.834 .33981 Mdot
.834 .33988 Mdot
.834 .33989 Mdot
.834 .34002 Mdot
.834 .34031 Mdot
.834 .34033 Mdot
.834 .34096 Mdot
.834 .341 Mdot
.834 .34159 Mdot
.834 .34194 Mdot
.834 .34196 Mdot
.834 .34236 Mdot
.834 .34237 Mdot
.834 .34248 Mdot
.834 .34256 Mdot
.834 .34277 Mdot
.834 .34287 Mdot
.834 .34321 Mdot
.834 .34438 Mdot
.834 .34449 Mdot
.834 .34476 Mdot
.834 .34479 Mdot
.834 .34503 Mdot
.834 .34577 Mdot
.834 .34623 Mdot
.834 .34648 Mdot
.834 .34663 Mdot
.834 .34717 Mdot
.834 .34724 Mdot
.834 .34782 Mdot
.834 .3479 Mdot
.834 .34807 Mdot
.834 .34872 Mdot
.834 .34904 Mdot
.834 .34918 Mdot
.834 .34923 Mdot
.834 .34987 Mdot
.834 .35032 Mdot
.834 .35034 Mdot
.834 .35062 Mdot
.834 .35068 Mdot
.834 .3507 Mdot
.834 .35138 Mdot
.834 .35171 Mdot
.834 .35183 Mdot
.834 .35191 Mdot
.834 .35192 Mdot
.834 .35201 Mdot
.834 .35224 Mdot
.834 .35255 Mdot
.834 .3527 Mdot
.834 .35289 Mdot
.834 .35303 Mdot
.834 .35322 Mdot
.834 .35407 Mdot
.834 .35456 Mdot
.834 .35478 Mdot
.834 .35483 Mdot
.834 .35526 Mdot
.834 .35538 Mdot
.834 .3555 Mdot
.834 .35557 Mdot
.834 .35562 Mdot
.834 .35633 Mdot
.834 .35679 Mdot
.834 .3568 Mdot
.834 .35701 Mdot
.834 .35719 Mdot
.834 .35762 Mdot
.834 .35808 Mdot
.834 .35867 Mdot
.834 .35902 Mdot
.834 .35919 Mdot
.834 .35979 Mdot
.834 .36041 Mdot
.834 .36117 Mdot
.834 .36154 Mdot
.834 .36289 Mdot
.834 .36301 Mdot
.834 .36307 Mdot
.834 .36316 Mdot
.834 .36317 Mdot
.834 .3643 Mdot
.834 .36468 Mdot
.834 .36474 Mdot
.834 .36478 Mdot
.834 .36542 Mdot
.834 .36577 Mdot
.834 .36662 Mdot
.834 .36667 Mdot
.834 .36672 Mdot
.834 .36697 Mdot
.834 .36752 Mdot
.834 .36802 Mdot
.834 .36824 Mdot
.834 .36847 Mdot
.834 .3686 Mdot
.834 .36875 Mdot
.834 .36875 Mdot
.834 .36893 Mdot
.834 .36951 Mdot
.834 .36962 Mdot
.834 .36971 Mdot
.834 .37014 Mdot
.834 .37028 Mdot
.834 .37071 Mdot
.834 .37074 Mdot
.834 .37115 Mdot
.834 .3712 Mdot
.834 .37161 Mdot
.834 .37162 Mdot
.834 .37171 Mdot
.834 .37174 Mdot
.834 .37215 Mdot
.834 .37246 Mdot
.834 .37265 Mdot
.834 .37323 Mdot
.834 .37349 Mdot
.834 .37356 Mdot
.834 .37377 Mdot
.834 .37401 Mdot
.834 .37473 Mdot
.834 .37564 Mdot
.834 .37613 Mdot
.834 .37617 Mdot
.834 .37619 Mdot
.834 .37679 Mdot
.834 .37681 Mdot
.834 .37747 Mdot
.834 .37759 Mdot
.834 .37779 Mdot
.834 .37823 Mdot
.834 .37851 Mdot
.834 .37878 Mdot
.834 .37895 Mdot
.834 .37909 Mdot
.834 .37926 Mdot
.834 .37931 Mdot
.834 .38004 Mdot
.834 .38012 Mdot
.834 .38038 Mdot
.834 .38091 Mdot
.834 .38141 Mdot
.834 .38232 Mdot
.834 .38311 Mdot
.834 .38339 Mdot
.834 .38382 Mdot
.834 .38429 Mdot
.834 .38545 Mdot
.834 .38561 Mdot
.834 .38631 Mdot
.834 .38658 Mdot
.834 .38674 Mdot
.834 .38701 Mdot
.834 .38713 Mdot
.834 .3876 Mdot
.834 .38761 Mdot
.834 .38797 Mdot
.834 .38798 Mdot
.834 .38829 Mdot
.834 .38884 Mdot
.834 .38927 Mdot
.834 .38942 Mdot
.834 .39009 Mdot
.834 .3902 Mdot
.834 .39064 Mdot
.834 .39071 Mdot
.834 .39071 Mdot
.834 .39099 Mdot
.834 .39124 Mdot
.834 .39151 Mdot
.834 .39159 Mdot
.834 .39197 Mdot
.834 .39243 Mdot
.834 .39243 Mdot
.834 .39316 Mdot
.834 .39349 Mdot
.834 .39371 Mdot
.834 .39421 Mdot
.834 .3948 Mdot
.834 .39483 Mdot
.834 .39509 Mdot
.834 .39578 Mdot
.834 .39583 Mdot
.834 .39587 Mdot
.834 .39594 Mdot
.834 .39675 Mdot
.834 .39826 Mdot
.834 .39882 Mdot
.834 .39947 Mdot
.834 .39959 Mdot
.834 .39987 Mdot
.834 .40022 Mdot
.834 .40033 Mdot
.834 .40037 Mdot
.834 .40044 Mdot
.834 .40077 Mdot
.834 .40174 Mdot
.834 .40205 Mdot
.834 .40232 Mdot
.834 .40246 Mdot
.834 .40252 Mdot
.834 .40252 Mdot
.834 .40257 Mdot
.834 .40325 Mdot
.834 .40326 Mdot
.834 .4033 Mdot
.834 .40346 Mdot
.834 .40347 Mdot
.834 .40416 Mdot
.834 .40424 Mdot
.834 .40482 Mdot
.834 .40493 Mdot
.834 .40497 Mdot
.834 .40532 Mdot
.834 .40537 Mdot
.834 .40569 Mdot
.834 .40578 Mdot
.834 .40593 Mdot
.834 .40664 Mdot
.834 .40679 Mdot
.834 .40697 Mdot
.834 .40794 Mdot
.834 .40818 Mdot
.834 .40824 Mdot
.834 .40825 Mdot
.834 .40849 Mdot
.834 .40871 Mdot
.834 .40909 Mdot
.834 .40946 Mdot
.834 .40965 Mdot
.834 .40973 Mdot
.834 .40974 Mdot
.834 .41029 Mdot
.834 .41121 Mdot
.834 .41127 Mdot
.834 .41163 Mdot
.834 .41171 Mdot
.834 .4118 Mdot
.834 .412 Mdot
.834 .41201 Mdot
.834 .41257 Mdot
.834 .41293 Mdot
.834 .41321 Mdot
.834 .41331 Mdot
.834 .4138 Mdot
.834 .41423 Mdot
.834 .41486 Mdot
.834 .41494 Mdot
.834 .41502 Mdot
.834 .4154 Mdot
.834 .41566 Mdot
.834 .41584 Mdot
.834 .41704 Mdot
.834 .41756 Mdot
.834 .41756 Mdot
.834 .41772 Mdot
.834 .41782 Mdot
.834 .41802 Mdot
.834 .41827 Mdot
.834 .41913 Mdot
.834 .42026 Mdot
.834 .42088 Mdot
.834 .42113 Mdot
.834 .42127 Mdot
.834 .42216 Mdot
.834 .42219 Mdot
.834 .42297 Mdot
.834 .4231 Mdot
.834 .4232 Mdot
.834 .4236 Mdot
.834 .42418 Mdot
.834 .42447 Mdot
.834 .42505 Mdot
.834 .42514 Mdot
.834 .42586 Mdot
.834 .42604 Mdot
.834 .42624 Mdot
.834 .42628 Mdot
.834 .4268 Mdot
.834 .42693 Mdot
.834 .42726 Mdot
.834 .42733 Mdot
.834 .42753 Mdot
.834 .42783 Mdot
.834 .42793 Mdot
.834 .42818 Mdot
.834 .42819 Mdot
.834 .42895 Mdot
.834 .42928 Mdot
.834 .42936 Mdot
.834 .43014 Mdot
.834 .43023 Mdot
.834 .43035 Mdot
.834 .43055 Mdot
.834 .43074 Mdot
.834 .43146 Mdot
.834 .43154 Mdot
.834 .43191 Mdot
.834 .43228 Mdot
.834 .4323 Mdot
.834 .43248 Mdot
.834 .43273 Mdot
.834 .43415 Mdot
.834 .43447 Mdot
.834 .43469 Mdot
.834 .43501 Mdot
.834 .43522 Mdot
.834 .43527 Mdot
.834 .43578 Mdot
.834 .43617 Mdot
.834 .43632 Mdot
.834 .43634 Mdot
.834 .43647 Mdot
.834 .43667 Mdot
.834 .43682 Mdot
.834 .43693 Mdot
.834 .43721 Mdot
.834 .43835 Mdot
.834 .43839 Mdot
.834 .43849 Mdot
.834 .43875 Mdot
.834 .43881 Mdot
.834 .43895 Mdot
.834 .43898 Mdot
.834 .43932 Mdot
.834 .4397 Mdot
.834 .43973 Mdot
.834 .44069 Mdot
.834 .4408 Mdot
.834 .44089 Mdot
.834 .44112 Mdot
.834 .44114 Mdot
.834 .44166 Mdot
.834 .44177 Mdot
.834 .4427 Mdot
.834 .44273 Mdot
.834 .44303 Mdot
.834 .44315 Mdot
.834 .44412 Mdot
.834 .44424 Mdot
.834 .44461 Mdot
.834 .44487 Mdot
.834 .44513 Mdot
.834 .44527 Mdot
.834 .44539 Mdot
.834 .44579 Mdot
.834 .4458 Mdot
.834 .44658 Mdot
.834 .4478 Mdot
.834 .44817 Mdot
.834 .4482 Mdot
.834 .44825 Mdot
.834 .44832 Mdot
.834 .44865 Mdot
.834 .44871 Mdot
.834 .44883 Mdot
.834 .44888 Mdot
.834 .44974 Mdot
.834 .44993 Mdot
.834 .45007 Mdot
.834 .45016 Mdot
.834 .45085 Mdot
.834 .45118 Mdot
.834 .45141 Mdot
.834 .45157 Mdot
.834 .45193 Mdot
.834 .45206 Mdot
.834 .45225 Mdot
.834 .45227 Mdot
.834 .45292 Mdot
.834 .45296 Mdot
.834 .45354 Mdot
.834 .45452 Mdot
.834 .45459 Mdot
.834 .45459 Mdot
.834 .45565 Mdot
.834 .45567 Mdot
.834 .45616 Mdot
.834 .45637 Mdot
.834 .4564 Mdot
.834 .45652 Mdot
.834 .45675 Mdot
.834 .45677 Mdot
.834 .4569 Mdot
.834 .45716 Mdot
.834 .45771 Mdot
.834 .45789 Mdot
.834 .45794 Mdot
.834 .45822 Mdot
.834 .45855 Mdot
.834 .4586 Mdot
.834 .45932 Mdot
.834 .45963 Mdot
.834 .46007 Mdot
.834 .46051 Mdot
.834 .46066 Mdot
.834 .46108 Mdot
.834 .46141 Mdot
.834 .46155 Mdot
.834 .46168 Mdot
.834 .46188 Mdot
.834 .46188 Mdot
.834 .46215 Mdot
.834 .4627 Mdot
.834 .4627 Mdot
.834 .46273 Mdot
.834 .46326 Mdot
.834 .46412 Mdot
.834 .46427 Mdot
.834 .46428 Mdot
.834 .46446 Mdot
.834 .46503 Mdot
.834 .46529 Mdot
.834 .46529 Mdot
.834 .46531 Mdot
.834 .46536 Mdot
.834 .46604 Mdot
.834 .46606 Mdot
.834 .46634 Mdot
.834 .46662 Mdot
.834 .46771 Mdot
.834 .46796 Mdot
.834 .46828 Mdot
.834 .46892 Mdot
.834 .46922 Mdot
.834 .46953 Mdot
.834 .46972 Mdot
.834 .46976 Mdot
.834 .4704 Mdot
.834 .47052 Mdot
.834 .47065 Mdot
.834 .47065 Mdot
.834 .47087 Mdot
.834 .47096 Mdot
.834 .47102 Mdot
.834 .47112 Mdot
.834 .47143 Mdot
.834 .47217 Mdot
.834 .47288 Mdot
.834 .47306 Mdot
.834 .47337 Mdot
.834 .47364 Mdot
.834 .47365 Mdot
.834 .47371 Mdot
.834 .47382 Mdot
.834 .4743 Mdot
.834 .47478 Mdot
.834 .4757 Mdot
.834 .47572 Mdot
.834 .47582 Mdot
.834 .47621 Mdot
.834 .47636 Mdot
.834 .47655 Mdot
.834 .47672 Mdot
.834 .47708 Mdot
.834 .47712 Mdot
.834 .47736 Mdot
.834 .47748 Mdot
.834 .47753 Mdot
.834 .47761 Mdot
.834 .47769 Mdot
.834 .47816 Mdot
.834 .47818 Mdot
.834 .47863 Mdot
.834 .47889 Mdot
.834 .47944 Mdot
.834 .48015 Mdot
.834 .48043 Mdot
.834 .48065 Mdot
.834 .48086 Mdot
.834 .48105 Mdot
.834 .48143 Mdot
.834 .48159 Mdot
.834 .48173 Mdot
.834 .48215 Mdot
.834 .48228 Mdot
.834 .48245 Mdot
.834 .48253 Mdot
.834 .48271 Mdot
.834 .48308 Mdot
.834 .48313 Mdot
.834 .48325 Mdot
.834 .48355 Mdot
.834 .48367 Mdot
.834 .48421 Mdot
.834 .48444 Mdot
.834 .48463 Mdot
.834 .48569 Mdot
.834 .48605 Mdot
.834 .48619 Mdot
.834 .48661 Mdot
.834 .48677 Mdot
.834 .48684 Mdot
.834 .48707 Mdot
.834 .4874 Mdot
.834 .48765 Mdot
.834 .48783 Mdot
.834 .48791 Mdot
.834 .48797 Mdot
.834 .48809 Mdot
.834 .48827 Mdot
.834 .4885 Mdot
.834 .48892 Mdot
.834 .48916 Mdot
.834 .48928 Mdot
.834 .4895 Mdot
.834 .48967 Mdot
.834 .48973 Mdot
.834 .48988 Mdot
.834 .49001 Mdot
.834 .49096 Mdot
.834 .49104 Mdot
.834 .49166 Mdot
.834 .49236 Mdot
.834 .49238 Mdot
.834 .49312 Mdot
.834 .49323 Mdot
.834 .49359 Mdot
.834 .4938 Mdot
.834 .49385 Mdot
.834 .49432 Mdot
.834 .49437 Mdot
.834 .49458 Mdot
.834 .49461 Mdot
.834 .49494 Mdot
.834 .49497 Mdot
.834 .49502 Mdot
.834 .49505 Mdot
.834 .4954 Mdot
.834 .49613 Mdot
.834 .49613 Mdot
.834 .49637 Mdot
.834 .49642 Mdot
.834 .49643 Mdot
.834 .49659 Mdot
.834 .49666 Mdot
.834 .49717 Mdot
.834 .4974 Mdot
.834 .49747 Mdot
.834 .49864 Mdot
.834 .49902 Mdot
.834 .49905 Mdot
.834 .49918 Mdot
.834 .49926 Mdot
.834 .49948 Mdot
.834 .49973 Mdot
.834 .49985 Mdot
.834 .50006 Mdot
.834 .50022 Mdot
.834 .50031 Mdot
.834 .50094 Mdot
.834 .5012 Mdot
.834 .50127 Mdot
.834 .50128 Mdot
.834 .50175 Mdot
.834 .50175 Mdot
.834 .50232 Mdot
.834 .50242 Mdot
.834 .5025 Mdot
.834 .50271 Mdot
.834 .50289 Mdot
.834 .50363 Mdot
.834 .50389 Mdot
.834 .50393 Mdot
.834 .50423 Mdot
.834 .50433 Mdot
.834 .50491 Mdot
.834 .50504 Mdot
.834 .50516 Mdot
.834 .50534 Mdot
.834 .50575 Mdot
.834 .50579 Mdot
.834 .50591 Mdot
.834 .50646 Mdot
.834 .50667 Mdot
.834 .50674 Mdot
.836 .17681 Mdot
.836 .1777 Mdot
.836 .1782 Mdot
.836 .17849 Mdot
.836 .17968 Mdot
.836 .17976 Mdot
.836 .18089 Mdot
.836 .18123 Mdot
.836 .18162 Mdot
.836 .18239 Mdot
.836 .18257 Mdot
.836 .18258 Mdot
.836 .18289 Mdot
.836 .18309 Mdot
.836 .18316 Mdot
.836 .18322 Mdot
.836 .18334 Mdot
.836 .18344 Mdot
.836 .1837 Mdot
.836 .18382 Mdot
.836 .18431 Mdot
.836 .18477 Mdot
.836 .18485 Mdot
.836 .18527 Mdot
.836 .18633 Mdot
.836 .18635 Mdot
.836 .1877 Mdot
.836 .18833 Mdot
.836 .18846 Mdot
.836 .1886 Mdot
.836 .18903 Mdot
.836 .1896 Mdot
.836 .18967 Mdot
.836 .18973 Mdot
.836 .19121 Mdot
.836 .1914 Mdot
.836 .19208 Mdot
.836 .19244 Mdot
.836 .19258 Mdot
.836 .19373 Mdot
.836 .19396 Mdot
.836 .19429 Mdot
.836 .19529 Mdot
.836 .19587 Mdot
.836 .19594 Mdot
.836 .19697 Mdot
.836 .19774 Mdot
.836 .1986 Mdot
.836 .19886 Mdot
.836 .19895 Mdot
.836 .19899 Mdot
.836 .19927 Mdot
.836 .19989 Mdot
.836 .19991 Mdot
.836 .20086 Mdot
.836 .20105 Mdot
.836 .20235 Mdot
.836 .20247 Mdot
.836 .20336 Mdot
.836 .20341 Mdot
.836 .20347 Mdot
.836 .20373 Mdot
.836 .20376 Mdot
.836 .20393 Mdot
.836 .20394 Mdot
.836 .20477 Mdot
.836 .20585 Mdot
.836 .20588 Mdot
.836 .20595 Mdot
.836 .20611 Mdot
.836 .20616 Mdot
.836 .20626 Mdot
.836 .20732 Mdot
.836 .20838 Mdot
.836 .20839 Mdot
.836 .20841 Mdot
.836 .20886 Mdot
.836 .20926 Mdot
.836 .2094 Mdot
.836 .20964 Mdot
.836 .21069 Mdot
.836 .2107 Mdot
.836 .21127 Mdot
.836 .21134 Mdot
.836 .21149 Mdot
.836 .21193 Mdot
.836 .21246 Mdot
.836 .21257 Mdot
.836 .21269 Mdot
.836 .21273 Mdot
.836 .21294 Mdot
.836 .21299 Mdot
.836 .21301 Mdot
.836 .21318 Mdot
.836 .21336 Mdot
.836 .21348 Mdot
.836 .21379 Mdot
.836 .2141 Mdot
.836 .21413 Mdot
.836 .21417 Mdot
.836 .21448 Mdot
.836 .21502 Mdot
.836 .21503 Mdot
.836 .21522 Mdot
.836 .21561 Mdot
.836 .21632 Mdot
.836 .21649 Mdot
.836 .21656 Mdot
.836 .21659 Mdot
.836 .21664 Mdot
.836 .21675 Mdot
.836 .21737 Mdot
.836 .21738 Mdot
.836 .21739 Mdot
.836 .21747 Mdot
.836 .21755 Mdot
.836 .21766 Mdot
.836 .21807 Mdot
.836 .21815 Mdot
.836 .21979 Mdot
.836 .22098 Mdot
.836 .22169 Mdot
.836 .22191 Mdot
.836 .22208 Mdot
.836 .22241 Mdot
.836 .22282 Mdot
.836 .22283 Mdot
.836 .22387 Mdot
.836 .22403 Mdot
.836 .22441 Mdot
.836 .2289 Mdot
.836 .22912 Mdot
.836 .22947 Mdot
.836 .22966 Mdot
.836 .22967 Mdot
.836 .23006 Mdot
.836 .23174 Mdot
.836 .23321 Mdot
.836 .2336 Mdot
.836 .23382 Mdot
.836 .23394 Mdot
.836 .23414 Mdot
.836 .23428 Mdot
.836 .23536 Mdot
.836 .23546 Mdot
.836 .2356 Mdot
.836 .23627 Mdot
.836 .23633 Mdot
.836 .23676 Mdot
.836 .23682 Mdot
.836 .23696 Mdot
.836 .23724 Mdot
.836 .23837 Mdot
.836 .23883 Mdot
.836 .23885 Mdot
.836 .23931 Mdot
.836 .24018 Mdot
.836 .2404 Mdot
.836 .24107 Mdot
.836 .24112 Mdot
.836 .24335 Mdot
.836 .24338 Mdot
.836 .24348 Mdot
.836 .24389 Mdot
.836 .24449 Mdot
.836 .24524 Mdot
.836 .24538 Mdot
.836 .24573 Mdot
.836 .24579 Mdot
.836 .24607 Mdot
.836 .24648 Mdot
.836 .24669 Mdot
.836 .24718 Mdot
.836 .24793 Mdot
.836 .24796 Mdot
.836 .24881 Mdot
.836 .25141 Mdot
.836 .25212 Mdot
.836 .25291 Mdot
.836 .25407 Mdot
.836 .25413 Mdot
.836 .25427 Mdot
.836 .25689 Mdot
.836 .25709 Mdot
.836 .25712 Mdot
.836 .25723 Mdot
.836 .25797 Mdot
.836 .25853 Mdot
.836 .2586 Mdot
.836 .25933 Mdot
.836 .25964 Mdot
.836 .25977 Mdot
.836 .26092 Mdot
.836 .26119 Mdot
.836 .26129 Mdot
.836 .26183 Mdot
.836 .26245 Mdot
.836 .26299 Mdot
.836 .26305 Mdot
.836 .26331 Mdot
.836 .26395 Mdot
.836 .26496 Mdot
.836 .26504 Mdot
.836 .26626 Mdot
.836 .26672 Mdot
.836 .26728 Mdot
.836 .2673 Mdot
.836 .26783 Mdot
.836 .26788 Mdot
.836 .26792 Mdot
.836 .26885 Mdot
.836 .27031 Mdot
.836 .2706 Mdot
.836 .27091 Mdot
.836 .27163 Mdot
.836 .27367 Mdot
.836 .27614 Mdot
.836 .27666 Mdot
.836 .27702 Mdot
.836 .27721 Mdot
.836 .27722 Mdot
.836 .27742 Mdot
.836 .27802 Mdot
.836 .27841 Mdot
.836 .27864 Mdot
.836 .27873 Mdot
.836 .27949 Mdot
.836 .27991 Mdot
.836 .28035 Mdot
.836 .28093 Mdot
.836 .28187 Mdot
.836 .28236 Mdot
.836 .2829 Mdot
.836 .28382 Mdot
.836 .28413 Mdot
.836 .28491 Mdot
.836 .28559 Mdot
.836 .28573 Mdot
.836 .28578 Mdot
.836 .28658 Mdot
.836 .2866 Mdot
.836 .28683 Mdot
.836 .28723 Mdot
.836 .28807 Mdot
.836 .28812 Mdot
.836 .28813 Mdot
.836 .28855 Mdot
.836 .28902 Mdot
.836 .2894 Mdot
.836 .29053 Mdot
.836 .29067 Mdot
.836 .29068 Mdot
.836 .29087 Mdot
.836 .29255 Mdot
.836 .29269 Mdot
.836 .29312 Mdot
.836 .29327 Mdot
.836 .29339 Mdot
.836 .29353 Mdot
.836 .29378 Mdot
.836 .29421 Mdot
.836 .29497 Mdot
.836 .29501 Mdot
.836 .29506 Mdot
.836 .29507 Mdot
.836 .29533 Mdot
.836 .29535 Mdot
.836 .29536 Mdot
.836 .29539 Mdot
.836 .29545 Mdot
.836 .2957 Mdot
.836 .29591 Mdot
.836 .29622 Mdot
.836 .29624 Mdot
.836 .29635 Mdot
.836 .29646 Mdot
.836 .29651 Mdot
.836 .29663 Mdot
.836 .29666 Mdot
.836 .29683 Mdot
.836 .29725 Mdot
.836 .29746 Mdot
.836 .29746 Mdot
.836 .29792 Mdot
.836 .29812 Mdot
.836 .29829 Mdot
.836 .29905 Mdot
.836 .29908 Mdot
.836 .29916 Mdot
.836 .29918 Mdot
.836 .29919 Mdot
.836 .29958 Mdot
.836 .29988 Mdot
.836 .29994 Mdot
.836 .30004 Mdot
.836 .3004 Mdot
.836 .30044 Mdot
.836 .30091 Mdot
.836 .30132 Mdot
.836 .30133 Mdot
.836 .30155 Mdot
.836 .30165 Mdot
.836 .30169 Mdot
.836 .30237 Mdot
.836 .30274 Mdot
.836 .30353 Mdot
.836 .30394 Mdot
.836 .30399 Mdot
.836 .30412 Mdot
.836 .30436 Mdot
.836 .30496 Mdot
.836 .30501 Mdot
.836 .30521 Mdot
.836 .30546 Mdot
.836 .30617 Mdot
.836 .30618 Mdot
.836 .30673 Mdot
.836 .3069 Mdot
.836 .30707 Mdot
.836 .30712 Mdot
.836 .30721 Mdot
.836 .30725 Mdot
.836 .30733 Mdot
.836 .3074 Mdot
.836 .30752 Mdot
.836 .30786 Mdot
.836 .30856 Mdot
.836 .30981 Mdot
.836 .31013 Mdot
.836 .31031 Mdot
.836 .31041 Mdot
.836 .31087 Mdot
.836 .31127 Mdot
.836 .31139 Mdot
.836 .31181 Mdot
.836 .31187 Mdot
.836 .31208 Mdot
.836 .31211 Mdot
.836 .31269 Mdot
.836 .31284 Mdot
.836 .31371 Mdot
.836 .31398 Mdot
.836 .31403 Mdot
.836 .31441 Mdot
.836 .31496 Mdot
.836 .31595 Mdot
.836 .31606 Mdot
.836 .31642 Mdot
.836 .31663 Mdot
.836 .3173 Mdot
.836 .3176 Mdot
.836 .31773 Mdot
.836 .31841 Mdot
.836 .31931 Mdot
.836 .31933 Mdot
.836 .31944 Mdot
.836 .31952 Mdot
.836 .32029 Mdot
.836 .32073 Mdot
.836 .32111 Mdot
.836 .32112 Mdot
.836 .32142 Mdot
.836 .32156 Mdot
.836 .32216 Mdot
.836 .32222 Mdot
.836 .32237 Mdot
.836 .3226 Mdot
.836 .32265 Mdot
.836 .32266 Mdot
.836 .32276 Mdot
.836 .32282 Mdot
.836 .32316 Mdot
.836 .32329 Mdot
.836 .32348 Mdot
.836 .32355 Mdot
.836 .3241 Mdot
.836 .32433 Mdot
.836 .32436 Mdot
.836 .32457 Mdot
.836 .3246 Mdot
.836 .32594 Mdot
.836 .32627 Mdot
.836 .32664 Mdot
.836 .32844 Mdot
.836 .32865 Mdot
.836 .32946 Mdot
.836 .33012 Mdot
.836 .33021 Mdot
.836 .33025 Mdot
.836 .33032 Mdot
.836 .33076 Mdot
.836 .33079 Mdot
.836 .33108 Mdot
.836 .3311 Mdot
.836 .33143 Mdot
.836 .33183 Mdot
.836 .332 Mdot
.836 .332 Mdot
.836 .33248 Mdot
.836 .33362 Mdot
.836 .33402 Mdot
.836 .33429 Mdot
.836 .33434 Mdot
.836 .33447 Mdot
.836 .33459 Mdot
.836 .33473 Mdot
.836 .33481 Mdot
.836 .33498 Mdot
.836 .33525 Mdot
.836 .33675 Mdot
.836 .33745 Mdot
.836 .33747 Mdot
.836 .33853 Mdot
.836 .33854 Mdot
.836 .33858 Mdot
.836 .33884 Mdot
.836 .33907 Mdot
.836 .33933 Mdot
.836 .33944 Mdot
.836 .34 Mdot
.836 .34003 Mdot
.836 .34022 Mdot
.836 .34045 Mdot
.836 .34064 Mdot
.836 .34134 Mdot
.836 .34181 Mdot
.836 .34239 Mdot
.836 .3424 Mdot
.836 .34336 Mdot
.836 .34347 Mdot
.836 .34373 Mdot
.836 .34446 Mdot
.836 .34534 Mdot
.836 .34553 Mdot
.836 .34566 Mdot
.836 .34573 Mdot
.836 .3458 Mdot
.836 .34602 Mdot
.836 .34615 Mdot
.836 .34624 Mdot
.836 .34627 Mdot
.836 .34654 Mdot
.836 .34669 Mdot
.836 .34685 Mdot
.836 .34706 Mdot
.836 .34739 Mdot
.836 .34757 Mdot
.836 .34809 Mdot
.836 .34814 Mdot
.836 .3482 Mdot
.836 .34872 Mdot
.836 .34908 Mdot
.836 .34917 Mdot
.836 .34963 Mdot
.836 .34963 Mdot
.836 .34995 Mdot
.836 .35009 Mdot
.836 .35061 Mdot
.836 .35126 Mdot
.836 .35181 Mdot
.836 .35208 Mdot
.836 .35221 Mdot
.836 .35221 Mdot
.836 .35225 Mdot
.836 .35234 Mdot
.836 .35252 Mdot
.836 .35263 Mdot
.836 .35297 Mdot
.836 .3532 Mdot
.836 .35355 Mdot
.836 .35358 Mdot
.836 .35359 Mdot
.836 .35373 Mdot
.836 .35386 Mdot
.836 .35389 Mdot
.836 .35402 Mdot
.836 .35404 Mdot
.836 .3542 Mdot
.836 .35435 Mdot
.836 .35473 Mdot
.836 .35486 Mdot
.836 .35514 Mdot
.836 .35531 Mdot
.836 .35535 Mdot
.836 .35565 Mdot
.836 .35629 Mdot
.836 .35646 Mdot
.836 .35653 Mdot
.836 .35657 Mdot
.836 .35669 Mdot
.836 .3576 Mdot
.836 .35777 Mdot
.836 .35795 Mdot
.836 .35842 Mdot
.836 .35878 Mdot
.836 .35888 Mdot
.836 .35958 Mdot
.836 .36046 Mdot
.836 .36078 Mdot
.836 .36114 Mdot
.836 .36143 Mdot
.836 .36154 Mdot
.836 .36159 Mdot
.836 .36183 Mdot
.836 .36188 Mdot
.836 .36198 Mdot
.836 .36198 Mdot
.836 .36267 Mdot
.836 .36268 Mdot
.836 .36341 Mdot
.836 .36442 Mdot
.836 .3647 Mdot
.836 .36532 Mdot
.836 .36591 Mdot
.836 .36605 Mdot
.836 .36625 Mdot
.836 .36728 Mdot
.836 .36777 Mdot
.836 .36785 Mdot
.836 .3682 Mdot
.836 .36835 Mdot
.836 .36867 Mdot
.836 .36883 Mdot
.836 .37021 Mdot
.836 .37034 Mdot
.836 .37083 Mdot
.836 .37256 Mdot
.836 .37282 Mdot
.836 .37316 Mdot
.836 .3732 Mdot
.836 .37327 Mdot
.836 .37368 Mdot
.836 .37378 Mdot
.836 .37407 Mdot
.836 .3741 Mdot
.836 .37411 Mdot
.836 .37454 Mdot
.836 .37461 Mdot
.836 .37477 Mdot
.836 .37494 Mdot
.836 .37589 Mdot
.836 .37599 Mdot
.836 .37656 Mdot
.836 .37745 Mdot
.836 .3775 Mdot
.836 .37758 Mdot
.836 .37794 Mdot
.836 .37812 Mdot
.836 .37815 Mdot
.836 .37844 Mdot
.836 .3785 Mdot
.836 .37904 Mdot
.836 .37983 Mdot
.836 .38005 Mdot
.836 .38023 Mdot
.836 .38037 Mdot
.836 .38068 Mdot
.836 .38106 Mdot
.836 .38126 Mdot
.836 .38158 Mdot
.836 .3816 Mdot
.836 .38176 Mdot
.836 .38182 Mdot
.836 .38183 Mdot
.836 .38194 Mdot
.836 .38196 Mdot
.836 .38315 Mdot
.836 .38319 Mdot
.836 .38319 Mdot
.836 .38362 Mdot
.836 .38363 Mdot
.836 .38364 Mdot
.836 .38379 Mdot
.836 .38403 Mdot
.836 .38404 Mdot
.836 .3843 Mdot
.836 .3843 Mdot
.836 .38432 Mdot
.836 .38504 Mdot
.836 .38505 Mdot
.836 .38512 Mdot
.836 .38515 Mdot
.836 .38526 Mdot
.836 .38598 Mdot
.836 .38607 Mdot
.836 .38631 Mdot
.836 .38678 Mdot
.836 .3871 Mdot
.836 .38714 Mdot
.836 .38731 Mdot
.836 .38733 Mdot
.836 .38744 Mdot
.836 .3877 Mdot
.836 .38773 Mdot
.836 .38826 Mdot
.836 .3886 Mdot
.836 .38866 Mdot
.836 .38923 Mdot
.836 .38943 Mdot
.836 .38947 Mdot
.836 .38975 Mdot
.836 .38999 Mdot
.836 .39023 Mdot
.836 .3903 Mdot
.836 .39066 Mdot
.836 .39169 Mdot
.836 .39198 Mdot
.836 .39206 Mdot
.836 .39289 Mdot
.836 .39298 Mdot
.836 .39318 Mdot
.836 .39327 Mdot
.836 .39347 Mdot
.836 .39352 Mdot
.836 .39381 Mdot
.836 .39443 Mdot
.836 .39455 Mdot
.836 .39464 Mdot
.836 .39613 Mdot
.836 .39698 Mdot
.836 .39704 Mdot
.836 .39708 Mdot
.836 .39722 Mdot
.836 .39725 Mdot
.836 .39789 Mdot
.836 .39884 Mdot
.836 .3989 Mdot
.836 .39911 Mdot
.836 .39939 Mdot
.836 .3995 Mdot
.836 .40015 Mdot
.836 .40022 Mdot
.836 .40025 Mdot
.836 .40029 Mdot
.836 .40039 Mdot
.836 .40077 Mdot
.836 .40095 Mdot
.836 .40098 Mdot
.836 .40107 Mdot
.836 .40155 Mdot
.836 .40163 Mdot
.836 .40174 Mdot
.836 .40182 Mdot
.836 .40223 Mdot
.836 .40237 Mdot
.836 .40258 Mdot
.836 .40282 Mdot
.836 .40339 Mdot
.836 .40465 Mdot
.836 .4047 Mdot
.836 .40571 Mdot
.836 .40613 Mdot
.836 .40653 Mdot
.836 .40675 Mdot
.836 .40905 Mdot
.836 .40933 Mdot
.836 .40986 Mdot
.836 .41011 Mdot
.836 .41046 Mdot
.836 .41069 Mdot
.836 .41082 Mdot
.836 .41164 Mdot
.836 .41166 Mdot
.836 .41297 Mdot
.836 .41337 Mdot
.836 .41371 Mdot
.836 .41394 Mdot
.836 .41491 Mdot
.836 .41492 Mdot
.836 .41501 Mdot
.836 .41526 Mdot
.836 .41596 Mdot
.836 .41643 Mdot
.836 .41812 Mdot
.836 .41934 Mdot
.836 .41936 Mdot
.836 .41964 Mdot
.836 .41997 Mdot
.836 .42001 Mdot
.836 .4202 Mdot
.836 .4205 Mdot
.836 .42051 Mdot
.836 .42067 Mdot
.836 .42076 Mdot
.836 .42116 Mdot
.836 .42124 Mdot
.836 .42142 Mdot
.836 .42143 Mdot
.836 .42192 Mdot
.836 .42238 Mdot
.836 .42249 Mdot
.836 .42251 Mdot
.836 .42304 Mdot
.836 .42371 Mdot
.836 .42423 Mdot
.836 .42445 Mdot
.836 .42452 Mdot
.836 .42569 Mdot
.836 .42586 Mdot
.836 .42637 Mdot
.836 .42646 Mdot
.836 .42683 Mdot
.836 .42699 Mdot
.836 .42724 Mdot
.836 .42755 Mdot
.836 .42782 Mdot
.836 .42789 Mdot
.836 .42894 Mdot
.836 .42935 Mdot
.836 .42956 Mdot
.836 .42962 Mdot
.836 .42974 Mdot
.836 .42982 Mdot
.836 .42993 Mdot
.836 .43003 Mdot
.836 .43036 Mdot
.836 .43109 Mdot
.836 .43144 Mdot
.836 .43159 Mdot
.836 .43167 Mdot
.836 .43194 Mdot
.836 .43242 Mdot
.836 .43264 Mdot
.836 .43313 Mdot
.836 .43326 Mdot
.836 .43326 Mdot
.836 .43351 Mdot
.836 .43379 Mdot
.836 .43381 Mdot
.836 .43403 Mdot
.836 .43409 Mdot
.836 .4343 Mdot
.836 .43453 Mdot
.836 .43456 Mdot
.836 .4346 Mdot
.836 .43518 Mdot
.836 .43529 Mdot
.836 .43557 Mdot
.836 .43607 Mdot
.836 .43614 Mdot
.836 .43631 Mdot
.836 .43662 Mdot
.836 .43678 Mdot
.836 .43683 Mdot
.836 .43684 Mdot
.836 .437 Mdot
.836 .43704 Mdot
.836 .43706 Mdot
.836 .43752 Mdot
.836 .43793 Mdot
.836 .43801 Mdot
.836 .43808 Mdot
.836 .43843 Mdot
.836 .43951 Mdot
.836 .43963 Mdot
.836 .44039 Mdot
.836 .44062 Mdot
.836 .44115 Mdot
.836 .44116 Mdot
.836 .44193 Mdot
.836 .44207 Mdot
.836 .44208 Mdot
.836 .44256 Mdot
.836 .44267 Mdot
.836 .44308 Mdot
.836 .44354 Mdot
.836 .44364 Mdot
.836 .44373 Mdot
.836 .44428 Mdot
.836 .4446 Mdot
.836 .44489 Mdot
.836 .44546 Mdot
.836 .44581 Mdot
.836 .44607 Mdot
.836 .44632 Mdot
.836 .44677 Mdot
.836 .44683 Mdot
.836 .44697 Mdot
.836 .4472 Mdot
.836 .44756 Mdot
.836 .44768 Mdot
.836 .44768 Mdot
.836 .4478 Mdot
.836 .44801 Mdot
.836 .44833 Mdot
.836 .4498 Mdot
.836 .45102 Mdot
.836 .45145 Mdot
.836 .45164 Mdot
.836 .45181 Mdot
.836 .45268 Mdot
.836 .45324 Mdot
.836 .45326 Mdot
.836 .45329 Mdot
.836 .45361 Mdot
.836 .45362 Mdot
.836 .45396 Mdot
.836 .45423 Mdot
.836 .45496 Mdot
.836 .45501 Mdot
.836 .45561 Mdot
.836 .456 Mdot
.836 .45615 Mdot
.836 .45619 Mdot
.836 .45651 Mdot
.836 .45688 Mdot
.836 .4572 Mdot
.836 .45726 Mdot
.836 .45742 Mdot
.836 .45811 Mdot
.836 .45819 Mdot
.836 .45838 Mdot
.836 .45881 Mdot
.836 .45885 Mdot
.836 .45919 Mdot
.836 .45963 Mdot
.836 .4597 Mdot
.836 .45972 Mdot
.836 .45983 Mdot
.836 .4614 Mdot
.836 .46149 Mdot
.836 .46152 Mdot
.836 .46222 Mdot
.836 .46269 Mdot
.836 .46312 Mdot
.836 .46467 Mdot
.836 .46518 Mdot
.836 .4652 Mdot
.836 .46564 Mdot
.836 .46594 Mdot
.836 .46606 Mdot
.836 .46631 Mdot
.836 .46647 Mdot
.836 .46651 Mdot
.836 .46672 Mdot
.836 .46681 Mdot
.836 .46725 Mdot
.836 .46761 Mdot
.836 .46785 Mdot
.836 .46792 Mdot
.836 .46794 Mdot
.836 .46927 Mdot
.836 .4693 Mdot
.836 .4697 Mdot
.836 .46983 Mdot
.836 .47035 Mdot
.836 .47062 Mdot
.836 .47064 Mdot
.836 .47091 Mdot
.836 .47159 Mdot
.836 .47176 Mdot
.836 .47184 Mdot
.836 .47187 Mdot
.836 .47213 Mdot
.836 .47217 Mdot
.836 .47257 Mdot
.836 .47266 Mdot
.836 .47271 Mdot
.836 .47336 Mdot
.836 .47344 Mdot
.836 .47356 Mdot
.836 .47363 Mdot
.836 .47377 Mdot
.836 .474 Mdot
.836 .47488 Mdot
.836 .47588 Mdot
.836 .47612 Mdot
.836 .47612 Mdot
.836 .47624 Mdot
.836 .47644 Mdot
.836 .47658 Mdot
.836 .47926 Mdot
.836 .47949 Mdot
.836 .47959 Mdot
.836 .48021 Mdot
.836 .48021 Mdot
.836 .48046 Mdot
.836 .48066 Mdot
.836 .48076 Mdot
.836 .48089 Mdot
.836 .48132 Mdot
.836 .48202 Mdot
.836 .48301 Mdot
.836 .48305 Mdot
.836 .4833 Mdot
.836 .48336 Mdot
.836 .48341 Mdot
.836 .48346 Mdot
.836 .48346 Mdot
.836 .48347 Mdot
.836 .48384 Mdot
.836 .48391 Mdot
.836 .48394 Mdot
.836 .48395 Mdot
.836 .484 Mdot
.836 .4841 Mdot
.836 .48453 Mdot
.836 .48476 Mdot
.836 .48488 Mdot
.836 .48488 Mdot
.836 .4852 Mdot
.836 .48539 Mdot
.836 .48541 Mdot
.836 .48543 Mdot
.836 .48561 Mdot
.836 .4858 Mdot
.836 .48587 Mdot
.836 .48598 Mdot
.836 .48608 Mdot
.836 .48609 Mdot
.836 .48612 Mdot
.836 .48625 Mdot
.836 .48627 Mdot
.836 .48634 Mdot
.836 .48641 Mdot
.836 .48673 Mdot
.836 .48699 Mdot
.836 .48708 Mdot
.836 .48712 Mdot
.836 .48746 Mdot
.836 .48747 Mdot
.836 .48809 Mdot
.836 .48824 Mdot
.836 .48832 Mdot
.836 .48856 Mdot
.836 .48883 Mdot
.836 .48884 Mdot
.836 .48885 Mdot
.836 .48948 Mdot
.836 .49012 Mdot
.836 .49018 Mdot
.836 .4902 Mdot
.836 .4903 Mdot
.836 .49035 Mdot
.836 .49036 Mdot
.836 .49101 Mdot
.836 .4915 Mdot
.836 .49151 Mdot
.836 .49162 Mdot
.836 .49163 Mdot
.836 .49178 Mdot
.836 .49182 Mdot
.836 .49185 Mdot
.836 .49238 Mdot
.836 .49246 Mdot
.836 .49323 Mdot
.836 .49335 Mdot
.836 .49392 Mdot
.836 .49393 Mdot
.836 .4943 Mdot
.836 .49447 Mdot
.836 .49449 Mdot
.836 .49454 Mdot
.836 .4947 Mdot
.836 .49522 Mdot
.836 .49567 Mdot
.836 .49629 Mdot
.836 .49633 Mdot
.836 .49668 Mdot
.836 .49728 Mdot
.836 .49747 Mdot
.836 .49761 Mdot
.836 .4983 Mdot
.836 .49838 Mdot
.836 .4986 Mdot
.836 .49901 Mdot
.836 .49912 Mdot
.836 .50001 Mdot
.836 .50004 Mdot
.836 .50008 Mdot
.836 .50042 Mdot
.836 .50068 Mdot
.836 .50077 Mdot
.836 .50084 Mdot
.836 .50122 Mdot
.836 .50202 Mdot
.836 .50204 Mdot
.836 .50267 Mdot
.836 .50292 Mdot
.836 .50297 Mdot
.836 .50324 Mdot
.836 .50354 Mdot
.836 .50361 Mdot
.836 .50376 Mdot
.836 .50383 Mdot
.836 .50389 Mdot
.836 .50393 Mdot
.836 .50397 Mdot
.836 .50409 Mdot
.836 .50428 Mdot
.836 .50429 Mdot
.836 .50439 Mdot
.836 .50485 Mdot
.836 .50509 Mdot
.836 .50529 Mdot
.836 .50596 Mdot
.836 .50602 Mdot
.836 .50673 Mdot
.836 .5069 Mdot
.836 .5072 Mdot
.836 .50773 Mdot
.838 .17515 Mdot
.838 .17521 Mdot
.838 .17689 Mdot
.838 .17723 Mdot
.838 .17772 Mdot
.838 .17781 Mdot
.838 .1784 Mdot
.838 .17869 Mdot
.838 .17907 Mdot
.838 .17908 Mdot
.838 .17936 Mdot
.838 .1798 Mdot
.838 .17983 Mdot
.838 .18008 Mdot
.838 .1803 Mdot
.838 .18034 Mdot
.838 .18047 Mdot
.838 .18052 Mdot
.838 .18085 Mdot
.838 .18085 Mdot
.838 .18153 Mdot
.838 .18198 Mdot
.838 .18266 Mdot
.838 .18271 Mdot
.838 .18272 Mdot
.838 .18328 Mdot
.838 .18336 Mdot
.838 .18375 Mdot
.838 .18479 Mdot
.838 .18524 Mdot
.838 .18551 Mdot
.838 .18592 Mdot
.838 .18604 Mdot
.838 .18852 Mdot
.838 .18862 Mdot
.838 .18953 Mdot
.838 .18957 Mdot
.838 .18968 Mdot
.838 .18977 Mdot
.838 .18997 Mdot
.838 .19022 Mdot
.838 .19067 Mdot
.838 .19114 Mdot
.838 .19198 Mdot
.838 .19306 Mdot
.838 .19361 Mdot
.838 .19383 Mdot
.838 .19417 Mdot
.838 .19435 Mdot
.838 .19649 Mdot
.838 .19694 Mdot
.838 .19746 Mdot
.838 .19772 Mdot
.838 .19783 Mdot
.838 .19804 Mdot
.838 .19837 Mdot
.838 .1988 Mdot
.838 .19941 Mdot
.838 .2007 Mdot
.838 .20152 Mdot
.838 .20158 Mdot
.838 .2016 Mdot
.838 .20195 Mdot
.838 .20206 Mdot
.838 .20282 Mdot
.838 .20353 Mdot
.838 .20378 Mdot
.838 .20417 Mdot
.838 .20457 Mdot
.838 .20482 Mdot
.838 .20491 Mdot
.838 .20545 Mdot
.838 .20567 Mdot
.838 .20666 Mdot
.838 .2077 Mdot
.838 .20774 Mdot
.838 .20782 Mdot
.838 .20785 Mdot
.838 .20803 Mdot
.838 .20827 Mdot
.838 .20836 Mdot
.838 .20939 Mdot
.838 .20956 Mdot
.838 .20993 Mdot
.838 .21073 Mdot
.838 .21092 Mdot
.838 .21236 Mdot
.838 .21257 Mdot
.838 .21258 Mdot
.838 .21284 Mdot
.838 .21284 Mdot
.838 .21293 Mdot
.838 .21583 Mdot
.838 .21602 Mdot
.838 .21608 Mdot
.838 .21664 Mdot
.838 .21816 Mdot
.838 .21821 Mdot
.838 .21896 Mdot
.838 .21898 Mdot
.838 .21914 Mdot
.838 .21989 Mdot
.838 .21998 Mdot
.838 .22136 Mdot
.838 .22137 Mdot
.838 .2214 Mdot
.838 .22154 Mdot
.838 .22168 Mdot
.838 .22187 Mdot
.838 .22289 Mdot
.838 .22315 Mdot
.838 .22333 Mdot
.838 .22359 Mdot
.838 .22374 Mdot
.838 .22393 Mdot
.838 .22448 Mdot
.838 .22499 Mdot
.838 .22507 Mdot
.838 .22574 Mdot
.838 .22602 Mdot
.838 .22614 Mdot
.838 .22614 Mdot
.838 .22628 Mdot
.838 .22716 Mdot
.838 .22717 Mdot
.838 .22747 Mdot
.838 .22763 Mdot
.838 .22767 Mdot
.838 .22778 Mdot
.838 .22799 Mdot
.838 .22829 Mdot
.838 .22836 Mdot
.838 .22892 Mdot
.838 .2297 Mdot
.838 .22976 Mdot
.838 .23097 Mdot
.838 .23153 Mdot
.838 .23189 Mdot
.838 .23248 Mdot
.838 .23288 Mdot
.838 .23299 Mdot
.838 .23299 Mdot
.838 .23325 Mdot
.838 .2352 Mdot
.838 .23542 Mdot
.838 .23568 Mdot
.838 .23608 Mdot
.838 .2364 Mdot
.838 .23816 Mdot
.838 .23824 Mdot
.838 .2384 Mdot
.838 .23997 Mdot
.838 .24 Mdot
.838 .2401 Mdot
.838 .2403 Mdot
.838 .24031 Mdot
.838 .2413 Mdot
.838 .24169 Mdot
.838 .24177 Mdot
.838 .24277 Mdot
.838 .24427 Mdot
.838 .24464 Mdot
.838 .24492 Mdot
.838 .24529 Mdot
.838 .24583 Mdot
.838 .24611 Mdot
.838 .24665 Mdot
.838 .24698 Mdot
.838 .247 Mdot
.838 .24788 Mdot
.838 .24792 Mdot
.838 .24821 Mdot
.838 .24856 Mdot
.838 .24871 Mdot
.838 .2488 Mdot
.838 .24952 Mdot
.838 .24993 Mdot
.838 .25184 Mdot
.838 .25272 Mdot
.838 .25323 Mdot
.838 .25434 Mdot
.838 .25486 Mdot
.838 .25502 Mdot
.838 .25542 Mdot
.838 .25554 Mdot
.838 .25642 Mdot
.838 .25751 Mdot
.838 .25795 Mdot
.838 .25941 Mdot
.838 .25977 Mdot
.838 .26099 Mdot
.838 .26102 Mdot
.838 .26208 Mdot
.838 .26224 Mdot
.838 .26278 Mdot
.838 .26305 Mdot
.838 .26312 Mdot
.838 .26345 Mdot
.838 .26357 Mdot
.838 .26358 Mdot
.838 .26444 Mdot
.838 .2646 Mdot
.838 .26461 Mdot
.838 .26468 Mdot
.838 .26534 Mdot
.838 .2655 Mdot
.838 .26551 Mdot
.838 .26588 Mdot
.838 .26652 Mdot
.838 .26731 Mdot
.838 .26742 Mdot
.838 .26785 Mdot
.838 .2691 Mdot
.838 .27 Mdot
.838 .27058 Mdot
.838 .2708 Mdot
.838 .27106 Mdot
.838 .27164 Mdot
.838 .27526 Mdot
.838 .27676 Mdot
.838 .2768 Mdot
.838 .27731 Mdot
.838 .27744 Mdot
.838 .27776 Mdot
.838 .27782 Mdot
.838 .27813 Mdot
.838 .27817 Mdot
.838 .27831 Mdot
.838 .2786 Mdot
.838 .27904 Mdot
.838 .27905 Mdot
.838 .27948 Mdot
.838 .28141 Mdot
.838 .28181 Mdot
.838 .2823 Mdot
.838 .28342 Mdot
.838 .2836 Mdot
.838 .2837 Mdot
.838 .28372 Mdot
.838 .28403 Mdot
.838 .28403 Mdot
.838 .28415 Mdot
.838 .28435 Mdot
.838 .28477 Mdot
.838 .28487 Mdot
.838 .28641 Mdot
.838 .28641 Mdot
.838 .28652 Mdot
.838 .28709 Mdot
.838 .28792 Mdot
.838 .28806 Mdot
.838 .28892 Mdot
.838 .28905 Mdot
.838 .2892 Mdot
.838 .28953 Mdot
.838 .29017 Mdot
.838 .29018 Mdot
.838 .29066 Mdot
.838 .29092 Mdot
.838 .29109 Mdot
.838 .2914 Mdot
.838 .29145 Mdot
.838 .29186 Mdot
.838 .29224 Mdot
.838 .29231 Mdot
.838 .29246 Mdot
.838 .29252 Mdot
.838 .29261 Mdot
.838 .29309 Mdot
.838 .29314 Mdot
.838 .29315 Mdot
.838 .29315 Mdot
.838 .29365 Mdot
.838 .29368 Mdot
.838 .29395 Mdot
.838 .294 Mdot
.838 .29401 Mdot
.838 .29428 Mdot
.838 .2943 Mdot
.838 .29506 Mdot
.838 .29619 Mdot
.838 .29619 Mdot
.838 .29628 Mdot
.838 .29629 Mdot
.838 .29636 Mdot
.838 .29694 Mdot
.838 .29723 Mdot
.838 .29736 Mdot
.838 .29797 Mdot
.838 .29801 Mdot
.838 .29802 Mdot
.838 .29882 Mdot
.838 .29901 Mdot
.838 .29904 Mdot
.838 .2995 Mdot
.838 .29975 Mdot
.838 .30019 Mdot
.838 .30051 Mdot
.838 .30097 Mdot
.838 .30134 Mdot
.838 .30146 Mdot
.838 .30153 Mdot
.838 .30157 Mdot
.838 .30166 Mdot
.838 .30185 Mdot
.838 .30201 Mdot
.838 .30277 Mdot
.838 .30284 Mdot
.838 .30296 Mdot
.838 .30408 Mdot
.838 .30433 Mdot
.838 .3044 Mdot
.838 .30444 Mdot
.838 .30447 Mdot
.838 .30481 Mdot
.838 .30573 Mdot
.838 .30592 Mdot
.838 .30602 Mdot
.838 .30618 Mdot
.838 .30668 Mdot
.838 .30734 Mdot
.838 .30771 Mdot
.838 .30777 Mdot
.838 .30785 Mdot
.838 .30794 Mdot
.838 .30795 Mdot
.838 .30811 Mdot
.838 .30821 Mdot
.838 .30821 Mdot
.838 .30835 Mdot
.838 .30845 Mdot
.838 .30866 Mdot
.838 .30869 Mdot
.838 .30887 Mdot
.838 .30959 Mdot
.838 .30961 Mdot
.838 .31041 Mdot
.838 .31164 Mdot
.838 .3117 Mdot
.838 .31181 Mdot
.838 .31182 Mdot
.838 .31222 Mdot
.838 .31246 Mdot
.838 .31248 Mdot
.838 .31248 Mdot
.838 .31268 Mdot
.838 .31285 Mdot
.838 .31362 Mdot
.838 .31455 Mdot
.838 .31491 Mdot
.838 .31515 Mdot
.838 .31548 Mdot
.838 .31578 Mdot
.838 .31616 Mdot
.838 .31636 Mdot
.838 .31821 Mdot
.838 .31917 Mdot
.838 .31919 Mdot
.838 .31933 Mdot
.838 .31937 Mdot
.838 .31998 Mdot
.838 .32012 Mdot
.838 .32026 Mdot
.838 .32065 Mdot
.838 .321 Mdot
.838 .32143 Mdot
.838 .32149 Mdot
.838 .32158 Mdot
.838 .32161 Mdot
.838 .32197 Mdot
.838 .32252 Mdot
.838 .32324 Mdot
.838 .32427 Mdot
.838 .32436 Mdot
.838 .32456 Mdot
.838 .32635 Mdot
.838 .32642 Mdot
.838 .32703 Mdot
.838 .32735 Mdot
.838 .32756 Mdot
.838 .3278 Mdot
.838 .3279 Mdot
.838 .32794 Mdot
.838 .32831 Mdot
.838 .32841 Mdot
.838 .32848 Mdot
.838 .32852 Mdot
.838 .3286 Mdot
.838 .3287 Mdot
.838 .32893 Mdot
.838 .32966 Mdot
.838 .32999 Mdot
.838 .33038 Mdot
.838 .33038 Mdot
.838 .33116 Mdot
.838 .33124 Mdot
.838 .33159 Mdot
.838 .33222 Mdot
.838 .33225 Mdot
.838 .33286 Mdot
.838 .33291 Mdot
.838 .33334 Mdot
.838 .33347 Mdot
.838 .3335 Mdot
.838 .33386 Mdot
.838 .33439 Mdot
.838 .33476 Mdot
.838 .33495 Mdot
.838 .33592 Mdot
.838 .33601 Mdot
.838 .33626 Mdot
.838 .33641 Mdot
.838 .3374 Mdot
.838 .33816 Mdot
.838 .33822 Mdot
.838 .33836 Mdot
.838 .3384 Mdot
.838 .33872 Mdot
.838 .33911 Mdot
.838 .33926 Mdot
.838 .33978 Mdot
.838 .34073 Mdot
.838 .34098 Mdot
.838 .3411 Mdot
.838 .34127 Mdot
.838 .34164 Mdot
.838 .34166 Mdot
.838 .34189 Mdot
.838 .34195 Mdot
.838 .34231 Mdot
.838 .34279 Mdot
.838 .34323 Mdot
.838 .34355 Mdot
.838 .34376 Mdot
.838 .34384 Mdot
.838 .34393 Mdot
.838 .34542 Mdot
.838 .34596 Mdot
.838 .34597 Mdot
.838 .34615 Mdot
.838 .3462 Mdot
.838 .34632 Mdot
.838 .34634 Mdot
.838 .34645 Mdot
.838 .34646 Mdot
.838 .34651 Mdot
.838 .34662 Mdot
.838 .34677 Mdot
.838 .34677 Mdot
.838 .34693 Mdot
.838 .34762 Mdot
.838 .34793 Mdot
.838 .34844 Mdot
.838 .34855 Mdot
.838 .34855 Mdot
.838 .34866 Mdot
.838 .34885 Mdot
.838 .3494 Mdot
.838 .35039 Mdot
.838 .351 Mdot
.838 .35106 Mdot
.838 .35177 Mdot
.838 .35179 Mdot
.838 .35198 Mdot
.838 .3521 Mdot
.838 .3521 Mdot
.838 .3522 Mdot
.838 .35294 Mdot
.838 .35314 Mdot
.838 .35352 Mdot
.838 .35381 Mdot
.838 .3543 Mdot
.838 .35475 Mdot
.838 .35522 Mdot
.838 .35529 Mdot
.838 .35569 Mdot
.838 .35577 Mdot
.838 .3558 Mdot
.838 .35684 Mdot
.838 .35703 Mdot
.838 .35706 Mdot
.838 .35716 Mdot
.838 .3572 Mdot
.838 .35733 Mdot
.838 .35765 Mdot
.838 .35844 Mdot
.838 .35858 Mdot
.838 .35867 Mdot
.838 .35868 Mdot
.838 .35868 Mdot
.838 .35875 Mdot
.838 .35881 Mdot
.838 .36006 Mdot
.838 .36071 Mdot
.838 .36106 Mdot
.838 .36107 Mdot
.838 .36111 Mdot
.838 .36135 Mdot
.838 .36159 Mdot
.838 .36191 Mdot
.838 .3629 Mdot
.838 .36361 Mdot
.838 .36404 Mdot
.838 .36431 Mdot
.838 .36435 Mdot
.838 .36441 Mdot
.838 .36479 Mdot
.838 .36505 Mdot
.838 .36536 Mdot
.838 .3657 Mdot
.838 .36593 Mdot
.838 .36629 Mdot
.838 .36702 Mdot
.838 .36705 Mdot
.838 .36714 Mdot
.838 .36728 Mdot
.838 .3684 Mdot
.838 .36873 Mdot
.838 .36887 Mdot
.838 .36906 Mdot
.838 .36906 Mdot
.838 .36917 Mdot
.838 .3693 Mdot
.838 .36981 Mdot
.838 .36984 Mdot
.838 .3704 Mdot
.838 .37066 Mdot
.838 .37077 Mdot
.838 .37077 Mdot
.838 .37079 Mdot
.838 .3713 Mdot
.838 .37152 Mdot
.838 .37156 Mdot
.838 .37162 Mdot
.838 .37182 Mdot
.838 .37217 Mdot
.838 .37267 Mdot
.838 .37278 Mdot
.838 .37308 Mdot
.838 .37339 Mdot
.838 .37372 Mdot
.838 .37389 Mdot
.838 .37392 Mdot
.838 .37458 Mdot
.838 .3746 Mdot
.838 .37504 Mdot
.838 .37512 Mdot
.838 .37512 Mdot
.838 .37517 Mdot
.838 .37561 Mdot
.838 .37585 Mdot
.838 .37713 Mdot
.838 .37717 Mdot
.838 .3781 Mdot
.838 .3787 Mdot
.838 .37886 Mdot
.838 .37969 Mdot
.838 .38025 Mdot
.838 .38036 Mdot
.838 .38054 Mdot
.838 .38055 Mdot
.838 .38078 Mdot
.838 .38079 Mdot
.838 .38098 Mdot
.838 .38169 Mdot
.838 .38231 Mdot
.838 .3828 Mdot
.838 .38299 Mdot
.838 .38353 Mdot
.838 .38378 Mdot
.838 .38406 Mdot
.838 .38416 Mdot
.838 .38425 Mdot
.838 .38431 Mdot
.838 .38447 Mdot
.838 .38462 Mdot
.838 .38494 Mdot
.838 .38506 Mdot
.838 .38535 Mdot
.838 .38572 Mdot
.838 .38626 Mdot
.838 .38626 Mdot
.838 .38658 Mdot
.838 .38741 Mdot
.838 .38844 Mdot
.838 .3892 Mdot
.838 .38934 Mdot
.838 .38961 Mdot
.838 .38964 Mdot
.838 .38995 Mdot
.838 .38996 Mdot
.838 .39036 Mdot
.838 .39037 Mdot
.838 .39067 Mdot
.838 .39086 Mdot
.838 .39179 Mdot
.838 .39224 Mdot
.838 .3923 Mdot
.838 .39245 Mdot
.838 .39279 Mdot
.838 .39281 Mdot
.838 .39319 Mdot
.838 .39345 Mdot
.838 .39445 Mdot
.838 .39447 Mdot
.838 .39512 Mdot
.838 .39526 Mdot
.838 .39603 Mdot
.838 .39609 Mdot
.838 .39693 Mdot
.838 .39823 Mdot
.838 .39863 Mdot
.838 .39937 Mdot
.838 .39945 Mdot
.838 .39945 Mdot
.838 .39945 Mdot
.838 .39959 Mdot
.838 .40007 Mdot
.838 .40033 Mdot
.838 .40036 Mdot
.838 .40054 Mdot
.838 .40117 Mdot
.838 .40147 Mdot
.838 .40151 Mdot
.838 .40179 Mdot
.838 .40206 Mdot
.838 .40235 Mdot
.838 .40253 Mdot
.838 .40287 Mdot
.838 .40338 Mdot
.838 .40344 Mdot
.838 .40357 Mdot
.838 .40399 Mdot
.838 .40403 Mdot
.838 .4044 Mdot
.838 .40499 Mdot
.838 .40532 Mdot
.838 .40543 Mdot
.838 .40549 Mdot
.838 .40549 Mdot
.838 .40556 Mdot
.838 .40586 Mdot
.838 .40605 Mdot
.838 .40665 Mdot
.838 .40671 Mdot
.838 .40674 Mdot
.838 .40675 Mdot
.838 .40689 Mdot
.838 .40692 Mdot
.838 .40704 Mdot
.838 .40736 Mdot
.838 .40825 Mdot
.838 .4083 Mdot
.838 .40835 Mdot
.838 .40893 Mdot
.838 .40921 Mdot
.838 .40943 Mdot
.838 .4096 Mdot
.838 .40962 Mdot
.838 .40994 Mdot
.838 .41016 Mdot
.838 .41072 Mdot
.838 .41214 Mdot
.838 .4126 Mdot
.838 .41282 Mdot
.838 .41298 Mdot
.838 .41303 Mdot
.838 .41361 Mdot
.838 .41426 Mdot
.838 .41447 Mdot
.838 .41485 Mdot
.838 .41524 Mdot
.838 .41582 Mdot
.838 .41633 Mdot
.838 .41634 Mdot
.838 .41676 Mdot
.838 .4172 Mdot
.838 .4174 Mdot
.838 .41747 Mdot
.838 .41751 Mdot
.838 .41757 Mdot
.838 .41802 Mdot
.838 .41814 Mdot
.838 .41833 Mdot
.838 .41874 Mdot
.838 .41981 Mdot
.838 .41993 Mdot
.838 .42159 Mdot
.838 .42164 Mdot
.838 .42214 Mdot
.838 .42237 Mdot
.838 .42254 Mdot
.838 .42293 Mdot
.838 .42301 Mdot
.838 .42302 Mdot
.838 .4236 Mdot
.838 .4247 Mdot
.838 .42482 Mdot
.838 .42542 Mdot
.838 .42679 Mdot
.838 .42689 Mdot
.838 .42701 Mdot
.838 .42701 Mdot
.838 .42703 Mdot
.838 .42717 Mdot
.838 .42741 Mdot
.838 .42748 Mdot
.838 .42752 Mdot
.838 .42874 Mdot
.838 .42927 Mdot
.838 .42929 Mdot
.838 .42948 Mdot
.838 .42956 Mdot
.838 .42956 Mdot
.838 .42972 Mdot
.838 .42977 Mdot
.838 .43008 Mdot
.838 .43047 Mdot
.838 .43093 Mdot
.838 .43104 Mdot
.838 .43159 Mdot
.838 .43179 Mdot
.838 .43181 Mdot
.838 .43183 Mdot
.838 .43188 Mdot
.838 .43202 Mdot
.838 .4327 Mdot
.838 .43281 Mdot
.838 .43326 Mdot
.838 .43352 Mdot
.838 .43354 Mdot
.838 .43359 Mdot
.838 .43366 Mdot
.838 .43435 Mdot
.838 .43476 Mdot
.838 .43503 Mdot
.838 .43505 Mdot
.838 .43517 Mdot
.838 .43565 Mdot
.838 .43567 Mdot
.838 .43629 Mdot
.838 .43663 Mdot
.838 .43673 Mdot
.838 .43788 Mdot
.838 .43803 Mdot
.838 .43804 Mdot
.838 .43807 Mdot
.838 .43823 Mdot
.838 .43825 Mdot
.838 .43855 Mdot
.838 .43858 Mdot
.838 .43896 Mdot
.838 .43978 Mdot
.838 .43988 Mdot
.838 .44091 Mdot
.838 .44107 Mdot
.838 .44257 Mdot
.838 .44257 Mdot
.838 .44349 Mdot
.838 .44355 Mdot
.838 .4438 Mdot
.838 .44392 Mdot
.838 .44399 Mdot
.838 .44399 Mdot
.838 .44418 Mdot
.838 .44435 Mdot
.838 .44502 Mdot
.838 .44531 Mdot
.838 .44555 Mdot
.838 .4467 Mdot
.838 .44696 Mdot
.838 .44697 Mdot
.838 .44723 Mdot
.838 .4474 Mdot
.838 .44748 Mdot
.838 .44751 Mdot
.838 .4477 Mdot
.838 .44773 Mdot
.838 .44792 Mdot
.838 .448 Mdot
.838 .44831 Mdot
.838 .44833 Mdot
.838 .44922 Mdot
.838 .45138 Mdot
.838 .45173 Mdot
.838 .45188 Mdot
.838 .45201 Mdot
.838 .45236 Mdot
.838 .4529 Mdot
.838 .45365 Mdot
.838 .4539 Mdot
.838 .45396 Mdot
.838 .45444 Mdot
.838 .45482 Mdot
.838 .45504 Mdot
.838 .45504 Mdot
.838 .45514 Mdot
.838 .45553 Mdot
.838 .45557 Mdot
.838 .45558 Mdot
.838 .45567 Mdot
.838 .45619 Mdot
.838 .4562 Mdot
.838 .45627 Mdot
.838 .45647 Mdot
.838 .4565 Mdot
.838 .45667 Mdot
.838 .45699 Mdot
.838 .45709 Mdot
.838 .45772 Mdot
.838 .45773 Mdot
.838 .45847 Mdot
.838 .45868 Mdot
.838 .45955 Mdot
.838 .45981 Mdot
.838 .46046 Mdot
.838 .46099 Mdot
.838 .46106 Mdot
.838 .4613 Mdot
.838 .46139 Mdot
.838 .4617 Mdot
.838 .46236 Mdot
.838 .46267 Mdot
.838 .46319 Mdot
.838 .46434 Mdot
.838 .46458 Mdot
.838 .46501 Mdot
.838 .46506 Mdot
.838 .46515 Mdot
.838 .46536 Mdot
.838 .46554 Mdot
.838 .46556 Mdot
.838 .46608 Mdot
.838 .46609 Mdot
.838 .46629 Mdot
.838 .46662 Mdot
.838 .46678 Mdot
.838 .4671 Mdot
.838 .46732 Mdot
.838 .46749 Mdot
.838 .46771 Mdot
.838 .46861 Mdot
.838 .4692 Mdot
.838 .46925 Mdot
.838 .46948 Mdot
.838 .47008 Mdot
.838 .47008 Mdot
.838 .4702 Mdot
.838 .47026 Mdot
.838 .47028 Mdot
.838 .47121 Mdot
.838 .47131 Mdot
.838 .47136 Mdot
.838 .47241 Mdot
.838 .4726 Mdot
.838 .47284 Mdot
.838 .47299 Mdot
.838 .47312 Mdot
.838 .47429 Mdot
.838 .47444 Mdot
.838 .47444 Mdot
.838 .47451 Mdot
.838 .47475 Mdot
.838 .4751 Mdot
.838 .47531 Mdot
.838 .47565 Mdot
.838 .47637 Mdot
.838 .4764 Mdot
.838 .47687 Mdot
.838 .47721 Mdot
.838 .47725 Mdot
.838 .47742 Mdot
.838 .47755 Mdot
.838 .47762 Mdot
.838 .47764 Mdot
.838 .47773 Mdot
.838 .47791 Mdot
.838 .47792 Mdot
.838 .47845 Mdot
.838 .47853 Mdot
.838 .47853 Mdot
.838 .4786 Mdot
.838 .47877 Mdot
.838 .47917 Mdot
.838 .47921 Mdot
.838 .47952 Mdot
.838 .47985 Mdot
.838 .47996 Mdot
.838 .48005 Mdot
.838 .48021 Mdot
.838 .48032 Mdot
.838 .48047 Mdot
.838 .48107 Mdot
.838 .48119 Mdot
.838 .48128 Mdot
.838 .48136 Mdot
.838 .48138 Mdot
.838 .48138 Mdot
.838 .4822 Mdot
.838 .48226 Mdot
.838 .48271 Mdot
.838 .4828 Mdot
.838 .48281 Mdot
.838 .48326 Mdot
.838 .48329 Mdot
.838 .4842 Mdot
.838 .48453 Mdot
.838 .48457 Mdot
.838 .48468 Mdot
.838 .48641 Mdot
.838 .48646 Mdot
.838 .48647 Mdot
.838 .48662 Mdot
.838 .48663 Mdot
.838 .48675 Mdot
.838 .48761 Mdot
.838 .48772 Mdot
.838 .4882 Mdot
.838 .48842 Mdot
.838 .48853 Mdot
.838 .48914 Mdot
.838 .48919 Mdot
.838 .48933 Mdot
.838 .48944 Mdot
.838 .48946 Mdot
.838 .48951 Mdot
.838 .48953 Mdot
.838 .49015 Mdot
.838 .49074 Mdot
.838 .49087 Mdot
.838 .4912 Mdot
.838 .49125 Mdot
.838 .4914 Mdot
.838 .49164 Mdot
.838 .49187 Mdot
.838 .49202 Mdot
.838 .49244 Mdot
.838 .4929 Mdot
.838 .49296 Mdot
.838 .49317 Mdot
.838 .49318 Mdot
.838 .49322 Mdot
.838 .49371 Mdot
.838 .49448 Mdot
.838 .49484 Mdot
.838 .4951 Mdot
.838 .49529 Mdot
.838 .49542 Mdot
.838 .49549 Mdot
.838 .49564 Mdot
.838 .49595 Mdot
.838 .49622 Mdot
.838 .4975 Mdot
.838 .49761 Mdot
.838 .49781 Mdot
.838 .49794 Mdot
.838 .49827 Mdot
.838 .49891 Mdot
.838 .49941 Mdot
.838 .4997 Mdot
.838 .49996 Mdot
.838 .50011 Mdot
.838 .50023 Mdot
.838 .50029 Mdot
.838 .50035 Mdot
.838 .50037 Mdot
.838 .50092 Mdot
.838 .50097 Mdot
.838 .50246 Mdot
.838 .50252 Mdot
.838 .50277 Mdot
.838 .50293 Mdot
.838 .5032 Mdot
.838 .50382 Mdot
.838 .50406 Mdot
.838 .5041 Mdot
.838 .50444 Mdot
.838 .50444 Mdot
.838 .50447 Mdot
.838 .50488 Mdot
.838 .50515 Mdot
.838 .50555 Mdot
.838 .50555 Mdot
.838 .50575 Mdot
.838 .50578 Mdot
.838 .50585 Mdot
.838 .50588 Mdot
.838 .50601 Mdot
.838 .50616 Mdot
.838 .50618 Mdot
.838 .50644 Mdot
.838 .50661 Mdot
.838 .50662 Mdot
.838 .50684 Mdot
.838 .50701 Mdot
.838 .50737 Mdot
.838 .50742 Mdot
.838 .50771 Mdot
.838 .50792 Mdot
.838 .50892 Mdot
.838 .50896 Mdot
.84 .17346 Mdot
.84 .17374 Mdot
.84 .17392 Mdot
.84 .17407 Mdot
.84 .17595 Mdot
.84 .17596 Mdot
.84 .1767 Mdot
.84 .1773 Mdot
.84 .17731 Mdot
.84 .17743 Mdot
.84 .1775 Mdot
.84 .17759 Mdot
.84 .17833 Mdot
.84 .17835 Mdot
.84 .1785 Mdot
.84 .17861 Mdot
.84 .17877 Mdot
.84 .17888 Mdot
.84 .17925 Mdot
.84 .17996 Mdot
.84 .18031 Mdot
.84 .18037 Mdot
.84 .18055 Mdot
.84 .18083 Mdot
.84 .18114 Mdot
.84 .1814 Mdot
.84 .18197 Mdot
.84 .18202 Mdot
.84 .18245 Mdot
.84 .18305 Mdot
.84 .18329 Mdot
.84 .18462 Mdot
.84 .18478 Mdot
.84 .1858 Mdot
.84 .18639 Mdot
.84 .1864 Mdot
.84 .18652 Mdot
.84 .18707 Mdot
.84 .18739 Mdot
.84 .18791 Mdot
.84 .18819 Mdot
.84 .18847 Mdot
.84 .18859 Mdot
.84 .18882 Mdot
.84 .18943 Mdot
.84 .19014 Mdot
.84 .19033 Mdot
.84 .19086 Mdot
.84 .19092 Mdot
.84 .1912 Mdot
.84 .1914 Mdot
.84 .19179 Mdot
.84 .19183 Mdot
.84 .19214 Mdot
.84 .19223 Mdot
.84 .19309 Mdot
.84 .19385 Mdot
.84 .194 Mdot
.84 .19412 Mdot
.84 .19429 Mdot
.84 .19463 Mdot
.84 .19486 Mdot
.84 .19494 Mdot
.84 .19531 Mdot
.84 .19705 Mdot
.84 .19772 Mdot
.84 .19923 Mdot
.84 .19946 Mdot
.84 .19996 Mdot
.84 .20021 Mdot
.84 .20133 Mdot
.84 .20176 Mdot
.84 .20302 Mdot
.84 .2037 Mdot
.84 .20388 Mdot
.84 .20403 Mdot
.84 .20443 Mdot
.84 .20457 Mdot
.84 .20462 Mdot
.84 .20473 Mdot
.84 .20512 Mdot
.84 .20517 Mdot
.84 .20531 Mdot
.84 .20653 Mdot
.84 .20769 Mdot
.84 .20847 Mdot
.84 .21027 Mdot
.84 .21053 Mdot
.84 .21256 Mdot
.84 .21278 Mdot
.84 .21298 Mdot
.84 .21299 Mdot
.84 .21303 Mdot
.84 .21493 Mdot
.84 .21514 Mdot
.84 .21549 Mdot
.84 .21562 Mdot
.84 .2161 Mdot
.84 .21669 Mdot
.84 .21672 Mdot
.84 .21673 Mdot
.84 .21678 Mdot
.84 .21679 Mdot
.84 .21779 Mdot
.84 .21797 Mdot
.84 .21809 Mdot
.84 .21821 Mdot
.84 .21911 Mdot
.84 .21936 Mdot
.84 .21951 Mdot
.84 .22027 Mdot
.84 .22038 Mdot
.84 .22068 Mdot
.84 .22116 Mdot
.84 .22119 Mdot
.84 .22218 Mdot
.84 .22231 Mdot
.84 .22264 Mdot
.84 .2256 Mdot
.84 .22568 Mdot
.84 .22584 Mdot
.84 .22595 Mdot
.84 .22619 Mdot
.84 .22686 Mdot
.84 .22746 Mdot
.84 .22765 Mdot
.84 .22796 Mdot
.84 .2287 Mdot
.84 .22873 Mdot
.84 .22886 Mdot
.84 .22888 Mdot
.84 .22925 Mdot
.84 .22994 Mdot
.84 .23007 Mdot
.84 .23044 Mdot
.84 .23088 Mdot
.84 .231 Mdot
.84 .23113 Mdot
.84 .23357 Mdot
.84 .23363 Mdot
.84 .23386 Mdot
.84 .234 Mdot
.84 .2343 Mdot
.84 .23433 Mdot
.84 .23461 Mdot
.84 .2349 Mdot
.84 .23492 Mdot
.84 .23586 Mdot
.84 .23625 Mdot
.84 .23684 Mdot
.84 .23769 Mdot
.84 .23776 Mdot
.84 .23838 Mdot
.84 .23839 Mdot
.84 .23876 Mdot
.84 .23896 Mdot
.84 .23925 Mdot
.84 .24009 Mdot
.84 .24029 Mdot
.84 .24067 Mdot
.84 .24087 Mdot
.84 .24096 Mdot
.84 .2412 Mdot
.84 .24125 Mdot
.84 .24128 Mdot
.84 .24133 Mdot
.84 .24135 Mdot
.84 .2417 Mdot
.84 .24177 Mdot
.84 .24356 Mdot
.84 .24381 Mdot
.84 .24402 Mdot
.84 .24449 Mdot
.84 .24458 Mdot
.84 .24725 Mdot
.84 .24792 Mdot
.84 .24919 Mdot
.84 .24932 Mdot
.84 .25025 Mdot
.84 .25025 Mdot
.84 .25094 Mdot
.84 .25097 Mdot
.84 .25183 Mdot
.84 .25315 Mdot
.84 .25371 Mdot
.84 .25411 Mdot
.84 .25412 Mdot
.84 .25465 Mdot
.84 .25473 Mdot
.84 .25575 Mdot
.84 .256 Mdot
.84 .25612 Mdot
.84 .25639 Mdot
.84 .25746 Mdot
.84 .2583 Mdot
.84 .25946 Mdot
.84 .26038 Mdot
.84 .26074 Mdot
.84 .26103 Mdot
.84 .2618 Mdot
.84 .26187 Mdot
.84 .2619 Mdot
.84 .26204 Mdot
.84 .26221 Mdot
.84 .26397 Mdot
.84 .26398 Mdot
.84 .26537 Mdot
.84 .26683 Mdot
.84 .26798 Mdot
.84 .2686 Mdot
.84 .26922 Mdot
.84 .26927 Mdot
.84 .27032 Mdot
.84 .27757 Mdot
.84 .27826 Mdot
.84 .27861 Mdot
.84 .27884 Mdot
.84 .27988 Mdot
.84 .2804 Mdot
.84 .28084 Mdot
.84 .28087 Mdot
.84 .28106 Mdot
.84 .2814 Mdot
.84 .28187 Mdot
.84 .28218 Mdot
.84 .28219 Mdot
.84 .28243 Mdot
.84 .28444 Mdot
.84 .28558 Mdot
.84 .28559 Mdot
.84 .28561 Mdot
.84 .28562 Mdot
.84 .28575 Mdot
.84 .28686 Mdot
.84 .28739 Mdot
.84 .28753 Mdot
.84 .28786 Mdot
.84 .28787 Mdot
.84 .28808 Mdot
.84 .28819 Mdot
.84 .28824 Mdot
.84 .28834 Mdot
.84 .28929 Mdot
.84 .28958 Mdot
.84 .28963 Mdot
.84 .28987 Mdot
.84 .29005 Mdot
.84 .29007 Mdot
.84 .29033 Mdot
.84 .29051 Mdot
.84 .29104 Mdot
.84 .29108 Mdot
.84 .29114 Mdot
.84 .29221 Mdot
.84 .29233 Mdot
.84 .29238 Mdot
.84 .29274 Mdot
.84 .29291 Mdot
.84 .29301 Mdot
.84 .29332 Mdot
.84 .29337 Mdot
.84 .29378 Mdot
.84 .29429 Mdot
.84 .29429 Mdot
.84 .29431 Mdot
.84 .29475 Mdot
.84 .29562 Mdot
.84 .29564 Mdot
.84 .29571 Mdot
.84 .29579 Mdot
.84 .2965 Mdot
.84 .2966 Mdot
.84 .29751 Mdot
.84 .29792 Mdot
.84 .2984 Mdot
.84 .29842 Mdot
.84 .29856 Mdot
.84 .2986 Mdot
.84 .29886 Mdot
.84 .29892 Mdot
.84 .30016 Mdot
.84 .30043 Mdot
.84 .30214 Mdot
.84 .30226 Mdot
.84 .30232 Mdot
.84 .30236 Mdot
.84 .30268 Mdot
.84 .30313 Mdot
.84 .30314 Mdot
.84 .30335 Mdot
.84 .30366 Mdot
.84 .30428 Mdot
.84 .30442 Mdot
.84 .30452 Mdot
.84 .3047 Mdot
.84 .30482 Mdot
.84 .30505 Mdot
.84 .30506 Mdot
.84 .30527 Mdot
.84 .30563 Mdot
.84 .30568 Mdot
.84 .30616 Mdot
.84 .30662 Mdot
.84 .30683 Mdot
.84 .30703 Mdot
.84 .30721 Mdot
.84 .30733 Mdot
.84 .30772 Mdot
.84 .30781 Mdot
.84 .30821 Mdot
.84 .30823 Mdot
.84 .30828 Mdot
.84 .30849 Mdot
.84 .30942 Mdot
.84 .30954 Mdot
.84 .30975 Mdot
.84 .30992 Mdot
.84 .31064 Mdot
.84 .31064 Mdot
.84 .31073 Mdot
.84 .31112 Mdot
.84 .31122 Mdot
.84 .31148 Mdot
.84 .31149 Mdot
.84 .31154 Mdot
.84 .31164 Mdot
.84 .31181 Mdot
.84 .3122 Mdot
.84 .31227 Mdot
.84 .31248 Mdot
.84 .31279 Mdot
.84 .31294 Mdot
.84 .31315 Mdot
.84 .31438 Mdot
.84 .31507 Mdot
.84 .3152 Mdot
.84 .31541 Mdot
.84 .31566 Mdot
.84 .31592 Mdot
.84 .31594 Mdot
.84 .31611 Mdot
.84 .31637 Mdot
.84 .3164 Mdot
.84 .31698 Mdot
.84 .31734 Mdot
.84 .31737 Mdot
.84 .3175 Mdot
.84 .31811 Mdot
.84 .31835 Mdot
.84 .31888 Mdot
.84 .31914 Mdot
.84 .31963 Mdot
.84 .31978 Mdot
.84 .32023 Mdot
.84 .32058 Mdot
.84 .32073 Mdot
.84 .32078 Mdot
.84 .32104 Mdot
.84 .32216 Mdot
.84 .32376 Mdot
.84 .32445 Mdot
.84 .32452 Mdot
.84 .32469 Mdot
.84 .32486 Mdot
.84 .32507 Mdot
.84 .32508 Mdot
.84 .32546 Mdot
.84 .32553 Mdot
.84 .32557 Mdot
.84 .32593 Mdot
.84 .32634 Mdot
.84 .32667 Mdot
.84 .32823 Mdot
.84 .32844 Mdot
.84 .32867 Mdot
.84 .32896 Mdot
.84 .32938 Mdot
.84 .32939 Mdot
.84 .32994 Mdot
.84 .33014 Mdot
.84 .33019 Mdot
.84 .33107 Mdot
.84 .33132 Mdot
.84 .33142 Mdot
.84 .33221 Mdot
.84 .33251 Mdot
.84 .33275 Mdot
.84 .33276 Mdot
.84 .33289 Mdot
.84 .33296 Mdot
.84 .33306 Mdot
.84 .33336 Mdot
.84 .33343 Mdot
.84 .33357 Mdot
.84 .33367 Mdot
.84 .33376 Mdot
.84 .33393 Mdot
.84 .33396 Mdot
.84 .33459 Mdot
.84 .33468 Mdot
.84 .33475 Mdot
.84 .33492 Mdot
.84 .3359 Mdot
.84 .33614 Mdot
.84 .33659 Mdot
.84 .33663 Mdot
.84 .33696 Mdot
.84 .33819 Mdot
.84 .33833 Mdot
.84 .33891 Mdot
.84 .33904 Mdot
.84 .33914 Mdot
.84 .33981 Mdot
.84 .34023 Mdot
.84 .34068 Mdot
.84 .34105 Mdot
.84 .34108 Mdot
.84 .34109 Mdot
.84 .3412 Mdot
.84 .34182 Mdot
.84 .34232 Mdot
.84 .34284 Mdot
.84 .34324 Mdot
.84 .34346 Mdot
.84 .34368 Mdot
.84 .3437 Mdot
.84 .34407 Mdot
.84 .34664 Mdot
.84 .34688 Mdot
.84 .34701 Mdot
.84 .34709 Mdot
.84 .34746 Mdot
.84 .34764 Mdot
.84 .3478 Mdot
.84 .34781 Mdot
.84 .34788 Mdot
.84 .34827 Mdot
.84 .34948 Mdot
.84 .34949 Mdot
.84 .34954 Mdot
.84 .35042 Mdot
.84 .35107 Mdot
.84 .35143 Mdot
.84 .35183 Mdot
.84 .35189 Mdot
.84 .35202 Mdot
.84 .35224 Mdot
.84 .35256 Mdot
.84 .35304 Mdot
.84 .35304 Mdot
.84 .35338 Mdot
.84 .35403 Mdot
.84 .35408 Mdot
.84 .35409 Mdot
.84 .35418 Mdot
.84 .35421 Mdot
.84 .35539 Mdot
.84 .35554 Mdot
.84 .35589 Mdot
.84 .35615 Mdot
.84 .35619 Mdot
.84 .35625 Mdot
.84 .35638 Mdot
.84 .35638 Mdot
.84 .35645 Mdot
.84 .35658 Mdot
.84 .35708 Mdot
.84 .35732 Mdot
.84 .35797 Mdot
.84 .3581 Mdot
.84 .35853 Mdot
.84 .35866 Mdot
.84 .35871 Mdot
.84 .35877 Mdot
.84 .35925 Mdot
.84 .35997 Mdot
.84 .36005 Mdot
.84 .36024 Mdot
.84 .36039 Mdot
.84 .36073 Mdot
.84 .36128 Mdot
.84 .36137 Mdot
.84 .36154 Mdot
.84 .3616 Mdot
.84 .36176 Mdot
.84 .36188 Mdot
.84 .36195 Mdot
.84 .36325 Mdot
.84 .36347 Mdot
.84 .36361 Mdot
.84 .36363 Mdot
.84 .36404 Mdot
.84 .365 Mdot
.84 .365 Mdot
.84 .3652 Mdot
.84 .36572 Mdot
.84 .36619 Mdot
.84 .36627 Mdot
.84 .3663 Mdot
.84 .36641 Mdot
.84 .36648 Mdot
.84 .36662 Mdot
.84 .3669 Mdot
.84 .36731 Mdot
.84 .36739 Mdot
.84 .36755 Mdot
.84 .36812 Mdot
.84 .36817 Mdot
.84 .3687 Mdot
.84 .369 Mdot
.84 .36913 Mdot
.84 .36918 Mdot
.84 .36941 Mdot
.84 .36958 Mdot
.84 .36977 Mdot
.84 .36999 Mdot
.84 .37111 Mdot
.84 .37124 Mdot
.84 .37169 Mdot
.84 .37212 Mdot
.84 .37212 Mdot
.84 .37245 Mdot
.84 .37295 Mdot
.84 .37297 Mdot
.84 .37321 Mdot
.84 .37338 Mdot
.84 .3735 Mdot
.84 .37421 Mdot
.84 .37427 Mdot
.84 .37448 Mdot
.84 .37452 Mdot
.84 .37456 Mdot
.84 .37459 Mdot
.84 .37513 Mdot
.84 .37539 Mdot
.84 .37598 Mdot
.84 .3763 Mdot
.84 .37633 Mdot
.84 .37647 Mdot
.84 .37651 Mdot
.84 .37654 Mdot
.84 .37713 Mdot
.84 .37713 Mdot
.84 .37762 Mdot
.84 .37787 Mdot
.84 .37808 Mdot
.84 .37829 Mdot
.84 .37847 Mdot
.84 .37874 Mdot
.84 .37893 Mdot
.84 .37983 Mdot
.84 .37999 Mdot
.84 .38053 Mdot
.84 .38059 Mdot
.84 .3813 Mdot
.84 .38151 Mdot
.84 .38168 Mdot
.84 .38191 Mdot
.84 .38209 Mdot
.84 .38239 Mdot
.84 .38249 Mdot
.84 .38287 Mdot
.84 .38293 Mdot
.84 .38312 Mdot
.84 .38339 Mdot
.84 .38347 Mdot
.84 .38361 Mdot
.84 .38367 Mdot
.84 .38397 Mdot
.84 .38414 Mdot
.84 .38416 Mdot
.84 .38434 Mdot
.84 .38441 Mdot
.84 .38462 Mdot
.84 .38466 Mdot
.84 .38477 Mdot
.84 .38488 Mdot
.84 .38518 Mdot
.84 .38523 Mdot
.84 .3855 Mdot
.84 .386 Mdot
.84 .38611 Mdot
.84 .38625 Mdot
.84 .38635 Mdot
.84 .38647 Mdot
.84 .3869 Mdot
.84 .38693 Mdot
.84 .38725 Mdot
.84 .38735 Mdot
.84 .38788 Mdot
.84 .388 Mdot
.84 .38816 Mdot
.84 .38866 Mdot
.84 .38896 Mdot
.84 .38931 Mdot
.84 .38935 Mdot
.84 .38943 Mdot
.84 .38964 Mdot
.84 .38999 Mdot
.84 .39047 Mdot
.84 .39048 Mdot
.84 .39111 Mdot
.84 .39119 Mdot
.84 .39129 Mdot
.84 .39144 Mdot
.84 .39193 Mdot
.84 .39219 Mdot
.84 .39246 Mdot
.84 .39334 Mdot
.84 .39368 Mdot
.84 .39398 Mdot
.84 .39429 Mdot
.84 .39432 Mdot
.84 .39466 Mdot
.84 .39475 Mdot
.84 .3948 Mdot
.84 .39504 Mdot
.84 .39521 Mdot
.84 .39529 Mdot
.84 .39534 Mdot
.84 .3954 Mdot
.84 .39542 Mdot
.84 .39546 Mdot
.84 .39575 Mdot
.84 .39606 Mdot
.84 .39617 Mdot
.84 .39618 Mdot
.84 .39699 Mdot
.84 .397 Mdot
.84 .39799 Mdot
.84 .39803 Mdot
.84 .39811 Mdot
.84 .39833 Mdot
.84 .39839 Mdot
.84 .39892 Mdot
.84 .39917 Mdot
.84 .3996 Mdot
.84 .39992 Mdot
.84 .39995 Mdot
.84 .40036 Mdot
.84 .40074 Mdot
.84 .40089 Mdot
.84 .40126 Mdot
.84 .40131 Mdot
.84 .40138 Mdot
.84 .40144 Mdot
.84 .40181 Mdot
.84 .4019 Mdot
.84 .40309 Mdot
.84 .4033 Mdot
.84 .40358 Mdot
.84 .40398 Mdot
.84 .40401 Mdot
.84 .40485 Mdot
.84 .40538 Mdot
.84 .4054 Mdot
.84 .40541 Mdot
.84 .40613 Mdot
.84 .40651 Mdot
.84 .40688 Mdot
.84 .4071 Mdot
.84 .40863 Mdot
.84 .40885 Mdot
.84 .40899 Mdot
.84 .40937 Mdot
.84 .40968 Mdot
.84 .40997 Mdot
.84 .41034 Mdot
.84 .41041 Mdot
.84 .41041 Mdot
.84 .41043 Mdot
.84 .41065 Mdot
.84 .41117 Mdot
.84 .41157 Mdot
.84 .41163 Mdot
.84 .41205 Mdot
.84 .41214 Mdot
.84 .41306 Mdot
.84 .41309 Mdot
.84 .41335 Mdot
.84 .4135 Mdot
.84 .41418 Mdot
.84 .41465 Mdot
.84 .41488 Mdot
.84 .41501 Mdot
.84 .41518 Mdot
.84 .41525 Mdot
.84 .41529 Mdot
.84 .41537 Mdot
.84 .41616 Mdot
.84 .41622 Mdot
.84 .4169 Mdot
.84 .41692 Mdot
.84 .41704 Mdot
.84 .41737 Mdot
.84 .41737 Mdot
.84 .4178 Mdot
.84 .41794 Mdot
.84 .41899 Mdot
.84 .41965 Mdot
.84 .41967 Mdot
.84 .41971 Mdot
.84 .41994 Mdot
.84 .42007 Mdot
.84 .42027 Mdot
.84 .42031 Mdot
.84 .42072 Mdot
.84 .4225 Mdot
.84 .42253 Mdot
.84 .42261 Mdot
.84 .42282 Mdot
.84 .42309 Mdot
.84 .42318 Mdot
.84 .42347 Mdot
.84 .42363 Mdot
.84 .42394 Mdot
.84 .42455 Mdot
.84 .42512 Mdot
.84 .42538 Mdot
.84 .42569 Mdot
.84 .42582 Mdot
.84 .42589 Mdot
.84 .42704 Mdot
.84 .42744 Mdot
.84 .42784 Mdot
.84 .42794 Mdot
.84 .42803 Mdot
.84 .42803 Mdot
.84 .42825 Mdot
.84 .42853 Mdot
.84 .42896 Mdot
.84 .42919 Mdot
.84 .42981 Mdot
.84 .42994 Mdot
.84 .42998 Mdot
.84 .43021 Mdot
.84 .43027 Mdot
.84 .4305 Mdot
.84 .43068 Mdot
.84 .43152 Mdot
.84 .43173 Mdot
.84 .43186 Mdot
.84 .43186 Mdot
.84 .43207 Mdot
.84 .43218 Mdot
.84 .43223 Mdot
.84 .43269 Mdot
.84 .43327 Mdot
.84 .43346 Mdot
.84 .43348 Mdot
.84 .43352 Mdot
.84 .43551 Mdot
.84 .43554 Mdot
.84 .4357 Mdot
.84 .43572 Mdot
.84 .4358 Mdot
.84 .43582 Mdot
.84 .43689 Mdot
.84 .43746 Mdot
.84 .43747 Mdot
.84 .43826 Mdot
.84 .43827 Mdot
.84 .43881 Mdot
.84 .43919 Mdot
.84 .4394 Mdot
.84 .4395 Mdot
.84 .44018 Mdot
.84 .4402 Mdot
.84 .44078 Mdot
.84 .44124 Mdot
.84 .44187 Mdot
.84 .44229 Mdot
.84 .44237 Mdot
.84 .44334 Mdot
.84 .44342 Mdot
.84 .44344 Mdot
.84 .44413 Mdot
.84 .44548 Mdot
.84 .44614 Mdot
.84 .44625 Mdot
.84 .44627 Mdot
.84 .44653 Mdot
.84 .44684 Mdot
.84 .44746 Mdot
.84 .4476 Mdot
.84 .44781 Mdot
.84 .44822 Mdot
.84 .45253 Mdot
.84 .45316 Mdot
.84 .45318 Mdot
.84 .45356 Mdot
.84 .45393 Mdot
.84 .45461 Mdot
.84 .45548 Mdot
.84 .4563 Mdot
.84 .45631 Mdot
.84 .45736 Mdot
.84 .45746 Mdot
.84 .45755 Mdot
.84 .45756 Mdot
.84 .45761 Mdot
.84 .45806 Mdot
.84 .45824 Mdot
.84 .45845 Mdot
.84 .45899 Mdot
.84 .45968 Mdot
.84 .46019 Mdot
.84 .46083 Mdot
.84 .46099 Mdot
.84 .46106 Mdot
.84 .46121 Mdot
.84 .46181 Mdot
.84 .46186 Mdot
.84 .46217 Mdot
.84 .46218 Mdot
.84 .46242 Mdot
.84 .46275 Mdot
.84 .46354 Mdot
.84 .46405 Mdot
.84 .46407 Mdot
.84 .46448 Mdot
.84 .46448 Mdot
.84 .46503 Mdot
.84 .46511 Mdot
.84 .46586 Mdot
.84 .46626 Mdot
.84 .46785 Mdot
.84 .4679 Mdot
.84 .46819 Mdot
.84 .46831 Mdot
.84 .46846 Mdot
.84 .46952 Mdot
.84 .46957 Mdot
.84 .46978 Mdot
.84 .46979 Mdot
.84 .46982 Mdot
.84 .46984 Mdot
.84 .46987 Mdot
.84 .47001 Mdot
.84 .47006 Mdot
.84 .47018 Mdot
.84 .47041 Mdot
.84 .47053 Mdot
.84 .47103 Mdot
.84 .4712 Mdot
.84 .47132 Mdot
.84 .47154 Mdot
.84 .47155 Mdot
.84 .47191 Mdot
.84 .47196 Mdot
.84 .47246 Mdot
.84 .47281 Mdot
.84 .47304 Mdot
.84 .4736 Mdot
.84 .47362 Mdot
.84 .47379 Mdot
.84 .47395 Mdot
.84 .47397 Mdot
.84 .47415 Mdot
.84 .47424 Mdot
.84 .47437 Mdot
.84 .47441 Mdot
.84 .47586 Mdot
.84 .47593 Mdot
.84 .47601 Mdot
.84 .47627 Mdot
.84 .47649 Mdot
.84 .47657 Mdot
.84 .47698 Mdot
.84 .4772 Mdot
.84 .47721 Mdot
.84 .47729 Mdot
.84 .4773 Mdot
.84 .47774 Mdot
.84 .47793 Mdot
.84 .47805 Mdot
.84 .4784 Mdot
.84 .4788 Mdot
.84 .47895 Mdot
.84 .47901 Mdot
.84 .4791 Mdot
.84 .47915 Mdot
.84 .48091 Mdot
.84 .48111 Mdot
.84 .48119 Mdot
.84 .48177 Mdot
.84 .48179 Mdot
.84 .48208 Mdot
.84 .48226 Mdot
.84 .48232 Mdot
.84 .48278 Mdot
.84 .48286 Mdot
.84 .48301 Mdot
.84 .48355 Mdot
.84 .48362 Mdot
.84 .48369 Mdot
.84 .4838 Mdot
.84 .48439 Mdot
.84 .4844 Mdot
.84 .48443 Mdot
.84 .48444 Mdot
.84 .48446 Mdot
.84 .48481 Mdot
.84 .48509 Mdot
.84 .48517 Mdot
.84 .48538 Mdot
.84 .4855 Mdot
.84 .48664 Mdot
.84 .48666 Mdot
.84 .48666 Mdot
.84 .48678 Mdot
.84 .48691 Mdot
.84 .48812 Mdot
.84 .48828 Mdot
.84 .48935 Mdot
.84 .48981 Mdot
.84 .4905 Mdot
.84 .49123 Mdot
.84 .49131 Mdot
.84 .49134 Mdot
.84 .49158 Mdot
.84 .49164 Mdot
.84 .49167 Mdot
.84 .49175 Mdot
.84 .49199 Mdot
.84 .49208 Mdot
.84 .49219 Mdot
.84 .49259 Mdot
.84 .49334 Mdot
.84 .4936 Mdot
.84 .49427 Mdot
.84 .49441 Mdot
.84 .49471 Mdot
.84 .49485 Mdot
.84 .49575 Mdot
.84 .49614 Mdot
.84 .49718 Mdot
.84 .4974 Mdot
.84 .49745 Mdot
.84 .49758 Mdot
.84 .49779 Mdot
.84 .49789 Mdot
.84 .49796 Mdot
.84 .49805 Mdot
.84 .4985 Mdot
.84 .49901 Mdot
.84 .49907 Mdot
.84 .49925 Mdot
.84 .49928 Mdot
.84 .49951 Mdot
.84 .49962 Mdot
.84 .4998 Mdot
.84 .49983 Mdot
.84 .50014 Mdot
.84 .50026 Mdot
.84 .50068 Mdot
.84 .50104 Mdot
.84 .50118 Mdot
.84 .50125 Mdot
.84 .50142 Mdot
.84 .50159 Mdot
.84 .50189 Mdot
.84 .50208 Mdot
.84 .50241 Mdot
.84 .50249 Mdot
.84 .50249 Mdot
.84 .50284 Mdot
.84 .50345 Mdot
.84 .50354 Mdot
.84 .50434 Mdot
.84 .50448 Mdot
.84 .50484 Mdot
.84 .50509 Mdot
.84 .50512 Mdot
.84 .50546 Mdot
.84 .50562 Mdot
.84 .5058 Mdot
.84 .50596 Mdot
.84 .50607 Mdot
.84 .50611 Mdot
.84 .50632 Mdot
.84 .50674 Mdot
.84 .50696 Mdot
.84 .50703 Mdot
.84 .50712 Mdot
.84 .50719 Mdot
.84 .50727 Mdot
.84 .50729 Mdot
.84 .50773 Mdot
.84 .50778 Mdot
.84 .50782 Mdot
.84 .5079 Mdot
.84 .5079 Mdot
.84 .50826 Mdot
.84 .50854 Mdot
.84 .5087 Mdot
.84 .50871 Mdot
.84 .50982 Mdot
.84 .50991 Mdot
.84 .51002 Mdot
.84 .51019 Mdot
.842 .17243 Mdot
.842 .17331 Mdot
.842 .17358 Mdot
.842 .17361 Mdot
.842 .17502 Mdot
.842 .17614 Mdot
.842 .17637 Mdot
.842 .17733 Mdot
.842 .17737 Mdot
.842 .17755 Mdot
.842 .17767 Mdot
.842 .17782 Mdot
.842 .17856 Mdot
.842 .17926 Mdot
.842 .17929 Mdot
.842 .18027 Mdot
.842 .18042 Mdot
.842 .18073 Mdot
.842 .18099 Mdot
.842 .18105 Mdot
.842 .18153 Mdot
.842 .18173 Mdot
.842 .18279 Mdot
.842 .18369 Mdot
.842 .18532 Mdot
.842 .18592 Mdot
.842 .18641 Mdot
.842 .1865 Mdot
.842 .18778 Mdot
.842 .18782 Mdot
.842 .18799 Mdot
.842 .18829 Mdot
.842 .1883 Mdot
.842 .1889 Mdot
.842 .19022 Mdot
.842 .19274 Mdot
.842 .19349 Mdot
.842 .19534 Mdot
.842 .19586 Mdot
.842 .19598 Mdot
.842 .19694 Mdot
.842 .19729 Mdot
.842 .19744 Mdot
.842 .19747 Mdot
.842 .19777 Mdot
.842 .1983 Mdot
.842 .19837 Mdot
.842 .19894 Mdot
.842 .19949 Mdot
.842 .20024 Mdot
.842 .2008 Mdot
.842 .201 Mdot
.842 .20124 Mdot
.842 .20142 Mdot
.842 .20159 Mdot
.842 .20246 Mdot
.842 .20318 Mdot
.842 .20359 Mdot
.842 .20431 Mdot
.842 .20513 Mdot
.842 .20539 Mdot
.842 .20555 Mdot
.842 .20556 Mdot
.842 .20613 Mdot
.842 .2067 Mdot
.842 .20708 Mdot
.842 .20779 Mdot
.842 .20793 Mdot
.842 .20864 Mdot
.842 .20937 Mdot
.842 .21061 Mdot
.842 .21068 Mdot
.842 .211 Mdot
.842 .21157 Mdot
.842 .21188 Mdot
.842 .21224 Mdot
.842 .2128 Mdot
.842 .21344 Mdot
.842 .21389 Mdot
.842 .21414 Mdot
.842 .2142 Mdot
.842 .21428 Mdot
.842 .21441 Mdot
.842 .21496 Mdot
.842 .21526 Mdot
.842 .21539 Mdot
.842 .21688 Mdot
.842 .21755 Mdot
.842 .21758 Mdot
.842 .21759 Mdot
.842 .21796 Mdot
.842 .21873 Mdot
.842 .21921 Mdot
.842 .21923 Mdot
.842 .21941 Mdot
.842 .21983 Mdot
.842 .22114 Mdot
.842 .22119 Mdot
.842 .22225 Mdot
.842 .22244 Mdot
.842 .22347 Mdot
.842 .22381 Mdot
.842 .22447 Mdot
.842 .22478 Mdot
.842 .22482 Mdot
.842 .22578 Mdot
.842 .22591 Mdot
.842 .22626 Mdot
.842 .22653 Mdot
.842 .22678 Mdot
.842 .22759 Mdot
.842 .22826 Mdot
.842 .22928 Mdot
.842 .22967 Mdot
.842 .22973 Mdot
.842 .22999 Mdot
.842 .23006 Mdot
.842 .2306 Mdot
.842 .23083 Mdot
.842 .23145 Mdot
.842 .23162 Mdot
.842 .23175 Mdot
.842 .23189 Mdot
.842 .23229 Mdot
.842 .23262 Mdot
.842 .23339 Mdot
.842 .23375 Mdot
.842 .23404 Mdot
.842 .23427 Mdot
.842 .23454 Mdot
.842 .23475 Mdot
.842 .23514 Mdot
.842 .23519 Mdot
.842 .23543 Mdot
.842 .2357 Mdot
.842 .23574 Mdot
.842 .23623 Mdot
.842 .23694 Mdot
.842 .23716 Mdot
.842 .23729 Mdot
.842 .23796 Mdot
.842 .23855 Mdot
.842 .2391 Mdot
.842 .23985 Mdot
.842 .24058 Mdot
.842 .24265 Mdot
.842 .24295 Mdot
.842 .24407 Mdot
.842 .24417 Mdot
.842 .24452 Mdot
.842 .24493 Mdot
.842 .24525 Mdot
.842 .24549 Mdot
.842 .24573 Mdot
.842 .24651 Mdot
.842 .24658 Mdot
.842 .24668 Mdot
.842 .24878 Mdot
.842 .24929 Mdot
.842 .24931 Mdot
.842 .24939 Mdot
.842 .24952 Mdot
.842 .25082 Mdot
.842 .25192 Mdot
.842 .25202 Mdot
.842 .25265 Mdot
.842 .25292 Mdot
.842 .25311 Mdot
.842 .25319 Mdot
.842 .25328 Mdot
.842 .25349 Mdot
.842 .25381 Mdot
.842 .25382 Mdot
.842 .25424 Mdot
.842 .25504 Mdot
.842 .25573 Mdot
.842 .2572 Mdot
.842 .25789 Mdot
.842 .26029 Mdot
.842 .26032 Mdot
.842 .26127 Mdot
.842 .26145 Mdot
.842 .26287 Mdot
.842 .26334 Mdot
.842 .26397 Mdot
.842 .26405 Mdot
.842 .26421 Mdot
.842 .26424 Mdot
.842 .26475 Mdot
.842 .26519 Mdot
.842 .26531 Mdot
.842 .26538 Mdot
.842 .26592 Mdot
.842 .26614 Mdot
.842 .26645 Mdot
.842 .26678 Mdot
.842 .26785 Mdot
.842 .26829 Mdot
.842 .26935 Mdot
.842 .27018 Mdot
.842 .27068 Mdot
.842 .27101 Mdot
.842 .27115 Mdot
.842 .27118 Mdot
.842 .27251 Mdot
.842 .27254 Mdot
.842 .27299 Mdot
.842 .2734 Mdot
.842 .27461 Mdot
.842 .27462 Mdot
.842 .27526 Mdot
.842 .27579 Mdot
.842 .27666 Mdot
.842 .27673 Mdot
.842 .27707 Mdot
.842 .27715 Mdot
.842 .27844 Mdot
.842 .27845 Mdot
.842 .28006 Mdot
.842 .2803 Mdot
.842 .28058 Mdot
.842 .28093 Mdot
.842 .28099 Mdot
.842 .28115 Mdot
.842 .2814 Mdot
.842 .28179 Mdot
.842 .28225 Mdot
.842 .2823 Mdot
.842 .28232 Mdot
.842 .28367 Mdot
.842 .28376 Mdot
.842 .28417 Mdot
.842 .28467 Mdot
.842 .28612 Mdot
.842 .28633 Mdot
.842 .28656 Mdot
.842 .28694 Mdot
.842 .28713 Mdot
.842 .28753 Mdot
.842 .28781 Mdot
.842 .28794 Mdot
.842 .28821 Mdot
.842 .28847 Mdot
.842 .28856 Mdot
.842 .28862 Mdot
.842 .28884 Mdot
.842 .28892 Mdot
.842 .28911 Mdot
.842 .28914 Mdot
.842 .28939 Mdot
.842 .29036 Mdot
.842 .29062 Mdot
.842 .29096 Mdot
.842 .29144 Mdot
.842 .2918 Mdot
.842 .29187 Mdot
.842 .29287 Mdot
.842 .29293 Mdot
.842 .29338 Mdot
.842 .29351 Mdot
.842 .29352 Mdot
.842 .29376 Mdot
.842 .29428 Mdot
.842 .29433 Mdot
.842 .29471 Mdot
.842 .29473 Mdot
.842 .29482 Mdot
.842 .2952 Mdot
.842 .29563 Mdot
.842 .29583 Mdot
.842 .29597 Mdot
.842 .29667 Mdot
.842 .29735 Mdot
.842 .29755 Mdot
.842 .29776 Mdot
.842 .2979 Mdot
.842 .29859 Mdot
.842 .29915 Mdot
.842 .29921 Mdot
.842 .29928 Mdot
.842 .30009 Mdot
.842 .30031 Mdot
.842 .3006 Mdot
.842 .30061 Mdot
.842 .30067 Mdot
.842 .30113 Mdot
.842 .30117 Mdot
.842 .30135 Mdot
.842 .30201 Mdot
.842 .30303 Mdot
.842 .30316 Mdot
.842 .30384 Mdot
.842 .30384 Mdot
.842 .30395 Mdot
.842 .30401 Mdot
.842 .30402 Mdot
.842 .30447 Mdot
.842 .30451 Mdot
.842 .30578 Mdot
.842 .30615 Mdot
.842 .30623 Mdot
.842 .3064 Mdot
.842 .30642 Mdot
.842 .30651 Mdot
.842 .30662 Mdot
.842 .30701 Mdot
.842 .30703 Mdot
.842 .30727 Mdot
.842 .30805 Mdot
.842 .30812 Mdot
.842 .30852 Mdot
.842 .30902 Mdot
.842 .30903 Mdot
.842 .30944 Mdot
.842 .31027 Mdot
.842 .31169 Mdot
.842 .3117 Mdot
.842 .31176 Mdot
.842 .31181 Mdot
.842 .31186 Mdot
.842 .31272 Mdot
.842 .31393 Mdot
.842 .3145 Mdot
.842 .31472 Mdot
.842 .31577 Mdot
.842 .31712 Mdot
.842 .3186 Mdot
.842 .31889 Mdot
.842 .31911 Mdot
.842 .3195 Mdot
.842 .31976 Mdot
.842 .31996 Mdot
.842 .32003 Mdot
.842 .32055 Mdot
.842 .32095 Mdot
.842 .3212 Mdot
.842 .32158 Mdot
.842 .32164 Mdot
.842 .32218 Mdot
.842 .32243 Mdot
.842 .32248 Mdot
.842 .32298 Mdot
.842 .32345 Mdot
.842 .32387 Mdot
.842 .32399 Mdot
.842 .32442 Mdot
.842 .32472 Mdot
.842 .32476 Mdot
.842 .32495 Mdot
.842 .32588 Mdot
.842 .32628 Mdot
.842 .32646 Mdot
.842 .32667 Mdot
.842 .32713 Mdot
.842 .32715 Mdot
.842 .32808 Mdot
.842 .32831 Mdot
.842 .32842 Mdot
.842 .32882 Mdot
.842 .32894 Mdot
.842 .32912 Mdot
.842 .32941 Mdot
.842 .32965 Mdot
.842 .33014 Mdot
.842 .33017 Mdot
.842 .33088 Mdot
.842 .33107 Mdot
.842 .33168 Mdot
.842 .33176 Mdot
.842 .33194 Mdot
.842 .33207 Mdot
.842 .33209 Mdot
.842 .33217 Mdot
.842 .33228 Mdot
.842 .33271 Mdot
.842 .33278 Mdot
.842 .33347 Mdot
.842 .33373 Mdot
.842 .33399 Mdot
.842 .33482 Mdot
.842 .33526 Mdot
.842 .33538 Mdot
.842 .33552 Mdot
.842 .33581 Mdot
.842 .33608 Mdot
.842 .3361 Mdot
.842 .33614 Mdot
.842 .33688 Mdot
.842 .33706 Mdot
.842 .33802 Mdot
.842 .33834 Mdot
.842 .33844 Mdot
.842 .33854 Mdot
.842 .33866 Mdot
.842 .33866 Mdot
.842 .33985 Mdot
.842 .34009 Mdot
.842 .34128 Mdot
.842 .34135 Mdot
.842 .34185 Mdot
.842 .34201 Mdot
.842 .34227 Mdot
.842 .34233 Mdot
.842 .34251 Mdot
.842 .34271 Mdot
.842 .34293 Mdot
.842 .343 Mdot
.842 .34311 Mdot
.842 .34323 Mdot
.842 .34376 Mdot
.842 .34443 Mdot
.842 .3446 Mdot
.842 .34472 Mdot
.842 .34525 Mdot
.842 .34526 Mdot
.842 .34542 Mdot
.842 .34556 Mdot
.842 .34599 Mdot
.842 .34622 Mdot
.842 .34671 Mdot
.842 .34674 Mdot
.842 .34734 Mdot
.842 .34735 Mdot
.842 .34791 Mdot
.842 .3481 Mdot
.842 .34829 Mdot
.842 .34919 Mdot
.842 .34936 Mdot
.842 .35012 Mdot
.842 .3504 Mdot
.842 .35055 Mdot
.842 .35065 Mdot
.842 .35069 Mdot
.842 .35079 Mdot
.842 .35088 Mdot
.842 .35101 Mdot
.842 .35176 Mdot
.842 .35192 Mdot
.842 .35243 Mdot
.842 .35245 Mdot
.842 .35266 Mdot
.842 .35308 Mdot
.842 .35377 Mdot
.842 .35445 Mdot
.842 .35467 Mdot
.842 .35497 Mdot
.842 .35505 Mdot
.842 .35516 Mdot
.842 .35536 Mdot
.842 .3563 Mdot
.842 .35634 Mdot
.842 .35636 Mdot
.842 .35653 Mdot
.842 .35698 Mdot
.842 .3572 Mdot
.842 .35721 Mdot
.842 .35728 Mdot
.842 .35751 Mdot
.842 .35781 Mdot
.842 .35812 Mdot
.842 .35827 Mdot
.842 .35906 Mdot
.842 .35909 Mdot
.842 .35912 Mdot
.842 .35943 Mdot
.842 .35986 Mdot
.842 .36013 Mdot
.842 .36098 Mdot
.842 .36168 Mdot
.842 .36182 Mdot
.842 .36201 Mdot
.842 .36233 Mdot
.842 .36242 Mdot
.842 .36257 Mdot
.842 .36321 Mdot
.842 .36355 Mdot
.842 .36367 Mdot
.842 .36421 Mdot
.842 .36427 Mdot
.842 .36452 Mdot
.842 .36493 Mdot
.842 .3654 Mdot
.842 .36614 Mdot
.842 .36625 Mdot
.842 .36633 Mdot
.842 .36684 Mdot
.842 .36722 Mdot
.842 .36769 Mdot
.842 .36795 Mdot
.842 .36846 Mdot
.842 .3685 Mdot
.842 .36853 Mdot
.842 .36952 Mdot
.842 .3697 Mdot
.842 .36976 Mdot
.842 .36985 Mdot
.842 .37015 Mdot
.842 .37019 Mdot
.842 .37037 Mdot
.842 .3709 Mdot
.842 .37096 Mdot
.842 .37101 Mdot
.842 .37116 Mdot
.842 .37141 Mdot
.842 .37164 Mdot
.842 .37184 Mdot
.842 .3719 Mdot
.842 .37229 Mdot
.842 .37319 Mdot
.842 .37344 Mdot
.842 .37422 Mdot
.842 .37433 Mdot
.842 .37436 Mdot
.842 .37511 Mdot
.842 .37511 Mdot
.842 .37514 Mdot
.842 .37544 Mdot
.842 .37577 Mdot
.842 .37605 Mdot
.842 .37669 Mdot
.842 .37681 Mdot
.842 .37701 Mdot
.842 .37723 Mdot
.842 .37735 Mdot
.842 .3774 Mdot
.842 .37761 Mdot
.842 .37784 Mdot
.842 .378 Mdot
.842 .37827 Mdot
.842 .37833 Mdot
.842 .37865 Mdot
.842 .3791 Mdot
.842 .37946 Mdot
.842 .37952 Mdot
.842 .37957 Mdot
.842 .37969 Mdot
.842 .37994 Mdot
.842 .37998 Mdot
.842 .38004 Mdot
.842 .3802 Mdot
.842 .38043 Mdot
.842 .38111 Mdot
.842 .38116 Mdot
.842 .38143 Mdot
.842 .38144 Mdot
.842 .38154 Mdot
.842 .38166 Mdot
.842 .38231 Mdot
.842 .38239 Mdot
.842 .38256 Mdot
.842 .38283 Mdot
.842 .38296 Mdot
.842 .38298 Mdot
.842 .383 Mdot
.842 .38313 Mdot
.842 .38356 Mdot
.842 .38366 Mdot
.842 .384 Mdot
.842 .38406 Mdot
.842 .38415 Mdot
.842 .38421 Mdot
.842 .38444 Mdot
.842 .38456 Mdot
.842 .38476 Mdot
.842 .38483 Mdot
.842 .38489 Mdot
.842 .38494 Mdot
.842 .38505 Mdot
.842 .38526 Mdot
.842 .3853 Mdot
.842 .38539 Mdot
.842 .38559 Mdot
.842 .3859 Mdot
.842 .38598 Mdot
.842 .38599 Mdot
.842 .38608 Mdot
.842 .38624 Mdot
.842 .38634 Mdot
.842 .38639 Mdot
.842 .38685 Mdot
.842 .38691 Mdot
.842 .38691 Mdot
.842 .38707 Mdot
.842 .38774 Mdot
.842 .3878 Mdot
.842 .38802 Mdot
.842 .38805 Mdot
.842 .38808 Mdot
.842 .3883 Mdot
.842 .38875 Mdot
.842 .38895 Mdot
.842 .38905 Mdot
.842 .38918 Mdot
.842 .38931 Mdot
.842 .38954 Mdot
.842 .39027 Mdot
.842 .39047 Mdot
.842 .39065 Mdot
.842 .39066 Mdot
.842 .39067 Mdot
.842 .39111 Mdot
.842 .3912 Mdot
.842 .39166 Mdot
.842 .39234 Mdot
.842 .39257 Mdot
.842 .39273 Mdot
.842 .39301 Mdot
.842 .3931 Mdot
.842 .39317 Mdot
.842 .39359 Mdot
.842 .39379 Mdot
.842 .39384 Mdot
.842 .39388 Mdot
.842 .39398 Mdot
.842 .39459 Mdot
.842 .39507 Mdot
.842 .39535 Mdot
.842 .39588 Mdot
.842 .39599 Mdot
.842 .39643 Mdot
.842 .39671 Mdot
.842 .3971 Mdot
.842 .39746 Mdot
.842 .39753 Mdot
.842 .39773 Mdot
.842 .39811 Mdot
.842 .39845 Mdot
.842 .39856 Mdot
.842 .39864 Mdot
.842 .39906 Mdot
.842 .39973 Mdot
.842 .4002 Mdot
.842 .40075 Mdot
.842 .40094 Mdot
.842 .40112 Mdot
.842 .40126 Mdot
.842 .4013 Mdot
.842 .4013 Mdot
.842 .4017 Mdot
.842 .4024 Mdot
.842 .40258 Mdot
.842 .40262 Mdot
.842 .40281 Mdot
.842 .40294 Mdot
.842 .40334 Mdot
.842 .40375 Mdot
.842 .40412 Mdot
.842 .40454 Mdot
.842 .40506 Mdot
.842 .40517 Mdot
.842 .40534 Mdot
.842 .40606 Mdot
.842 .40671 Mdot
.842 .40682 Mdot
.842 .40715 Mdot
.842 .40753 Mdot
.842 .40796 Mdot
.842 .40821 Mdot
.842 .4083 Mdot
.842 .4084 Mdot
.842 .40889 Mdot
.842 .40928 Mdot
.842 .4096 Mdot
.842 .40967 Mdot
.842 .40973 Mdot
.842 .40978 Mdot
.842 .40991 Mdot
.842 .41013 Mdot
.842 .41017 Mdot
.842 .41032 Mdot
.842 .41042 Mdot
.842 .41072 Mdot
.842 .41231 Mdot
.842 .41238 Mdot
.842 .41244 Mdot
.842 .4125 Mdot
.842 .41337 Mdot
.842 .41381 Mdot
.842 .41417 Mdot
.842 .41433 Mdot
.842 .41459 Mdot
.842 .41524 Mdot
.842 .4154 Mdot
.842 .41585 Mdot
.842 .4161 Mdot
.842 .41616 Mdot
.842 .41622 Mdot
.842 .4163 Mdot
.842 .41641 Mdot
.842 .41645 Mdot
.842 .41682 Mdot
.842 .41736 Mdot
.842 .41737 Mdot
.842 .41766 Mdot
.842 .41808 Mdot
.842 .41846 Mdot
.842 .41915 Mdot
.842 .41943 Mdot
.842 .41956 Mdot
.842 .41966 Mdot
.842 .42056 Mdot
.842 .42059 Mdot
.842 .42077 Mdot
.842 .42135 Mdot
.842 .42242 Mdot
.842 .42268 Mdot
.842 .42283 Mdot
.842 .42307 Mdot
.842 .42337 Mdot
.842 .42369 Mdot
.842 .42392 Mdot
.842 .42422 Mdot
.842 .4251 Mdot
.842 .42653 Mdot
.842 .427 Mdot
.842 .42771 Mdot
.842 .42823 Mdot
.842 .42826 Mdot
.842 .42828 Mdot
.842 .42832 Mdot
.842 .42833 Mdot
.842 .42967 Mdot
.842 .42991 Mdot
.842 .42991 Mdot
.842 .43021 Mdot
.842 .43044 Mdot
.842 .43095 Mdot
.842 .43134 Mdot
.842 .43146 Mdot
.842 .43147 Mdot
.842 .43184 Mdot
.842 .43259 Mdot
.842 .43261 Mdot
.842 .43288 Mdot
.842 .43292 Mdot
.842 .43299 Mdot
.842 .43339 Mdot
.842 .43446 Mdot
.842 .43457 Mdot
.842 .4346 Mdot
.842 .43487 Mdot
.842 .4349 Mdot
.842 .43491 Mdot
.842 .43508 Mdot
.842 .43522 Mdot
.842 .43574 Mdot
.842 .43577 Mdot
.842 .4361 Mdot
.842 .43651 Mdot
.842 .43672 Mdot
.842 .43684 Mdot
.842 .43725 Mdot
.842 .43774 Mdot
.842 .43812 Mdot
.842 .43841 Mdot
.842 .43863 Mdot
.842 .43912 Mdot
.842 .4392 Mdot
.842 .43947 Mdot
.842 .4395 Mdot
.842 .44035 Mdot
.842 .44064 Mdot
.842 .441 Mdot
.842 .44173 Mdot
.842 .44189 Mdot
.842 .44212 Mdot
.842 .44227 Mdot
.842 .44243 Mdot
.842 .44251 Mdot
.842 .44267 Mdot
.842 .44291 Mdot
.842 .44339 Mdot
.842 .44351 Mdot
.842 .44467 Mdot
.842 .44491 Mdot
.842 .44496 Mdot
.842 .44577 Mdot
.842 .44631 Mdot
.842 .44646 Mdot
.842 .44656 Mdot
.842 .4466 Mdot
.842 .4468 Mdot
.842 .44711 Mdot
.842 .44806 Mdot
.842 .44807 Mdot
.842 .44884 Mdot
.842 .44889 Mdot
.842 .44909 Mdot
.842 .44913 Mdot
.842 .44965 Mdot
.842 .44996 Mdot
.842 .45034 Mdot
.842 .45034 Mdot
.842 .45106 Mdot
.842 .45131 Mdot
.842 .45158 Mdot
.842 .4516 Mdot
.842 .45238 Mdot
.842 .4524 Mdot
.842 .45248 Mdot
.842 .45268 Mdot
.842 .45298 Mdot
.842 .45347 Mdot
.842 .4541 Mdot
.842 .45436 Mdot
.842 .45499 Mdot
.842 .45519 Mdot
.842 .45537 Mdot
.842 .45551 Mdot
.842 .45582 Mdot
.842 .45587 Mdot
.842 .45594 Mdot
.842 .4562 Mdot
.842 .45651 Mdot
.842 .45652 Mdot
.842 .45662 Mdot
.842 .45666 Mdot
.842 .45704 Mdot
.842 .45732 Mdot
.842 .45816 Mdot
.842 .45827 Mdot
.842 .45883 Mdot
.842 .45885 Mdot
.842 .46027 Mdot
.842 .46068 Mdot
.842 .46155 Mdot
.842 .46196 Mdot
.842 .46244 Mdot
.842 .46269 Mdot
.842 .4627 Mdot
.842 .46288 Mdot
.842 .46301 Mdot
.842 .46307 Mdot
.842 .46312 Mdot
.842 .46323 Mdot
.842 .46339 Mdot
.842 .46376 Mdot
.842 .46382 Mdot
.842 .46447 Mdot
.842 .46524 Mdot
.842 .46532 Mdot
.842 .46537 Mdot
.842 .46538 Mdot
.842 .46568 Mdot
.842 .46693 Mdot
.842 .46699 Mdot
.842 .46703 Mdot
.842 .46749 Mdot
.842 .46764 Mdot
.842 .46778 Mdot
.842 .46797 Mdot
.842 .46822 Mdot
.842 .46842 Mdot
.842 .46848 Mdot
.842 .46915 Mdot
.842 .46932 Mdot
.842 .47055 Mdot
.842 .47099 Mdot
.842 .47144 Mdot
.842 .47176 Mdot
.842 .47211 Mdot
.842 .4725 Mdot
.842 .47259 Mdot
.842 .47271 Mdot
.842 .47314 Mdot
.842 .47343 Mdot
.842 .47345 Mdot
.842 .47361 Mdot
.842 .47376 Mdot
.842 .47379 Mdot
.842 .47401 Mdot
.842 .47414 Mdot
.842 .4743 Mdot
.842 .47444 Mdot
.842 .47461 Mdot
.842 .47482 Mdot
.842 .47528 Mdot
.842 .47548 Mdot
.842 .47572 Mdot
.842 .4758 Mdot
.842 .47587 Mdot
.842 .47598 Mdot
.842 .47635 Mdot
.842 .47648 Mdot
.842 .4768 Mdot
.842 .47684 Mdot
.842 .47699 Mdot
.842 .47703 Mdot
.842 .47726 Mdot
.842 .47787 Mdot
.842 .47827 Mdot
.842 .47875 Mdot
.842 .4789 Mdot
.842 .47906 Mdot
.842 .47926 Mdot
.842 .47934 Mdot
.842 .47991 Mdot
.842 .47994 Mdot
.842 .48012 Mdot
.842 .48051 Mdot
.842 .48072 Mdot
.842 .48133 Mdot
.842 .48144 Mdot
.842 .48207 Mdot
.842 .4821 Mdot
.842 .48287 Mdot
.842 .48312 Mdot
.842 .48323 Mdot
.842 .48324 Mdot
.842 .48353 Mdot
.842 .48399 Mdot
.842 .4842 Mdot
.842 .48421 Mdot
.842 .48423 Mdot
.842 .48463 Mdot
.842 .48551 Mdot
.842 .48559 Mdot
.842 .48577 Mdot
.842 .48609 Mdot
.842 .48617 Mdot
.842 .48622 Mdot
.842 .48625 Mdot
.842 .4864 Mdot
.842 .48667 Mdot
.842 .48705 Mdot
.842 .48739 Mdot
.842 .4876 Mdot
.842 .48778 Mdot
.842 .48812 Mdot
.842 .48831 Mdot
.842 .48835 Mdot
.842 .48909 Mdot
.842 .48952 Mdot
.842 .48994 Mdot
.842 .49003 Mdot
.842 .49045 Mdot
.842 .49067 Mdot
.842 .49101 Mdot
.842 .49135 Mdot
.842 .49136 Mdot
.842 .49145 Mdot
.842 .4916 Mdot
.842 .49209 Mdot
.842 .49252 Mdot
.842 .49276 Mdot
.842 .49319 Mdot
.842 .49371 Mdot
.842 .49381 Mdot
.842 .49392 Mdot
.842 .49406 Mdot
.842 .49418 Mdot
.842 .49451 Mdot
.842 .49495 Mdot
.842 .49528 Mdot
.842 .49562 Mdot
.842 .49566 Mdot
.842 .49597 Mdot
.842 .49615 Mdot
.842 .49617 Mdot
.842 .49626 Mdot
.842 .49647 Mdot
.842 .49704 Mdot
.842 .49711 Mdot
.842 .49742 Mdot
.842 .49852 Mdot
.842 .49896 Mdot
.842 .50046 Mdot
.842 .50124 Mdot
.842 .5016 Mdot
.842 .50161 Mdot
.842 .50178 Mdot
.842 .50188 Mdot
.842 .50191 Mdot
.842 .50267 Mdot
.842 .50272 Mdot
.842 .50301 Mdot
.842 .50337 Mdot
.842 .50433 Mdot
.842 .50487 Mdot
.842 .5055 Mdot
.842 .50562 Mdot
.842 .50591 Mdot
.842 .50594 Mdot
.842 .50609 Mdot
.842 .50628 Mdot
.842 .50637 Mdot
.842 .50695 Mdot
.842 .50697 Mdot
.842 .50739 Mdot
.842 .50782 Mdot
.842 .50791 Mdot
.842 .50798 Mdot
.842 .50809 Mdot
.842 .50811 Mdot
.842 .50868 Mdot
.842 .50882 Mdot
.842 .50948 Mdot
.842 .51032 Mdot
.842 .51034 Mdot
.842 .5105 Mdot
.842 .51102 Mdot
.844 .17085 Mdot
.844 .1711 Mdot
.844 .17243 Mdot
.844 .17283 Mdot
.844 .1731 Mdot
.844 .17346 Mdot
.844 .17349 Mdot
.844 .17379 Mdot
.844 .17396 Mdot
.844 .17407 Mdot
.844 .17459 Mdot
.844 .1769 Mdot
.844 .17885 Mdot
.844 .17956 Mdot
.844 .17962 Mdot
.844 .17965 Mdot
.844 .17987 Mdot
.844 .1799 Mdot
.844 .18054 Mdot
.844 .18085 Mdot
.844 .18103 Mdot
.844 .1829 Mdot
.844 .18316 Mdot
.844 .18329 Mdot
.844 .1833 Mdot
.844 .18441 Mdot
.844 .18464 Mdot
.844 .18514 Mdot
.844 .1859 Mdot
.844 .18601 Mdot
.844 .18672 Mdot
.844 .18672 Mdot
.844 .18719 Mdot
.844 .18723 Mdot
.844 .18743 Mdot
.844 .18853 Mdot
.844 .18876 Mdot
.844 .18884 Mdot
.844 .18898 Mdot
.844 .19024 Mdot
.844 .19089 Mdot
.844 .19151 Mdot
.844 .19303 Mdot
.844 .19331 Mdot
.844 .19366 Mdot
.844 .19437 Mdot
.844 .19487 Mdot
.844 .19581 Mdot
.844 .19604 Mdot
.844 .19655 Mdot
.844 .19675 Mdot
.844 .1973 Mdot
.844 .19854 Mdot
.844 .1987 Mdot
.844 .19903 Mdot
.844 .19939 Mdot
.844 .19973 Mdot
.844 .19978 Mdot
.844 .20041 Mdot
.844 .2006 Mdot
.844 .20129 Mdot
.844 .20167 Mdot
.844 .20167 Mdot
.844 .20168 Mdot
.844 .20286 Mdot
.844 .20291 Mdot
.844 .20298 Mdot
.844 .20314 Mdot
.844 .20368 Mdot
.844 .20414 Mdot
.844 .20512 Mdot
.844 .20548 Mdot
.844 .20584 Mdot
.844 .20586 Mdot
.844 .20633 Mdot
.844 .20772 Mdot
.844 .20821 Mdot
.844 .20936 Mdot
.844 .21028 Mdot
.844 .21063 Mdot
.844 .21112 Mdot
.844 .2114 Mdot
.844 .21152 Mdot
.844 .21171 Mdot
.844 .21252 Mdot
.844 .21263 Mdot
.844 .21301 Mdot
.844 .21306 Mdot
.844 .21373 Mdot
.844 .21447 Mdot
.844 .21471 Mdot
.844 .21563 Mdot
.844 .21608 Mdot
.844 .2161 Mdot
.844 .2161 Mdot
.844 .21622 Mdot
.844 .21636 Mdot
.844 .21638 Mdot
.844 .21642 Mdot
.844 .21713 Mdot
.844 .21728 Mdot
.844 .21733 Mdot
.844 .21743 Mdot
.844 .21773 Mdot
.844 .2178 Mdot
.844 .21781 Mdot
.844 .21943 Mdot
.844 .21965 Mdot
.844 .22089 Mdot
.844 .22114 Mdot
.844 .22128 Mdot
.844 .22151 Mdot
.844 .22182 Mdot
.844 .22195 Mdot
.844 .22227 Mdot
.844 .2227 Mdot
.844 .22294 Mdot
.844 .22361 Mdot
.844 .22391 Mdot
.844 .22403 Mdot
.844 .22412 Mdot
.844 .2252 Mdot
.844 .22541 Mdot
.844 .22557 Mdot
.844 .22692 Mdot
.844 .22699 Mdot
.844 .2276 Mdot
.844 .22801 Mdot
.844 .22876 Mdot
.844 .22877 Mdot
.844 .22879 Mdot
.844 .23051 Mdot
.844 .23101 Mdot
.844 .23138 Mdot
.844 .23148 Mdot
.844 .23304 Mdot
.844 .2342 Mdot
.844 .2345 Mdot
.844 .23471 Mdot
.844 .23507 Mdot
.844 .23509 Mdot
.844 .23547 Mdot
.844 .23581 Mdot
.844 .23629 Mdot
.844 .23631 Mdot
.844 .23637 Mdot
.844 .23841 Mdot
.844 .2389 Mdot
.844 .24016 Mdot
.844 .24063 Mdot
.844 .24063 Mdot
.844 .24068 Mdot
.844 .24117 Mdot
.844 .24124 Mdot
.844 .24213 Mdot
.844 .24411 Mdot
.844 .24425 Mdot
.844 .24461 Mdot
.844 .24465 Mdot
.844 .24533 Mdot
.844 .24535 Mdot
.844 .24548 Mdot
.844 .24553 Mdot
.844 .24589 Mdot
.844 .24689 Mdot
.844 .24697 Mdot
.844 .24704 Mdot
.844 .2471 Mdot
.844 .24712 Mdot
.844 .24717 Mdot
.844 .24726 Mdot
.844 .24748 Mdot
.844 .24871 Mdot
.844 .24881 Mdot
.844 .24883 Mdot
.844 .2489 Mdot
.844 .25007 Mdot
.844 .25039 Mdot
.844 .25046 Mdot
.844 .25116 Mdot
.844 .25194 Mdot
.844 .252 Mdot
.844 .252 Mdot
.844 .25314 Mdot
.844 .25356 Mdot
.844 .25368 Mdot
.844 .25388 Mdot
.844 .25498 Mdot
.844 .25519 Mdot
.844 .25628 Mdot
.844 .25629 Mdot
.844 .25717 Mdot
.844 .25734 Mdot
.844 .25787 Mdot
.844 .25839 Mdot
.844 .25884 Mdot
.844 .25961 Mdot
.844 .26021 Mdot
.844 .26079 Mdot
.844 .26082 Mdot
.844 .26187 Mdot
.844 .26231 Mdot
.844 .26302 Mdot
.844 .26483 Mdot
.844 .26506 Mdot
.844 .26565 Mdot
.844 .26575 Mdot
.844 .26582 Mdot
.844 .26639 Mdot
.844 .26657 Mdot
.844 .26695 Mdot
.844 .26734 Mdot
.844 .26735 Mdot
.844 .26859 Mdot
.844 .27016 Mdot
.844 .27115 Mdot
.844 .27187 Mdot
.844 .27422 Mdot
.844 .27512 Mdot
.844 .27556 Mdot
.844 .27615 Mdot
.844 .27636 Mdot
.844 .27707 Mdot
.844 .27733 Mdot
.844 .27786 Mdot
.844 .27827 Mdot
.844 .27854 Mdot
.844 .2787 Mdot
.844 .27907 Mdot
.844 .27913 Mdot
.844 .27982 Mdot
.844 .27989 Mdot
.844 .28028 Mdot
.844 .2804 Mdot
.844 .28094 Mdot
.844 .28094 Mdot
.844 .28096 Mdot
.844 .28148 Mdot
.844 .28151 Mdot
.844 .28162 Mdot
.844 .28206 Mdot
.844 .2821 Mdot
.844 .28268 Mdot
.844 .28271 Mdot
.844 .28273 Mdot
.844 .28323 Mdot
.844 .28328 Mdot
.844 .28352 Mdot
.844 .28354 Mdot
.844 .28371 Mdot
.844 .28458 Mdot
.844 .28554 Mdot
.844 .28645 Mdot
.844 .28674 Mdot
.844 .28719 Mdot
.844 .2876 Mdot
.844 .28814 Mdot
.844 .28848 Mdot
.844 .29022 Mdot
.844 .29035 Mdot
.844 .29073 Mdot
.844 .29076 Mdot
.844 .29149 Mdot
.844 .29177 Mdot
.844 .29186 Mdot
.844 .29295 Mdot
.844 .29297 Mdot
.844 .29307 Mdot
.844 .29313 Mdot
.844 .29318 Mdot
.844 .29345 Mdot
.844 .2935 Mdot
.844 .29354 Mdot
.844 .29354 Mdot
.844 .29461 Mdot
.844 .29463 Mdot
.844 .29476 Mdot
.844 .2948 Mdot
.844 .29508 Mdot
.844 .29515 Mdot
.844 .29529 Mdot
.844 .29546 Mdot
.844 .29558 Mdot
.844 .29591 Mdot
.844 .29727 Mdot
.844 .2979 Mdot
.844 .29809 Mdot
.844 .29815 Mdot
.844 .29819 Mdot
.844 .29861 Mdot
.844 .29874 Mdot
.844 .29905 Mdot
.844 .29927 Mdot
.844 .29929 Mdot
.844 .29941 Mdot
.844 .29953 Mdot
.844 .2997 Mdot
.844 .30033 Mdot
.844 .3004 Mdot
.844 .30066 Mdot
.844 .30099 Mdot
.844 .30117 Mdot
.844 .30154 Mdot
.844 .30239 Mdot
.844 .30306 Mdot
.844 .30311 Mdot
.844 .3036 Mdot
.844 .30368 Mdot
.844 .30385 Mdot
.844 .30385 Mdot
.844 .3041 Mdot
.844 .30458 Mdot
.844 .30466 Mdot
.844 .30505 Mdot
.844 .30506 Mdot
.844 .3051 Mdot
.844 .30585 Mdot
.844 .30591 Mdot
.844 .30602 Mdot
.844 .30626 Mdot
.844 .30633 Mdot
.844 .30634 Mdot
.844 .30637 Mdot
.844 .30811 Mdot
.844 .3085 Mdot
.844 .30863 Mdot
.844 .30887 Mdot
.844 .30933 Mdot
.844 .30942 Mdot
.844 .31067 Mdot
.844 .3109 Mdot
.844 .311 Mdot
.844 .31106 Mdot
.844 .3111 Mdot
.844 .31209 Mdot
.844 .31278 Mdot
.844 .31315 Mdot
.844 .3142 Mdot
.844 .31499 Mdot
.844 .31525 Mdot
.844 .3157 Mdot
.844 .31617 Mdot
.844 .31626 Mdot
.844 .31678 Mdot
.844 .31722 Mdot
.844 .31775 Mdot
.844 .31798 Mdot
.844 .31881 Mdot
.844 .31925 Mdot
.844 .31974 Mdot
.844 .32041 Mdot
.844 .32079 Mdot
.844 .32079 Mdot
.844 .32122 Mdot
.844 .32165 Mdot
.844 .322 Mdot
.844 .32225 Mdot
.844 .32226 Mdot
.844 .32242 Mdot
.844 .32291 Mdot
.844 .32308 Mdot
.844 .3242 Mdot
.844 .32502 Mdot
.844 .32528 Mdot
.844 .32536 Mdot
.844 .32569 Mdot
.844 .32585 Mdot
.844 .32595 Mdot
.844 .32596 Mdot
.844 .32628 Mdot
.844 .32645 Mdot
.844 .32702 Mdot
.844 .3271 Mdot
.844 .32767 Mdot
.844 .32775 Mdot
.844 .32786 Mdot
.844 .32802 Mdot
.844 .32817 Mdot
.844 .32825 Mdot
.844 .32849 Mdot
.844 .32859 Mdot
.844 .32912 Mdot
.844 .32965 Mdot
.844 .32967 Mdot
.844 .32989 Mdot
.844 .33003 Mdot
.844 .33029 Mdot
.844 .3303 Mdot
.844 .3303 Mdot
.844 .33108 Mdot
.844 .33121 Mdot
.844 .33231 Mdot
.844 .33238 Mdot
.844 .33251 Mdot
.844 .33252 Mdot
.844 .33277 Mdot
.844 .33294 Mdot
.844 .33296 Mdot
.844 .33368 Mdot
.844 .3343 Mdot
.844 .33446 Mdot
.844 .33446 Mdot
.844 .33448 Mdot
.844 .33465 Mdot
.844 .33467 Mdot
.844 .33499 Mdot
.844 .33573 Mdot
.844 .33612 Mdot
.844 .33618 Mdot
.844 .33631 Mdot
.844 .33673 Mdot
.844 .33674 Mdot
.844 .33676 Mdot
.844 .33679 Mdot
.844 .33687 Mdot
.844 .33734 Mdot
.844 .33736 Mdot
.844 .33816 Mdot
.844 .33885 Mdot
.844 .33904 Mdot
.844 .33995 Mdot
.844 .33996 Mdot
.844 .34051 Mdot
.844 .34133 Mdot
.844 .34155 Mdot
.844 .34191 Mdot
.844 .34295 Mdot
.844 .34328 Mdot
.844 .3433 Mdot
.844 .3435 Mdot
.844 .34356 Mdot
.844 .3437 Mdot
.844 .34384 Mdot
.844 .34483 Mdot
.844 .34542 Mdot
.844 .34625 Mdot
.844 .34656 Mdot
.844 .34672 Mdot
.844 .34693 Mdot
.844 .347 Mdot
.844 .34725 Mdot
.844 .34734 Mdot
.844 .34777 Mdot
.844 .34795 Mdot
.844 .34797 Mdot
.844 .34821 Mdot
.844 .34838 Mdot
.844 .34842 Mdot
.844 .34861 Mdot
.844 .34862 Mdot
.844 .3488 Mdot
.844 .34881 Mdot
.844 .34901 Mdot
.844 .34943 Mdot
.844 .34952 Mdot
.844 .35022 Mdot
.844 .35054 Mdot
.844 .35064 Mdot
.844 .35094 Mdot
.844 .35114 Mdot
.844 .35186 Mdot
.844 .35191 Mdot
.844 .35231 Mdot
.844 .3529 Mdot
.844 .35303 Mdot
.844 .3534 Mdot
.844 .35346 Mdot
.844 .35347 Mdot
.844 .35386 Mdot
.844 .35463 Mdot
.844 .35465 Mdot
.844 .35466 Mdot
.844 .35485 Mdot
.844 .35509 Mdot
.844 .35513 Mdot
.844 .35519 Mdot
.844 .35541 Mdot
.844 .35544 Mdot
.844 .35553 Mdot
.844 .35565 Mdot
.844 .35639 Mdot
.844 .35656 Mdot
.844 .35665 Mdot
.844 .35674 Mdot
.844 .35691 Mdot
.844 .35693 Mdot
.844 .35741 Mdot
.844 .35752 Mdot
.844 .35753 Mdot
.844 .35904 Mdot
.844 .35912 Mdot
.844 .35919 Mdot
.844 .36028 Mdot
.844 .36065 Mdot
.844 .36259 Mdot
.844 .36274 Mdot
.844 .36317 Mdot
.844 .3634 Mdot
.844 .36379 Mdot
.844 .36431 Mdot
.844 .3644 Mdot
.844 .36452 Mdot
.844 .36501 Mdot
.844 .36504 Mdot
.844 .36507 Mdot
.844 .36513 Mdot
.844 .36521 Mdot
.844 .36533 Mdot
.844 .36579 Mdot
.844 .36621 Mdot
.844 .36671 Mdot
.844 .36686 Mdot
.844 .36687 Mdot
.844 .36733 Mdot
.844 .36747 Mdot
.844 .36758 Mdot
.844 .36784 Mdot
.844 .36799 Mdot
.844 .36804 Mdot
.844 .36819 Mdot
.844 .3682 Mdot
.844 .36821 Mdot
.844 .36932 Mdot
.844 .36988 Mdot
.844 .37001 Mdot
.844 .37037 Mdot
.844 .37063 Mdot
.844 .37164 Mdot
.844 .37179 Mdot
.844 .37206 Mdot
.844 .37213 Mdot
.844 .37292 Mdot
.844 .37303 Mdot
.844 .37318 Mdot
.844 .37324 Mdot
.844 .37406 Mdot
.844 .37475 Mdot
.844 .37483 Mdot
.844 .37602 Mdot
.844 .37605 Mdot
.844 .37607 Mdot
.844 .3779 Mdot
.844 .37811 Mdot
.844 .37812 Mdot
.844 .37818 Mdot
.844 .37897 Mdot
.844 .37901 Mdot
.844 .37916 Mdot
.844 .37923 Mdot
.844 .37963 Mdot
.844 .37982 Mdot
.844 .38044 Mdot
.844 .38059 Mdot
.844 .38061 Mdot
.844 .381 Mdot
.844 .38156 Mdot
.844 .38264 Mdot
.844 .38271 Mdot
.844 .38271 Mdot
.844 .38274 Mdot
.844 .38324 Mdot
.844 .38373 Mdot
.844 .38433 Mdot
.844 .38433 Mdot
.844 .38489 Mdot
.844 .38509 Mdot
.844 .38516 Mdot
.844 .38518 Mdot
.844 .38521 Mdot
.844 .38522 Mdot
.844 .38526 Mdot
.844 .38538 Mdot
.844 .38571 Mdot
.844 .38571 Mdot
.844 .38607 Mdot
.844 .38666 Mdot
.844 .38667 Mdot
.844 .38667 Mdot
.844 .38671 Mdot
.844 .38735 Mdot
.844 .38768 Mdot
.844 .38793 Mdot
.844 .3885 Mdot
.844 .38873 Mdot
.844 .38877 Mdot
.844 .38886 Mdot
.844 .38935 Mdot
.844 .38939 Mdot
.844 .3894 Mdot
.844 .38952 Mdot
.844 .39134 Mdot
.844 .39228 Mdot
.844 .39232 Mdot
.844 .39294 Mdot
.844 .39298 Mdot
.844 .39314 Mdot
.844 .39323 Mdot
.844 .39427 Mdot
.844 .3946 Mdot
.844 .39526 Mdot
.844 .39527 Mdot
.844 .39539 Mdot
.844 .39564 Mdot
.844 .3957 Mdot
.844 .39606 Mdot
.844 .39606 Mdot
.844 .39615 Mdot
.844 .39697 Mdot
.844 .39704 Mdot
.844 .39709 Mdot
.844 .39714 Mdot
.844 .39716 Mdot
.844 .39752 Mdot
.844 .39859 Mdot
.844 .4006 Mdot
.844 .40065 Mdot
.844 .40069 Mdot
.844 .40194 Mdot
.844 .40216 Mdot
.844 .4027 Mdot
.844 .40277 Mdot
.844 .40283 Mdot
.844 .40284 Mdot
.844 .40399 Mdot
.844 .404 Mdot
.844 .40403 Mdot
.844 .40425 Mdot
.844 .40433 Mdot
.844 .40494 Mdot
.844 .40538 Mdot
.844 .40549 Mdot
.844 .40573 Mdot
.844 .40592 Mdot
.844 .40663 Mdot
.844 .40676 Mdot
.844 .40687 Mdot
.844 .40699 Mdot
.844 .40701 Mdot
.844 .40711 Mdot
.844 .40725 Mdot
.844 .40726 Mdot
.844 .40737 Mdot
.844 .40763 Mdot
.844 .40783 Mdot
.844 .40808 Mdot
.844 .4097 Mdot
.844 .40978 Mdot
.844 .40986 Mdot
.844 .4099 Mdot
.844 .41002 Mdot
.844 .41022 Mdot
.844 .41084 Mdot
.844 .41106 Mdot
.844 .412 Mdot
.844 .412 Mdot
.844 .41254 Mdot
.844 .41265 Mdot
.844 .41383 Mdot
.844 .41388 Mdot
.844 .41389 Mdot
.844 .41391 Mdot
.844 .41416 Mdot
.844 .41424 Mdot
.844 .4145 Mdot
.844 .41494 Mdot
.844 .41513 Mdot
.844 .41514 Mdot
.844 .41524 Mdot
.844 .41526 Mdot
.844 .41535 Mdot
.844 .41614 Mdot
.844 .41616 Mdot
.844 .41641 Mdot
.844 .41718 Mdot
.844 .41726 Mdot
.844 .41788 Mdot
.844 .41797 Mdot
.844 .41809 Mdot
.844 .41842 Mdot
.844 .41873 Mdot
.844 .41893 Mdot
.844 .41907 Mdot
.844 .41917 Mdot
.844 .41923 Mdot
.844 .41928 Mdot
.844 .4201 Mdot
.844 .42029 Mdot
.844 .4203 Mdot
.844 .42045 Mdot
.844 .42064 Mdot
.844 .42133 Mdot
.844 .422 Mdot
.844 .42239 Mdot
.844 .42248 Mdot
.844 .42249 Mdot
.844 .4231 Mdot
.844 .42335 Mdot
.844 .42397 Mdot
.844 .42427 Mdot
.844 .42515 Mdot
.844 .42547 Mdot
.844 .42604 Mdot
.844 .42663 Mdot
.844 .42679 Mdot
.844 .42726 Mdot
.844 .4281 Mdot
.844 .42909 Mdot
.844 .42912 Mdot
.844 .42921 Mdot
.844 .42935 Mdot
.844 .43009 Mdot
.844 .43014 Mdot
.844 .4319 Mdot
.844 .43191 Mdot
.844 .43192 Mdot
.844 .4321 Mdot
.844 .43265 Mdot
.844 .43291 Mdot
.844 .43295 Mdot
.844 .43324 Mdot
.844 .43339 Mdot
.844 .43354 Mdot
.844 .43383 Mdot
.844 .43386 Mdot
.844 .43508 Mdot
.844 .43528 Mdot
.844 .43543 Mdot
.844 .43547 Mdot
.844 .43585 Mdot
.844 .43595 Mdot
.844 .43602 Mdot
.844 .43642 Mdot
.844 .43674 Mdot
.844 .43677 Mdot
.844 .4368 Mdot
.844 .43691 Mdot
.844 .43729 Mdot
.844 .4381 Mdot
.844 .43829 Mdot
.844 .43846 Mdot
.844 .43858 Mdot
.844 .43875 Mdot
.844 .43878 Mdot
.844 .43886 Mdot
.844 .4395 Mdot
.844 .43955 Mdot
.844 .43971 Mdot
.844 .43985 Mdot
.844 .44049 Mdot
.844 .44071 Mdot
.844 .44115 Mdot
.844 .44116 Mdot
.844 .44139 Mdot
.844 .44146 Mdot
.844 .44269 Mdot
.844 .44302 Mdot
.844 .44326 Mdot
.844 .44352 Mdot
.844 .4437 Mdot
.844 .44424 Mdot
.844 .44542 Mdot
.844 .44557 Mdot
.844 .44591 Mdot
.844 .44628 Mdot
.844 .44663 Mdot
.844 .44664 Mdot
.844 .44695 Mdot
.844 .44696 Mdot
.844 .44728 Mdot
.844 .44735 Mdot
.844 .44758 Mdot
.844 .44762 Mdot
.844 .44803 Mdot
.844 .44807 Mdot
.844 .44838 Mdot
.844 .44879 Mdot
.844 .4491 Mdot
.844 .44925 Mdot
.844 .44967 Mdot
.844 .4498 Mdot
.844 .45015 Mdot
.844 .45041 Mdot
.844 .45094 Mdot
.844 .45234 Mdot
.844 .45276 Mdot
.844 .45335 Mdot
.844 .45428 Mdot
.844 .45501 Mdot
.844 .45502 Mdot
.844 .45525 Mdot
.844 .45547 Mdot
.844 .45558 Mdot
.844 .45592 Mdot
.844 .45596 Mdot
.844 .45602 Mdot
.844 .45637 Mdot
.844 .4565 Mdot
.844 .45758 Mdot
.844 .458 Mdot
.844 .45826 Mdot
.844 .45888 Mdot
.844 .4589 Mdot
.844 .45924 Mdot
.844 .4596 Mdot
.844 .46006 Mdot
.844 .46032 Mdot
.844 .46063 Mdot
.844 .46094 Mdot
.844 .46105 Mdot
.844 .46157 Mdot
.844 .46157 Mdot
.844 .46221 Mdot
.844 .46234 Mdot
.844 .46299 Mdot
.844 .46311 Mdot
.844 .46318 Mdot
.844 .46343 Mdot
.844 .4641 Mdot
.844 .46411 Mdot
.844 .46414 Mdot
.844 .46461 Mdot
.844 .46502 Mdot
.844 .46506 Mdot
.844 .46525 Mdot
.844 .46594 Mdot
.844 .46599 Mdot
.844 .466 Mdot
.844 .46605 Mdot
.844 .46678 Mdot
.844 .46691 Mdot
.844 .46696 Mdot
.844 .467 Mdot
.844 .46701 Mdot
.844 .46705 Mdot
.844 .46709 Mdot
.844 .46713 Mdot
.844 .46772 Mdot
.844 .46794 Mdot
.844 .46797 Mdot
.844 .46804 Mdot
.844 .46806 Mdot
.844 .46846 Mdot
.844 .46849 Mdot
.844 .4687 Mdot
.844 .46878 Mdot
.844 .46995 Mdot
.844 .47024 Mdot
.844 .47048 Mdot
.844 .47052 Mdot
.844 .47081 Mdot
.844 .47084 Mdot
.844 .47084 Mdot
.844 .47112 Mdot
.844 .47187 Mdot
.844 .47215 Mdot
.844 .47337 Mdot
.844 .4734 Mdot
.844 .47341 Mdot
.844 .4737 Mdot
.844 .4739 Mdot
.844 .47412 Mdot
.844 .47414 Mdot
.844 .47435 Mdot
.844 .47447 Mdot
.844 .47465 Mdot
.844 .47534 Mdot
.844 .47626 Mdot
.844 .47632 Mdot
.844 .47654 Mdot
.844 .47684 Mdot
.844 .47786 Mdot
.844 .47787 Mdot
.844 .47788 Mdot
.844 .47832 Mdot
.844 .47856 Mdot
.844 .47892 Mdot
.844 .47896 Mdot
.844 .47977 Mdot
.844 .47986 Mdot
.844 .47999 Mdot
.844 .48062 Mdot
.844 .48068 Mdot
.844 .48075 Mdot
.844 .48092 Mdot
.844 .48132 Mdot
.844 .48147 Mdot
.844 .48172 Mdot
.844 .48191 Mdot
.844 .48198 Mdot
.844 .48217 Mdot
.844 .4823 Mdot
.844 .48239 Mdot
.844 .48253 Mdot
.844 .48327 Mdot
.844 .4834 Mdot
.844 .48436 Mdot
.844 .48437 Mdot
.844 .48441 Mdot
.844 .48458 Mdot
.844 .48464 Mdot
.844 .48467 Mdot
.844 .48476 Mdot
.844 .48518 Mdot
.844 .48521 Mdot
.844 .48522 Mdot
.844 .4853 Mdot
.844 .48537 Mdot
.844 .48538 Mdot
.844 .48538 Mdot
.844 .48565 Mdot
.844 .4862 Mdot
.844 .48634 Mdot
.844 .48678 Mdot
.844 .48718 Mdot
.844 .48721 Mdot
.844 .48743 Mdot
.844 .48749 Mdot
.844 .48797 Mdot
.844 .48809 Mdot
.844 .48816 Mdot
.844 .48832 Mdot
.844 .48861 Mdot
.844 .48882 Mdot
.844 .48937 Mdot
.844 .49005 Mdot
.844 .49034 Mdot
.844 .49116 Mdot
.844 .49144 Mdot
.844 .49145 Mdot
.844 .49166 Mdot
.844 .49188 Mdot
.844 .49246 Mdot
.844 .49273 Mdot
.844 .49305 Mdot
.844 .49315 Mdot
.844 .49319 Mdot
.844 .49322 Mdot
.844 .49392 Mdot
.844 .49392 Mdot
.844 .49392 Mdot
.844 .49415 Mdot
.844 .49456 Mdot
.844 .49467 Mdot
.844 .49504 Mdot
.844 .49507 Mdot
.844 .49527 Mdot
.844 .49548 Mdot
.844 .49568 Mdot
.844 .49577 Mdot
.844 .49651 Mdot
.844 .49683 Mdot
.844 .49696 Mdot
.844 .49726 Mdot
.844 .49739 Mdot
.844 .49795 Mdot
.844 .49825 Mdot
.844 .49867 Mdot
.844 .49888 Mdot
.844 .49904 Mdot
.844 .49994 Mdot
.844 .50031 Mdot
.844 .50069 Mdot
.844 .50144 Mdot
.844 .50152 Mdot
.844 .50157 Mdot
.844 .50171 Mdot
.844 .50236 Mdot
.844 .50248 Mdot
.844 .5025 Mdot
.844 .50278 Mdot
.844 .50278 Mdot
.844 .5032 Mdot
.844 .50327 Mdot
.844 .50372 Mdot
.844 .50401 Mdot
.844 .50415 Mdot
.844 .50481 Mdot
.844 .50481 Mdot
.844 .50489 Mdot
.844 .50504 Mdot
.844 .50615 Mdot
.844 .50626 Mdot
.844 .50644 Mdot
.844 .50682 Mdot
.844 .50684 Mdot
.844 .50697 Mdot
.844 .50699 Mdot
.844 .50702 Mdot
.844 .50744 Mdot
.844 .5086 Mdot
.844 .50997 Mdot
.844 .51027 Mdot
.844 .51034 Mdot
.844 .51044 Mdot
.844 .51061 Mdot
.844 .51063 Mdot
.844 .51085 Mdot
.844 .51101 Mdot
.844 .51124 Mdot
.844 .51203 Mdot
.844 .51218 Mdot
.846 .1685 Mdot
.846 .16878 Mdot
.846 .1691 Mdot
.846 .16941 Mdot
.846 .17063 Mdot
.846 .17136 Mdot
.846 .1718 Mdot
.846 .17197 Mdot
.846 .17295 Mdot
.846 .17299 Mdot
.846 .17403 Mdot
.846 .17417 Mdot
.846 .1743 Mdot
.846 .17466 Mdot
.846 .17469 Mdot
.846 .17493 Mdot
.846 .17588 Mdot
.846 .17604 Mdot
.846 .1783 Mdot
.846 .1785 Mdot
.846 .17907 Mdot
.846 .17922 Mdot
.846 .17966 Mdot
.846 .18042 Mdot
.846 .18088 Mdot
.846 .18099 Mdot
.846 .18259 Mdot
.846 .18305 Mdot
.846 .1836 Mdot
.846 .18364 Mdot
.846 .1848 Mdot
.846 .18604 Mdot
.846 .18649 Mdot
.846 .18674 Mdot
.846 .18686 Mdot
.846 .18772 Mdot
.846 .18833 Mdot
.846 .18892 Mdot
.846 .18907 Mdot
.846 .18925 Mdot
.846 .18975 Mdot
.846 .19024 Mdot
.846 .19026 Mdot
.846 .19062 Mdot
.846 .19128 Mdot
.846 .19153 Mdot
.846 .19243 Mdot
.846 .19377 Mdot
.846 .19382 Mdot
.846 .19465 Mdot
.846 .19485 Mdot
.846 .19486 Mdot
.846 .19556 Mdot
.846 .1957 Mdot
.846 .19624 Mdot
.846 .19653 Mdot
.846 .19658 Mdot
.846 .19755 Mdot
.846 .19777 Mdot
.846 .19784 Mdot
.846 .19819 Mdot
.846 .19819 Mdot
.846 .19824 Mdot
.846 .19948 Mdot
.846 .19974 Mdot
.846 .19977 Mdot
.846 .19997 Mdot
.846 .20001 Mdot
.846 .20064 Mdot
.846 .20066 Mdot
.846 .20069 Mdot
.846 .2009 Mdot
.846 .20116 Mdot
.846 .20121 Mdot
.846 .20156 Mdot
.846 .20194 Mdot
.846 .20263 Mdot
.846 .20278 Mdot
.846 .20324 Mdot
.846 .20453 Mdot
.846 .20466 Mdot
.846 .20472 Mdot
.846 .20489 Mdot
.846 .20554 Mdot
.846 .20712 Mdot
.846 .20729 Mdot
.846 .20751 Mdot
.846 .20804 Mdot
.846 .20958 Mdot
.846 .20999 Mdot
.846 .21025 Mdot
.846 .21034 Mdot
.846 .21066 Mdot
.846 .21099 Mdot
.846 .2111 Mdot
.846 .21178 Mdot
.846 .21187 Mdot
.846 .21271 Mdot
.846 .21272 Mdot
.846 .21294 Mdot
.846 .21317 Mdot
.846 .21397 Mdot
.846 .2142 Mdot
.846 .21508 Mdot
.846 .21586 Mdot
.846 .21607 Mdot
.846 .21678 Mdot
.846 .21691 Mdot
.846 .21894 Mdot
.846 .21924 Mdot
.846 .21954 Mdot
.846 .21961 Mdot
.846 .22004 Mdot
.846 .22018 Mdot
.846 .22036 Mdot
.846 .22056 Mdot
.846 .2206 Mdot
.846 .22124 Mdot
.846 .22134 Mdot
.846 .22151 Mdot
.846 .22387 Mdot
.846 .22407 Mdot
.846 .22417 Mdot
.846 .22425 Mdot
.846 .22457 Mdot
.846 .22465 Mdot
.846 .22478 Mdot
.846 .2248 Mdot
.846 .22581 Mdot
.846 .22664 Mdot
.846 .22707 Mdot
.846 .22733 Mdot
.846 .22735 Mdot
.846 .22856 Mdot
.846 .22901 Mdot
.846 .22904 Mdot
.846 .22972 Mdot
.846 .22987 Mdot
.846 .23004 Mdot
.846 .23087 Mdot
.846 .23121 Mdot
.846 .23146 Mdot
.846 .23224 Mdot
.846 .23354 Mdot
.846 .2342 Mdot
.846 .23493 Mdot
.846 .23564 Mdot
.846 .23607 Mdot
.846 .23663 Mdot
.846 .23687 Mdot
.846 .23714 Mdot
.846 .238 Mdot
.846 .23802 Mdot
.846 .23818 Mdot
.846 .23832 Mdot
.846 .23841 Mdot
.846 .23993 Mdot
.846 .24056 Mdot
.846 .24113 Mdot
.846 .24121 Mdot
.846 .24166 Mdot
.846 .24247 Mdot
.846 .24331 Mdot
.846 .24336 Mdot
.846 .24339 Mdot
.846 .24354 Mdot
.846 .24387 Mdot
.846 .24403 Mdot
.846 .24431 Mdot
.846 .2447 Mdot
.846 .24477 Mdot
.846 .24514 Mdot
.846 .2455 Mdot
.846 .24628 Mdot
.846 .24632 Mdot
.846 .24634 Mdot
.846 .24644 Mdot
.846 .24687 Mdot
.846 .24883 Mdot
.846 .24963 Mdot
.846 .25055 Mdot
.846 .25095 Mdot
.846 .25121 Mdot
.846 .25204 Mdot
.846 .25216 Mdot
.846 .25357 Mdot
.846 .25416 Mdot
.846 .25595 Mdot
.846 .25627 Mdot
.846 .25636 Mdot
.846 .25642 Mdot
.846 .25643 Mdot
.846 .25657 Mdot
.846 .25672 Mdot
.846 .25677 Mdot
.846 .25678 Mdot
.846 .25765 Mdot
.846 .25769 Mdot
.846 .2577 Mdot
.846 .25786 Mdot
.846 .25812 Mdot
.846 .25945 Mdot
.846 .25981 Mdot
.846 .26009 Mdot
.846 .2604 Mdot
.846 .2629 Mdot
.846 .26358 Mdot
.846 .2651 Mdot
.846 .26627 Mdot
.846 .2666 Mdot
.846 .26665 Mdot
.846 .26712 Mdot
.846 .26783 Mdot
.846 .26785 Mdot
.846 .26801 Mdot
.846 .26861 Mdot
.846 .26986 Mdot
.846 .27113 Mdot
.846 .2713 Mdot
.846 .27154 Mdot
.846 .27248 Mdot
.846 .27305 Mdot
.846 .27312 Mdot
.846 .27316 Mdot
.846 .27335 Mdot
.846 .27377 Mdot
.846 .27471 Mdot
.846 .27492 Mdot
.846 .27498 Mdot
.846 .27523 Mdot
.846 .27539 Mdot
.846 .27593 Mdot
.846 .27646 Mdot
.846 .27768 Mdot
.846 .27837 Mdot
.846 .27852 Mdot
.846 .27852 Mdot
.846 .27884 Mdot
.846 .27886 Mdot
.846 .27896 Mdot
.846 .27896 Mdot
.846 .27902 Mdot
.846 .27976 Mdot
.846 .27996 Mdot
.846 .2805 Mdot
.846 .28078 Mdot
.846 .28102 Mdot
.846 .28245 Mdot
.846 .28249 Mdot
.846 .28249 Mdot
.846 .28251 Mdot
.846 .28303 Mdot
.846 .28306 Mdot
.846 .28335 Mdot
.846 .28346 Mdot
.846 .28384 Mdot
.846 .28412 Mdot
.846 .28428 Mdot
.846 .2843 Mdot
.846 .28451 Mdot
.846 .28473 Mdot
.846 .28526 Mdot
.846 .28529 Mdot
.846 .28534 Mdot
.846 .28539 Mdot
.846 .28579 Mdot
.846 .28608 Mdot
.846 .28741 Mdot
.846 .28768 Mdot
.846 .28777 Mdot
.846 .28818 Mdot
.846 .28824 Mdot
.846 .28829 Mdot
.846 .28853 Mdot
.846 .28912 Mdot
.846 .29002 Mdot
.846 .2902 Mdot
.846 .29023 Mdot
.846 .29033 Mdot
.846 .29125 Mdot
.846 .29149 Mdot
.846 .29167 Mdot
.846 .29182 Mdot
.846 .29185 Mdot
.846 .29276 Mdot
.846 .29281 Mdot
.846 .29306 Mdot
.846 .29313 Mdot
.846 .29379 Mdot
.846 .29453 Mdot
.846 .2948 Mdot
.846 .29509 Mdot
.846 .29518 Mdot
.846 .29587 Mdot
.846 .29605 Mdot
.846 .29613 Mdot
.846 .29619 Mdot
.846 .29674 Mdot
.846 .29827 Mdot
.846 .29875 Mdot
.846 .2993 Mdot
.846 .29953 Mdot
.846 .29999 Mdot
.846 .30047 Mdot
.846 .30047 Mdot
.846 .30054 Mdot
.846 .30225 Mdot
.846 .30243 Mdot
.846 .30249 Mdot
.846 .30275 Mdot
.846 .30339 Mdot
.846 .30355 Mdot
.846 .30459 Mdot
.846 .30535 Mdot
.846 .30578 Mdot
.846 .30598 Mdot
.846 .30625 Mdot
.846 .30743 Mdot
.846 .30751 Mdot
.846 .30774 Mdot
.846 .30811 Mdot
.846 .30847 Mdot
.846 .30868 Mdot
.846 .30947 Mdot
.846 .30958 Mdot
.846 .30972 Mdot
.846 .31004 Mdot
.846 .31046 Mdot
.846 .31087 Mdot
.846 .31127 Mdot
.846 .3117 Mdot
.846 .31174 Mdot
.846 .31187 Mdot
.846 .3123 Mdot
.846 .31235 Mdot
.846 .31321 Mdot
.846 .31346 Mdot
.846 .31388 Mdot
.846 .31408 Mdot
.846 .31464 Mdot
.846 .31499 Mdot
.846 .31501 Mdot
.846 .31541 Mdot
.846 .31609 Mdot
.846 .31613 Mdot
.846 .31643 Mdot
.846 .31685 Mdot
.846 .31731 Mdot
.846 .31732 Mdot
.846 .31744 Mdot
.846 .31767 Mdot
.846 .31776 Mdot
.846 .31808 Mdot
.846 .31854 Mdot
.846 .31856 Mdot
.846 .31917 Mdot
.846 .31922 Mdot
.846 .31951 Mdot
.846 .31953 Mdot
.846 .31994 Mdot
.846 .31997 Mdot
.846 .32009 Mdot
.846 .32011 Mdot
.846 .32054 Mdot
.846 .32063 Mdot
.846 .32071 Mdot
.846 .32072 Mdot
.846 .32094 Mdot
.846 .32095 Mdot
.846 .32096 Mdot
.846 .32103 Mdot
.846 .32114 Mdot
.846 .32126 Mdot
.846 .3214 Mdot
.846 .32164 Mdot
.846 .32169 Mdot
.846 .32185 Mdot
.846 .3223 Mdot
.846 .32235 Mdot
.846 .32237 Mdot
.846 .32243 Mdot
.846 .32407 Mdot
.846 .32433 Mdot
.846 .32445 Mdot
.846 .32456 Mdot
.846 .32483 Mdot
.846 .32516 Mdot
.846 .32516 Mdot
.846 .32524 Mdot
.846 .32532 Mdot
.846 .32568 Mdot
.846 .32599 Mdot
.846 .32734 Mdot
.846 .32744 Mdot
.846 .32777 Mdot
.846 .32783 Mdot
.846 .32792 Mdot
.846 .32817 Mdot
.846 .32824 Mdot
.846 .32913 Mdot
.846 .3293 Mdot
.846 .32933 Mdot
.846 .32938 Mdot
.846 .32974 Mdot
.846 .33003 Mdot
.846 .33018 Mdot
.846 .33027 Mdot
.846 .3307 Mdot
.846 .33085 Mdot
.846 .3315 Mdot
.846 .33244 Mdot
.846 .33267 Mdot
.846 .33292 Mdot
.846 .33317 Mdot
.846 .33352 Mdot
.846 .33369 Mdot
.846 .33399 Mdot
.846 .33585 Mdot
.846 .33587 Mdot
.846 .33588 Mdot
.846 .3361 Mdot
.846 .3362 Mdot
.846 .33649 Mdot
.846 .33661 Mdot
.846 .33709 Mdot
.846 .33759 Mdot
.846 .33778 Mdot
.846 .33806 Mdot
.846 .33852 Mdot
.846 .33894 Mdot
.846 .34026 Mdot
.846 .34041 Mdot
.846 .34048 Mdot
.846 .34055 Mdot
.846 .34086 Mdot
.846 .34093 Mdot
.846 .34149 Mdot
.846 .34161 Mdot
.846 .34182 Mdot
.846 .34269 Mdot
.846 .34387 Mdot
.846 .34398 Mdot
.846 .34442 Mdot
.846 .34512 Mdot
.846 .34556 Mdot
.846 .34571 Mdot
.846 .34626 Mdot
.846 .34649 Mdot
.846 .34682 Mdot
.846 .347 Mdot
.846 .34815 Mdot
.846 .34826 Mdot
.846 .3483 Mdot
.846 .3483 Mdot
.846 .34832 Mdot
.846 .34865 Mdot
.846 .34902 Mdot
.846 .34953 Mdot
.846 .34972 Mdot
.846 .34973 Mdot
.846 .34983 Mdot
.846 .34987 Mdot
.846 .35 Mdot
.846 .3501 Mdot
.846 .35017 Mdot
.846 .3505 Mdot
.846 .35051 Mdot
.846 .35152 Mdot
.846 .35164 Mdot
.846 .35185 Mdot
.846 .35216 Mdot
.846 .35223 Mdot
.846 .35224 Mdot
.846 .3526 Mdot
.846 .35325 Mdot
.846 .35374 Mdot
.846 .35383 Mdot
.846 .35397 Mdot
.846 .35432 Mdot
.846 .35451 Mdot
.846 .35505 Mdot
.846 .35541 Mdot
.846 .35565 Mdot
.846 .35644 Mdot
.846 .35661 Mdot
.846 .35684 Mdot
.846 .35689 Mdot
.846 .35783 Mdot
.846 .35827 Mdot
.846 .35836 Mdot
.846 .35848 Mdot
.846 .35868 Mdot
.846 .3598 Mdot
.846 .36027 Mdot
.846 .36057 Mdot
.846 .36076 Mdot
.846 .36089 Mdot
.846 .36089 Mdot
.846 .36128 Mdot
.846 .36139 Mdot
.846 .36196 Mdot
.846 .36213 Mdot
.846 .36213 Mdot
.846 .36236 Mdot
.846 .36267 Mdot
.846 .36286 Mdot
.846 .36289 Mdot
.846 .363 Mdot
.846 .36308 Mdot
.846 .36321 Mdot
.846 .36323 Mdot
.846 .36346 Mdot
.846 .36415 Mdot
.846 .36432 Mdot
.846 .36449 Mdot
.846 .36462 Mdot
.846 .36473 Mdot
.846 .3654 Mdot
.846 .36614 Mdot
.846 .36637 Mdot
.846 .36698 Mdot
.846 .36752 Mdot
.846 .36817 Mdot
.846 .36861 Mdot
.846 .36894 Mdot
.846 .3691 Mdot
.846 .36925 Mdot
.846 .36979 Mdot
.846 .36992 Mdot
.846 .37014 Mdot
.846 .37018 Mdot
.846 .37097 Mdot
.846 .37101 Mdot
.846 .37189 Mdot
.846 .37251 Mdot
.846 .37253 Mdot
.846 .37264 Mdot
.846 .37277 Mdot
.846 .37317 Mdot
.846 .37329 Mdot
.846 .37365 Mdot
.846 .37369 Mdot
.846 .37387 Mdot
.846 .37402 Mdot
.846 .37445 Mdot
.846 .3745 Mdot
.846 .37615 Mdot
.846 .37654 Mdot
.846 .37681 Mdot
.846 .37692 Mdot
.846 .37729 Mdot
.846 .37735 Mdot
.846 .37761 Mdot
.846 .37762 Mdot
.846 .37774 Mdot
.846 .37782 Mdot
.846 .3785 Mdot
.846 .37875 Mdot
.846 .37905 Mdot
.846 .37924 Mdot
.846 .38044 Mdot
.846 .38046 Mdot
.846 .38098 Mdot
.846 .38102 Mdot
.846 .38145 Mdot
.846 .38248 Mdot
.846 .38276 Mdot
.846 .3828 Mdot
.846 .38283 Mdot
.846 .38394 Mdot
.846 .38458 Mdot
.846 .38497 Mdot
.846 .38608 Mdot
.846 .38646 Mdot
.846 .38711 Mdot
.846 .38713 Mdot
.846 .38732 Mdot
.846 .38821 Mdot
.846 .38853 Mdot
.846 .38924 Mdot
.846 .39008 Mdot
.846 .39013 Mdot
.846 .3902 Mdot
.846 .3902 Mdot
.846 .39061 Mdot
.846 .39068 Mdot
.846 .39107 Mdot
.846 .39241 Mdot
.846 .39252 Mdot
.846 .39254 Mdot
.846 .39282 Mdot
.846 .39306 Mdot
.846 .39314 Mdot
.846 .3932 Mdot
.846 .39322 Mdot
.846 .3941 Mdot
.846 .39412 Mdot
.846 .39578 Mdot
.846 .39616 Mdot
.846 .39648 Mdot
.846 .39684 Mdot
.846 .39698 Mdot
.846 .39742 Mdot
.846 .39781 Mdot
.846 .39795 Mdot
.846 .39856 Mdot
.846 .3987 Mdot
.846 .39871 Mdot
.846 .3989 Mdot
.846 .39892 Mdot
.846 .39935 Mdot
.846 .39945 Mdot
.846 .40008 Mdot
.846 .40008 Mdot
.846 .40027 Mdot
.846 .40073 Mdot
.846 .40139 Mdot
.846 .40151 Mdot
.846 .40158 Mdot
.846 .40163 Mdot
.846 .40189 Mdot
.846 .40245 Mdot
.846 .40271 Mdot
.846 .40318 Mdot
.846 .40385 Mdot
.846 .40397 Mdot
.846 .40417 Mdot
.846 .40425 Mdot
.846 .4046 Mdot
.846 .40498 Mdot
.846 .4052 Mdot
.846 .40524 Mdot
.846 .40555 Mdot
.846 .40562 Mdot
.846 .40622 Mdot
.846 .40642 Mdot
.846 .40652 Mdot
.846 .40659 Mdot
.846 .40662 Mdot
.846 .40679 Mdot
.846 .4071 Mdot
.846 .40732 Mdot
.846 .40751 Mdot
.846 .40752 Mdot
.846 .40755 Mdot
.846 .40859 Mdot
.846 .41008 Mdot
.846 .41014 Mdot
.846 .41084 Mdot
.846 .41148 Mdot
.846 .41155 Mdot
.846 .41192 Mdot
.846 .41215 Mdot
.846 .41219 Mdot
.846 .41306 Mdot
.846 .4133 Mdot
.846 .41358 Mdot
.846 .41374 Mdot
.846 .41415 Mdot
.846 .41443 Mdot
.846 .41487 Mdot
.846 .41488 Mdot
.846 .41598 Mdot
.846 .41626 Mdot
.846 .41647 Mdot
.846 .4169 Mdot
.846 .41793 Mdot
.846 .41832 Mdot
.846 .41885 Mdot
.846 .41957 Mdot
.846 .41985 Mdot
.846 .42071 Mdot
.846 .42089 Mdot
.846 .4211 Mdot
.846 .42139 Mdot
.846 .42169 Mdot
.846 .42285 Mdot
.846 .42289 Mdot
.846 .42325 Mdot
.846 .42328 Mdot
.846 .42342 Mdot
.846 .4235 Mdot
.846 .42357 Mdot
.846 .42364 Mdot
.846 .42368 Mdot
.846 .42369 Mdot
.846 .42382 Mdot
.846 .42388 Mdot
.846 .42393 Mdot
.846 .42419 Mdot
.846 .4242 Mdot
.846 .42427 Mdot
.846 .42428 Mdot
.846 .42471 Mdot
.846 .4251 Mdot
.846 .42511 Mdot
.846 .42539 Mdot
.846 .42576 Mdot
.846 .42583 Mdot
.846 .42584 Mdot
.846 .42611 Mdot
.846 .42636 Mdot
.846 .42654 Mdot
.846 .42656 Mdot
.846 .4272 Mdot
.846 .42721 Mdot
.846 .42742 Mdot
.846 .42775 Mdot
.846 .42826 Mdot
.846 .4288 Mdot
.846 .42906 Mdot
.846 .42941 Mdot
.846 .42989 Mdot
.846 .43041 Mdot
.846 .43094 Mdot
.846 .43128 Mdot
.846 .43149 Mdot
.846 .43163 Mdot
.846 .43237 Mdot
.846 .43397 Mdot
.846 .43406 Mdot
.846 .43444 Mdot
.846 .43464 Mdot
.846 .43474 Mdot
.846 .43579 Mdot
.846 .43608 Mdot
.846 .43648 Mdot
.846 .43709 Mdot
.846 .438 Mdot
.846 .43832 Mdot
.846 .43836 Mdot
.846 .43892 Mdot
.846 .43915 Mdot
.846 .4393 Mdot
.846 .44013 Mdot
.846 .44035 Mdot
.846 .4409 Mdot
.846 .44099 Mdot
.846 .44124 Mdot
.846 .44178 Mdot
.846 .44184 Mdot
.846 .44186 Mdot
.846 .44197 Mdot
.846 .4425 Mdot
.846 .44285 Mdot
.846 .44299 Mdot
.846 .44302 Mdot
.846 .44306 Mdot
.846 .4433 Mdot
.846 .4443 Mdot
.846 .44477 Mdot
.846 .44478 Mdot
.846 .44535 Mdot
.846 .44546 Mdot
.846 .44562 Mdot
.846 .44584 Mdot
.846 .44591 Mdot
.846 .44608 Mdot
.846 .4461 Mdot
.846 .44642 Mdot
.846 .44642 Mdot
.846 .44729 Mdot
.846 .44791 Mdot
.846 .44847 Mdot
.846 .4485 Mdot
.846 .4485 Mdot
.846 .44856 Mdot
.846 .44857 Mdot
.846 .44877 Mdot
.846 .44885 Mdot
.846 .44926 Mdot
.846 .45071 Mdot
.846 .45086 Mdot
.846 .45102 Mdot
.846 .45157 Mdot
.846 .45182 Mdot
.846 .45193 Mdot
.846 .45196 Mdot
.846 .452 Mdot
.846 .45233 Mdot
.846 .45289 Mdot
.846 .45303 Mdot
.846 .45313 Mdot
.846 .45388 Mdot
.846 .45462 Mdot
.846 .45497 Mdot
.846 .45507 Mdot
.846 .45508 Mdot
.846 .4555 Mdot
.846 .45578 Mdot
.846 .45581 Mdot
.846 .456 Mdot
.846 .4567 Mdot
.846 .45759 Mdot
.846 .458 Mdot
.846 .45948 Mdot
.846 .45966 Mdot
.846 .45983 Mdot
.846 .46004 Mdot
.846 .46082 Mdot
.846 .46098 Mdot
.846 .46107 Mdot
.846 .46107 Mdot
.846 .4611 Mdot
.846 .46162 Mdot
.846 .46162 Mdot
.846 .46165 Mdot
.846 .46174 Mdot
.846 .46182 Mdot
.846 .46183 Mdot
.846 .46186 Mdot
.846 .46192 Mdot
.846 .4621 Mdot
.846 .46316 Mdot
.846 .46351 Mdot
.846 .46435 Mdot
.846 .46442 Mdot
.846 .4649 Mdot
.846 .46506 Mdot
.846 .4653 Mdot
.846 .46584 Mdot
.846 .46631 Mdot
.846 .46663 Mdot
.846 .46747 Mdot
.846 .46772 Mdot
.846 .46779 Mdot
.846 .46779 Mdot
.846 .46782 Mdot
.846 .46828 Mdot
.846 .46849 Mdot
.846 .46871 Mdot
.846 .46875 Mdot
.846 .46899 Mdot
.846 .46915 Mdot
.846 .46924 Mdot
.846 .46944 Mdot
.846 .46953 Mdot
.846 .46955 Mdot
.846 .46957 Mdot
.846 .47007 Mdot
.846 .47055 Mdot
.846 .47081 Mdot
.846 .47086 Mdot
.846 .4712 Mdot
.846 .47157 Mdot
.846 .47247 Mdot
.846 .47252 Mdot
.846 .4726 Mdot
.846 .4727 Mdot
.846 .47271 Mdot
.846 .47322 Mdot
.846 .47338 Mdot
.846 .47352 Mdot
.846 .47386 Mdot
.846 .4741 Mdot
.846 .47453 Mdot
.846 .47496 Mdot
.846 .47535 Mdot
.846 .47612 Mdot
.846 .47658 Mdot
.846 .47673 Mdot
.846 .47692 Mdot
.846 .47742 Mdot
.846 .47752 Mdot
.846 .47761 Mdot
.846 .47801 Mdot
.846 .47803 Mdot
.846 .47829 Mdot
.846 .479 Mdot
.846 .47902 Mdot
.846 .47917 Mdot
.846 .47943 Mdot
.846 .47992 Mdot
.846 .48051 Mdot
.846 .48053 Mdot
.846 .4806 Mdot
.846 .48065 Mdot
.846 .48084 Mdot
.846 .48089 Mdot
.846 .48095 Mdot
.846 .48106 Mdot
.846 .48246 Mdot
.846 .48256 Mdot
.846 .48262 Mdot
.846 .48299 Mdot
.846 .48302 Mdot
.846 .48314 Mdot
.846 .48324 Mdot
.846 .48333 Mdot
.846 .48358 Mdot
.846 .48362 Mdot
.846 .4838 Mdot
.846 .48398 Mdot
.846 .48517 Mdot
.846 .48525 Mdot
.846 .48567 Mdot
.846 .4858 Mdot
.846 .48626 Mdot
.846 .48678 Mdot
.846 .48692 Mdot
.846 .48739 Mdot
.846 .48753 Mdot
.846 .48766 Mdot
.846 .48766 Mdot
.846 .48816 Mdot
.846 .48821 Mdot
.846 .48861 Mdot
.846 .48867 Mdot
.846 .48887 Mdot
.846 .48906 Mdot
.846 .48911 Mdot
.846 .48927 Mdot
.846 .48951 Mdot
.846 .49042 Mdot
.846 .49073 Mdot
.846 .49086 Mdot
.846 .49096 Mdot
.846 .4919 Mdot
.846 .49228 Mdot
.846 .49238 Mdot
.846 .49242 Mdot
.846 .4925 Mdot
.846 .49326 Mdot
.846 .49353 Mdot
.846 .49362 Mdot
.846 .49402 Mdot
.846 .49425 Mdot
.846 .49446 Mdot
.846 .49449 Mdot
.846 .49464 Mdot
.846 .49476 Mdot
.846 .49478 Mdot
.846 .49479 Mdot
.846 .49517 Mdot
.846 .49519 Mdot
.846 .49531 Mdot
.846 .49533 Mdot
.846 .49548 Mdot
.846 .49621 Mdot
.846 .49624 Mdot
.846 .49624 Mdot
.846 .49645 Mdot
.846 .49649 Mdot
.846 .49662 Mdot
.846 .49719 Mdot
.846 .49722 Mdot
.846 .4974 Mdot
.846 .49771 Mdot
.846 .49779 Mdot
.846 .49821 Mdot
.846 .49821 Mdot
.846 .49833 Mdot
.846 .49882 Mdot
.846 .49885 Mdot
.846 .49965 Mdot
.846 .50018 Mdot
.846 .50033 Mdot
.846 .50071 Mdot
.846 .50093 Mdot
.846 .50094 Mdot
.846 .50123 Mdot
.846 .50152 Mdot
.846 .50163 Mdot
.846 .50172 Mdot
.846 .50207 Mdot
.846 .50243 Mdot
.846 .50294 Mdot
.846 .50301 Mdot
.846 .50316 Mdot
.846 .50342 Mdot
.846 .50416 Mdot
.846 .50484 Mdot
.846 .50486 Mdot
.846 .50519 Mdot
.846 .50546 Mdot
.846 .50641 Mdot
.846 .50647 Mdot
.846 .50674 Mdot
.846 .5072 Mdot
.846 .50745 Mdot
.846 .50754 Mdot
.846 .50788 Mdot
.846 .508 Mdot
.846 .50933 Mdot
.846 .50942 Mdot
.846 .50999 Mdot
.846 .51013 Mdot
.846 .51015 Mdot
.846 .51036 Mdot
.846 .51044 Mdot
.846 .51052 Mdot
.846 .51114 Mdot
.846 .51116 Mdot
.846 .51174 Mdot
.846 .51184 Mdot
.846 .5121 Mdot
.846 .51253 Mdot
.846 .51325 Mdot
.846 .51343 Mdot
.846 .51362 Mdot
.846 .51379 Mdot
.848 .16682 Mdot
.848 .16709 Mdot
.848 .16732 Mdot
.848 .16912 Mdot
.848 .16975 Mdot
.848 .17024 Mdot
.848 .17031 Mdot
.848 .17172 Mdot
.848 .17217 Mdot
.848 .17241 Mdot
.848 .17274 Mdot
.848 .1728 Mdot
.848 .17418 Mdot
.848 .17439 Mdot
.848 .17512 Mdot
.848 .17531 Mdot
.848 .17537 Mdot
.848 .17551 Mdot
.848 .17624 Mdot
.848 .17644 Mdot
.848 .17659 Mdot
.848 .17707 Mdot
.848 .17892 Mdot
.848 .179 Mdot
.848 .18028 Mdot
.848 .18076 Mdot
.848 .18078 Mdot
.848 .18165 Mdot
.848 .18184 Mdot
.848 .18253 Mdot
.848 .18338 Mdot
.848 .18346 Mdot
.848 .18354 Mdot
.848 .18358 Mdot
.848 .18417 Mdot
.848 .18429 Mdot
.848 .18431 Mdot
.848 .18439 Mdot
.848 .1844 Mdot
.848 .18486 Mdot
.848 .1852 Mdot
.848 .18524 Mdot
.848 .18542 Mdot
.848 .18664 Mdot
.848 .18713 Mdot
.848 .18749 Mdot
.848 .18754 Mdot
.848 .18792 Mdot
.848 .18804 Mdot
.848 .18864 Mdot
.848 .1887 Mdot
.848 .19035 Mdot
.848 .19058 Mdot
.848 .19062 Mdot
.848 .19114 Mdot
.848 .1915 Mdot
.848 .19169 Mdot
.848 .19207 Mdot
.848 .19223 Mdot
.848 .19223 Mdot
.848 .19246 Mdot
.848 .19352 Mdot
.848 .19363 Mdot
.848 .19386 Mdot
.848 .19412 Mdot
.848 .19484 Mdot
.848 .19499 Mdot
.848 .19514 Mdot
.848 .19516 Mdot
.848 .19604 Mdot
.848 .19661 Mdot
.848 .19689 Mdot
.848 .19703 Mdot
.848 .19778 Mdot
.848 .19803 Mdot
.848 .19852 Mdot
.848 .19858 Mdot
.848 .19862 Mdot
.848 .20001 Mdot
.848 .20021 Mdot
.848 .20092 Mdot
.848 .20098 Mdot
.848 .20102 Mdot
.848 .20143 Mdot
.848 .20288 Mdot
.848 .20371 Mdot
.848 .20374 Mdot
.848 .20378 Mdot
.848 .20515 Mdot
.848 .20526 Mdot
.848 .2056 Mdot
.848 .20567 Mdot
.848 .20596 Mdot
.848 .20703 Mdot
.848 .20705 Mdot
.848 .20707 Mdot
.848 .2076 Mdot
.848 .20774 Mdot
.848 .20801 Mdot
.848 .20834 Mdot
.848 .209 Mdot
.848 .20929 Mdot
.848 .20929 Mdot
.848 .20975 Mdot
.848 .21025 Mdot
.848 .21079 Mdot
.848 .21136 Mdot
.848 .21247 Mdot
.848 .21258 Mdot
.848 .21263 Mdot
.848 .21268 Mdot
.848 .21386 Mdot
.848 .21425 Mdot
.848 .21468 Mdot
.848 .215 Mdot
.848 .2153 Mdot
.848 .21547 Mdot
.848 .21652 Mdot
.848 .21732 Mdot
.848 .2181 Mdot
.848 .21847 Mdot
.848 .21889 Mdot
.848 .22037 Mdot
.848 .22103 Mdot
.848 .22227 Mdot
.848 .22323 Mdot
.848 .22327 Mdot
.848 .2233 Mdot
.848 .224 Mdot
.848 .22442 Mdot
.848 .22461 Mdot
.848 .22532 Mdot
.848 .22562 Mdot
.848 .22568 Mdot
.848 .22632 Mdot
.848 .22672 Mdot
.848 .22698 Mdot
.848 .2272 Mdot
.848 .22729 Mdot
.848 .22768 Mdot
.848 .22846 Mdot
.848 .22875 Mdot
.848 .22881 Mdot
.848 .22911 Mdot
.848 .22921 Mdot
.848 .2293 Mdot
.848 .22993 Mdot
.848 .23067 Mdot
.848 .23088 Mdot
.848 .23155 Mdot
.848 .23186 Mdot
.848 .23276 Mdot
.848 .23348 Mdot
.848 .23628 Mdot
.848 .23633 Mdot
.848 .23737 Mdot
.848 .23886 Mdot
.848 .23923 Mdot
.848 .23925 Mdot
.848 .24016 Mdot
.848 .24032 Mdot
.848 .24047 Mdot
.848 .24059 Mdot
.848 .24066 Mdot
.848 .24112 Mdot
.848 .24119 Mdot
.848 .24162 Mdot
.848 .24189 Mdot
.848 .24212 Mdot
.848 .243 Mdot
.848 .24348 Mdot
.848 .24409 Mdot
.848 .24439 Mdot
.848 .24453 Mdot
.848 .24494 Mdot
.848 .24601 Mdot
.848 .24718 Mdot
.848 .24735 Mdot
.848 .24747 Mdot
.848 .24789 Mdot
.848 .2485 Mdot
.848 .24934 Mdot
.848 .24953 Mdot
.848 .24967 Mdot
.848 .24987 Mdot
.848 .25015 Mdot
.848 .25058 Mdot
.848 .25081 Mdot
.848 .25126 Mdot
.848 .25196 Mdot
.848 .25246 Mdot
.848 .25305 Mdot
.848 .25354 Mdot
.848 .25492 Mdot
.848 .25515 Mdot
.848 .25624 Mdot
.848 .25638 Mdot
.848 .25649 Mdot
.848 .25659 Mdot
.848 .25661 Mdot
.848 .25672 Mdot
.848 .25675 Mdot
.848 .25784 Mdot
.848 .25897 Mdot
.848 .25899 Mdot
.848 .25929 Mdot
.848 .25942 Mdot
.848 .25996 Mdot
.848 .26043 Mdot
.848 .26126 Mdot
.848 .26203 Mdot
.848 .26215 Mdot
.848 .26224 Mdot
.848 .26267 Mdot
.848 .26289 Mdot
.848 .26515 Mdot
.848 .26556 Mdot
.848 .26612 Mdot
.848 .26709 Mdot
.848 .26713 Mdot
.848 .26751 Mdot
.848 .26751 Mdot
.848 .26755 Mdot
.848 .26765 Mdot
.848 .26774 Mdot
.848 .26977 Mdot
.848 .27003 Mdot
.848 .27044 Mdot
.848 .27067 Mdot
.848 .27085 Mdot
.848 .27155 Mdot
.848 .27161 Mdot
.848 .27196 Mdot
.848 .27221 Mdot
.848 .27222 Mdot
.848 .27268 Mdot
.848 .27305 Mdot
.848 .27314 Mdot
.848 .27328 Mdot
.848 .27353 Mdot
.848 .27461 Mdot
.848 .27464 Mdot
.848 .27469 Mdot
.848 .27483 Mdot
.848 .27536 Mdot
.848 .2755 Mdot
.848 .27637 Mdot
.848 .27652 Mdot
.848 .27659 Mdot
.848 .27765 Mdot
.848 .27766 Mdot
.848 .27843 Mdot
.848 .27848 Mdot
.848 .27855 Mdot
.848 .2786 Mdot
.848 .27906 Mdot
.848 .27971 Mdot
.848 .28089 Mdot
.848 .281 Mdot
.848 .28165 Mdot
.848 .28175 Mdot
.848 .28216 Mdot
.848 .28267 Mdot
.848 .28272 Mdot
.848 .28283 Mdot
.848 .28304 Mdot
.848 .28359 Mdot
.848 .28383 Mdot
.848 .28404 Mdot
.848 .28452 Mdot
.848 .28516 Mdot
.848 .28553 Mdot
.848 .28676 Mdot
.848 .28708 Mdot
.848 .28719 Mdot
.848 .28742 Mdot
.848 .28749 Mdot
.848 .28775 Mdot
.848 .28803 Mdot
.848 .28814 Mdot
.848 .28816 Mdot
.848 .28867 Mdot
.848 .289 Mdot
.848 .28923 Mdot
.848 .28925 Mdot
.848 .28935 Mdot
.848 .28981 Mdot
.848 .29005 Mdot
.848 .29007 Mdot
.848 .29159 Mdot
.848 .29173 Mdot
.848 .29213 Mdot
.848 .2932 Mdot
.848 .29334 Mdot
.848 .29375 Mdot
.848 .29376 Mdot
.848 .29382 Mdot
.848 .29477 Mdot
.848 .29492 Mdot
.848 .29493 Mdot
.848 .29526 Mdot
.848 .29537 Mdot
.848 .29551 Mdot
.848 .29608 Mdot
.848 .29632 Mdot
.848 .29636 Mdot
.848 .29685 Mdot
.848 .29686 Mdot
.848 .29766 Mdot
.848 .29783 Mdot
.848 .29808 Mdot
.848 .29815 Mdot
.848 .29933 Mdot
.848 .30078 Mdot
.848 .30091 Mdot
.848 .30105 Mdot
.848 .30111 Mdot
.848 .30143 Mdot
.848 .30208 Mdot
.848 .3021 Mdot
.848 .30231 Mdot
.848 .30235 Mdot
.848 .30249 Mdot
.848 .3025 Mdot
.848 .3028 Mdot
.848 .30329 Mdot
.848 .3033 Mdot
.848 .30358 Mdot
.848 .30358 Mdot
.848 .30366 Mdot
.848 .30386 Mdot
.848 .3039 Mdot
.848 .30393 Mdot
.848 .30423 Mdot
.848 .30549 Mdot
.848 .30613 Mdot
.848 .3063 Mdot
.848 .30672 Mdot
.848 .30713 Mdot
.848 .30763 Mdot
.848 .30775 Mdot
.848 .30783 Mdot
.848 .30848 Mdot
.848 .3085 Mdot
.848 .30867 Mdot
.848 .30969 Mdot
.848 .3098 Mdot
.848 .30987 Mdot
.848 .3105 Mdot
.848 .31141 Mdot
.848 .31178 Mdot
.848 .31233 Mdot
.848 .31259 Mdot
.848 .31265 Mdot
.848 .31272 Mdot
.848 .31298 Mdot
.848 .31305 Mdot
.848 .31394 Mdot
.848 .31438 Mdot
.848 .31455 Mdot
.848 .31456 Mdot
.848 .31486 Mdot
.848 .31492 Mdot
.848 .31552 Mdot
.848 .31578 Mdot
.848 .31578 Mdot
.848 .31598 Mdot
.848 .31617 Mdot
.848 .31676 Mdot
.848 .31788 Mdot
.848 .31798 Mdot
.848 .31816 Mdot
.848 .31854 Mdot
.848 .31854 Mdot
.848 .31899 Mdot
.848 .31902 Mdot
.848 .3191 Mdot
.848 .31919 Mdot
.848 .31944 Mdot
.848 .3195 Mdot
.848 .31955 Mdot
.848 .31956 Mdot
.848 .31986 Mdot
.848 .32016 Mdot
.848 .32021 Mdot
.848 .32046 Mdot
.848 .32055 Mdot
.848 .32072 Mdot
.848 .32075 Mdot
.848 .32076 Mdot
.848 .32158 Mdot
.848 .32159 Mdot
.848 .32224 Mdot
.848 .32255 Mdot
.848 .32319 Mdot
.848 .32321 Mdot
.848 .32368 Mdot
.848 .32369 Mdot
.848 .3237 Mdot
.848 .32393 Mdot
.848 .32437 Mdot
.848 .3248 Mdot
.848 .32499 Mdot
.848 .32519 Mdot
.848 .32561 Mdot
.848 .32634 Mdot
.848 .32645 Mdot
.848 .32656 Mdot
.848 .32661 Mdot
.848 .32698 Mdot
.848 .32753 Mdot
.848 .32832 Mdot
.848 .32855 Mdot
.848 .32898 Mdot
.848 .32931 Mdot
.848 .32973 Mdot
.848 .32979 Mdot
.848 .33053 Mdot
.848 .33062 Mdot
.848 .33069 Mdot
.848 .33086 Mdot
.848 .33113 Mdot
.848 .33139 Mdot
.848 .33143 Mdot
.848 .33288 Mdot
.848 .33385 Mdot
.848 .33475 Mdot
.848 .33488 Mdot
.848 .3352 Mdot
.848 .33525 Mdot
.848 .33531 Mdot
.848 .33537 Mdot
.848 .33553 Mdot
.848 .33571 Mdot
.848 .33588 Mdot
.848 .33619 Mdot
.848 .33686 Mdot
.848 .3377 Mdot
.848 .33789 Mdot
.848 .3381 Mdot
.848 .33846 Mdot
.848 .33857 Mdot
.848 .33867 Mdot
.848 .33882 Mdot
.848 .3389 Mdot
.848 .33906 Mdot
.848 .3393 Mdot
.848 .33948 Mdot
.848 .33985 Mdot
.848 .34041 Mdot
.848 .34087 Mdot
.848 .34092 Mdot
.848 .34096 Mdot
.848 .34134 Mdot
.848 .34185 Mdot
.848 .3419 Mdot
.848 .34208 Mdot
.848 .34225 Mdot
.848 .34253 Mdot
.848 .34284 Mdot
.848 .3431 Mdot
.848 .34423 Mdot
.848 .34458 Mdot
.848 .34471 Mdot
.848 .34472 Mdot
.848 .34549 Mdot
.848 .34559 Mdot
.848 .34573 Mdot
.848 .34581 Mdot
.848 .34613 Mdot
.848 .34634 Mdot
.848 .34663 Mdot
.848 .3472 Mdot
.848 .34725 Mdot
.848 .34749 Mdot
.848 .34823 Mdot
.848 .3485 Mdot
.848 .34998 Mdot
.848 .35011 Mdot
.848 .3503 Mdot
.848 .35038 Mdot
.848 .35046 Mdot
.848 .35062 Mdot
.848 .35246 Mdot
.848 .35255 Mdot
.848 .35308 Mdot
.848 .35313 Mdot
.848 .35383 Mdot
.848 .35385 Mdot
.848 .35418 Mdot
.848 .35424 Mdot
.848 .35435 Mdot
.848 .35439 Mdot
.848 .35464 Mdot
.848 .35491 Mdot
.848 .35491 Mdot
.848 .35519 Mdot
.848 .35534 Mdot
.848 .35552 Mdot
.848 .35698 Mdot
.848 .35725 Mdot
.848 .35728 Mdot
.848 .35791 Mdot
.848 .35834 Mdot
.848 .35866 Mdot
.848 .35965 Mdot
.848 .36029 Mdot
.848 .361 Mdot
.848 .36106 Mdot
.848 .36119 Mdot
.848 .36183 Mdot
.848 .36222 Mdot
.848 .36245 Mdot
.848 .36262 Mdot
.848 .36276 Mdot
.848 .3628 Mdot
.848 .36322 Mdot
.848 .3635 Mdot
.848 .36351 Mdot
.848 .36384 Mdot
.848 .36406 Mdot
.848 .36424 Mdot
.848 .36463 Mdot
.848 .36469 Mdot
.848 .36516 Mdot
.848 .36538 Mdot
.848 .36557 Mdot
.848 .36593 Mdot
.848 .36636 Mdot
.848 .36673 Mdot
.848 .36683 Mdot
.848 .36808 Mdot
.848 .36824 Mdot
.848 .36836 Mdot
.848 .36842 Mdot
.848 .36848 Mdot
.848 .36945 Mdot
.848 .3695 Mdot
.848 .36967 Mdot
.848 .37038 Mdot
.848 .37057 Mdot
.848 .37069 Mdot
.848 .37185 Mdot
.848 .3719 Mdot
.848 .37241 Mdot
.848 .37251 Mdot
.848 .37287 Mdot
.848 .3736 Mdot
.848 .37427 Mdot
.848 .37472 Mdot
.848 .37484 Mdot
.848 .3749 Mdot
.848 .37509 Mdot
.848 .37524 Mdot
.848 .37591 Mdot
.848 .37614 Mdot
.848 .37723 Mdot
.848 .37763 Mdot
.848 .37771 Mdot
.848 .37782 Mdot
.848 .37784 Mdot
.848 .37798 Mdot
.848 .37808 Mdot
.848 .37834 Mdot
.848 .37849 Mdot
.848 .37866 Mdot
.848 .37973 Mdot
.848 .38098 Mdot
.848 .38134 Mdot
.848 .38204 Mdot
.848 .38247 Mdot
.848 .38299 Mdot
.848 .38315 Mdot
.848 .38453 Mdot
.848 .38491 Mdot
.848 .38552 Mdot
.848 .38574 Mdot
.848 .38604 Mdot
.848 .3864 Mdot
.848 .38744 Mdot
.848 .38809 Mdot
.848 .39043 Mdot
.848 .39049 Mdot
.848 .39057 Mdot
.848 .39069 Mdot
.848 .39158 Mdot
.848 .3923 Mdot
.848 .39234 Mdot
.848 .3935 Mdot
.848 .3941 Mdot
.848 .39486 Mdot
.848 .39549 Mdot
.848 .39552 Mdot
.848 .39623 Mdot
.848 .39632 Mdot
.848 .39706 Mdot
.848 .39734 Mdot
.848 .39759 Mdot
.848 .3978 Mdot
.848 .39792 Mdot
.848 .39805 Mdot
.848 .39832 Mdot
.848 .39859 Mdot
.848 .39869 Mdot
.848 .39882 Mdot
.848 .39902 Mdot
.848 .39919 Mdot
.848 .39944 Mdot
.848 .39946 Mdot
.848 .39955 Mdot
.848 .39965 Mdot
.848 .39978 Mdot
.848 .40001 Mdot
.848 .40039 Mdot
.848 .40046 Mdot
.848 .40188 Mdot
.848 .40232 Mdot
.848 .4027 Mdot
.848 .40271 Mdot
.848 .40373 Mdot
.848 .40384 Mdot
.848 .40409 Mdot
.848 .40425 Mdot
.848 .40442 Mdot
.848 .40449 Mdot
.848 .40452 Mdot
.848 .40473 Mdot
.848 .40517 Mdot
.848 .40549 Mdot
.848 .40662 Mdot
.848 .407 Mdot
.848 .40787 Mdot
.848 .40847 Mdot
.848 .40864 Mdot
.848 .40897 Mdot
.848 .40927 Mdot
.848 .40946 Mdot
.848 .40951 Mdot
.848 .40959 Mdot
.848 .41018 Mdot
.848 .41121 Mdot
.848 .41156 Mdot
.848 .41176 Mdot
.848 .41209 Mdot
.848 .41264 Mdot
.848 .41297 Mdot
.848 .41319 Mdot
.848 .41329 Mdot
.848 .41353 Mdot
.848 .41358 Mdot
.848 .41367 Mdot
.848 .414 Mdot
.848 .41473 Mdot
.848 .41513 Mdot
.848 .41531 Mdot
.848 .41541 Mdot
.848 .41552 Mdot
.848 .41571 Mdot
.848 .4159 Mdot
.848 .41598 Mdot
.848 .41708 Mdot
.848 .41794 Mdot
.848 .41811 Mdot
.848 .41827 Mdot
.848 .4189 Mdot
.848 .41894 Mdot
.848 .41963 Mdot
.848 .41977 Mdot
.848 .42024 Mdot
.848 .42056 Mdot
.848 .42094 Mdot
.848 .42173 Mdot
.848 .42184 Mdot
.848 .4221 Mdot
.848 .4225 Mdot
.848 .4225 Mdot
.848 .4228 Mdot
.848 .42317 Mdot
.848 .42374 Mdot
.848 .42374 Mdot
.848 .42424 Mdot
.848 .42435 Mdot
.848 .42458 Mdot
.848 .42476 Mdot
.848 .42494 Mdot
.848 .42494 Mdot
.848 .42497 Mdot
.848 .425 Mdot
.848 .42515 Mdot
.848 .4252 Mdot
.848 .42525 Mdot
.848 .42554 Mdot
.848 .42592 Mdot
.848 .42658 Mdot
.848 .42705 Mdot
.848 .42767 Mdot
.848 .42788 Mdot
.848 .42799 Mdot
.848 .42897 Mdot
.848 .42901 Mdot
.848 .42919 Mdot
.848 .42952 Mdot
.848 .42974 Mdot
.848 .43027 Mdot
.848 .43065 Mdot
.848 .43145 Mdot
.848 .43197 Mdot
.848 .43251 Mdot
.848 .43285 Mdot
.848 .43323 Mdot
.848 .43417 Mdot
.848 .43431 Mdot
.848 .43436 Mdot
.848 .43436 Mdot
.848 .43452 Mdot
.848 .43482 Mdot
.848 .43524 Mdot
.848 .43562 Mdot
.848 .4376 Mdot
.848 .43785 Mdot
.848 .43832 Mdot
.848 .43832 Mdot
.848 .43878 Mdot
.848 .4392 Mdot
.848 .43926 Mdot
.848 .43946 Mdot
.848 .43946 Mdot
.848 .43955 Mdot
.848 .44011 Mdot
.848 .44014 Mdot
.848 .44015 Mdot
.848 .44111 Mdot
.848 .44134 Mdot
.848 .44143 Mdot
.848 .44233 Mdot
.848 .44248 Mdot
.848 .44275 Mdot
.848 .44282 Mdot
.848 .44345 Mdot
.848 .44346 Mdot
.848 .44352 Mdot
.848 .44369 Mdot
.848 .44384 Mdot
.848 .4456 Mdot
.848 .44588 Mdot
.848 .446 Mdot
.848 .44614 Mdot
.848 .44647 Mdot
.848 .44668 Mdot
.848 .44728 Mdot
.848 .44774 Mdot
.848 .44843 Mdot
.848 .44881 Mdot
.848 .44911 Mdot
.848 .44919 Mdot
.848 .44965 Mdot
.848 .45031 Mdot
.848 .4504 Mdot
.848 .45091 Mdot
.848 .45099 Mdot
.848 .45131 Mdot
.848 .45139 Mdot
.848 .45142 Mdot
.848 .45144 Mdot
.848 .45222 Mdot
.848 .45236 Mdot
.848 .45285 Mdot
.848 .45285 Mdot
.848 .453 Mdot
.848 .45321 Mdot
.848 .45324 Mdot
.848 .45366 Mdot
.848 .45376 Mdot
.848 .45389 Mdot
.848 .45414 Mdot
.848 .45429 Mdot
.848 .45549 Mdot
.848 .45554 Mdot
.848 .4556 Mdot
.848 .45562 Mdot
.848 .45563 Mdot
.848 .45585 Mdot
.848 .45587 Mdot
.848 .45644 Mdot
.848 .45677 Mdot
.848 .45701 Mdot
.848 .45835 Mdot
.848 .45848 Mdot
.848 .45873 Mdot
.848 .45879 Mdot
.848 .45885 Mdot
.848 .45931 Mdot
.848 .4598 Mdot
.848 .46008 Mdot
.848 .46039 Mdot
.848 .46047 Mdot
.848 .46065 Mdot
.848 .46066 Mdot
.848 .46133 Mdot
.848 .46197 Mdot
.848 .46199 Mdot
.848 .46205 Mdot
.848 .46206 Mdot
.848 .46212 Mdot
.848 .46219 Mdot
.848 .46227 Mdot
.848 .46291 Mdot
.848 .46305 Mdot
.848 .46386 Mdot
.848 .46415 Mdot
.848 .4645 Mdot
.848 .46479 Mdot
.848 .4652 Mdot
.848 .46547 Mdot
.848 .46561 Mdot
.848 .46586 Mdot
.848 .46603 Mdot
.848 .46615 Mdot
.848 .46622 Mdot
.848 .46634 Mdot
.848 .46684 Mdot
.848 .46719 Mdot
.848 .46744 Mdot
.848 .46751 Mdot
.848 .46761 Mdot
.848 .4683 Mdot
.848 .46893 Mdot
.848 .46917 Mdot
.848 .46925 Mdot
.848 .46943 Mdot
.848 .46979 Mdot
.848 .47008 Mdot
.848 .4706 Mdot
.848 .47073 Mdot
.848 .47089 Mdot
.848 .47114 Mdot
.848 .47119 Mdot
.848 .47146 Mdot
.848 .4715 Mdot
.848 .47157 Mdot
.848 .47166 Mdot
.848 .47175 Mdot
.848 .47229 Mdot
.848 .4723 Mdot
.848 .47252 Mdot
.848 .47339 Mdot
.848 .47401 Mdot
.848 .47404 Mdot
.848 .47569 Mdot
.848 .47611 Mdot
.848 .47664 Mdot
.848 .47683 Mdot
.848 .47722 Mdot
.848 .47734 Mdot
.848 .47778 Mdot
.848 .47815 Mdot
.848 .47821 Mdot
.848 .47826 Mdot
.848 .47844 Mdot
.848 .47848 Mdot
.848 .47865 Mdot
.848 .47911 Mdot
.848 .47934 Mdot
.848 .47939 Mdot
.848 .47952 Mdot
.848 .47968 Mdot
.848 .47991 Mdot
.848 .48029 Mdot
.848 .48032 Mdot
.848 .4805 Mdot
.848 .48092 Mdot
.848 .48103 Mdot
.848 .48128 Mdot
.848 .48169 Mdot
.848 .48171 Mdot
.848 .48173 Mdot
.848 .4823 Mdot
.848 .48303 Mdot
.848 .48342 Mdot
.848 .48429 Mdot
.848 .48454 Mdot
.848 .48476 Mdot
.848 .48522 Mdot
.848 .48569 Mdot
.848 .48631 Mdot
.848 .48641 Mdot
.848 .48659 Mdot
.848 .48677 Mdot
.848 .48703 Mdot
.848 .48726 Mdot
.848 .48796 Mdot
.848 .48798 Mdot
.848 .48801 Mdot
.848 .48808 Mdot
.848 .48873 Mdot
.848 .48907 Mdot
.848 .48939 Mdot
.848 .48968 Mdot
.848 .48995 Mdot
.848 .48995 Mdot
.848 .49012 Mdot
.848 .49051 Mdot
.848 .49071 Mdot
.848 .49087 Mdot
.848 .49095 Mdot
.848 .49126 Mdot
.848 .49127 Mdot
.848 .49129 Mdot
.848 .49192 Mdot
.848 .49209 Mdot
.848 .49213 Mdot
.848 .49233 Mdot
.848 .49239 Mdot
.848 .4932 Mdot
.848 .49322 Mdot
.848 .49324 Mdot
.848 .49373 Mdot
.848 .49458 Mdot
.848 .49483 Mdot
.848 .49485 Mdot
.848 .49488 Mdot
.848 .49531 Mdot
.848 .49542 Mdot
.848 .49624 Mdot
.848 .49626 Mdot
.848 .4963 Mdot
.848 .49659 Mdot
.848 .49674 Mdot
.848 .49718 Mdot
.848 .49726 Mdot
.848 .49743 Mdot
.848 .49777 Mdot
.848 .49828 Mdot
.848 .49829 Mdot
.848 .49838 Mdot
.848 .49847 Mdot
.848 .4989 Mdot
.848 .49905 Mdot
.848 .49918 Mdot
.848 .49925 Mdot
.848 .49988 Mdot
.848 .50001 Mdot
.848 .50001 Mdot
.848 .5001 Mdot
.848 .50033 Mdot
.848 .50044 Mdot
.848 .50065 Mdot
.848 .50096 Mdot
.848 .50099 Mdot
.848 .50112 Mdot
.848 .50209 Mdot
.848 .50213 Mdot
.848 .50248 Mdot
.848 .50255 Mdot
.848 .50277 Mdot
.848 .5028 Mdot
.848 .50302 Mdot
.848 .50331 Mdot
.848 .50403 Mdot
.848 .50413 Mdot
.848 .50415 Mdot
.848 .50435 Mdot
.848 .50463 Mdot
.848 .50463 Mdot
.848 .50468 Mdot
.848 .50469 Mdot
.848 .50477 Mdot
.848 .50511 Mdot
.848 .50513 Mdot
.848 .50518 Mdot
.848 .50523 Mdot
.848 .50573 Mdot
.848 .50614 Mdot
.848 .50625 Mdot
.848 .50676 Mdot
.848 .50677 Mdot
.848 .50706 Mdot
.848 .50781 Mdot
.848 .50786 Mdot
.848 .50895 Mdot
.848 .50924 Mdot
.848 .50932 Mdot
.848 .50944 Mdot
.848 .50987 Mdot
.848 .50995 Mdot
.848 .50999 Mdot
.848 .5101 Mdot
.848 .51053 Mdot
.848 .51066 Mdot
.848 .51147 Mdot
.848 .5115 Mdot
.848 .5117 Mdot
.848 .51184 Mdot
.848 .5121 Mdot
.848 .51294 Mdot
.848 .51298 Mdot
.848 .51327 Mdot
.848 .51364 Mdot
.848 .5147 Mdot
.848 .51484 Mdot
.848 .515 Mdot
.85 .1658 Mdot
.85 .16662 Mdot
.85 .16664 Mdot
.85 .16912 Mdot
.85 .16962 Mdot
.85 .16966 Mdot
.85 .16998 Mdot
.85 .17024 Mdot
.85 .17099 Mdot
.85 .17111 Mdot
.85 .17136 Mdot
.85 .17197 Mdot
.85 .17343 Mdot
.85 .17351 Mdot
.85 .17359 Mdot
.85 .17396 Mdot
.85 .17405 Mdot
.85 .17541 Mdot
.85 .17562 Mdot
.85 .17692 Mdot
.85 .17724 Mdot
.85 .17736 Mdot
.85 .17811 Mdot
.85 .17812 Mdot
.85 .17817 Mdot
.85 .1797 Mdot
.85 .17975 Mdot
.85 .1802 Mdot
.85 .18049 Mdot
.85 .18096 Mdot
.85 .18107 Mdot
.85 .1812 Mdot
.85 .18159 Mdot
.85 .18227 Mdot
.85 .18272 Mdot
.85 .18281 Mdot
.85 .18464 Mdot
.85 .18475 Mdot
.85 .18489 Mdot
.85 .18577 Mdot
.85 .1861 Mdot
.85 .18615 Mdot
.85 .18642 Mdot
.85 .18652 Mdot
.85 .18697 Mdot
.85 .18837 Mdot
.85 .18853 Mdot
.85 .18904 Mdot
.85 .18944 Mdot
.85 .18992 Mdot
.85 .19087 Mdot
.85 .19135 Mdot
.85 .19181 Mdot
.85 .19222 Mdot
.85 .1925 Mdot
.85 .19444 Mdot
.85 .19494 Mdot
.85 .19497 Mdot
.85 .19521 Mdot
.85 .19563 Mdot
.85 .19654 Mdot
.85 .19777 Mdot
.85 .1981 Mdot
.85 .19826 Mdot
.85 .19909 Mdot
.85 .19945 Mdot
.85 .19971 Mdot
.85 .20036 Mdot
.85 .20084 Mdot
.85 .20087 Mdot
.85 .2015 Mdot
.85 .20254 Mdot
.85 .20275 Mdot
.85 .20316 Mdot
.85 .2032 Mdot
.85 .2035 Mdot
.85 .20427 Mdot
.85 .20462 Mdot
.85 .20465 Mdot
.85 .205 Mdot
.85 .20538 Mdot
.85 .20545 Mdot
.85 .20555 Mdot
.85 .20567 Mdot
.85 .20597 Mdot
.85 .20602 Mdot
.85 .20619 Mdot
.85 .20684 Mdot
.85 .20708 Mdot
.85 .20834 Mdot
.85 .20901 Mdot
.85 .20979 Mdot
.85 .21144 Mdot
.85 .21165 Mdot
.85 .21203 Mdot
.85 .21213 Mdot
.85 .21214 Mdot
.85 .21266 Mdot
.85 .21338 Mdot
.85 .21364 Mdot
.85 .21439 Mdot
.85 .21451 Mdot
.85 .21461 Mdot
.85 .21476 Mdot
.85 .21485 Mdot
.85 .2149 Mdot
.85 .21628 Mdot
.85 .21734 Mdot
.85 .21776 Mdot
.85 .21848 Mdot
.85 .21857 Mdot
.85 .21911 Mdot
.85 .21919 Mdot
.85 .22029 Mdot
.85 .22049 Mdot
.85 .22074 Mdot
.85 .22155 Mdot
.85 .22213 Mdot
.85 .2247 Mdot
.85 .22473 Mdot
.85 .22487 Mdot
.85 .22502 Mdot
.85 .22585 Mdot
.85 .2259 Mdot
.85 .22669 Mdot
.85 .22692 Mdot
.85 .2271 Mdot
.85 .22711 Mdot
.85 .22725 Mdot
.85 .22767 Mdot
.85 .22815 Mdot
.85 .22822 Mdot
.85 .22866 Mdot
.85 .22985 Mdot
.85 .23033 Mdot
.85 .23076 Mdot
.85 .23096 Mdot
.85 .23148 Mdot
.85 .23358 Mdot
.85 .23482 Mdot
.85 .23524 Mdot
.85 .23527 Mdot
.85 .23541 Mdot
.85 .2355 Mdot
.85 .2358 Mdot
.85 .23606 Mdot
.85 .23646 Mdot
.85 .23672 Mdot
.85 .23708 Mdot
.85 .23748 Mdot
.85 .23788 Mdot
.85 .2385 Mdot
.85 .2387 Mdot
.85 .23906 Mdot
.85 .24014 Mdot
.85 .24071 Mdot
.85 .24156 Mdot
.85 .24262 Mdot
.85 .24298 Mdot
.85 .24298 Mdot
.85 .2434 Mdot
.85 .24361 Mdot
.85 .24395 Mdot
.85 .24396 Mdot
.85 .24442 Mdot
.85 .24484 Mdot
.85 .24497 Mdot
.85 .24506 Mdot
.85 .24529 Mdot
.85 .2453 Mdot
.85 .24568 Mdot
.85 .24582 Mdot
.85 .24645 Mdot
.85 .24728 Mdot
.85 .24751 Mdot
.85 .24779 Mdot
.85 .24806 Mdot
.85 .24806 Mdot
.85 .24819 Mdot
.85 .24931 Mdot
.85 .24937 Mdot
.85 .24939 Mdot
.85 .24976 Mdot
.85 .24985 Mdot
.85 .25025 Mdot
.85 .25041 Mdot
.85 .25083 Mdot
.85 .25111 Mdot
.85 .25129 Mdot
.85 .25183 Mdot
.85 .25231 Mdot
.85 .25253 Mdot
.85 .25338 Mdot
.85 .25343 Mdot
.85 .25356 Mdot
.85 .25399 Mdot
.85 .25483 Mdot
.85 .25641 Mdot
.85 .25655 Mdot
.85 .2566 Mdot
.85 .25776 Mdot
.85 .25868 Mdot
.85 .25907 Mdot
.85 .26022 Mdot
.85 .26114 Mdot
.85 .26158 Mdot
.85 .2622 Mdot
.85 .26224 Mdot
.85 .26259 Mdot
.85 .26344 Mdot
.85 .26396 Mdot
.85 .26441 Mdot
.85 .26452 Mdot
.85 .26525 Mdot
.85 .26562 Mdot
.85 .26685 Mdot
.85 .26695 Mdot
.85 .26723 Mdot
.85 .26756 Mdot
.85 .26762 Mdot
.85 .26873 Mdot
.85 .269 Mdot
.85 .26977 Mdot
.85 .27106 Mdot
.85 .27123 Mdot
.85 .27135 Mdot
.85 .27157 Mdot
.85 .27295 Mdot
.85 .27299 Mdot
.85 .27376 Mdot
.85 .27447 Mdot
.85 .27535 Mdot
.85 .27569 Mdot
.85 .27598 Mdot
.85 .27633 Mdot
.85 .2768 Mdot
.85 .2772 Mdot
.85 .27805 Mdot
.85 .27812 Mdot
.85 .27867 Mdot
.85 .27911 Mdot
.85 .27915 Mdot
.85 .2802 Mdot
.85 .28039 Mdot
.85 .28056 Mdot
.85 .28058 Mdot
.85 .28096 Mdot
.85 .28101 Mdot
.85 .28157 Mdot
.85 .28205 Mdot
.85 .28208 Mdot
.85 .28212 Mdot
.85 .28227 Mdot
.85 .28255 Mdot
.85 .28262 Mdot
.85 .28277 Mdot
.85 .28326 Mdot
.85 .28355 Mdot
.85 .28453 Mdot
.85 .28467 Mdot
.85 .28481 Mdot
.85 .28516 Mdot
.85 .28525 Mdot
.85 .28535 Mdot
.85 .28539 Mdot
.85 .28543 Mdot
.85 .28559 Mdot
.85 .28675 Mdot
.85 .28693 Mdot
.85 .28731 Mdot
.85 .28787 Mdot
.85 .2879 Mdot
.85 .28807 Mdot
.85 .28826 Mdot
.85 .28868 Mdot
.85 .28869 Mdot
.85 .28898 Mdot
.85 .28909 Mdot
.85 .28998 Mdot
.85 .29046 Mdot
.85 .291 Mdot
.85 .29121 Mdot
.85 .29248 Mdot
.85 .2925 Mdot
.85 .29253 Mdot
.85 .29258 Mdot
.85 .29262 Mdot
.85 .29301 Mdot
.85 .29344 Mdot
.85 .29344 Mdot
.85 .29361 Mdot
.85 .29368 Mdot
.85 .29425 Mdot
.85 .29475 Mdot
.85 .29519 Mdot
.85 .29527 Mdot
.85 .2955 Mdot
.85 .29572 Mdot
.85 .29591 Mdot
.85 .29603 Mdot
.85 .29604 Mdot
.85 .29616 Mdot
.85 .29643 Mdot
.85 .29653 Mdot
.85 .29655 Mdot
.85 .29669 Mdot
.85 .29734 Mdot
.85 .29735 Mdot
.85 .29752 Mdot
.85 .29774 Mdot
.85 .29841 Mdot
.85 .29884 Mdot
.85 .2993 Mdot
.85 .29938 Mdot
.85 .29939 Mdot
.85 .29956 Mdot
.85 .30033 Mdot
.85 .30047 Mdot
.85 .30113 Mdot
.85 .30129 Mdot
.85 .30143 Mdot
.85 .30161 Mdot
.85 .30231 Mdot
.85 .30234 Mdot
.85 .30243 Mdot
.85 .30295 Mdot
.85 .30359 Mdot
.85 .30377 Mdot
.85 .30401 Mdot
.85 .30423 Mdot
.85 .30465 Mdot
.85 .30466 Mdot
.85 .30547 Mdot
.85 .30552 Mdot
.85 .30607 Mdot
.85 .30615 Mdot
.85 .30662 Mdot
.85 .30678 Mdot
.85 .30734 Mdot
.85 .30755 Mdot
.85 .30768 Mdot
.85 .30803 Mdot
.85 .30814 Mdot
.85 .30815 Mdot
.85 .30992 Mdot
.85 .3102 Mdot
.85 .31021 Mdot
.85 .31107 Mdot
.85 .31146 Mdot
.85 .31176 Mdot
.85 .31256 Mdot
.85 .31259 Mdot
.85 .31274 Mdot
.85 .31377 Mdot
.85 .31418 Mdot
.85 .31418 Mdot
.85 .3142 Mdot
.85 .3149 Mdot
.85 .315 Mdot
.85 .3152 Mdot
.85 .31525 Mdot
.85 .31578 Mdot
.85 .31648 Mdot
.85 .31652 Mdot
.85 .31683 Mdot
.85 .31694 Mdot
.85 .31725 Mdot
.85 .31773 Mdot
.85 .31859 Mdot
.85 .31876 Mdot
.85 .31916 Mdot
.85 .32024 Mdot
.85 .3211 Mdot
.85 .32115 Mdot
.85 .32144 Mdot
.85 .32156 Mdot
.85 .32227 Mdot
.85 .32263 Mdot
.85 .32361 Mdot
.85 .32364 Mdot
.85 .32372 Mdot
.85 .32382 Mdot
.85 .32384 Mdot
.85 .32487 Mdot
.85 .32592 Mdot
.85 .32613 Mdot
.85 .32647 Mdot
.85 .32673 Mdot
.85 .32739 Mdot
.85 .32775 Mdot
.85 .3279 Mdot
.85 .32815 Mdot
.85 .32836 Mdot
.85 .32877 Mdot
.85 .32884 Mdot
.85 .32921 Mdot
.85 .33031 Mdot
.85 .33036 Mdot
.85 .33099 Mdot
.85 .33107 Mdot
.85 .33113 Mdot
.85 .33118 Mdot
.85 .33167 Mdot
.85 .33225 Mdot
.85 .3324 Mdot
.85 .33337 Mdot
.85 .33395 Mdot
.85 .33401 Mdot
.85 .33437 Mdot
.85 .33446 Mdot
.85 .33508 Mdot
.85 .33514 Mdot
.85 .33527 Mdot
.85 .33564 Mdot
.85 .3365 Mdot
.85 .33662 Mdot
.85 .33696 Mdot
.85 .33697 Mdot
.85 .33742 Mdot
.85 .33743 Mdot
.85 .33756 Mdot
.85 .33761 Mdot
.85 .33811 Mdot
.85 .33819 Mdot
.85 .33829 Mdot
.85 .33838 Mdot
.85 .33884 Mdot
.85 .33897 Mdot
.85 .33914 Mdot
.85 .33934 Mdot
.85 .33944 Mdot
.85 .3395 Mdot
.85 .33969 Mdot
.85 .33986 Mdot
.85 .33993 Mdot
.85 .34023 Mdot
.85 .34044 Mdot
.85 .34132 Mdot
.85 .34174 Mdot
.85 .34206 Mdot
.85 .34291 Mdot
.85 .34327 Mdot
.85 .34329 Mdot
.85 .34388 Mdot
.85 .34408 Mdot
.85 .34433 Mdot
.85 .34446 Mdot
.85 .34488 Mdot
.85 .34502 Mdot
.85 .34513 Mdot
.85 .34515 Mdot
.85 .34553 Mdot
.85 .34589 Mdot
.85 .34634 Mdot
.85 .34728 Mdot
.85 .34752 Mdot
.85 .34794 Mdot
.85 .34914 Mdot
.85 .3495 Mdot
.85 .34977 Mdot
.85 .34998 Mdot
.85 .35015 Mdot
.85 .35017 Mdot
.85 .35022 Mdot
.85 .35032 Mdot
.85 .35034 Mdot
.85 .35056 Mdot
.85 .35122 Mdot
.85 .35125 Mdot
.85 .35129 Mdot
.85 .3513 Mdot
.85 .35197 Mdot
.85 .35223 Mdot
.85 .35244 Mdot
.85 .35258 Mdot
.85 .35289 Mdot
.85 .3538 Mdot
.85 .35394 Mdot
.85 .35408 Mdot
.85 .35409 Mdot
.85 .35417 Mdot
.85 .35437 Mdot
.85 .35454 Mdot
.85 .3548 Mdot
.85 .35494 Mdot
.85 .35503 Mdot
.85 .35512 Mdot
.85 .35516 Mdot
.85 .35521 Mdot
.85 .35611 Mdot
.85 .35614 Mdot
.85 .35614 Mdot
.85 .35675 Mdot
.85 .35685 Mdot
.85 .35691 Mdot
.85 .35738 Mdot
.85 .35796 Mdot
.85 .35797 Mdot
.85 .35889 Mdot
.85 .35901 Mdot
.85 .35913 Mdot
.85 .35918 Mdot
.85 .35989 Mdot
.85 .36076 Mdot
.85 .36112 Mdot
.85 .36126 Mdot
.85 .36127 Mdot
.85 .36151 Mdot
.85 .36162 Mdot
.85 .36207 Mdot
.85 .36218 Mdot
.85 .36232 Mdot
.85 .36249 Mdot
.85 .36377 Mdot
.85 .36419 Mdot
.85 .36453 Mdot
.85 .36454 Mdot
.85 .3646 Mdot
.85 .36496 Mdot
.85 .36617 Mdot
.85 .36634 Mdot
.85 .36711 Mdot
.85 .36731 Mdot
.85 .3679 Mdot
.85 .36903 Mdot
.85 .3693 Mdot
.85 .36931 Mdot
.85 .3696 Mdot
.85 .37035 Mdot
.85 .37091 Mdot
.85 .37169 Mdot
.85 .37174 Mdot
.85 .37197 Mdot
.85 .37198 Mdot
.85 .37224 Mdot
.85 .37271 Mdot
.85 .3728 Mdot
.85 .37365 Mdot
.85 .37373 Mdot
.85 .37385 Mdot
.85 .3741 Mdot
.85 .37502 Mdot
.85 .37507 Mdot
.85 .37507 Mdot
.85 .37546 Mdot
.85 .37577 Mdot
.85 .37578 Mdot
.85 .37603 Mdot
.85 .37605 Mdot
.85 .37673 Mdot
.85 .37682 Mdot
.85 .37738 Mdot
.85 .37755 Mdot
.85 .37764 Mdot
.85 .37768 Mdot
.85 .37798 Mdot
.85 .37842 Mdot
.85 .37871 Mdot
.85 .37958 Mdot
.85 .37985 Mdot
.85 .38024 Mdot
.85 .38034 Mdot
.85 .38044 Mdot
.85 .38126 Mdot
.85 .38155 Mdot
.85 .382 Mdot
.85 .38233 Mdot
.85 .38313 Mdot
.85 .38322 Mdot
.85 .38512 Mdot
.85 .38679 Mdot
.85 .38796 Mdot
.85 .3889 Mdot
.85 .38961 Mdot
.85 .38966 Mdot
.85 .38989 Mdot
.85 .39005 Mdot
.85 .39056 Mdot
.85 .39099 Mdot
.85 .39119 Mdot
.85 .39134 Mdot
.85 .39168 Mdot
.85 .39213 Mdot
.85 .3927 Mdot
.85 .39273 Mdot
.85 .39327 Mdot
.85 .39342 Mdot
.85 .39404 Mdot
.85 .39409 Mdot
.85 .39453 Mdot
.85 .39515 Mdot
.85 .39548 Mdot
.85 .39592 Mdot
.85 .39609 Mdot
.85 .3961 Mdot
.85 .39626 Mdot
.85 .39692 Mdot
.85 .39739 Mdot
.85 .39794 Mdot
.85 .39886 Mdot
.85 .3989 Mdot
.85 .39935 Mdot
.85 .4001 Mdot
.85 .40035 Mdot
.85 .40062 Mdot
.85 .40068 Mdot
.85 .40083 Mdot
.85 .40112 Mdot
.85 .40208 Mdot
.85 .40215 Mdot
.85 .40222 Mdot
.85 .40276 Mdot
.85 .40277 Mdot
.85 .40339 Mdot
.85 .40342 Mdot
.85 .40348 Mdot
.85 .40384 Mdot
.85 .40384 Mdot
.85 .40386 Mdot
.85 .40439 Mdot
.85 .40442 Mdot
.85 .40444 Mdot
.85 .40505 Mdot
.85 .40505 Mdot
.85 .40514 Mdot
.85 .40522 Mdot
.85 .40593 Mdot
.85 .40614 Mdot
.85 .4063 Mdot
.85 .40669 Mdot
.85 .40669 Mdot
.85 .40671 Mdot
.85 .40712 Mdot
.85 .40732 Mdot
.85 .40735 Mdot
.85 .40746 Mdot
.85 .40759 Mdot
.85 .40866 Mdot
.85 .40891 Mdot
.85 .40905 Mdot
.85 .40987 Mdot
.85 .41008 Mdot
.85 .4103 Mdot
.85 .41032 Mdot
.85 .41046 Mdot
.85 .41071 Mdot
.85 .41079 Mdot
.85 .41093 Mdot
.85 .4114 Mdot
.85 .41141 Mdot
.85 .41162 Mdot
.85 .41212 Mdot
.85 .41308 Mdot
.85 .41352 Mdot
.85 .41363 Mdot
.85 .41366 Mdot
.85 .41429 Mdot
.85 .41434 Mdot
.85 .41444 Mdot
.85 .41485 Mdot
.85 .41485 Mdot
.85 .41512 Mdot
.85 .41532 Mdot
.85 .41539 Mdot
.85 .41612 Mdot
.85 .41659 Mdot
.85 .41689 Mdot
.85 .41723 Mdot
.85 .41781 Mdot
.85 .41823 Mdot
.85 .41859 Mdot
.85 .41863 Mdot
.85 .419 Mdot
.85 .4199 Mdot
.85 .42018 Mdot
.85 .42045 Mdot
.85 .42054 Mdot
.85 .42075 Mdot
.85 .42149 Mdot
.85 .42223 Mdot
.85 .42284 Mdot
.85 .42291 Mdot
.85 .42296 Mdot
.85 .42297 Mdot
.85 .42355 Mdot
.85 .42425 Mdot
.85 .42559 Mdot
.85 .42583 Mdot
.85 .42593 Mdot
.85 .42644 Mdot
.85 .42672 Mdot
.85 .42696 Mdot
.85 .42714 Mdot
.85 .42789 Mdot
.85 .42792 Mdot
.85 .4281 Mdot
.85 .42851 Mdot
.85 .42852 Mdot
.85 .42876 Mdot
.85 .42937 Mdot
.85 .42946 Mdot
.85 .43012 Mdot
.85 .43086 Mdot
.85 .43207 Mdot
.85 .43208 Mdot
.85 .43214 Mdot
.85 .43235 Mdot
.85 .43255 Mdot
.85 .43364 Mdot
.85 .43412 Mdot
.85 .43413 Mdot
.85 .43438 Mdot
.85 .43513 Mdot
.85 .43543 Mdot
.85 .43551 Mdot
.85 .43592 Mdot
.85 .43602 Mdot
.85 .4361 Mdot
.85 .4362 Mdot
.85 .43722 Mdot
.85 .43723 Mdot
.85 .43728 Mdot
.85 .43755 Mdot
.85 .43842 Mdot
.85 .43881 Mdot
.85 .4389 Mdot
.85 .43896 Mdot
.85 .43912 Mdot
.85 .4392 Mdot
.85 .43927 Mdot
.85 .43938 Mdot
.85 .43951 Mdot
.85 .43995 Mdot
.85 .44024 Mdot
.85 .44058 Mdot
.85 .44062 Mdot
.85 .44072 Mdot
.85 .44072 Mdot
.85 .44097 Mdot
.85 .44121 Mdot
.85 .44126 Mdot
.85 .44276 Mdot
.85 .44328 Mdot
.85 .44334 Mdot
.85 .44351 Mdot
.85 .44352 Mdot
.85 .44388 Mdot
.85 .444 Mdot
.85 .44433 Mdot
.85 .44455 Mdot
.85 .44466 Mdot
.85 .44546 Mdot
.85 .44548 Mdot
.85 .44554 Mdot
.85 .44559 Mdot
.85 .44654 Mdot
.85 .44671 Mdot
.85 .447 Mdot
.85 .44709 Mdot
.85 .44713 Mdot
.85 .44729 Mdot
.85 .44738 Mdot
.85 .4474 Mdot
.85 .44771 Mdot
.85 .44806 Mdot
.85 .4483 Mdot
.85 .44851 Mdot
.85 .44913 Mdot
.85 .45051 Mdot
.85 .45078 Mdot
.85 .45099 Mdot
.85 .45116 Mdot
.85 .45136 Mdot
.85 .45188 Mdot
.85 .4523 Mdot
.85 .45372 Mdot
.85 .45379 Mdot
.85 .45388 Mdot
.85 .45465 Mdot
.85 .4551 Mdot
.85 .45526 Mdot
.85 .45591 Mdot
.85 .45594 Mdot
.85 .45614 Mdot
.85 .4563 Mdot
.85 .45636 Mdot
.85 .45709 Mdot
.85 .4573 Mdot
.85 .45773 Mdot
.85 .4578 Mdot
.85 .45807 Mdot
.85 .45837 Mdot
.85 .45887 Mdot
.85 .45908 Mdot
.85 .4591 Mdot
.85 .45947 Mdot
.85 .45972 Mdot
.85 .46026 Mdot
.85 .46094 Mdot
.85 .46117 Mdot
.85 .46171 Mdot
.85 .46239 Mdot
.85 .46242 Mdot
.85 .46251 Mdot
.85 .46343 Mdot
.85 .46393 Mdot
.85 .46418 Mdot
.85 .46425 Mdot
.85 .46428 Mdot
.85 .46479 Mdot
.85 .46491 Mdot
.85 .4652 Mdot
.85 .46552 Mdot
.85 .46562 Mdot
.85 .46578 Mdot
.85 .46604 Mdot
.85 .46613 Mdot
.85 .46636 Mdot
.85 .46642 Mdot
.85 .46663 Mdot
.85 .46665 Mdot
.85 .46668 Mdot
.85 .46734 Mdot
.85 .46741 Mdot
.85 .46742 Mdot
.85 .46758 Mdot
.85 .46774 Mdot
.85 .46787 Mdot
.85 .46836 Mdot
.85 .46874 Mdot
.85 .46882 Mdot
.85 .46904 Mdot
.85 .46905 Mdot
.85 .46918 Mdot
.85 .46924 Mdot
.85 .46931 Mdot
.85 .46956 Mdot
.85 .46983 Mdot
.85 .46983 Mdot
.85 .47003 Mdot
.85 .47016 Mdot
.85 .4704 Mdot
.85 .4704 Mdot
.85 .47062 Mdot
.85 .47124 Mdot
.85 .47174 Mdot
.85 .47207 Mdot
.85 .47271 Mdot
.85 .47292 Mdot
.85 .47304 Mdot
.85 .47341 Mdot
.85 .47364 Mdot
.85 .47388 Mdot
.85 .47408 Mdot
.85 .47424 Mdot
.85 .47448 Mdot
.85 .47463 Mdot
.85 .4748 Mdot
.85 .47486 Mdot
.85 .47494 Mdot
.85 .47496 Mdot
.85 .4752 Mdot
.85 .47593 Mdot
.85 .47717 Mdot
.85 .47748 Mdot
.85 .47759 Mdot
.85 .47785 Mdot
.85 .47813 Mdot
.85 .47883 Mdot
.85 .47909 Mdot
.85 .47913 Mdot
.85 .47941 Mdot
.85 .47966 Mdot
.85 .47974 Mdot
.85 .47974 Mdot
.85 .47985 Mdot
.85 .47999 Mdot
.85 .48045 Mdot
.85 .48048 Mdot
.85 .48097 Mdot
.85 .48106 Mdot
.85 .48114 Mdot
.85 .48116 Mdot
.85 .48267 Mdot
.85 .48301 Mdot
.85 .48349 Mdot
.85 .48364 Mdot
.85 .48375 Mdot
.85 .4844 Mdot
.85 .48445 Mdot
.85 .48476 Mdot
.85 .48481 Mdot
.85 .48524 Mdot
.85 .48549 Mdot
.85 .48611 Mdot
.85 .48692 Mdot
.85 .48695 Mdot
.85 .487 Mdot
.85 .48709 Mdot
.85 .48715 Mdot
.85 .48722 Mdot
.85 .48766 Mdot
.85 .48782 Mdot
.85 .48824 Mdot
.85 .48854 Mdot
.85 .48855 Mdot
.85 .48861 Mdot
.85 .48883 Mdot
.85 .48896 Mdot
.85 .48993 Mdot
.85 .49039 Mdot
.85 .49078 Mdot
.85 .49152 Mdot
.85 .49167 Mdot
.85 .49204 Mdot
.85 .49215 Mdot
.85 .49217 Mdot
.85 .49235 Mdot
.85 .49242 Mdot
.85 .49248 Mdot
.85 .49252 Mdot
.85 .49275 Mdot
.85 .49295 Mdot
.85 .49297 Mdot
.85 .49317 Mdot
.85 .49363 Mdot
.85 .4938 Mdot
.85 .49383 Mdot
.85 .49407 Mdot
.85 .49419 Mdot
.85 .4948 Mdot
.85 .49517 Mdot
.85 .49519 Mdot
.85 .49548 Mdot
.85 .49586 Mdot
.85 .49601 Mdot
.85 .49622 Mdot
.85 .49671 Mdot
.85 .4968 Mdot
.85 .497 Mdot
.85 .49772 Mdot
.85 .49826 Mdot
.85 .4985 Mdot
.85 .49865 Mdot
.85 .49866 Mdot
.85 .49896 Mdot
.85 .5001 Mdot
.85 .50026 Mdot
.85 .5005 Mdot
.85 .50077 Mdot
.85 .50106 Mdot
.85 .50162 Mdot
.85 .5019 Mdot
.85 .50213 Mdot
.85 .50243 Mdot
.85 .50253 Mdot
.85 .50335 Mdot
.85 .50362 Mdot
.85 .50367 Mdot
.85 .50384 Mdot
.85 .50386 Mdot
.85 .50405 Mdot
.85 .50458 Mdot
.85 .50466 Mdot
.85 .50472 Mdot
.85 .5058 Mdot
.85 .50585 Mdot
.85 .50611 Mdot
.85 .50651 Mdot
.85 .50675 Mdot
.85 .50682 Mdot
.85 .50688 Mdot
.85 .50716 Mdot
.85 .50733 Mdot
.85 .5076 Mdot
.85 .50763 Mdot
.85 .50853 Mdot
.85 .50856 Mdot
.85 .50856 Mdot
.85 .509 Mdot
.85 .50908 Mdot
.85 .50926 Mdot
.85 .51003 Mdot
.85 .51015 Mdot
.85 .51095 Mdot
.85 .511 Mdot
.85 .51122 Mdot
.85 .51127 Mdot
.85 .51132 Mdot
.85 .51217 Mdot
.85 .51253 Mdot
.85 .51268 Mdot
.85 .51275 Mdot
.85 .51319 Mdot
.85 .51335 Mdot
.85 .51353 Mdot
.85 .51356 Mdot
.85 .51385 Mdot
.85 .51531 Mdot
.85 .51532 Mdot
.85 .5158 Mdot
.852 .16355 Mdot
.852 .16372 Mdot
.852 .16395 Mdot
.852 .16446 Mdot
.852 .16576 Mdot
.852 .16578 Mdot
.852 .16579 Mdot
.852 .16587 Mdot
.852 .16608 Mdot
.852 .16612 Mdot
.852 .16665 Mdot
.852 .16707 Mdot
.852 .16736 Mdot
.852 .16831 Mdot
.852 .16855 Mdot
.852 .1686 Mdot
.852 .16874 Mdot
.852 .16922 Mdot
.852 .16971 Mdot
.852 .16974 Mdot
.852 .16984 Mdot
.852 .17029 Mdot
.852 .17086 Mdot
.852 .17146 Mdot
.852 .17173 Mdot
.852 .17202 Mdot
.852 .17261 Mdot
.852 .17273 Mdot
.852 .1734 Mdot
.852 .17413 Mdot
.852 .17474 Mdot
.852 .17526 Mdot
.852 .17527 Mdot
.852 .17534 Mdot
.852 .17609 Mdot
.852 .17719 Mdot
.852 .17833 Mdot
.852 .17848 Mdot
.852 .17993 Mdot
.852 .18035 Mdot
.852 .18054 Mdot
.852 .18065 Mdot
.852 .18126 Mdot
.852 .18192 Mdot
.852 .1824 Mdot
.852 .18258 Mdot
.852 .18304 Mdot
.852 .18388 Mdot
.852 .18401 Mdot
.852 .18545 Mdot
.852 .18568 Mdot
.852 .18583 Mdot
.852 .18667 Mdot
.852 .18679 Mdot
.852 .1871 Mdot
.852 .18719 Mdot
.852 .18731 Mdot
.852 .18774 Mdot
.852 .18784 Mdot
.852 .18829 Mdot
.852 .18944 Mdot
.852 .19037 Mdot
.852 .19085 Mdot
.852 .19115 Mdot
.852 .19123 Mdot
.852 .19129 Mdot
.852 .19168 Mdot
.852 .19197 Mdot
.852 .19226 Mdot
.852 .19253 Mdot
.852 .19272 Mdot
.852 .19352 Mdot
.852 .19564 Mdot
.852 .19597 Mdot
.852 .19634 Mdot
.852 .19685 Mdot
.852 .19903 Mdot
.852 .19955 Mdot
.852 .20049 Mdot
.852 .20161 Mdot
.852 .20216 Mdot
.852 .20257 Mdot
.852 .20275 Mdot
.852 .20367 Mdot
.852 .20373 Mdot
.852 .20379 Mdot
.852 .20443 Mdot
.852 .20561 Mdot
.852 .20714 Mdot
.852 .20816 Mdot
.852 .20866 Mdot
.852 .20911 Mdot
.852 .20938 Mdot
.852 .20976 Mdot
.852 .21047 Mdot
.852 .21119 Mdot
.852 .21163 Mdot
.852 .21325 Mdot
.852 .21505 Mdot
.852 .21572 Mdot
.852 .21596 Mdot
.852 .21614 Mdot
.852 .21693 Mdot
.852 .21731 Mdot
.852 .21801 Mdot
.852 .21841 Mdot
.852 .21893 Mdot
.852 .21907 Mdot
.852 .22069 Mdot
.852 .22109 Mdot
.852 .22117 Mdot
.852 .22124 Mdot
.852 .22143 Mdot
.852 .22152 Mdot
.852 .22159 Mdot
.852 .22172 Mdot
.852 .22253 Mdot
.852 .2227 Mdot
.852 .22286 Mdot
.852 .22304 Mdot
.852 .2234 Mdot
.852 .22403 Mdot
.852 .22441 Mdot
.852 .22529 Mdot
.852 .22564 Mdot
.852 .22567 Mdot
.852 .22596 Mdot
.852 .22618 Mdot
.852 .22824 Mdot
.852 .22965 Mdot
.852 .22982 Mdot
.852 .23001 Mdot
.852 .23125 Mdot
.852 .23167 Mdot
.852 .23198 Mdot
.852 .23423 Mdot
.852 .23441 Mdot
.852 .23469 Mdot
.852 .23489 Mdot
.852 .23646 Mdot
.852 .23734 Mdot
.852 .23756 Mdot
.852 .2382 Mdot
.852 .23833 Mdot
.852 .2385 Mdot
.852 .23855 Mdot
.852 .23881 Mdot
.852 .23894 Mdot
.852 .2393 Mdot
.852 .24004 Mdot
.852 .24016 Mdot
.852 .24166 Mdot
.852 .24173 Mdot
.852 .24179 Mdot
.852 .24191 Mdot
.852 .24211 Mdot
.852 .2422 Mdot
.852 .24231 Mdot
.852 .24234 Mdot
.852 .24247 Mdot
.852 .24312 Mdot
.852 .24314 Mdot
.852 .24319 Mdot
.852 .24445 Mdot
.852 .24489 Mdot
.852 .24491 Mdot
.852 .24507 Mdot
.852 .24566 Mdot
.852 .24601 Mdot
.852 .24744 Mdot
.852 .24798 Mdot
.852 .24822 Mdot
.852 .24933 Mdot
.852 .25 Mdot
.852 .25025 Mdot
.852 .25122 Mdot
.852 .25148 Mdot
.852 .25231 Mdot
.852 .25234 Mdot
.852 .25248 Mdot
.852 .25251 Mdot
.852 .25283 Mdot
.852 .25296 Mdot
.852 .25312 Mdot
.852 .25344 Mdot
.852 .25457 Mdot
.852 .25545 Mdot
.852 .25553 Mdot
.852 .25641 Mdot
.852 .25655 Mdot
.852 .25733 Mdot
.852 .25772 Mdot
.852 .25794 Mdot
.852 .25825 Mdot
.852 .25861 Mdot
.852 .25875 Mdot
.852 .25889 Mdot
.852 .25906 Mdot
.852 .25907 Mdot
.852 .25932 Mdot
.852 .26008 Mdot
.852 .26074 Mdot
.852 .26153 Mdot
.852 .26198 Mdot
.852 .26264 Mdot
.852 .26264 Mdot
.852 .26272 Mdot
.852 .26387 Mdot
.852 .264 Mdot
.852 .26411 Mdot
.852 .2642 Mdot
.852 .26452 Mdot
.852 .26476 Mdot
.852 .26554 Mdot
.852 .26618 Mdot
.852 .2662 Mdot
.852 .26657 Mdot
.852 .26829 Mdot
.852 .26834 Mdot
.852 .26862 Mdot
.852 .26879 Mdot
.852 .269 Mdot
.852 .26988 Mdot
.852 .27015 Mdot
.852 .27025 Mdot
.852 .27088 Mdot
.852 .27097 Mdot
.852 .2711 Mdot
.852 .27112 Mdot
.852 .27127 Mdot
.852 .27129 Mdot
.852 .27145 Mdot
.852 .27201 Mdot
.852 .27209 Mdot
.852 .27211 Mdot
.852 .27213 Mdot
.852 .27213 Mdot
.852 .27215 Mdot
.852 .27223 Mdot
.852 .27228 Mdot
.852 .27229 Mdot
.852 .27252 Mdot
.852 .27257 Mdot
.852 .27258 Mdot
.852 .27263 Mdot
.852 .27264 Mdot
.852 .27268 Mdot
.852 .27271 Mdot
.852 .27293 Mdot
.852 .27361 Mdot
.852 .27433 Mdot
.852 .27455 Mdot
.852 .27482 Mdot
.852 .27501 Mdot
.852 .27508 Mdot
.852 .27552 Mdot
.852 .27555 Mdot
.852 .27555 Mdot
.852 .27578 Mdot
.852 .27593 Mdot
.852 .27621 Mdot
.852 .27643 Mdot
.852 .27684 Mdot
.852 .27694 Mdot
.852 .27717 Mdot
.852 .27725 Mdot
.852 .2777 Mdot
.852 .278 Mdot
.852 .27803 Mdot
.852 .27833 Mdot
.852 .27883 Mdot
.852 .27888 Mdot
.852 .27893 Mdot
.852 .27904 Mdot
.852 .27905 Mdot
.852 .2791 Mdot
.852 .27911 Mdot
.852 .27982 Mdot
.852 .28079 Mdot
.852 .28128 Mdot
.852 .28166 Mdot
.852 .28182 Mdot
.852 .28225 Mdot
.852 .28227 Mdot
.852 .28227 Mdot
.852 .28262 Mdot
.852 .28275 Mdot
.852 .28278 Mdot
.852 .28359 Mdot
.852 .28371 Mdot
.852 .28376 Mdot
.852 .28387 Mdot
.852 .28397 Mdot
.852 .28511 Mdot
.852 .28518 Mdot
.852 .28534 Mdot
.852 .28636 Mdot
.852 .28679 Mdot
.852 .2874 Mdot
.852 .28829 Mdot
.852 .2883 Mdot
.852 .28842 Mdot
.852 .28872 Mdot
.852 .28907 Mdot
.852 .28931 Mdot
.852 .28969 Mdot
.852 .28981 Mdot
.852 .28986 Mdot
.852 .29 Mdot
.852 .29157 Mdot
.852 .29171 Mdot
.852 .29194 Mdot
.852 .29352 Mdot
.852 .29377 Mdot
.852 .29399 Mdot
.852 .29467 Mdot
.852 .2956 Mdot
.852 .29586 Mdot
.852 .29618 Mdot
.852 .29624 Mdot
.852 .29657 Mdot
.852 .29696 Mdot
.852 .29728 Mdot
.852 .29746 Mdot
.852 .29821 Mdot
.852 .29851 Mdot
.852 .29936 Mdot
.852 .29963 Mdot
.852 .2997 Mdot
.852 .29989 Mdot
.852 .30012 Mdot
.852 .30015 Mdot
.852 .30017 Mdot
.852 .30028 Mdot
.852 .30044 Mdot
.852 .30076 Mdot
.852 .3015 Mdot
.852 .30154 Mdot
.852 .30206 Mdot
.852 .30268 Mdot
.852 .30297 Mdot
.852 .30319 Mdot
.852 .30335 Mdot
.852 .30358 Mdot
.852 .30564 Mdot
.852 .30565 Mdot
.852 .30582 Mdot
.852 .30603 Mdot
.852 .30629 Mdot
.852 .30686 Mdot
.852 .30716 Mdot
.852 .30751 Mdot
.852 .30756 Mdot
.852 .30772 Mdot
.852 .30794 Mdot
.852 .30804 Mdot
.852 .30847 Mdot
.852 .30861 Mdot
.852 .30879 Mdot
.852 .30881 Mdot
.852 .30936 Mdot
.852 .30954 Mdot
.852 .30972 Mdot
.852 .30977 Mdot
.852 .31047 Mdot
.852 .31048 Mdot
.852 .31049 Mdot
.852 .31051 Mdot
.852 .31103 Mdot
.852 .31143 Mdot
.852 .3115 Mdot
.852 .31185 Mdot
.852 .31204 Mdot
.852 .31244 Mdot
.852 .31263 Mdot
.852 .31283 Mdot
.852 .31287 Mdot
.852 .31377 Mdot
.852 .31403 Mdot
.852 .31441 Mdot
.852 .3148 Mdot
.852 .31485 Mdot
.852 .31535 Mdot
.852 .3155 Mdot
.852 .31557 Mdot
.852 .3156 Mdot
.852 .31627 Mdot
.852 .31676 Mdot
.852 .31726 Mdot
.852 .31739 Mdot
.852 .31768 Mdot
.852 .31772 Mdot
.852 .31783 Mdot
.852 .31804 Mdot
.852 .31808 Mdot
.852 .31823 Mdot
.852 .3194 Mdot
.852 .3196 Mdot
.852 .32077 Mdot
.852 .32101 Mdot
.852 .32301 Mdot
.852 .32355 Mdot
.852 .32357 Mdot
.852 .3242 Mdot
.852 .32508 Mdot
.852 .32525 Mdot
.852 .32612 Mdot
.852 .32627 Mdot
.852 .32683 Mdot
.852 .32776 Mdot
.852 .3281 Mdot
.852 .32823 Mdot
.852 .32847 Mdot
.852 .32861 Mdot
.852 .32879 Mdot
.852 .32883 Mdot
.852 .32956 Mdot
.852 .32965 Mdot
.852 .32968 Mdot
.852 .32975 Mdot
.852 .33003 Mdot
.852 .33014 Mdot
.852 .3302 Mdot
.852 .33054 Mdot
.852 .33121 Mdot
.852 .33128 Mdot
.852 .33248 Mdot
.852 .33254 Mdot
.852 .33318 Mdot
.852 .33328 Mdot
.852 .33412 Mdot
.852 .33482 Mdot
.852 .33513 Mdot
.852 .3352 Mdot
.852 .33547 Mdot
.852 .33554 Mdot
.852 .33606 Mdot
.852 .3361 Mdot
.852 .33666 Mdot
.852 .3367 Mdot
.852 .3368 Mdot
.852 .33684 Mdot
.852 .33685 Mdot
.852 .33689 Mdot
.852 .33773 Mdot
.852 .33779 Mdot
.852 .33799 Mdot
.852 .33879 Mdot
.852 .33887 Mdot
.852 .33926 Mdot
.852 .33949 Mdot
.852 .33991 Mdot
.852 .34 Mdot
.852 .34067 Mdot
.852 .34174 Mdot
.852 .34201 Mdot
.852 .34233 Mdot
.852 .3425 Mdot
.852 .34261 Mdot
.852 .34261 Mdot
.852 .3427 Mdot
.852 .34426 Mdot
.852 .34435 Mdot
.852 .34449 Mdot
.852 .34506 Mdot
.852 .34519 Mdot
.852 .34596 Mdot
.852 .34643 Mdot
.852 .34707 Mdot
.852 .34714 Mdot
.852 .34829 Mdot
.852 .34837 Mdot
.852 .34887 Mdot
.852 .34903 Mdot
.852 .34945 Mdot
.852 .34949 Mdot
.852 .34951 Mdot
.852 .35026 Mdot
.852 .35059 Mdot
.852 .35072 Mdot
.852 .35115 Mdot
.852 .3516 Mdot
.852 .35166 Mdot
.852 .35216 Mdot
.852 .35294 Mdot
.852 .35302 Mdot
.852 .35326 Mdot
.852 .35393 Mdot
.852 .35609 Mdot
.852 .35649 Mdot
.852 .3566 Mdot
.852 .35677 Mdot
.852 .3568 Mdot
.852 .35722 Mdot
.852 .35763 Mdot
.852 .35794 Mdot
.852 .35871 Mdot
.852 .35907 Mdot
.852 .35917 Mdot
.852 .35929 Mdot
.852 .35948 Mdot
.852 .35974 Mdot
.852 .35993 Mdot
.852 .36031 Mdot
.852 .36067 Mdot
.852 .36085 Mdot
.852 .36106 Mdot
.852 .36113 Mdot
.852 .36181 Mdot
.852 .36269 Mdot
.852 .36279 Mdot
.852 .36293 Mdot
.852 .36346 Mdot
.852 .3654 Mdot
.852 .3657 Mdot
.852 .36576 Mdot
.852 .36638 Mdot
.852 .36651 Mdot
.852 .36664 Mdot
.852 .36695 Mdot
.852 .36711 Mdot
.852 .36723 Mdot
.852 .36745 Mdot
.852 .36789 Mdot
.852 .36883 Mdot
.852 .36892 Mdot
.852 .36895 Mdot
.852 .36913 Mdot
.852 .36933 Mdot
.852 .3694 Mdot
.852 .3697 Mdot
.852 .36972 Mdot
.852 .3701 Mdot
.852 .37023 Mdot
.852 .37031 Mdot
.852 .37045 Mdot
.852 .37072 Mdot
.852 .37108 Mdot
.852 .37129 Mdot
.852 .37134 Mdot
.852 .37138 Mdot
.852 .37203 Mdot
.852 .37223 Mdot
.852 .37294 Mdot
.852 .37336 Mdot
.852 .37354 Mdot
.852 .37359 Mdot
.852 .37375 Mdot
.852 .37413 Mdot
.852 .37418 Mdot
.852 .37467 Mdot
.852 .37505 Mdot
.852 .37528 Mdot
.852 .37616 Mdot
.852 .37833 Mdot
.852 .37856 Mdot
.852 .38044 Mdot
.852 .38072 Mdot
.852 .38097 Mdot
.852 .38126 Mdot
.852 .38128 Mdot
.852 .38158 Mdot
.852 .38197 Mdot
.852 .38211 Mdot
.852 .38263 Mdot
.852 .38369 Mdot
.852 .38441 Mdot
.852 .38494 Mdot
.852 .38876 Mdot
.852 .38907 Mdot
.852 .38915 Mdot
.852 .38956 Mdot
.852 .38989 Mdot
.852 .39005 Mdot
.852 .39129 Mdot
.852 .39256 Mdot
.852 .39308 Mdot
.852 .39398 Mdot
.852 .39407 Mdot
.852 .3942 Mdot
.852 .39445 Mdot
.852 .39487 Mdot
.852 .39539 Mdot
.852 .39542 Mdot
.852 .39554 Mdot
.852 .39576 Mdot
.852 .39591 Mdot
.852 .39604 Mdot
.852 .39612 Mdot
.852 .39634 Mdot
.852 .39657 Mdot
.852 .39679 Mdot
.852 .39681 Mdot
.852 .39741 Mdot
.852 .39867 Mdot
.852 .39888 Mdot
.852 .40002 Mdot
.852 .40041 Mdot
.852 .40143 Mdot
.852 .40155 Mdot
.852 .40165 Mdot
.852 .40186 Mdot
.852 .4022 Mdot
.852 .40235 Mdot
.852 .40253 Mdot
.852 .40259 Mdot
.852 .4028 Mdot
.852 .40392 Mdot
.852 .40394 Mdot
.852 .40404 Mdot
.852 .40411 Mdot
.852 .40561 Mdot
.852 .406 Mdot
.852 .40619 Mdot
.852 .40665 Mdot
.852 .40694 Mdot
.852 .40697 Mdot
.852 .40724 Mdot
.852 .40749 Mdot
.852 .40757 Mdot
.852 .40821 Mdot
.852 .40824 Mdot
.852 .40849 Mdot
.852 .40858 Mdot
.852 .40887 Mdot
.852 .40959 Mdot
.852 .41081 Mdot
.852 .41115 Mdot
.852 .41128 Mdot
.852 .4122 Mdot
.852 .41225 Mdot
.852 .41232 Mdot
.852 .41242 Mdot
.852 .4126 Mdot
.852 .41276 Mdot
.852 .41339 Mdot
.852 .41384 Mdot
.852 .41408 Mdot
.852 .41422 Mdot
.852 .41444 Mdot
.852 .41449 Mdot
.852 .41508 Mdot
.852 .41512 Mdot
.852 .41563 Mdot
.852 .41564 Mdot
.852 .41574 Mdot
.852 .41607 Mdot
.852 .4161 Mdot
.852 .4164 Mdot
.852 .41644 Mdot
.852 .4166 Mdot
.852 .41773 Mdot
.852 .41816 Mdot
.852 .4182 Mdot
.852 .41894 Mdot
.852 .41933 Mdot
.852 .41953 Mdot
.852 .41957 Mdot
.852 .41964 Mdot
.852 .4198 Mdot
.852 .41986 Mdot
.852 .41991 Mdot
.852 .42034 Mdot
.852 .42047 Mdot
.852 .42055 Mdot
.852 .42069 Mdot
.852 .42077 Mdot
.852 .42096 Mdot
.852 .42151 Mdot
.852 .42184 Mdot
.852 .42193 Mdot
.852 .42244 Mdot
.852 .42343 Mdot
.852 .42493 Mdot
.852 .42507 Mdot
.852 .42575 Mdot
.852 .42656 Mdot
.852 .42665 Mdot
.852 .4268 Mdot
.852 .42688 Mdot
.852 .42705 Mdot
.852 .42812 Mdot
.852 .42857 Mdot
.852 .4288 Mdot
.852 .42917 Mdot
.852 .4297 Mdot
.852 .42973 Mdot
.852 .42985 Mdot
.852 .43019 Mdot
.852 .4303 Mdot
.852 .43051 Mdot
.852 .43055 Mdot
.852 .43079 Mdot
.852 .43109 Mdot
.852 .4311 Mdot
.852 .43111 Mdot
.852 .43152 Mdot
.852 .43176 Mdot
.852 .4321 Mdot
.852 .43254 Mdot
.852 .43282 Mdot
.852 .43285 Mdot
.852 .43305 Mdot
.852 .43323 Mdot
.852 .43384 Mdot
.852 .43395 Mdot
.852 .43516 Mdot
.852 .43529 Mdot
.852 .43569 Mdot
.852 .43605 Mdot
.852 .43638 Mdot
.852 .4371 Mdot
.852 .43715 Mdot
.852 .43717 Mdot
.852 .43718 Mdot
.852 .43732 Mdot
.852 .43744 Mdot
.852 .43763 Mdot
.852 .43831 Mdot
.852 .43927 Mdot
.852 .4395 Mdot
.852 .43969 Mdot
.852 .43984 Mdot
.852 .44039 Mdot
.852 .44078 Mdot
.852 .44199 Mdot
.852 .44212 Mdot
.852 .44313 Mdot
.852 .44321 Mdot
.852 .44324 Mdot
.852 .44353 Mdot
.852 .44367 Mdot
.852 .44388 Mdot
.852 .44501 Mdot
.852 .44586 Mdot
.852 .44596 Mdot
.852 .44673 Mdot
.852 .44681 Mdot
.852 .44689 Mdot
.852 .44736 Mdot
.852 .44746 Mdot
.852 .44766 Mdot
.852 .44767 Mdot
.852 .44802 Mdot
.852 .44824 Mdot
.852 .44952 Mdot
.852 .44952 Mdot
.852 .44956 Mdot
.852 .44962 Mdot
.852 .44997 Mdot
.852 .45015 Mdot
.852 .45034 Mdot
.852 .45061 Mdot
.852 .45122 Mdot
.852 .45138 Mdot
.852 .45147 Mdot
.852 .4516 Mdot
.852 .4516 Mdot
.852 .45162 Mdot
.852 .45188 Mdot
.852 .45192 Mdot
.852 .45219 Mdot
.852 .45314 Mdot
.852 .45329 Mdot
.852 .45332 Mdot
.852 .45335 Mdot
.852 .45335 Mdot
.852 .45338 Mdot
.852 .45352 Mdot
.852 .45355 Mdot
.852 .45361 Mdot
.852 .45362 Mdot
.852 .45368 Mdot
.852 .45401 Mdot
.852 .45411 Mdot
.852 .45412 Mdot
.852 .45421 Mdot
.852 .45421 Mdot
.852 .45429 Mdot
.852 .45435 Mdot
.852 .45471 Mdot
.852 .45478 Mdot
.852 .45557 Mdot
.852 .45586 Mdot
.852 .45688 Mdot
.852 .4571 Mdot
.852 .45711 Mdot
.852 .45748 Mdot
.852 .45794 Mdot
.852 .45808 Mdot
.852 .45827 Mdot
.852 .45832 Mdot
.852 .45838 Mdot
.852 .45846 Mdot
.852 .45913 Mdot
.852 .45918 Mdot
.852 .45918 Mdot
.852 .45957 Mdot
.852 .45983 Mdot
.852 .4603 Mdot
.852 .46068 Mdot
.852 .46113 Mdot
.852 .46127 Mdot
.852 .46128 Mdot
.852 .46138 Mdot
.852 .46147 Mdot
.852 .46155 Mdot
.852 .46176 Mdot
.852 .46194 Mdot
.852 .46207 Mdot
.852 .4623 Mdot
.852 .46276 Mdot
.852 .46284 Mdot
.852 .46335 Mdot
.852 .4634 Mdot
.852 .46392 Mdot
.852 .46458 Mdot
.852 .46477 Mdot
.852 .46486 Mdot
.852 .46494 Mdot
.852 .46513 Mdot
.852 .46515 Mdot
.852 .46522 Mdot
.852 .46525 Mdot
.852 .46573 Mdot
.852 .46588 Mdot
.852 .46645 Mdot
.852 .4666 Mdot
.852 .467 Mdot
.852 .46765 Mdot
.852 .46778 Mdot
.852 .4681 Mdot
.852 .46894 Mdot
.852 .46915 Mdot
.852 .46949 Mdot
.852 .46958 Mdot
.852 .4696 Mdot
.852 .46986 Mdot
.852 .4706 Mdot
.852 .47063 Mdot
.852 .47064 Mdot
.852 .47102 Mdot
.852 .47109 Mdot
.852 .47111 Mdot
.852 .47118 Mdot
.852 .47123 Mdot
.852 .47135 Mdot
.852 .47142 Mdot
.852 .47145 Mdot
.852 .4715 Mdot
.852 .47237 Mdot
.852 .47245 Mdot
.852 .47288 Mdot
.852 .47309 Mdot
.852 .47317 Mdot
.852 .47332 Mdot
.852 .47335 Mdot
.852 .47345 Mdot
.852 .47352 Mdot
.852 .4739 Mdot
.852 .47403 Mdot
.852 .47455 Mdot
.852 .47547 Mdot
.852 .47558 Mdot
.852 .47575 Mdot
.852 .47586 Mdot
.852 .47717 Mdot
.852 .47735 Mdot
.852 .47761 Mdot
.852 .47833 Mdot
.852 .47844 Mdot
.852 .47854 Mdot
.852 .47937 Mdot
.852 .48058 Mdot
.852 .48071 Mdot
.852 .48088 Mdot
.852 .4809 Mdot
.852 .4811 Mdot
.852 .48162 Mdot
.852 .48184 Mdot
.852 .48221 Mdot
.852 .48242 Mdot
.852 .48253 Mdot
.852 .48262 Mdot
.852 .48272 Mdot
.852 .48319 Mdot
.852 .48327 Mdot
.852 .48331 Mdot
.852 .48337 Mdot
.852 .48348 Mdot
.852 .48352 Mdot
.852 .48356 Mdot
.852 .4838 Mdot
.852 .48475 Mdot
.852 .48483 Mdot
.852 .48514 Mdot
.852 .48537 Mdot
.852 .48579 Mdot
.852 .48601 Mdot
.852 .48647 Mdot
.852 .48658 Mdot
.852 .48672 Mdot
.852 .48711 Mdot
.852 .48816 Mdot
.852 .48912 Mdot
.852 .48937 Mdot
.852 .4898 Mdot
.852 .49022 Mdot
.852 .49044 Mdot
.852 .4906 Mdot
.852 .49086 Mdot
.852 .49115 Mdot
.852 .49175 Mdot
.852 .49265 Mdot
.852 .49334 Mdot
.852 .49372 Mdot
.852 .49375 Mdot
.852 .49379 Mdot
.852 .49433 Mdot
.852 .49443 Mdot
.852 .49468 Mdot
.852 .495 Mdot
.852 .49565 Mdot
.852 .49621 Mdot
.852 .49651 Mdot
.852 .49779 Mdot
.852 .49809 Mdot
.852 .49831 Mdot
.852 .4985 Mdot
.852 .49974 Mdot
.852 .50021 Mdot
.852 .50032 Mdot
.852 .50048 Mdot
.852 .50065 Mdot
.852 .50082 Mdot
.852 .50105 Mdot
.852 .50109 Mdot
.852 .50114 Mdot
.852 .50131 Mdot
.852 .50159 Mdot
.852 .50214 Mdot
.852 .50282 Mdot
.852 .50308 Mdot
.852 .50314 Mdot
.852 .50339 Mdot
.852 .50346 Mdot
.852 .50351 Mdot
.852 .50369 Mdot
.852 .50377 Mdot
.852 .50426 Mdot
.852 .50435 Mdot
.852 .50448 Mdot
.852 .50533 Mdot
.852 .5054 Mdot
.852 .5059 Mdot
.852 .50616 Mdot
.852 .50627 Mdot
.852 .50655 Mdot
.852 .50694 Mdot
.852 .5073 Mdot
.852 .50736 Mdot
.852 .50747 Mdot
.852 .50772 Mdot
.852 .50857 Mdot
.852 .50866 Mdot
.852 .50933 Mdot
.852 .50998 Mdot
.852 .51042 Mdot
.852 .51046 Mdot
.852 .51046 Mdot
.852 .51077 Mdot
.852 .51112 Mdot
.852 .51155 Mdot
.852 .51195 Mdot
.852 .51202 Mdot
.852 .51237 Mdot
.852 .51253 Mdot
.852 .51269 Mdot
.852 .51304 Mdot
.852 .51338 Mdot
.852 .51364 Mdot
.852 .5137 Mdot
.852 .51372 Mdot
.852 .514 Mdot
.852 .51429 Mdot
.852 .51437 Mdot
.852 .5144 Mdot
.852 .51454 Mdot
.852 .5151 Mdot
.852 .51527 Mdot
.852 .51552 Mdot
.852 .51582 Mdot
.852 .51585 Mdot
.852 .51597 Mdot
.852 .51602 Mdot
.852 .51602 Mdot
.852 .51604 Mdot
.852 .5168 Mdot
.852 .5171 Mdot
.852 .51723 Mdot
.852 .51733 Mdot
.854 .16207 Mdot
.854 .1626 Mdot
.854 .1633 Mdot
.854 .16396 Mdot
.854 .16404 Mdot
.854 .16427 Mdot
.854 .16521 Mdot
.854 .16585 Mdot
.854 .16593 Mdot
.854 .16702 Mdot
.854 .16707 Mdot
.854 .16741 Mdot
.854 .16811 Mdot
.854 .16834 Mdot
.854 .16886 Mdot
.854 .16911 Mdot
.854 .16937 Mdot
.854 .16992 Mdot
.854 .17001 Mdot
.854 .17166 Mdot
.854 .17214 Mdot
.854 .17265 Mdot
.854 .17384 Mdot
.854 .17425 Mdot
.854 .17595 Mdot
.854 .177 Mdot
.854 .17774 Mdot
.854 .17798 Mdot
.854 .17823 Mdot
.854 .17922 Mdot
.854 .17955 Mdot
.854 .18 Mdot
.854 .18023 Mdot
.854 .18081 Mdot
.854 .18122 Mdot
.854 .18142 Mdot
.854 .18206 Mdot
.854 .18259 Mdot
.854 .18268 Mdot
.854 .18326 Mdot
.854 .18349 Mdot
.854 .18361 Mdot
.854 .18378 Mdot
.854 .18413 Mdot
.854 .18545 Mdot
.854 .18591 Mdot
.854 .18674 Mdot
.854 .18823 Mdot
.854 .18854 Mdot
.854 .18883 Mdot
.854 .18888 Mdot
.854 .18949 Mdot
.854 .18959 Mdot
.854 .18991 Mdot
.854 .19061 Mdot
.854 .1916 Mdot
.854 .19172 Mdot
.854 .19272 Mdot
.854 .19284 Mdot
.854 .19299 Mdot
.854 .1932 Mdot
.854 .19449 Mdot
.854 .19479 Mdot
.854 .19684 Mdot
.854 .19708 Mdot
.854 .19767 Mdot
.854 .19768 Mdot
.854 .19768 Mdot
.854 .19853 Mdot
.854 .19881 Mdot
.854 .19882 Mdot
.854 .1993 Mdot
.854 .19943 Mdot
.854 .19972 Mdot
.854 .19986 Mdot
.854 .19993 Mdot
.854 .20019 Mdot
.854 .20103 Mdot
.854 .20137 Mdot
.854 .20179 Mdot
.854 .20209 Mdot
.854 .2027 Mdot
.854 .20385 Mdot
.854 .20548 Mdot
.854 .20763 Mdot
.854 .20795 Mdot
.854 .20874 Mdot
.854 .20886 Mdot
.854 .20921 Mdot
.854 .20997 Mdot
.854 .21009 Mdot
.854 .21016 Mdot
.854 .21071 Mdot
.854 .21135 Mdot
.854 .21156 Mdot
.854 .21226 Mdot
.854 .21249 Mdot
.854 .21259 Mdot
.854 .2129 Mdot
.854 .21293 Mdot
.854 .21298 Mdot
.854 .21377 Mdot
.854 .21384 Mdot
.854 .21448 Mdot
.854 .21469 Mdot
.854 .21485 Mdot
.854 .21494 Mdot
.854 .21674 Mdot
.854 .21711 Mdot
.854 .21715 Mdot
.854 .2172 Mdot
.854 .21725 Mdot
.854 .21807 Mdot
.854 .21859 Mdot
.854 .21861 Mdot
.854 .21863 Mdot
.854 .219 Mdot
.854 .21999 Mdot
.854 .2205 Mdot
.854 .22059 Mdot
.854 .22072 Mdot
.854 .221 Mdot
.854 .22169 Mdot
.854 .22172 Mdot
.854 .22241 Mdot
.854 .22251 Mdot
.854 .22255 Mdot
.854 .22277 Mdot
.854 .22313 Mdot
.854 .22321 Mdot
.854 .22348 Mdot
.854 .2238 Mdot
.854 .22415 Mdot
.854 .22421 Mdot
.854 .22473 Mdot
.854 .22544 Mdot
.854 .22689 Mdot
.854 .22737 Mdot
.854 .22746 Mdot
.854 .22864 Mdot
.854 .22866 Mdot
.854 .2287 Mdot
.854 .22874 Mdot
.854 .22884 Mdot
.854 .22911 Mdot
.854 .22951 Mdot
.854 .22966 Mdot
.854 .23134 Mdot
.854 .2321 Mdot
.854 .23228 Mdot
.854 .23243 Mdot
.854 .23345 Mdot
.854 .23367 Mdot
.854 .23377 Mdot
.854 .23492 Mdot
.854 .23543 Mdot
.854 .23547 Mdot
.854 .23797 Mdot
.854 .23798 Mdot
.854 .23894 Mdot
.854 .23902 Mdot
.854 .23937 Mdot
.854 .24009 Mdot
.854 .24013 Mdot
.854 .24038 Mdot
.854 .24055 Mdot
.854 .24115 Mdot
.854 .24185 Mdot
.854 .24234 Mdot
.854 .24264 Mdot
.854 .24364 Mdot
.854 .24368 Mdot
.854 .24373 Mdot
.854 .24408 Mdot
.854 .24433 Mdot
.854 .24537 Mdot
.854 .24594 Mdot
.854 .2466 Mdot
.854 .24861 Mdot
.854 .24905 Mdot
.854 .2494 Mdot
.854 .24961 Mdot
.854 .25036 Mdot
.854 .25073 Mdot
.854 .25177 Mdot
.854 .2518 Mdot
.854 .25211 Mdot
.854 .25212 Mdot
.854 .2525 Mdot
.854 .25277 Mdot
.854 .25309 Mdot
.854 .25327 Mdot
.854 .25432 Mdot
.854 .25454 Mdot
.854 .25459 Mdot
.854 .25467 Mdot
.854 .25663 Mdot
.854 .25673 Mdot
.854 .25693 Mdot
.854 .25805 Mdot
.854 .25827 Mdot
.854 .25872 Mdot
.854 .25926 Mdot
.854 .26156 Mdot
.854 .26251 Mdot
.854 .26265 Mdot
.854 .26322 Mdot
.854 .26322 Mdot
.854 .26346 Mdot
.854 .26366 Mdot
.854 .26414 Mdot
.854 .26443 Mdot
.854 .26524 Mdot
.854 .26546 Mdot
.854 .2664 Mdot
.854 .26731 Mdot
.854 .26745 Mdot
.854 .26807 Mdot
.854 .26851 Mdot
.854 .26863 Mdot
.854 .26868 Mdot
.854 .26889 Mdot
.854 .2693 Mdot
.854 .26962 Mdot
.854 .26962 Mdot
.854 .26975 Mdot
.854 .27015 Mdot
.854 .27034 Mdot
.854 .2704 Mdot
.854 .27176 Mdot
.854 .2725 Mdot
.854 .27275 Mdot
.854 .27286 Mdot
.854 .273 Mdot
.854 .27309 Mdot
.854 .27417 Mdot
.854 .27479 Mdot
.854 .27486 Mdot
.854 .27494 Mdot
.854 .27514 Mdot
.854 .27551 Mdot
.854 .27648 Mdot
.854 .27664 Mdot
.854 .27671 Mdot
.854 .2771 Mdot
.854 .2772 Mdot
.854 .27787 Mdot
.854 .27792 Mdot
.854 .27799 Mdot
.854 .27835 Mdot
.854 .27842 Mdot
.854 .27875 Mdot
.854 .27875 Mdot
.854 .27887 Mdot
.854 .27961 Mdot
.854 .27968 Mdot
.854 .2798 Mdot
.854 .27995 Mdot
.854 .28087 Mdot
.854 .28106 Mdot
.854 .2815 Mdot
.854 .28162 Mdot
.854 .282 Mdot
.854 .2821 Mdot
.854 .28277 Mdot
.854 .28312 Mdot
.854 .28326 Mdot
.854 .28359 Mdot
.854 .28447 Mdot
.854 .28507 Mdot
.854 .28549 Mdot
.854 .28561 Mdot
.854 .2865 Mdot
.854 .28673 Mdot
.854 .28678 Mdot
.854 .2872 Mdot
.854 .28723 Mdot
.854 .28814 Mdot
.854 .28881 Mdot
.854 .28888 Mdot
.854 .28893 Mdot
.854 .28917 Mdot
.854 .2901 Mdot
.854 .29088 Mdot
.854 .29152 Mdot
.854 .29187 Mdot
.854 .29189 Mdot
.854 .29233 Mdot
.854 .29265 Mdot
.854 .29313 Mdot
.854 .29315 Mdot
.854 .29346 Mdot
.854 .29357 Mdot
.854 .29389 Mdot
.854 .294 Mdot
.854 .29474 Mdot
.854 .29569 Mdot
.854 .29614 Mdot
.854 .29626 Mdot
.854 .29664 Mdot
.854 .29671 Mdot
.854 .29702 Mdot
.854 .29741 Mdot
.854 .29741 Mdot
.854 .29741 Mdot
.854 .2977 Mdot
.854 .2984 Mdot
.854 .2985 Mdot
.854 .29895 Mdot
.854 .29907 Mdot
.854 .29911 Mdot
.854 .29945 Mdot
.854 .29949 Mdot
.854 .30007 Mdot
.854 .30054 Mdot
.854 .30116 Mdot
.854 .30144 Mdot
.854 .3016 Mdot
.854 .30227 Mdot
.854 .30258 Mdot
.854 .30298 Mdot
.854 .30319 Mdot
.854 .30347 Mdot
.854 .30374 Mdot
.854 .30408 Mdot
.854 .30416 Mdot
.854 .30633 Mdot
.854 .30711 Mdot
.854 .30747 Mdot
.854 .3079 Mdot
.854 .30792 Mdot
.854 .30854 Mdot
.854 .30897 Mdot
.854 .30978 Mdot
.854 .30996 Mdot
.854 .3102 Mdot
.854 .31045 Mdot
.854 .31053 Mdot
.854 .31107 Mdot
.854 .3111 Mdot
.854 .31161 Mdot
.854 .31185 Mdot
.854 .31211 Mdot
.854 .31219 Mdot
.854 .31247 Mdot
.854 .3125 Mdot
.854 .31323 Mdot
.854 .3134 Mdot
.854 .31381 Mdot
.854 .31395 Mdot
.854 .31453 Mdot
.854 .31489 Mdot
.854 .31515 Mdot
.854 .31577 Mdot
.854 .316 Mdot
.854 .31634 Mdot
.854 .31663 Mdot
.854 .31684 Mdot
.854 .31704 Mdot
.854 .31716 Mdot
.854 .31722 Mdot
.854 .31734 Mdot
.854 .31874 Mdot
.854 .31895 Mdot
.854 .31897 Mdot
.854 .31918 Mdot
.854 .31921 Mdot
.854 .31956 Mdot
.854 .32038 Mdot
.854 .32178 Mdot
.854 .32228 Mdot
.854 .32237 Mdot
.854 .32254 Mdot
.854 .32259 Mdot
.854 .32273 Mdot
.854 .32284 Mdot
.854 .32339 Mdot
.854 .3235 Mdot
.854 .3241 Mdot
.854 .32578 Mdot
.854 .3262 Mdot
.854 .32645 Mdot
.854 .32667 Mdot
.854 .32698 Mdot
.854 .32709 Mdot
.854 .3272 Mdot
.854 .32721 Mdot
.854 .32723 Mdot
.854 .32774 Mdot
.854 .32781 Mdot
.854 .3279 Mdot
.854 .32865 Mdot
.854 .32866 Mdot
.854 .32867 Mdot
.854 .32869 Mdot
.854 .32897 Mdot
.854 .32915 Mdot
.854 .32916 Mdot
.854 .32917 Mdot
.854 .32963 Mdot
.854 .32981 Mdot
.854 .32984 Mdot
.854 .32988 Mdot
.854 .32998 Mdot
.854 .33022 Mdot
.854 .3305 Mdot
.854 .33071 Mdot
.854 .33074 Mdot
.854 .33083 Mdot
.854 .33094 Mdot
.854 .33106 Mdot
.854 .33108 Mdot
.854 .3315 Mdot
.854 .332 Mdot
.854 .3326 Mdot
.854 .3326 Mdot
.854 .33263 Mdot
.854 .33276 Mdot
.854 .33295 Mdot
.854 .33352 Mdot
.854 .33384 Mdot
.854 .33425 Mdot
.854 .33436 Mdot
.854 .33475 Mdot
.854 .33494 Mdot
.854 .3358 Mdot
.854 .33615 Mdot
.854 .33652 Mdot
.854 .33653 Mdot
.854 .33668 Mdot
.854 .33689 Mdot
.854 .33712 Mdot
.854 .33774 Mdot
.854 .33775 Mdot
.854 .33798 Mdot
.854 .33875 Mdot
.854 .34004 Mdot
.854 .34017 Mdot
.854 .34054 Mdot
.854 .34078 Mdot
.854 .34087 Mdot
.854 .34149 Mdot
.854 .34223 Mdot
.854 .34309 Mdot
.854 .34421 Mdot
.854 .34445 Mdot
.854 .34477 Mdot
.854 .34487 Mdot
.854 .34514 Mdot
.854 .3459 Mdot
.854 .34611 Mdot
.854 .34632 Mdot
.854 .34691 Mdot
.854 .34772 Mdot
.854 .34783 Mdot
.854 .34821 Mdot
.854 .34842 Mdot
.854 .34854 Mdot
.854 .34947 Mdot
.854 .34949 Mdot
.854 .35007 Mdot
.854 .35057 Mdot
.854 .35092 Mdot
.854 .35127 Mdot
.854 .35213 Mdot
.854 .35251 Mdot
.854 .35253 Mdot
.854 .35268 Mdot
.854 .35322 Mdot
.854 .35325 Mdot
.854 .35326 Mdot
.854 .35334 Mdot
.854 .35427 Mdot
.854 .35443 Mdot
.854 .35454 Mdot
.854 .3547 Mdot
.854 .35482 Mdot
.854 .35591 Mdot
.854 .35627 Mdot
.854 .35654 Mdot
.854 .3567 Mdot
.854 .35708 Mdot
.854 .35746 Mdot
.854 .35834 Mdot
.854 .35848 Mdot
.854 .35962 Mdot
.854 .35977 Mdot
.854 .35977 Mdot
.854 .36041 Mdot
.854 .36047 Mdot
.854 .36056 Mdot
.854 .36064 Mdot
.854 .36086 Mdot
.854 .36133 Mdot
.854 .36179 Mdot
.854 .36204 Mdot
.854 .36216 Mdot
.854 .36254 Mdot
.854 .36294 Mdot
.854 .36296 Mdot
.854 .363 Mdot
.854 .36356 Mdot
.854 .36363 Mdot
.854 .36404 Mdot
.854 .36478 Mdot
.854 .36489 Mdot
.854 .36511 Mdot
.854 .36532 Mdot
.854 .3662 Mdot
.854 .36635 Mdot
.854 .36657 Mdot
.854 .36688 Mdot
.854 .36688 Mdot
.854 .36699 Mdot
.854 .36705 Mdot
.854 .36722 Mdot
.854 .3673 Mdot
.854 .36751 Mdot
.854 .36771 Mdot
.854 .36803 Mdot
.854 .36823 Mdot
.854 .36823 Mdot
.854 .36824 Mdot
.854 .36829 Mdot
.854 .36884 Mdot
.854 .36945 Mdot
.854 .36958 Mdot
.854 .36958 Mdot
.854 .36963 Mdot
.854 .3697 Mdot
.854 .37008 Mdot
.854 .37069 Mdot
.854 .37083 Mdot
.854 .37104 Mdot
.854 .37107 Mdot
.854 .37128 Mdot
.854 .37153 Mdot
.854 .37183 Mdot
.854 .3723 Mdot
.854 .37244 Mdot
.854 .37253 Mdot
.854 .37342 Mdot
.854 .37422 Mdot
.854 .37463 Mdot
.854 .37663 Mdot
.854 .37711 Mdot
.854 .37749 Mdot
.854 .37792 Mdot
.854 .37808 Mdot
.854 .37837 Mdot
.854 .3785 Mdot
.854 .37938 Mdot
.854 .37998 Mdot
.854 .37998 Mdot
.854 .3801 Mdot
.854 .38013 Mdot
.854 .3802 Mdot
.854 .38027 Mdot
.854 .38045 Mdot
.854 .38065 Mdot
.854 .38091 Mdot
.854 .38091 Mdot
.854 .38158 Mdot
.854 .38184 Mdot
.854 .3825 Mdot
.854 .38332 Mdot
.854 .38362 Mdot
.854 .38427 Mdot
.854 .38448 Mdot
.854 .38471 Mdot
.854 .38479 Mdot
.854 .38534 Mdot
.854 .38602 Mdot
.854 .38612 Mdot
.854 .38631 Mdot
.854 .38658 Mdot
.854 .38723 Mdot
.854 .38769 Mdot
.854 .388 Mdot
.854 .38819 Mdot
.854 .38831 Mdot
.854 .38869 Mdot
.854 .38886 Mdot
.854 .38935 Mdot
.854 .39028 Mdot
.854 .39043 Mdot
.854 .39082 Mdot
.854 .39082 Mdot
.854 .39117 Mdot
.854 .39169 Mdot
.854 .39177 Mdot
.854 .39228 Mdot
.854 .39279 Mdot
.854 .39419 Mdot
.854 .39532 Mdot
.854 .39577 Mdot
.854 .39604 Mdot
.854 .39606 Mdot
.854 .39691 Mdot
.854 .39691 Mdot
.854 .39735 Mdot
.854 .39769 Mdot
.854 .3977 Mdot
.854 .39782 Mdot
.854 .39801 Mdot
.854 .39812 Mdot
.854 .39825 Mdot
.854 .3983 Mdot
.854 .39843 Mdot
.854 .39849 Mdot
.854 .39849 Mdot
.854 .39953 Mdot
.854 .39966 Mdot
.854 .39972 Mdot
.854 .40015 Mdot
.854 .40044 Mdot
.854 .40103 Mdot
.854 .40125 Mdot
.854 .40147 Mdot
.854 .40174 Mdot
.854 .40201 Mdot
.854 .40265 Mdot
.854 .40274 Mdot
.854 .40341 Mdot
.854 .40349 Mdot
.854 .40401 Mdot
.854 .40423 Mdot
.854 .40572 Mdot
.854 .40578 Mdot
.854 .40587 Mdot
.854 .40647 Mdot
.854 .4069 Mdot
.854 .40763 Mdot
.854 .40834 Mdot
.854 .40867 Mdot
.854 .40964 Mdot
.854 .40971 Mdot
.854 .41077 Mdot
.854 .41122 Mdot
.854 .41138 Mdot
.854 .41162 Mdot
.854 .41242 Mdot
.854 .41293 Mdot
.854 .41336 Mdot
.854 .41372 Mdot
.854 .41378 Mdot
.854 .41413 Mdot
.854 .41421 Mdot
.854 .41437 Mdot
.854 .41496 Mdot
.854 .41542 Mdot
.854 .41555 Mdot
.854 .41591 Mdot
.854 .41605 Mdot
.854 .41617 Mdot
.854 .41626 Mdot
.854 .41627 Mdot
.854 .41648 Mdot
.854 .41719 Mdot
.854 .41753 Mdot
.854 .41783 Mdot
.854 .41847 Mdot
.854 .41854 Mdot
.854 .41856 Mdot
.854 .41856 Mdot
.854 .41892 Mdot
.854 .41945 Mdot
.854 .4196 Mdot
.854 .41965 Mdot
.854 .41979 Mdot
.854 .42015 Mdot
.854 .42018 Mdot
.854 .4202 Mdot
.854 .4203 Mdot
.854 .42058 Mdot
.854 .42069 Mdot
.854 .42085 Mdot
.854 .42087 Mdot
.854 .42088 Mdot
.854 .42131 Mdot
.854 .42141 Mdot
.854 .42179 Mdot
.854 .42185 Mdot
.854 .42203 Mdot
.854 .42216 Mdot
.854 .42354 Mdot
.854 .42389 Mdot
.854 .42395 Mdot
.854 .42427 Mdot
.854 .42434 Mdot
.854 .42443 Mdot
.854 .42445 Mdot
.854 .42455 Mdot
.854 .42572 Mdot
.854 .42642 Mdot
.854 .42654 Mdot
.854 .4275 Mdot
.854 .42757 Mdot
.854 .4276 Mdot
.854 .42791 Mdot
.854 .42808 Mdot
.854 .42828 Mdot
.854 .42842 Mdot
.854 .42893 Mdot
.854 .42914 Mdot
.854 .42956 Mdot
.854 .43033 Mdot
.854 .43035 Mdot
.854 .43071 Mdot
.854 .43115 Mdot
.854 .43148 Mdot
.854 .43153 Mdot
.854 .43168 Mdot
.854 .43182 Mdot
.854 .43192 Mdot
.854 .4324 Mdot
.854 .43301 Mdot
.854 .43302 Mdot
.854 .43328 Mdot
.854 .43521 Mdot
.854 .43546 Mdot
.854 .43632 Mdot
.854 .43697 Mdot
.854 .43761 Mdot
.854 .43795 Mdot
.854 .43819 Mdot
.854 .43827 Mdot
.854 .43853 Mdot
.854 .439 Mdot
.854 .43916 Mdot
.854 .43917 Mdot
.854 .43958 Mdot
.854 .43962 Mdot
.854 .43991 Mdot
.854 .44073 Mdot
.854 .44123 Mdot
.854 .44148 Mdot
.854 .44167 Mdot
.854 .44195 Mdot
.854 .44214 Mdot
.854 .44241 Mdot
.854 .44261 Mdot
.854 .44299 Mdot
.854 .44399 Mdot
.854 .44413 Mdot
.854 .44416 Mdot
.854 .4442 Mdot
.854 .44459 Mdot
.854 .44512 Mdot
.854 .44539 Mdot
.854 .44542 Mdot
.854 .44608 Mdot
.854 .44614 Mdot
.854 .44639 Mdot
.854 .44745 Mdot
.854 .44753 Mdot
.854 .44813 Mdot
.854 .44819 Mdot
.854 .44841 Mdot
.854 .44848 Mdot
.854 .44874 Mdot
.854 .44885 Mdot
.854 .44955 Mdot
.854 .44959 Mdot
.854 .45009 Mdot
.854 .45009 Mdot
.854 .45032 Mdot
.854 .45058 Mdot
.854 .4506 Mdot
.854 .451 Mdot
.854 .45133 Mdot
.854 .45142 Mdot
.854 .45221 Mdot
.854 .45241 Mdot
.854 .45277 Mdot
.854 .45341 Mdot
.854 .4536 Mdot
.854 .45375 Mdot
.854 .45498 Mdot
.854 .45501 Mdot
.854 .45544 Mdot
.854 .45562 Mdot
.854 .45586 Mdot
.854 .45599 Mdot
.854 .45601 Mdot
.854 .45634 Mdot
.854 .45671 Mdot
.854 .45787 Mdot
.854 .458 Mdot
.854 .45847 Mdot
.854 .45865 Mdot
.854 .45893 Mdot
.854 .45904 Mdot
.854 .45918 Mdot
.854 .45918 Mdot
.854 .45951 Mdot
.854 .4596 Mdot
.854 .46016 Mdot
.854 .4615 Mdot
.854 .46182 Mdot
.854 .46208 Mdot
.854 .46221 Mdot
.854 .46287 Mdot
.854 .46298 Mdot
.854 .46304 Mdot
.854 .46419 Mdot
.854 .46423 Mdot
.854 .46426 Mdot
.854 .4644 Mdot
.854 .46501 Mdot
.854 .46512 Mdot
.854 .4653 Mdot
.854 .46546 Mdot
.854 .46568 Mdot
.854 .46569 Mdot
.854 .46587 Mdot
.854 .46589 Mdot
.854 .46649 Mdot
.854 .46671 Mdot
.854 .46715 Mdot
.854 .46728 Mdot
.854 .46748 Mdot
.854 .46774 Mdot
.854 .46891 Mdot
.854 .4693 Mdot
.854 .46963 Mdot
.854 .47024 Mdot
.854 .47039 Mdot
.854 .47059 Mdot
.854 .47063 Mdot
.854 .47065 Mdot
.854 .47123 Mdot
.854 .47141 Mdot
.854 .4717 Mdot
.854 .4721 Mdot
.854 .47246 Mdot
.854 .47255 Mdot
.854 .4727 Mdot
.854 .47272 Mdot
.854 .47315 Mdot
.854 .47335 Mdot
.854 .4734 Mdot
.854 .47396 Mdot
.854 .47396 Mdot
.854 .47543 Mdot
.854 .47546 Mdot
.854 .47575 Mdot
.854 .47642 Mdot
.854 .47648 Mdot
.854 .47661 Mdot
.854 .47721 Mdot
.854 .4773 Mdot
.854 .4774 Mdot
.854 .47785 Mdot
.854 .47883 Mdot
.854 .47892 Mdot
.854 .47915 Mdot
.854 .47931 Mdot
.854 .47937 Mdot
.854 .47939 Mdot
.854 .47942 Mdot
.854 .47943 Mdot
.854 .48012 Mdot
.854 .48018 Mdot
.854 .48045 Mdot
.854 .4813 Mdot
.854 .48172 Mdot
.854 .48202 Mdot
.854 .48206 Mdot
.854 .48226 Mdot
.854 .48245 Mdot
.854 .48261 Mdot
.854 .48265 Mdot
.854 .48286 Mdot
.854 .48299 Mdot
.854 .48302 Mdot
.854 .48308 Mdot
.854 .48348 Mdot
.854 .4835 Mdot
.854 .4839 Mdot
.854 .48407 Mdot
.854 .48414 Mdot
.854 .48419 Mdot
.854 .4845 Mdot
.854 .48507 Mdot
.854 .48529 Mdot
.854 .4853 Mdot
.854 .48531 Mdot
.854 .48562 Mdot
.854 .4861 Mdot
.854 .48613 Mdot
.854 .48616 Mdot
.854 .48618 Mdot
.854 .4864 Mdot
.854 .48745 Mdot
.854 .4875 Mdot
.854 .4876 Mdot
.854 .48772 Mdot
.854 .4881 Mdot
.854 .48813 Mdot
.854 .4886 Mdot
.854 .48863 Mdot
.854 .48864 Mdot
.854 .48883 Mdot
.854 .48889 Mdot
.854 .48902 Mdot
.854 .48943 Mdot
.854 .48955 Mdot
.854 .48993 Mdot
.854 .49025 Mdot
.854 .49029 Mdot
.854 .49036 Mdot
.854 .49081 Mdot
.854 .49101 Mdot
.854 .49108 Mdot
.854 .49154 Mdot
.854 .49173 Mdot
.854 .49299 Mdot
.854 .49395 Mdot
.854 .49462 Mdot
.854 .49497 Mdot
.854 .49515 Mdot
.854 .4954 Mdot
.854 .49559 Mdot
.854 .49609 Mdot
.854 .49624 Mdot
.854 .49628 Mdot
.854 .49636 Mdot
.854 .49653 Mdot
.854 .49661 Mdot
.854 .49689 Mdot
.854 .49689 Mdot
.854 .49706 Mdot
.854 .49755 Mdot
.854 .49756 Mdot
.854 .49756 Mdot
.854 .49791 Mdot
.854 .49805 Mdot
.854 .49925 Mdot
.854 .49942 Mdot
.854 .50018 Mdot
.854 .5003 Mdot
.854 .50039 Mdot
.854 .50046 Mdot
.854 .50104 Mdot
.854 .50111 Mdot
.854 .50169 Mdot
.854 .5021 Mdot
.854 .50229 Mdot
.854 .50235 Mdot
.854 .50271 Mdot
.854 .50274 Mdot
.854 .50291 Mdot
.854 .50309 Mdot
.854 .50396 Mdot
.854 .50445 Mdot
.854 .50472 Mdot
.854 .50549 Mdot
.854 .5057 Mdot
.854 .50579 Mdot
.854 .50586 Mdot
.854 .506 Mdot
.854 .50634 Mdot
.854 .50639 Mdot
.854 .5067 Mdot
.854 .50707 Mdot
.854 .50719 Mdot
.854 .50743 Mdot
.854 .50777 Mdot
.854 .50791 Mdot
.854 .50817 Mdot
.854 .50836 Mdot
.854 .50894 Mdot
.854 .50909 Mdot
.854 .50923 Mdot
.854 .50966 Mdot
.854 .51028 Mdot
.854 .51127 Mdot
.854 .51151 Mdot
.854 .51221 Mdot
.854 .51251 Mdot
.854 .51279 Mdot
.854 .51376 Mdot
.854 .51381 Mdot
.854 .51413 Mdot
.854 .51428 Mdot
.854 .51443 Mdot
.854 .51474 Mdot
.854 .51487 Mdot
.854 .51528 Mdot
.854 .51548 Mdot
.854 .5155 Mdot
.854 .51614 Mdot
.854 .51619 Mdot
.854 .51657 Mdot
.854 .51712 Mdot
.854 .51725 Mdot
.854 .5173 Mdot
.854 .51768 Mdot
.854 .51809 Mdot
.854 .5184 Mdot
.856 .16027 Mdot
.856 .16032 Mdot
.856 .16122 Mdot
.856 .16136 Mdot
.856 .16161 Mdot
.856 .16271 Mdot
.856 .16315 Mdot
.856 .16408 Mdot
.856 .16432 Mdot
.856 .16449 Mdot
.856 .16485 Mdot
.856 .16536 Mdot
.856 .16552 Mdot
.856 .16672 Mdot
.856 .16764 Mdot
.856 .16778 Mdot
.856 .16902 Mdot
.856 .16935 Mdot
.856 .16943 Mdot
.856 .17087 Mdot
.856 .17121 Mdot
.856 .17121 Mdot
.856 .17142 Mdot
.856 .17178 Mdot
.856 .17191 Mdot
.856 .17332 Mdot
.856 .17406 Mdot
.856 .17431 Mdot
.856 .17478 Mdot
.856 .17565 Mdot
.856 .17706 Mdot
.856 .17919 Mdot
.856 .17959 Mdot
.856 .17974 Mdot
.856 .18049 Mdot
.856 .1805 Mdot
.856 .18059 Mdot
.856 .18248 Mdot
.856 .18295 Mdot
.856 .18488 Mdot
.856 .1855 Mdot
.856 .18619 Mdot
.856 .18723 Mdot
.856 .18731 Mdot
.856 .18885 Mdot
.856 .18887 Mdot
.856 .18922 Mdot
.856 .18936 Mdot
.856 .18964 Mdot
.856 .19092 Mdot
.856 .19194 Mdot
.856 .19243 Mdot
.856 .19274 Mdot
.856 .19284 Mdot
.856 .19289 Mdot
.856 .19315 Mdot
.856 .19376 Mdot
.856 .19398 Mdot
.856 .19451 Mdot
.856 .1951 Mdot
.856 .19623 Mdot
.856 .19655 Mdot
.856 .19668 Mdot
.856 .19741 Mdot
.856 .19775 Mdot
.856 .19944 Mdot
.856 .19955 Mdot
.856 .19962 Mdot
.856 .2007 Mdot
.856 .20128 Mdot
.856 .20214 Mdot
.856 .20263 Mdot
.856 .20292 Mdot
.856 .20307 Mdot
.856 .20435 Mdot
.856 .2045 Mdot
.856 .20485 Mdot
.856 .20504 Mdot
.856 .20525 Mdot
.856 .20527 Mdot
.856 .20546 Mdot
.856 .20581 Mdot
.856 .20587 Mdot
.856 .20639 Mdot
.856 .20728 Mdot
.856 .20801 Mdot
.856 .20863 Mdot
.856 .20866 Mdot
.856 .20928 Mdot
.856 .21012 Mdot
.856 .21095 Mdot
.856 .21142 Mdot
.856 .21142 Mdot
.856 .21144 Mdot
.856 .21148 Mdot
.856 .21229 Mdot
.856 .21273 Mdot
.856 .21381 Mdot
.856 .21391 Mdot
.856 .21402 Mdot
.856 .2165 Mdot
.856 .21681 Mdot
.856 .21717 Mdot
.856 .21776 Mdot
.856 .21859 Mdot
.856 .21903 Mdot
.856 .2195 Mdot
.856 .22027 Mdot
.856 .22065 Mdot
.856 .22115 Mdot
.856 .22156 Mdot
.856 .22196 Mdot
.856 .22243 Mdot
.856 .2225 Mdot
.856 .22303 Mdot
.856 .22341 Mdot
.856 .22379 Mdot
.856 .22392 Mdot
.856 .22483 Mdot
.856 .22503 Mdot
.856 .22518 Mdot
.856 .22565 Mdot
.856 .22672 Mdot
.856 .2288 Mdot
.856 .22886 Mdot
.856 .22929 Mdot
.856 .22939 Mdot
.856 .2299 Mdot
.856 .23063 Mdot
.856 .23082 Mdot
.856 .23123 Mdot
.856 .23175 Mdot
.856 .23216 Mdot
.856 .23262 Mdot
.856 .23332 Mdot
.856 .23572 Mdot
.856 .23597 Mdot
.856 .23606 Mdot
.856 .23663 Mdot
.856 .2375 Mdot
.856 .23801 Mdot
.856 .23841 Mdot
.856 .23845 Mdot
.856 .23852 Mdot
.856 .23867 Mdot
.856 .23923 Mdot
.856 .23947 Mdot
.856 .23948 Mdot
.856 .23951 Mdot
.856 .23958 Mdot
.856 .23996 Mdot
.856 .24065 Mdot
.856 .24069 Mdot
.856 .24097 Mdot
.856 .24106 Mdot
.856 .24117 Mdot
.856 .24227 Mdot
.856 .2427 Mdot
.856 .24372 Mdot
.856 .24434 Mdot
.856 .24461 Mdot
.856 .24497 Mdot
.856 .24542 Mdot
.856 .24568 Mdot
.856 .24623 Mdot
.856 .24648 Mdot
.856 .24695 Mdot
.856 .24715 Mdot
.856 .24722 Mdot
.856 .24747 Mdot
.856 .24779 Mdot
.856 .24786 Mdot
.856 .24839 Mdot
.856 .24847 Mdot
.856 .2488 Mdot
.856 .24966 Mdot
.856 .25047 Mdot
.856 .25062 Mdot
.856 .25143 Mdot
.856 .25163 Mdot
.856 .25177 Mdot
.856 .25271 Mdot
.856 .25296 Mdot
.856 .25303 Mdot
.856 .25347 Mdot
.856 .25368 Mdot
.856 .25379 Mdot
.856 .25444 Mdot
.856 .25476 Mdot
.856 .25498 Mdot
.856 .25631 Mdot
.856 .25641 Mdot
.856 .25671 Mdot
.856 .25703 Mdot
.856 .25736 Mdot
.856 .25739 Mdot
.856 .25764 Mdot
.856 .25854 Mdot
.856 .25866 Mdot
.856 .25918 Mdot
.856 .25944 Mdot
.856 .26089 Mdot
.856 .26104 Mdot
.856 .26183 Mdot
.856 .26202 Mdot
.856 .26267 Mdot
.856 .2639 Mdot
.856 .26392 Mdot
.856 .264 Mdot
.856 .26464 Mdot
.856 .26464 Mdot
.856 .2648 Mdot
.856 .26492 Mdot
.856 .26548 Mdot
.856 .26553 Mdot
.856 .26578 Mdot
.856 .2662 Mdot
.856 .26623 Mdot
.856 .26711 Mdot
.856 .26719 Mdot
.856 .26805 Mdot
.856 .26808 Mdot
.856 .2686 Mdot
.856 .26869 Mdot
.856 .26878 Mdot
.856 .26881 Mdot
.856 .26884 Mdot
.856 .26958 Mdot
.856 .27042 Mdot
.856 .27084 Mdot
.856 .27102 Mdot
.856 .27114 Mdot
.856 .27131 Mdot
.856 .27141 Mdot
.856 .27174 Mdot
.856 .27177 Mdot
.856 .27187 Mdot
.856 .27236 Mdot
.856 .27263 Mdot
.856 .27266 Mdot
.856 .27289 Mdot
.856 .27318 Mdot
.856 .27351 Mdot
.856 .274 Mdot
.856 .27405 Mdot
.856 .27494 Mdot
.856 .27528 Mdot
.856 .27609 Mdot
.856 .27652 Mdot
.856 .27675 Mdot
.856 .27689 Mdot
.856 .27775 Mdot
.856 .27786 Mdot
.856 .27803 Mdot
.856 .27888 Mdot
.856 .27945 Mdot
.856 .27959 Mdot
.856 .27991 Mdot
.856 .27999 Mdot
.856 .28008 Mdot
.856 .28024 Mdot
.856 .28033 Mdot
.856 .2806 Mdot
.856 .28088 Mdot
.856 .28097 Mdot
.856 .28206 Mdot
.856 .28212 Mdot
.856 .28223 Mdot
.856 .2826 Mdot
.856 .28262 Mdot
.856 .28263 Mdot
.856 .28264 Mdot
.856 .28272 Mdot
.856 .28291 Mdot
.856 .283 Mdot
.856 .28314 Mdot
.856 .28331 Mdot
.856 .2836 Mdot
.856 .28383 Mdot
.856 .28473 Mdot
.856 .28497 Mdot
.856 .28559 Mdot
.856 .28625 Mdot
.856 .28699 Mdot
.856 .28751 Mdot
.856 .28756 Mdot
.856 .28763 Mdot
.856 .28794 Mdot
.856 .28861 Mdot
.856 .28875 Mdot
.856 .28889 Mdot
.856 .28919 Mdot
.856 .28961 Mdot
.856 .28976 Mdot
.856 .29004 Mdot
.856 .29024 Mdot
.856 .29037 Mdot
.856 .29136 Mdot
.856 .29139 Mdot
.856 .29176 Mdot
.856 .29221 Mdot
.856 .29221 Mdot
.856 .29265 Mdot
.856 .29362 Mdot
.856 .2941 Mdot
.856 .29431 Mdot
.856 .29438 Mdot
.856 .29462 Mdot
.856 .29511 Mdot
.856 .29566 Mdot
.856 .29629 Mdot
.856 .29699 Mdot
.856 .29724 Mdot
.856 .29739 Mdot
.856 .29798 Mdot
.856 .29853 Mdot
.856 .29855 Mdot
.856 .29869 Mdot
.856 .29978 Mdot
.856 .29991 Mdot
.856 .30046 Mdot
.856 .30105 Mdot
.856 .30192 Mdot
.856 .30273 Mdot
.856 .30275 Mdot
.856 .3032 Mdot
.856 .30573 Mdot
.856 .30604 Mdot
.856 .3071 Mdot
.856 .30746 Mdot
.856 .3081 Mdot
.856 .30822 Mdot
.856 .30828 Mdot
.856 .30836 Mdot
.856 .30867 Mdot
.856 .30966 Mdot
.856 .30975 Mdot
.856 .31006 Mdot
.856 .31011 Mdot
.856 .31019 Mdot
.856 .31057 Mdot
.856 .31147 Mdot
.856 .31152 Mdot
.856 .31225 Mdot
.856 .31272 Mdot
.856 .31283 Mdot
.856 .31286 Mdot
.856 .31347 Mdot
.856 .31347 Mdot
.856 .31354 Mdot
.856 .31371 Mdot
.856 .31419 Mdot
.856 .31444 Mdot
.856 .31452 Mdot
.856 .31469 Mdot
.856 .31498 Mdot
.856 .31546 Mdot
.856 .31633 Mdot
.856 .31638 Mdot
.856 .31663 Mdot
.856 .31731 Mdot
.856 .31813 Mdot
.856 .31858 Mdot
.856 .31896 Mdot
.856 .31949 Mdot
.856 .31966 Mdot
.856 .31976 Mdot
.856 .32019 Mdot
.856 .32054 Mdot
.856 .32081 Mdot
.856 .32095 Mdot
.856 .32116 Mdot
.856 .32124 Mdot
.856 .32162 Mdot
.856 .32211 Mdot
.856 .32252 Mdot
.856 .32314 Mdot
.856 .32316 Mdot
.856 .32353 Mdot
.856 .32402 Mdot
.856 .32419 Mdot
.856 .32434 Mdot
.856 .32482 Mdot
.856 .32495 Mdot
.856 .32509 Mdot
.856 .32515 Mdot
.856 .32527 Mdot
.856 .32547 Mdot
.856 .32602 Mdot
.856 .32623 Mdot
.856 .32625 Mdot
.856 .32646 Mdot
.856 .32703 Mdot
.856 .32719 Mdot
.856 .32721 Mdot
.856 .32748 Mdot
.856 .32807 Mdot
.856 .32892 Mdot
.856 .32994 Mdot
.856 .33034 Mdot
.856 .33094 Mdot
.856 .33097 Mdot
.856 .33115 Mdot
.856 .33128 Mdot
.856 .33141 Mdot
.856 .33204 Mdot
.856 .33312 Mdot
.856 .33328 Mdot
.856 .33332 Mdot
.856 .33349 Mdot
.856 .33374 Mdot
.856 .33394 Mdot
.856 .33412 Mdot
.856 .33426 Mdot
.856 .33548 Mdot
.856 .33559 Mdot
.856 .33641 Mdot
.856 .33643 Mdot
.856 .33692 Mdot
.856 .33717 Mdot
.856 .3373 Mdot
.856 .33771 Mdot
.856 .33786 Mdot
.856 .33821 Mdot
.856 .33863 Mdot
.856 .33938 Mdot
.856 .3396 Mdot
.856 .33962 Mdot
.856 .33983 Mdot
.856 .34023 Mdot
.856 .34056 Mdot
.856 .34084 Mdot
.856 .34091 Mdot
.856 .34095 Mdot
.856 .34127 Mdot
.856 .34138 Mdot
.856 .34161 Mdot
.856 .34186 Mdot
.856 .34198 Mdot
.856 .34205 Mdot
.856 .34254 Mdot
.856 .34275 Mdot
.856 .34286 Mdot
.856 .34296 Mdot
.856 .34326 Mdot
.856 .34348 Mdot
.856 .34357 Mdot
.856 .34407 Mdot
.856 .34438 Mdot
.856 .34467 Mdot
.856 .3451 Mdot
.856 .34535 Mdot
.856 .34544 Mdot
.856 .34563 Mdot
.856 .34619 Mdot
.856 .3467 Mdot
.856 .34676 Mdot
.856 .34778 Mdot
.856 .34781 Mdot
.856 .34854 Mdot
.856 .34925 Mdot
.856 .34952 Mdot
.856 .34985 Mdot
.856 .34991 Mdot
.856 .35067 Mdot
.856 .35089 Mdot
.856 .35092 Mdot
.856 .35147 Mdot
.856 .35148 Mdot
.856 .35151 Mdot
.856 .35158 Mdot
.856 .35165 Mdot
.856 .35171 Mdot
.856 .35249 Mdot
.856 .35297 Mdot
.856 .35352 Mdot
.856 .35372 Mdot
.856 .35401 Mdot
.856 .35412 Mdot
.856 .35446 Mdot
.856 .35523 Mdot
.856 .35557 Mdot
.856 .35574 Mdot
.856 .35593 Mdot
.856 .35652 Mdot
.856 .35733 Mdot
.856 .35777 Mdot
.856 .35936 Mdot
.856 .36017 Mdot
.856 .36026 Mdot
.856 .36037 Mdot
.856 .3607 Mdot
.856 .36101 Mdot
.856 .36132 Mdot
.856 .36134 Mdot
.856 .36159 Mdot
.856 .36234 Mdot
.856 .36242 Mdot
.856 .36252 Mdot
.856 .36332 Mdot
.856 .36375 Mdot
.856 .36451 Mdot
.856 .36456 Mdot
.856 .3653 Mdot
.856 .36531 Mdot
.856 .36566 Mdot
.856 .36588 Mdot
.856 .36597 Mdot
.856 .36599 Mdot
.856 .36603 Mdot
.856 .36663 Mdot
.856 .36669 Mdot
.856 .36728 Mdot
.856 .36812 Mdot
.856 .36834 Mdot
.856 .36876 Mdot
.856 .36884 Mdot
.856 .36899 Mdot
.856 .3691 Mdot
.856 .36951 Mdot
.856 .36983 Mdot
.856 .37013 Mdot
.856 .37028 Mdot
.856 .37033 Mdot
.856 .37044 Mdot
.856 .37134 Mdot
.856 .37175 Mdot
.856 .37199 Mdot
.856 .37207 Mdot
.856 .37227 Mdot
.856 .37265 Mdot
.856 .3728 Mdot
.856 .37288 Mdot
.856 .37431 Mdot
.856 .37444 Mdot
.856 .37477 Mdot
.856 .37503 Mdot
.856 .37532 Mdot
.856 .37584 Mdot
.856 .37587 Mdot
.856 .37599 Mdot
.856 .37625 Mdot
.856 .37697 Mdot
.856 .37766 Mdot
.856 .37797 Mdot
.856 .37801 Mdot
.856 .37901 Mdot
.856 .37969 Mdot
.856 .37994 Mdot
.856 .38123 Mdot
.856 .38134 Mdot
.856 .382 Mdot
.856 .38207 Mdot
.856 .38225 Mdot
.856 .38311 Mdot
.856 .3833 Mdot
.856 .38401 Mdot
.856 .38402 Mdot
.856 .38437 Mdot
.856 .3846 Mdot
.856 .38468 Mdot
.856 .38539 Mdot
.856 .38583 Mdot
.856 .38608 Mdot
.856 .38627 Mdot
.856 .38669 Mdot
.856 .38699 Mdot
.856 .3874 Mdot
.856 .38776 Mdot
.856 .38791 Mdot
.856 .38862 Mdot
.856 .38896 Mdot
.856 .38897 Mdot
.856 .38938 Mdot
.856 .39014 Mdot
.856 .39135 Mdot
.856 .39149 Mdot
.856 .39189 Mdot
.856 .39248 Mdot
.856 .3925 Mdot
.856 .39308 Mdot
.856 .3935 Mdot
.856 .39365 Mdot
.856 .39372 Mdot
.856 .39405 Mdot
.856 .39464 Mdot
.856 .39552 Mdot
.856 .39582 Mdot
.856 .39595 Mdot
.856 .39613 Mdot
.856 .39699 Mdot
.856 .39707 Mdot
.856 .39725 Mdot
.856 .39768 Mdot
.856 .39774 Mdot
.856 .39787 Mdot
.856 .39812 Mdot
.856 .39908 Mdot
.856 .39947 Mdot
.856 .39949 Mdot
.856 .39951 Mdot
.856 .39956 Mdot
.856 .39969 Mdot
.856 .39989 Mdot
.856 .40033 Mdot
.856 .40106 Mdot
.856 .40152 Mdot
.856 .40158 Mdot
.856 .40206 Mdot
.856 .40221 Mdot
.856 .4024 Mdot
.856 .40278 Mdot
.856 .40284 Mdot
.856 .40336 Mdot
.856 .4043 Mdot
.856 .40455 Mdot
.856 .40503 Mdot
.856 .40578 Mdot
.856 .40623 Mdot
.856 .40643 Mdot
.856 .40649 Mdot
.856 .40678 Mdot
.856 .40738 Mdot
.856 .40783 Mdot
.856 .40787 Mdot
.856 .4083 Mdot
.856 .40832 Mdot
.856 .40888 Mdot
.856 .40892 Mdot
.856 .40911 Mdot
.856 .40969 Mdot
.856 .41013 Mdot
.856 .41106 Mdot
.856 .4115 Mdot
.856 .41155 Mdot
.856 .4117 Mdot
.856 .41194 Mdot
.856 .4123 Mdot
.856 .41259 Mdot
.856 .41264 Mdot
.856 .41277 Mdot
.856 .41295 Mdot
.856 .41307 Mdot
.856 .41319 Mdot
.856 .41348 Mdot
.856 .41374 Mdot
.856 .41387 Mdot
.856 .41419 Mdot
.856 .41477 Mdot
.856 .41491 Mdot
.856 .41547 Mdot
.856 .41572 Mdot
.856 .41593 Mdot
.856 .41601 Mdot
.856 .41625 Mdot
.856 .41677 Mdot
.856 .41732 Mdot
.856 .41803 Mdot
.856 .41821 Mdot
.856 .41833 Mdot
.856 .41848 Mdot
.856 .41858 Mdot
.856 .4186 Mdot
.856 .41932 Mdot
.856 .41969 Mdot
.856 .41996 Mdot
.856 .42032 Mdot
.856 .42055 Mdot
.856 .42115 Mdot
.856 .42215 Mdot
.856 .42215 Mdot
.856 .42225 Mdot
.856 .42259 Mdot
.856 .42271 Mdot
.856 .42328 Mdot
.856 .42335 Mdot
.856 .42338 Mdot
.856 .42347 Mdot
.856 .42354 Mdot
.856 .42382 Mdot
.856 .42391 Mdot
.856 .42401 Mdot
.856 .42451 Mdot
.856 .42453 Mdot
.856 .42512 Mdot
.856 .42568 Mdot
.856 .4258 Mdot
.856 .42588 Mdot
.856 .42604 Mdot
.856 .42719 Mdot
.856 .42793 Mdot
.856 .42832 Mdot
.856 .4285 Mdot
.856 .42901 Mdot
.856 .42929 Mdot
.856 .42946 Mdot
.856 .42956 Mdot
.856 .42961 Mdot
.856 .43013 Mdot
.856 .43017 Mdot
.856 .43061 Mdot
.856 .43088 Mdot
.856 .43131 Mdot
.856 .43134 Mdot
.856 .43187 Mdot
.856 .43214 Mdot
.856 .43234 Mdot
.856 .4324 Mdot
.856 .43297 Mdot
.856 .43316 Mdot
.856 .43324 Mdot
.856 .43331 Mdot
.856 .43368 Mdot
.856 .43469 Mdot
.856 .43617 Mdot
.856 .43643 Mdot
.856 .43743 Mdot
.856 .43777 Mdot
.856 .43809 Mdot
.856 .43817 Mdot
.856 .43922 Mdot
.856 .43956 Mdot
.856 .44057 Mdot
.856 .4409 Mdot
.856 .44118 Mdot
.856 .44132 Mdot
.856 .44136 Mdot
.856 .44149 Mdot
.856 .44177 Mdot
.856 .44259 Mdot
.856 .44259 Mdot
.856 .44285 Mdot
.856 .44307 Mdot
.856 .44309 Mdot
.856 .44367 Mdot
.856 .44386 Mdot
.856 .44402 Mdot
.856 .44411 Mdot
.856 .44436 Mdot
.856 .44453 Mdot
.856 .44469 Mdot
.856 .44527 Mdot
.856 .4453 Mdot
.856 .44564 Mdot
.856 .44646 Mdot
.856 .44682 Mdot
.856 .44696 Mdot
.856 .44779 Mdot
.856 .44789 Mdot
.856 .44802 Mdot
.856 .44813 Mdot
.856 .44819 Mdot
.856 .4482 Mdot
.856 .44842 Mdot
.856 .44848 Mdot
.856 .44915 Mdot
.856 .44921 Mdot
.856 .44937 Mdot
.856 .44953 Mdot
.856 .44958 Mdot
.856 .44967 Mdot
.856 .44973 Mdot
.856 .44978 Mdot
.856 .45087 Mdot
.856 .45097 Mdot
.856 .45104 Mdot
.856 .45154 Mdot
.856 .45201 Mdot
.856 .45248 Mdot
.856 .4532 Mdot
.856 .45323 Mdot
.856 .45351 Mdot
.856 .45371 Mdot
.856 .45401 Mdot
.856 .45418 Mdot
.856 .45447 Mdot
.856 .45453 Mdot
.856 .45474 Mdot
.856 .4548 Mdot
.856 .45497 Mdot
.856 .45581 Mdot
.856 .45626 Mdot
.856 .45628 Mdot
.856 .45633 Mdot
.856 .45638 Mdot
.856 .4567 Mdot
.856 .4572 Mdot
.856 .45725 Mdot
.856 .45777 Mdot
.856 .4582 Mdot
.856 .45853 Mdot
.856 .4586 Mdot
.856 .45869 Mdot
.856 .45869 Mdot
.856 .45911 Mdot
.856 .45984 Mdot
.856 .46023 Mdot
.856 .46034 Mdot
.856 .46079 Mdot
.856 .46088 Mdot
.856 .46173 Mdot
.856 .46188 Mdot
.856 .46219 Mdot
.856 .46226 Mdot
.856 .46278 Mdot
.856 .46293 Mdot
.856 .46294 Mdot
.856 .46314 Mdot
.856 .46333 Mdot
.856 .4635 Mdot
.856 .46356 Mdot
.856 .46434 Mdot
.856 .46446 Mdot
.856 .46465 Mdot
.856 .46503 Mdot
.856 .4651 Mdot
.856 .46522 Mdot
.856 .46548 Mdot
.856 .46552 Mdot
.856 .46566 Mdot
.856 .46621 Mdot
.856 .46629 Mdot
.856 .46641 Mdot
.856 .46689 Mdot
.856 .46697 Mdot
.856 .46745 Mdot
.856 .46794 Mdot
.856 .46814 Mdot
.856 .46818 Mdot
.856 .46849 Mdot
.856 .46854 Mdot
.856 .46872 Mdot
.856 .46887 Mdot
.856 .46891 Mdot
.856 .46903 Mdot
.856 .4693 Mdot
.856 .46945 Mdot
.856 .46977 Mdot
.856 .46992 Mdot
.856 .47018 Mdot
.856 .47039 Mdot
.856 .47055 Mdot
.856 .47091 Mdot
.856 .47151 Mdot
.856 .47176 Mdot
.856 .4724 Mdot
.856 .47247 Mdot
.856 .47252 Mdot
.856 .47268 Mdot
.856 .4727 Mdot
.856 .47311 Mdot
.856 .47333 Mdot
.856 .47337 Mdot
.856 .47339 Mdot
.856 .4734 Mdot
.856 .47354 Mdot
.856 .47386 Mdot
.856 .47395 Mdot
.856 .47399 Mdot
.856 .47402 Mdot
.856 .47425 Mdot
.856 .47455 Mdot
.856 .47505 Mdot
.856 .47539 Mdot
.856 .47544 Mdot
.856 .47558 Mdot
.856 .47699 Mdot
.856 .4774 Mdot
.856 .47766 Mdot
.856 .47791 Mdot
.856 .47821 Mdot
.856 .47845 Mdot
.856 .47856 Mdot
.856 .47899 Mdot
.856 .47928 Mdot
.856 .47934 Mdot
.856 .47959 Mdot
.856 .47963 Mdot
.856 .48084 Mdot
.856 .48147 Mdot
.856 .48174 Mdot
.856 .48183 Mdot
.856 .48194 Mdot
.856 .48248 Mdot
.856 .48255 Mdot
.856 .48278 Mdot
.856 .483 Mdot
.856 .48331 Mdot
.856 .48335 Mdot
.856 .48363 Mdot
.856 .48386 Mdot
.856 .4841 Mdot
.856 .48439 Mdot
.856 .48461 Mdot
.856 .48506 Mdot
.856 .48533 Mdot
.856 .48559 Mdot
.856 .48607 Mdot
.856 .48642 Mdot
.856 .48663 Mdot
.856 .48681 Mdot
.856 .48826 Mdot
.856 .48832 Mdot
.856 .48838 Mdot
.856 .48901 Mdot
.856 .48927 Mdot
.856 .48974 Mdot
.856 .48977 Mdot
.856 .48978 Mdot
.856 .48978 Mdot
.856 .49005 Mdot
.856 .49054 Mdot
.856 .49103 Mdot
.856 .49139 Mdot
.856 .49141 Mdot
.856 .49177 Mdot
.856 .4922 Mdot
.856 .49272 Mdot
.856 .49302 Mdot
.856 .49306 Mdot
.856 .49326 Mdot
.856 .49337 Mdot
.856 .49339 Mdot
.856 .4935 Mdot
.856 .49362 Mdot
.856 .49382 Mdot
.856 .49391 Mdot
.856 .49466 Mdot
.856 .49474 Mdot
.856 .49491 Mdot
.856 .4952 Mdot
.856 .4957 Mdot
.856 .49604 Mdot
.856 .49667 Mdot
.856 .49672 Mdot
.856 .49678 Mdot
.856 .49776 Mdot
.856 .49796 Mdot
.856 .49839 Mdot
.856 .49846 Mdot
.856 .49865 Mdot
.856 .49931 Mdot
.856 .49966 Mdot
.856 .49997 Mdot
.856 .5001 Mdot
.856 .50045 Mdot
.856 .5006 Mdot
.856 .50063 Mdot
.856 .50069 Mdot
.856 .50087 Mdot
.856 .50116 Mdot
.856 .50175 Mdot
.856 .5025 Mdot
.856 .50267 Mdot
.856 .50275 Mdot
.856 .50295 Mdot
.856 .50296 Mdot
.856 .50386 Mdot
.856 .50391 Mdot
.856 .50452 Mdot
.856 .50492 Mdot
.856 .50528 Mdot
.856 .50641 Mdot
.856 .50669 Mdot
.856 .50779 Mdot
.856 .50784 Mdot
.856 .50784 Mdot
.856 .50829 Mdot
.856 .50837 Mdot
.856 .50861 Mdot
.856 .50985 Mdot
.856 .51067 Mdot
.856 .51118 Mdot
.856 .51146 Mdot
.856 .5116 Mdot
.856 .51203 Mdot
.856 .51286 Mdot
.856 .51294 Mdot
.856 .51314 Mdot
.856 .51327 Mdot
.856 .51327 Mdot
.856 .51346 Mdot
.856 .51431 Mdot
.856 .51435 Mdot
.856 .51455 Mdot
.856 .51527 Mdot
.856 .51535 Mdot
.856 .51589 Mdot
.856 .51659 Mdot
.856 .51668 Mdot
.856 .51699 Mdot
.856 .51719 Mdot
.856 .51729 Mdot
.856 .51743 Mdot
.856 .51797 Mdot
.856 .51823 Mdot
.856 .51887 Mdot
.856 .51902 Mdot
.856 .5191 Mdot
.856 .51963 Mdot
.856 .51966 Mdot
.858 .15962 Mdot
.858 .15978 Mdot
.858 .1602 Mdot
.858 .16111 Mdot
.858 .16117 Mdot
.858 .16153 Mdot
.858 .1616 Mdot
.858 .16175 Mdot
.858 .16225 Mdot
.858 .16255 Mdot
.858 .16303 Mdot
.858 .16417 Mdot
.858 .16449 Mdot
.858 .16474 Mdot
.858 .16485 Mdot
.858 .1652 Mdot
.858 .16584 Mdot
.858 .16604 Mdot
.858 .16693 Mdot
.858 .16796 Mdot
.858 .16985 Mdot
.858 .17006 Mdot
.858 .1701 Mdot
.858 .17137 Mdot
.858 .17147 Mdot
.858 .17291 Mdot
.858 .17375 Mdot
.858 .1739 Mdot
.858 .17403 Mdot
.858 .17437 Mdot
.858 .1744 Mdot
.858 .1755 Mdot
.858 .17681 Mdot
.858 .17716 Mdot
.858 .17731 Mdot
.858 .17781 Mdot
.858 .17959 Mdot
.858 .17989 Mdot
.858 .1815 Mdot
.858 .18206 Mdot
.858 .18244 Mdot
.858 .18279 Mdot
.858 .18299 Mdot
.858 .18431 Mdot
.858 .18494 Mdot
.858 .18516 Mdot
.858 .18535 Mdot
.858 .18537 Mdot
.858 .18542 Mdot
.858 .18636 Mdot
.858 .18684 Mdot
.858 .18714 Mdot
.858 .18736 Mdot
.858 .18811 Mdot
.858 .18818 Mdot
.858 .18967 Mdot
.858 .1897 Mdot
.858 .19031 Mdot
.858 .19143 Mdot
.858 .19248 Mdot
.858 .19314 Mdot
.858 .19387 Mdot
.858 .19398 Mdot
.858 .19488 Mdot
.858 .19512 Mdot
.858 .19571 Mdot
.858 .19642 Mdot
.858 .19646 Mdot
.858 .19743 Mdot
.858 .19775 Mdot
.858 .19794 Mdot
.858 .19914 Mdot
.858 .20025 Mdot
.858 .20146 Mdot
.858 .20146 Mdot
.858 .2018 Mdot
.858 .20215 Mdot
.858 .20266 Mdot
.858 .20281 Mdot
.858 .20296 Mdot
.858 .20385 Mdot
.858 .2044 Mdot
.858 .20445 Mdot
.858 .20548 Mdot
.858 .20603 Mdot
.858 .20625 Mdot
.858 .20664 Mdot
.858 .20692 Mdot
.858 .20704 Mdot
.858 .208 Mdot
.858 .20801 Mdot
.858 .20823 Mdot
.858 .20955 Mdot
.858 .2104 Mdot
.858 .21077 Mdot
.858 .21103 Mdot
.858 .21196 Mdot
.858 .21278 Mdot
.858 .21311 Mdot
.858 .21444 Mdot
.858 .21464 Mdot
.858 .21474 Mdot
.858 .21475 Mdot
.858 .2149 Mdot
.858 .21567 Mdot
.858 .21682 Mdot
.858 .21741 Mdot
.858 .21781 Mdot
.858 .21974 Mdot
.858 .22019 Mdot
.858 .22034 Mdot
.858 .22176 Mdot
.858 .22204 Mdot
.858 .22243 Mdot
.858 .22258 Mdot
.858 .22274 Mdot
.858 .22346 Mdot
.858 .22371 Mdot
.858 .22423 Mdot
.858 .22517 Mdot
.858 .22552 Mdot
.858 .2256 Mdot
.858 .22663 Mdot
.858 .22736 Mdot
.858 .22774 Mdot
.858 .22902 Mdot
.858 .2293 Mdot
.858 .22982 Mdot
.858 .23029 Mdot
.858 .23046 Mdot
.858 .23065 Mdot
.858 .23162 Mdot
.858 .23182 Mdot
.858 .23188 Mdot
.858 .23347 Mdot
.858 .23349 Mdot
.858 .23372 Mdot
.858 .2339 Mdot
.858 .23423 Mdot
.858 .23501 Mdot
.858 .23519 Mdot
.858 .2355 Mdot
.858 .23614 Mdot
.858 .23634 Mdot
.858 .23698 Mdot
.858 .23954 Mdot
.858 .23974 Mdot
.858 .23981 Mdot
.858 .24028 Mdot
.858 .24034 Mdot
.858 .24053 Mdot
.858 .24108 Mdot
.858 .24116 Mdot
.858 .24194 Mdot
.858 .24215 Mdot
.858 .24321 Mdot
.858 .24322 Mdot
.858 .2443 Mdot
.858 .24505 Mdot
.858 .24521 Mdot
.858 .24555 Mdot
.858 .24561 Mdot
.858 .24564 Mdot
.858 .24582 Mdot
.858 .24585 Mdot
.858 .24612 Mdot
.858 .24625 Mdot
.858 .24767 Mdot
.858 .24827 Mdot
.858 .24836 Mdot
.858 .24857 Mdot
.858 .24988 Mdot
.858 .25006 Mdot
.858 .25061 Mdot
.858 .25082 Mdot
.858 .25096 Mdot
.858 .25275 Mdot
.858 .25279 Mdot
.858 .25323 Mdot
.858 .25381 Mdot
.858 .25396 Mdot
.858 .25397 Mdot
.858 .25524 Mdot
.858 .25658 Mdot
.858 .25768 Mdot
.858 .25796 Mdot
.858 .25799 Mdot
.858 .25854 Mdot
.858 .25965 Mdot
.858 .25968 Mdot
.858 .26081 Mdot
.858 .26106 Mdot
.858 .26145 Mdot
.858 .26167 Mdot
.858 .26194 Mdot
.858 .26242 Mdot
.858 .26254 Mdot
.858 .26303 Mdot
.858 .2633 Mdot
.858 .26338 Mdot
.858 .26344 Mdot
.858 .26364 Mdot
.858 .26437 Mdot
.858 .2644 Mdot
.858 .26451 Mdot
.858 .26507 Mdot
.858 .26592 Mdot
.858 .26603 Mdot
.858 .26648 Mdot
.858 .26651 Mdot
.858 .26657 Mdot
.858 .26664 Mdot
.858 .26667 Mdot
.858 .26678 Mdot
.858 .26681 Mdot
.858 .26702 Mdot
.858 .26704 Mdot
.858 .26708 Mdot
.858 .26732 Mdot
.858 .26771 Mdot
.858 .26788 Mdot
.858 .26839 Mdot
.858 .26842 Mdot
.858 .26846 Mdot
.858 .26863 Mdot
.858 .2689 Mdot
.858 .26899 Mdot
.858 .26922 Mdot
.858 .26935 Mdot
.858 .26935 Mdot
.858 .2695 Mdot
.858 .26982 Mdot
.858 .27027 Mdot
.858 .2704 Mdot
.858 .27118 Mdot
.858 .27173 Mdot
.858 .27188 Mdot
.858 .27199 Mdot
.858 .27204 Mdot
.858 .27216 Mdot
.858 .27234 Mdot
.858 .27236 Mdot
.858 .27283 Mdot
.858 .27295 Mdot
.858 .27369 Mdot
.858 .27405 Mdot
.858 .27419 Mdot
.858 .27436 Mdot
.858 .27439 Mdot
.858 .27456 Mdot
.858 .27494 Mdot
.858 .2759 Mdot
.858 .27591 Mdot
.858 .27683 Mdot
.858 .27727 Mdot
.858 .27727 Mdot
.858 .27767 Mdot
.858 .27768 Mdot
.858 .27834 Mdot
.858 .27859 Mdot
.858 .27865 Mdot
.858 .2794 Mdot
.858 .27989 Mdot
.858 .28002 Mdot
.858 .2801 Mdot
.858 .28011 Mdot
.858 .28024 Mdot
.858 .28055 Mdot
.858 .28092 Mdot
.858 .28128 Mdot
.858 .28135 Mdot
.858 .28161 Mdot
.858 .28183 Mdot
.858 .2821 Mdot
.858 .28325 Mdot
.858 .28354 Mdot
.858 .2837 Mdot
.858 .28397 Mdot
.858 .28408 Mdot
.858 .28414 Mdot
.858 .28477 Mdot
.858 .28486 Mdot
.858 .28518 Mdot
.858 .28525 Mdot
.858 .28547 Mdot
.858 .28564 Mdot
.858 .28574 Mdot
.858 .28617 Mdot
.858 .28655 Mdot
.858 .2869 Mdot
.858 .28704 Mdot
.858 .28737 Mdot
.858 .28763 Mdot
.858 .28787 Mdot
.858 .28811 Mdot
.858 .28869 Mdot
.858 .28874 Mdot
.858 .28955 Mdot
.858 .28968 Mdot
.858 .28988 Mdot
.858 .29062 Mdot
.858 .29069 Mdot
.858 .29153 Mdot
.858 .29185 Mdot
.858 .29193 Mdot
.858 .29206 Mdot
.858 .29235 Mdot
.858 .29287 Mdot
.858 .2932 Mdot
.858 .29347 Mdot
.858 .29373 Mdot
.858 .29408 Mdot
.858 .29459 Mdot
.858 .29469 Mdot
.858 .29486 Mdot
.858 .29498 Mdot
.858 .2951 Mdot
.858 .29589 Mdot
.858 .2963 Mdot
.858 .29733 Mdot
.858 .29764 Mdot
.858 .29768 Mdot
.858 .29815 Mdot
.858 .29888 Mdot
.858 .29909 Mdot
.858 .2991 Mdot
.858 .29989 Mdot
.858 .30006 Mdot
.858 .30054 Mdot
.858 .30056 Mdot
.858 .30063 Mdot
.858 .30071 Mdot
.858 .30092 Mdot
.858 .30137 Mdot
.858 .30169 Mdot
.858 .30188 Mdot
.858 .30242 Mdot
.858 .30253 Mdot
.858 .30313 Mdot
.858 .30347 Mdot
.858 .30429 Mdot
.858 .30528 Mdot
.858 .30575 Mdot
.858 .30576 Mdot
.858 .30583 Mdot
.858 .30683 Mdot
.858 .30719 Mdot
.858 .30741 Mdot
.858 .30753 Mdot
.858 .30757 Mdot
.858 .30765 Mdot
.858 .30815 Mdot
.858 .30863 Mdot
.858 .30878 Mdot
.858 .30911 Mdot
.858 .30925 Mdot
.858 .31009 Mdot
.858 .31059 Mdot
.858 .31073 Mdot
.858 .31081 Mdot
.858 .31098 Mdot
.858 .31108 Mdot
.858 .31163 Mdot
.858 .31227 Mdot
.858 .31238 Mdot
.858 .31292 Mdot
.858 .31408 Mdot
.858 .3146 Mdot
.858 .31489 Mdot
.858 .31493 Mdot
.858 .31498 Mdot
.858 .3151 Mdot
.858 .31548 Mdot
.858 .31604 Mdot
.858 .31609 Mdot
.858 .31783 Mdot
.858 .31795 Mdot
.858 .31883 Mdot
.858 .31917 Mdot
.858 .31943 Mdot
.858 .31976 Mdot
.858 .31978 Mdot
.858 .32089 Mdot
.858 .32147 Mdot
.858 .32214 Mdot
.858 .32234 Mdot
.858 .32258 Mdot
.858 .3226 Mdot
.858 .32293 Mdot
.858 .32304 Mdot
.858 .32388 Mdot
.858 .32429 Mdot
.858 .32475 Mdot
.858 .32511 Mdot
.858 .32529 Mdot
.858 .32585 Mdot
.858 .32606 Mdot
.858 .32615 Mdot
.858 .32651 Mdot
.858 .3266 Mdot
.858 .32814 Mdot
.858 .32825 Mdot
.858 .3288 Mdot
.858 .32881 Mdot
.858 .32886 Mdot
.858 .32912 Mdot
.858 .3305 Mdot
.858 .33119 Mdot
.858 .33142 Mdot
.858 .33147 Mdot
.858 .33185 Mdot
.858 .33247 Mdot
.858 .33309 Mdot
.858 .33409 Mdot
.858 .33461 Mdot
.858 .33516 Mdot
.858 .33517 Mdot
.858 .33575 Mdot
.858 .33607 Mdot
.858 .33636 Mdot
.858 .33723 Mdot
.858 .33732 Mdot
.858 .33748 Mdot
.858 .3375 Mdot
.858 .33775 Mdot
.858 .33848 Mdot
.858 .3391 Mdot
.858 .33927 Mdot
.858 .33936 Mdot
.858 .33946 Mdot
.858 .34019 Mdot
.858 .34022 Mdot
.858 .34029 Mdot
.858 .34099 Mdot
.858 .34111 Mdot
.858 .34188 Mdot
.858 .34207 Mdot
.858 .34301 Mdot
.858 .34339 Mdot
.858 .34368 Mdot
.858 .34406 Mdot
.858 .34407 Mdot
.858 .34454 Mdot
.858 .34467 Mdot
.858 .34474 Mdot
.858 .3453 Mdot
.858 .34567 Mdot
.858 .3459 Mdot
.858 .34637 Mdot
.858 .34639 Mdot
.858 .34641 Mdot
.858 .34649 Mdot
.858 .34658 Mdot
.858 .34666 Mdot
.858 .34679 Mdot
.858 .34711 Mdot
.858 .3472 Mdot
.858 .34735 Mdot
.858 .34771 Mdot
.858 .34825 Mdot
.858 .34826 Mdot
.858 .34837 Mdot
.858 .34853 Mdot
.858 .34882 Mdot
.858 .34905 Mdot
.858 .34925 Mdot
.858 .35051 Mdot
.858 .351 Mdot
.858 .35105 Mdot
.858 .35115 Mdot
.858 .35159 Mdot
.858 .35319 Mdot
.858 .35331 Mdot
.858 .35421 Mdot
.858 .35425 Mdot
.858 .3546 Mdot
.858 .35506 Mdot
.858 .35516 Mdot
.858 .35545 Mdot
.858 .35606 Mdot
.858 .3565 Mdot
.858 .35738 Mdot
.858 .35745 Mdot
.858 .35778 Mdot
.858 .35795 Mdot
.858 .35797 Mdot
.858 .358 Mdot
.858 .35822 Mdot
.858 .35921 Mdot
.858 .35955 Mdot
.858 .36028 Mdot
.858 .36053 Mdot
.858 .36069 Mdot
.858 .36074 Mdot
.858 .36152 Mdot
.858 .36215 Mdot
.858 .36254 Mdot
.858 .36272 Mdot
.858 .36289 Mdot
.858 .36302 Mdot
.858 .36322 Mdot
.858 .36427 Mdot
.858 .36436 Mdot
.858 .36448 Mdot
.858 .36505 Mdot
.858 .36554 Mdot
.858 .36628 Mdot
.858 .36654 Mdot
.858 .36732 Mdot
.858 .36754 Mdot
.858 .36756 Mdot
.858 .36812 Mdot
.858 .36844 Mdot
.858 .37001 Mdot
.858 .37043 Mdot
.858 .37049 Mdot
.858 .37116 Mdot
.858 .37141 Mdot
.858 .37168 Mdot
.858 .37198 Mdot
.858 .37259 Mdot
.858 .37272 Mdot
.858 .37293 Mdot
.858 .37335 Mdot
.858 .37351 Mdot
.858 .37361 Mdot
.858 .37396 Mdot
.858 .37414 Mdot
.858 .37415 Mdot
.858 .37424 Mdot
.858 .37448 Mdot
.858 .37508 Mdot
.858 .37586 Mdot
.858 .37646 Mdot
.858 .37659 Mdot
.858 .3768 Mdot
.858 .37695 Mdot
.858 .37787 Mdot
.858 .37837 Mdot
.858 .37839 Mdot
.858 .37916 Mdot
.858 .37961 Mdot
.858 .38002 Mdot
.858 .38027 Mdot
.858 .3807 Mdot
.858 .38089 Mdot
.858 .381 Mdot
.858 .38168 Mdot
.858 .3822 Mdot
.858 .38245 Mdot
.858 .38272 Mdot
.858 .38276 Mdot
.858 .38288 Mdot
.858 .38294 Mdot
.858 .38294 Mdot
.858 .38384 Mdot
.858 .38464 Mdot
.858 .38493 Mdot
.858 .38523 Mdot
.858 .38527 Mdot
.858 .38585 Mdot
.858 .38586 Mdot
.858 .3867 Mdot
.858 .38691 Mdot
.858 .38692 Mdot
.858 .3872 Mdot
.858 .38727 Mdot
.858 .38737 Mdot
.858 .38761 Mdot
.858 .38778 Mdot
.858 .3879 Mdot
.858 .38839 Mdot
.858 .3884 Mdot
.858 .38876 Mdot
.858 .39009 Mdot
.858 .39013 Mdot
.858 .3902 Mdot
.858 .39022 Mdot
.858 .39052 Mdot
.858 .39083 Mdot
.858 .39122 Mdot
.858 .39129 Mdot
.858 .3914 Mdot
.858 .3918 Mdot
.858 .3923 Mdot
.858 .39275 Mdot
.858 .39305 Mdot
.858 .39359 Mdot
.858 .39368 Mdot
.858 .39468 Mdot
.858 .39502 Mdot
.858 .39522 Mdot
.858 .39522 Mdot
.858 .39533 Mdot
.858 .39553 Mdot
.858 .39559 Mdot
.858 .39605 Mdot
.858 .39612 Mdot
.858 .39648 Mdot
.858 .39738 Mdot
.858 .39854 Mdot
.858 .39873 Mdot
.858 .39907 Mdot
.858 .3998 Mdot
.858 .40023 Mdot
.858 .40052 Mdot
.858 .40085 Mdot
.858 .40092 Mdot
.858 .40098 Mdot
.858 .40171 Mdot
.858 .40178 Mdot
.858 .40188 Mdot
.858 .40221 Mdot
.858 .40303 Mdot
.858 .40306 Mdot
.858 .40316 Mdot
.858 .4033 Mdot
.858 .40392 Mdot
.858 .40463 Mdot
.858 .40499 Mdot
.858 .4055 Mdot
.858 .40576 Mdot
.858 .40611 Mdot
.858 .40634 Mdot
.858 .40681 Mdot
.858 .40684 Mdot
.858 .40736 Mdot
.858 .40868 Mdot
.858 .40871 Mdot
.858 .40973 Mdot
.858 .40998 Mdot
.858 .41015 Mdot
.858 .41024 Mdot
.858 .4103 Mdot
.858 .41031 Mdot
.858 .41063 Mdot
.858 .41083 Mdot
.858 .41092 Mdot
.858 .41098 Mdot
.858 .41124 Mdot
.858 .41128 Mdot
.858 .41134 Mdot
.858 .4114 Mdot
.858 .41168 Mdot
.858 .41181 Mdot
.858 .41203 Mdot
.858 .4124 Mdot
.858 .41275 Mdot
.858 .41297 Mdot
.858 .41402 Mdot
.858 .41447 Mdot
.858 .41454 Mdot
.858 .41501 Mdot
.858 .41543 Mdot
.858 .41549 Mdot
.858 .41564 Mdot
.858 .416 Mdot
.858 .41658 Mdot
.858 .41668 Mdot
.858 .41741 Mdot
.858 .41826 Mdot
.858 .41856 Mdot
.858 .41951 Mdot
.858 .41987 Mdot
.858 .42009 Mdot
.858 .42012 Mdot
.858 .42065 Mdot
.858 .42161 Mdot
.858 .42164 Mdot
.858 .42203 Mdot
.858 .42319 Mdot
.858 .42324 Mdot
.858 .42337 Mdot
.858 .4238 Mdot
.858 .424 Mdot
.858 .425 Mdot
.858 .42507 Mdot
.858 .42526 Mdot
.858 .42527 Mdot
.858 .42592 Mdot
.858 .4269 Mdot
.858 .4271 Mdot
.858 .42726 Mdot
.858 .42746 Mdot
.858 .42905 Mdot
.858 .42941 Mdot
.858 .42963 Mdot
.858 .42975 Mdot
.858 .42992 Mdot
.858 .43022 Mdot
.858 .4309 Mdot
.858 .43165 Mdot
.858 .43197 Mdot
.858 .43213 Mdot
.858 .43217 Mdot
.858 .43312 Mdot
.858 .43331 Mdot
.858 .4334 Mdot
.858 .43368 Mdot
.858 .43411 Mdot
.858 .43503 Mdot
.858 .43507 Mdot
.858 .43535 Mdot
.858 .43593 Mdot
.858 .43701 Mdot
.858 .43744 Mdot
.858 .43763 Mdot
.858 .43802 Mdot
.858 .43806 Mdot
.858 .4381 Mdot
.858 .43811 Mdot
.858 .43839 Mdot
.858 .43849 Mdot
.858 .43895 Mdot
.858 .43896 Mdot
.858 .43908 Mdot
.858 .43978 Mdot
.858 .43998 Mdot
.858 .44059 Mdot
.858 .44083 Mdot
.858 .44128 Mdot
.858 .44135 Mdot
.858 .44142 Mdot
.858 .44152 Mdot
.858 .44188 Mdot
.858 .44239 Mdot
.858 .44289 Mdot
.858 .44305 Mdot
.858 .44313 Mdot
.858 .44318 Mdot
.858 .44336 Mdot
.858 .44385 Mdot
.858 .44432 Mdot
.858 .44444 Mdot
.858 .44452 Mdot
.858 .44579 Mdot
.858 .44598 Mdot
.858 .44606 Mdot
.858 .44627 Mdot
.858 .44674 Mdot
.858 .44679 Mdot
.858 .4469 Mdot
.858 .44702 Mdot
.858 .44706 Mdot
.858 .44725 Mdot
.858 .4473 Mdot
.858 .44767 Mdot
.858 .4477 Mdot
.858 .44777 Mdot
.858 .44819 Mdot
.858 .44886 Mdot
.858 .44902 Mdot
.858 .44914 Mdot
.858 .44976 Mdot
.858 .44994 Mdot
.858 .45002 Mdot
.858 .45003 Mdot
.858 .45007 Mdot
.858 .45015 Mdot
.858 .45043 Mdot
.858 .45087 Mdot
.858 .4509 Mdot
.858 .45105 Mdot
.858 .45144 Mdot
.858 .45167 Mdot
.858 .45168 Mdot
.858 .45193 Mdot
.858 .45247 Mdot
.858 .45303 Mdot
.858 .45325 Mdot
.858 .45337 Mdot
.858 .45347 Mdot
.858 .45376 Mdot
.858 .45426 Mdot
.858 .45454 Mdot
.858 .45472 Mdot
.858 .45475 Mdot
.858 .45481 Mdot
.858 .45568 Mdot
.858 .45575 Mdot
.858 .45602 Mdot
.858 .4562 Mdot
.858 .45629 Mdot
.858 .45629 Mdot
.858 .4565 Mdot
.858 .45655 Mdot
.858 .45671 Mdot
.858 .45681 Mdot
.858 .45683 Mdot
.858 .45724 Mdot
.858 .45747 Mdot
.858 .45761 Mdot
.858 .45764 Mdot
.858 .45777 Mdot
.858 .45785 Mdot
.858 .45791 Mdot
.858 .45794 Mdot
.858 .45796 Mdot
.858 .45878 Mdot
.858 .45911 Mdot
.858 .45917 Mdot
.858 .45973 Mdot
.858 .45982 Mdot
.858 .45997 Mdot
.858 .46026 Mdot
.858 .46033 Mdot
.858 .46061 Mdot
.858 .46076 Mdot
.858 .46089 Mdot
.858 .46112 Mdot
.858 .46127 Mdot
.858 .46193 Mdot
.858 .46194 Mdot
.858 .46259 Mdot
.858 .46291 Mdot
.858 .46292 Mdot
.858 .46309 Mdot
.858 .46373 Mdot
.858 .46451 Mdot
.858 .46525 Mdot
.858 .46526 Mdot
.858 .46534 Mdot
.858 .46568 Mdot
.858 .46594 Mdot
.858 .46596 Mdot
.858 .467 Mdot
.858 .46709 Mdot
.858 .46721 Mdot
.858 .46753 Mdot
.858 .46763 Mdot
.858 .4684 Mdot
.858 .46852 Mdot
.858 .46857 Mdot
.858 .46892 Mdot
.858 .46975 Mdot
.858 .46982 Mdot
.858 .46999 Mdot
.858 .47 Mdot
.858 .47011 Mdot
.858 .47013 Mdot
.858 .47016 Mdot
.858 .47036 Mdot
.858 .47045 Mdot
.858 .47089 Mdot
.858 .47151 Mdot
.858 .47152 Mdot
.858 .47214 Mdot
.858 .47226 Mdot
.858 .47271 Mdot
.858 .47276 Mdot
.858 .47308 Mdot
.858 .4732 Mdot
.858 .47323 Mdot
.858 .4735 Mdot
.858 .47355 Mdot
.858 .47366 Mdot
.858 .47515 Mdot
.858 .47553 Mdot
.858 .47564 Mdot
.858 .47601 Mdot
.858 .4762 Mdot
.858 .4763 Mdot
.858 .47676 Mdot
.858 .47695 Mdot
.858 .47705 Mdot
.858 .47719 Mdot
.858 .4772 Mdot
.858 .47812 Mdot
.858 .47816 Mdot
.858 .47828 Mdot
.858 .47884 Mdot
.858 .47895 Mdot
.858 .47905 Mdot
.858 .47932 Mdot
.858 .47963 Mdot
.858 .47979 Mdot
.858 .48054 Mdot
.858 .48076 Mdot
.858 .48118 Mdot
.858 .48179 Mdot
.858 .48183 Mdot
.858 .48203 Mdot
.858 .48258 Mdot
.858 .48289 Mdot
.858 .48303 Mdot
.858 .48345 Mdot
.858 .48355 Mdot
.858 .48363 Mdot
.858 .48386 Mdot
.858 .48402 Mdot
.858 .48485 Mdot
.858 .48494 Mdot
.858 .4852 Mdot
.858 .48632 Mdot
.858 .48656 Mdot
.858 .4869 Mdot
.858 .48757 Mdot
.858 .48802 Mdot
.858 .48811 Mdot
.858 .48812 Mdot
.858 .48817 Mdot
.858 .48829 Mdot
.858 .48906 Mdot
.858 .48925 Mdot
.858 .48973 Mdot
.858 .49028 Mdot
.858 .49042 Mdot
.858 .49064 Mdot
.858 .49114 Mdot
.858 .4919 Mdot
.858 .49204 Mdot
.858 .49204 Mdot
.858 .4926 Mdot
.858 .49267 Mdot
.858 .49283 Mdot
.858 .49306 Mdot
.858 .49319 Mdot
.858 .49351 Mdot
.858 .49411 Mdot
.858 .49414 Mdot
.858 .49446 Mdot
.858 .49498 Mdot
.858 .49507 Mdot
.858 .49515 Mdot
.858 .49545 Mdot
.858 .49566 Mdot
.858 .49585 Mdot
.858 .49585 Mdot
.858 .49656 Mdot
.858 .4972 Mdot
.858 .49791 Mdot
.858 .49801 Mdot
.858 .4982 Mdot
.858 .49876 Mdot
.858 .49879 Mdot
.858 .49921 Mdot
.858 .49955 Mdot
.858 .49968 Mdot
.858 .50021 Mdot
.858 .50028 Mdot
.858 .5007 Mdot
.858 .50108 Mdot
.858 .5017 Mdot
.858 .50235 Mdot
.858 .50271 Mdot
.858 .50272 Mdot
.858 .50359 Mdot
.858 .50363 Mdot
.858 .50407 Mdot
.858 .5042 Mdot
.858 .50437 Mdot
.858 .50465 Mdot
.858 .5052 Mdot
.858 .50523 Mdot
.858 .50524 Mdot
.858 .50535 Mdot
.858 .50548 Mdot
.858 .50584 Mdot
.858 .50662 Mdot
.858 .50673 Mdot
.858 .50694 Mdot
.858 .50716 Mdot
.858 .50748 Mdot
.858 .50842 Mdot
.858 .5086 Mdot
.858 .50963 Mdot
.858 .50992 Mdot
.858 .51001 Mdot
.858 .51022 Mdot
.858 .51098 Mdot
.858 .51162 Mdot
.858 .51164 Mdot
.858 .51183 Mdot
.858 .51191 Mdot
.858 .512 Mdot
.858 .51249 Mdot
.858 .51333 Mdot
.858 .51339 Mdot
.858 .51413 Mdot
.858 .51415 Mdot
.858 .51428 Mdot
.858 .51538 Mdot
.858 .51598 Mdot
.858 .51649 Mdot
.858 .51661 Mdot
.858 .51698 Mdot
.858 .51719 Mdot
.858 .51725 Mdot
.858 .5174 Mdot
.858 .51758 Mdot
.858 .51825 Mdot
.858 .51853 Mdot
.858 .5187 Mdot
.858 .519 Mdot
.858 .51908 Mdot
.858 .51912 Mdot
.858 .51933 Mdot
.858 .51937 Mdot
.858 .51989 Mdot
.858 .52014 Mdot
.858 .52023 Mdot
.86 .15701 Mdot
.86 .15743 Mdot
.86 .15746 Mdot
.86 .15752 Mdot
.86 .15895 Mdot
.86 .15945 Mdot
.86 .15969 Mdot
.86 .15995 Mdot
.86 .1608 Mdot
.86 .16099 Mdot
.86 .16102 Mdot
.86 .16138 Mdot
.86 .16207 Mdot
.86 .16257 Mdot
.86 .16261 Mdot
.86 .16293 Mdot
.86 .16573 Mdot
.86 .16646 Mdot
.86 .16714 Mdot
.86 .16726 Mdot
.86 .16837 Mdot
.86 .16845 Mdot
.86 .16874 Mdot
.86 .16947 Mdot
.86 .17054 Mdot
.86 .1707 Mdot
.86 .17088 Mdot
.86 .17101 Mdot
.86 .17123 Mdot
.86 .17174 Mdot
.86 .17178 Mdot
.86 .17185 Mdot
.86 .17284 Mdot
.86 .17324 Mdot
.86 .17445 Mdot
.86 .1755 Mdot
.86 .17585 Mdot
.86 .1761 Mdot
.86 .17633 Mdot
.86 .17656 Mdot
.86 .17697 Mdot
.86 .17726 Mdot
.86 .17764 Mdot
.86 .17828 Mdot
.86 .1794 Mdot
.86 .17988 Mdot
.86 .18242 Mdot
.86 .18254 Mdot
.86 .18306 Mdot
.86 .18351 Mdot
.86 .18392 Mdot
.86 .18543 Mdot
.86 .18609 Mdot
.86 .18664 Mdot
.86 .18704 Mdot
.86 .18857 Mdot
.86 .18901 Mdot
.86 .18945 Mdot
.86 .19032 Mdot
.86 .19147 Mdot
.86 .19185 Mdot
.86 .19209 Mdot
.86 .19216 Mdot
.86 .19311 Mdot
.86 .19315 Mdot
.86 .19336 Mdot
.86 .19376 Mdot
.86 .19398 Mdot
.86 .19403 Mdot
.86 .19517 Mdot
.86 .19587 Mdot
.86 .1963 Mdot
.86 .19654 Mdot
.86 .19718 Mdot
.86 .1981 Mdot
.86 .19875 Mdot
.86 .19879 Mdot
.86 .19881 Mdot
.86 .19932 Mdot
.86 .19948 Mdot
.86 .19995 Mdot
.86 .20025 Mdot
.86 .20041 Mdot
.86 .20177 Mdot
.86 .20182 Mdot
.86 .20212 Mdot
.86 .20233 Mdot
.86 .20235 Mdot
.86 .20382 Mdot
.86 .20532 Mdot
.86 .20579 Mdot
.86 .20589 Mdot
.86 .20591 Mdot
.86 .2062 Mdot
.86 .20684 Mdot
.86 .20707 Mdot
.86 .208 Mdot
.86 .20811 Mdot
.86 .20826 Mdot
.86 .2085 Mdot
.86 .20898 Mdot
.86 .20929 Mdot
.86 .20946 Mdot
.86 .20955 Mdot
.86 .20966 Mdot
.86 .20993 Mdot
.86 .20994 Mdot
.86 .21132 Mdot
.86 .21196 Mdot
.86 .21238 Mdot
.86 .21257 Mdot
.86 .21294 Mdot
.86 .21379 Mdot
.86 .21416 Mdot
.86 .21484 Mdot
.86 .21533 Mdot
.86 .21665 Mdot
.86 .21727 Mdot
.86 .21777 Mdot
.86 .22053 Mdot
.86 .22074 Mdot
.86 .22085 Mdot
.86 .22092 Mdot
.86 .22101 Mdot
.86 .22164 Mdot
.86 .2228 Mdot
.86 .22288 Mdot
.86 .22348 Mdot
.86 .22405 Mdot
.86 .22426 Mdot
.86 .22485 Mdot
.86 .22577 Mdot
.86 .22653 Mdot
.86 .22666 Mdot
.86 .22694 Mdot
.86 .22812 Mdot
.86 .2282 Mdot
.86 .22865 Mdot
.86 .22899 Mdot
.86 .2294 Mdot
.86 .22984 Mdot
.86 .22984 Mdot
.86 .22988 Mdot
.86 .23023 Mdot
.86 .23043 Mdot
.86 .2312 Mdot
.86 .23137 Mdot
.86 .23199 Mdot
.86 .23238 Mdot
.86 .2324 Mdot
.86 .23305 Mdot
.86 .23415 Mdot
.86 .23481 Mdot
.86 .23519 Mdot
.86 .23532 Mdot
.86 .23574 Mdot
.86 .23595 Mdot
.86 .23595 Mdot
.86 .23616 Mdot
.86 .23655 Mdot
.86 .23763 Mdot
.86 .23771 Mdot
.86 .2388 Mdot
.86 .23886 Mdot
.86 .24094 Mdot
.86 .24153 Mdot
.86 .24197 Mdot
.86 .24309 Mdot
.86 .24571 Mdot
.86 .24575 Mdot
.86 .24576 Mdot
.86 .24636 Mdot
.86 .24719 Mdot
.86 .24757 Mdot
.86 .24815 Mdot
.86 .25145 Mdot
.86 .2517 Mdot
.86 .25199 Mdot
.86 .25215 Mdot
.86 .25241 Mdot
.86 .25315 Mdot
.86 .25321 Mdot
.86 .25329 Mdot
.86 .25378 Mdot
.86 .25383 Mdot
.86 .25396 Mdot
.86 .25491 Mdot
.86 .25508 Mdot
.86 .2557 Mdot
.86 .25629 Mdot
.86 .2563 Mdot
.86 .25636 Mdot
.86 .2569 Mdot
.86 .25698 Mdot
.86 .2573 Mdot
.86 .25792 Mdot
.86 .25793 Mdot
.86 .25798 Mdot
.86 .25849 Mdot
.86 .25861 Mdot
.86 .25867 Mdot
.86 .25933 Mdot
.86 .25946 Mdot
.86 .26003 Mdot
.86 .26019 Mdot
.86 .26024 Mdot
.86 .26035 Mdot
.86 .26101 Mdot
.86 .26174 Mdot
.86 .26184 Mdot
.86 .26247 Mdot
.86 .26281 Mdot
.86 .26281 Mdot
.86 .26289 Mdot
.86 .26315 Mdot
.86 .26365 Mdot
.86 .26397 Mdot
.86 .26405 Mdot
.86 .26408 Mdot
.86 .26442 Mdot
.86 .26452 Mdot
.86 .26534 Mdot
.86 .26598 Mdot
.86 .2663 Mdot
.86 .26635 Mdot
.86 .26653 Mdot
.86 .26698 Mdot
.86 .26762 Mdot
.86 .26817 Mdot
.86 .26817 Mdot
.86 .26893 Mdot
.86 .26902 Mdot
.86 .26909 Mdot
.86 .26922 Mdot
.86 .26964 Mdot
.86 .27008 Mdot
.86 .27016 Mdot
.86 .27085 Mdot
.86 .27169 Mdot
.86 .2726 Mdot
.86 .27374 Mdot
.86 .27386 Mdot
.86 .27397 Mdot
.86 .27418 Mdot
.86 .27446 Mdot
.86 .27503 Mdot
.86 .27527 Mdot
.86 .27549 Mdot
.86 .27551 Mdot
.86 .27551 Mdot
.86 .27572 Mdot
.86 .27606 Mdot
.86 .27653 Mdot
.86 .27689 Mdot
.86 .27691 Mdot
.86 .27708 Mdot
.86 .2771 Mdot
.86 .27712 Mdot
.86 .27737 Mdot
.86 .27746 Mdot
.86 .27751 Mdot
.86 .27761 Mdot
.86 .27901 Mdot
.86 .27914 Mdot
.86 .27962 Mdot
.86 .27962 Mdot
.86 .27964 Mdot
.86 .2809 Mdot
.86 .28105 Mdot
.86 .28125 Mdot
.86 .28273 Mdot
.86 .28301 Mdot
.86 .28315 Mdot
.86 .28332 Mdot
.86 .28354 Mdot
.86 .28391 Mdot
.86 .28448 Mdot
.86 .28454 Mdot
.86 .2848 Mdot
.86 .28487 Mdot
.86 .28499 Mdot
.86 .285 Mdot
.86 .28515 Mdot
.86 .28598 Mdot
.86 .28612 Mdot
.86 .28669 Mdot
.86 .28735 Mdot
.86 .28738 Mdot
.86 .28777 Mdot
.86 .28801 Mdot
.86 .28908 Mdot
.86 .28946 Mdot
.86 .2899 Mdot
.86 .29042 Mdot
.86 .29071 Mdot
.86 .2909 Mdot
.86 .29126 Mdot
.86 .29173 Mdot
.86 .29173 Mdot
.86 .29182 Mdot
.86 .29186 Mdot
.86 .29205 Mdot
.86 .2923 Mdot
.86 .2927 Mdot
.86 .29277 Mdot
.86 .29299 Mdot
.86 .29309 Mdot
.86 .29379 Mdot
.86 .2943 Mdot
.86 .29437 Mdot
.86 .29449 Mdot
.86 .29495 Mdot
.86 .2951 Mdot
.86 .29526 Mdot
.86 .29549 Mdot
.86 .2955 Mdot
.86 .29604 Mdot
.86 .29648 Mdot
.86 .2971 Mdot
.86 .29712 Mdot
.86 .29797 Mdot
.86 .29836 Mdot
.86 .29865 Mdot
.86 .2988 Mdot
.86 .29895 Mdot
.86 .29979 Mdot
.86 .30081 Mdot
.86 .30099 Mdot
.86 .30243 Mdot
.86 .30277 Mdot
.86 .30301 Mdot
.86 .30309 Mdot
.86 .30317 Mdot
.86 .30325 Mdot
.86 .30337 Mdot
.86 .30372 Mdot
.86 .30427 Mdot
.86 .30493 Mdot
.86 .30499 Mdot
.86 .30504 Mdot
.86 .30541 Mdot
.86 .30575 Mdot
.86 .30578 Mdot
.86 .30619 Mdot
.86 .30773 Mdot
.86 .30791 Mdot
.86 .30826 Mdot
.86 .30834 Mdot
.86 .30862 Mdot
.86 .30879 Mdot
.86 .30948 Mdot
.86 .30977 Mdot
.86 .30993 Mdot
.86 .30995 Mdot
.86 .31043 Mdot
.86 .31068 Mdot
.86 .31112 Mdot
.86 .31125 Mdot
.86 .31165 Mdot
.86 .31178 Mdot
.86 .31272 Mdot
.86 .31297 Mdot
.86 .31324 Mdot
.86 .31374 Mdot
.86 .31451 Mdot
.86 .31458 Mdot
.86 .31475 Mdot
.86 .31477 Mdot
.86 .31479 Mdot
.86 .31526 Mdot
.86 .31652 Mdot
.86 .31675 Mdot
.86 .31734 Mdot
.86 .31751 Mdot
.86 .31836 Mdot
.86 .31873 Mdot
.86 .31887 Mdot
.86 .31938 Mdot
.86 .31979 Mdot
.86 .31993 Mdot
.86 .32155 Mdot
.86 .32163 Mdot
.86 .32166 Mdot
.86 .32198 Mdot
.86 .32199 Mdot
.86 .32206 Mdot
.86 .3222 Mdot
.86 .32267 Mdot
.86 .32306 Mdot
.86 .32314 Mdot
.86 .32367 Mdot
.86 .32388 Mdot
.86 .32408 Mdot
.86 .32439 Mdot
.86 .32492 Mdot
.86 .3251 Mdot
.86 .3261 Mdot
.86 .32626 Mdot
.86 .3263 Mdot
.86 .32701 Mdot
.86 .32705 Mdot
.86 .32718 Mdot
.86 .32745 Mdot
.86 .3275 Mdot
.86 .32835 Mdot
.86 .32856 Mdot
.86 .32909 Mdot
.86 .32932 Mdot
.86 .33014 Mdot
.86 .33125 Mdot
.86 .33132 Mdot
.86 .33135 Mdot
.86 .33141 Mdot
.86 .33224 Mdot
.86 .33243 Mdot
.86 .33251 Mdot
.86 .33302 Mdot
.86 .33332 Mdot
.86 .33337 Mdot
.86 .33381 Mdot
.86 .33384 Mdot
.86 .33399 Mdot
.86 .3341 Mdot
.86 .33439 Mdot
.86 .33512 Mdot
.86 .33525 Mdot
.86 .33526 Mdot
.86 .33646 Mdot
.86 .33646 Mdot
.86 .33653 Mdot
.86 .33703 Mdot
.86 .33705 Mdot
.86 .33742 Mdot
.86 .33744 Mdot
.86 .33887 Mdot
.86 .33998 Mdot
.86 .34058 Mdot
.86 .3417 Mdot
.86 .34255 Mdot
.86 .34292 Mdot
.86 .34313 Mdot
.86 .34334 Mdot
.86 .34336 Mdot
.86 .34354 Mdot
.86 .34357 Mdot
.86 .34408 Mdot
.86 .34414 Mdot
.86 .3446 Mdot
.86 .34518 Mdot
.86 .34556 Mdot
.86 .34593 Mdot
.86 .34596 Mdot
.86 .34608 Mdot
.86 .34639 Mdot
.86 .34716 Mdot
.86 .34735 Mdot
.86 .34761 Mdot
.86 .348 Mdot
.86 .34802 Mdot
.86 .34826 Mdot
.86 .34885 Mdot
.86 .34927 Mdot
.86 .34938 Mdot
.86 .34967 Mdot
.86 .34982 Mdot
.86 .34983 Mdot
.86 .34983 Mdot
.86 .35002 Mdot
.86 .35036 Mdot
.86 .35049 Mdot
.86 .35051 Mdot
.86 .35054 Mdot
.86 .3517 Mdot
.86 .35288 Mdot
.86 .35337 Mdot
.86 .35383 Mdot
.86 .35398 Mdot
.86 .35442 Mdot
.86 .3547 Mdot
.86 .35503 Mdot
.86 .35531 Mdot
.86 .35567 Mdot
.86 .35621 Mdot
.86 .35645 Mdot
.86 .35713 Mdot
.86 .35713 Mdot
.86 .35775 Mdot
.86 .35804 Mdot
.86 .35844 Mdot
.86 .35893 Mdot
.86 .35913 Mdot
.86 .35977 Mdot
.86 .3598 Mdot
.86 .3602 Mdot
.86 .36102 Mdot
.86 .36108 Mdot
.86 .36172 Mdot
.86 .36191 Mdot
.86 .36205 Mdot
.86 .36258 Mdot
.86 .36311 Mdot
.86 .36397 Mdot
.86 .36403 Mdot
.86 .36554 Mdot
.86 .36635 Mdot
.86 .36653 Mdot
.86 .36693 Mdot
.86 .3673 Mdot
.86 .36802 Mdot
.86 .36872 Mdot
.86 .36907 Mdot
.86 .36927 Mdot
.86 .36939 Mdot
.86 .36954 Mdot
.86 .3696 Mdot
.86 .36973 Mdot
.86 .36998 Mdot
.86 .37002 Mdot
.86 .37003 Mdot
.86 .37043 Mdot
.86 .37062 Mdot
.86 .37262 Mdot
.86 .37269 Mdot
.86 .37276 Mdot
.86 .37318 Mdot
.86 .37379 Mdot
.86 .37433 Mdot
.86 .37442 Mdot
.86 .37476 Mdot
.86 .37495 Mdot
.86 .37495 Mdot
.86 .37513 Mdot
.86 .37519 Mdot
.86 .37558 Mdot
.86 .37615 Mdot
.86 .3765 Mdot
.86 .3768 Mdot
.86 .37711 Mdot
.86 .37719 Mdot
.86 .37773 Mdot
.86 .37809 Mdot
.86 .37832 Mdot
.86 .37874 Mdot
.86 .37876 Mdot
.86 .37897 Mdot
.86 .37904 Mdot
.86 .37926 Mdot
.86 .37975 Mdot
.86 .38026 Mdot
.86 .38073 Mdot
.86 .38086 Mdot
.86 .3811 Mdot
.86 .38163 Mdot
.86 .38178 Mdot
.86 .38178 Mdot
.86 .38192 Mdot
.86 .38268 Mdot
.86 .38326 Mdot
.86 .38352 Mdot
.86 .38397 Mdot
.86 .38417 Mdot
.86 .38451 Mdot
.86 .38472 Mdot
.86 .38473 Mdot
.86 .3848 Mdot
.86 .3854 Mdot
.86 .38544 Mdot
.86 .38552 Mdot
.86 .3857 Mdot
.86 .38575 Mdot
.86 .38656 Mdot
.86 .38667 Mdot
.86 .38708 Mdot
.86 .38737 Mdot
.86 .38842 Mdot
.86 .38849 Mdot
.86 .38899 Mdot
.86 .38909 Mdot
.86 .38914 Mdot
.86 .38968 Mdot
.86 .38988 Mdot
.86 .39025 Mdot
.86 .39127 Mdot
.86 .39135 Mdot
.86 .39166 Mdot
.86 .39181 Mdot
.86 .39188 Mdot
.86 .39215 Mdot
.86 .3929 Mdot
.86 .39303 Mdot
.86 .39304 Mdot
.86 .39328 Mdot
.86 .39341 Mdot
.86 .39394 Mdot
.86 .39398 Mdot
.86 .39416 Mdot
.86 .39434 Mdot
.86 .39487 Mdot
.86 .3951 Mdot
.86 .39524 Mdot
.86 .39524 Mdot
.86 .39555 Mdot
.86 .3956 Mdot
.86 .39627 Mdot
.86 .39655 Mdot
.86 .39787 Mdot
.86 .3981 Mdot
.86 .3981 Mdot
.86 .39813 Mdot
.86 .39827 Mdot
.86 .39835 Mdot
.86 .39927 Mdot
.86 .39969 Mdot
.86 .3999 Mdot
.86 .40013 Mdot
.86 .40024 Mdot
.86 .40071 Mdot
.86 .40159 Mdot
.86 .40243 Mdot
.86 .40282 Mdot
.86 .40293 Mdot
.86 .4033 Mdot
.86 .40334 Mdot
.86 .40381 Mdot
.86 .40405 Mdot
.86 .40444 Mdot
.86 .40484 Mdot
.86 .40507 Mdot
.86 .4056 Mdot
.86 .40599 Mdot
.86 .40614 Mdot
.86 .40666 Mdot
.86 .40718 Mdot
.86 .40752 Mdot
.86 .40779 Mdot
.86 .40875 Mdot
.86 .40943 Mdot
.86 .40954 Mdot
.86 .40984 Mdot
.86 .40984 Mdot
.86 .41017 Mdot
.86 .41076 Mdot
.86 .41091 Mdot
.86 .41184 Mdot
.86 .41202 Mdot
.86 .4121 Mdot
.86 .41211 Mdot
.86 .41289 Mdot
.86 .41315 Mdot
.86 .41362 Mdot
.86 .41374 Mdot
.86 .41386 Mdot
.86 .41457 Mdot
.86 .41522 Mdot
.86 .41622 Mdot
.86 .41729 Mdot
.86 .41762 Mdot
.86 .41831 Mdot
.86 .41832 Mdot
.86 .4184 Mdot
.86 .41882 Mdot
.86 .41905 Mdot
.86 .41916 Mdot
.86 .41941 Mdot
.86 .41962 Mdot
.86 .41996 Mdot
.86 .42055 Mdot
.86 .42177 Mdot
.86 .4219 Mdot
.86 .42233 Mdot
.86 .42282 Mdot
.86 .42301 Mdot
.86 .42311 Mdot
.86 .42355 Mdot
.86 .42364 Mdot
.86 .42433 Mdot
.86 .42463 Mdot
.86 .42482 Mdot
.86 .42493 Mdot
.86 .42506 Mdot
.86 .42591 Mdot
.86 .42599 Mdot
.86 .42603 Mdot
.86 .42622 Mdot
.86 .42784 Mdot
.86 .42814 Mdot
.86 .42864 Mdot
.86 .42873 Mdot
.86 .42921 Mdot
.86 .43022 Mdot
.86 .43023 Mdot
.86 .43024 Mdot
.86 .43034 Mdot
.86 .43112 Mdot
.86 .43127 Mdot
.86 .43142 Mdot
.86 .43197 Mdot
.86 .43204 Mdot
.86 .43227 Mdot
.86 .4326 Mdot
.86 .43303 Mdot
.86 .43304 Mdot
.86 .43313 Mdot
.86 .4337 Mdot
.86 .4338 Mdot
.86 .43401 Mdot
.86 .43422 Mdot
.86 .43432 Mdot
.86 .43521 Mdot
.86 .43546 Mdot
.86 .43567 Mdot
.86 .43591 Mdot
.86 .43595 Mdot
.86 .43665 Mdot
.86 .43692 Mdot
.86 .43702 Mdot
.86 .43706 Mdot
.86 .4372 Mdot
.86 .4374 Mdot
.86 .43824 Mdot
.86 .43834 Mdot
.86 .43894 Mdot
.86 .43942 Mdot
.86 .4396 Mdot
.86 .43977 Mdot
.86 .44049 Mdot
.86 .4405 Mdot
.86 .44086 Mdot
.86 .44143 Mdot
.86 .44144 Mdot
.86 .44157 Mdot
.86 .44166 Mdot
.86 .44202 Mdot
.86 .44209 Mdot
.86 .44289 Mdot
.86 .44302 Mdot
.86 .44344 Mdot
.86 .44357 Mdot
.86 .44362 Mdot
.86 .44363 Mdot
.86 .4441 Mdot
.86 .44421 Mdot
.86 .44438 Mdot
.86 .44468 Mdot
.86 .44516 Mdot
.86 .44578 Mdot
.86 .44592 Mdot
.86 .44617 Mdot
.86 .44688 Mdot
.86 .44697 Mdot
.86 .44745 Mdot
.86 .44753 Mdot
.86 .4478 Mdot
.86 .44784 Mdot
.86 .44861 Mdot
.86 .44972 Mdot
.86 .44983 Mdot
.86 .45066 Mdot
.86 .45066 Mdot
.86 .45183 Mdot
.86 .45189 Mdot
.86 .45192 Mdot
.86 .45197 Mdot
.86 .45212 Mdot
.86 .45214 Mdot
.86 .45224 Mdot
.86 .45246 Mdot
.86 .45273 Mdot
.86 .45305 Mdot
.86 .45306 Mdot
.86 .45307 Mdot
.86 .45319 Mdot
.86 .45333 Mdot
.86 .45382 Mdot
.86 .45395 Mdot
.86 .45401 Mdot
.86 .45408 Mdot
.86 .45475 Mdot
.86 .45527 Mdot
.86 .45576 Mdot
.86 .45616 Mdot
.86 .45621 Mdot
.86 .45671 Mdot
.86 .45688 Mdot
.86 .45732 Mdot
.86 .45764 Mdot
.86 .45827 Mdot
.86 .45897 Mdot
.86 .4595 Mdot
.86 .45972 Mdot
.86 .45976 Mdot
.86 .46024 Mdot
.86 .46039 Mdot
.86 .46044 Mdot
.86 .46063 Mdot
.86 .461 Mdot
.86 .46106 Mdot
.86 .46148 Mdot
.86 .46206 Mdot
.86 .46246 Mdot
.86 .46284 Mdot
.86 .46288 Mdot
.86 .46295 Mdot
.86 .46324 Mdot
.86 .46327 Mdot
.86 .46328 Mdot
.86 .46364 Mdot
.86 .46382 Mdot
.86 .46387 Mdot
.86 .46419 Mdot
.86 .46422 Mdot
.86 .46423 Mdot
.86 .46457 Mdot
.86 .46493 Mdot
.86 .46503 Mdot
.86 .46558 Mdot
.86 .46566 Mdot
.86 .46569 Mdot
.86 .46597 Mdot
.86 .46602 Mdot
.86 .46606 Mdot
.86 .46648 Mdot
.86 .46663 Mdot
.86 .46673 Mdot
.86 .46689 Mdot
.86 .46704 Mdot
.86 .46896 Mdot
.86 .4693 Mdot
.86 .46952 Mdot
.86 .47 Mdot
.86 .47035 Mdot
.86 .47035 Mdot
.86 .47038 Mdot
.86 .4719 Mdot
.86 .47255 Mdot
.86 .47281 Mdot
.86 .47315 Mdot
.86 .47436 Mdot
.86 .4744 Mdot
.86 .47503 Mdot
.86 .47508 Mdot
.86 .47571 Mdot
.86 .47593 Mdot
.86 .47605 Mdot
.86 .47605 Mdot
.86 .47618 Mdot
.86 .47642 Mdot
.86 .47649 Mdot
.86 .47672 Mdot
.86 .4771 Mdot
.86 .47774 Mdot
.86 .47811 Mdot
.86 .47813 Mdot
.86 .47836 Mdot
.86 .47871 Mdot
.86 .47881 Mdot
.86 .47926 Mdot
.86 .47938 Mdot
.86 .47958 Mdot
.86 .47961 Mdot
.86 .47961 Mdot
.86 .47986 Mdot
.86 .4801 Mdot
.86 .4803 Mdot
.86 .48056 Mdot
.86 .4806 Mdot
.86 .48129 Mdot
.86 .48145 Mdot
.86 .48153 Mdot
.86 .48197 Mdot
.86 .48251 Mdot
.86 .48285 Mdot
.86 .48297 Mdot
.86 .4833 Mdot
.86 .48365 Mdot
.86 .4837 Mdot
.86 .48437 Mdot
.86 .48474 Mdot
.86 .48479 Mdot
.86 .48483 Mdot
.86 .4849 Mdot
.86 .48502 Mdot
.86 .48662 Mdot
.86 .48691 Mdot
.86 .48727 Mdot
.86 .48804 Mdot
.86 .48833 Mdot
.86 .48872 Mdot
.86 .48893 Mdot
.86 .48943 Mdot
.86 .48964 Mdot
.86 .48976 Mdot
.86 .49 Mdot
.86 .49037 Mdot
.86 .49117 Mdot
.86 .49118 Mdot
.86 .49134 Mdot
.86 .4914 Mdot
.86 .49146 Mdot
.86 .49155 Mdot
.86 .49173 Mdot
.86 .49201 Mdot
.86 .49215 Mdot
.86 .49224 Mdot
.86 .4923 Mdot
.86 .49284 Mdot
.86 .49298 Mdot
.86 .49335 Mdot
.86 .49352 Mdot
.86 .49353 Mdot
.86 .49359 Mdot
.86 .49386 Mdot
.86 .49473 Mdot
.86 .49559 Mdot
.86 .4956 Mdot
.86 .49572 Mdot
.86 .4959 Mdot
.86 .49592 Mdot
.86 .49672 Mdot
.86 .49681 Mdot
.86 .49698 Mdot
.86 .49726 Mdot
.86 .49735 Mdot
.86 .49765 Mdot
.86 .49766 Mdot
.86 .49768 Mdot
.86 .49806 Mdot
.86 .49859 Mdot
.86 .49897 Mdot
.86 .4991 Mdot
.86 .49936 Mdot
.86 .49976 Mdot
.86 .50043 Mdot
.86 .50045 Mdot
.86 .50058 Mdot
.86 .50082 Mdot
.86 .50093 Mdot
.86 .50096 Mdot
.86 .50151 Mdot
.86 .50156 Mdot
.86 .50169 Mdot
.86 .50191 Mdot
.86 .50258 Mdot
.86 .50309 Mdot
.86 .50334 Mdot
.86 .5036 Mdot
.86 .50449 Mdot
.86 .50472 Mdot
.86 .50504 Mdot
.86 .50543 Mdot
.86 .5063 Mdot
.86 .50654 Mdot
.86 .5068 Mdot
.86 .50711 Mdot
.86 .50718 Mdot
.86 .50865 Mdot
.86 .50893 Mdot
.86 .50958 Mdot
.86 .50995 Mdot
.86 .51017 Mdot
.86 .51034 Mdot
.86 .51058 Mdot
.86 .51071 Mdot
.86 .51085 Mdot
.86 .511 Mdot
.86 .5112 Mdot
.86 .51181 Mdot
.86 .51251 Mdot
.86 .51275 Mdot
.86 .51332 Mdot
.86 .51336 Mdot
.86 .51338 Mdot
.86 .51368 Mdot
.86 .51381 Mdot
.86 .51388 Mdot
.86 .51399 Mdot
.86 .51408 Mdot
.86 .5147 Mdot
.86 .51513 Mdot
.86 .5153 Mdot
.86 .51534 Mdot
.86 .51599 Mdot
.86 .51606 Mdot
.86 .51645 Mdot
.86 .51688 Mdot
.86 .51851 Mdot
.86 .51869 Mdot
.86 .51872 Mdot
.86 .519 Mdot
.86 .51941 Mdot
.86 .51962 Mdot
.86 .51964 Mdot
.86 .51975 Mdot
.86 .52024 Mdot
.86 .52039 Mdot
.86 .52053 Mdot
.86 .52082 Mdot
.86 .52165 Mdot
.86 .52168 Mdot
.86 .5217 Mdot
.86 .52195 Mdot
.862 .15581 Mdot
.862 .15594 Mdot
.862 .15682 Mdot
.862 .15732 Mdot
.862 .15741 Mdot
.862 .15759 Mdot
.862 .1576 Mdot
.862 .15796 Mdot
.862 .15864 Mdot
.862 .15868 Mdot
.862 .15947 Mdot
.862 .1596 Mdot
.862 .16001 Mdot
.862 .16029 Mdot
.862 .16048 Mdot
.862 .16076 Mdot
.862 .16112 Mdot
.862 .16112 Mdot
.862 .16154 Mdot
.862 .16181 Mdot
.862 .16217 Mdot
.862 .16272 Mdot
.862 .16448 Mdot
.862 .16491 Mdot
.862 .16506 Mdot
.862 .16533 Mdot
.862 .16585 Mdot
.862 .16601 Mdot
.862 .16711 Mdot
.862 .1675 Mdot
.862 .16763 Mdot
.862 .16769 Mdot
.862 .16793 Mdot
.862 .16894 Mdot
.862 .16948 Mdot
.862 .17054 Mdot
.862 .17254 Mdot
.862 .17306 Mdot
.862 .17363 Mdot
.862 .17405 Mdot
.862 .17433 Mdot
.862 .17462 Mdot
.862 .17539 Mdot
.862 .17592 Mdot
.862 .17639 Mdot
.862 .17664 Mdot
.862 .1768 Mdot
.862 .17691 Mdot
.862 .17803 Mdot
.862 .17817 Mdot
.862 .17843 Mdot
.862 .17934 Mdot
.862 .17993 Mdot
.862 .18041 Mdot
.862 .18069 Mdot
.862 .18078 Mdot
.862 .18087 Mdot
.862 .18108 Mdot
.862 .18134 Mdot
.862 .18185 Mdot
.862 .182 Mdot
.862 .18211 Mdot
.862 .1828 Mdot
.862 .18301 Mdot
.862 .18339 Mdot
.862 .18371 Mdot
.862 .1845 Mdot
.862 .18471 Mdot
.862 .18486 Mdot
.862 .18496 Mdot
.862 .18512 Mdot
.862 .18525 Mdot
.862 .18565 Mdot
.862 .18616 Mdot
.862 .18651 Mdot
.862 .18817 Mdot
.862 .18828 Mdot
.862 .18958 Mdot
.862 .19038 Mdot
.862 .1911 Mdot
.862 .19141 Mdot
.862 .19156 Mdot
.862 .19163 Mdot
.862 .19178 Mdot
.862 .19291 Mdot
.862 .19295 Mdot
.862 .19412 Mdot
.862 .19425 Mdot
.862 .19497 Mdot
.862 .19499 Mdot
.862 .19524 Mdot
.862 .1953 Mdot
.862 .1953 Mdot
.862 .19563 Mdot
.862 .19694 Mdot
.862 .19761 Mdot
.862 .19822 Mdot
.862 .1983 Mdot
.862 .20026 Mdot
.862 .20069 Mdot
.862 .20071 Mdot
.862 .2009 Mdot
.862 .20126 Mdot
.862 .20128 Mdot
.862 .20129 Mdot
.862 .20138 Mdot
.862 .20197 Mdot
.862 .20208 Mdot
.862 .20209 Mdot
.862 .20262 Mdot
.862 .20337 Mdot
.862 .20341 Mdot
.862 .20364 Mdot
.862 .20364 Mdot
.862 .20367 Mdot
.862 .20536 Mdot
.862 .20579 Mdot
.862 .20597 Mdot
.862 .2085 Mdot
.862 .20884 Mdot
.862 .20956 Mdot
.862 .21069 Mdot
.862 .21089 Mdot
.862 .21209 Mdot
.862 .21246 Mdot
.862 .2128 Mdot
.862 .21336 Mdot
.862 .21393 Mdot
.862 .21395 Mdot
.862 .21457 Mdot
.862 .21459 Mdot
.862 .21478 Mdot
.862 .21532 Mdot
.862 .21538 Mdot
.862 .21549 Mdot
.862 .21639 Mdot
.862 .21751 Mdot
.862 .21863 Mdot
.862 .21903 Mdot
.862 .22045 Mdot
.862 .22138 Mdot
.862 .22157 Mdot
.862 .22257 Mdot
.862 .22292 Mdot
.862 .22314 Mdot
.862 .2259 Mdot
.862 .22676 Mdot
.862 .22856 Mdot
.862 .22877 Mdot
.862 .22885 Mdot
.862 .22907 Mdot
.862 .2313 Mdot
.862 .23136 Mdot
.862 .23139 Mdot
.862 .23234 Mdot
.862 .23243 Mdot
.862 .23286 Mdot
.862 .23302 Mdot
.862 .23334 Mdot
.862 .23412 Mdot
.862 .2342 Mdot
.862 .23429 Mdot
.862 .23437 Mdot
.862 .23479 Mdot
.862 .23591 Mdot
.862 .23601 Mdot
.862 .23709 Mdot
.862 .23716 Mdot
.862 .23783 Mdot
.862 .23816 Mdot
.862 .23836 Mdot
.862 .23841 Mdot
.862 .23845 Mdot
.862 .23853 Mdot
.862 .23858 Mdot
.862 .23878 Mdot
.862 .23997 Mdot
.862 .2407 Mdot
.862 .24083 Mdot
.862 .24115 Mdot
.862 .24154 Mdot
.862 .24496 Mdot
.862 .24499 Mdot
.862 .24519 Mdot
.862 .24639 Mdot
.862 .2464 Mdot
.862 .24653 Mdot
.862 .24671 Mdot
.862 .24798 Mdot
.862 .24827 Mdot
.862 .24892 Mdot
.862 .24903 Mdot
.862 .24956 Mdot
.862 .25094 Mdot
.862 .25138 Mdot
.862 .25191 Mdot
.862 .25308 Mdot
.862 .25325 Mdot
.862 .25352 Mdot
.862 .25447 Mdot
.862 .25464 Mdot
.862 .25473 Mdot
.862 .2552 Mdot
.862 .25523 Mdot
.862 .25656 Mdot
.862 .25706 Mdot
.862 .25739 Mdot
.862 .25742 Mdot
.862 .25794 Mdot
.862 .25796 Mdot
.862 .25819 Mdot
.862 .25836 Mdot
.862 .25913 Mdot
.862 .25971 Mdot
.862 .26003 Mdot
.862 .26049 Mdot
.862 .26057 Mdot
.862 .26072 Mdot
.862 .26103 Mdot
.862 .26106 Mdot
.862 .26142 Mdot
.862 .26158 Mdot
.862 .26167 Mdot
.862 .26223 Mdot
.862 .26284 Mdot
.862 .26286 Mdot
.862 .2629 Mdot
.862 .26384 Mdot
.862 .26399 Mdot
.862 .26421 Mdot
.862 .26427 Mdot
.862 .26434 Mdot
.862 .26443 Mdot
.862 .26449 Mdot
.862 .2652 Mdot
.862 .26531 Mdot
.862 .26569 Mdot
.862 .26602 Mdot
.862 .26602 Mdot
.862 .2665 Mdot
.862 .26696 Mdot
.862 .2671 Mdot
.862 .26712 Mdot
.862 .26713 Mdot
.862 .26738 Mdot
.862 .26785 Mdot
.862 .26831 Mdot
.862 .26892 Mdot
.862 .26922 Mdot
.862 .26932 Mdot
.862 .26987 Mdot
.862 .27129 Mdot
.862 .2729 Mdot
.862 .27305 Mdot
.862 .27343 Mdot
.862 .27364 Mdot
.862 .27386 Mdot
.862 .27392 Mdot
.862 .27438 Mdot
.862 .27509 Mdot
.862 .27527 Mdot
.862 .27538 Mdot
.862 .27555 Mdot
.862 .27626 Mdot
.862 .27672 Mdot
.862 .27729 Mdot
.862 .27744 Mdot
.862 .27808 Mdot
.862 .27812 Mdot
.862 .27834 Mdot
.862 .27844 Mdot
.862 .27886 Mdot
.862 .27945 Mdot
.862 .2806 Mdot
.862 .28084 Mdot
.862 .28153 Mdot
.862 .2816 Mdot
.862 .28162 Mdot
.862 .28167 Mdot
.862 .2821 Mdot
.862 .2825 Mdot
.862 .28336 Mdot
.862 .28347 Mdot
.862 .28353 Mdot
.862 .28488 Mdot
.862 .2849 Mdot
.862 .28587 Mdot
.862 .2868 Mdot
.862 .28699 Mdot
.862 .28732 Mdot
.862 .28739 Mdot
.862 .2877 Mdot
.862 .28869 Mdot
.862 .28941 Mdot
.862 .28943 Mdot
.862 .28961 Mdot
.862 .28967 Mdot
.862 .28989 Mdot
.862 .28989 Mdot
.862 .29009 Mdot
.862 .29027 Mdot
.862 .29039 Mdot
.862 .29092 Mdot
.862 .29137 Mdot
.862 .29161 Mdot
.862 .29172 Mdot
.862 .29263 Mdot
.862 .29336 Mdot
.862 .29344 Mdot
.862 .29388 Mdot
.862 .29415 Mdot
.862 .29416 Mdot
.862 .29428 Mdot
.862 .29434 Mdot
.862 .29435 Mdot
.862 .29616 Mdot
.862 .29618 Mdot
.862 .29627 Mdot
.862 .29627 Mdot
.862 .29651 Mdot
.862 .29697 Mdot
.862 .29758 Mdot
.862 .29782 Mdot
.862 .29809 Mdot
.862 .29852 Mdot
.862 .29856 Mdot
.862 .29912 Mdot
.862 .29924 Mdot
.862 .29954 Mdot
.862 .29959 Mdot
.862 .29964 Mdot
.862 .29973 Mdot
.862 .30037 Mdot
.862 .30064 Mdot
.862 .30086 Mdot
.862 .30102 Mdot
.862 .30105 Mdot
.862 .30108 Mdot
.862 .30117 Mdot
.862 .30133 Mdot
.862 .30153 Mdot
.862 .30197 Mdot
.862 .30239 Mdot
.862 .30253 Mdot
.862 .30268 Mdot
.862 .30286 Mdot
.862 .30312 Mdot
.862 .30331 Mdot
.862 .30345 Mdot
.862 .30365 Mdot
.862 .30382 Mdot
.862 .30449 Mdot
.862 .30485 Mdot
.862 .30503 Mdot
.862 .30537 Mdot
.862 .30551 Mdot
.862 .30602 Mdot
.862 .30607 Mdot
.862 .30624 Mdot
.862 .30634 Mdot
.862 .30653 Mdot
.862 .30712 Mdot
.862 .30731 Mdot
.862 .30743 Mdot
.862 .30766 Mdot
.862 .30778 Mdot
.862 .30804 Mdot
.862 .30817 Mdot
.862 .30822 Mdot
.862 .30848 Mdot
.862 .30873 Mdot
.862 .30885 Mdot
.862 .30891 Mdot
.862 .30941 Mdot
.862 .30945 Mdot
.862 .31028 Mdot
.862 .31045 Mdot
.862 .31055 Mdot
.862 .3109 Mdot
.862 .31145 Mdot
.862 .31152 Mdot
.862 .31173 Mdot
.862 .31187 Mdot
.862 .313 Mdot
.862 .31375 Mdot
.862 .31392 Mdot
.862 .31394 Mdot
.862 .31617 Mdot
.862 .31695 Mdot
.862 .31704 Mdot
.862 .31747 Mdot
.862 .31756 Mdot
.862 .31845 Mdot
.862 .31871 Mdot
.862 .31879 Mdot
.862 .31909 Mdot
.862 .31922 Mdot
.862 .31933 Mdot
.862 .3196 Mdot
.862 .31972 Mdot
.862 .31998 Mdot
.862 .32192 Mdot
.862 .32197 Mdot
.862 .322 Mdot
.862 .32205 Mdot
.862 .32244 Mdot
.862 .32283 Mdot
.862 .32323 Mdot
.862 .32334 Mdot
.862 .32378 Mdot
.862 .32401 Mdot
.862 .32421 Mdot
.862 .32424 Mdot
.862 .3249 Mdot
.862 .32525 Mdot
.862 .32527 Mdot
.862 .32547 Mdot
.862 .32551 Mdot
.862 .32569 Mdot
.862 .32594 Mdot
.862 .32604 Mdot
.862 .32605 Mdot
.862 .32661 Mdot
.862 .32682 Mdot
.862 .32841 Mdot
.862 .32888 Mdot
.862 .32971 Mdot
.862 .33002 Mdot
.862 .33033 Mdot
.862 .33108 Mdot
.862 .33121 Mdot
.862 .33252 Mdot
.862 .33382 Mdot
.862 .33442 Mdot
.862 .33459 Mdot
.862 .33534 Mdot
.862 .33536 Mdot
.862 .33537 Mdot
.862 .33569 Mdot
.862 .33572 Mdot
.862 .33629 Mdot
.862 .33632 Mdot
.862 .33635 Mdot
.862 .33638 Mdot
.862 .33652 Mdot
.862 .33693 Mdot
.862 .33731 Mdot
.862 .33754 Mdot
.862 .33765 Mdot
.862 .33773 Mdot
.862 .33775 Mdot
.862 .33826 Mdot
.862 .3385 Mdot
.862 .33866 Mdot
.862 .33995 Mdot
.862 .34002 Mdot
.862 .34042 Mdot
.862 .34042 Mdot
.862 .34047 Mdot
.862 .34149 Mdot
.862 .34228 Mdot
.862 .34273 Mdot
.862 .34282 Mdot
.862 .3432 Mdot
.862 .34323 Mdot
.862 .34338 Mdot
.862 .34339 Mdot
.862 .34413 Mdot
.862 .34445 Mdot
.862 .34471 Mdot
.862 .34516 Mdot
.862 .34629 Mdot
.862 .34642 Mdot
.862 .34646 Mdot
.862 .34679 Mdot
.862 .34703 Mdot
.862 .34734 Mdot
.862 .34739 Mdot
.862 .34748 Mdot
.862 .3488 Mdot
.862 .34939 Mdot
.862 .34966 Mdot
.862 .35063 Mdot
.862 .35082 Mdot
.862 .35257 Mdot
.862 .35291 Mdot
.862 .35421 Mdot
.862 .35498 Mdot
.862 .35563 Mdot
.862 .35622 Mdot
.862 .35717 Mdot
.862 .3572 Mdot
.862 .35764 Mdot
.862 .35816 Mdot
.862 .3582 Mdot
.862 .35832 Mdot
.862 .35881 Mdot
.862 .35926 Mdot
.862 .35931 Mdot
.862 .35962 Mdot
.862 .35974 Mdot
.862 .36015 Mdot
.862 .36048 Mdot
.862 .36056 Mdot
.862 .36059 Mdot
.862 .36066 Mdot
.862 .36085 Mdot
.862 .36092 Mdot
.862 .36164 Mdot
.862 .36231 Mdot
.862 .3624 Mdot
.862 .36245 Mdot
.862 .36314 Mdot
.862 .36433 Mdot
.862 .36488 Mdot
.862 .36585 Mdot
.862 .36601 Mdot
.862 .36627 Mdot
.862 .36646 Mdot
.862 .3666 Mdot
.862 .36683 Mdot
.862 .36695 Mdot
.862 .36696 Mdot
.862 .3671 Mdot
.862 .36866 Mdot
.862 .3694 Mdot
.862 .37004 Mdot
.862 .37067 Mdot
.862 .37088 Mdot
.862 .37101 Mdot
.862 .37133 Mdot
.862 .37242 Mdot
.862 .37283 Mdot
.862 .37306 Mdot
.862 .3735 Mdot
.862 .37365 Mdot
.862 .37403 Mdot
.862 .37407 Mdot
.862 .37409 Mdot
.862 .37428 Mdot
.862 .37438 Mdot
.862 .37517 Mdot
.862 .37556 Mdot
.862 .3767 Mdot
.862 .3777 Mdot
.862 .37808 Mdot
.862 .37881 Mdot
.862 .37884 Mdot
.862 .37895 Mdot
.862 .3792 Mdot
.862 .37947 Mdot
.862 .3797 Mdot
.862 .38029 Mdot
.862 .38067 Mdot
.862 .38202 Mdot
.862 .38282 Mdot
.862 .38296 Mdot
.862 .38319 Mdot
.862 .38338 Mdot
.862 .38345 Mdot
.862 .38375 Mdot
.862 .38388 Mdot
.862 .38426 Mdot
.862 .38473 Mdot
.862 .38498 Mdot
.862 .3856 Mdot
.862 .38632 Mdot
.862 .38645 Mdot
.862 .38726 Mdot
.862 .3875 Mdot
.862 .38754 Mdot
.862 .38782 Mdot
.862 .3879 Mdot
.862 .38791 Mdot
.862 .38804 Mdot
.862 .38808 Mdot
.862 .38811 Mdot
.862 .38813 Mdot
.862 .38821 Mdot
.862 .38821 Mdot
.862 .38826 Mdot
.862 .38842 Mdot
.862 .38844 Mdot
.862 .38859 Mdot
.862 .38906 Mdot
.862 .38913 Mdot
.862 .38955 Mdot
.862 .3899 Mdot
.862 .39005 Mdot
.862 .3908 Mdot
.862 .39095 Mdot
.862 .39108 Mdot
.862 .39116 Mdot
.862 .39162 Mdot
.862 .39241 Mdot
.862 .39297 Mdot
.862 .3931 Mdot
.862 .39326 Mdot
.862 .3934 Mdot
.862 .39347 Mdot
.862 .39391 Mdot
.862 .39413 Mdot
.862 .39471 Mdot
.862 .39537 Mdot
.862 .3956 Mdot
.862 .39605 Mdot
.862 .39611 Mdot
.862 .39622 Mdot
.862 .39623 Mdot
.862 .39657 Mdot
.862 .39695 Mdot
.862 .3972 Mdot
.862 .39808 Mdot
.862 .39821 Mdot
.862 .39857 Mdot
.862 .39937 Mdot
.862 .39993 Mdot
.862 .40028 Mdot
.862 .40036 Mdot
.862 .40043 Mdot
.862 .40057 Mdot
.862 .40065 Mdot
.862 .40091 Mdot
.862 .401 Mdot
.862 .40156 Mdot
.862 .40257 Mdot
.862 .40297 Mdot
.862 .40306 Mdot
.862 .40345 Mdot
.862 .40386 Mdot
.862 .40405 Mdot
.862 .40412 Mdot
.862 .40431 Mdot
.862 .40455 Mdot
.862 .40509 Mdot
.862 .40537 Mdot
.862 .40576 Mdot
.862 .40602 Mdot
.862 .40775 Mdot
.862 .40972 Mdot
.862 .41039 Mdot
.862 .41166 Mdot
.862 .41171 Mdot
.862 .41174 Mdot
.862 .41192 Mdot
.862 .41206 Mdot
.862 .41225 Mdot
.862 .41228 Mdot
.862 .41235 Mdot
.862 .413 Mdot
.862 .41327 Mdot
.862 .41403 Mdot
.862 .41413 Mdot
.862 .41414 Mdot
.862 .41436 Mdot
.862 .41441 Mdot
.862 .41468 Mdot
.862 .41514 Mdot
.862 .41686 Mdot
.862 .41701 Mdot
.862 .41736 Mdot
.862 .41756 Mdot
.862 .41778 Mdot
.862 .41815 Mdot
.862 .41848 Mdot
.862 .41868 Mdot
.862 .41923 Mdot
.862 .41958 Mdot
.862 .42034 Mdot
.862 .42161 Mdot
.862 .42196 Mdot
.862 .42272 Mdot
.862 .42364 Mdot
.862 .4243 Mdot
.862 .42454 Mdot
.862 .42455 Mdot
.862 .42476 Mdot
.862 .42515 Mdot
.862 .4254 Mdot
.862 .42566 Mdot
.862 .42573 Mdot
.862 .42596 Mdot
.862 .42618 Mdot
.862 .42641 Mdot
.862 .42645 Mdot
.862 .42805 Mdot
.862 .42812 Mdot
.862 .42835 Mdot
.862 .4285 Mdot
.862 .42907 Mdot
.862 .42931 Mdot
.862 .42937 Mdot
.862 .43112 Mdot
.862 .43166 Mdot
.862 .43231 Mdot
.862 .43239 Mdot
.862 .43252 Mdot
.862 .43256 Mdot
.862 .43308 Mdot
.862 .43314 Mdot
.862 .43372 Mdot
.862 .43403 Mdot
.862 .43407 Mdot
.862 .43446 Mdot
.862 .43476 Mdot
.862 .43496 Mdot
.862 .43507 Mdot
.862 .43541 Mdot
.862 .43552 Mdot
.862 .43558 Mdot
.862 .43571 Mdot
.862 .43608 Mdot
.862 .43628 Mdot
.862 .43698 Mdot
.862 .43708 Mdot
.862 .4372 Mdot
.862 .43764 Mdot
.862 .43773 Mdot
.862 .43782 Mdot
.862 .43843 Mdot
.862 .43857 Mdot
.862 .43859 Mdot
.862 .43883 Mdot
.862 .43936 Mdot
.862 .43941 Mdot
.862 .43944 Mdot
.862 .43964 Mdot
.862 .43971 Mdot
.862 .44003 Mdot
.862 .44031 Mdot
.862 .44046 Mdot
.862 .4406 Mdot
.862 .44137 Mdot
.862 .44141 Mdot
.862 .44143 Mdot
.862 .44248 Mdot
.862 .44252 Mdot
.862 .44259 Mdot
.862 .44305 Mdot
.862 .44407 Mdot
.862 .44421 Mdot
.862 .44447 Mdot
.862 .44484 Mdot
.862 .44495 Mdot
.862 .44506 Mdot
.862 .44519 Mdot
.862 .44523 Mdot
.862 .44533 Mdot
.862 .44652 Mdot
.862 .44655 Mdot
.862 .44675 Mdot
.862 .4474 Mdot
.862 .44796 Mdot
.862 .44797 Mdot
.862 .44876 Mdot
.862 .44879 Mdot
.862 .44935 Mdot
.862 .44958 Mdot
.862 .44983 Mdot
.862 .44986 Mdot
.862 .44987 Mdot
.862 .45031 Mdot
.862 .45112 Mdot
.862 .45191 Mdot
.862 .45237 Mdot
.862 .4527 Mdot
.862 .45297 Mdot
.862 .45348 Mdot
.862 .45365 Mdot
.862 .45436 Mdot
.862 .45461 Mdot
.862 .45483 Mdot
.862 .45585 Mdot
.862 .45705 Mdot
.862 .45812 Mdot
.862 .45828 Mdot
.862 .45837 Mdot
.862 .45891 Mdot
.862 .45932 Mdot
.862 .45983 Mdot
.862 .45989 Mdot
.862 .45996 Mdot
.862 .46009 Mdot
.862 .46017 Mdot
.862 .46074 Mdot
.862 .46111 Mdot
.862 .46149 Mdot
.862 .46158 Mdot
.862 .46212 Mdot
.862 .46238 Mdot
.862 .46291 Mdot
.862 .46335 Mdot
.862 .4636 Mdot
.862 .4639 Mdot
.862 .46392 Mdot
.862 .46411 Mdot
.862 .4644 Mdot
.862 .46517 Mdot
.862 .46518 Mdot
.862 .46546 Mdot
.862 .46551 Mdot
.862 .46561 Mdot
.862 .46616 Mdot
.862 .46631 Mdot
.862 .46641 Mdot
.862 .46709 Mdot
.862 .4674 Mdot
.862 .46766 Mdot
.862 .46846 Mdot
.862 .46876 Mdot
.862 .46883 Mdot
.862 .46921 Mdot
.862 .46937 Mdot
.862 .47011 Mdot
.862 .47021 Mdot
.862 .47029 Mdot
.862 .47029 Mdot
.862 .47099 Mdot
.862 .47111 Mdot
.862 .47113 Mdot
.862 .47311 Mdot
.862 .47334 Mdot
.862 .47352 Mdot
.862 .4736 Mdot
.862 .47402 Mdot
.862 .47471 Mdot
.862 .47483 Mdot
.862 .47486 Mdot
.862 .4749 Mdot
.862 .47493 Mdot
.862 .47495 Mdot
.862 .47507 Mdot
.862 .47526 Mdot
.862 .47565 Mdot
.862 .47569 Mdot
.862 .47632 Mdot
.862 .47638 Mdot
.862 .47702 Mdot
.862 .47727 Mdot
.862 .47731 Mdot
.862 .47737 Mdot
.862 .47741 Mdot
.862 .47787 Mdot
.862 .47805 Mdot
.862 .47814 Mdot
.862 .47839 Mdot
.862 .47844 Mdot
.862 .479 Mdot
.862 .47901 Mdot
.862 .47905 Mdot
.862 .48034 Mdot
.862 .48047 Mdot
.862 .48052 Mdot
.862 .48064 Mdot
.862 .48168 Mdot
.862 .48218 Mdot
.862 .48378 Mdot
.862 .48391 Mdot
.862 .48411 Mdot
.862 .48469 Mdot
.862 .4848 Mdot
.862 .48534 Mdot
.862 .48617 Mdot
.862 .48639 Mdot
.862 .48705 Mdot
.862 .4877 Mdot
.862 .48822 Mdot
.862 .48828 Mdot
.862 .48832 Mdot
.862 .48863 Mdot
.862 .48874 Mdot
.862 .48875 Mdot
.862 .48911 Mdot
.862 .48912 Mdot
.862 .48946 Mdot
.862 .48978 Mdot
.862 .48997 Mdot
.862 .49019 Mdot
.862 .49089 Mdot
.862 .49101 Mdot
.862 .49166 Mdot
.862 .49208 Mdot
.862 .49227 Mdot
.862 .49374 Mdot
.862 .49384 Mdot
.862 .4941 Mdot
.862 .49508 Mdot
.862 .49509 Mdot
.862 .49509 Mdot
.862 .49523 Mdot
.862 .49525 Mdot
.862 .49569 Mdot
.862 .49599 Mdot
.862 .496 Mdot
.862 .49606 Mdot
.862 .49641 Mdot
.862 .49645 Mdot
.862 .49646 Mdot
.862 .49647 Mdot
.862 .49668 Mdot
.862 .49679 Mdot
.862 .4968 Mdot
.862 .49705 Mdot
.862 .49819 Mdot
.862 .49824 Mdot
.862 .49859 Mdot
.862 .49898 Mdot
.862 .49974 Mdot
.862 .49993 Mdot
.862 .49993 Mdot
.862 .49996 Mdot
.862 .50011 Mdot
.862 .50012 Mdot
.862 .50054 Mdot
.862 .50062 Mdot
.862 .50129 Mdot
.862 .50132 Mdot
.862 .50197 Mdot
.862 .50206 Mdot
.862 .5021 Mdot
.862 .50219 Mdot
.862 .50237 Mdot
.862 .50279 Mdot
.862 .50325 Mdot
.862 .504 Mdot
.862 .50407 Mdot
.862 .50503 Mdot
.862 .50523 Mdot
.862 .50553 Mdot
.862 .50576 Mdot
.862 .50584 Mdot
.862 .50593 Mdot
.862 .50599 Mdot
.862 .50607 Mdot
.862 .50619 Mdot
.862 .50665 Mdot
.862 .50684 Mdot
.862 .50706 Mdot
.862 .50718 Mdot
.862 .50758 Mdot
.862 .50764 Mdot
.862 .50773 Mdot
.862 .50803 Mdot
.862 .50818 Mdot
.862 .5083 Mdot
.862 .50835 Mdot
.862 .5084 Mdot
.862 .50857 Mdot
.862 .50885 Mdot
.862 .50919 Mdot
.862 .50971 Mdot
.862 .50987 Mdot
.862 .50995 Mdot
.862 .5106 Mdot
.862 .51066 Mdot
.862 .51075 Mdot
.862 .5109 Mdot
.862 .51117 Mdot
.862 .51148 Mdot
.862 .51193 Mdot
.862 .5121 Mdot
.862 .51226 Mdot
.862 .5125 Mdot
.862 .51283 Mdot
.862 .51313 Mdot
.862 .51429 Mdot
.862 .51491 Mdot
.862 .51522 Mdot
.862 .5158 Mdot
.862 .51595 Mdot
.862 .51598 Mdot
.862 .51605 Mdot
.862 .51628 Mdot
.862 .51692 Mdot
.862 .51701 Mdot
.862 .51731 Mdot
.862 .51747 Mdot
.862 .51756 Mdot
.862 .51781 Mdot
.862 .51883 Mdot
.862 .51915 Mdot
.862 .51935 Mdot
.862 .51951 Mdot
.862 .51975 Mdot
.862 .51976 Mdot
.862 .51996 Mdot
.862 .52013 Mdot
.862 .52024 Mdot
.862 .5204 Mdot
.862 .52064 Mdot
.862 .52071 Mdot
.862 .52117 Mdot
.862 .5212 Mdot
.862 .52159 Mdot
.862 .5218 Mdot
.862 .5218 Mdot
.862 .52191 Mdot
.862 .52196 Mdot
.862 .52225 Mdot
.862 .52276 Mdot
.862 .52284 Mdot
.864 .15338 Mdot
.864 .15431 Mdot
.864 .15494 Mdot
.864 .1557 Mdot
.864 .15573 Mdot
.864 .15585 Mdot
.864 .15621 Mdot
.864 .15672 Mdot
.864 .15775 Mdot
.864 .15834 Mdot
.864 .15846 Mdot
.864 .15915 Mdot
.864 .15937 Mdot
.864 .15965 Mdot
.864 .16015 Mdot
.864 .16037 Mdot
.864 .16039 Mdot
.864 .16112 Mdot
.864 .16122 Mdot
.864 .16172 Mdot
.864 .16224 Mdot
.864 .16262 Mdot
.864 .16267 Mdot
.864 .16318 Mdot
.864 .16412 Mdot
.864 .16427 Mdot
.864 .16445 Mdot
.864 .16455 Mdot
.864 .16506 Mdot
.864 .16529 Mdot
.864 .16582 Mdot
.864 .1661 Mdot
.864 .16835 Mdot
.864 .17008 Mdot
.864 .1703 Mdot
.864 .17031 Mdot
.864 .17122 Mdot
.864 .17168 Mdot
.864 .17192 Mdot
.864 .17303 Mdot
.864 .17315 Mdot
.864 .17407 Mdot
.864 .17408 Mdot
.864 .17522 Mdot
.864 .17534 Mdot
.864 .17551 Mdot
.864 .17575 Mdot
.864 .17584 Mdot
.864 .1763 Mdot
.864 .17645 Mdot
.864 .17759 Mdot
.864 .17798 Mdot
.864 .17802 Mdot
.864 .17879 Mdot
.864 .17962 Mdot
.864 .17969 Mdot
.864 .1802 Mdot
.864 .18032 Mdot
.864 .18033 Mdot
.864 .18098 Mdot
.864 .18159 Mdot
.864 .18161 Mdot
.864 .18295 Mdot
.864 .18331 Mdot
.864 .18363 Mdot
.864 .18426 Mdot
.864 .18497 Mdot
.864 .18543 Mdot
.864 .18607 Mdot
.864 .18639 Mdot
.864 .18654 Mdot
.864 .18664 Mdot
.864 .18674 Mdot
.864 .18757 Mdot
.864 .18971 Mdot
.864 .18976 Mdot
.864 .1899 Mdot
.864 .19012 Mdot
.864 .1909 Mdot
.864 .19141 Mdot
.864 .19155 Mdot
.864 .19176 Mdot
.864 .19255 Mdot
.864 .19375 Mdot
.864 .1939 Mdot
.864 .1951 Mdot
.864 .19635 Mdot
.864 .19661 Mdot
.864 .19709 Mdot
.864 .1976 Mdot
.864 .19772 Mdot
.864 .19924 Mdot
.864 .19951 Mdot
.864 .19966 Mdot
.864 .20003 Mdot
.864 .20041 Mdot
.864 .20128 Mdot
.864 .20212 Mdot
.864 .20244 Mdot
.864 .2028 Mdot
.864 .20287 Mdot
.864 .20327 Mdot
.864 .2033 Mdot
.864 .20363 Mdot
.864 .2037 Mdot
.864 .20451 Mdot
.864 .20472 Mdot
.864 .20539 Mdot
.864 .20602 Mdot
.864 .20627 Mdot
.864 .20648 Mdot
.864 .20703 Mdot
.864 .20784 Mdot
.864 .20974 Mdot
.864 .21108 Mdot
.864 .21142 Mdot
.864 .2119 Mdot
.864 .21195 Mdot
.864 .21224 Mdot
.864 .21355 Mdot
.864 .21358 Mdot
.864 .21426 Mdot
.864 .21539 Mdot
.864 .21618 Mdot
.864 .21648 Mdot
.864 .21669 Mdot
.864 .21682 Mdot
.864 .21688 Mdot
.864 .21732 Mdot
.864 .21883 Mdot
.864 .21963 Mdot
.864 .21984 Mdot
.864 .22047 Mdot
.864 .2211 Mdot
.864 .22303 Mdot
.864 .22311 Mdot
.864 .22352 Mdot
.864 .22426 Mdot
.864 .22468 Mdot
.864 .22487 Mdot
.864 .22583 Mdot
.864 .22604 Mdot
.864 .22624 Mdot
.864 .22659 Mdot
.864 .22666 Mdot
.864 .22683 Mdot
.864 .22739 Mdot
.864 .22874 Mdot
.864 .2289 Mdot
.864 .23009 Mdot
.864 .23046 Mdot
.864 .23068 Mdot
.864 .23077 Mdot
.864 .23135 Mdot
.864 .2314 Mdot
.864 .23251 Mdot
.864 .23427 Mdot
.864 .23452 Mdot
.864 .23498 Mdot
.864 .23518 Mdot
.864 .23532 Mdot
.864 .23553 Mdot
.864 .23618 Mdot
.864 .23629 Mdot
.864 .23697 Mdot
.864 .23867 Mdot
.864 .2394 Mdot
.864 .23954 Mdot
.864 .24087 Mdot
.864 .24117 Mdot
.864 .24118 Mdot
.864 .24143 Mdot
.864 .24254 Mdot
.864 .24288 Mdot
.864 .24301 Mdot
.864 .24339 Mdot
.864 .24544 Mdot
.864 .24545 Mdot
.864 .24553 Mdot
.864 .24562 Mdot
.864 .24571 Mdot
.864 .24684 Mdot
.864 .24701 Mdot
.864 .2473 Mdot
.864 .24734 Mdot
.864 .24769 Mdot
.864 .24869 Mdot
.864 .24974 Mdot
.864 .24988 Mdot
.864 .25184 Mdot
.864 .25236 Mdot
.864 .25295 Mdot
.864 .25307 Mdot
.864 .25433 Mdot
.864 .25449 Mdot
.864 .25502 Mdot
.864 .25594 Mdot
.864 .2564 Mdot
.864 .25647 Mdot
.864 .25702 Mdot
.864 .25706 Mdot
.864 .25723 Mdot
.864 .25761 Mdot
.864 .25783 Mdot
.864 .25834 Mdot
.864 .25838 Mdot
.864 .25844 Mdot
.864 .25859 Mdot
.864 .25868 Mdot
.864 .25922 Mdot
.864 .25939 Mdot
.864 .25942 Mdot
.864 .25966 Mdot
.864 .26011 Mdot
.864 .26094 Mdot
.864 .26106 Mdot
.864 .26155 Mdot
.864 .26189 Mdot
.864 .26202 Mdot
.864 .26252 Mdot
.864 .26281 Mdot
.864 .26289 Mdot
.864 .26299 Mdot
.864 .2631 Mdot
.864 .26327 Mdot
.864 .2633 Mdot
.864 .2643 Mdot
.864 .26468 Mdot
.864 .26487 Mdot
.864 .26516 Mdot
.864 .26595 Mdot
.864 .26602 Mdot
.864 .26641 Mdot
.864 .26644 Mdot
.864 .26649 Mdot
.864 .26656 Mdot
.864 .26672 Mdot
.864 .26715 Mdot
.864 .26719 Mdot
.864 .2677 Mdot
.864 .26788 Mdot
.864 .26815 Mdot
.864 .26874 Mdot
.864 .2689 Mdot
.864 .26903 Mdot
.864 .26962 Mdot
.864 .26964 Mdot
.864 .2703 Mdot
.864 .27038 Mdot
.864 .27076 Mdot
.864 .271 Mdot
.864 .27125 Mdot
.864 .27288 Mdot
.864 .27289 Mdot
.864 .27298 Mdot
.864 .27304 Mdot
.864 .27314 Mdot
.864 .27346 Mdot
.864 .27358 Mdot
.864 .27363 Mdot
.864 .27451 Mdot
.864 .27479 Mdot
.864 .27491 Mdot
.864 .27517 Mdot
.864 .27565 Mdot
.864 .27583 Mdot
.864 .2763 Mdot
.864 .27654 Mdot
.864 .27742 Mdot
.864 .27777 Mdot
.864 .27822 Mdot
.864 .27877 Mdot
.864 .27883 Mdot
.864 .2802 Mdot
.864 .28029 Mdot
.864 .28039 Mdot
.864 .28113 Mdot
.864 .2817 Mdot
.864 .28196 Mdot
.864 .28218 Mdot
.864 .28225 Mdot
.864 .28236 Mdot
.864 .28252 Mdot
.864 .2826 Mdot
.864 .28319 Mdot
.864 .28356 Mdot
.864 .28358 Mdot
.864 .28377 Mdot
.864 .284 Mdot
.864 .2849 Mdot
.864 .28515 Mdot
.864 .28529 Mdot
.864 .28543 Mdot
.864 .28575 Mdot
.864 .28595 Mdot
.864 .28634 Mdot
.864 .28637 Mdot
.864 .28722 Mdot
.864 .2875 Mdot
.864 .28777 Mdot
.864 .28828 Mdot
.864 .28849 Mdot
.864 .28856 Mdot
.864 .28892 Mdot
.864 .28998 Mdot
.864 .29007 Mdot
.864 .29009 Mdot
.864 .29025 Mdot
.864 .29145 Mdot
.864 .29172 Mdot
.864 .29191 Mdot
.864 .29198 Mdot
.864 .29206 Mdot
.864 .29227 Mdot
.864 .2925 Mdot
.864 .29257 Mdot
.864 .29284 Mdot
.864 .29286 Mdot
.864 .29298 Mdot
.864 .29312 Mdot
.864 .29314 Mdot
.864 .29337 Mdot
.864 .29394 Mdot
.864 .29407 Mdot
.864 .29419 Mdot
.864 .29424 Mdot
.864 .29433 Mdot
.864 .29521 Mdot
.864 .29572 Mdot
.864 .29612 Mdot
.864 .29617 Mdot
.864 .29684 Mdot
.864 .29691 Mdot
.864 .29713 Mdot
.864 .29746 Mdot
.864 .29751 Mdot
.864 .29824 Mdot
.864 .29852 Mdot
.864 .29858 Mdot
.864 .29864 Mdot
.864 .29896 Mdot
.864 .29967 Mdot
.864 .29979 Mdot
.864 .30024 Mdot
.864 .30045 Mdot
.864 .30066 Mdot
.864 .30067 Mdot
.864 .30088 Mdot
.864 .3009 Mdot
.864 .30144 Mdot
.864 .30201 Mdot
.864 .30217 Mdot
.864 .30234 Mdot
.864 .30276 Mdot
.864 .30307 Mdot
.864 .30311 Mdot
.864 .30348 Mdot
.864 .30356 Mdot
.864 .3041 Mdot
.864 .30543 Mdot
.864 .3057 Mdot
.864 .30595 Mdot
.864 .30604 Mdot
.864 .30641 Mdot
.864 .30658 Mdot
.864 .30659 Mdot
.864 .30672 Mdot
.864 .30768 Mdot
.864 .30799 Mdot
.864 .30823 Mdot
.864 .3089 Mdot
.864 .30891 Mdot
.864 .30917 Mdot
.864 .3097 Mdot
.864 .31002 Mdot
.864 .31053 Mdot
.864 .31065 Mdot
.864 .31082 Mdot
.864 .31136 Mdot
.864 .31163 Mdot
.864 .3118 Mdot
.864 .31197 Mdot
.864 .31205 Mdot
.864 .31205 Mdot
.864 .31229 Mdot
.864 .31233 Mdot
.864 .3125 Mdot
.864 .3133 Mdot
.864 .31341 Mdot
.864 .31361 Mdot
.864 .31387 Mdot
.864 .31472 Mdot
.864 .31537 Mdot
.864 .31537 Mdot
.864 .31568 Mdot
.864 .31663 Mdot
.864 .31702 Mdot
.864 .31711 Mdot
.864 .31719 Mdot
.864 .31743 Mdot
.864 .31781 Mdot
.864 .31794 Mdot
.864 .31821 Mdot
.864 .31868 Mdot
.864 .31916 Mdot
.864 .31983 Mdot
.864 .32004 Mdot
.864 .32028 Mdot
.864 .32065 Mdot
.864 .32084 Mdot
.864 .32187 Mdot
.864 .32201 Mdot
.864 .32244 Mdot
.864 .32282 Mdot
.864 .32409 Mdot
.864 .32434 Mdot
.864 .32451 Mdot
.864 .32455 Mdot
.864 .32574 Mdot
.864 .32613 Mdot
.864 .32642 Mdot
.864 .32858 Mdot
.864 .32903 Mdot
.864 .32986 Mdot
.864 .32986 Mdot
.864 .33073 Mdot
.864 .33095 Mdot
.864 .33097 Mdot
.864 .33196 Mdot
.864 .33238 Mdot
.864 .33319 Mdot
.864 .33358 Mdot
.864 .33404 Mdot
.864 .33422 Mdot
.864 .3343 Mdot
.864 .33494 Mdot
.864 .33499 Mdot
.864 .33552 Mdot
.864 .33559 Mdot
.864 .3371 Mdot
.864 .33747 Mdot
.864 .33851 Mdot
.864 .33856 Mdot
.864 .33911 Mdot
.864 .33956 Mdot
.864 .33968 Mdot
.864 .33972 Mdot
.864 .33985 Mdot
.864 .34054 Mdot
.864 .34054 Mdot
.864 .34059 Mdot
.864 .341 Mdot
.864 .34106 Mdot
.864 .34116 Mdot
.864 .34129 Mdot
.864 .34202 Mdot
.864 .34268 Mdot
.864 .34305 Mdot
.864 .3442 Mdot
.864 .34443 Mdot
.864 .34468 Mdot
.864 .34497 Mdot
.864 .34521 Mdot
.864 .34522 Mdot
.864 .3453 Mdot
.864 .34572 Mdot
.864 .34609 Mdot
.864 .34704 Mdot
.864 .3474 Mdot
.864 .34758 Mdot
.864 .34761 Mdot
.864 .34766 Mdot
.864 .34781 Mdot
.864 .34782 Mdot
.864 .34843 Mdot
.864 .34972 Mdot
.864 .34996 Mdot
.864 .35095 Mdot
.864 .35136 Mdot
.864 .35172 Mdot
.864 .35248 Mdot
.864 .35276 Mdot
.864 .35286 Mdot
.864 .35375 Mdot
.864 .35388 Mdot
.864 .35392 Mdot
.864 .35403 Mdot
.864 .35462 Mdot
.864 .35497 Mdot
.864 .35545 Mdot
.864 .35554 Mdot
.864 .35594 Mdot
.864 .35603 Mdot
.864 .35642 Mdot
.864 .35682 Mdot
.864 .35691 Mdot
.864 .3572 Mdot
.864 .35796 Mdot
.864 .35797 Mdot
.864 .35831 Mdot
.864 .35835 Mdot
.864 .35889 Mdot
.864 .35896 Mdot
.864 .35903 Mdot
.864 .35953 Mdot
.864 .35959 Mdot
.864 .36148 Mdot
.864 .36188 Mdot
.864 .36284 Mdot
.864 .36284 Mdot
.864 .36293 Mdot
.864 .36326 Mdot
.864 .36336 Mdot
.864 .36373 Mdot
.864 .36395 Mdot
.864 .36395 Mdot
.864 .36406 Mdot
.864 .3645 Mdot
.864 .36481 Mdot
.864 .36545 Mdot
.864 .36579 Mdot
.864 .36613 Mdot
.864 .36701 Mdot
.864 .36743 Mdot
.864 .3688 Mdot
.864 .36918 Mdot
.864 .36992 Mdot
.864 .37027 Mdot
.864 .37053 Mdot
.864 .37135 Mdot
.864 .37254 Mdot
.864 .37288 Mdot
.864 .37468 Mdot
.864 .37474 Mdot
.864 .37475 Mdot
.864 .37477 Mdot
.864 .37482 Mdot
.864 .37482 Mdot
.864 .37546 Mdot
.864 .37554 Mdot
.864 .37587 Mdot
.864 .37648 Mdot
.864 .37681 Mdot
.864 .37686 Mdot
.864 .37722 Mdot
.864 .37754 Mdot
.864 .3777 Mdot
.864 .37783 Mdot
.864 .37786 Mdot
.864 .37855 Mdot
.864 .37857 Mdot
.864 .37876 Mdot
.864 .37953 Mdot
.864 .37988 Mdot
.864 .38022 Mdot
.864 .38041 Mdot
.864 .38084 Mdot
.864 .38095 Mdot
.864 .38125 Mdot
.864 .38222 Mdot
.864 .38384 Mdot
.864 .38384 Mdot
.864 .38384 Mdot
.864 .38455 Mdot
.864 .38467 Mdot
.864 .38483 Mdot
.864 .38511 Mdot
.864 .38518 Mdot
.864 .38573 Mdot
.864 .38688 Mdot
.864 .38688 Mdot
.864 .38716 Mdot
.864 .38731 Mdot
.864 .38733 Mdot
.864 .38752 Mdot
.864 .3879 Mdot
.864 .38805 Mdot
.864 .38904 Mdot
.864 .38906 Mdot
.864 .38914 Mdot
.864 .3893 Mdot
.864 .38997 Mdot
.864 .39029 Mdot
.864 .39033 Mdot
.864 .39059 Mdot
.864 .39106 Mdot
.864 .39106 Mdot
.864 .39107 Mdot
.864 .39305 Mdot
.864 .394 Mdot
.864 .39411 Mdot
.864 .39413 Mdot
.864 .39454 Mdot
.864 .39462 Mdot
.864 .3949 Mdot
.864 .3951 Mdot
.864 .39533 Mdot
.864 .39568 Mdot
.864 .39591 Mdot
.864 .39629 Mdot
.864 .39631 Mdot
.864 .39633 Mdot
.864 .39633 Mdot
.864 .39741 Mdot
.864 .39761 Mdot
.864 .39877 Mdot
.864 .39912 Mdot
.864 .4008 Mdot
.864 .40131 Mdot
.864 .40151 Mdot
.864 .40171 Mdot
.864 .40225 Mdot
.864 .40257 Mdot
.864 .40297 Mdot
.864 .40316 Mdot
.864 .40322 Mdot
.864 .40377 Mdot
.864 .4051 Mdot
.864 .40542 Mdot
.864 .40546 Mdot
.864 .4055 Mdot
.864 .40603 Mdot
.864 .40604 Mdot
.864 .40648 Mdot
.864 .40665 Mdot
.864 .4067 Mdot
.864 .40693 Mdot
.864 .40721 Mdot
.864 .40777 Mdot
.864 .40838 Mdot
.864 .4084 Mdot
.864 .40848 Mdot
.864 .40899 Mdot
.864 .40905 Mdot
.864 .40921 Mdot
.864 .40986 Mdot
.864 .4101 Mdot
.864 .41067 Mdot
.864 .41081 Mdot
.864 .41191 Mdot
.864 .41192 Mdot
.864 .412 Mdot
.864 .41203 Mdot
.864 .41205 Mdot
.864 .41215 Mdot
.864 .41342 Mdot
.864 .41342 Mdot
.864 .41356 Mdot
.864 .41372 Mdot
.864 .41387 Mdot
.864 .41526 Mdot
.864 .41582 Mdot
.864 .41585 Mdot
.864 .41612 Mdot
.864 .41662 Mdot
.864 .41669 Mdot
.864 .4173 Mdot
.864 .4179 Mdot
.864 .41903 Mdot
.864 .41933 Mdot
.864 .41978 Mdot
.864 .42037 Mdot
.864 .42084 Mdot
.864 .42109 Mdot
.864 .42166 Mdot
.864 .42231 Mdot
.864 .42446 Mdot
.864 .42468 Mdot
.864 .42537 Mdot
.864 .4254 Mdot
.864 .42638 Mdot
.864 .4266 Mdot
.864 .42693 Mdot
.864 .42752 Mdot
.864 .42811 Mdot
.864 .42877 Mdot
.864 .42904 Mdot
.864 .4292 Mdot
.864 .42974 Mdot
.864 .42996 Mdot
.864 .43051 Mdot
.864 .43069 Mdot
.864 .43069 Mdot
.864 .43107 Mdot
.864 .43156 Mdot
.864 .4317 Mdot
.864 .43189 Mdot
.864 .43235 Mdot
.864 .43245 Mdot
.864 .43247 Mdot
.864 .43261 Mdot
.864 .43261 Mdot
.864 .43342 Mdot
.864 .43349 Mdot
.864 .43379 Mdot
.864 .43428 Mdot
.864 .43443 Mdot
.864 .43482 Mdot
.864 .43496 Mdot
.864 .43569 Mdot
.864 .43577 Mdot
.864 .43587 Mdot
.864 .43614 Mdot
.864 .43628 Mdot
.864 .43721 Mdot
.864 .43752 Mdot
.864 .43757 Mdot
.864 .43798 Mdot
.864 .43823 Mdot
.864 .43833 Mdot
.864 .43875 Mdot
.864 .4392 Mdot
.864 .43932 Mdot
.864 .43944 Mdot
.864 .44019 Mdot
.864 .44037 Mdot
.864 .4404 Mdot
.864 .44044 Mdot
.864 .44103 Mdot
.864 .44105 Mdot
.864 .44125 Mdot
.864 .44183 Mdot
.864 .44206 Mdot
.864 .44235 Mdot
.864 .44286 Mdot
.864 .44291 Mdot
.864 .44302 Mdot
.864 .44342 Mdot
.864 .44357 Mdot
.864 .44371 Mdot
.864 .44373 Mdot
.864 .44393 Mdot
.864 .44423 Mdot
.864 .44427 Mdot
.864 .44437 Mdot
.864 .44453 Mdot
.864 .44522 Mdot
.864 .44538 Mdot
.864 .44599 Mdot
.864 .4462 Mdot
.864 .44666 Mdot
.864 .44681 Mdot
.864 .44698 Mdot
.864 .44749 Mdot
.864 .44783 Mdot
.864 .44802 Mdot
.864 .44809 Mdot
.864 .44832 Mdot
.864 .44884 Mdot
.864 .44897 Mdot
.864 .44965 Mdot
.864 .4497 Mdot
.864 .44979 Mdot
.864 .44985 Mdot
.864 .4499 Mdot
.864 .45002 Mdot
.864 .45017 Mdot
.864 .4505 Mdot
.864 .45093 Mdot
.864 .45099 Mdot
.864 .45183 Mdot
.864 .45187 Mdot
.864 .45218 Mdot
.864 .45245 Mdot
.864 .45265 Mdot
.864 .45316 Mdot
.864 .45367 Mdot
.864 .45395 Mdot
.864 .45417 Mdot
.864 .45487 Mdot
.864 .45518 Mdot
.864 .45522 Mdot
.864 .45528 Mdot
.864 .45636 Mdot
.864 .4565 Mdot
.864 .45717 Mdot
.864 .4575 Mdot
.864 .45758 Mdot
.864 .45801 Mdot
.864 .45857 Mdot
.864 .45859 Mdot
.864 .45884 Mdot
.864 .45894 Mdot
.864 .45897 Mdot
.864 .45929 Mdot
.864 .45991 Mdot
.864 .46082 Mdot
.864 .46084 Mdot
.864 .461 Mdot
.864 .4611 Mdot
.864 .46127 Mdot
.864 .46156 Mdot
.864 .46183 Mdot
.864 .46204 Mdot
.864 .46212 Mdot
.864 .46219 Mdot
.864 .46293 Mdot
.864 .46307 Mdot
.864 .46308 Mdot
.864 .4635 Mdot
.864 .46363 Mdot
.864 .46398 Mdot
.864 .46412 Mdot
.864 .46433 Mdot
.864 .46443 Mdot
.864 .46477 Mdot
.864 .46481 Mdot
.864 .46561 Mdot
.864 .46592 Mdot
.864 .46674 Mdot
.864 .46681 Mdot
.864 .46715 Mdot
.864 .46746 Mdot
.864 .46858 Mdot
.864 .46867 Mdot
.864 .46927 Mdot
.864 .46985 Mdot
.864 .47006 Mdot
.864 .47008 Mdot
.864 .47025 Mdot
.864 .47035 Mdot
.864 .471 Mdot
.864 .47105 Mdot
.864 .47111 Mdot
.864 .47115 Mdot
.864 .47115 Mdot
.864 .47234 Mdot
.864 .47256 Mdot
.864 .47264 Mdot
.864 .47283 Mdot
.864 .47348 Mdot
.864 .47362 Mdot
.864 .47363 Mdot
.864 .4738 Mdot
.864 .47457 Mdot
.864 .47465 Mdot
.864 .47507 Mdot
.864 .47606 Mdot
.864 .47645 Mdot
.864 .47651 Mdot
.864 .47689 Mdot
.864 .47701 Mdot
.864 .47709 Mdot
.864 .47721 Mdot
.864 .47748 Mdot
.864 .47762 Mdot
.864 .47864 Mdot
.864 .47928 Mdot
.864 .47931 Mdot
.864 .47965 Mdot
.864 .4797 Mdot
.864 .47983 Mdot
.864 .48004 Mdot
.864 .48073 Mdot
.864 .48082 Mdot
.864 .4816 Mdot
.864 .48193 Mdot
.864 .48203 Mdot
.864 .48206 Mdot
.864 .48227 Mdot
.864 .48238 Mdot
.864 .4825 Mdot
.864 .48306 Mdot
.864 .48317 Mdot
.864 .48341 Mdot
.864 .48384 Mdot
.864 .48408 Mdot
.864 .48413 Mdot
.864 .48524 Mdot
.864 .4856 Mdot
.864 .48597 Mdot
.864 .48609 Mdot
.864 .48656 Mdot
.864 .48743 Mdot
.864 .48768 Mdot
.864 .48772 Mdot
.864 .48779 Mdot
.864 .48792 Mdot
.864 .48809 Mdot
.864 .48855 Mdot
.864 .4896 Mdot
.864 .48961 Mdot
.864 .49037 Mdot
.864 .49054 Mdot
.864 .49057 Mdot
.864 .49084 Mdot
.864 .49104 Mdot
.864 .49182 Mdot
.864 .49292 Mdot
.864 .49338 Mdot
.864 .4937 Mdot
.864 .49382 Mdot
.864 .49397 Mdot
.864 .49433 Mdot
.864 .49472 Mdot
.864 .49484 Mdot
.864 .49531 Mdot
.864 .49535 Mdot
.864 .49554 Mdot
.864 .49556 Mdot
.864 .49579 Mdot
.864 .49583 Mdot
.864 .49604 Mdot
.864 .49622 Mdot
.864 .49671 Mdot
.864 .49722 Mdot
.864 .49744 Mdot
.864 .49765 Mdot
.864 .49774 Mdot
.864 .49789 Mdot
.864 .49877 Mdot
.864 .49884 Mdot
.864 .49914 Mdot
.864 .49942 Mdot
.864 .49957 Mdot
.864 .50029 Mdot
.864 .50098 Mdot
.864 .50107 Mdot
.864 .50177 Mdot
.864 .50222 Mdot
.864 .50234 Mdot
.864 .50242 Mdot
.864 .50272 Mdot
.864 .50317 Mdot
.864 .5033 Mdot
.864 .50338 Mdot
.864 .50341 Mdot
.864 .50464 Mdot
.864 .50513 Mdot
.864 .50518 Mdot
.864 .50524 Mdot
.864 .50533 Mdot
.864 .50551 Mdot
.864 .50589 Mdot
.864 .50615 Mdot
.864 .50656 Mdot
.864 .50693 Mdot
.864 .50711 Mdot
.864 .50732 Mdot
.864 .50809 Mdot
.864 .50811 Mdot
.864 .50846 Mdot
.864 .50883 Mdot
.864 .50884 Mdot
.864 .50891 Mdot
.864 .50921 Mdot
.864 .50925 Mdot
.864 .50973 Mdot
.864 .51017 Mdot
.864 .5102 Mdot
.864 .51042 Mdot
.864 .51108 Mdot
.864 .51117 Mdot
.864 .51143 Mdot
.864 .51149 Mdot
.864 .51163 Mdot
.864 .51172 Mdot
.864 .5118 Mdot
.864 .51245 Mdot
.864 .51246 Mdot
.864 .51299 Mdot
.864 .51306 Mdot
.864 .5137 Mdot
.864 .51384 Mdot
.864 .51411 Mdot
.864 .51464 Mdot
.864 .51464 Mdot
.864 .51477 Mdot
.864 .51577 Mdot
.864 .51707 Mdot
.864 .51723 Mdot
.864 .51754 Mdot
.864 .51767 Mdot
.864 .51797 Mdot
.864 .51802 Mdot
.864 .51813 Mdot
.864 .51822 Mdot
.864 .51876 Mdot
.864 .51906 Mdot
.864 .51908 Mdot
.864 .51931 Mdot
.864 .5196 Mdot
.864 .51989 Mdot
.864 .51995 Mdot
.864 .52037 Mdot
.864 .52038 Mdot
.864 .52052 Mdot
.864 .5208 Mdot
.864 .52096 Mdot
.864 .52109 Mdot
.864 .52149 Mdot
.864 .52156 Mdot
.864 .5219 Mdot
.864 .5225 Mdot
.864 .5228 Mdot
.864 .523 Mdot
.864 .52307 Mdot
.864 .52309 Mdot
.864 .52353 Mdot
.864 .52389 Mdot
.864 .52443 Mdot
.866 .153 Mdot
.866 .15428 Mdot
.866 .15434 Mdot
.866 .15537 Mdot
.866 .15544 Mdot
.866 .15549 Mdot
.866 .15586 Mdot
.866 .15622 Mdot
.866 .1567 Mdot
.866 .15693 Mdot
.866 .15727 Mdot
.866 .15801 Mdot
.866 .15974 Mdot
.866 .16028 Mdot
.866 .1615 Mdot
.866 .16175 Mdot
.866 .16268 Mdot
.866 .1627 Mdot
.866 .16348 Mdot
.866 .16358 Mdot
.866 .16461 Mdot
.866 .16469 Mdot
.866 .16493 Mdot
.866 .16498 Mdot
.866 .16538 Mdot
.866 .16576 Mdot
.866 .16618 Mdot
.866 .16637 Mdot
.866 .16653 Mdot
.866 .16699 Mdot
.866 .16833 Mdot
.866 .16852 Mdot
.866 .16919 Mdot
.866 .16974 Mdot
.866 .17004 Mdot
.866 .1703 Mdot
.866 .17037 Mdot
.866 .17121 Mdot
.866 .17166 Mdot
.866 .17214 Mdot
.866 .17247 Mdot
.866 .17254 Mdot
.866 .17265 Mdot
.866 .17375 Mdot
.866 .17424 Mdot
.866 .17441 Mdot
.866 .17522 Mdot
.866 .17568 Mdot
.866 .17634 Mdot
.866 .17663 Mdot
.866 .17685 Mdot
.866 .17778 Mdot
.866 .17877 Mdot
.866 .17881 Mdot
.866 .1798 Mdot
.866 .18027 Mdot
.866 .18049 Mdot
.866 .18064 Mdot
.866 .18102 Mdot
.866 .18394 Mdot
.866 .18415 Mdot
.866 .18431 Mdot
.866 .18754 Mdot
.866 .18783 Mdot
.866 .18786 Mdot
.866 .18789 Mdot
.866 .18851 Mdot
.866 .18863 Mdot
.866 .18928 Mdot
.866 .19201 Mdot
.866 .1928 Mdot
.866 .19313 Mdot
.866 .19373 Mdot
.866 .19415 Mdot
.866 .19501 Mdot
.866 .19529 Mdot
.866 .19538 Mdot
.866 .19544 Mdot
.866 .19602 Mdot
.866 .19677 Mdot
.866 .19687 Mdot
.866 .19761 Mdot
.866 .19806 Mdot
.866 .19859 Mdot
.866 .19873 Mdot
.866 .19876 Mdot
.866 .19895 Mdot
.866 .19904 Mdot
.866 .19981 Mdot
.866 .20019 Mdot
.866 .20086 Mdot
.866 .20257 Mdot
.866 .2035 Mdot
.866 .20397 Mdot
.866 .20473 Mdot
.866 .20495 Mdot
.866 .20502 Mdot
.866 .20542 Mdot
.866 .20556 Mdot
.866 .20575 Mdot
.866 .2061 Mdot
.866 .20631 Mdot
.866 .2068 Mdot
.866 .20681 Mdot
.866 .2069 Mdot
.866 .20769 Mdot
.866 .20836 Mdot
.866 .20876 Mdot
.866 .21001 Mdot
.866 .21022 Mdot
.866 .21056 Mdot
.866 .21112 Mdot
.866 .21236 Mdot
.866 .21264 Mdot
.866 .21264 Mdot
.866 .21315 Mdot
.866 .21432 Mdot
.866 .2157 Mdot
.866 .21597 Mdot
.866 .21635 Mdot
.866 .21652 Mdot
.866 .2169 Mdot
.866 .21699 Mdot
.866 .2183 Mdot
.866 .2184 Mdot
.866 .21847 Mdot
.866 .21861 Mdot
.866 .21909 Mdot
.866 .21923 Mdot
.866 .21936 Mdot
.866 .22111 Mdot
.866 .22123 Mdot
.866 .2221 Mdot
.866 .22213 Mdot
.866 .22282 Mdot
.866 .22297 Mdot
.866 .22342 Mdot
.866 .22396 Mdot
.866 .22398 Mdot
.866 .22445 Mdot
.866 .22535 Mdot
.866 .22604 Mdot
.866 .22677 Mdot
.866 .22743 Mdot
.866 .22775 Mdot
.866 .2278 Mdot
.866 .22785 Mdot
.866 .22817 Mdot
.866 .22845 Mdot
.866 .22882 Mdot
.866 .2295 Mdot
.866 .22994 Mdot
.866 .23039 Mdot
.866 .23107 Mdot
.866 .23163 Mdot
.866 .23181 Mdot
.866 .23313 Mdot
.866 .23391 Mdot
.866 .23394 Mdot
.866 .23505 Mdot
.866 .23592 Mdot
.866 .23632 Mdot
.866 .23647 Mdot
.866 .23707 Mdot
.866 .23743 Mdot
.866 .2377 Mdot
.866 .23837 Mdot
.866 .2384 Mdot
.866 .23982 Mdot
.866 .24013 Mdot
.866 .24169 Mdot
.866 .24184 Mdot
.866 .24195 Mdot
.866 .24279 Mdot
.866 .24418 Mdot
.866 .24465 Mdot
.866 .24535 Mdot
.866 .24672 Mdot
.866 .24737 Mdot
.866 .2476 Mdot
.866 .24774 Mdot
.866 .24843 Mdot
.866 .24859 Mdot
.866 .24959 Mdot
.866 .25004 Mdot
.866 .25175 Mdot
.866 .25243 Mdot
.866 .25298 Mdot
.866 .25374 Mdot
.866 .25378 Mdot
.866 .25399 Mdot
.866 .25423 Mdot
.866 .25478 Mdot
.866 .25513 Mdot
.866 .2553 Mdot
.866 .25552 Mdot
.866 .2557 Mdot
.866 .25578 Mdot
.866 .25591 Mdot
.866 .25605 Mdot
.866 .25644 Mdot
.866 .25654 Mdot
.866 .25658 Mdot
.866 .2573 Mdot
.866 .25731 Mdot
.866 .2576 Mdot
.866 .25772 Mdot
.866 .25832 Mdot
.866 .25833 Mdot
.866 .25845 Mdot
.866 .25848 Mdot
.866 .25853 Mdot
.866 .25905 Mdot
.866 .25918 Mdot
.866 .25929 Mdot
.866 .25981 Mdot
.866 .26064 Mdot
.866 .26103 Mdot
.866 .26112 Mdot
.866 .26162 Mdot
.866 .26217 Mdot
.866 .26224 Mdot
.866 .26282 Mdot
.866 .26291 Mdot
.866 .263 Mdot
.866 .26308 Mdot
.866 .26315 Mdot
.866 .26362 Mdot
.866 .26441 Mdot
.866 .26474 Mdot
.866 .26484 Mdot
.866 .26528 Mdot
.866 .2659 Mdot
.866 .2665 Mdot
.866 .26684 Mdot
.866 .26703 Mdot
.866 .26734 Mdot
.866 .26764 Mdot
.866 .26776 Mdot
.866 .26888 Mdot
.866 .26894 Mdot
.866 .26938 Mdot
.866 .2694 Mdot
.866 .26986 Mdot
.866 .27029 Mdot
.866 .27099 Mdot
.866 .27103 Mdot
.866 .27113 Mdot
.866 .2721 Mdot
.866 .27237 Mdot
.866 .27252 Mdot
.866 .27255 Mdot
.866 .27257 Mdot
.866 .27285 Mdot
.866 .27389 Mdot
.866 .27408 Mdot
.866 .27434 Mdot
.866 .27447 Mdot
.866 .27489 Mdot
.866 .27494 Mdot
.866 .27498 Mdot
.866 .27565 Mdot
.866 .27566 Mdot
.866 .27591 Mdot
.866 .27632 Mdot
.866 .27704 Mdot
.866 .27738 Mdot
.866 .27743 Mdot
.866 .27766 Mdot
.866 .27779 Mdot
.866 .27846 Mdot
.866 .27869 Mdot
.866 .27959 Mdot
.866 .27963 Mdot
.866 .2802 Mdot
.866 .28078 Mdot
.866 .2811 Mdot
.866 .28122 Mdot
.866 .28142 Mdot
.866 .28226 Mdot
.866 .28253 Mdot
.866 .28303 Mdot
.866 .28322 Mdot
.866 .28374 Mdot
.866 .28419 Mdot
.866 .28429 Mdot
.866 .28431 Mdot
.866 .28433 Mdot
.866 .28465 Mdot
.866 .28489 Mdot
.866 .28559 Mdot
.866 .28577 Mdot
.866 .28621 Mdot
.866 .2865 Mdot
.866 .28654 Mdot
.866 .28716 Mdot
.866 .28721 Mdot
.866 .28737 Mdot
.866 .28742 Mdot
.866 .28748 Mdot
.866 .28794 Mdot
.866 .28807 Mdot
.866 .28812 Mdot
.866 .28825 Mdot
.866 .28946 Mdot
.866 .28987 Mdot
.866 .29017 Mdot
.866 .29024 Mdot
.866 .29101 Mdot
.866 .29128 Mdot
.866 .29131 Mdot
.866 .29147 Mdot
.866 .29172 Mdot
.866 .2919 Mdot
.866 .292 Mdot
.866 .29225 Mdot
.866 .29272 Mdot
.866 .29351 Mdot
.866 .29364 Mdot
.866 .294 Mdot
.866 .29422 Mdot
.866 .29465 Mdot
.866 .29509 Mdot
.866 .29512 Mdot
.866 .29515 Mdot
.866 .29524 Mdot
.866 .29552 Mdot
.866 .29587 Mdot
.866 .29715 Mdot
.866 .29736 Mdot
.866 .29763 Mdot
.866 .29773 Mdot
.866 .29881 Mdot
.866 .29886 Mdot
.866 .29893 Mdot
.866 .30015 Mdot
.866 .30064 Mdot
.866 .30098 Mdot
.866 .30129 Mdot
.866 .30146 Mdot
.866 .30183 Mdot
.866 .3021 Mdot
.866 .30273 Mdot
.866 .30275 Mdot
.866 .30286 Mdot
.866 .30317 Mdot
.866 .30348 Mdot
.866 .30356 Mdot
.866 .30385 Mdot
.866 .30512 Mdot
.866 .30526 Mdot
.866 .30537 Mdot
.866 .30572 Mdot
.866 .30575 Mdot
.866 .30602 Mdot
.866 .30633 Mdot
.866 .30757 Mdot
.866 .30782 Mdot
.866 .30793 Mdot
.866 .30817 Mdot
.866 .30845 Mdot
.866 .3088 Mdot
.866 .30882 Mdot
.866 .31015 Mdot
.866 .31096 Mdot
.866 .31098 Mdot
.866 .3111 Mdot
.866 .31138 Mdot
.866 .3124 Mdot
.866 .31258 Mdot
.866 .31298 Mdot
.866 .31338 Mdot
.866 .31362 Mdot
.866 .31405 Mdot
.866 .31415 Mdot
.866 .3144 Mdot
.866 .31454 Mdot
.866 .31461 Mdot
.866 .31466 Mdot
.866 .31481 Mdot
.866 .31526 Mdot
.866 .31532 Mdot
.866 .31573 Mdot
.866 .31594 Mdot
.866 .31637 Mdot
.866 .3167 Mdot
.866 .31707 Mdot
.866 .31723 Mdot
.866 .31771 Mdot
.866 .31803 Mdot
.866 .31874 Mdot
.866 .31908 Mdot
.866 .31931 Mdot
.866 .31937 Mdot
.866 .31949 Mdot
.866 .32177 Mdot
.866 .32178 Mdot
.866 .32199 Mdot
.866 .32315 Mdot
.866 .32342 Mdot
.866 .32373 Mdot
.866 .32449 Mdot
.866 .32477 Mdot
.866 .32502 Mdot
.866 .32535 Mdot
.866 .3254 Mdot
.866 .32547 Mdot
.866 .3255 Mdot
.866 .32611 Mdot
.866 .32698 Mdot
.866 .32747 Mdot
.866 .32762 Mdot
.866 .32773 Mdot
.866 .32785 Mdot
.866 .32809 Mdot
.866 .3286 Mdot
.866 .32874 Mdot
.866 .32934 Mdot
.866 .33003 Mdot
.866 .33003 Mdot
.866 .3302 Mdot
.866 .33059 Mdot
.866 .33105 Mdot
.866 .33148 Mdot
.866 .33195 Mdot
.866 .33227 Mdot
.866 .33319 Mdot
.866 .33342 Mdot
.866 .33348 Mdot
.866 .33381 Mdot
.866 .33397 Mdot
.866 .33427 Mdot
.866 .33496 Mdot
.866 .3353 Mdot
.866 .33543 Mdot
.866 .33595 Mdot
.866 .33642 Mdot
.866 .33712 Mdot
.866 .3375 Mdot
.866 .33779 Mdot
.866 .33793 Mdot
.866 .33839 Mdot
.866 .33862 Mdot
.866 .33909 Mdot
.866 .33972 Mdot
.866 .34008 Mdot
.866 .34055 Mdot
.866 .34139 Mdot
.866 .34168 Mdot
.866 .3425 Mdot
.866 .3433 Mdot
.866 .34382 Mdot
.866 .34408 Mdot
.866 .3442 Mdot
.866 .34425 Mdot
.866 .34433 Mdot
.866 .34439 Mdot
.866 .34468 Mdot
.866 .34492 Mdot
.866 .34502 Mdot
.866 .34526 Mdot
.866 .34558 Mdot
.866 .34619 Mdot
.866 .34657 Mdot
.866 .34676 Mdot
.866 .3474 Mdot
.866 .34743 Mdot
.866 .34758 Mdot
.866 .34799 Mdot
.866 .34816 Mdot
.866 .34878 Mdot
.866 .34895 Mdot
.866 .34925 Mdot
.866 .34985 Mdot
.866 .3501 Mdot
.866 .3508 Mdot
.866 .35103 Mdot
.866 .35112 Mdot
.866 .35235 Mdot
.866 .35296 Mdot
.866 .35333 Mdot
.866 .35392 Mdot
.866 .35393 Mdot
.866 .35404 Mdot
.866 .35435 Mdot
.866 .35487 Mdot
.866 .35489 Mdot
.866 .35496 Mdot
.866 .35519 Mdot
.866 .35564 Mdot
.866 .3559 Mdot
.866 .35645 Mdot
.866 .35703 Mdot
.866 .35752 Mdot
.866 .35752 Mdot
.866 .35757 Mdot
.866 .3584 Mdot
.866 .3592 Mdot
.866 .35948 Mdot
.866 .36006 Mdot
.866 .36031 Mdot
.866 .36044 Mdot
.866 .36116 Mdot
.866 .36126 Mdot
.866 .36254 Mdot
.866 .36281 Mdot
.866 .36329 Mdot
.866 .36395 Mdot
.866 .36424 Mdot
.866 .36472 Mdot
.866 .3649 Mdot
.866 .36506 Mdot
.866 .36551 Mdot
.866 .36559 Mdot
.866 .36648 Mdot
.866 .36732 Mdot
.866 .36749 Mdot
.866 .3676 Mdot
.866 .36762 Mdot
.866 .36786 Mdot
.866 .36844 Mdot
.866 .36852 Mdot
.866 .36869 Mdot
.866 .36893 Mdot
.866 .36916 Mdot
.866 .3695 Mdot
.866 .37058 Mdot
.866 .3713 Mdot
.866 .37175 Mdot
.866 .37195 Mdot
.866 .37218 Mdot
.866 .37239 Mdot
.866 .37295 Mdot
.866 .37359 Mdot
.866 .37385 Mdot
.866 .37391 Mdot
.866 .37395 Mdot
.866 .37413 Mdot
.866 .37515 Mdot
.866 .37541 Mdot
.866 .37557 Mdot
.866 .37577 Mdot
.866 .37617 Mdot
.866 .3762 Mdot
.866 .37713 Mdot
.866 .37717 Mdot
.866 .37727 Mdot
.866 .37747 Mdot
.866 .37779 Mdot
.866 .37797 Mdot
.866 .37834 Mdot
.866 .37889 Mdot
.866 .37898 Mdot
.866 .37918 Mdot
.866 .37954 Mdot
.866 .38 Mdot
.866 .38073 Mdot
.866 .38132 Mdot
.866 .38199 Mdot
.866 .38268 Mdot
.866 .38314 Mdot
.866 .38368 Mdot
.866 .38377 Mdot
.866 .38386 Mdot
.866 .38441 Mdot
.866 .38454 Mdot
.866 .38491 Mdot
.866 .38498 Mdot
.866 .38508 Mdot
.866 .38527 Mdot
.866 .38555 Mdot
.866 .38582 Mdot
.866 .38671 Mdot
.866 .38734 Mdot
.866 .38748 Mdot
.866 .38752 Mdot
.866 .38827 Mdot
.866 .38943 Mdot
.866 .38954 Mdot
.866 .39041 Mdot
.866 .39073 Mdot
.866 .39084 Mdot
.866 .3909 Mdot
.866 .39115 Mdot
.866 .39223 Mdot
.866 .39301 Mdot
.866 .39377 Mdot
.866 .39425 Mdot
.866 .39436 Mdot
.866 .39442 Mdot
.866 .39473 Mdot
.866 .39505 Mdot
.866 .39523 Mdot
.866 .39535 Mdot
.866 .39599 Mdot
.866 .39622 Mdot
.866 .39633 Mdot
.866 .39717 Mdot
.866 .39733 Mdot
.866 .39748 Mdot
.866 .39784 Mdot
.866 .39842 Mdot
.866 .39854 Mdot
.866 .3988 Mdot
.866 .39921 Mdot
.866 .39983 Mdot
.866 .4004 Mdot
.866 .40045 Mdot
.866 .40093 Mdot
.866 .40158 Mdot
.866 .40209 Mdot
.866 .40214 Mdot
.866 .4026 Mdot
.866 .40386 Mdot
.866 .40459 Mdot
.866 .40465 Mdot
.866 .40514 Mdot
.866 .40529 Mdot
.866 .40562 Mdot
.866 .40578 Mdot
.866 .40673 Mdot
.866 .40737 Mdot
.866 .40769 Mdot
.866 .40784 Mdot
.866 .4081 Mdot
.866 .40823 Mdot
.866 .40828 Mdot
.866 .40858 Mdot
.866 .40876 Mdot
.866 .40883 Mdot
.866 .40974 Mdot
.866 .41045 Mdot
.866 .4105 Mdot
.866 .41118 Mdot
.866 .41153 Mdot
.866 .4118 Mdot
.866 .41216 Mdot
.866 .41226 Mdot
.866 .41297 Mdot
.866 .41403 Mdot
.866 .41417 Mdot
.866 .41434 Mdot
.866 .41441 Mdot
.866 .41451 Mdot
.866 .41497 Mdot
.866 .41606 Mdot
.866 .41655 Mdot
.866 .41703 Mdot
.866 .41739 Mdot
.866 .41767 Mdot
.866 .4178 Mdot
.866 .41807 Mdot
.866 .41814 Mdot
.866 .41831 Mdot
.866 .41893 Mdot
.866 .41951 Mdot
.866 .41978 Mdot
.866 .42018 Mdot
.866 .42152 Mdot
.866 .42204 Mdot
.866 .4223 Mdot
.866 .42262 Mdot
.866 .42302 Mdot
.866 .42345 Mdot
.866 .42375 Mdot
.866 .42388 Mdot
.866 .42489 Mdot
.866 .42526 Mdot
.866 .4253 Mdot
.866 .42533 Mdot
.866 .42552 Mdot
.866 .42582 Mdot
.866 .42644 Mdot
.866 .42727 Mdot
.866 .42739 Mdot
.866 .42871 Mdot
.866 .42878 Mdot
.866 .42881 Mdot
.866 .42895 Mdot
.866 .42914 Mdot
.866 .42956 Mdot
.866 .42974 Mdot
.866 .43002 Mdot
.866 .43032 Mdot
.866 .43051 Mdot
.866 .43112 Mdot
.866 .43115 Mdot
.866 .43141 Mdot
.866 .43165 Mdot
.866 .4318 Mdot
.866 .4321 Mdot
.866 .43224 Mdot
.866 .43247 Mdot
.866 .4327 Mdot
.866 .43281 Mdot
.866 .43339 Mdot
.866 .43355 Mdot
.866 .43362 Mdot
.866 .43363 Mdot
.866 .4341 Mdot
.866 .43487 Mdot
.866 .43488 Mdot
.866 .43538 Mdot
.866 .43559 Mdot
.866 .43631 Mdot
.866 .43649 Mdot
.866 .43664 Mdot
.866 .43666 Mdot
.866 .43686 Mdot
.866 .43692 Mdot
.866 .43701 Mdot
.866 .43774 Mdot
.866 .43791 Mdot
.866 .43796 Mdot
.866 .43813 Mdot
.866 .43831 Mdot
.866 .43839 Mdot
.866 .43922 Mdot
.866 .4394 Mdot
.866 .43988 Mdot
.866 .44065 Mdot
.866 .44128 Mdot
.866 .44133 Mdot
.866 .44149 Mdot
.866 .44235 Mdot
.866 .44271 Mdot
.866 .44278 Mdot
.866 .4428 Mdot
.866 .4433 Mdot
.866 .44343 Mdot
.866 .44364 Mdot
.866 .44444 Mdot
.866 .44458 Mdot
.866 .44464 Mdot
.866 .44474 Mdot
.866 .44489 Mdot
.866 .445 Mdot
.866 .4456 Mdot
.866 .44581 Mdot
.866 .44605 Mdot
.866 .44682 Mdot
.866 .44719 Mdot
.866 .44723 Mdot
.866 .44735 Mdot
.866 .44737 Mdot
.866 .44776 Mdot
.866 .44793 Mdot
.866 .44829 Mdot
.866 .44868 Mdot
.866 .44883 Mdot
.866 .44901 Mdot
.866 .44903 Mdot
.866 .44976 Mdot
.866 .45005 Mdot
.866 .45069 Mdot
.866 .45081 Mdot
.866 .4514 Mdot
.866 .45173 Mdot
.866 .45175 Mdot
.866 .45227 Mdot
.866 .45279 Mdot
.866 .45299 Mdot
.866 .45387 Mdot
.866 .45402 Mdot
.866 .45443 Mdot
.866 .45493 Mdot
.866 .45504 Mdot
.866 .45564 Mdot
.866 .4558 Mdot
.866 .45583 Mdot
.866 .45607 Mdot
.866 .45663 Mdot
.866 .45712 Mdot
.866 .45736 Mdot
.866 .45763 Mdot
.866 .45793 Mdot
.866 .45858 Mdot
.866 .45864 Mdot
.866 .45882 Mdot
.866 .459 Mdot
.866 .4593 Mdot
.866 .46001 Mdot
.866 .46027 Mdot
.866 .46032 Mdot
.866 .46051 Mdot
.866 .46097 Mdot
.866 .46124 Mdot
.866 .46128 Mdot
.866 .46133 Mdot
.866 .46143 Mdot
.866 .46176 Mdot
.866 .46181 Mdot
.866 .46241 Mdot
.866 .46347 Mdot
.866 .46361 Mdot
.866 .46393 Mdot
.866 .46403 Mdot
.866 .46438 Mdot
.866 .46445 Mdot
.866 .46461 Mdot
.866 .46462 Mdot
.866 .46503 Mdot
.866 .46534 Mdot
.866 .46542 Mdot
.866 .4655 Mdot
.866 .46554 Mdot
.866 .46564 Mdot
.866 .46577 Mdot
.866 .46587 Mdot
.866 .46607 Mdot
.866 .46653 Mdot
.866 .46665 Mdot
.866 .46667 Mdot
.866 .46711 Mdot
.866 .46743 Mdot
.866 .46782 Mdot
.866 .46881 Mdot
.866 .46907 Mdot
.866 .46965 Mdot
.866 .46974 Mdot
.866 .47014 Mdot
.866 .47022 Mdot
.866 .47035 Mdot
.866 .47072 Mdot
.866 .47152 Mdot
.866 .47192 Mdot
.866 .47219 Mdot
.866 .473 Mdot
.866 .47348 Mdot
.866 .47354 Mdot
.866 .47363 Mdot
.866 .47453 Mdot
.866 .47471 Mdot
.866 .47553 Mdot
.866 .47554 Mdot
.866 .47593 Mdot
.866 .47609 Mdot
.866 .4763 Mdot
.866 .47664 Mdot
.866 .47673 Mdot
.866 .47696 Mdot
.866 .47746 Mdot
.866 .4781 Mdot
.866 .47812 Mdot
.866 .47857 Mdot
.866 .47933 Mdot
.866 .47944 Mdot
.866 .47976 Mdot
.866 .48015 Mdot
.866 .48042 Mdot
.866 .48067 Mdot
.866 .48106 Mdot
.866 .48127 Mdot
.866 .48144 Mdot
.866 .48162 Mdot
.866 .48165 Mdot
.866 .48168 Mdot
.866 .48186 Mdot
.866 .48224 Mdot
.866 .48267 Mdot
.866 .48306 Mdot
.866 .48359 Mdot
.866 .48385 Mdot
.866 .48387 Mdot
.866 .48418 Mdot
.866 .48444 Mdot
.866 .48453 Mdot
.866 .48493 Mdot
.866 .48494 Mdot
.866 .48544 Mdot
.866 .48551 Mdot
.866 .48652 Mdot
.866 .4866 Mdot
.866 .48668 Mdot
.866 .48696 Mdot
.866 .48704 Mdot
.866 .48708 Mdot
.866 .48714 Mdot
.866 .48789 Mdot
.866 .48794 Mdot
.866 .48816 Mdot
.866 .48826 Mdot
.866 .48848 Mdot
.866 .48864 Mdot
.866 .48943 Mdot
.866 .49011 Mdot
.866 .4904 Mdot
.866 .4904 Mdot
.866 .49057 Mdot
.866 .49128 Mdot
.866 .4916 Mdot
.866 .4918 Mdot
.866 .49192 Mdot
.866 .49264 Mdot
.866 .49288 Mdot
.866 .49326 Mdot
.866 .49372 Mdot
.866 .49377 Mdot
.866 .49378 Mdot
.866 .49405 Mdot
.866 .49418 Mdot
.866 .49438 Mdot
.866 .49449 Mdot
.866 .49457 Mdot
.866 .4948 Mdot
.866 .49484 Mdot
.866 .49497 Mdot
.866 .49541 Mdot
.866 .49568 Mdot
.866 .49622 Mdot
.866 .4972 Mdot
.866 .49759 Mdot
.866 .49781 Mdot
.866 .49825 Mdot
.866 .49831 Mdot
.866 .49842 Mdot
.866 .49844 Mdot
.866 .49851 Mdot
.866 .49882 Mdot
.866 .49908 Mdot
.866 .49951 Mdot
.866 .49957 Mdot
.866 .5 Mdot
.866 .50033 Mdot
.866 .50037 Mdot
.866 .50042 Mdot
.866 .50058 Mdot
.866 .50108 Mdot
.866 .50132 Mdot
.866 .50167 Mdot
.866 .50186 Mdot
.866 .50232 Mdot
.866 .50389 Mdot
.866 .50426 Mdot
.866 .50433 Mdot
.866 .50469 Mdot
.866 .50471 Mdot
.866 .50473 Mdot
.866 .50489 Mdot
.866 .50676 Mdot
.866 .50685 Mdot
.866 .50697 Mdot
.866 .50866 Mdot
.866 .50888 Mdot
.866 .50897 Mdot
.866 .50909 Mdot
.866 .50936 Mdot
.866 .50993 Mdot
.866 .50996 Mdot
.866 .51053 Mdot
.866 .51107 Mdot
.866 .5112 Mdot
.866 .51136 Mdot
.866 .51174 Mdot
.866 .512 Mdot
.866 .51247 Mdot
.866 .51257 Mdot
.866 .51285 Mdot
.866 .51349 Mdot
.866 .51355 Mdot
.866 .5136 Mdot
.866 .51379 Mdot
.866 .51406 Mdot
.866 .51432 Mdot
.866 .51481 Mdot
.866 .51485 Mdot
.866 .515 Mdot
.866 .51517 Mdot
.866 .51549 Mdot
.866 .51588 Mdot
.866 .51598 Mdot
.866 .51676 Mdot
.866 .51702 Mdot
.866 .51712 Mdot
.866 .51723 Mdot
.866 .51747 Mdot
.866 .51769 Mdot
.866 .51792 Mdot
.866 .51795 Mdot
.866 .51809 Mdot
.866 .51813 Mdot
.866 .51873 Mdot
.866 .51879 Mdot
.866 .51924 Mdot
.866 .51925 Mdot
.866 .51978 Mdot
.866 .51993 Mdot
.866 .52063 Mdot
.866 .52095 Mdot
.866 .52194 Mdot
.866 .52237 Mdot
.866 .52257 Mdot
.866 .5227 Mdot
.866 .52298 Mdot
.866 .52318 Mdot
.866 .5234 Mdot
.866 .52343 Mdot
.866 .52347 Mdot
.866 .52407 Mdot
.866 .5241 Mdot
.866 .52483 Mdot
.868 .15043 Mdot
.868 .15056 Mdot
.868 .15131 Mdot
.868 .15138 Mdot
.868 .15139 Mdot
.868 .1533 Mdot
.868 .15377 Mdot
.868 .15385 Mdot
.868 .15448 Mdot
.868 .15467 Mdot
.868 .15496 Mdot
.868 .156 Mdot
.868 .15734 Mdot
.868 .1581 Mdot
.868 .15825 Mdot
.868 .15841 Mdot
.868 .15893 Mdot
.868 .15907 Mdot
.868 .15924 Mdot
.868 .15972 Mdot
.868 .1603 Mdot
.868 .16116 Mdot
.868 .16152 Mdot
.868 .16173 Mdot
.868 .16194 Mdot
.868 .16235 Mdot
.868 .16324 Mdot
.868 .16358 Mdot
.868 .16407 Mdot
.868 .16441 Mdot
.868 .16496 Mdot
.868 .16635 Mdot
.868 .16641 Mdot
.868 .16677 Mdot
.868 .16708 Mdot
.868 .16711 Mdot
.868 .16884 Mdot
.868 .17 Mdot
.868 .17085 Mdot
.868 .17131 Mdot
.868 .17133 Mdot
.868 .1714 Mdot
.868 .17357 Mdot
.868 .17398 Mdot
.868 .17403 Mdot
.868 .17503 Mdot
.868 .17544 Mdot
.868 .17561 Mdot
.868 .17667 Mdot
.868 .17794 Mdot
.868 .17812 Mdot
.868 .17861 Mdot
.868 .17972 Mdot
.868 .18002 Mdot
.868 .18011 Mdot
.868 .18054 Mdot
.868 .18054 Mdot
.868 .18102 Mdot
.868 .18141 Mdot
.868 .18149 Mdot
.868 .18237 Mdot
.868 .18241 Mdot
.868 .18276 Mdot
.868 .18376 Mdot
.868 .18399 Mdot
.868 .18453 Mdot
.868 .18492 Mdot
.868 .1862 Mdot
.868 .18639 Mdot
.868 .18642 Mdot
.868 .18679 Mdot
.868 .18694 Mdot
.868 .18718 Mdot
.868 .18924 Mdot
.868 .19041 Mdot
.868 .19084 Mdot
.868 .19157 Mdot
.868 .19161 Mdot
.868 .19161 Mdot
.868 .19176 Mdot
.868 .19246 Mdot
.868 .19264 Mdot
.868 .19288 Mdot
.868 .19303 Mdot
.868 .19366 Mdot
.868 .1938 Mdot
.868 .1938 Mdot
.868 .19628 Mdot
.868 .19641 Mdot
.868 .19666 Mdot
.868 .19709 Mdot
.868 .1971 Mdot
.868 .19713 Mdot
.868 .19787 Mdot
.868 .19788 Mdot
.868 .19801 Mdot
.868 .19818 Mdot
.868 .19858 Mdot
.868 .19879 Mdot
.868 .20016 Mdot
.868 .20112 Mdot
.868 .20362 Mdot
.868 .20526 Mdot
.868 .20539 Mdot
.868 .20558 Mdot
.868 .20567 Mdot
.868 .20651 Mdot
.868 .20669 Mdot
.868 .20759 Mdot
.868 .20774 Mdot
.868 .20777 Mdot
.868 .20799 Mdot
.868 .20939 Mdot
.868 .21019 Mdot
.868 .21085 Mdot
.868 .21149 Mdot
.868 .21218 Mdot
.868 .21224 Mdot
.868 .21284 Mdot
.868 .21312 Mdot
.868 .2132 Mdot
.868 .21336 Mdot
.868 .21509 Mdot
.868 .21514 Mdot
.868 .21527 Mdot
.868 .21548 Mdot
.868 .21645 Mdot
.868 .21732 Mdot
.868 .21767 Mdot
.868 .21795 Mdot
.868 .21813 Mdot
.868 .21824 Mdot
.868 .21826 Mdot
.868 .21828 Mdot
.868 .21913 Mdot
.868 .21913 Mdot
.868 .2192 Mdot
.868 .2194 Mdot
.868 .21951 Mdot
.868 .21951 Mdot
.868 .21961 Mdot
.868 .21978 Mdot
.868 .21988 Mdot
.868 .21994 Mdot
.868 .22079 Mdot
.868 .2218 Mdot
.868 .22201 Mdot
.868 .22252 Mdot
.868 .22255 Mdot
.868 .22288 Mdot
.868 .22398 Mdot
.868 .22412 Mdot
.868 .22472 Mdot
.868 .22501 Mdot
.868 .22622 Mdot
.868 .22648 Mdot
.868 .22706 Mdot
.868 .22749 Mdot
.868 .22777 Mdot
.868 .22806 Mdot
.868 .22845 Mdot
.868 .22853 Mdot
.868 .2307 Mdot
.868 .23099 Mdot
.868 .23099 Mdot
.868 .23114 Mdot
.868 .23159 Mdot
.868 .23167 Mdot
.868 .23254 Mdot
.868 .23306 Mdot
.868 .23613 Mdot
.868 .23652 Mdot
.868 .23773 Mdot
.868 .23845 Mdot
.868 .23856 Mdot
.868 .23894 Mdot
.868 .24028 Mdot
.868 .24116 Mdot
.868 .24128 Mdot
.868 .24154 Mdot
.868 .24158 Mdot
.868 .24174 Mdot
.868 .2419 Mdot
.868 .24339 Mdot
.868 .24405 Mdot
.868 .24524 Mdot
.868 .24557 Mdot
.868 .24583 Mdot
.868 .24775 Mdot
.868 .24844 Mdot
.868 .24921 Mdot
.868 .25032 Mdot
.868 .25055 Mdot
.868 .25076 Mdot
.868 .25184 Mdot
.868 .25197 Mdot
.868 .25199 Mdot
.868 .25222 Mdot
.868 .25286 Mdot
.868 .2533 Mdot
.868 .25373 Mdot
.868 .25431 Mdot
.868 .2553 Mdot
.868 .25574 Mdot
.868 .25612 Mdot
.868 .25625 Mdot
.868 .25735 Mdot
.868 .25749 Mdot
.868 .25759 Mdot
.868 .25767 Mdot
.868 .25782 Mdot
.868 .25818 Mdot
.868 .25849 Mdot
.868 .25857 Mdot
.868 .25949 Mdot
.868 .25996 Mdot
.868 .25999 Mdot
.868 .26005 Mdot
.868 .26127 Mdot
.868 .26182 Mdot
.868 .26231 Mdot
.868 .26322 Mdot
.868 .26363 Mdot
.868 .26389 Mdot
.868 .26417 Mdot
.868 .26434 Mdot
.868 .26459 Mdot
.868 .26508 Mdot
.868 .26528 Mdot
.868 .26532 Mdot
.868 .2656 Mdot
.868 .26567 Mdot
.868 .26568 Mdot
.868 .26621 Mdot
.868 .26644 Mdot
.868 .26648 Mdot
.868 .26663 Mdot
.868 .26676 Mdot
.868 .2668 Mdot
.868 .26704 Mdot
.868 .26724 Mdot
.868 .26745 Mdot
.868 .26794 Mdot
.868 .26864 Mdot
.868 .26894 Mdot
.868 .26954 Mdot
.868 .26957 Mdot
.868 .26972 Mdot
.868 .26994 Mdot
.868 .27 Mdot
.868 .2703 Mdot
.868 .27039 Mdot
.868 .27053 Mdot
.868 .27076 Mdot
.868 .27083 Mdot
.868 .27092 Mdot
.868 .27097 Mdot
.868 .27102 Mdot
.868 .27128 Mdot
.868 .2721 Mdot
.868 .27256 Mdot
.868 .27274 Mdot
.868 .27315 Mdot
.868 .27364 Mdot
.868 .274 Mdot
.868 .27458 Mdot
.868 .27553 Mdot
.868 .27575 Mdot
.868 .27723 Mdot
.868 .27787 Mdot
.868 .27795 Mdot
.868 .27806 Mdot
.868 .27846 Mdot
.868 .27868 Mdot
.868 .27917 Mdot
.868 .27923 Mdot
.868 .27928 Mdot
.868 .27929 Mdot
.868 .27938 Mdot
.868 .27942 Mdot
.868 .27971 Mdot
.868 .28015 Mdot
.868 .28028 Mdot
.868 .28056 Mdot
.868 .28096 Mdot
.868 .28228 Mdot
.868 .28256 Mdot
.868 .28259 Mdot
.868 .28279 Mdot
.868 .28361 Mdot
.868 .28363 Mdot
.868 .28376 Mdot
.868 .28409 Mdot
.868 .28429 Mdot
.868 .28438 Mdot
.868 .28559 Mdot
.868 .28577 Mdot
.868 .28584 Mdot
.868 .28657 Mdot
.868 .2866 Mdot
.868 .2866 Mdot
.868 .28664 Mdot
.868 .28673 Mdot
.868 .28701 Mdot
.868 .28706 Mdot
.868 .28712 Mdot
.868 .28733 Mdot
.868 .28794 Mdot
.868 .28869 Mdot
.868 .28872 Mdot
.868 .28969 Mdot
.868 .28996 Mdot
.868 .29042 Mdot
.868 .29049 Mdot
.868 .29086 Mdot
.868 .29091 Mdot
.868 .29119 Mdot
.868 .29129 Mdot
.868 .2927 Mdot
.868 .29302 Mdot
.868 .29373 Mdot
.868 .29404 Mdot
.868 .29404 Mdot
.868 .29418 Mdot
.868 .29431 Mdot
.868 .29586 Mdot
.868 .29587 Mdot
.868 .29746 Mdot
.868 .29808 Mdot
.868 .29839 Mdot
.868 .29879 Mdot
.868 .29891 Mdot
.868 .29922 Mdot
.868 .29924 Mdot
.868 .29937 Mdot
.868 .29953 Mdot
.868 .2997 Mdot
.868 .2998 Mdot
.868 .30017 Mdot
.868 .30039 Mdot
.868 .30117 Mdot
.868 .30122 Mdot
.868 .30136 Mdot
.868 .30169 Mdot
.868 .30184 Mdot
.868 .30259 Mdot
.868 .30259 Mdot
.868 .30275 Mdot
.868 .30341 Mdot
.868 .304 Mdot
.868 .3041 Mdot
.868 .30422 Mdot
.868 .30424 Mdot
.868 .30489 Mdot
.868 .30516 Mdot
.868 .30577 Mdot
.868 .30584 Mdot
.868 .30625 Mdot
.868 .30644 Mdot
.868 .3067 Mdot
.868 .30693 Mdot
.868 .30723 Mdot
.868 .30767 Mdot
.868 .30818 Mdot
.868 .30857 Mdot
.868 .30923 Mdot
.868 .30948 Mdot
.868 .30952 Mdot
.868 .31019 Mdot
.868 .31019 Mdot
.868 .31098 Mdot
.868 .311 Mdot
.868 .31128 Mdot
.868 .31137 Mdot
.868 .31242 Mdot
.868 .31252 Mdot
.868 .31274 Mdot
.868 .31279 Mdot
.868 .31343 Mdot
.868 .31369 Mdot
.868 .31383 Mdot
.868 .31412 Mdot
.868 .3144 Mdot
.868 .31469 Mdot
.868 .31541 Mdot
.868 .31636 Mdot
.868 .31683 Mdot
.868 .31768 Mdot
.868 .31858 Mdot
.868 .31906 Mdot
.868 .31972 Mdot
.868 .31986 Mdot
.868 .32047 Mdot
.868 .32093 Mdot
.868 .32119 Mdot
.868 .32174 Mdot
.868 .3218 Mdot
.868 .32181 Mdot
.868 .32198 Mdot
.868 .32207 Mdot
.868 .32275 Mdot
.868 .32314 Mdot
.868 .32328 Mdot
.868 .32353 Mdot
.868 .32358 Mdot
.868 .32382 Mdot
.868 .32387 Mdot
.868 .32395 Mdot
.868 .324 Mdot
.868 .32422 Mdot
.868 .32426 Mdot
.868 .32426 Mdot
.868 .32513 Mdot
.868 .32537 Mdot
.868 .32561 Mdot
.868 .32562 Mdot
.868 .32572 Mdot
.868 .32585 Mdot
.868 .32592 Mdot
.868 .32752 Mdot
.868 .32806 Mdot
.868 .32817 Mdot
.868 .32884 Mdot
.868 .32889 Mdot
.868 .32992 Mdot
.868 .33013 Mdot
.868 .33036 Mdot
.868 .33038 Mdot
.868 .33058 Mdot
.868 .33075 Mdot
.868 .33133 Mdot
.868 .33134 Mdot
.868 .33139 Mdot
.868 .33178 Mdot
.868 .33218 Mdot
.868 .33237 Mdot
.868 .33238 Mdot
.868 .33267 Mdot
.868 .33269 Mdot
.868 .33288 Mdot
.868 .33292 Mdot
.868 .33294 Mdot
.868 .33322 Mdot
.868 .33379 Mdot
.868 .33391 Mdot
.868 .33428 Mdot
.868 .33432 Mdot
.868 .33452 Mdot
.868 .33462 Mdot
.868 .33544 Mdot
.868 .33553 Mdot
.868 .3365 Mdot
.868 .3366 Mdot
.868 .33665 Mdot
.868 .33729 Mdot
.868 .33831 Mdot
.868 .33908 Mdot
.868 .34239 Mdot
.868 .34265 Mdot
.868 .34316 Mdot
.868 .34401 Mdot
.868 .34415 Mdot
.868 .34434 Mdot
.868 .34543 Mdot
.868 .3455 Mdot
.868 .34573 Mdot
.868 .34606 Mdot
.868 .34621 Mdot
.868 .34767 Mdot
.868 .34775 Mdot
.868 .34798 Mdot
.868 .34811 Mdot
.868 .34829 Mdot
.868 .34849 Mdot
.868 .34955 Mdot
.868 .34972 Mdot
.868 .3498 Mdot
.868 .34987 Mdot
.868 .34997 Mdot
.868 .35024 Mdot
.868 .35266 Mdot
.868 .35267 Mdot
.868 .35305 Mdot
.868 .35406 Mdot
.868 .35422 Mdot
.868 .35472 Mdot
.868 .35507 Mdot
.868 .35519 Mdot
.868 .35521 Mdot
.868 .35529 Mdot
.868 .35575 Mdot
.868 .35608 Mdot
.868 .35632 Mdot
.868 .35647 Mdot
.868 .35649 Mdot
.868 .35752 Mdot
.868 .35761 Mdot
.868 .35866 Mdot
.868 .3591 Mdot
.868 .35914 Mdot
.868 .35924 Mdot
.868 .35929 Mdot
.868 .35956 Mdot
.868 .35963 Mdot
.868 .35995 Mdot
.868 .36041 Mdot
.868 .36112 Mdot
.868 .36256 Mdot
.868 .36265 Mdot
.868 .36288 Mdot
.868 .36315 Mdot
.868 .36324 Mdot
.868 .36428 Mdot
.868 .36437 Mdot
.868 .36461 Mdot
.868 .36493 Mdot
.868 .36645 Mdot
.868 .36679 Mdot
.868 .36705 Mdot
.868 .36731 Mdot
.868 .36745 Mdot
.868 .36754 Mdot
.868 .36784 Mdot
.868 .36803 Mdot
.868 .36808 Mdot
.868 .3681 Mdot
.868 .36881 Mdot
.868 .36909 Mdot
.868 .36957 Mdot
.868 .36958 Mdot
.868 .3697 Mdot
.868 .37004 Mdot
.868 .37024 Mdot
.868 .37025 Mdot
.868 .37041 Mdot
.868 .37043 Mdot
.868 .37071 Mdot
.868 .37089 Mdot
.868 .37099 Mdot
.868 .37126 Mdot
.868 .37129 Mdot
.868 .37161 Mdot
.868 .37187 Mdot
.868 .37247 Mdot
.868 .3741 Mdot
.868 .37421 Mdot
.868 .37457 Mdot
.868 .37546 Mdot
.868 .37552 Mdot
.868 .37559 Mdot
.868 .37608 Mdot
.868 .37697 Mdot
.868 .3771 Mdot
.868 .37777 Mdot
.868 .378 Mdot
.868 .37824 Mdot
.868 .37916 Mdot
.868 .37929 Mdot
.868 .37939 Mdot
.868 .37955 Mdot
.868 .37978 Mdot
.868 .38086 Mdot
.868 .38183 Mdot
.868 .38188 Mdot
.868 .38233 Mdot
.868 .38242 Mdot
.868 .38315 Mdot
.868 .38316 Mdot
.868 .38335 Mdot
.868 .38409 Mdot
.868 .38458 Mdot
.868 .38504 Mdot
.868 .38508 Mdot
.868 .38531 Mdot
.868 .38577 Mdot
.868 .38584 Mdot
.868 .3859 Mdot
.868 .38665 Mdot
.868 .38709 Mdot
.868 .38709 Mdot
.868 .38799 Mdot
.868 .38966 Mdot
.868 .39017 Mdot
.868 .39018 Mdot
.868 .39043 Mdot
.868 .39089 Mdot
.868 .3912 Mdot
.868 .39136 Mdot
.868 .39244 Mdot
.868 .39245 Mdot
.868 .39286 Mdot
.868 .3932 Mdot
.868 .39376 Mdot
.868 .39452 Mdot
.868 .39461 Mdot
.868 .39475 Mdot
.868 .39554 Mdot
.868 .39593 Mdot
.868 .396 Mdot
.868 .3968 Mdot
.868 .39766 Mdot
.868 .39894 Mdot
.868 .39909 Mdot
.868 .39928 Mdot
.868 .39929 Mdot
.868 .39977 Mdot
.868 .40055 Mdot
.868 .4007 Mdot
.868 .40149 Mdot
.868 .40157 Mdot
.868 .40187 Mdot
.868 .40312 Mdot
.868 .40326 Mdot
.868 .40332 Mdot
.868 .40397 Mdot
.868 .40514 Mdot
.868 .40554 Mdot
.868 .40581 Mdot
.868 .40599 Mdot
.868 .40622 Mdot
.868 .4063 Mdot
.868 .40781 Mdot
.868 .40782 Mdot
.868 .40804 Mdot
.868 .40823 Mdot
.868 .40849 Mdot
.868 .40855 Mdot
.868 .40862 Mdot
.868 .40882 Mdot
.868 .40911 Mdot
.868 .40979 Mdot
.868 .41001 Mdot
.868 .41156 Mdot
.868 .4117 Mdot
.868 .41241 Mdot
.868 .41253 Mdot
.868 .41263 Mdot
.868 .41284 Mdot
.868 .41417 Mdot
.868 .4148 Mdot
.868 .41491 Mdot
.868 .41499 Mdot
.868 .41548 Mdot
.868 .41592 Mdot
.868 .41783 Mdot
.868 .41886 Mdot
.868 .41926 Mdot
.868 .41932 Mdot
.868 .41987 Mdot
.868 .41993 Mdot
.868 .4204 Mdot
.868 .42046 Mdot
.868 .42057 Mdot
.868 .42088 Mdot
.868 .42137 Mdot
.868 .4214 Mdot
.868 .42169 Mdot
.868 .4217 Mdot
.868 .4218 Mdot
.868 .42204 Mdot
.868 .42263 Mdot
.868 .42284 Mdot
.868 .42285 Mdot
.868 .4237 Mdot
.868 .42373 Mdot
.868 .42412 Mdot
.868 .42418 Mdot
.868 .42449 Mdot
.868 .42541 Mdot
.868 .42545 Mdot
.868 .42553 Mdot
.868 .42587 Mdot
.868 .42637 Mdot
.868 .42639 Mdot
.868 .42654 Mdot
.868 .42659 Mdot
.868 .42662 Mdot
.868 .42679 Mdot
.868 .42702 Mdot
.868 .42724 Mdot
.868 .42768 Mdot
.868 .42814 Mdot
.868 .42829 Mdot
.868 .4289 Mdot
.868 .42936 Mdot
.868 .42964 Mdot
.868 .43065 Mdot
.868 .43092 Mdot
.868 .43147 Mdot
.868 .43188 Mdot
.868 .43205 Mdot
.868 .43238 Mdot
.868 .43313 Mdot
.868 .43379 Mdot
.868 .43385 Mdot
.868 .434 Mdot
.868 .43402 Mdot
.868 .43447 Mdot
.868 .43488 Mdot
.868 .43503 Mdot
.868 .43592 Mdot
.868 .43618 Mdot
.868 .43635 Mdot
.868 .43648 Mdot
.868 .43674 Mdot
.868 .43737 Mdot
.868 .43753 Mdot
.868 .43791 Mdot
.868 .43804 Mdot
.868 .43876 Mdot
.868 .43956 Mdot
.868 .43964 Mdot
.868 .44012 Mdot
.868 .44024 Mdot
.868 .44046 Mdot
.868 .44051 Mdot
.868 .44061 Mdot
.868 .4407 Mdot
.868 .44079 Mdot
.868 .44097 Mdot
.868 .44104 Mdot
.868 .44181 Mdot
.868 .44273 Mdot
.868 .44362 Mdot
.868 .44369 Mdot
.868 .44378 Mdot
.868 .44455 Mdot
.868 .44558 Mdot
.868 .44561 Mdot
.868 .44586 Mdot
.868 .44613 Mdot
.868 .44628 Mdot
.868 .44684 Mdot
.868 .44686 Mdot
.868 .44729 Mdot
.868 .44764 Mdot
.868 .44776 Mdot
.868 .4478 Mdot
.868 .44782 Mdot
.868 .44804 Mdot
.868 .44806 Mdot
.868 .4485 Mdot
.868 .44864 Mdot
.868 .44934 Mdot
.868 .44951 Mdot
.868 .4497 Mdot
.868 .44977 Mdot
.868 .44979 Mdot
.868 .45026 Mdot
.868 .45037 Mdot
.868 .45039 Mdot
.868 .45131 Mdot
.868 .45154 Mdot
.868 .4517 Mdot
.868 .45178 Mdot
.868 .45203 Mdot
.868 .4522 Mdot
.868 .45222 Mdot
.868 .45227 Mdot
.868 .45234 Mdot
.868 .45275 Mdot
.868 .45309 Mdot
.868 .45346 Mdot
.868 .45431 Mdot
.868 .45553 Mdot
.868 .45604 Mdot
.868 .45642 Mdot
.868 .45689 Mdot
.868 .45707 Mdot
.868 .45709 Mdot
.868 .45715 Mdot
.868 .45718 Mdot
.868 .45732 Mdot
.868 .4574 Mdot
.868 .45762 Mdot
.868 .45779 Mdot
.868 .45789 Mdot
.868 .45841 Mdot
.868 .45856 Mdot
.868 .45881 Mdot
.868 .45922 Mdot
.868 .45933 Mdot
.868 .45947 Mdot
.868 .45949 Mdot
.868 .45957 Mdot
.868 .45965 Mdot
.868 .45981 Mdot
.868 .46011 Mdot
.868 .46012 Mdot
.868 .46034 Mdot
.868 .46074 Mdot
.868 .46089 Mdot
.868 .46153 Mdot
.868 .46233 Mdot
.868 .46265 Mdot
.868 .46336 Mdot
.868 .46341 Mdot
.868 .46368 Mdot
.868 .46421 Mdot
.868 .46425 Mdot
.868 .46464 Mdot
.868 .46477 Mdot
.868 .46483 Mdot
.868 .46584 Mdot
.868 .46666 Mdot
.868 .467 Mdot
.868 .46724 Mdot
.868 .4675 Mdot
.868 .46787 Mdot
.868 .46871 Mdot
.868 .4696 Mdot
.868 .47004 Mdot
.868 .47044 Mdot
.868 .47155 Mdot
.868 .4717 Mdot
.868 .47188 Mdot
.868 .47257 Mdot
.868 .47295 Mdot
.868 .47381 Mdot
.868 .47391 Mdot
.868 .474 Mdot
.868 .47402 Mdot
.868 .47417 Mdot
.868 .47424 Mdot
.868 .47474 Mdot
.868 .47552 Mdot
.868 .47573 Mdot
.868 .4758 Mdot
.868 .47621 Mdot
.868 .47691 Mdot
.868 .47713 Mdot
.868 .4789 Mdot
.868 .4792 Mdot
.868 .4797 Mdot
.868 .47975 Mdot
.868 .48001 Mdot
.868 .48009 Mdot
.868 .48009 Mdot
.868 .48026 Mdot
.868 .48151 Mdot
.868 .48156 Mdot
.868 .48178 Mdot
.868 .48195 Mdot
.868 .48211 Mdot
.868 .48236 Mdot
.868 .4827 Mdot
.868 .48285 Mdot
.868 .48354 Mdot
.868 .48371 Mdot
.868 .48405 Mdot
.868 .48413 Mdot
.868 .48477 Mdot
.868 .48495 Mdot
.868 .48497 Mdot
.868 .48527 Mdot
.868 .48539 Mdot
.868 .48597 Mdot
.868 .48646 Mdot
.868 .48649 Mdot
.868 .48655 Mdot
.868 .48665 Mdot
.868 .48671 Mdot
.868 .48671 Mdot
.868 .48677 Mdot
.868 .48689 Mdot
.868 .48693 Mdot
.868 .48693 Mdot
.868 .48742 Mdot
.868 .48743 Mdot
.868 .48744 Mdot
.868 .48751 Mdot
.868 .48761 Mdot
.868 .48777 Mdot
.868 .48797 Mdot
.868 .48847 Mdot
.868 .48903 Mdot
.868 .48915 Mdot
.868 .48923 Mdot
.868 .48926 Mdot
.868 .49025 Mdot
.868 .49034 Mdot
.868 .49039 Mdot
.868 .49055 Mdot
.868 .4909 Mdot
.868 .49093 Mdot
.868 .49133 Mdot
.868 .4917 Mdot
.868 .49208 Mdot
.868 .49254 Mdot
.868 .49334 Mdot
.868 .49347 Mdot
.868 .49349 Mdot
.868 .49357 Mdot
.868 .49409 Mdot
.868 .4942 Mdot
.868 .49468 Mdot
.868 .49473 Mdot
.868 .49484 Mdot
.868 .49492 Mdot
.868 .49586 Mdot
.868 .4973 Mdot
.868 .49785 Mdot
.868 .49864 Mdot
.868 .49876 Mdot
.868 .49899 Mdot
.868 .49909 Mdot
.868 .49917 Mdot
.868 .49918 Mdot
.868 .4996 Mdot
.868 .49962 Mdot
.868 .49962 Mdot
.868 .49987 Mdot
.868 .50002 Mdot
.868 .50009 Mdot
.868 .50152 Mdot
.868 .50152 Mdot
.868 .5016 Mdot
.868 .50196 Mdot
.868 .50205 Mdot
.868 .50219 Mdot
.868 .50229 Mdot
.868 .50269 Mdot
.868 .50278 Mdot
.868 .50278 Mdot
.868 .5028 Mdot
.868 .50322 Mdot
.868 .50347 Mdot
.868 .50415 Mdot
.868 .50533 Mdot
.868 .50547 Mdot
.868 .50556 Mdot
.868 .50577 Mdot
.868 .50579 Mdot
.868 .5059 Mdot
.868 .50663 Mdot
.868 .50686 Mdot
.868 .50717 Mdot
.868 .5073 Mdot
.868 .50788 Mdot
.868 .50808 Mdot
.868 .5081 Mdot
.868 .50861 Mdot
.868 .50865 Mdot
.868 .50888 Mdot
.868 .50915 Mdot
.868 .50916 Mdot
.868 .5094 Mdot
.868 .50945 Mdot
.868 .50963 Mdot
.868 .51027 Mdot
.868 .51055 Mdot
.868 .51065 Mdot
.868 .51139 Mdot
.868 .51199 Mdot
.868 .51209 Mdot
.868 .51233 Mdot
.868 .51291 Mdot
.868 .51294 Mdot
.868 .51317 Mdot
.868 .51442 Mdot
.868 .51446 Mdot
.868 .51447 Mdot
.868 .51474 Mdot
.868 .51523 Mdot
.868 .5159 Mdot
.868 .51689 Mdot
.868 .51691 Mdot
.868 .51709 Mdot
.868 .51729 Mdot
.868 .51733 Mdot
.868 .51813 Mdot
.868 .51845 Mdot
.868 .51864 Mdot
.868 .51892 Mdot
.868 .51912 Mdot
.868 .51963 Mdot
.868 .51987 Mdot
.868 .51999 Mdot
.868 .52011 Mdot
.868 .52032 Mdot
.868 .52082 Mdot
.868 .52115 Mdot
.868 .52143 Mdot
.868 .52152 Mdot
.868 .5216 Mdot
.868 .5219 Mdot
.868 .522 Mdot
.868 .52208 Mdot
.868 .52252 Mdot
.868 .52329 Mdot
.868 .52389 Mdot
.868 .52406 Mdot
.868 .52417 Mdot
.868 .52453 Mdot
.868 .52458 Mdot
.868 .52485 Mdot
.868 .52595 Mdot
.868 .52595 Mdot
.868 .52599 Mdot
.868 .52643 Mdot
.868 .5265 Mdot
.87 .14829 Mdot
.87 .14835 Mdot
.87 .14862 Mdot
.87 .14907 Mdot
.87 .14909 Mdot
.87 .14918 Mdot
.87 .14939 Mdot
.87 .1502 Mdot
.87 .15104 Mdot
.87 .15121 Mdot
.87 .15178 Mdot
.87 .15357 Mdot
.87 .15364 Mdot
.87 .15395 Mdot
.87 .15402 Mdot
.87 .15458 Mdot
.87 .15513 Mdot
.87 .15517 Mdot
.87 .15578 Mdot
.87 .15584 Mdot
.87 .15627 Mdot
.87 .15669 Mdot
.87 .15712 Mdot
.87 .15778 Mdot
.87 .15853 Mdot
.87 .15948 Mdot
.87 .15954 Mdot
.87 .15978 Mdot
.87 .16007 Mdot
.87 .16093 Mdot
.87 .1615 Mdot
.87 .16167 Mdot
.87 .16306 Mdot
.87 .1631 Mdot
.87 .16346 Mdot
.87 .16414 Mdot
.87 .16492 Mdot
.87 .16579 Mdot
.87 .16603 Mdot
.87 .16659 Mdot
.87 .16801 Mdot
.87 .16822 Mdot
.87 .16875 Mdot
.87 .16907 Mdot
.87 .16918 Mdot
.87 .16923 Mdot
.87 .17008 Mdot
.87 .17201 Mdot
.87 .17237 Mdot
.87 .17269 Mdot
.87 .17279 Mdot
.87 .17329 Mdot
.87 .17343 Mdot
.87 .17348 Mdot
.87 .1741 Mdot
.87 .17415 Mdot
.87 .17454 Mdot
.87 .17501 Mdot
.87 .17684 Mdot
.87 .17759 Mdot
.87 .17786 Mdot
.87 .17931 Mdot
.87 .17932 Mdot
.87 .17959 Mdot
.87 .18168 Mdot
.87 .18182 Mdot
.87 .18242 Mdot
.87 .18263 Mdot
.87 .18292 Mdot
.87 .18303 Mdot
.87 .18315 Mdot
.87 .18322 Mdot
.87 .18405 Mdot
.87 .18416 Mdot
.87 .18422 Mdot
.87 .18482 Mdot
.87 .18569 Mdot
.87 .18594 Mdot
.87 .18645 Mdot
.87 .18715 Mdot
.87 .18742 Mdot
.87 .18824 Mdot
.87 .18877 Mdot
.87 .18904 Mdot
.87 .19075 Mdot
.87 .19086 Mdot
.87 .19108 Mdot
.87 .1917 Mdot
.87 .19185 Mdot
.87 .19233 Mdot
.87 .19679 Mdot
.87 .19776 Mdot
.87 .19805 Mdot
.87 .19919 Mdot
.87 .1993 Mdot
.87 .20087 Mdot
.87 .20136 Mdot
.87 .20161 Mdot
.87 .20217 Mdot
.87 .20225 Mdot
.87 .20413 Mdot
.87 .20416 Mdot
.87 .20454 Mdot
.87 .20462 Mdot
.87 .20489 Mdot
.87 .20513 Mdot
.87 .20587 Mdot
.87 .20624 Mdot
.87 .20638 Mdot
.87 .20673 Mdot
.87 .20851 Mdot
.87 .20852 Mdot
.87 .20901 Mdot
.87 .21064 Mdot
.87 .21074 Mdot
.87 .21112 Mdot
.87 .21261 Mdot
.87 .21426 Mdot
.87 .21468 Mdot
.87 .21485 Mdot
.87 .21503 Mdot
.87 .21509 Mdot
.87 .2162 Mdot
.87 .21628 Mdot
.87 .21688 Mdot
.87 .21844 Mdot
.87 .21882 Mdot
.87 .21939 Mdot
.87 .21966 Mdot
.87 .21988 Mdot
.87 .22009 Mdot
.87 .22087 Mdot
.87 .22181 Mdot
.87 .22276 Mdot
.87 .224 Mdot
.87 .22476 Mdot
.87 .22547 Mdot
.87 .2269 Mdot
.87 .22715 Mdot
.87 .22728 Mdot
.87 .22736 Mdot
.87 .22746 Mdot
.87 .22753 Mdot
.87 .22754 Mdot
.87 .2281 Mdot
.87 .22918 Mdot
.87 .22979 Mdot
.87 .23077 Mdot
.87 .23078 Mdot
.87 .23138 Mdot
.87 .23157 Mdot
.87 .23258 Mdot
.87 .23259 Mdot
.87 .23261 Mdot
.87 .23369 Mdot
.87 .23392 Mdot
.87 .23402 Mdot
.87 .23572 Mdot
.87 .23801 Mdot
.87 .23809 Mdot
.87 .23831 Mdot
.87 .23963 Mdot
.87 .24117 Mdot
.87 .24214 Mdot
.87 .24217 Mdot
.87 .2422 Mdot
.87 .24254 Mdot
.87 .24259 Mdot
.87 .24303 Mdot
.87 .24317 Mdot
.87 .24321 Mdot
.87 .24321 Mdot
.87 .24402 Mdot
.87 .24413 Mdot
.87 .24476 Mdot
.87 .24536 Mdot
.87 .24653 Mdot
.87 .24699 Mdot
.87 .24713 Mdot
.87 .24724 Mdot
.87 .2477 Mdot
.87 .2485 Mdot
.87 .24852 Mdot
.87 .24868 Mdot
.87 .24885 Mdot
.87 .24905 Mdot
.87 .24995 Mdot
.87 .24999 Mdot
.87 .25001 Mdot
.87 .25023 Mdot
.87 .25024 Mdot
.87 .25045 Mdot
.87 .25158 Mdot
.87 .25159 Mdot
.87 .25191 Mdot
.87 .25222 Mdot
.87 .25294 Mdot
.87 .2531 Mdot
.87 .25321 Mdot
.87 .25405 Mdot
.87 .25416 Mdot
.87 .25433 Mdot
.87 .25472 Mdot
.87 .2551 Mdot
.87 .25546 Mdot
.87 .25551 Mdot
.87 .25632 Mdot
.87 .25644 Mdot
.87 .25648 Mdot
.87 .25694 Mdot
.87 .25698 Mdot
.87 .25711 Mdot
.87 .25764 Mdot
.87 .25797 Mdot
.87 .25809 Mdot
.87 .25817 Mdot
.87 .25829 Mdot
.87 .25903 Mdot
.87 .2591 Mdot
.87 .25955 Mdot
.87 .25974 Mdot
.87 .26 Mdot
.87 .2601 Mdot
.87 .26014 Mdot
.87 .26016 Mdot
.87 .26026 Mdot
.87 .26028 Mdot
.87 .26044 Mdot
.87 .261 Mdot
.87 .26102 Mdot
.87 .26116 Mdot
.87 .26175 Mdot
.87 .26209 Mdot
.87 .2625 Mdot
.87 .26321 Mdot
.87 .26364 Mdot
.87 .26405 Mdot
.87 .26438 Mdot
.87 .26478 Mdot
.87 .26496 Mdot
.87 .26518 Mdot
.87 .26536 Mdot
.87 .26555 Mdot
.87 .2666 Mdot
.87 .2666 Mdot
.87 .26671 Mdot
.87 .26707 Mdot
.87 .26712 Mdot
.87 .26763 Mdot
.87 .26763 Mdot
.87 .26797 Mdot
.87 .26854 Mdot
.87 .26859 Mdot
.87 .26865 Mdot
.87 .26889 Mdot
.87 .26913 Mdot
.87 .26915 Mdot
.87 .27013 Mdot
.87 .27024 Mdot
.87 .27042 Mdot
.87 .27092 Mdot
.87 .27099 Mdot
.87 .2717 Mdot
.87 .27243 Mdot
.87 .27261 Mdot
.87 .27276 Mdot
.87 .27284 Mdot
.87 .27291 Mdot
.87 .27343 Mdot
.87 .27354 Mdot
.87 .27426 Mdot
.87 .2745 Mdot
.87 .27469 Mdot
.87 .27472 Mdot
.87 .27553 Mdot
.87 .27554 Mdot
.87 .27598 Mdot
.87 .27606 Mdot
.87 .27606 Mdot
.87 .27608 Mdot
.87 .27706 Mdot
.87 .27721 Mdot
.87 .27759 Mdot
.87 .27779 Mdot
.87 .278 Mdot
.87 .27804 Mdot
.87 .2783 Mdot
.87 .27832 Mdot
.87 .27852 Mdot
.87 .27864 Mdot
.87 .27865 Mdot
.87 .27866 Mdot
.87 .27898 Mdot
.87 .28134 Mdot
.87 .28145 Mdot
.87 .28181 Mdot
.87 .28181 Mdot
.87 .28241 Mdot
.87 .28274 Mdot
.87 .28294 Mdot
.87 .28329 Mdot
.87 .28348 Mdot
.87 .28357 Mdot
.87 .28361 Mdot
.87 .28416 Mdot
.87 .2844 Mdot
.87 .28506 Mdot
.87 .28537 Mdot
.87 .28636 Mdot
.87 .2872 Mdot
.87 .28723 Mdot
.87 .28759 Mdot
.87 .28767 Mdot
.87 .28773 Mdot
.87 .28841 Mdot
.87 .2889 Mdot
.87 .28903 Mdot
.87 .2896 Mdot
.87 .28976 Mdot
.87 .28977 Mdot
.87 .29064 Mdot
.87 .29088 Mdot
.87 .29096 Mdot
.87 .29105 Mdot
.87 .29204 Mdot
.87 .29213 Mdot
.87 .29229 Mdot
.87 .29281 Mdot
.87 .29322 Mdot
.87 .29331 Mdot
.87 .29364 Mdot
.87 .29511 Mdot
.87 .29552 Mdot
.87 .29559 Mdot
.87 .2962 Mdot
.87 .29682 Mdot
.87 .2973 Mdot
.87 .29759 Mdot
.87 .29779 Mdot
.87 .29784 Mdot
.87 .29812 Mdot
.87 .29814 Mdot
.87 .29822 Mdot
.87 .29831 Mdot
.87 .29858 Mdot
.87 .29863 Mdot
.87 .29941 Mdot
.87 .29998 Mdot
.87 .30111 Mdot
.87 .30113 Mdot
.87 .30134 Mdot
.87 .3014 Mdot
.87 .30156 Mdot
.87 .30159 Mdot
.87 .3038 Mdot
.87 .30442 Mdot
.87 .30476 Mdot
.87 .30523 Mdot
.87 .30529 Mdot
.87 .30548 Mdot
.87 .30577 Mdot
.87 .30627 Mdot
.87 .30652 Mdot
.87 .30688 Mdot
.87 .30738 Mdot
.87 .3074 Mdot
.87 .30758 Mdot
.87 .30776 Mdot
.87 .30779 Mdot
.87 .30789 Mdot
.87 .30791 Mdot
.87 .3085 Mdot
.87 .30929 Mdot
.87 .30936 Mdot
.87 .30939 Mdot
.87 .3094 Mdot
.87 .30955 Mdot
.87 .30966 Mdot
.87 .30976 Mdot
.87 .31037 Mdot
.87 .31064 Mdot
.87 .3107 Mdot
.87 .31221 Mdot
.87 .31223 Mdot
.87 .31237 Mdot
.87 .31265 Mdot
.87 .31343 Mdot
.87 .31345 Mdot
.87 .31353 Mdot
.87 .31462 Mdot
.87 .31475 Mdot
.87 .31523 Mdot
.87 .31552 Mdot
.87 .31578 Mdot
.87 .31625 Mdot
.87 .31632 Mdot
.87 .3165 Mdot
.87 .3166 Mdot
.87 .31664 Mdot
.87 .31665 Mdot
.87 .31694 Mdot
.87 .31757 Mdot
.87 .31769 Mdot
.87 .31804 Mdot
.87 .31841 Mdot
.87 .31856 Mdot
.87 .31917 Mdot
.87 .3195 Mdot
.87 .31999 Mdot
.87 .32008 Mdot
.87 .32101 Mdot
.87 .32121 Mdot
.87 .32159 Mdot
.87 .32218 Mdot
.87 .32266 Mdot
.87 .32293 Mdot
.87 .32311 Mdot
.87 .32376 Mdot
.87 .32407 Mdot
.87 .32413 Mdot
.87 .32655 Mdot
.87 .32753 Mdot
.87 .32756 Mdot
.87 .32818 Mdot
.87 .32819 Mdot
.87 .32832 Mdot
.87 .32888 Mdot
.87 .32892 Mdot
.87 .32904 Mdot
.87 .33033 Mdot
.87 .33153 Mdot
.87 .33178 Mdot
.87 .33239 Mdot
.87 .33291 Mdot
.87 .33322 Mdot
.87 .33331 Mdot
.87 .33338 Mdot
.87 .33345 Mdot
.87 .33371 Mdot
.87 .33475 Mdot
.87 .3357 Mdot
.87 .33585 Mdot
.87 .33589 Mdot
.87 .33591 Mdot
.87 .33698 Mdot
.87 .33718 Mdot
.87 .33724 Mdot
.87 .33759 Mdot
.87 .33802 Mdot
.87 .33862 Mdot
.87 .33937 Mdot
.87 .3394 Mdot
.87 .33947 Mdot
.87 .33991 Mdot
.87 .34088 Mdot
.87 .34103 Mdot
.87 .34109 Mdot
.87 .34295 Mdot
.87 .34341 Mdot
.87 .3443 Mdot
.87 .34436 Mdot
.87 .34476 Mdot
.87 .34502 Mdot
.87 .34515 Mdot
.87 .34547 Mdot
.87 .34562 Mdot
.87 .34603 Mdot
.87 .34607 Mdot
.87 .34667 Mdot
.87 .34668 Mdot
.87 .34672 Mdot
.87 .34702 Mdot
.87 .34733 Mdot
.87 .34797 Mdot
.87 .34808 Mdot
.87 .34821 Mdot
.87 .34835 Mdot
.87 .34882 Mdot
.87 .34946 Mdot
.87 .34947 Mdot
.87 .34949 Mdot
.87 .34957 Mdot
.87 .34966 Mdot
.87 .35002 Mdot
.87 .35107 Mdot
.87 .35134 Mdot
.87 .35149 Mdot
.87 .35191 Mdot
.87 .35194 Mdot
.87 .35194 Mdot
.87 .35251 Mdot
.87 .35259 Mdot
.87 .35268 Mdot
.87 .35275 Mdot
.87 .3528 Mdot
.87 .35368 Mdot
.87 .35469 Mdot
.87 .35562 Mdot
.87 .35563 Mdot
.87 .35577 Mdot
.87 .35579 Mdot
.87 .35647 Mdot
.87 .35761 Mdot
.87 .35859 Mdot
.87 .35905 Mdot
.87 .36031 Mdot
.87 .36159 Mdot
.87 .36192 Mdot
.87 .36265 Mdot
.87 .36295 Mdot
.87 .36327 Mdot
.87 .36336 Mdot
.87 .36428 Mdot
.87 .36497 Mdot
.87 .36521 Mdot
.87 .3653 Mdot
.87 .36533 Mdot
.87 .36544 Mdot
.87 .36569 Mdot
.87 .36593 Mdot
.87 .36598 Mdot
.87 .36648 Mdot
.87 .36862 Mdot
.87 .36895 Mdot
.87 .3692 Mdot
.87 .36986 Mdot
.87 .37085 Mdot
.87 .37132 Mdot
.87 .37171 Mdot
.87 .37206 Mdot
.87 .37213 Mdot
.87 .37285 Mdot
.87 .37342 Mdot
.87 .37418 Mdot
.87 .37487 Mdot
.87 .37506 Mdot
.87 .37526 Mdot
.87 .37528 Mdot
.87 .37573 Mdot
.87 .37582 Mdot
.87 .37619 Mdot
.87 .37625 Mdot
.87 .37672 Mdot
.87 .377 Mdot
.87 .37727 Mdot
.87 .37758 Mdot
.87 .37791 Mdot
.87 .37827 Mdot
.87 .37887 Mdot
.87 .3792 Mdot
.87 .38019 Mdot
.87 .38143 Mdot
.87 .38154 Mdot
.87 .38162 Mdot
.87 .38164 Mdot
.87 .38251 Mdot
.87 .38262 Mdot
.87 .38391 Mdot
.87 .38435 Mdot
.87 .38457 Mdot
.87 .38471 Mdot
.87 .38471 Mdot
.87 .38486 Mdot
.87 .38489 Mdot
.87 .38501 Mdot
.87 .38503 Mdot
.87 .38528 Mdot
.87 .38558 Mdot
.87 .38601 Mdot
.87 .3871 Mdot
.87 .38714 Mdot
.87 .38788 Mdot
.87 .38811 Mdot
.87 .38895 Mdot
.87 .39008 Mdot
.87 .39064 Mdot
.87 .39066 Mdot
.87 .39154 Mdot
.87 .39171 Mdot
.87 .39195 Mdot
.87 .39204 Mdot
.87 .39324 Mdot
.87 .3933 Mdot
.87 .3938 Mdot
.87 .39381 Mdot
.87 .39386 Mdot
.87 .3952 Mdot
.87 .39574 Mdot
.87 .39594 Mdot
.87 .39614 Mdot
.87 .39631 Mdot
.87 .39647 Mdot
.87 .3969 Mdot
.87 .39693 Mdot
.87 .39715 Mdot
.87 .3972 Mdot
.87 .39746 Mdot
.87 .39747 Mdot
.87 .39769 Mdot
.87 .39809 Mdot
.87 .39885 Mdot
.87 .39927 Mdot
.87 .40109 Mdot
.87 .40129 Mdot
.87 .4028 Mdot
.87 .40283 Mdot
.87 .40297 Mdot
.87 .40317 Mdot
.87 .40324 Mdot
.87 .40338 Mdot
.87 .40378 Mdot
.87 .40532 Mdot
.87 .40606 Mdot
.87 .40705 Mdot
.87 .40761 Mdot
.87 .40867 Mdot
.87 .40875 Mdot
.87 .40929 Mdot
.87 .40987 Mdot
.87 .4104 Mdot
.87 .41044 Mdot
.87 .4105 Mdot
.87 .41054 Mdot
.87 .41087 Mdot
.87 .41113 Mdot
.87 .41121 Mdot
.87 .41137 Mdot
.87 .41198 Mdot
.87 .41218 Mdot
.87 .41223 Mdot
.87 .41228 Mdot
.87 .41229 Mdot
.87 .4123 Mdot
.87 .41294 Mdot
.87 .41309 Mdot
.87 .4137 Mdot
.87 .41387 Mdot
.87 .41389 Mdot
.87 .4139 Mdot
.87 .41424 Mdot
.87 .41459 Mdot
.87 .41499 Mdot
.87 .41577 Mdot
.87 .41604 Mdot
.87 .41711 Mdot
.87 .41808 Mdot
.87 .41809 Mdot
.87 .41887 Mdot
.87 .41912 Mdot
.87 .41932 Mdot
.87 .41935 Mdot
.87 .41947 Mdot
.87 .42008 Mdot
.87 .42012 Mdot
.87 .42075 Mdot
.87 .4215 Mdot
.87 .42153 Mdot
.87 .42158 Mdot
.87 .42181 Mdot
.87 .4221 Mdot
.87 .42245 Mdot
.87 .42329 Mdot
.87 .42403 Mdot
.87 .4241 Mdot
.87 .42412 Mdot
.87 .42445 Mdot
.87 .42452 Mdot
.87 .42452 Mdot
.87 .42488 Mdot
.87 .4249 Mdot
.87 .42546 Mdot
.87 .42686 Mdot
.87 .42688 Mdot
.87 .42744 Mdot
.87 .42798 Mdot
.87 .42918 Mdot
.87 .42923 Mdot
.87 .42951 Mdot
.87 .4297 Mdot
.87 .43005 Mdot
.87 .43014 Mdot
.87 .43055 Mdot
.87 .43099 Mdot
.87 .43116 Mdot
.87 .43118 Mdot
.87 .43124 Mdot
.87 .43134 Mdot
.87 .43138 Mdot
.87 .43165 Mdot
.87 .4318 Mdot
.87 .43232 Mdot
.87 .43299 Mdot
.87 .433 Mdot
.87 .43361 Mdot
.87 .43369 Mdot
.87 .4346 Mdot
.87 .43476 Mdot
.87 .43511 Mdot
.87 .43532 Mdot
.87 .43532 Mdot
.87 .43538 Mdot
.87 .43584 Mdot
.87 .43619 Mdot
.87 .43626 Mdot
.87 .43648 Mdot
.87 .43712 Mdot
.87 .43741 Mdot
.87 .43768 Mdot
.87 .43798 Mdot
.87 .43818 Mdot
.87 .43833 Mdot
.87 .43854 Mdot
.87 .43982 Mdot
.87 .43992 Mdot
.87 .43995 Mdot
.87 .44073 Mdot
.87 .44106 Mdot
.87 .44151 Mdot
.87 .44169 Mdot
.87 .44175 Mdot
.87 .44179 Mdot
.87 .44196 Mdot
.87 .44199 Mdot
.87 .44211 Mdot
.87 .44227 Mdot
.87 .44291 Mdot
.87 .44325 Mdot
.87 .44329 Mdot
.87 .44353 Mdot
.87 .44456 Mdot
.87 .44462 Mdot
.87 .44515 Mdot
.87 .44586 Mdot
.87 .4466 Mdot
.87 .4471 Mdot
.87 .44777 Mdot
.87 .44781 Mdot
.87 .44785 Mdot
.87 .44806 Mdot
.87 .44808 Mdot
.87 .44856 Mdot
.87 .44913 Mdot
.87 .44969 Mdot
.87 .44982 Mdot
.87 .45014 Mdot
.87 .45053 Mdot
.87 .45083 Mdot
.87 .45117 Mdot
.87 .45145 Mdot
.87 .45299 Mdot
.87 .45299 Mdot
.87 .453 Mdot
.87 .45306 Mdot
.87 .45318 Mdot
.87 .45319 Mdot
.87 .45334 Mdot
.87 .45348 Mdot
.87 .45382 Mdot
.87 .45391 Mdot
.87 .45447 Mdot
.87 .45448 Mdot
.87 .45452 Mdot
.87 .45478 Mdot
.87 .45478 Mdot
.87 .45527 Mdot
.87 .45537 Mdot
.87 .45552 Mdot
.87 .45599 Mdot
.87 .45638 Mdot
.87 .45646 Mdot
.87 .45657 Mdot
.87 .45699 Mdot
.87 .45739 Mdot
.87 .45743 Mdot
.87 .45783 Mdot
.87 .45845 Mdot
.87 .4586 Mdot
.87 .45874 Mdot
.87 .45877 Mdot
.87 .4588 Mdot
.87 .45913 Mdot
.87 .45933 Mdot
.87 .45964 Mdot
.87 .45992 Mdot
.87 .46052 Mdot
.87 .46063 Mdot
.87 .46073 Mdot
.87 .46096 Mdot
.87 .46119 Mdot
.87 .46138 Mdot
.87 .46186 Mdot
.87 .46251 Mdot
.87 .46304 Mdot
.87 .46313 Mdot
.87 .46346 Mdot
.87 .46356 Mdot
.87 .46363 Mdot
.87 .46365 Mdot
.87 .46371 Mdot
.87 .46386 Mdot
.87 .46397 Mdot
.87 .46469 Mdot
.87 .46476 Mdot
.87 .46487 Mdot
.87 .46506 Mdot
.87 .46547 Mdot
.87 .46573 Mdot
.87 .46629 Mdot
.87 .46632 Mdot
.87 .46652 Mdot
.87 .46675 Mdot
.87 .46697 Mdot
.87 .46707 Mdot
.87 .46713 Mdot
.87 .46767 Mdot
.87 .46776 Mdot
.87 .46854 Mdot
.87 .46855 Mdot
.87 .46932 Mdot
.87 .46932 Mdot
.87 .46945 Mdot
.87 .46946 Mdot
.87 .46948 Mdot
.87 .47012 Mdot
.87 .47119 Mdot
.87 .47145 Mdot
.87 .47212 Mdot
.87 .47247 Mdot
.87 .47283 Mdot
.87 .4729 Mdot
.87 .47336 Mdot
.87 .47336 Mdot
.87 .47338 Mdot
.87 .47346 Mdot
.87 .47372 Mdot
.87 .47374 Mdot
.87 .47394 Mdot
.87 .47395 Mdot
.87 .47397 Mdot
.87 .47453 Mdot
.87 .47542 Mdot
.87 .47617 Mdot
.87 .4763 Mdot
.87 .47635 Mdot
.87 .47766 Mdot
.87 .47864 Mdot
.87 .4787 Mdot
.87 .47883 Mdot
.87 .47945 Mdot
.87 .47946 Mdot
.87 .47947 Mdot
.87 .48005 Mdot
.87 .48016 Mdot
.87 .4805 Mdot
.87 .48051 Mdot
.87 .48107 Mdot
.87 .48142 Mdot
.87 .48204 Mdot
.87 .48236 Mdot
.87 .48237 Mdot
.87 .48241 Mdot
.87 .48247 Mdot
.87 .48252 Mdot
.87 .48259 Mdot
.87 .48274 Mdot
.87 .48356 Mdot
.87 .48396 Mdot
.87 .4844 Mdot
.87 .48511 Mdot
.87 .48566 Mdot
.87 .4862 Mdot
.87 .48665 Mdot
.87 .48677 Mdot
.87 .48689 Mdot
.87 .48705 Mdot
.87 .48737 Mdot
.87 .48759 Mdot
.87 .48849 Mdot
.87 .48883 Mdot
.87 .48888 Mdot
.87 .48952 Mdot
.87 .48955 Mdot
.87 .48966 Mdot
.87 .48976 Mdot
.87 .49 Mdot
.87 .49095 Mdot
.87 .4918 Mdot
.87 .49202 Mdot
.87 .49208 Mdot
.87 .49301 Mdot
.87 .49329 Mdot
.87 .4933 Mdot
.87 .49433 Mdot
.87 .49453 Mdot
.87 .4946 Mdot
.87 .49482 Mdot
.87 .49525 Mdot
.87 .49538 Mdot
.87 .49554 Mdot
.87 .49558 Mdot
.87 .4958 Mdot
.87 .49582 Mdot
.87 .4969 Mdot
.87 .49695 Mdot
.87 .49727 Mdot
.87 .49741 Mdot
.87 .49769 Mdot
.87 .4986 Mdot
.87 .49866 Mdot
.87 .49932 Mdot
.87 .49948 Mdot
.87 .50004 Mdot
.87 .5026 Mdot
.87 .50287 Mdot
.87 .50296 Mdot
.87 .50332 Mdot
.87 .50344 Mdot
.87 .50351 Mdot
.87 .50449 Mdot
.87 .50465 Mdot
.87 .50495 Mdot
.87 .50542 Mdot
.87 .50558 Mdot
.87 .50627 Mdot
.87 .50642 Mdot
.87 .50691 Mdot
.87 .50726 Mdot
.87 .5073 Mdot
.87 .50736 Mdot
.87 .50784 Mdot
.87 .50788 Mdot
.87 .50795 Mdot
.87 .50801 Mdot
.87 .50818 Mdot
.87 .5083 Mdot
.87 .50864 Mdot
.87 .50872 Mdot
.87 .50992 Mdot
.87 .51008 Mdot
.87 .51008 Mdot
.87 .51092 Mdot
.87 .51107 Mdot
.87 .5115 Mdot
.87 .51255 Mdot
.87 .51283 Mdot
.87 .51305 Mdot
.87 .51308 Mdot
.87 .51344 Mdot
.87 .51346 Mdot
.87 .51354 Mdot
.87 .51383 Mdot
.87 .51389 Mdot
.87 .51407 Mdot
.87 .51428 Mdot
.87 .51539 Mdot
.87 .51588 Mdot
.87 .51591 Mdot
.87 .51597 Mdot
.87 .51615 Mdot
.87 .51646 Mdot
.87 .51658 Mdot
.87 .51739 Mdot
.87 .51772 Mdot
.87 .51785 Mdot
.87 .51836 Mdot
.87 .5188 Mdot
.87 .51919 Mdot
.87 .5194 Mdot
.87 .51942 Mdot
.87 .52022 Mdot
.87 .52032 Mdot
.87 .52065 Mdot
.87 .52114 Mdot
.87 .52131 Mdot
.87 .52144 Mdot
.87 .52148 Mdot
.87 .52202 Mdot
.87 .52246 Mdot
.87 .52283 Mdot
.87 .52308 Mdot
.87 .52332 Mdot
.87 .52357 Mdot
.87 .52361 Mdot
.87 .52396 Mdot
.87 .52398 Mdot
.87 .52429 Mdot
.87 .52462 Mdot
.87 .52466 Mdot
.87 .52484 Mdot
.87 .52488 Mdot
.87 .5259 Mdot
.87 .52623 Mdot
.87 .52633 Mdot
.87 .52682 Mdot
.87 .52728 Mdot
.87 .5274 Mdot
.87 .52745 Mdot
.87 .52746 Mdot
.87 .52772 Mdot
.87 .52787 Mdot
.87 .52791 Mdot
.872 .14651 Mdot
.872 .14653 Mdot
.872 .14677 Mdot
.872 .14678 Mdot
.872 .14736 Mdot
.872 .14736 Mdot
.872 .14738 Mdot
.872 .14772 Mdot
.872 .14865 Mdot
.872 .14876 Mdot
.872 .14922 Mdot
.872 .14926 Mdot
.872 .14987 Mdot
.872 .14991 Mdot
.872 .15194 Mdot
.872 .15239 Mdot
.872 .15248 Mdot
.872 .15392 Mdot
.872 .15446 Mdot
.872 .15505 Mdot
.872 .15597 Mdot
.872 .15666 Mdot
.872 .15751 Mdot
.872 .15838 Mdot
.872 .15849 Mdot
.872 .16002 Mdot
.872 .16004 Mdot
.872 .16087 Mdot
.872 .16314 Mdot
.872 .16317 Mdot
.872 .16472 Mdot
.872 .16475 Mdot
.872 .16569 Mdot
.872 .16592 Mdot
.872 .16637 Mdot
.872 .16644 Mdot
.872 .16652 Mdot
.872 .16676 Mdot
.872 .16748 Mdot
.872 .16755 Mdot
.872 .16778 Mdot
.872 .16816 Mdot
.872 .16831 Mdot
.872 .16874 Mdot
.872 .16877 Mdot
.872 .1689 Mdot
.872 .16899 Mdot
.872 .16927 Mdot
.872 .16941 Mdot
.872 .16984 Mdot
.872 .16984 Mdot
.872 .17036 Mdot
.872 .17298 Mdot
.872 .17543 Mdot
.872 .17575 Mdot
.872 .17599 Mdot
.872 .17683 Mdot
.872 .17692 Mdot
.872 .1781 Mdot
.872 .17812 Mdot
.872 .17833 Mdot
.872 .17944 Mdot
.872 .17973 Mdot
.872 .17976 Mdot
.872 .17987 Mdot
.872 .18018 Mdot
.872 .18041 Mdot
.872 .1807 Mdot
.872 .18192 Mdot
.872 .1832 Mdot
.872 .18361 Mdot
.872 .18368 Mdot
.872 .18368 Mdot
.872 .18379 Mdot
.872 .18392 Mdot
.872 .1849 Mdot
.872 .18783 Mdot
.872 .18806 Mdot
.872 .1881 Mdot
.872 .18811 Mdot
.872 .18933 Mdot
.872 .18943 Mdot
.872 .19008 Mdot
.872 .19111 Mdot
.872 .19319 Mdot
.872 .19426 Mdot
.872 .19465 Mdot
.872 .19554 Mdot
.872 .19573 Mdot
.872 .19594 Mdot
.872 .19655 Mdot
.872 .1975 Mdot
.872 .1981 Mdot
.872 .19927 Mdot
.872 .20098 Mdot
.872 .20159 Mdot
.872 .20161 Mdot
.872 .2018 Mdot
.872 .20367 Mdot
.872 .20408 Mdot
.872 .20424 Mdot
.872 .20469 Mdot
.872 .20539 Mdot
.872 .20576 Mdot
.872 .20755 Mdot
.872 .2076 Mdot
.872 .2079 Mdot
.872 .20798 Mdot
.872 .20838 Mdot
.872 .20861 Mdot
.872 .20928 Mdot
.872 .20939 Mdot
.872 .21044 Mdot
.872 .21054 Mdot
.872 .21251 Mdot
.872 .21257 Mdot
.872 .21344 Mdot
.872 .21374 Mdot
.872 .21414 Mdot
.872 .21442 Mdot
.872 .2159 Mdot
.872 .21606 Mdot
.872 .21775 Mdot
.872 .21802 Mdot
.872 .21807 Mdot
.872 .21825 Mdot
.872 .21879 Mdot
.872 .21894 Mdot
.872 .21988 Mdot
.872 .22065 Mdot
.872 .22074 Mdot
.872 .22078 Mdot
.872 .22108 Mdot
.872 .22196 Mdot
.872 .22287 Mdot
.872 .22302 Mdot
.872 .22314 Mdot
.872 .22345 Mdot
.872 .22378 Mdot
.872 .22525 Mdot
.872 .22545 Mdot
.872 .22573 Mdot
.872 .22597 Mdot
.872 .22642 Mdot
.872 .22661 Mdot
.872 .22688 Mdot
.872 .2281 Mdot
.872 .22817 Mdot
.872 .22888 Mdot
.872 .22969 Mdot
.872 .23093 Mdot
.872 .23106 Mdot
.872 .23166 Mdot
.872 .23171 Mdot
.872 .23198 Mdot
.872 .23249 Mdot
.872 .23279 Mdot
.872 .23279 Mdot
.872 .23293 Mdot
.872 .23328 Mdot
.872 .23384 Mdot
.872 .23594 Mdot
.872 .23703 Mdot
.872 .2371 Mdot
.872 .23717 Mdot
.872 .23723 Mdot
.872 .23828 Mdot
.872 .23836 Mdot
.872 .23837 Mdot
.872 .23857 Mdot
.872 .23863 Mdot
.872 .23879 Mdot
.872 .23896 Mdot
.872 .23917 Mdot
.872 .24046 Mdot
.872 .2406 Mdot
.872 .24154 Mdot
.872 .24158 Mdot
.872 .24277 Mdot
.872 .24339 Mdot
.872 .24368 Mdot
.872 .24373 Mdot
.872 .24456 Mdot
.872 .2446 Mdot
.872 .24481 Mdot
.872 .24502 Mdot
.872 .24503 Mdot
.872 .2455 Mdot
.872 .24604 Mdot
.872 .24605 Mdot
.872 .24608 Mdot
.872 .24667 Mdot
.872 .24731 Mdot
.872 .24775 Mdot
.872 .24794 Mdot
.872 .24799 Mdot
.872 .24807 Mdot
.872 .2483 Mdot
.872 .24848 Mdot
.872 .24929 Mdot
.872 .24936 Mdot
.872 .2494 Mdot
.872 .25005 Mdot
.872 .2503 Mdot
.872 .25043 Mdot
.872 .25049 Mdot
.872 .25068 Mdot
.872 .25151 Mdot
.872 .25198 Mdot
.872 .25236 Mdot
.872 .25241 Mdot
.872 .2537 Mdot
.872 .25384 Mdot
.872 .25403 Mdot
.872 .25454 Mdot
.872 .25481 Mdot
.872 .25498 Mdot
.872 .25576 Mdot
.872 .25612 Mdot
.872 .25632 Mdot
.872 .25695 Mdot
.872 .25749 Mdot
.872 .25843 Mdot
.872 .25854 Mdot
.872 .25888 Mdot
.872 .25946 Mdot
.872 .26003 Mdot
.872 .26007 Mdot
.872 .26049 Mdot
.872 .26051 Mdot
.872 .26065 Mdot
.872 .26073 Mdot
.872 .26107 Mdot
.872 .26226 Mdot
.872 .26262 Mdot
.872 .26316 Mdot
.872 .26376 Mdot
.872 .26434 Mdot
.872 .26456 Mdot
.872 .26526 Mdot
.872 .26546 Mdot
.872 .26595 Mdot
.872 .26813 Mdot
.872 .26817 Mdot
.872 .26835 Mdot
.872 .26893 Mdot
.872 .26961 Mdot
.872 .27039 Mdot
.872 .27211 Mdot
.872 .27218 Mdot
.872 .27234 Mdot
.872 .27272 Mdot
.872 .27283 Mdot
.872 .27356 Mdot
.872 .27363 Mdot
.872 .27375 Mdot
.872 .27438 Mdot
.872 .27485 Mdot
.872 .27584 Mdot
.872 .27632 Mdot
.872 .27638 Mdot
.872 .27652 Mdot
.872 .2777 Mdot
.872 .27802 Mdot
.872 .27842 Mdot
.872 .2792 Mdot
.872 .27927 Mdot
.872 .27932 Mdot
.872 .27946 Mdot
.872 .27947 Mdot
.872 .27988 Mdot
.872 .2799 Mdot
.872 .28026 Mdot
.872 .28095 Mdot
.872 .28114 Mdot
.872 .28125 Mdot
.872 .2813 Mdot
.872 .28156 Mdot
.872 .28165 Mdot
.872 .28167 Mdot
.872 .28187 Mdot
.872 .28232 Mdot
.872 .28258 Mdot
.872 .28333 Mdot
.872 .28339 Mdot
.872 .28354 Mdot
.872 .28362 Mdot
.872 .28371 Mdot
.872 .28378 Mdot
.872 .28426 Mdot
.872 .28437 Mdot
.872 .28451 Mdot
.872 .28525 Mdot
.872 .28526 Mdot
.872 .28608 Mdot
.872 .28614 Mdot
.872 .28615 Mdot
.872 .28743 Mdot
.872 .28794 Mdot
.872 .28796 Mdot
.872 .28865 Mdot
.872 .28903 Mdot
.872 .28948 Mdot
.872 .2896 Mdot
.872 .29031 Mdot
.872 .29068 Mdot
.872 .29074 Mdot
.872 .29384 Mdot
.872 .29432 Mdot
.872 .295 Mdot
.872 .29534 Mdot
.872 .29555 Mdot
.872 .29559 Mdot
.872 .29599 Mdot
.872 .296 Mdot
.872 .29608 Mdot
.872 .29736 Mdot
.872 .29744 Mdot
.872 .29747 Mdot
.872 .2976 Mdot
.872 .29843 Mdot
.872 .29874 Mdot
.872 .2992 Mdot
.872 .29928 Mdot
.872 .29967 Mdot
.872 .2997 Mdot
.872 .30005 Mdot
.872 .30096 Mdot
.872 .30199 Mdot
.872 .302 Mdot
.872 .30218 Mdot
.872 .30235 Mdot
.872 .3025 Mdot
.872 .30255 Mdot
.872 .30275 Mdot
.872 .30311 Mdot
.872 .30314 Mdot
.872 .30328 Mdot
.872 .30336 Mdot
.872 .30368 Mdot
.872 .30419 Mdot
.872 .3042 Mdot
.872 .30494 Mdot
.872 .30521 Mdot
.872 .30573 Mdot
.872 .30633 Mdot
.872 .30686 Mdot
.872 .30705 Mdot
.872 .30723 Mdot
.872 .30773 Mdot
.872 .30855 Mdot
.872 .30856 Mdot
.872 .30876 Mdot
.872 .30927 Mdot
.872 .30938 Mdot
.872 .30938 Mdot
.872 .30939 Mdot
.872 .30958 Mdot
.872 .30967 Mdot
.872 .30973 Mdot
.872 .30981 Mdot
.872 .31043 Mdot
.872 .31047 Mdot
.872 .31062 Mdot
.872 .31151 Mdot
.872 .31169 Mdot
.872 .31284 Mdot
.872 .31335 Mdot
.872 .31363 Mdot
.872 .31417 Mdot
.872 .31573 Mdot
.872 .31631 Mdot
.872 .31639 Mdot
.872 .31662 Mdot
.872 .31672 Mdot
.872 .31704 Mdot
.872 .31709 Mdot
.872 .31712 Mdot
.872 .31726 Mdot
.872 .31757 Mdot
.872 .31924 Mdot
.872 .31942 Mdot
.872 .32012 Mdot
.872 .32055 Mdot
.872 .32066 Mdot
.872 .3207 Mdot
.872 .3208 Mdot
.872 .32087 Mdot
.872 .32137 Mdot
.872 .32195 Mdot
.872 .32198 Mdot
.872 .32235 Mdot
.872 .3234 Mdot
.872 .32543 Mdot
.872 .32585 Mdot
.872 .32591 Mdot
.872 .32598 Mdot
.872 .32618 Mdot
.872 .32649 Mdot
.872 .32669 Mdot
.872 .32707 Mdot
.872 .32764 Mdot
.872 .32784 Mdot
.872 .32784 Mdot
.872 .32791 Mdot
.872 .32852 Mdot
.872 .32886 Mdot
.872 .32921 Mdot
.872 .32981 Mdot
.872 .32994 Mdot
.872 .33007 Mdot
.872 .33014 Mdot
.872 .3304 Mdot
.872 .33078 Mdot
.872 .33173 Mdot
.872 .33183 Mdot
.872 .33206 Mdot
.872 .33254 Mdot
.872 .3326 Mdot
.872 .33315 Mdot
.872 .33349 Mdot
.872 .33354 Mdot
.872 .33385 Mdot
.872 .3341 Mdot
.872 .33424 Mdot
.872 .33453 Mdot
.872 .33483 Mdot
.872 .33492 Mdot
.872 .33615 Mdot
.872 .33656 Mdot
.872 .33658 Mdot
.872 .33748 Mdot
.872 .3381 Mdot
.872 .33954 Mdot
.872 .33956 Mdot
.872 .3399 Mdot
.872 .34 Mdot
.872 .34001 Mdot
.872 .34062 Mdot
.872 .34066 Mdot
.872 .34099 Mdot
.872 .34158 Mdot
.872 .34168 Mdot
.872 .34205 Mdot
.872 .34227 Mdot
.872 .34309 Mdot
.872 .34312 Mdot
.872 .34377 Mdot
.872 .34385 Mdot
.872 .34398 Mdot
.872 .34425 Mdot
.872 .34441 Mdot
.872 .34453 Mdot
.872 .34497 Mdot
.872 .34525 Mdot
.872 .34604 Mdot
.872 .34706 Mdot
.872 .3472 Mdot
.872 .34726 Mdot
.872 .3479 Mdot
.872 .34808 Mdot
.872 .34847 Mdot
.872 .34854 Mdot
.872 .34998 Mdot
.872 .35102 Mdot
.872 .3511 Mdot
.872 .35156 Mdot
.872 .35163 Mdot
.872 .35177 Mdot
.872 .35192 Mdot
.872 .35225 Mdot
.872 .35247 Mdot
.872 .35286 Mdot
.872 .35338 Mdot
.872 .35359 Mdot
.872 .3537 Mdot
.872 .35404 Mdot
.872 .35417 Mdot
.872 .35423 Mdot
.872 .35478 Mdot
.872 .35562 Mdot
.872 .35606 Mdot
.872 .35623 Mdot
.872 .35646 Mdot
.872 .35658 Mdot
.872 .35673 Mdot
.872 .35701 Mdot
.872 .35817 Mdot
.872 .35967 Mdot
.872 .35978 Mdot
.872 .35996 Mdot
.872 .36091 Mdot
.872 .36122 Mdot
.872 .36122 Mdot
.872 .3613 Mdot
.872 .36157 Mdot
.872 .36182 Mdot
.872 .36208 Mdot
.872 .36251 Mdot
.872 .36257 Mdot
.872 .36274 Mdot
.872 .363 Mdot
.872 .36337 Mdot
.872 .36339 Mdot
.872 .36362 Mdot
.872 .36368 Mdot
.872 .36404 Mdot
.872 .36467 Mdot
.872 .36558 Mdot
.872 .36587 Mdot
.872 .36597 Mdot
.872 .36681 Mdot
.872 .367 Mdot
.872 .36706 Mdot
.872 .36722 Mdot
.872 .36742 Mdot
.872 .36855 Mdot
.872 .36869 Mdot
.872 .3688 Mdot
.872 .36928 Mdot
.872 .36937 Mdot
.872 .36968 Mdot
.872 .3698 Mdot
.872 .37063 Mdot
.872 .37073 Mdot
.872 .37089 Mdot
.872 .37122 Mdot
.872 .37167 Mdot
.872 .37221 Mdot
.872 .37252 Mdot
.872 .37319 Mdot
.872 .37386 Mdot
.872 .37402 Mdot
.872 .37409 Mdot
.872 .37461 Mdot
.872 .37465 Mdot
.872 .37613 Mdot
.872 .37615 Mdot
.872 .37715 Mdot
.872 .37726 Mdot
.872 .37737 Mdot
.872 .37774 Mdot
.872 .378 Mdot
.872 .3782 Mdot
.872 .37848 Mdot
.872 .37876 Mdot
.872 .37885 Mdot
.872 .37932 Mdot
.872 .3799 Mdot
.872 .38032 Mdot
.872 .38032 Mdot
.872 .38113 Mdot
.872 .38125 Mdot
.872 .38146 Mdot
.872 .38188 Mdot
.872 .38224 Mdot
.872 .38273 Mdot
.872 .38278 Mdot
.872 .38314 Mdot
.872 .38361 Mdot
.872 .38376 Mdot
.872 .38393 Mdot
.872 .38426 Mdot
.872 .38474 Mdot
.872 .38522 Mdot
.872 .3856 Mdot
.872 .38563 Mdot
.872 .38599 Mdot
.872 .38687 Mdot
.872 .38697 Mdot
.872 .38821 Mdot
.872 .38835 Mdot
.872 .38924 Mdot
.872 .38953 Mdot
.872 .38963 Mdot
.872 .38976 Mdot
.872 .38993 Mdot
.872 .39044 Mdot
.872 .39179 Mdot
.872 .392 Mdot
.872 .39202 Mdot
.872 .39223 Mdot
.872 .39307 Mdot
.872 .39316 Mdot
.872 .39363 Mdot
.872 .39439 Mdot
.872 .39451 Mdot
.872 .39458 Mdot
.872 .39504 Mdot
.872 .39504 Mdot
.872 .39528 Mdot
.872 .39589 Mdot
.872 .3961 Mdot
.872 .39673 Mdot
.872 .39679 Mdot
.872 .39686 Mdot
.872 .39745 Mdot
.872 .39829 Mdot
.872 .39913 Mdot
.872 .39969 Mdot
.872 .4 Mdot
.872 .40026 Mdot
.872 .40054 Mdot
.872 .40108 Mdot
.872 .40171 Mdot
.872 .40179 Mdot
.872 .40244 Mdot
.872 .40255 Mdot
.872 .40265 Mdot
.872 .40268 Mdot
.872 .40279 Mdot
.872 .40327 Mdot
.872 .40401 Mdot
.872 .40438 Mdot
.872 .40458 Mdot
.872 .40462 Mdot
.872 .40475 Mdot
.872 .40476 Mdot
.872 .40512 Mdot
.872 .40522 Mdot
.872 .4055 Mdot
.872 .40579 Mdot
.872 .40599 Mdot
.872 .406 Mdot
.872 .40617 Mdot
.872 .40672 Mdot
.872 .40774 Mdot
.872 .40841 Mdot
.872 .40857 Mdot
.872 .40865 Mdot
.872 .40872 Mdot
.872 .40921 Mdot
.872 .40969 Mdot
.872 .41004 Mdot
.872 .4103 Mdot
.872 .41037 Mdot
.872 .41049 Mdot
.872 .41114 Mdot
.872 .41132 Mdot
.872 .41153 Mdot
.872 .41244 Mdot
.872 .41326 Mdot
.872 .41331 Mdot
.872 .41353 Mdot
.872 .41403 Mdot
.872 .41411 Mdot
.872 .41556 Mdot
.872 .41563 Mdot
.872 .41588 Mdot
.872 .41595 Mdot
.872 .416 Mdot
.872 .41637 Mdot
.872 .41639 Mdot
.872 .41686 Mdot
.872 .41699 Mdot
.872 .4172 Mdot
.872 .41725 Mdot
.872 .41815 Mdot
.872 .41816 Mdot
.872 .41822 Mdot
.872 .41843 Mdot
.872 .41925 Mdot
.872 .4196 Mdot
.872 .42014 Mdot
.872 .42037 Mdot
.872 .42107 Mdot
.872 .42112 Mdot
.872 .42146 Mdot
.872 .42154 Mdot
.872 .42169 Mdot
.872 .42186 Mdot
.872 .42209 Mdot
.872 .42241 Mdot
.872 .42244 Mdot
.872 .42272 Mdot
.872 .4229 Mdot
.872 .42381 Mdot
.872 .42393 Mdot
.872 .424 Mdot
.872 .42435 Mdot
.872 .42455 Mdot
.872 .4251 Mdot
.872 .42514 Mdot
.872 .42525 Mdot
.872 .42557 Mdot
.872 .42579 Mdot
.872 .42591 Mdot
.872 .42609 Mdot
.872 .42624 Mdot
.872 .42628 Mdot
.872 .42652 Mdot
.872 .42768 Mdot
.872 .42849 Mdot
.872 .42851 Mdot
.872 .42884 Mdot
.872 .42913 Mdot
.872 .42917 Mdot
.872 .42923 Mdot
.872 .42925 Mdot
.872 .42956 Mdot
.872 .43102 Mdot
.872 .4312 Mdot
.872 .43151 Mdot
.872 .4317 Mdot
.872 .43175 Mdot
.872 .43208 Mdot
.872 .43297 Mdot
.872 .43328 Mdot
.872 .43344 Mdot
.872 .43373 Mdot
.872 .43439 Mdot
.872 .43501 Mdot
.872 .4351 Mdot
.872 .43512 Mdot
.872 .43552 Mdot
.872 .43555 Mdot
.872 .43572 Mdot
.872 .43607 Mdot
.872 .4362 Mdot
.872 .43666 Mdot
.872 .43695 Mdot
.872 .43705 Mdot
.872 .43717 Mdot
.872 .43781 Mdot
.872 .43811 Mdot
.872 .43826 Mdot
.872 .43869 Mdot
.872 .43917 Mdot
.872 .4393 Mdot
.872 .43931 Mdot
.872 .43975 Mdot
.872 .43985 Mdot
.872 .43995 Mdot
.872 .44055 Mdot
.872 .44151 Mdot
.872 .44155 Mdot
.872 .44182 Mdot
.872 .442 Mdot
.872 .44255 Mdot
.872 .44261 Mdot
.872 .44334 Mdot
.872 .44339 Mdot
.872 .44363 Mdot
.872 .44377 Mdot
.872 .44436 Mdot
.872 .44463 Mdot
.872 .44644 Mdot
.872 .44666 Mdot
.872 .44706 Mdot
.872 .44713 Mdot
.872 .44739 Mdot
.872 .44761 Mdot
.872 .448 Mdot
.872 .44801 Mdot
.872 .4483 Mdot
.872 .44905 Mdot
.872 .44908 Mdot
.872 .45006 Mdot
.872 .45044 Mdot
.872 .45053 Mdot
.872 .45149 Mdot
.872 .45161 Mdot
.872 .45167 Mdot
.872 .45182 Mdot
.872 .45202 Mdot
.872 .45242 Mdot
.872 .45262 Mdot
.872 .45287 Mdot
.872 .45298 Mdot
.872 .45388 Mdot
.872 .45456 Mdot
.872 .45495 Mdot
.872 .45552 Mdot
.872 .45579 Mdot
.872 .45603 Mdot
.872 .45615 Mdot
.872 .45668 Mdot
.872 .45674 Mdot
.872 .45696 Mdot
.872 .45705 Mdot
.872 .45709 Mdot
.872 .45807 Mdot
.872 .45891 Mdot
.872 .45925 Mdot
.872 .46062 Mdot
.872 .46142 Mdot
.872 .46154 Mdot
.872 .46222 Mdot
.872 .46253 Mdot
.872 .46361 Mdot
.872 .46366 Mdot
.872 .46374 Mdot
.872 .46375 Mdot
.872 .46399 Mdot
.872 .46401 Mdot
.872 .46467 Mdot
.872 .46487 Mdot
.872 .46578 Mdot
.872 .46614 Mdot
.872 .46626 Mdot
.872 .46646 Mdot
.872 .46716 Mdot
.872 .46757 Mdot
.872 .46764 Mdot
.872 .46839 Mdot
.872 .46841 Mdot
.872 .46863 Mdot
.872 .4689 Mdot
.872 .46938 Mdot
.872 .4696 Mdot
.872 .46974 Mdot
.872 .47011 Mdot
.872 .47087 Mdot
.872 .47092 Mdot
.872 .47095 Mdot
.872 .47106 Mdot
.872 .47131 Mdot
.872 .47235 Mdot
.872 .47274 Mdot
.872 .47336 Mdot
.872 .47339 Mdot
.872 .47356 Mdot
.872 .47391 Mdot
.872 .47459 Mdot
.872 .47462 Mdot
.872 .47516 Mdot
.872 .47524 Mdot
.872 .47597 Mdot
.872 .4761 Mdot
.872 .47619 Mdot
.872 .47629 Mdot
.872 .47632 Mdot
.872 .47644 Mdot
.872 .47644 Mdot
.872 .47649 Mdot
.872 .47709 Mdot
.872 .47712 Mdot
.872 .47716 Mdot
.872 .4772 Mdot
.872 .47783 Mdot
.872 .47903 Mdot
.872 .47936 Mdot
.872 .47956 Mdot
.872 .47963 Mdot
.872 .47963 Mdot
.872 .47981 Mdot
.872 .4801 Mdot
.872 .48025 Mdot
.872 .48028 Mdot
.872 .48063 Mdot
.872 .4807 Mdot
.872 .48141 Mdot
.872 .48188 Mdot
.872 .48229 Mdot
.872 .48232 Mdot
.872 .48302 Mdot
.872 .48318 Mdot
.872 .48329 Mdot
.872 .48355 Mdot
.872 .48368 Mdot
.872 .48384 Mdot
.872 .48396 Mdot
.872 .4848 Mdot
.872 .48499 Mdot
.872 .48517 Mdot
.872 .48524 Mdot
.872 .48532 Mdot
.872 .48584 Mdot
.872 .48635 Mdot
.872 .48652 Mdot
.872 .48655 Mdot
.872 .4866 Mdot
.872 .48704 Mdot
.872 .48757 Mdot
.872 .48766 Mdot
.872 .48797 Mdot
.872 .48807 Mdot
.872 .4881 Mdot
.872 .48826 Mdot
.872 .48923 Mdot
.872 .48932 Mdot
.872 .49017 Mdot
.872 .49033 Mdot
.872 .49056 Mdot
.872 .49073 Mdot
.872 .49123 Mdot
.872 .49126 Mdot
.872 .49239 Mdot
.872 .49245 Mdot
.872 .49305 Mdot
.872 .49311 Mdot
.872 .4935 Mdot
.872 .49363 Mdot
.872 .49386 Mdot
.872 .49391 Mdot
.872 .49408 Mdot
.872 .49411 Mdot
.872 .49513 Mdot
.872 .49534 Mdot
.872 .49575 Mdot
.872 .49601 Mdot
.872 .4961 Mdot
.872 .49633 Mdot
.872 .49741 Mdot
.872 .49751 Mdot
.872 .49753 Mdot
.872 .49788 Mdot
.872 .49886 Mdot
.872 .49953 Mdot
.872 .49987 Mdot
.872 .50042 Mdot
.872 .50076 Mdot
.872 .50089 Mdot
.872 .50099 Mdot
.872 .5015 Mdot
.872 .50173 Mdot
.872 .50234 Mdot
.872 .50353 Mdot
.872 .50412 Mdot
.872 .5045 Mdot
.872 .50456 Mdot
.872 .50525 Mdot
.872 .50526 Mdot
.872 .50528 Mdot
.872 .50542 Mdot
.872 .5071 Mdot
.872 .50765 Mdot
.872 .50773 Mdot
.872 .5078 Mdot
.872 .5078 Mdot
.872 .50783 Mdot
.872 .50807 Mdot
.872 .5088 Mdot
.872 .50951 Mdot
.872 .50967 Mdot
.872 .5098 Mdot
.872 .50998 Mdot
.872 .51004 Mdot
.872 .51006 Mdot
.872 .51023 Mdot
.872 .51086 Mdot
.872 .51098 Mdot
.872 .51099 Mdot
.872 .51167 Mdot
.872 .51172 Mdot
.872 .5122 Mdot
.872 .51234 Mdot
.872 .51253 Mdot
.872 .51393 Mdot
.872 .51543 Mdot
.872 .51573 Mdot
.872 .51573 Mdot
.872 .51597 Mdot
.872 .51606 Mdot
.872 .51622 Mdot
.872 .51627 Mdot
.872 .51634 Mdot
.872 .51636 Mdot
.872 .51661 Mdot
.872 .5167 Mdot
.872 .51691 Mdot
.872 .51705 Mdot
.872 .51708 Mdot
.872 .5175 Mdot
.872 .51763 Mdot
.872 .51768 Mdot
.872 .51772 Mdot
.872 .51798 Mdot
.872 .51811 Mdot
.872 .51865 Mdot
.872 .51867 Mdot
.872 .51955 Mdot
.872 .51957 Mdot
.872 .52087 Mdot
.872 .52135 Mdot
.872 .52136 Mdot
.872 .52224 Mdot
.872 .5223 Mdot
.872 .5228 Mdot
.872 .52329 Mdot
.872 .52368 Mdot
.872 .52421 Mdot
.872 .52455 Mdot
.872 .52486 Mdot
.872 .52568 Mdot
.872 .52574 Mdot
.872 .526 Mdot
.872 .52716 Mdot
.872 .52718 Mdot
.872 .52753 Mdot
.872 .52755 Mdot
.872 .52782 Mdot
.872 .52788 Mdot
.872 .52841 Mdot
.872 .52861 Mdot
.872 .52862 Mdot
.872 .52862 Mdot
.872 .52895 Mdot
.872 .52896 Mdot
.872 .5291 Mdot
.872 .52911 Mdot
.874 .14589 Mdot
.874 .14615 Mdot
.874 .14624 Mdot
.874 .14699 Mdot
.874 .1471 Mdot
.874 .14717 Mdot
.874 .14777 Mdot
.874 .14862 Mdot
.874 .14943 Mdot
.874 .15044 Mdot
.874 .15077 Mdot
.874 .15121 Mdot
.874 .15266 Mdot
.874 .15272 Mdot
.874 .15309 Mdot
.874 .15314 Mdot
.874 .15393 Mdot
.874 .15471 Mdot
.874 .155 Mdot
.874 .15645 Mdot
.874 .15658 Mdot
.874 .15702 Mdot
.874 .15757 Mdot
.874 .15842 Mdot
.874 .15966 Mdot
.874 .16001 Mdot
.874 .16014 Mdot
.874 .16353 Mdot
.874 .16355 Mdot
.874 .16383 Mdot
.874 .16444 Mdot
.874 .16482 Mdot
.874 .16594 Mdot
.874 .16641 Mdot
.874 .16661 Mdot
.874 .16674 Mdot
.874 .16686 Mdot
.874 .16785 Mdot
.874 .16809 Mdot
.874 .1684 Mdot
.874 .16949 Mdot
.874 .16964 Mdot
.874 .16986 Mdot
.874 .17011 Mdot
.874 .17135 Mdot
.874 .1715 Mdot
.874 .1724 Mdot
.874 .17241 Mdot
.874 .17256 Mdot
.874 .17397 Mdot
.874 .17427 Mdot
.874 .17462 Mdot
.874 .17597 Mdot
.874 .17615 Mdot
.874 .17616 Mdot
.874 .17628 Mdot
.874 .17755 Mdot
.874 .17757 Mdot
.874 .17786 Mdot
.874 .1787 Mdot
.874 .17879 Mdot
.874 .17936 Mdot
.874 .17969 Mdot
.874 .18105 Mdot
.874 .183 Mdot
.874 .18303 Mdot
.874 .1837 Mdot
.874 .18377 Mdot
.874 .18405 Mdot
.874 .18421 Mdot
.874 .18436 Mdot
.874 .1847 Mdot
.874 .18535 Mdot
.874 .18541 Mdot
.874 .18578 Mdot
.874 .18605 Mdot
.874 .18634 Mdot
.874 .18706 Mdot
.874 .18791 Mdot
.874 .18812 Mdot
.874 .18869 Mdot
.874 .18963 Mdot
.874 .18969 Mdot
.874 .19085 Mdot
.874 .19189 Mdot
.874 .19288 Mdot
.874 .19302 Mdot
.874 .19377 Mdot
.874 .19494 Mdot
.874 .19539 Mdot
.874 .19568 Mdot
.874 .19586 Mdot
.874 .19731 Mdot
.874 .19735 Mdot
.874 .19771 Mdot
.874 .19814 Mdot
.874 .19833 Mdot
.874 .19847 Mdot
.874 .19923 Mdot
.874 .19936 Mdot
.874 .1997 Mdot
.874 .20066 Mdot
.874 .20183 Mdot
.874 .20193 Mdot
.874 .20231 Mdot
.874 .20291 Mdot
.874 .20342 Mdot
.874 .2037 Mdot
.874 .20375 Mdot
.874 .20443 Mdot
.874 .20592 Mdot
.874 .20592 Mdot
.874 .20613 Mdot
.874 .20637 Mdot
.874 .20793 Mdot
.874 .20797 Mdot
.874 .20832 Mdot
.874 .20857 Mdot
.874 .20913 Mdot
.874 .20935 Mdot
.874 .2099 Mdot
.874 .21016 Mdot
.874 .21062 Mdot
.874 .21084 Mdot
.874 .21086 Mdot
.874 .21188 Mdot
.874 .21267 Mdot
.874 .21321 Mdot
.874 .21342 Mdot
.874 .21399 Mdot
.874 .21601 Mdot
.874 .21672 Mdot
.874 .21691 Mdot
.874 .21733 Mdot
.874 .21733 Mdot
.874 .21765 Mdot
.874 .21767 Mdot
.874 .21854 Mdot
.874 .21857 Mdot
.874 .21879 Mdot
.874 .2193 Mdot
.874 .22006 Mdot
.874 .22074 Mdot
.874 .22169 Mdot
.874 .22274 Mdot
.874 .22297 Mdot
.874 .22302 Mdot
.874 .22401 Mdot
.874 .22478 Mdot
.874 .22514 Mdot
.874 .22517 Mdot
.874 .22634 Mdot
.874 .22651 Mdot
.874 .22679 Mdot
.874 .22743 Mdot
.874 .22774 Mdot
.874 .2281 Mdot
.874 .22883 Mdot
.874 .22955 Mdot
.874 .23017 Mdot
.874 .23133 Mdot
.874 .23142 Mdot
.874 .23247 Mdot
.874 .23282 Mdot
.874 .23337 Mdot
.874 .23391 Mdot
.874 .23401 Mdot
.874 .23469 Mdot
.874 .23568 Mdot
.874 .23579 Mdot
.874 .23591 Mdot
.874 .23649 Mdot
.874 .23731 Mdot
.874 .23759 Mdot
.874 .23821 Mdot
.874 .23829 Mdot
.874 .23875 Mdot
.874 .2392 Mdot
.874 .23928 Mdot
.874 .24016 Mdot
.874 .24178 Mdot
.874 .24178 Mdot
.874 .24274 Mdot
.874 .24318 Mdot
.874 .24327 Mdot
.874 .24343 Mdot
.874 .24401 Mdot
.874 .24426 Mdot
.874 .24446 Mdot
.874 .24462 Mdot
.874 .24492 Mdot
.874 .24513 Mdot
.874 .24528 Mdot
.874 .2456 Mdot
.874 .24593 Mdot
.874 .24612 Mdot
.874 .24624 Mdot
.874 .24628 Mdot
.874 .24729 Mdot
.874 .24794 Mdot
.874 .24848 Mdot
.874 .24862 Mdot
.874 .24878 Mdot
.874 .24907 Mdot
.874 .24939 Mdot
.874 .24956 Mdot
.874 .24982 Mdot
.874 .25004 Mdot
.874 .2502 Mdot
.874 .25096 Mdot
.874 .25103 Mdot
.874 .25114 Mdot
.874 .25122 Mdot
.874 .25128 Mdot
.874 .25196 Mdot
.874 .25233 Mdot
.874 .25251 Mdot
.874 .25254 Mdot
.874 .25271 Mdot
.874 .25298 Mdot
.874 .25332 Mdot
.874 .25366 Mdot
.874 .25584 Mdot
.874 .25594 Mdot
.874 .25658 Mdot
.874 .25659 Mdot
.874 .25667 Mdot
.874 .25806 Mdot
.874 .25854 Mdot
.874 .25906 Mdot
.874 .25943 Mdot
.874 .25992 Mdot
.874 .25993 Mdot
.874 .26043 Mdot
.874 .2605 Mdot
.874 .26136 Mdot
.874 .26143 Mdot
.874 .26153 Mdot
.874 .26246 Mdot
.874 .2627 Mdot
.874 .26347 Mdot
.874 .26405 Mdot
.874 .26443 Mdot
.874 .26455 Mdot
.874 .26458 Mdot
.874 .26546 Mdot
.874 .2657 Mdot
.874 .26591 Mdot
.874 .26608 Mdot
.874 .26697 Mdot
.874 .26707 Mdot
.874 .26808 Mdot
.874 .2682 Mdot
.874 .26869 Mdot
.874 .26891 Mdot
.874 .26926 Mdot
.874 .26995 Mdot
.874 .27145 Mdot
.874 .2718 Mdot
.874 .2744 Mdot
.874 .27446 Mdot
.874 .27485 Mdot
.874 .27488 Mdot
.874 .2749 Mdot
.874 .27521 Mdot
.874 .27528 Mdot
.874 .27536 Mdot
.874 .27552 Mdot
.874 .27644 Mdot
.874 .27688 Mdot
.874 .2771 Mdot
.874 .27737 Mdot
.874 .27791 Mdot
.874 .27844 Mdot
.874 .27873 Mdot
.874 .27905 Mdot
.874 .27908 Mdot
.874 .27983 Mdot
.874 .27987 Mdot
.874 .28023 Mdot
.874 .28045 Mdot
.874 .28066 Mdot
.874 .2813 Mdot
.874 .28171 Mdot
.874 .28239 Mdot
.874 .2825 Mdot
.874 .28261 Mdot
.874 .28281 Mdot
.874 .28291 Mdot
.874 .28296 Mdot
.874 .28335 Mdot
.874 .28414 Mdot
.874 .28502 Mdot
.874 .28527 Mdot
.874 .28552 Mdot
.874 .2858 Mdot
.874 .28581 Mdot
.874 .28591 Mdot
.874 .28591 Mdot
.874 .28634 Mdot
.874 .28719 Mdot
.874 .28826 Mdot
.874 .28852 Mdot
.874 .28878 Mdot
.874 .28897 Mdot
.874 .28958 Mdot
.874 .28965 Mdot
.874 .29036 Mdot
.874 .29037 Mdot
.874 .29063 Mdot
.874 .29083 Mdot
.874 .29095 Mdot
.874 .29137 Mdot
.874 .29184 Mdot
.874 .29213 Mdot
.874 .29233 Mdot
.874 .29246 Mdot
.874 .29309 Mdot
.874 .29362 Mdot
.874 .29424 Mdot
.874 .29496 Mdot
.874 .29638 Mdot
.874 .29659 Mdot
.874 .2967 Mdot
.874 .29675 Mdot
.874 .2969 Mdot
.874 .29692 Mdot
.874 .29714 Mdot
.874 .29778 Mdot
.874 .29823 Mdot
.874 .29852 Mdot
.874 .29934 Mdot
.874 .29939 Mdot
.874 .29939 Mdot
.874 .29989 Mdot
.874 .30061 Mdot
.874 .30096 Mdot
.874 .30137 Mdot
.874 .30152 Mdot
.874 .30203 Mdot
.874 .30211 Mdot
.874 .30243 Mdot
.874 .30251 Mdot
.874 .30258 Mdot
.874 .30273 Mdot
.874 .3031 Mdot
.874 .30352 Mdot
.874 .30463 Mdot
.874 .30547 Mdot
.874 .30666 Mdot
.874 .30692 Mdot
.874 .30694 Mdot
.874 .30706 Mdot
.874 .30708 Mdot
.874 .30769 Mdot
.874 .3078 Mdot
.874 .30887 Mdot
.874 .3089 Mdot
.874 .30893 Mdot
.874 .30921 Mdot
.874 .3101 Mdot
.874 .31022 Mdot
.874 .31072 Mdot
.874 .31099 Mdot
.874 .31126 Mdot
.874 .31184 Mdot
.874 .31299 Mdot
.874 .31308 Mdot
.874 .31356 Mdot
.874 .3136 Mdot
.874 .31374 Mdot
.874 .3142 Mdot
.874 .31461 Mdot
.874 .31472 Mdot
.874 .31588 Mdot
.874 .31597 Mdot
.874 .31617 Mdot
.874 .31692 Mdot
.874 .31747 Mdot
.874 .31783 Mdot
.874 .31795 Mdot
.874 .31848 Mdot
.874 .31878 Mdot
.874 .31883 Mdot
.874 .31929 Mdot
.874 .31939 Mdot
.874 .31995 Mdot
.874 .32046 Mdot
.874 .32047 Mdot
.874 .32056 Mdot
.874 .32084 Mdot
.874 .32105 Mdot
.874 .32225 Mdot
.874 .32259 Mdot
.874 .32303 Mdot
.874 .32316 Mdot
.874 .32324 Mdot
.874 .32334 Mdot
.874 .32357 Mdot
.874 .32385 Mdot
.874 .32392 Mdot
.874 .32411 Mdot
.874 .32442 Mdot
.874 .32481 Mdot
.874 .32548 Mdot
.874 .32553 Mdot
.874 .32615 Mdot
.874 .3264 Mdot
.874 .32646 Mdot
.874 .32694 Mdot
.874 .3272 Mdot
.874 .32731 Mdot
.874 .3276 Mdot
.874 .32771 Mdot
.874 .32841 Mdot
.874 .32893 Mdot
.874 .32926 Mdot
.874 .32975 Mdot
.874 .32989 Mdot
.874 .3304 Mdot
.874 .33053 Mdot
.874 .3308 Mdot
.874 .33105 Mdot
.874 .33128 Mdot
.874 .33136 Mdot
.874 .33136 Mdot
.874 .3317 Mdot
.874 .33196 Mdot
.874 .33213 Mdot
.874 .33239 Mdot
.874 .33328 Mdot
.874 .33334 Mdot
.874 .33389 Mdot
.874 .33396 Mdot
.874 .3346 Mdot
.874 .33491 Mdot
.874 .33533 Mdot
.874 .33534 Mdot
.874 .33567 Mdot
.874 .33592 Mdot
.874 .33605 Mdot
.874 .33724 Mdot
.874 .33748 Mdot
.874 .33807 Mdot
.874 .33844 Mdot
.874 .33855 Mdot
.874 .33891 Mdot
.874 .33949 Mdot
.874 .33975 Mdot
.874 .34002 Mdot
.874 .34011 Mdot
.874 .34049 Mdot
.874 .34064 Mdot
.874 .34149 Mdot
.874 .3418 Mdot
.874 .34194 Mdot
.874 .34197 Mdot
.874 .34258 Mdot
.874 .34263 Mdot
.874 .34273 Mdot
.874 .3435 Mdot
.874 .34368 Mdot
.874 .34372 Mdot
.874 .34397 Mdot
.874 .34457 Mdot
.874 .34459 Mdot
.874 .34506 Mdot
.874 .34515 Mdot
.874 .34537 Mdot
.874 .34633 Mdot
.874 .34697 Mdot
.874 .34714 Mdot
.874 .34742 Mdot
.874 .34761 Mdot
.874 .34789 Mdot
.874 .34792 Mdot
.874 .34877 Mdot
.874 .34894 Mdot
.874 .34895 Mdot
.874 .34923 Mdot
.874 .34931 Mdot
.874 .34973 Mdot
.874 .34976 Mdot
.874 .35216 Mdot
.874 .35218 Mdot
.874 .35245 Mdot
.874 .35253 Mdot
.874 .35297 Mdot
.874 .35313 Mdot
.874 .35358 Mdot
.874 .35442 Mdot
.874 .35455 Mdot
.874 .35494 Mdot
.874 .35563 Mdot
.874 .35589 Mdot
.874 .35589 Mdot
.874 .35635 Mdot
.874 .35713 Mdot
.874 .35715 Mdot
.874 .35754 Mdot
.874 .35758 Mdot
.874 .35771 Mdot
.874 .35807 Mdot
.874 .35935 Mdot
.874 .35981 Mdot
.874 .36005 Mdot
.874 .36074 Mdot
.874 .3612 Mdot
.874 .36123 Mdot
.874 .36138 Mdot
.874 .36143 Mdot
.874 .36169 Mdot
.874 .36205 Mdot
.874 .36285 Mdot
.874 .36285 Mdot
.874 .36306 Mdot
.874 .36309 Mdot
.874 .36497 Mdot
.874 .36532 Mdot
.874 .36583 Mdot
.874 .36659 Mdot
.874 .36723 Mdot
.874 .36736 Mdot
.874 .36782 Mdot
.874 .36808 Mdot
.874 .36815 Mdot
.874 .36835 Mdot
.874 .36866 Mdot
.874 .36888 Mdot
.874 .36889 Mdot
.874 .36944 Mdot
.874 .36948 Mdot
.874 .37011 Mdot
.874 .37049 Mdot
.874 .3708 Mdot
.874 .371 Mdot
.874 .37106 Mdot
.874 .37114 Mdot
.874 .37143 Mdot
.874 .37196 Mdot
.874 .37234 Mdot
.874 .37364 Mdot
.874 .37367 Mdot
.874 .37384 Mdot
.874 .37452 Mdot
.874 .37485 Mdot
.874 .37591 Mdot
.874 .37606 Mdot
.874 .37622 Mdot
.874 .3765 Mdot
.874 .37682 Mdot
.874 .37787 Mdot
.874 .37835 Mdot
.874 .37875 Mdot
.874 .37883 Mdot
.874 .37943 Mdot
.874 .37954 Mdot
.874 .38057 Mdot
.874 .38058 Mdot
.874 .38063 Mdot
.874 .38111 Mdot
.874 .38192 Mdot
.874 .38254 Mdot
.874 .38258 Mdot
.874 .38282 Mdot
.874 .38301 Mdot
.874 .38382 Mdot
.874 .38409 Mdot
.874 .38464 Mdot
.874 .38493 Mdot
.874 .38543 Mdot
.874 .38568 Mdot
.874 .38653 Mdot
.874 .38691 Mdot
.874 .38708 Mdot
.874 .38764 Mdot
.874 .38771 Mdot
.874 .38858 Mdot
.874 .38898 Mdot
.874 .38953 Mdot
.874 .39025 Mdot
.874 .3908 Mdot
.874 .39133 Mdot
.874 .39175 Mdot
.874 .39245 Mdot
.874 .39337 Mdot
.874 .39352 Mdot
.874 .39398 Mdot
.874 .39409 Mdot
.874 .39507 Mdot
.874 .39535 Mdot
.874 .39537 Mdot
.874 .39597 Mdot
.874 .39603 Mdot
.874 .39692 Mdot
.874 .39752 Mdot
.874 .39787 Mdot
.874 .39796 Mdot
.874 .39804 Mdot
.874 .39884 Mdot
.874 .39923 Mdot
.874 .39935 Mdot
.874 .4003 Mdot
.874 .40077 Mdot
.874 .40097 Mdot
.874 .40115 Mdot
.874 .40136 Mdot
.874 .40219 Mdot
.874 .40237 Mdot
.874 .40253 Mdot
.874 .40294 Mdot
.874 .40301 Mdot
.874 .40381 Mdot
.874 .4041 Mdot
.874 .4043 Mdot
.874 .40538 Mdot
.874 .40551 Mdot
.874 .40552 Mdot
.874 .40633 Mdot
.874 .40636 Mdot
.874 .40644 Mdot
.874 .40646 Mdot
.874 .40711 Mdot
.874 .40725 Mdot
.874 .40825 Mdot
.874 .40846 Mdot
.874 .40879 Mdot
.874 .4095 Mdot
.874 .40964 Mdot
.874 .41034 Mdot
.874 .41117 Mdot
.874 .41162 Mdot
.874 .41163 Mdot
.874 .413 Mdot
.874 .41331 Mdot
.874 .41357 Mdot
.874 .41406 Mdot
.874 .41407 Mdot
.874 .41423 Mdot
.874 .41434 Mdot
.874 .4145 Mdot
.874 .4146 Mdot
.874 .41552 Mdot
.874 .41596 Mdot
.874 .41631 Mdot
.874 .41646 Mdot
.874 .41659 Mdot
.874 .41702 Mdot
.874 .41711 Mdot
.874 .41748 Mdot
.874 .41774 Mdot
.874 .41822 Mdot
.874 .41831 Mdot
.874 .41852 Mdot
.874 .41858 Mdot
.874 .41888 Mdot
.874 .41921 Mdot
.874 .41942 Mdot
.874 .41948 Mdot
.874 .42085 Mdot
.874 .42126 Mdot
.874 .4215 Mdot
.874 .4224 Mdot
.874 .42243 Mdot
.874 .42294 Mdot
.874 .42309 Mdot
.874 .42319 Mdot
.874 .42334 Mdot
.874 .42353 Mdot
.874 .42357 Mdot
.874 .42385 Mdot
.874 .42408 Mdot
.874 .42437 Mdot
.874 .42473 Mdot
.874 .42492 Mdot
.874 .42522 Mdot
.874 .42568 Mdot
.874 .42585 Mdot
.874 .42591 Mdot
.874 .42606 Mdot
.874 .42634 Mdot
.874 .42687 Mdot
.874 .42689 Mdot
.874 .42728 Mdot
.874 .42768 Mdot
.874 .42779 Mdot
.874 .42782 Mdot
.874 .42798 Mdot
.874 .42812 Mdot
.874 .42817 Mdot
.874 .42822 Mdot
.874 .42829 Mdot
.874 .42874 Mdot
.874 .42943 Mdot
.874 .42955 Mdot
.874 .42977 Mdot
.874 .43006 Mdot
.874 .43038 Mdot
.874 .43044 Mdot
.874 .43073 Mdot
.874 .4309 Mdot
.874 .4312 Mdot
.874 .43179 Mdot
.874 .43222 Mdot
.874 .43239 Mdot
.874 .43311 Mdot
.874 .43372 Mdot
.874 .4362 Mdot
.874 .43638 Mdot
.874 .43701 Mdot
.874 .43707 Mdot
.874 .43742 Mdot
.874 .43743 Mdot
.874 .4375 Mdot
.874 .43751 Mdot
.874 .43766 Mdot
.874 .43882 Mdot
.874 .43946 Mdot
.874 .43991 Mdot
.874 .44 Mdot
.874 .44008 Mdot
.874 .44027 Mdot
.874 .44031 Mdot
.874 .44092 Mdot
.874 .44112 Mdot
.874 .44182 Mdot
.874 .44232 Mdot
.874 .44248 Mdot
.874 .44274 Mdot
.874 .44333 Mdot
.874 .44336 Mdot
.874 .44354 Mdot
.874 .44436 Mdot
.874 .44578 Mdot
.874 .44586 Mdot
.874 .44597 Mdot
.874 .44614 Mdot
.874 .44641 Mdot
.874 .44665 Mdot
.874 .44672 Mdot
.874 .44739 Mdot
.874 .44743 Mdot
.874 .44778 Mdot
.874 .44819 Mdot
.874 .4488 Mdot
.874 .44953 Mdot
.874 .44959 Mdot
.874 .44959 Mdot
.874 .45004 Mdot
.874 .45054 Mdot
.874 .45122 Mdot
.874 .45125 Mdot
.874 .45142 Mdot
.874 .45148 Mdot
.874 .45194 Mdot
.874 .45217 Mdot
.874 .45301 Mdot
.874 .45344 Mdot
.874 .45364 Mdot
.874 .45381 Mdot
.874 .45411 Mdot
.874 .45442 Mdot
.874 .4547 Mdot
.874 .45547 Mdot
.874 .45561 Mdot
.874 .45566 Mdot
.874 .45583 Mdot
.874 .45608 Mdot
.874 .45612 Mdot
.874 .4576 Mdot
.874 .45781 Mdot
.874 .45866 Mdot
.874 .45906 Mdot
.874 .45966 Mdot
.874 .46031 Mdot
.874 .46037 Mdot
.874 .46087 Mdot
.874 .46109 Mdot
.874 .46123 Mdot
.874 .46173 Mdot
.874 .46175 Mdot
.874 .46204 Mdot
.874 .46348 Mdot
.874 .46354 Mdot
.874 .46357 Mdot
.874 .46407 Mdot
.874 .46411 Mdot
.874 .4644 Mdot
.874 .46489 Mdot
.874 .46519 Mdot
.874 .46631 Mdot
.874 .46798 Mdot
.874 .46837 Mdot
.874 .46853 Mdot
.874 .46864 Mdot
.874 .46874 Mdot
.874 .46935 Mdot
.874 .46938 Mdot
.874 .46942 Mdot
.874 .46949 Mdot
.874 .46952 Mdot
.874 .47005 Mdot
.874 .47018 Mdot
.874 .47033 Mdot
.874 .47043 Mdot
.874 .47061 Mdot
.874 .47087 Mdot
.874 .47094 Mdot
.874 .47125 Mdot
.874 .47221 Mdot
.874 .47259 Mdot
.874 .47278 Mdot
.874 .47286 Mdot
.874 .47298 Mdot
.874 .47336 Mdot
.874 .47384 Mdot
.874 .47392 Mdot
.874 .47398 Mdot
.874 .47423 Mdot
.874 .47478 Mdot
.874 .47478 Mdot
.874 .47571 Mdot
.874 .47621 Mdot
.874 .47625 Mdot
.874 .47651 Mdot
.874 .47678 Mdot
.874 .47682 Mdot
.874 .47718 Mdot
.874 .47734 Mdot
.874 .47781 Mdot
.874 .47814 Mdot
.874 .47821 Mdot
.874 .47827 Mdot
.874 .47883 Mdot
.874 .47922 Mdot
.874 .47928 Mdot
.874 .47959 Mdot
.874 .4799 Mdot
.874 .48011 Mdot
.874 .4807 Mdot
.874 .48075 Mdot
.874 .48142 Mdot
.874 .48177 Mdot
.874 .48219 Mdot
.874 .48261 Mdot
.874 .48281 Mdot
.874 .48299 Mdot
.874 .48335 Mdot
.874 .48352 Mdot
.874 .48361 Mdot
.874 .48428 Mdot
.874 .4843 Mdot
.874 .4845 Mdot
.874 .48494 Mdot
.874 .48551 Mdot
.874 .48554 Mdot
.874 .48567 Mdot
.874 .48627 Mdot
.874 .48681 Mdot
.874 .4872 Mdot
.874 .48764 Mdot
.874 .48793 Mdot
.874 .48806 Mdot
.874 .48807 Mdot
.874 .48857 Mdot
.874 .48858 Mdot
.874 .48876 Mdot
.874 .48877 Mdot
.874 .48901 Mdot
.874 .48911 Mdot
.874 .48952 Mdot
.874 .49067 Mdot
.874 .491 Mdot
.874 .49112 Mdot
.874 .49143 Mdot
.874 .49189 Mdot
.874 .49247 Mdot
.874 .49248 Mdot
.874 .49261 Mdot
.874 .49287 Mdot
.874 .49302 Mdot
.874 .49333 Mdot
.874 .49346 Mdot
.874 .49378 Mdot
.874 .49392 Mdot
.874 .49412 Mdot
.874 .49415 Mdot
.874 .49504 Mdot
.874 .49517 Mdot
.874 .49529 Mdot
.874 .49529 Mdot
.874 .49615 Mdot
.874 .49653 Mdot
.874 .49656 Mdot
.874 .49672 Mdot
.874 .49702 Mdot
.874 .49736 Mdot
.874 .49757 Mdot
.874 .49763 Mdot
.874 .4983 Mdot
.874 .49885 Mdot
.874 .49904 Mdot
.874 .49912 Mdot
.874 .49955 Mdot
.874 .49964 Mdot
.874 .49974 Mdot
.874 .49999 Mdot
.874 .5002 Mdot
.874 .50022 Mdot
.874 .50105 Mdot
.874 .50115 Mdot
.874 .50132 Mdot
.874 .50157 Mdot
.874 .50224 Mdot
.874 .50267 Mdot
.874 .50275 Mdot
.874 .50332 Mdot
.874 .50392 Mdot
.874 .50458 Mdot
.874 .50461 Mdot
.874 .50515 Mdot
.874 .50548 Mdot
.874 .50559 Mdot
.874 .50608 Mdot
.874 .50649 Mdot
.874 .50666 Mdot
.874 .50681 Mdot
.874 .50703 Mdot
.874 .50706 Mdot
.874 .50743 Mdot
.874 .50763 Mdot
.874 .50771 Mdot
.874 .5078 Mdot
.874 .50797 Mdot
.874 .508 Mdot
.874 .50839 Mdot
.874 .50841 Mdot
.874 .50952 Mdot
.874 .5103 Mdot
.874 .51049 Mdot
.874 .51081 Mdot
.874 .51086 Mdot
.874 .51135 Mdot
.874 .51151 Mdot
.874 .51152 Mdot
.874 .51225 Mdot
.874 .51232 Mdot
.874 .51233 Mdot
.874 .51243 Mdot
.874 .5132 Mdot
.874 .5134 Mdot
.874 .51357 Mdot
.874 .51438 Mdot
.874 .51446 Mdot
.874 .51447 Mdot
.874 .51498 Mdot
.874 .51507 Mdot
.874 .51578 Mdot
.874 .51592 Mdot
.874 .51605 Mdot
.874 .51613 Mdot
.874 .51676 Mdot
.874 .51694 Mdot
.874 .51707 Mdot
.874 .51764 Mdot
.874 .51771 Mdot
.874 .51778 Mdot
.874 .5179 Mdot
.874 .51817 Mdot
.874 .51881 Mdot
.874 .51902 Mdot
.874 .51937 Mdot
.874 .51953 Mdot
.874 .51954 Mdot
.874 .52148 Mdot
.874 .52156 Mdot
.874 .52176 Mdot
.874 .52247 Mdot
.874 .52295 Mdot
.874 .52327 Mdot
.874 .52352 Mdot
.874 .5236 Mdot
.874 .52442 Mdot
.874 .52459 Mdot
.874 .52504 Mdot
.874 .52549 Mdot
.874 .52552 Mdot
.874 .52573 Mdot
.874 .52576 Mdot
.874 .52659 Mdot
.874 .52684 Mdot
.874 .52703 Mdot
.874 .52761 Mdot
.874 .52807 Mdot
.874 .52856 Mdot
.874 .52891 Mdot
.874 .52894 Mdot
.874 .52901 Mdot
.874 .52944 Mdot
.874 .52949 Mdot
.874 .52964 Mdot
.876 .14302 Mdot
.876 .14323 Mdot
.876 .14331 Mdot
.876 .14424 Mdot
.876 .14427 Mdot
.876 .14567 Mdot
.876 .1462 Mdot
.876 .14745 Mdot
.876 .14959 Mdot
.876 .14962 Mdot
.876 .14973 Mdot
.876 .15038 Mdot
.876 .15069 Mdot
.876 .15083 Mdot
.876 .15113 Mdot
.876 .15116 Mdot
.876 .15119 Mdot
.876 .15132 Mdot
.876 .15148 Mdot
.876 .15156 Mdot
.876 .15204 Mdot
.876 .15258 Mdot
.876 .15322 Mdot
.876 .15344 Mdot
.876 .15502 Mdot
.876 .15506 Mdot
.876 .15515 Mdot
.876 .15587 Mdot
.876 .15603 Mdot
.876 .15651 Mdot
.876 .15686 Mdot
.876 .15729 Mdot
.876 .15741 Mdot
.876 .15742 Mdot
.876 .15784 Mdot
.876 .15835 Mdot
.876 .16055 Mdot
.876 .16085 Mdot
.876 .16196 Mdot
.876 .16214 Mdot
.876 .1622 Mdot
.876 .16306 Mdot
.876 .16331 Mdot
.876 .16376 Mdot
.876 .16495 Mdot
.876 .16503 Mdot
.876 .1651 Mdot
.876 .16558 Mdot
.876 .16567 Mdot
.876 .16678 Mdot
.876 .16684 Mdot
.876 .16743 Mdot
.876 .16778 Mdot
.876 .16959 Mdot
.876 .17072 Mdot
.876 .17284 Mdot
.876 .17383 Mdot
.876 .17418 Mdot
.876 .17428 Mdot
.876 .17452 Mdot
.876 .17511 Mdot
.876 .17592 Mdot
.876 .17733 Mdot
.876 .17863 Mdot
.876 .17933 Mdot
.876 .17949 Mdot
.876 .18038 Mdot
.876 .18055 Mdot
.876 .18116 Mdot
.876 .18138 Mdot
.876 .18149 Mdot
.876 .18154 Mdot
.876 .18163 Mdot
.876 .18183 Mdot
.876 .18316 Mdot
.876 .1837 Mdot
.876 .18433 Mdot
.876 .1855 Mdot
.876 .18568 Mdot
.876 .18579 Mdot
.876 .18666 Mdot
.876 .18719 Mdot
.876 .18765 Mdot
.876 .18865 Mdot
.876 .18892 Mdot
.876 .18923 Mdot
.876 .18973 Mdot
.876 .19006 Mdot
.876 .1902 Mdot
.876 .19033 Mdot
.876 .19079 Mdot
.876 .19132 Mdot
.876 .19159 Mdot
.876 .19179 Mdot
.876 .19218 Mdot
.876 .19237 Mdot
.876 .19264 Mdot
.876 .19264 Mdot
.876 .19281 Mdot
.876 .19366 Mdot
.876 .19378 Mdot
.876 .19425 Mdot
.876 .19429 Mdot
.876 .19521 Mdot
.876 .19575 Mdot
.876 .1966 Mdot
.876 .19674 Mdot
.876 .19676 Mdot
.876 .19788 Mdot
.876 .19799 Mdot
.876 .19875 Mdot
.876 .1989 Mdot
.876 .19899 Mdot
.876 .19952 Mdot
.876 .19977 Mdot
.876 .20038 Mdot
.876 .2004 Mdot
.876 .20048 Mdot
.876 .20062 Mdot
.876 .20075 Mdot
.876 .20084 Mdot
.876 .20295 Mdot
.876 .20311 Mdot
.876 .20316 Mdot
.876 .20514 Mdot
.876 .20573 Mdot
.876 .2065 Mdot
.876 .20734 Mdot
.876 .20801 Mdot
.876 .20807 Mdot
.876 .20808 Mdot
.876 .20836 Mdot
.876 .20935 Mdot
.876 .20983 Mdot
.876 .21033 Mdot
.876 .2107 Mdot
.876 .21084 Mdot
.876 .21103 Mdot
.876 .21117 Mdot
.876 .21219 Mdot
.876 .21337 Mdot
.876 .21484 Mdot
.876 .21544 Mdot
.876 .21555 Mdot
.876 .21631 Mdot
.876 .21632 Mdot
.876 .21645 Mdot
.876 .21908 Mdot
.876 .22128 Mdot
.876 .22197 Mdot
.876 .22245 Mdot
.876 .22245 Mdot
.876 .22306 Mdot
.876 .22328 Mdot
.876 .22345 Mdot
.876 .22412 Mdot
.876 .22421 Mdot
.876 .22465 Mdot
.876 .22495 Mdot
.876 .22507 Mdot
.876 .22518 Mdot
.876 .22707 Mdot
.876 .22713 Mdot
.876 .22796 Mdot
.876 .22843 Mdot
.876 .2292 Mdot
.876 .23022 Mdot
.876 .23054 Mdot
.876 .23084 Mdot
.876 .23116 Mdot
.876 .23126 Mdot
.876 .23127 Mdot
.876 .23197 Mdot
.876 .23218 Mdot
.876 .23261 Mdot
.876 .23483 Mdot
.876 .23593 Mdot
.876 .23601 Mdot
.876 .23646 Mdot
.876 .23653 Mdot
.876 .23704 Mdot
.876 .23719 Mdot
.876 .23774 Mdot
.876 .23791 Mdot
.876 .23827 Mdot
.876 .23837 Mdot
.876 .23951 Mdot
.876 .2396 Mdot
.876 .23964 Mdot
.876 .23987 Mdot
.876 .23999 Mdot
.876 .24001 Mdot
.876 .2404 Mdot
.876 .24165 Mdot
.876 .24169 Mdot
.876 .24223 Mdot
.876 .2425 Mdot
.876 .24351 Mdot
.876 .24415 Mdot
.876 .24508 Mdot
.876 .24667 Mdot
.876 .2468 Mdot
.876 .24682 Mdot
.876 .24726 Mdot
.876 .248 Mdot
.876 .24843 Mdot
.876 .24921 Mdot
.876 .24974 Mdot
.876 .25055 Mdot
.876 .2506 Mdot
.876 .25083 Mdot
.876 .25102 Mdot
.876 .25108 Mdot
.876 .25125 Mdot
.876 .2524 Mdot
.876 .25294 Mdot
.876 .25318 Mdot
.876 .25371 Mdot
.876 .25376 Mdot
.876 .25382 Mdot
.876 .25405 Mdot
.876 .25432 Mdot
.876 .25443 Mdot
.876 .25447 Mdot
.876 .25451 Mdot
.876 .2552 Mdot
.876 .25531 Mdot
.876 .2555 Mdot
.876 .25608 Mdot
.876 .25625 Mdot
.876 .25647 Mdot
.876 .25738 Mdot
.876 .25777 Mdot
.876 .25867 Mdot
.876 .25989 Mdot
.876 .26052 Mdot
.876 .2606 Mdot
.876 .26075 Mdot
.876 .26128 Mdot
.876 .2613 Mdot
.876 .26148 Mdot
.876 .26202 Mdot
.876 .2623 Mdot
.876 .26246 Mdot
.876 .26315 Mdot
.876 .26375 Mdot
.876 .26397 Mdot
.876 .26406 Mdot
.876 .26451 Mdot
.876 .26469 Mdot
.876 .26472 Mdot
.876 .26473 Mdot
.876 .26547 Mdot
.876 .26637 Mdot
.876 .26638 Mdot
.876 .26651 Mdot
.876 .26846 Mdot
.876 .26879 Mdot
.876 .26946 Mdot
.876 .27022 Mdot
.876 .27074 Mdot
.876 .27158 Mdot
.876 .27197 Mdot
.876 .27269 Mdot
.876 .27282 Mdot
.876 .27301 Mdot
.876 .2731 Mdot
.876 .27333 Mdot
.876 .27462 Mdot
.876 .27506 Mdot
.876 .27545 Mdot
.876 .27584 Mdot
.876 .27584 Mdot
.876 .27588 Mdot
.876 .27691 Mdot
.876 .27724 Mdot
.876 .27733 Mdot
.876 .27793 Mdot
.876 .27806 Mdot
.876 .27819 Mdot
.876 .27862 Mdot
.876 .27879 Mdot
.876 .27902 Mdot
.876 .27919 Mdot
.876 .28061 Mdot
.876 .28067 Mdot
.876 .2809 Mdot
.876 .28094 Mdot
.876 .28104 Mdot
.876 .28114 Mdot
.876 .28124 Mdot
.876 .28158 Mdot
.876 .28227 Mdot
.876 .28289 Mdot
.876 .28296 Mdot
.876 .28323 Mdot
.876 .28377 Mdot
.876 .28393 Mdot
.876 .28416 Mdot
.876 .28577 Mdot
.876 .28606 Mdot
.876 .28673 Mdot
.876 .28745 Mdot
.876 .28756 Mdot
.876 .2876 Mdot
.876 .28772 Mdot
.876 .28789 Mdot
.876 .28804 Mdot
.876 .28837 Mdot
.876 .28848 Mdot
.876 .2887 Mdot
.876 .28922 Mdot
.876 .28942 Mdot
.876 .29007 Mdot
.876 .29082 Mdot
.876 .29089 Mdot
.876 .29093 Mdot
.876 .29096 Mdot
.876 .29125 Mdot
.876 .29142 Mdot
.876 .29145 Mdot
.876 .2915 Mdot
.876 .29174 Mdot
.876 .29214 Mdot
.876 .29215 Mdot
.876 .29312 Mdot
.876 .29315 Mdot
.876 .29349 Mdot
.876 .29358 Mdot
.876 .29383 Mdot
.876 .29392 Mdot
.876 .29409 Mdot
.876 .29428 Mdot
.876 .29433 Mdot
.876 .2947 Mdot
.876 .29572 Mdot
.876 .29575 Mdot
.876 .2971 Mdot
.876 .29715 Mdot
.876 .29939 Mdot
.876 .2995 Mdot
.876 .29961 Mdot
.876 .301 Mdot
.876 .30159 Mdot
.876 .30189 Mdot
.876 .30227 Mdot
.876 .3029 Mdot
.876 .30312 Mdot
.876 .3034 Mdot
.876 .30348 Mdot
.876 .30384 Mdot
.876 .30496 Mdot
.876 .30526 Mdot
.876 .30574 Mdot
.876 .30626 Mdot
.876 .30633 Mdot
.876 .30671 Mdot
.876 .3069 Mdot
.876 .30695 Mdot
.876 .30699 Mdot
.876 .30701 Mdot
.876 .30715 Mdot
.876 .30725 Mdot
.876 .30747 Mdot
.876 .3075 Mdot
.876 .30821 Mdot
.876 .30879 Mdot
.876 .30925 Mdot
.876 .30965 Mdot
.876 .30981 Mdot
.876 .30983 Mdot
.876 .31015 Mdot
.876 .31078 Mdot
.876 .31188 Mdot
.876 .31228 Mdot
.876 .31239 Mdot
.876 .31252 Mdot
.876 .31285 Mdot
.876 .31366 Mdot
.876 .31369 Mdot
.876 .31393 Mdot
.876 .31398 Mdot
.876 .31425 Mdot
.876 .31439 Mdot
.876 .31443 Mdot
.876 .31457 Mdot
.876 .31474 Mdot
.876 .31545 Mdot
.876 .31597 Mdot
.876 .31635 Mdot
.876 .31689 Mdot
.876 .31691 Mdot
.876 .31693 Mdot
.876 .31709 Mdot
.876 .31748 Mdot
.876 .31769 Mdot
.876 .31877 Mdot
.876 .31945 Mdot
.876 .31993 Mdot
.876 .32019 Mdot
.876 .32046 Mdot
.876 .32092 Mdot
.876 .32134 Mdot
.876 .32157 Mdot
.876 .32162 Mdot
.876 .32191 Mdot
.876 .32197 Mdot
.876 .32217 Mdot
.876 .32227 Mdot
.876 .32232 Mdot
.876 .32238 Mdot
.876 .32282 Mdot
.876 .32299 Mdot
.876 .3232 Mdot
.876 .32358 Mdot
.876 .32396 Mdot
.876 .32413 Mdot
.876 .32428 Mdot
.876 .32444 Mdot
.876 .32461 Mdot
.876 .32479 Mdot
.876 .32496 Mdot
.876 .32515 Mdot
.876 .32563 Mdot
.876 .32576 Mdot
.876 .32591 Mdot
.876 .32596 Mdot
.876 .32643 Mdot
.876 .32644 Mdot
.876 .32674 Mdot
.876 .32692 Mdot
.876 .3272 Mdot
.876 .32761 Mdot
.876 .32823 Mdot
.876 .32843 Mdot
.876 .32855 Mdot
.876 .32927 Mdot
.876 .32933 Mdot
.876 .33042 Mdot
.876 .33093 Mdot
.876 .33094 Mdot
.876 .3319 Mdot
.876 .33227 Mdot
.876 .33314 Mdot
.876 .33337 Mdot
.876 .33362 Mdot
.876 .33366 Mdot
.876 .33452 Mdot
.876 .33562 Mdot
.876 .33582 Mdot
.876 .33589 Mdot
.876 .33594 Mdot
.876 .33619 Mdot
.876 .33633 Mdot
.876 .33647 Mdot
.876 .33714 Mdot
.876 .33741 Mdot
.876 .33757 Mdot
.876 .33849 Mdot
.876 .33893 Mdot
.876 .33965 Mdot
.876 .34001 Mdot
.876 .34003 Mdot
.876 .34018 Mdot
.876 .34042 Mdot
.876 .34065 Mdot
.876 .3408 Mdot
.876 .34122 Mdot
.876 .34408 Mdot
.876 .34451 Mdot
.876 .34479 Mdot
.876 .34486 Mdot
.876 .34604 Mdot
.876 .34827 Mdot
.876 .34827 Mdot
.876 .34833 Mdot
.876 .34915 Mdot
.876 .34938 Mdot
.876 .34997 Mdot
.876 .35071 Mdot
.876 .35162 Mdot
.876 .35175 Mdot
.876 .35203 Mdot
.876 .35219 Mdot
.876 .35336 Mdot
.876 .35347 Mdot
.876 .3535 Mdot
.876 .35397 Mdot
.876 .35456 Mdot
.876 .35459 Mdot
.876 .3556 Mdot
.876 .35572 Mdot
.876 .35656 Mdot
.876 .35679 Mdot
.876 .35683 Mdot
.876 .35684 Mdot
.876 .35688 Mdot
.876 .35713 Mdot
.876 .3572 Mdot
.876 .35743 Mdot
.876 .35765 Mdot
.876 .35789 Mdot
.876 .35793 Mdot
.876 .35794 Mdot
.876 .35803 Mdot
.876 .35809 Mdot
.876 .35832 Mdot
.876 .35833 Mdot
.876 .35865 Mdot
.876 .3589 Mdot
.876 .35903 Mdot
.876 .35994 Mdot
.876 .36068 Mdot
.876 .36121 Mdot
.876 .3614 Mdot
.876 .36183 Mdot
.876 .36213 Mdot
.876 .36275 Mdot
.876 .36317 Mdot
.876 .36325 Mdot
.876 .36356 Mdot
.876 .36375 Mdot
.876 .36403 Mdot
.876 .36533 Mdot
.876 .36544 Mdot
.876 .36592 Mdot
.876 .36639 Mdot
.876 .3664 Mdot
.876 .36658 Mdot
.876 .36746 Mdot
.876 .3677 Mdot
.876 .36791 Mdot
.876 .36793 Mdot
.876 .36804 Mdot
.876 .36815 Mdot
.876 .36869 Mdot
.876 .36908 Mdot
.876 .36927 Mdot
.876 .36932 Mdot
.876 .36974 Mdot
.876 .36988 Mdot
.876 .37079 Mdot
.876 .37168 Mdot
.876 .37267 Mdot
.876 .37276 Mdot
.876 .3738 Mdot
.876 .37661 Mdot
.876 .37661 Mdot
.876 .37783 Mdot
.876 .37866 Mdot
.876 .37867 Mdot
.876 .3794 Mdot
.876 .37941 Mdot
.876 .37949 Mdot
.876 .37966 Mdot
.876 .37974 Mdot
.876 .37975 Mdot
.876 .38012 Mdot
.876 .38041 Mdot
.876 .38082 Mdot
.876 .38089 Mdot
.876 .38146 Mdot
.876 .38159 Mdot
.876 .38174 Mdot
.876 .38251 Mdot
.876 .38305 Mdot
.876 .38326 Mdot
.876 .38345 Mdot
.876 .3836 Mdot
.876 .38365 Mdot
.876 .38395 Mdot
.876 .38423 Mdot
.876 .38493 Mdot
.876 .38584 Mdot
.876 .38675 Mdot
.876 .38675 Mdot
.876 .38684 Mdot
.876 .38687 Mdot
.876 .38723 Mdot
.876 .38833 Mdot
.876 .38914 Mdot
.876 .3893 Mdot
.876 .38998 Mdot
.876 .39049 Mdot
.876 .39087 Mdot
.876 .39205 Mdot
.876 .39228 Mdot
.876 .39233 Mdot
.876 .39285 Mdot
.876 .39337 Mdot
.876 .39376 Mdot
.876 .39393 Mdot
.876 .3941 Mdot
.876 .39412 Mdot
.876 .39535 Mdot
.876 .39568 Mdot
.876 .39571 Mdot
.876 .39632 Mdot
.876 .39637 Mdot
.876 .39647 Mdot
.876 .39652 Mdot
.876 .39653 Mdot
.876 .39812 Mdot
.876 .39972 Mdot
.876 .40036 Mdot
.876 .40093 Mdot
.876 .40144 Mdot
.876 .40196 Mdot
.876 .40204 Mdot
.876 .40228 Mdot
.876 .4023 Mdot
.876 .40242 Mdot
.876 .40264 Mdot
.876 .40301 Mdot
.876 .4032 Mdot
.876 .40334 Mdot
.876 .40394 Mdot
.876 .40422 Mdot
.876 .40449 Mdot
.876 .4053 Mdot
.876 .40546 Mdot
.876 .40557 Mdot
.876 .40574 Mdot
.876 .40579 Mdot
.876 .40638 Mdot
.876 .40655 Mdot
.876 .4068 Mdot
.876 .40691 Mdot
.876 .40763 Mdot
.876 .40815 Mdot
.876 .40855 Mdot
.876 .40872 Mdot
.876 .40877 Mdot
.876 .40878 Mdot
.876 .4088 Mdot
.876 .40894 Mdot
.876 .4092 Mdot
.876 .40924 Mdot
.876 .40938 Mdot
.876 .4094 Mdot
.876 .40941 Mdot
.876 .40943 Mdot
.876 .41011 Mdot
.876 .41069 Mdot
.876 .4107 Mdot
.876 .41215 Mdot
.876 .4123 Mdot
.876 .41238 Mdot
.876 .41332 Mdot
.876 .41379 Mdot
.876 .41429 Mdot
.876 .41429 Mdot
.876 .41557 Mdot
.876 .41668 Mdot
.876 .41832 Mdot
.876 .41921 Mdot
.876 .42103 Mdot
.876 .42111 Mdot
.876 .42119 Mdot
.876 .42133 Mdot
.876 .42136 Mdot
.876 .42214 Mdot
.876 .42293 Mdot
.876 .42342 Mdot
.876 .42419 Mdot
.876 .42448 Mdot
.876 .42555 Mdot
.876 .42608 Mdot
.876 .42632 Mdot
.876 .42648 Mdot
.876 .42706 Mdot
.876 .42714 Mdot
.876 .42749 Mdot
.876 .42789 Mdot
.876 .42799 Mdot
.876 .42817 Mdot
.876 .42839 Mdot
.876 .42872 Mdot
.876 .42882 Mdot
.876 .4291 Mdot
.876 .42913 Mdot
.876 .42931 Mdot
.876 .4295 Mdot
.876 .42953 Mdot
.876 .4299 Mdot
.876 .43032 Mdot
.876 .43113 Mdot
.876 .43187 Mdot
.876 .43209 Mdot
.876 .43218 Mdot
.876 .43219 Mdot
.876 .43251 Mdot
.876 .43302 Mdot
.876 .43343 Mdot
.876 .43353 Mdot
.876 .43363 Mdot
.876 .43386 Mdot
.876 .43403 Mdot
.876 .43404 Mdot
.876 .43451 Mdot
.876 .4347 Mdot
.876 .43477 Mdot
.876 .43483 Mdot
.876 .43605 Mdot
.876 .43624 Mdot
.876 .43634 Mdot
.876 .43656 Mdot
.876 .43683 Mdot
.876 .43716 Mdot
.876 .43758 Mdot
.876 .4377 Mdot
.876 .43784 Mdot
.876 .43788 Mdot
.876 .43827 Mdot
.876 .43857 Mdot
.876 .43965 Mdot
.876 .43986 Mdot
.876 .44019 Mdot
.876 .44055 Mdot
.876 .44094 Mdot
.876 .44128 Mdot
.876 .44213 Mdot
.876 .44219 Mdot
.876 .4435 Mdot
.876 .44427 Mdot
.876 .44508 Mdot
.876 .44532 Mdot
.876 .44537 Mdot
.876 .44551 Mdot
.876 .44575 Mdot
.876 .44577 Mdot
.876 .44632 Mdot
.876 .44633 Mdot
.876 .4467 Mdot
.876 .44673 Mdot
.876 .44674 Mdot
.876 .44684 Mdot
.876 .447 Mdot
.876 .44702 Mdot
.876 .44705 Mdot
.876 .44709 Mdot
.876 .44751 Mdot
.876 .44789 Mdot
.876 .448 Mdot
.876 .4483 Mdot
.876 .44842 Mdot
.876 .44848 Mdot
.876 .44876 Mdot
.876 .44885 Mdot
.876 .44892 Mdot
.876 .44895 Mdot
.876 .44901 Mdot
.876 .44942 Mdot
.876 .44997 Mdot
.876 .45089 Mdot
.876 .45102 Mdot
.876 .4511 Mdot
.876 .45142 Mdot
.876 .45157 Mdot
.876 .45236 Mdot
.876 .45267 Mdot
.876 .45272 Mdot
.876 .45275 Mdot
.876 .45288 Mdot
.876 .45291 Mdot
.876 .45395 Mdot
.876 .45405 Mdot
.876 .45478 Mdot
.876 .45483 Mdot
.876 .45502 Mdot
.876 .45561 Mdot
.876 .45563 Mdot
.876 .45586 Mdot
.876 .45707 Mdot
.876 .45736 Mdot
.876 .45784 Mdot
.876 .45807 Mdot
.876 .45927 Mdot
.876 .45966 Mdot
.876 .45985 Mdot
.876 .46096 Mdot
.876 .46103 Mdot
.876 .462 Mdot
.876 .46236 Mdot
.876 .46241 Mdot
.876 .46327 Mdot
.876 .46383 Mdot
.876 .46393 Mdot
.876 .46394 Mdot
.876 .46474 Mdot
.876 .46543 Mdot
.876 .46669 Mdot
.876 .46691 Mdot
.876 .46725 Mdot
.876 .46741 Mdot
.876 .46781 Mdot
.876 .46785 Mdot
.876 .46991 Mdot
.876 .47004 Mdot
.876 .47007 Mdot
.876 .47053 Mdot
.876 .47083 Mdot
.876 .47128 Mdot
.876 .47153 Mdot
.876 .4722 Mdot
.876 .47221 Mdot
.876 .47228 Mdot
.876 .47409 Mdot
.876 .47466 Mdot
.876 .47482 Mdot
.876 .47586 Mdot
.876 .4761 Mdot
.876 .4763 Mdot
.876 .47632 Mdot
.876 .47702 Mdot
.876 .47708 Mdot
.876 .47729 Mdot
.876 .47738 Mdot
.876 .47769 Mdot
.876 .47778 Mdot
.876 .47807 Mdot
.876 .47811 Mdot
.876 .47837 Mdot
.876 .47842 Mdot
.876 .47904 Mdot
.876 .48031 Mdot
.876 .48055 Mdot
.876 .48067 Mdot
.876 .48107 Mdot
.876 .48108 Mdot
.876 .48114 Mdot
.876 .48132 Mdot
.876 .48149 Mdot
.876 .48167 Mdot
.876 .48226 Mdot
.876 .48269 Mdot
.876 .48296 Mdot
.876 .48344 Mdot
.876 .48347 Mdot
.876 .48455 Mdot
.876 .48461 Mdot
.876 .48468 Mdot
.876 .48485 Mdot
.876 .48511 Mdot
.876 .48516 Mdot
.876 .48554 Mdot
.876 .48564 Mdot
.876 .48576 Mdot
.876 .48611 Mdot
.876 .48611 Mdot
.876 .48638 Mdot
.876 .48678 Mdot
.876 .48803 Mdot
.876 .48953 Mdot
.876 .48961 Mdot
.876 .48961 Mdot
.876 .49005 Mdot
.876 .49011 Mdot
.876 .49045 Mdot
.876 .49129 Mdot
.876 .49197 Mdot
.876 .49255 Mdot
.876 .49263 Mdot
.876 .49274 Mdot
.876 .49281 Mdot
.876 .49302 Mdot
.876 .49331 Mdot
.876 .49358 Mdot
.876 .49415 Mdot
.876 .49431 Mdot
.876 .49432 Mdot
.876 .49435 Mdot
.876 .49473 Mdot
.876 .49521 Mdot
.876 .49565 Mdot
.876 .49599 Mdot
.876 .49712 Mdot
.876 .49714 Mdot
.876 .49724 Mdot
.876 .49844 Mdot
.876 .49849 Mdot
.876 .49857 Mdot
.876 .49865 Mdot
.876 .49869 Mdot
.876 .4987 Mdot
.876 .49905 Mdot
.876 .4992 Mdot
.876 .4995 Mdot
.876 .49955 Mdot
.876 .49964 Mdot
.876 .50007 Mdot
.876 .50013 Mdot
.876 .50077 Mdot
.876 .50078 Mdot
.876 .50086 Mdot
.876 .50134 Mdot
.876 .50166 Mdot
.876 .50218 Mdot
.876 .5022 Mdot
.876 .50247 Mdot
.876 .50254 Mdot
.876 .50302 Mdot
.876 .50312 Mdot
.876 .50312 Mdot
.876 .50328 Mdot
.876 .50339 Mdot
.876 .5036 Mdot
.876 .50372 Mdot
.876 .50387 Mdot
.876 .50418 Mdot
.876 .50444 Mdot
.876 .50451 Mdot
.876 .5046 Mdot
.876 .50478 Mdot
.876 .50507 Mdot
.876 .50524 Mdot
.876 .5054 Mdot
.876 .50569 Mdot
.876 .50597 Mdot
.876 .50623 Mdot
.876 .50653 Mdot
.876 .50703 Mdot
.876 .50709 Mdot
.876 .5072 Mdot
.876 .50787 Mdot
.876 .50822 Mdot
.876 .50853 Mdot
.876 .50929 Mdot
.876 .50941 Mdot
.876 .50946 Mdot
.876 .50949 Mdot
.876 .50955 Mdot
.876 .50967 Mdot
.876 .51002 Mdot
.876 .51012 Mdot
.876 .51063 Mdot
.876 .51072 Mdot
.876 .51112 Mdot
.876 .51186 Mdot
.876 .51266 Mdot
.876 .51313 Mdot
.876 .51346 Mdot
.876 .5136 Mdot
.876 .51366 Mdot
.876 .51386 Mdot
.876 .51443 Mdot
.876 .51563 Mdot
.876 .51628 Mdot
.876 .51731 Mdot
.876 .51751 Mdot
.876 .51785 Mdot
.876 .51788 Mdot
.876 .51852 Mdot
.876 .51857 Mdot
.876 .51884 Mdot
.876 .51888 Mdot
.876 .51893 Mdot
.876 .51961 Mdot
.876 .51986 Mdot
.876 .52 Mdot
.876 .5205 Mdot
.876 .52053 Mdot
.876 .52063 Mdot
.876 .52127 Mdot
.876 .52144 Mdot
.876 .52269 Mdot
.876 .52298 Mdot
.876 .52323 Mdot
.876 .52323 Mdot
.876 .5233 Mdot
.876 .52355 Mdot
.876 .52374 Mdot
.876 .52402 Mdot
.876 .52411 Mdot
.876 .52452 Mdot
.876 .52457 Mdot
.876 .5246 Mdot
.876 .52549 Mdot
.876 .52562 Mdot
.876 .52599 Mdot
.876 .52629 Mdot
.876 .52657 Mdot
.876 .52662 Mdot
.876 .52671 Mdot
.876 .52678 Mdot
.876 .5268 Mdot
.876 .52682 Mdot
.876 .52699 Mdot
.876 .52707 Mdot
.876 .52724 Mdot
.876 .52762 Mdot
.876 .52767 Mdot
.876 .52769 Mdot
.876 .52892 Mdot
.876 .52963 Mdot
.876 .52993 Mdot
.876 .53073 Mdot
.876 .53075 Mdot
.876 .53128 Mdot
.876 .53132 Mdot
.876 .53144 Mdot
.878 .14118 Mdot
.878 .14141 Mdot
.878 .14243 Mdot
.878 .14375 Mdot
.878 .14412 Mdot
.878 .14639 Mdot
.878 .14677 Mdot
.878 .1473 Mdot
.878 .14789 Mdot
.878 .14793 Mdot
.878 .1481 Mdot
.878 .14833 Mdot
.878 .14846 Mdot
.878 .14926 Mdot
.878 .14956 Mdot
.878 .14978 Mdot
.878 .15155 Mdot
.878 .15226 Mdot
.878 .15233 Mdot
.878 .1528 Mdot
.878 .15283 Mdot
.878 .15351 Mdot
.878 .15393 Mdot
.878 .15399 Mdot
.878 .15568 Mdot
.878 .15584 Mdot
.878 .15616 Mdot
.878 .15639 Mdot
.878 .15667 Mdot
.878 .15795 Mdot
.878 .15812 Mdot
.878 .15821 Mdot
.878 .15829 Mdot
.878 .15896 Mdot
.878 .15936 Mdot
.878 .1598 Mdot
.878 .16042 Mdot
.878 .1613 Mdot
.878 .16176 Mdot
.878 .16224 Mdot
.878 .16243 Mdot
.878 .16253 Mdot
.878 .16282 Mdot
.878 .16375 Mdot
.878 .16402 Mdot
.878 .16481 Mdot
.878 .16664 Mdot
.878 .16716 Mdot
.878 .1687 Mdot
.878 .16878 Mdot
.878 .16891 Mdot
.878 .17014 Mdot
.878 .1703 Mdot
.878 .17082 Mdot
.878 .17101 Mdot
.878 .17249 Mdot
.878 .17335 Mdot
.878 .17364 Mdot
.878 .17443 Mdot
.878 .17458 Mdot
.878 .17477 Mdot
.878 .17531 Mdot
.878 .17537 Mdot
.878 .17591 Mdot
.878 .17637 Mdot
.878 .17648 Mdot
.878 .17654 Mdot
.878 .17734 Mdot
.878 .17789 Mdot
.878 .17959 Mdot
.878 .18053 Mdot
.878 .18064 Mdot
.878 .18077 Mdot
.878 .18114 Mdot
.878 .18119 Mdot
.878 .18145 Mdot
.878 .18165 Mdot
.878 .18269 Mdot
.878 .18326 Mdot
.878 .18384 Mdot
.878 .18399 Mdot
.878 .18403 Mdot
.878 .1843 Mdot
.878 .18508 Mdot
.878 .18539 Mdot
.878 .18586 Mdot
.878 .18607 Mdot
.878 .18671 Mdot
.878 .18708 Mdot
.878 .18809 Mdot
.878 .1901 Mdot
.878 .19015 Mdot
.878 .19048 Mdot
.878 .19062 Mdot
.878 .19068 Mdot
.878 .19138 Mdot
.878 .19175 Mdot
.878 .19198 Mdot
.878 .1923 Mdot
.878 .19249 Mdot
.878 .1929 Mdot
.878 .19308 Mdot
.878 .19414 Mdot
.878 .19515 Mdot
.878 .19632 Mdot
.878 .19637 Mdot
.878 .19731 Mdot
.878 .19747 Mdot
.878 .19902 Mdot
.878 .20024 Mdot
.878 .20056 Mdot
.878 .20058 Mdot
.878 .2018 Mdot
.878 .202 Mdot
.878 .20225 Mdot
.878 .20243 Mdot
.878 .20305 Mdot
.878 .20398 Mdot
.878 .2044 Mdot
.878 .20473 Mdot
.878 .20492 Mdot
.878 .20541 Mdot
.878 .20761 Mdot
.878 .20824 Mdot
.878 .20826 Mdot
.878 .20838 Mdot
.878 .20852 Mdot
.878 .20852 Mdot
.878 .20859 Mdot
.878 .20907 Mdot
.878 .20913 Mdot
.878 .2092 Mdot
.878 .20985 Mdot
.878 .21029 Mdot
.878 .2111 Mdot
.878 .21231 Mdot
.878 .21246 Mdot
.878 .21248 Mdot
.878 .21263 Mdot
.878 .21474 Mdot
.878 .21487 Mdot
.878 .21512 Mdot
.878 .21549 Mdot
.878 .21577 Mdot
.878 .21649 Mdot
.878 .21691 Mdot
.878 .21786 Mdot
.878 .21787 Mdot
.878 .21791 Mdot
.878 .21852 Mdot
.878 .21928 Mdot
.878 .21961 Mdot
.878 .22023 Mdot
.878 .22073 Mdot
.878 .22106 Mdot
.878 .2211 Mdot
.878 .22125 Mdot
.878 .22176 Mdot
.878 .22461 Mdot
.878 .22524 Mdot
.878 .22629 Mdot
.878 .22738 Mdot
.878 .22741 Mdot
.878 .22804 Mdot
.878 .22862 Mdot
.878 .22946 Mdot
.878 .22985 Mdot
.878 .22986 Mdot
.878 .23069 Mdot
.878 .23193 Mdot
.878 .23216 Mdot
.878 .23264 Mdot
.878 .23374 Mdot
.878 .23413 Mdot
.878 .23456 Mdot
.878 .2352 Mdot
.878 .23572 Mdot
.878 .23609 Mdot
.878 .23671 Mdot
.878 .23679 Mdot
.878 .2372 Mdot
.878 .23754 Mdot
.878 .23782 Mdot
.878 .2379 Mdot
.878 .23795 Mdot
.878 .23898 Mdot
.878 .23898 Mdot
.878 .2398 Mdot
.878 .24014 Mdot
.878 .24066 Mdot
.878 .24131 Mdot
.878 .24196 Mdot
.878 .24225 Mdot
.878 .24374 Mdot
.878 .24455 Mdot
.878 .24507 Mdot
.878 .24512 Mdot
.878 .2456 Mdot
.878 .24594 Mdot
.878 .24661 Mdot
.878 .24694 Mdot
.878 .2472 Mdot
.878 .24753 Mdot
.878 .24774 Mdot
.878 .24786 Mdot
.878 .24792 Mdot
.878 .24841 Mdot
.878 .24857 Mdot
.878 .24864 Mdot
.878 .24877 Mdot
.878 .24893 Mdot
.878 .24934 Mdot
.878 .24957 Mdot
.878 .25029 Mdot
.878 .25053 Mdot
.878 .25087 Mdot
.878 .25097 Mdot
.878 .2513 Mdot
.878 .2515 Mdot
.878 .25188 Mdot
.878 .2519 Mdot
.878 .25211 Mdot
.878 .25278 Mdot
.878 .25341 Mdot
.878 .2543 Mdot
.878 .25446 Mdot
.878 .25499 Mdot
.878 .2562 Mdot
.878 .25625 Mdot
.878 .25633 Mdot
.878 .25637 Mdot
.878 .25699 Mdot
.878 .25719 Mdot
.878 .25724 Mdot
.878 .25844 Mdot
.878 .25862 Mdot
.878 .25883 Mdot
.878 .25918 Mdot
.878 .25929 Mdot
.878 .25939 Mdot
.878 .26037 Mdot
.878 .26143 Mdot
.878 .26171 Mdot
.878 .26173 Mdot
.878 .26225 Mdot
.878 .26238 Mdot
.878 .26253 Mdot
.878 .26253 Mdot
.878 .26254 Mdot
.878 .26309 Mdot
.878 .2635 Mdot
.878 .26398 Mdot
.878 .2641 Mdot
.878 .26465 Mdot
.878 .26508 Mdot
.878 .26532 Mdot
.878 .26624 Mdot
.878 .26653 Mdot
.878 .2667 Mdot
.878 .26683 Mdot
.878 .26746 Mdot
.878 .26801 Mdot
.878 .26872 Mdot
.878 .26949 Mdot
.878 .26963 Mdot
.878 .27058 Mdot
.878 .27133 Mdot
.878 .27152 Mdot
.878 .27211 Mdot
.878 .27293 Mdot
.878 .27299 Mdot
.878 .27327 Mdot
.878 .27348 Mdot
.878 .2737 Mdot
.878 .27377 Mdot
.878 .2741 Mdot
.878 .27421 Mdot
.878 .27429 Mdot
.878 .27478 Mdot
.878 .27511 Mdot
.878 .27598 Mdot
.878 .27641 Mdot
.878 .27689 Mdot
.878 .27758 Mdot
.878 .27769 Mdot
.878 .27796 Mdot
.878 .27829 Mdot
.878 .27869 Mdot
.878 .27939 Mdot
.878 .27953 Mdot
.878 .28001 Mdot
.878 .28017 Mdot
.878 .28091 Mdot
.878 .28092 Mdot
.878 .28132 Mdot
.878 .2815 Mdot
.878 .28172 Mdot
.878 .28207 Mdot
.878 .28241 Mdot
.878 .28262 Mdot
.878 .28354 Mdot
.878 .28387 Mdot
.878 .28424 Mdot
.878 .28459 Mdot
.878 .2848 Mdot
.878 .28511 Mdot
.878 .28525 Mdot
.878 .28548 Mdot
.878 .28582 Mdot
.878 .2865 Mdot
.878 .28655 Mdot
.878 .28655 Mdot
.878 .287 Mdot
.878 .2874 Mdot
.878 .28763 Mdot
.878 .28792 Mdot
.878 .28813 Mdot
.878 .28884 Mdot
.878 .289 Mdot
.878 .28906 Mdot
.878 .28917 Mdot
.878 .28995 Mdot
.878 .29052 Mdot
.878 .29142 Mdot
.878 .29177 Mdot
.878 .29309 Mdot
.878 .2932 Mdot
.878 .29327 Mdot
.878 .29362 Mdot
.878 .29364 Mdot
.878 .29368 Mdot
.878 .29379 Mdot
.878 .29491 Mdot
.878 .29518 Mdot
.878 .29543 Mdot
.878 .29577 Mdot
.878 .29621 Mdot
.878 .29655 Mdot
.878 .29671 Mdot
.878 .29683 Mdot
.878 .29688 Mdot
.878 .29777 Mdot
.878 .29795 Mdot
.878 .2982 Mdot
.878 .29858 Mdot
.878 .2986 Mdot
.878 .29878 Mdot
.878 .29889 Mdot
.878 .29914 Mdot
.878 .30028 Mdot
.878 .30125 Mdot
.878 .30141 Mdot
.878 .30226 Mdot
.878 .30235 Mdot
.878 .30284 Mdot
.878 .303 Mdot
.878 .30315 Mdot
.878 .30343 Mdot
.878 .30363 Mdot
.878 .3039 Mdot
.878 .30423 Mdot
.878 .30465 Mdot
.878 .30554 Mdot
.878 .30567 Mdot
.878 .30589 Mdot
.878 .3059 Mdot
.878 .30606 Mdot
.878 .30608 Mdot
.878 .30631 Mdot
.878 .30695 Mdot
.878 .30705 Mdot
.878 .30731 Mdot
.878 .3075 Mdot
.878 .30786 Mdot
.878 .30967 Mdot
.878 .3098 Mdot
.878 .31013 Mdot
.878 .31056 Mdot
.878 .31068 Mdot
.878 .31141 Mdot
.878 .31171 Mdot
.878 .31191 Mdot
.878 .31196 Mdot
.878 .31204 Mdot
.878 .31251 Mdot
.878 .31388 Mdot
.878 .31442 Mdot
.878 .31447 Mdot
.878 .31458 Mdot
.878 .31466 Mdot
.878 .31521 Mdot
.878 .31524 Mdot
.878 .31527 Mdot
.878 .31562 Mdot
.878 .31661 Mdot
.878 .31665 Mdot
.878 .31674 Mdot
.878 .31739 Mdot
.878 .31865 Mdot
.878 .31867 Mdot
.878 .31871 Mdot
.878 .31917 Mdot
.878 .31933 Mdot
.878 .31939 Mdot
.878 .31988 Mdot
.878 .32015 Mdot
.878 .32055 Mdot
.878 .32098 Mdot
.878 .32113 Mdot
.878 .32117 Mdot
.878 .32218 Mdot
.878 .32248 Mdot
.878 .3227 Mdot
.878 .32278 Mdot
.878 .32337 Mdot
.878 .32356 Mdot
.878 .3236 Mdot
.878 .32371 Mdot
.878 .32406 Mdot
.878 .32428 Mdot
.878 .32461 Mdot
.878 .32493 Mdot
.878 .32559 Mdot
.878 .326 Mdot
.878 .32636 Mdot
.878 .32649 Mdot
.878 .32655 Mdot
.878 .3269 Mdot
.878 .32722 Mdot
.878 .3276 Mdot
.878 .32793 Mdot
.878 .32848 Mdot
.878 .32898 Mdot
.878 .32898 Mdot
.878 .32938 Mdot
.878 .32953 Mdot
.878 .32958 Mdot
.878 .32979 Mdot
.878 .33009 Mdot
.878 .33148 Mdot
.878 .33151 Mdot
.878 .33156 Mdot
.878 .33156 Mdot
.878 .33158 Mdot
.878 .33174 Mdot
.878 .33178 Mdot
.878 .33214 Mdot
.878 .33279 Mdot
.878 .33362 Mdot
.878 .3337 Mdot
.878 .33382 Mdot
.878 .33459 Mdot
.878 .3346 Mdot
.878 .33505 Mdot
.878 .33536 Mdot
.878 .33563 Mdot
.878 .33564 Mdot
.878 .33569 Mdot
.878 .33768 Mdot
.878 .33835 Mdot
.878 .33875 Mdot
.878 .33915 Mdot
.878 .33974 Mdot
.878 .34021 Mdot
.878 .34038 Mdot
.878 .3405 Mdot
.878 .34097 Mdot
.878 .34106 Mdot
.878 .34109 Mdot
.878 .34198 Mdot
.878 .34324 Mdot
.878 .34343 Mdot
.878 .34358 Mdot
.878 .34402 Mdot
.878 .3441 Mdot
.878 .34432 Mdot
.878 .34434 Mdot
.878 .3445 Mdot
.878 .34543 Mdot
.878 .34702 Mdot
.878 .34706 Mdot
.878 .34781 Mdot
.878 .34838 Mdot
.878 .34872 Mdot
.878 .34881 Mdot
.878 .34903 Mdot
.878 .34907 Mdot
.878 .34908 Mdot
.878 .34958 Mdot
.878 .34998 Mdot
.878 .35199 Mdot
.878 .35247 Mdot
.878 .35263 Mdot
.878 .35344 Mdot
.878 .35396 Mdot
.878 .35399 Mdot
.878 .35454 Mdot
.878 .35459 Mdot
.878 .35479 Mdot
.878 .35504 Mdot
.878 .35504 Mdot
.878 .35517 Mdot
.878 .35559 Mdot
.878 .356 Mdot
.878 .35611 Mdot
.878 .35623 Mdot
.878 .35663 Mdot
.878 .35738 Mdot
.878 .35815 Mdot
.878 .35844 Mdot
.878 .35899 Mdot
.878 .35916 Mdot
.878 .35916 Mdot
.878 .35918 Mdot
.878 .35958 Mdot
.878 .36064 Mdot
.878 .36169 Mdot
.878 .36196 Mdot
.878 .36199 Mdot
.878 .36225 Mdot
.878 .36234 Mdot
.878 .36249 Mdot
.878 .36273 Mdot
.878 .3636 Mdot
.878 .36451 Mdot
.878 .36465 Mdot
.878 .36592 Mdot
.878 .36596 Mdot
.878 .36616 Mdot
.878 .36618 Mdot
.878 .36663 Mdot
.878 .36727 Mdot
.878 .3673 Mdot
.878 .36767 Mdot
.878 .36776 Mdot
.878 .36803 Mdot
.878 .36808 Mdot
.878 .36903 Mdot
.878 .36921 Mdot
.878 .36978 Mdot
.878 .37063 Mdot
.878 .3708 Mdot
.878 .37143 Mdot
.878 .37145 Mdot
.878 .37146 Mdot
.878 .37152 Mdot
.878 .37244 Mdot
.878 .37259 Mdot
.878 .3728 Mdot
.878 .37392 Mdot
.878 .37411 Mdot
.878 .37451 Mdot
.878 .37531 Mdot
.878 .3756 Mdot
.878 .37648 Mdot
.878 .37706 Mdot
.878 .37713 Mdot
.878 .37714 Mdot
.878 .37824 Mdot
.878 .37829 Mdot
.878 .37872 Mdot
.878 .38018 Mdot
.878 .38036 Mdot
.878 .38042 Mdot
.878 .38089 Mdot
.878 .38215 Mdot
.878 .38305 Mdot
.878 .38317 Mdot
.878 .38329 Mdot
.878 .38413 Mdot
.878 .3844 Mdot
.878 .38472 Mdot
.878 .38624 Mdot
.878 .3866 Mdot
.878 .38729 Mdot
.878 .38731 Mdot
.878 .38787 Mdot
.878 .38816 Mdot
.878 .3882 Mdot
.878 .38851 Mdot
.878 .38931 Mdot
.878 .38972 Mdot
.878 .39032 Mdot
.878 .39112 Mdot
.878 .39181 Mdot
.878 .39218 Mdot
.878 .3925 Mdot
.878 .39251 Mdot
.878 .3929 Mdot
.878 .39397 Mdot
.878 .3943 Mdot
.878 .39485 Mdot
.878 .39492 Mdot
.878 .39543 Mdot
.878 .39615 Mdot
.878 .39642 Mdot
.878 .39645 Mdot
.878 .39655 Mdot
.878 .39738 Mdot
.878 .39766 Mdot
.878 .39828 Mdot
.878 .39933 Mdot
.878 .40001 Mdot
.878 .40076 Mdot
.878 .40096 Mdot
.878 .40152 Mdot
.878 .40189 Mdot
.878 .40199 Mdot
.878 .4028 Mdot
.878 .40344 Mdot
.878 .40347 Mdot
.878 .40368 Mdot
.878 .40389 Mdot
.878 .40454 Mdot
.878 .40467 Mdot
.878 .4054 Mdot
.878 .40548 Mdot
.878 .406 Mdot
.878 .40649 Mdot
.878 .40663 Mdot
.878 .40671 Mdot
.878 .40768 Mdot
.878 .40851 Mdot
.878 .40852 Mdot
.878 .40853 Mdot
.878 .40862 Mdot
.878 .40893 Mdot
.878 .40997 Mdot
.878 .41056 Mdot
.878 .41147 Mdot
.878 .41149 Mdot
.878 .41225 Mdot
.878 .41234 Mdot
.878 .41261 Mdot
.878 .41375 Mdot
.878 .41427 Mdot
.878 .41427 Mdot
.878 .41429 Mdot
.878 .41442 Mdot
.878 .41544 Mdot
.878 .41688 Mdot
.878 .41698 Mdot
.878 .41748 Mdot
.878 .41831 Mdot
.878 .41888 Mdot
.878 .41922 Mdot
.878 .41931 Mdot
.878 .41958 Mdot
.878 .41992 Mdot
.878 .42015 Mdot
.878 .42075 Mdot
.878 .42189 Mdot
.878 .42192 Mdot
.878 .42226 Mdot
.878 .42251 Mdot
.878 .42252 Mdot
.878 .42296 Mdot
.878 .42354 Mdot
.878 .42391 Mdot
.878 .42412 Mdot
.878 .42414 Mdot
.878 .42423 Mdot
.878 .42424 Mdot
.878 .42427 Mdot
.878 .42429 Mdot
.878 .42508 Mdot
.878 .42537 Mdot
.878 .4254 Mdot
.878 .42548 Mdot
.878 .42571 Mdot
.878 .42571 Mdot
.878 .426 Mdot
.878 .42671 Mdot
.878 .42713 Mdot
.878 .4272 Mdot
.878 .4282 Mdot
.878 .42839 Mdot
.878 .42851 Mdot
.878 .4288 Mdot
.878 .42941 Mdot
.878 .42959 Mdot
.878 .43016 Mdot
.878 .43018 Mdot
.878 .43027 Mdot
.878 .43051 Mdot
.878 .43074 Mdot
.878 .4309 Mdot
.878 .43117 Mdot
.878 .4312 Mdot
.878 .43156 Mdot
.878 .43158 Mdot
.878 .4316 Mdot
.878 .43274 Mdot
.878 .43275 Mdot
.878 .43352 Mdot
.878 .43355 Mdot
.878 .43387 Mdot
.878 .43391 Mdot
.878 .43397 Mdot
.878 .43543 Mdot
.878 .43572 Mdot
.878 .4362 Mdot
.878 .43645 Mdot
.878 .43664 Mdot
.878 .43805 Mdot
.878 .43877 Mdot
.878 .43885 Mdot
.878 .43898 Mdot
.878 .43906 Mdot
.878 .43957 Mdot
.878 .43999 Mdot
.878 .44015 Mdot
.878 .44026 Mdot
.878 .44042 Mdot
.878 .44051 Mdot
.878 .4406 Mdot
.878 .44087 Mdot
.878 .44093 Mdot
.878 .44141 Mdot
.878 .4427 Mdot
.878 .44301 Mdot
.878 .44324 Mdot
.878 .44338 Mdot
.878 .44399 Mdot
.878 .44418 Mdot
.878 .44437 Mdot
.878 .44512 Mdot
.878 .44581 Mdot
.878 .44584 Mdot
.878 .44585 Mdot
.878 .44609 Mdot
.878 .44615 Mdot
.878 .4471 Mdot
.878 .44761 Mdot
.878 .44794 Mdot
.878 .44844 Mdot
.878 .44848 Mdot
.878 .44898 Mdot
.878 .44939 Mdot
.878 .44962 Mdot
.878 .44987 Mdot
.878 .44987 Mdot
.878 .4499 Mdot
.878 .45029 Mdot
.878 .45087 Mdot
.878 .45099 Mdot
.878 .45119 Mdot
.878 .4514 Mdot
.878 .45159 Mdot
.878 .45212 Mdot
.878 .45243 Mdot
.878 .45263 Mdot
.878 .45285 Mdot
.878 .45308 Mdot
.878 .45308 Mdot
.878 .45351 Mdot
.878 .4536 Mdot
.878 .45387 Mdot
.878 .45395 Mdot
.878 .45435 Mdot
.878 .45477 Mdot
.878 .45492 Mdot
.878 .45498 Mdot
.878 .45589 Mdot
.878 .45639 Mdot
.878 .4569 Mdot
.878 .45719 Mdot
.878 .45732 Mdot
.878 .45743 Mdot
.878 .4576 Mdot
.878 .45844 Mdot
.878 .45854 Mdot
.878 .45951 Mdot
.878 .46074 Mdot
.878 .46197 Mdot
.878 .4621 Mdot
.878 .46235 Mdot
.878 .46266 Mdot
.878 .46355 Mdot
.878 .46356 Mdot
.878 .46364 Mdot
.878 .46401 Mdot
.878 .46402 Mdot
.878 .46418 Mdot
.878 .46478 Mdot
.878 .46534 Mdot
.878 .46566 Mdot
.878 .46578 Mdot
.878 .46671 Mdot
.878 .46709 Mdot
.878 .46716 Mdot
.878 .46815 Mdot
.878 .46824 Mdot
.878 .46874 Mdot
.878 .46911 Mdot
.878 .46949 Mdot
.878 .46962 Mdot
.878 .46995 Mdot
.878 .47019 Mdot
.878 .47039 Mdot
.878 .47052 Mdot
.878 .47139 Mdot
.878 .47159 Mdot
.878 .47187 Mdot
.878 .47191 Mdot
.878 .47197 Mdot
.878 .47228 Mdot
.878 .47243 Mdot
.878 .47319 Mdot
.878 .47347 Mdot
.878 .4735 Mdot
.878 .47379 Mdot
.878 .47426 Mdot
.878 .4751 Mdot
.878 .47601 Mdot
.878 .4763 Mdot
.878 .4765 Mdot
.878 .47696 Mdot
.878 .47755 Mdot
.878 .47758 Mdot
.878 .47762 Mdot
.878 .47778 Mdot
.878 .47826 Mdot
.878 .47861 Mdot
.878 .47882 Mdot
.878 .47911 Mdot
.878 .47948 Mdot
.878 .47973 Mdot
.878 .47995 Mdot
.878 .48058 Mdot
.878 .48085 Mdot
.878 .48098 Mdot
.878 .48168 Mdot
.878 .48216 Mdot
.878 .48216 Mdot
.878 .48238 Mdot
.878 .48287 Mdot
.878 .48319 Mdot
.878 .48356 Mdot
.878 .48357 Mdot
.878 .48419 Mdot
.878 .48479 Mdot
.878 .48515 Mdot
.878 .48677 Mdot
.878 .48706 Mdot
.878 .48715 Mdot
.878 .48717 Mdot
.878 .48736 Mdot
.878 .48764 Mdot
.878 .48799 Mdot
.878 .48819 Mdot
.878 .48862 Mdot
.878 .48897 Mdot
.878 .48899 Mdot
.878 .48899 Mdot
.878 .48953 Mdot
.878 .48977 Mdot
.878 .49018 Mdot
.878 .49034 Mdot
.878 .49055 Mdot
.878 .4907 Mdot
.878 .49077 Mdot
.878 .49197 Mdot
.878 .49206 Mdot
.878 .49206 Mdot
.878 .49215 Mdot
.878 .49284 Mdot
.878 .4933 Mdot
.878 .49355 Mdot
.878 .49392 Mdot
.878 .49396 Mdot
.878 .494 Mdot
.878 .49427 Mdot
.878 .49431 Mdot
.878 .49431 Mdot
.878 .49439 Mdot
.878 .49446 Mdot
.878 .49447 Mdot
.878 .49483 Mdot
.878 .49608 Mdot
.878 .49636 Mdot
.878 .49647 Mdot
.878 .49666 Mdot
.878 .4969 Mdot
.878 .49742 Mdot
.878 .49778 Mdot
.878 .49788 Mdot
.878 .49802 Mdot
.878 .49813 Mdot
.878 .49883 Mdot
.878 .49884 Mdot
.878 .49902 Mdot
.878 .49972 Mdot
.878 .50061 Mdot
.878 .50069 Mdot
.878 .50123 Mdot
.878 .50126 Mdot
.878 .50192 Mdot
.878 .5025 Mdot
.878 .5031 Mdot
.878 .50321 Mdot
.878 .50344 Mdot
.878 .50355 Mdot
.878 .50373 Mdot
.878 .50386 Mdot
.878 .50407 Mdot
.878 .50447 Mdot
.878 .5045 Mdot
.878 .50458 Mdot
.878 .50477 Mdot
.878 .5048 Mdot
.878 .50594 Mdot
.878 .50652 Mdot
.878 .50673 Mdot
.878 .50709 Mdot
.878 .50722 Mdot
.878 .50748 Mdot
.878 .50766 Mdot
.878 .5081 Mdot
.878 .50825 Mdot
.878 .50828 Mdot
.878 .50836 Mdot
.878 .5087 Mdot
.878 .50902 Mdot
.878 .50961 Mdot
.878 .50973 Mdot
.878 .50987 Mdot
.878 .5099 Mdot
.878 .51011 Mdot
.878 .51019 Mdot
.878 .51025 Mdot
.878 .51079 Mdot
.878 .51175 Mdot
.878 .51207 Mdot
.878 .51252 Mdot
.878 .51256 Mdot
.878 .51262 Mdot
.878 .51288 Mdot
.878 .51319 Mdot
.878 .51322 Mdot
.878 .51353 Mdot
.878 .51364 Mdot
.878 .51372 Mdot
.878 .51417 Mdot
.878 .51434 Mdot
.878 .51483 Mdot
.878 .51567 Mdot
.878 .51578 Mdot
.878 .51608 Mdot
.878 .51617 Mdot
.878 .51687 Mdot
.878 .51694 Mdot
.878 .51699 Mdot
.878 .51786 Mdot
.878 .51816 Mdot
.878 .5192 Mdot
.878 .51965 Mdot
.878 .51981 Mdot
.878 .52034 Mdot
.878 .5205 Mdot
.878 .52056 Mdot
.878 .52066 Mdot
.878 .52094 Mdot
.878 .5212 Mdot
.878 .5217 Mdot
.878 .52205 Mdot
.878 .5223 Mdot
.878 .52253 Mdot
.878 .52292 Mdot
.878 .52296 Mdot
.878 .52301 Mdot
.878 .52311 Mdot
.878 .52384 Mdot
.878 .52399 Mdot
.878 .52413 Mdot
.878 .52431 Mdot
.878 .5244 Mdot
.878 .52536 Mdot
.878 .5254 Mdot
.878 .52564 Mdot
.878 .52602 Mdot
.878 .52604 Mdot
.878 .52631 Mdot
.878 .52635 Mdot
.878 .52676 Mdot
.878 .52776 Mdot
.878 .52789 Mdot
.878 .52806 Mdot
.878 .52851 Mdot
.878 .52859 Mdot
.878 .52872 Mdot
.878 .52882 Mdot
.878 .52884 Mdot
.878 .52917 Mdot
.878 .52947 Mdot
.878 .52969 Mdot
.878 .53098 Mdot
.878 .53119 Mdot
.878 .53195 Mdot
.878 .53253 Mdot
.878 .53266 Mdot
.88 .13945 Mdot
.88 .13946 Mdot
.88 .13987 Mdot
.88 .14034 Mdot
.88 .1404 Mdot
.88 .14142 Mdot
.88 .14161 Mdot
.88 .14387 Mdot
.88 .14412 Mdot
.88 .14455 Mdot
.88 .14511 Mdot
.88 .1461 Mdot
.88 .14684 Mdot
.88 .14748 Mdot
.88 .14752 Mdot
.88 .14793 Mdot
.88 .14861 Mdot
.88 .15028 Mdot
.88 .15076 Mdot
.88 .15155 Mdot
.88 .15252 Mdot
.88 .15457 Mdot
.88 .1547 Mdot
.88 .15512 Mdot
.88 .15512 Mdot
.88 .15575 Mdot
.88 .1579 Mdot
.88 .15844 Mdot
.88 .15996 Mdot
.88 .16044 Mdot
.88 .16145 Mdot
.88 .16187 Mdot
.88 .16233 Mdot
.88 .16269 Mdot
.88 .16303 Mdot
.88 .16312 Mdot
.88 .16382 Mdot
.88 .16498 Mdot
.88 .16517 Mdot
.88 .1653 Mdot
.88 .16694 Mdot
.88 .1681 Mdot
.88 .16905 Mdot
.88 .16927 Mdot
.88 .17 Mdot
.88 .17007 Mdot
.88 .17144 Mdot
.88 .17181 Mdot
.88 .17221 Mdot
.88 .17239 Mdot
.88 .1726 Mdot
.88 .17312 Mdot
.88 .17496 Mdot
.88 .17668 Mdot
.88 .17686 Mdot
.88 .17761 Mdot
.88 .17795 Mdot
.88 .17818 Mdot
.88 .17826 Mdot
.88 .17942 Mdot
.88 .18061 Mdot
.88 .18081 Mdot
.88 .1837 Mdot
.88 .1839 Mdot
.88 .18442 Mdot
.88 .18514 Mdot
.88 .18886 Mdot
.88 .18934 Mdot
.88 .18945 Mdot
.88 .1905 Mdot
.88 .19227 Mdot
.88 .19228 Mdot
.88 .19341 Mdot
.88 .1936 Mdot
.88 .19365 Mdot
.88 .19393 Mdot
.88 .1941 Mdot
.88 .19442 Mdot
.88 .19489 Mdot
.88 .19658 Mdot
.88 .1972 Mdot
.88 .19752 Mdot
.88 .1977 Mdot
.88 .19849 Mdot
.88 .19861 Mdot
.88 .19862 Mdot
.88 .19925 Mdot
.88 .19981 Mdot
.88 .19992 Mdot
.88 .20076 Mdot
.88 .20081 Mdot
.88 .20087 Mdot
.88 .2011 Mdot
.88 .20199 Mdot
.88 .20261 Mdot
.88 .20262 Mdot
.88 .20274 Mdot
.88 .20357 Mdot
.88 .20361 Mdot
.88 .20531 Mdot
.88 .20611 Mdot
.88 .20613 Mdot
.88 .20648 Mdot
.88 .20684 Mdot
.88 .20779 Mdot
.88 .20779 Mdot
.88 .20784 Mdot
.88 .20981 Mdot
.88 .21064 Mdot
.88 .21094 Mdot
.88 .2116 Mdot
.88 .21165 Mdot
.88 .21193 Mdot
.88 .21292 Mdot
.88 .2168 Mdot
.88 .21681 Mdot
.88 .21708 Mdot
.88 .21757 Mdot
.88 .21835 Mdot
.88 .21867 Mdot
.88 .21903 Mdot
.88 .21963 Mdot
.88 .22004 Mdot
.88 .22043 Mdot
.88 .22218 Mdot
.88 .22316 Mdot
.88 .22317 Mdot
.88 .22326 Mdot
.88 .22355 Mdot
.88 .2237 Mdot
.88 .22542 Mdot
.88 .22561 Mdot
.88 .2259 Mdot
.88 .22672 Mdot
.88 .22748 Mdot
.88 .22774 Mdot
.88 .22797 Mdot
.88 .22812 Mdot
.88 .22819 Mdot
.88 .22837 Mdot
.88 .23019 Mdot
.88 .23042 Mdot
.88 .23119 Mdot
.88 .23154 Mdot
.88 .23157 Mdot
.88 .23163 Mdot
.88 .23212 Mdot
.88 .23243 Mdot
.88 .23254 Mdot
.88 .23269 Mdot
.88 .23283 Mdot
.88 .23384 Mdot
.88 .23394 Mdot
.88 .23425 Mdot
.88 .23427 Mdot
.88 .23469 Mdot
.88 .23481 Mdot
.88 .23499 Mdot
.88 .23525 Mdot
.88 .23582 Mdot
.88 .23593 Mdot
.88 .23597 Mdot
.88 .23615 Mdot
.88 .23686 Mdot
.88 .2369 Mdot
.88 .23735 Mdot
.88 .23763 Mdot
.88 .23771 Mdot
.88 .23804 Mdot
.88 .23984 Mdot
.88 .23985 Mdot
.88 .24012 Mdot
.88 .24019 Mdot
.88 .24045 Mdot
.88 .24113 Mdot
.88 .24168 Mdot
.88 .24171 Mdot
.88 .24188 Mdot
.88 .24189 Mdot
.88 .24203 Mdot
.88 .24206 Mdot
.88 .24246 Mdot
.88 .24322 Mdot
.88 .24368 Mdot
.88 .24398 Mdot
.88 .24421 Mdot
.88 .24445 Mdot
.88 .24498 Mdot
.88 .24594 Mdot
.88 .24632 Mdot
.88 .24654 Mdot
.88 .24726 Mdot
.88 .24828 Mdot
.88 .24838 Mdot
.88 .24845 Mdot
.88 .24863 Mdot
.88 .24917 Mdot
.88 .24936 Mdot
.88 .24992 Mdot
.88 .24999 Mdot
.88 .25037 Mdot
.88 .25067 Mdot
.88 .2508 Mdot
.88 .25222 Mdot
.88 .25276 Mdot
.88 .25304 Mdot
.88 .2531 Mdot
.88 .25332 Mdot
.88 .25415 Mdot
.88 .25463 Mdot
.88 .25471 Mdot
.88 .25517 Mdot
.88 .25519 Mdot
.88 .2554 Mdot
.88 .25554 Mdot
.88 .2564 Mdot
.88 .25669 Mdot
.88 .25725 Mdot
.88 .25861 Mdot
.88 .259 Mdot
.88 .26048 Mdot
.88 .26078 Mdot
.88 .26086 Mdot
.88 .2611 Mdot
.88 .26122 Mdot
.88 .26139 Mdot
.88 .26183 Mdot
.88 .26183 Mdot
.88 .26204 Mdot
.88 .26216 Mdot
.88 .26226 Mdot
.88 .26293 Mdot
.88 .26347 Mdot
.88 .2638 Mdot
.88 .26391 Mdot
.88 .26393 Mdot
.88 .26416 Mdot
.88 .26464 Mdot
.88 .26491 Mdot
.88 .26538 Mdot
.88 .26538 Mdot
.88 .26672 Mdot
.88 .26767 Mdot
.88 .269 Mdot
.88 .26915 Mdot
.88 .26947 Mdot
.88 .26951 Mdot
.88 .27008 Mdot
.88 .27034 Mdot
.88 .27106 Mdot
.88 .27119 Mdot
.88 .27244 Mdot
.88 .27247 Mdot
.88 .27296 Mdot
.88 .27298 Mdot
.88 .27307 Mdot
.88 .27371 Mdot
.88 .27452 Mdot
.88 .27515 Mdot
.88 .27576 Mdot
.88 .27591 Mdot
.88 .276 Mdot
.88 .27658 Mdot
.88 .27659 Mdot
.88 .27713 Mdot
.88 .27805 Mdot
.88 .27819 Mdot
.88 .27821 Mdot
.88 .27844 Mdot
.88 .27849 Mdot
.88 .27887 Mdot
.88 .27915 Mdot
.88 .27918 Mdot
.88 .27951 Mdot
.88 .27974 Mdot
.88 .28036 Mdot
.88 .28108 Mdot
.88 .28115 Mdot
.88 .28148 Mdot
.88 .28174 Mdot
.88 .28184 Mdot
.88 .28245 Mdot
.88 .2825 Mdot
.88 .28263 Mdot
.88 .28418 Mdot
.88 .28468 Mdot
.88 .28468 Mdot
.88 .28625 Mdot
.88 .28635 Mdot
.88 .28657 Mdot
.88 .28694 Mdot
.88 .28759 Mdot
.88 .28759 Mdot
.88 .28801 Mdot
.88 .28813 Mdot
.88 .28894 Mdot
.88 .28922 Mdot
.88 .28946 Mdot
.88 .28986 Mdot
.88 .29056 Mdot
.88 .29059 Mdot
.88 .29085 Mdot
.88 .29121 Mdot
.88 .29176 Mdot
.88 .29191 Mdot
.88 .29223 Mdot
.88 .2926 Mdot
.88 .29351 Mdot
.88 .2937 Mdot
.88 .29537 Mdot
.88 .29636 Mdot
.88 .29675 Mdot
.88 .29712 Mdot
.88 .29757 Mdot
.88 .29878 Mdot
.88 .29895 Mdot
.88 .29908 Mdot
.88 .2992 Mdot
.88 .29932 Mdot
.88 .29977 Mdot
.88 .29979 Mdot
.88 .3001 Mdot
.88 .30078 Mdot
.88 .30131 Mdot
.88 .30135 Mdot
.88 .30141 Mdot
.88 .30179 Mdot
.88 .30201 Mdot
.88 .30227 Mdot
.88 .30242 Mdot
.88 .30255 Mdot
.88 .30288 Mdot
.88 .30303 Mdot
.88 .30352 Mdot
.88 .30439 Mdot
.88 .30459 Mdot
.88 .30575 Mdot
.88 .30616 Mdot
.88 .3067 Mdot
.88 .30705 Mdot
.88 .30706 Mdot
.88 .30751 Mdot
.88 .30782 Mdot
.88 .30815 Mdot
.88 .30822 Mdot
.88 .30965 Mdot
.88 .30974 Mdot
.88 .30988 Mdot
.88 .31003 Mdot
.88 .31005 Mdot
.88 .31037 Mdot
.88 .31044 Mdot
.88 .31139 Mdot
.88 .31213 Mdot
.88 .31248 Mdot
.88 .31339 Mdot
.88 .31396 Mdot
.88 .31462 Mdot
.88 .31466 Mdot
.88 .3148 Mdot
.88 .3157 Mdot
.88 .31724 Mdot
.88 .31735 Mdot
.88 .31899 Mdot
.88 .31937 Mdot
.88 .32038 Mdot
.88 .3212 Mdot
.88 .32176 Mdot
.88 .32206 Mdot
.88 .32217 Mdot
.88 .32224 Mdot
.88 .32309 Mdot
.88 .32409 Mdot
.88 .32426 Mdot
.88 .32449 Mdot
.88 .32585 Mdot
.88 .32622 Mdot
.88 .32679 Mdot
.88 .32722 Mdot
.88 .32724 Mdot
.88 .32733 Mdot
.88 .32738 Mdot
.88 .32838 Mdot
.88 .32849 Mdot
.88 .32884 Mdot
.88 .32905 Mdot
.88 .32923 Mdot
.88 .32926 Mdot
.88 .32955 Mdot
.88 .32957 Mdot
.88 .32964 Mdot
.88 .33013 Mdot
.88 .33013 Mdot
.88 .33044 Mdot
.88 .331 Mdot
.88 .33127 Mdot
.88 .33149 Mdot
.88 .33182 Mdot
.88 .33272 Mdot
.88 .33303 Mdot
.88 .33346 Mdot
.88 .3348 Mdot
.88 .33496 Mdot
.88 .33531 Mdot
.88 .33543 Mdot
.88 .33563 Mdot
.88 .33576 Mdot
.88 .33588 Mdot
.88 .33645 Mdot
.88 .33677 Mdot
.88 .3368 Mdot
.88 .33749 Mdot
.88 .33816 Mdot
.88 .33836 Mdot
.88 .33839 Mdot
.88 .33845 Mdot
.88 .33911 Mdot
.88 .33936 Mdot
.88 .33947 Mdot
.88 .33948 Mdot
.88 .3395 Mdot
.88 .33976 Mdot
.88 .33979 Mdot
.88 .33984 Mdot
.88 .34049 Mdot
.88 .34067 Mdot
.88 .34144 Mdot
.88 .34215 Mdot
.88 .34215 Mdot
.88 .34224 Mdot
.88 .34234 Mdot
.88 .34256 Mdot
.88 .34274 Mdot
.88 .34275 Mdot
.88 .34287 Mdot
.88 .34381 Mdot
.88 .34431 Mdot
.88 .34499 Mdot
.88 .34522 Mdot
.88 .3454 Mdot
.88 .34543 Mdot
.88 .34564 Mdot
.88 .34615 Mdot
.88 .3471 Mdot
.88 .34711 Mdot
.88 .34717 Mdot
.88 .3475 Mdot
.88 .34759 Mdot
.88 .34881 Mdot
.88 .34891 Mdot
.88 .34911 Mdot
.88 .34935 Mdot
.88 .34939 Mdot
.88 .34992 Mdot
.88 .35 Mdot
.88 .35016 Mdot
.88 .35039 Mdot
.88 .35156 Mdot
.88 .35161 Mdot
.88 .35171 Mdot
.88 .35191 Mdot
.88 .35223 Mdot
.88 .35268 Mdot
.88 .35285 Mdot
.88 .35288 Mdot
.88 .35382 Mdot
.88 .35453 Mdot
.88 .35453 Mdot
.88 .35461 Mdot
.88 .35463 Mdot
.88 .35484 Mdot
.88 .35568 Mdot
.88 .35571 Mdot
.88 .35591 Mdot
.88 .35662 Mdot
.88 .35809 Mdot
.88 .35954 Mdot
.88 .36008 Mdot
.88 .36064 Mdot
.88 .36118 Mdot
.88 .36123 Mdot
.88 .36127 Mdot
.88 .36131 Mdot
.88 .36135 Mdot
.88 .3615 Mdot
.88 .36182 Mdot
.88 .36199 Mdot
.88 .36201 Mdot
.88 .3623 Mdot
.88 .3625 Mdot
.88 .36255 Mdot
.88 .36343 Mdot
.88 .36356 Mdot
.88 .3641 Mdot
.88 .36472 Mdot
.88 .36481 Mdot
.88 .36481 Mdot
.88 .36492 Mdot
.88 .36494 Mdot
.88 .36714 Mdot
.88 .3677 Mdot
.88 .36782 Mdot
.88 .36815 Mdot
.88 .36991 Mdot
.88 .37039 Mdot
.88 .37041 Mdot
.88 .37073 Mdot
.88 .37088 Mdot
.88 .3713 Mdot
.88 .37166 Mdot
.88 .37174 Mdot
.88 .37223 Mdot
.88 .37237 Mdot
.88 .37297 Mdot
.88 .37301 Mdot
.88 .37311 Mdot
.88 .37367 Mdot
.88 .37398 Mdot
.88 .3742 Mdot
.88 .37428 Mdot
.88 .37431 Mdot
.88 .37432 Mdot
.88 .37441 Mdot
.88 .37443 Mdot
.88 .37531 Mdot
.88 .37537 Mdot
.88 .37609 Mdot
.88 .37647 Mdot
.88 .37678 Mdot
.88 .3769 Mdot
.88 .37742 Mdot
.88 .37784 Mdot
.88 .37833 Mdot
.88 .37858 Mdot
.88 .37864 Mdot
.88 .37962 Mdot
.88 .37985 Mdot
.88 .38115 Mdot
.88 .38132 Mdot
.88 .38138 Mdot
.88 .38143 Mdot
.88 .38158 Mdot
.88 .38159 Mdot
.88 .38175 Mdot
.88 .38226 Mdot
.88 .38246 Mdot
.88 .38249 Mdot
.88 .38253 Mdot
.88 .38489 Mdot
.88 .38493 Mdot
.88 .38552 Mdot
.88 .38556 Mdot
.88 .38559 Mdot
.88 .3856 Mdot
.88 .38588 Mdot
.88 .38626 Mdot
.88 .3864 Mdot
.88 .38694 Mdot
.88 .38784 Mdot
.88 .38819 Mdot
.88 .38899 Mdot
.88 .38918 Mdot
.88 .3892 Mdot
.88 .38942 Mdot
.88 .38964 Mdot
.88 .39004 Mdot
.88 .3903 Mdot
.88 .39037 Mdot
.88 .39044 Mdot
.88 .39074 Mdot
.88 .39124 Mdot
.88 .39178 Mdot
.88 .3919 Mdot
.88 .39202 Mdot
.88 .39248 Mdot
.88 .39319 Mdot
.88 .39357 Mdot
.88 .39395 Mdot
.88 .39395 Mdot
.88 .39399 Mdot
.88 .39433 Mdot
.88 .39435 Mdot
.88 .39571 Mdot
.88 .39573 Mdot
.88 .39632 Mdot
.88 .39635 Mdot
.88 .39638 Mdot
.88 .39648 Mdot
.88 .39735 Mdot
.88 .3979 Mdot
.88 .39794 Mdot
.88 .39808 Mdot
.88 .39836 Mdot
.88 .39859 Mdot
.88 .39889 Mdot
.88 .39914 Mdot
.88 .39979 Mdot
.88 .40029 Mdot
.88 .40031 Mdot
.88 .40036 Mdot
.88 .40038 Mdot
.88 .40043 Mdot
.88 .40055 Mdot
.88 .4011 Mdot
.88 .40112 Mdot
.88 .40146 Mdot
.88 .40154 Mdot
.88 .40187 Mdot
.88 .40207 Mdot
.88 .40239 Mdot
.88 .40286 Mdot
.88 .40386 Mdot
.88 .40405 Mdot
.88 .40412 Mdot
.88 .40444 Mdot
.88 .40569 Mdot
.88 .4057 Mdot
.88 .40576 Mdot
.88 .40576 Mdot
.88 .40581 Mdot
.88 .40617 Mdot
.88 .40655 Mdot
.88 .40704 Mdot
.88 .40707 Mdot
.88 .40719 Mdot
.88 .40735 Mdot
.88 .40736 Mdot
.88 .40764 Mdot
.88 .40772 Mdot
.88 .40777 Mdot
.88 .40782 Mdot
.88 .40813 Mdot
.88 .41041 Mdot
.88 .41082 Mdot
.88 .41093 Mdot
.88 .41095 Mdot
.88 .41143 Mdot
.88 .41155 Mdot
.88 .412 Mdot
.88 .41254 Mdot
.88 .41265 Mdot
.88 .41309 Mdot
.88 .4132 Mdot
.88 .41395 Mdot
.88 .41417 Mdot
.88 .41422 Mdot
.88 .41452 Mdot
.88 .41454 Mdot
.88 .41468 Mdot
.88 .4148 Mdot
.88 .41485 Mdot
.88 .41555 Mdot
.88 .4156 Mdot
.88 .41582 Mdot
.88 .41636 Mdot
.88 .41689 Mdot
.88 .41702 Mdot
.88 .41769 Mdot
.88 .41823 Mdot
.88 .4183 Mdot
.88 .4184 Mdot
.88 .41863 Mdot
.88 .41904 Mdot
.88 .41995 Mdot
.88 .41998 Mdot
.88 .41999 Mdot
.88 .42015 Mdot
.88 .42016 Mdot
.88 .42022 Mdot
.88 .42036 Mdot
.88 .42074 Mdot
.88 .42128 Mdot
.88 .42168 Mdot
.88 .42227 Mdot
.88 .42234 Mdot
.88 .42245 Mdot
.88 .42252 Mdot
.88 .42272 Mdot
.88 .42357 Mdot
.88 .42382 Mdot
.88 .42399 Mdot
.88 .42469 Mdot
.88 .42482 Mdot
.88 .42547 Mdot
.88 .42578 Mdot
.88 .42596 Mdot
.88 .42608 Mdot
.88 .4262 Mdot
.88 .4264 Mdot
.88 .42646 Mdot
.88 .42703 Mdot
.88 .42706 Mdot
.88 .42736 Mdot
.88 .42769 Mdot
.88 .4279 Mdot
.88 .42867 Mdot
.88 .4288 Mdot
.88 .42946 Mdot
.88 .42999 Mdot
.88 .43022 Mdot
.88 .43101 Mdot
.88 .43158 Mdot
.88 .43179 Mdot
.88 .43272 Mdot
.88 .43279 Mdot
.88 .43367 Mdot
.88 .43418 Mdot
.88 .43428 Mdot
.88 .43465 Mdot
.88 .43611 Mdot
.88 .43665 Mdot
.88 .43669 Mdot
.88 .43688 Mdot
.88 .43689 Mdot
.88 .43697 Mdot
.88 .43705 Mdot
.88 .4371 Mdot
.88 .43791 Mdot
.88 .43796 Mdot
.88 .43814 Mdot
.88 .43832 Mdot
.88 .43857 Mdot
.88 .43909 Mdot
.88 .43932 Mdot
.88 .44009 Mdot
.88 .44058 Mdot
.88 .44086 Mdot
.88 .44095 Mdot
.88 .4413 Mdot
.88 .44157 Mdot
.88 .44182 Mdot
.88 .44184 Mdot
.88 .44214 Mdot
.88 .4427 Mdot
.88 .44297 Mdot
.88 .44304 Mdot
.88 .44311 Mdot
.88 .44318 Mdot
.88 .44328 Mdot
.88 .44396 Mdot
.88 .44422 Mdot
.88 .44465 Mdot
.88 .44522 Mdot
.88 .44616 Mdot
.88 .44727 Mdot
.88 .44778 Mdot
.88 .44793 Mdot
.88 .44834 Mdot
.88 .44857 Mdot
.88 .44871 Mdot
.88 .44887 Mdot
.88 .44964 Mdot
.88 .44964 Mdot
.88 .45001 Mdot
.88 .45021 Mdot
.88 .4504 Mdot
.88 .45129 Mdot
.88 .45157 Mdot
.88 .45253 Mdot
.88 .45255 Mdot
.88 .4529 Mdot
.88 .45296 Mdot
.88 .45311 Mdot
.88 .45329 Mdot
.88 .45334 Mdot
.88 .45374 Mdot
.88 .45443 Mdot
.88 .45459 Mdot
.88 .4548 Mdot
.88 .45484 Mdot
.88 .45497 Mdot
.88 .45497 Mdot
.88 .45506 Mdot
.88 .45589 Mdot
.88 .45589 Mdot
.88 .45622 Mdot
.88 .45788 Mdot
.88 .45794 Mdot
.88 .45823 Mdot
.88 .45824 Mdot
.88 .45903 Mdot
.88 .45959 Mdot
.88 .45991 Mdot
.88 .45993 Mdot
.88 .46011 Mdot
.88 .4602 Mdot
.88 .46225 Mdot
.88 .46225 Mdot
.88 .46252 Mdot
.88 .46267 Mdot
.88 .46295 Mdot
.88 .46308 Mdot
.88 .46309 Mdot
.88 .46315 Mdot
.88 .46334 Mdot
.88 .46403 Mdot
.88 .46409 Mdot
.88 .46415 Mdot
.88 .46452 Mdot
.88 .46462 Mdot
.88 .46487 Mdot
.88 .46504 Mdot
.88 .46588 Mdot
.88 .4661 Mdot
.88 .46719 Mdot
.88 .46735 Mdot
.88 .46793 Mdot
.88 .46804 Mdot
.88 .46806 Mdot
.88 .46832 Mdot
.88 .46836 Mdot
.88 .46923 Mdot
.88 .46926 Mdot
.88 .46943 Mdot
.88 .46973 Mdot
.88 .47054 Mdot
.88 .47062 Mdot
.88 .471 Mdot
.88 .47104 Mdot
.88 .47136 Mdot
.88 .47177 Mdot
.88 .47197 Mdot
.88 .47296 Mdot
.88 .47308 Mdot
.88 .47385 Mdot
.88 .47415 Mdot
.88 .47441 Mdot
.88 .47458 Mdot
.88 .4755 Mdot
.88 .4756 Mdot
.88 .47561 Mdot
.88 .47571 Mdot
.88 .47572 Mdot
.88 .47603 Mdot
.88 .47642 Mdot
.88 .47657 Mdot
.88 .47661 Mdot
.88 .47676 Mdot
.88 .47677 Mdot
.88 .47802 Mdot
.88 .47818 Mdot
.88 .47844 Mdot
.88 .47846 Mdot
.88 .47886 Mdot
.88 .47897 Mdot
.88 .47937 Mdot
.88 .47963 Mdot
.88 .47969 Mdot
.88 .48012 Mdot
.88 .48017 Mdot
.88 .48075 Mdot
.88 .48083 Mdot
.88 .48092 Mdot
.88 .48097 Mdot
.88 .48115 Mdot
.88 .48143 Mdot
.88 .48146 Mdot
.88 .48148 Mdot
.88 .48168 Mdot
.88 .48212 Mdot
.88 .48225 Mdot
.88 .48328 Mdot
.88 .48338 Mdot
.88 .48343 Mdot
.88 .48351 Mdot
.88 .48364 Mdot
.88 .48379 Mdot
.88 .48422 Mdot
.88 .48469 Mdot
.88 .48485 Mdot
.88 .48496 Mdot
.88 .48594 Mdot
.88 .48602 Mdot
.88 .48619 Mdot
.88 .48624 Mdot
.88 .48624 Mdot
.88 .4868 Mdot
.88 .48779 Mdot
.88 .48801 Mdot
.88 .48825 Mdot
.88 .48859 Mdot
.88 .48879 Mdot
.88 .48898 Mdot
.88 .48942 Mdot
.88 .4897 Mdot
.88 .48985 Mdot
.88 .48985 Mdot
.88 .49206 Mdot
.88 .49262 Mdot
.88 .49279 Mdot
.88 .49281 Mdot
.88 .49319 Mdot
.88 .49336 Mdot
.88 .49383 Mdot
.88 .49495 Mdot
.88 .49497 Mdot
.88 .49498 Mdot
.88 .49552 Mdot
.88 .49572 Mdot
.88 .49592 Mdot
.88 .49593 Mdot
.88 .49639 Mdot
.88 .49735 Mdot
.88 .49737 Mdot
.88 .49784 Mdot
.88 .49791 Mdot
.88 .49792 Mdot
.88 .49827 Mdot
.88 .49878 Mdot
.88 .49891 Mdot
.88 .49894 Mdot
.88 .49897 Mdot
.88 .49945 Mdot
.88 .49951 Mdot
.88 .49983 Mdot
.88 .50019 Mdot
.88 .50019 Mdot
.88 .50026 Mdot
.88 .50071 Mdot
.88 .50081 Mdot
.88 .50099 Mdot
.88 .50134 Mdot
.88 .50231 Mdot
.88 .50257 Mdot
.88 .50275 Mdot
.88 .50285 Mdot
.88 .50301 Mdot
.88 .50304 Mdot
.88 .50314 Mdot
.88 .50379 Mdot
.88 .50379 Mdot
.88 .5048 Mdot
.88 .5054 Mdot
.88 .50546 Mdot
.88 .50573 Mdot
.88 .50784 Mdot
.88 .50826 Mdot
.88 .50855 Mdot
.88 .50866 Mdot
.88 .5103 Mdot
.88 .51042 Mdot
.88 .5111 Mdot
.88 .51176 Mdot
.88 .5118 Mdot
.88 .51193 Mdot
.88 .51212 Mdot
.88 .51255 Mdot
.88 .51265 Mdot
.88 .51363 Mdot
.88 .51467 Mdot
.88 .51497 Mdot
.88 .51509 Mdot
.88 .51519 Mdot
.88 .51542 Mdot
.88 .51563 Mdot
.88 .51641 Mdot
.88 .51645 Mdot
.88 .51686 Mdot
.88 .51699 Mdot
.88 .51752 Mdot
.88 .51819 Mdot
.88 .51912 Mdot
.88 .51919 Mdot
.88 .5193 Mdot
.88 .51996 Mdot
.88 .52036 Mdot
.88 .52041 Mdot
.88 .5206 Mdot
.88 .5208 Mdot
.88 .52107 Mdot
.88 .52131 Mdot
.88 .52188 Mdot
.88 .52215 Mdot
.88 .52302 Mdot
.88 .52332 Mdot
.88 .52455 Mdot
.88 .5249 Mdot
.88 .5249 Mdot
.88 .52514 Mdot
.88 .52521 Mdot
.88 .52638 Mdot
.88 .52693 Mdot
.88 .52738 Mdot
.88 .52765 Mdot
.88 .5286 Mdot
.88 .52899 Mdot
.88 .52922 Mdot
.88 .52924 Mdot
.88 .52961 Mdot
.88 .53003 Mdot
.88 .53059 Mdot
.88 .53091 Mdot
.88 .53115 Mdot
.88 .53129 Mdot
.88 .53258 Mdot
.88 .53269 Mdot
.88 .53326 Mdot
.88 .5333 Mdot
.88 .53357 Mdot
.88 .5338 Mdot
.88 .5338 Mdot
.882 .13835 Mdot
.882 .13943 Mdot
.882 .14137 Mdot
.882 .14234 Mdot
.882 .14334 Mdot
.882 .14398 Mdot
.882 .1441 Mdot
.882 .14434 Mdot
.882 .14502 Mdot
.882 .14527 Mdot
.882 .14581 Mdot
.882 .14715 Mdot
.882 .14752 Mdot
.882 .14774 Mdot
.882 .14873 Mdot
.882 .14885 Mdot
.882 .14978 Mdot
.882 .15018 Mdot
.882 .15023 Mdot
.882 .15068 Mdot
.882 .15106 Mdot
.882 .15123 Mdot
.882 .15134 Mdot
.882 .15265 Mdot
.882 .15599 Mdot
.882 .15623 Mdot
.882 .15724 Mdot
.882 .15756 Mdot
.882 .15782 Mdot
.882 .15881 Mdot
.882 .15939 Mdot
.882 .16005 Mdot
.882 .16115 Mdot
.882 .16144 Mdot
.882 .16218 Mdot
.882 .16226 Mdot
.882 .16241 Mdot
.882 .16315 Mdot
.882 .16322 Mdot
.882 .16405 Mdot
.882 .16408 Mdot
.882 .16535 Mdot
.882 .16554 Mdot
.882 .16645 Mdot
.882 .16652 Mdot
.882 .16692 Mdot
.882 .16697 Mdot
.882 .16875 Mdot
.882 .16889 Mdot
.882 .1691 Mdot
.882 .16949 Mdot
.882 .16992 Mdot
.882 .17125 Mdot
.882 .17186 Mdot
.882 .17188 Mdot
.882 .17303 Mdot
.882 .17455 Mdot
.882 .17499 Mdot
.882 .17568 Mdot
.882 .17806 Mdot
.882 .17853 Mdot
.882 .17857 Mdot
.882 .17962 Mdot
.882 .1797 Mdot
.882 .18018 Mdot
.882 .18106 Mdot
.882 .18209 Mdot
.882 .18335 Mdot
.882 .18376 Mdot
.882 .18444 Mdot
.882 .18553 Mdot
.882 .18564 Mdot
.882 .18592 Mdot
.882 .18643 Mdot
.882 .18678 Mdot
.882 .18721 Mdot
.882 .18961 Mdot
.882 .19069 Mdot
.882 .1907 Mdot
.882 .19237 Mdot
.882 .19272 Mdot
.882 .19275 Mdot
.882 .19282 Mdot
.882 .19335 Mdot
.882 .19361 Mdot
.882 .19374 Mdot
.882 .19479 Mdot
.882 .19515 Mdot
.882 .19543 Mdot
.882 .19601 Mdot
.882 .19621 Mdot
.882 .19668 Mdot
.882 .19688 Mdot
.882 .19723 Mdot
.882 .19848 Mdot
.882 .19913 Mdot
.882 .20016 Mdot
.882 .20147 Mdot
.882 .20159 Mdot
.882 .20198 Mdot
.882 .20219 Mdot
.882 .2023 Mdot
.882 .20259 Mdot
.882 .20346 Mdot
.882 .20351 Mdot
.882 .20416 Mdot
.882 .20426 Mdot
.882 .20504 Mdot
.882 .20583 Mdot
.882 .20797 Mdot
.882 .20808 Mdot
.882 .20817 Mdot
.882 .20853 Mdot
.882 .20915 Mdot
.882 .20993 Mdot
.882 .21004 Mdot
.882 .21158 Mdot
.882 .21192 Mdot
.882 .21213 Mdot
.882 .21371 Mdot
.882 .21476 Mdot
.882 .21586 Mdot
.882 .21642 Mdot
.882 .21723 Mdot
.882 .21846 Mdot
.882 .21882 Mdot
.882 .21886 Mdot
.882 .21903 Mdot
.882 .21956 Mdot
.882 .21967 Mdot
.882 .21994 Mdot
.882 .22012 Mdot
.882 .22047 Mdot
.882 .22143 Mdot
.882 .22175 Mdot
.882 .22216 Mdot
.882 .22252 Mdot
.882 .22318 Mdot
.882 .22365 Mdot
.882 .22426 Mdot
.882 .22459 Mdot
.882 .22518 Mdot
.882 .22557 Mdot
.882 .22685 Mdot
.882 .22719 Mdot
.882 .22751 Mdot
.882 .22798 Mdot
.882 .22829 Mdot
.882 .22859 Mdot
.882 .22862 Mdot
.882 .23002 Mdot
.882 .23079 Mdot
.882 .23094 Mdot
.882 .23112 Mdot
.882 .23132 Mdot
.882 .23175 Mdot
.882 .23187 Mdot
.882 .23233 Mdot
.882 .23241 Mdot
.882 .2328 Mdot
.882 .23301 Mdot
.882 .23405 Mdot
.882 .23424 Mdot
.882 .23466 Mdot
.882 .23472 Mdot
.882 .23522 Mdot
.882 .23534 Mdot
.882 .23554 Mdot
.882 .23573 Mdot
.882 .23583 Mdot
.882 .23751 Mdot
.882 .23806 Mdot
.882 .23814 Mdot
.882 .23845 Mdot
.882 .23984 Mdot
.882 .24024 Mdot
.882 .24067 Mdot
.882 .2415 Mdot
.882 .24161 Mdot
.882 .24273 Mdot
.882 .24295 Mdot
.882 .24321 Mdot
.882 .24337 Mdot
.882 .24394 Mdot
.882 .24433 Mdot
.882 .24457 Mdot
.882 .24472 Mdot
.882 .24473 Mdot
.882 .24502 Mdot
.882 .2451 Mdot
.882 .24541 Mdot
.882 .24547 Mdot
.882 .24552 Mdot
.882 .24596 Mdot
.882 .24597 Mdot
.882 .24613 Mdot
.882 .24666 Mdot
.882 .24755 Mdot
.882 .24768 Mdot
.882 .24807 Mdot
.882 .24832 Mdot
.882 .2487 Mdot
.882 .24898 Mdot
.882 .24928 Mdot
.882 .24936 Mdot
.882 .25001 Mdot
.882 .25012 Mdot
.882 .25081 Mdot
.882 .25088 Mdot
.882 .25112 Mdot
.882 .25133 Mdot
.882 .25137 Mdot
.882 .25149 Mdot
.882 .25162 Mdot
.882 .25297 Mdot
.882 .25331 Mdot
.882 .25368 Mdot
.882 .25376 Mdot
.882 .25397 Mdot
.882 .25456 Mdot
.882 .25522 Mdot
.882 .25553 Mdot
.882 .25567 Mdot
.882 .25572 Mdot
.882 .25593 Mdot
.882 .25692 Mdot
.882 .25702 Mdot
.882 .25767 Mdot
.882 .25803 Mdot
.882 .2595 Mdot
.882 .25986 Mdot
.882 .26007 Mdot
.882 .26073 Mdot
.882 .26102 Mdot
.882 .26125 Mdot
.882 .26126 Mdot
.882 .26134 Mdot
.882 .26205 Mdot
.882 .26306 Mdot
.882 .26392 Mdot
.882 .26433 Mdot
.882 .26435 Mdot
.882 .26447 Mdot
.882 .26475 Mdot
.882 .26528 Mdot
.882 .26564 Mdot
.882 .26613 Mdot
.882 .2667 Mdot
.882 .26715 Mdot
.882 .26864 Mdot
.882 .2689 Mdot
.882 .2699 Mdot
.882 .26993 Mdot
.882 .26993 Mdot
.882 .2701 Mdot
.882 .27108 Mdot
.882 .27132 Mdot
.882 .27303 Mdot
.882 .27307 Mdot
.882 .27355 Mdot
.882 .27429 Mdot
.882 .27462 Mdot
.882 .27484 Mdot
.882 .27499 Mdot
.882 .27524 Mdot
.882 .27573 Mdot
.882 .27628 Mdot
.882 .27655 Mdot
.882 .27669 Mdot
.882 .27738 Mdot
.882 .2781 Mdot
.882 .27813 Mdot
.882 .27819 Mdot
.882 .27826 Mdot
.882 .27861 Mdot
.882 .27867 Mdot
.882 .27955 Mdot
.882 .27997 Mdot
.882 .28042 Mdot
.882 .28043 Mdot
.882 .28078 Mdot
.882 .28099 Mdot
.882 .28152 Mdot
.882 .28171 Mdot
.882 .28238 Mdot
.882 .28249 Mdot
.882 .28263 Mdot
.882 .28304 Mdot
.882 .28315 Mdot
.882 .28321 Mdot
.882 .2833 Mdot
.882 .2835 Mdot
.882 .28578 Mdot
.882 .28642 Mdot
.882 .28668 Mdot
.882 .28687 Mdot
.882 .28705 Mdot
.882 .28774 Mdot
.882 .288 Mdot
.882 .28825 Mdot
.882 .28828 Mdot
.882 .28849 Mdot
.882 .28878 Mdot
.882 .28898 Mdot
.882 .2899 Mdot
.882 .29083 Mdot
.882 .29118 Mdot
.882 .29163 Mdot
.882 .29175 Mdot
.882 .29193 Mdot
.882 .29195 Mdot
.882 .29196 Mdot
.882 .2926 Mdot
.882 .29373 Mdot
.882 .29398 Mdot
.882 .29462 Mdot
.882 .29497 Mdot
.882 .29537 Mdot
.882 .29598 Mdot
.882 .29667 Mdot
.882 .29743 Mdot
.882 .29828 Mdot
.882 .29866 Mdot
.882 .29928 Mdot
.882 .29942 Mdot
.882 .30023 Mdot
.882 .30069 Mdot
.882 .30143 Mdot
.882 .30174 Mdot
.882 .30201 Mdot
.882 .3021 Mdot
.882 .30285 Mdot
.882 .30325 Mdot
.882 .30368 Mdot
.882 .30376 Mdot
.882 .30483 Mdot
.882 .30547 Mdot
.882 .30561 Mdot
.882 .30563 Mdot
.882 .30576 Mdot
.882 .30605 Mdot
.882 .30609 Mdot
.882 .3066 Mdot
.882 .30703 Mdot
.882 .30762 Mdot
.882 .30815 Mdot
.882 .30908 Mdot
.882 .30996 Mdot
.882 .31094 Mdot
.882 .31157 Mdot
.882 .31181 Mdot
.882 .31189 Mdot
.882 .31211 Mdot
.882 .31219 Mdot
.882 .31291 Mdot
.882 .31298 Mdot
.882 .31405 Mdot
.882 .3141 Mdot
.882 .31414 Mdot
.882 .31604 Mdot
.882 .31622 Mdot
.882 .31673 Mdot
.882 .31694 Mdot
.882 .31762 Mdot
.882 .31769 Mdot
.882 .31793 Mdot
.882 .31822 Mdot
.882 .31823 Mdot
.882 .31864 Mdot
.882 .319 Mdot
.882 .31902 Mdot
.882 .31915 Mdot
.882 .31973 Mdot
.882 .31978 Mdot
.882 .32054 Mdot
.882 .32074 Mdot
.882 .3216 Mdot
.882 .32174 Mdot
.882 .32288 Mdot
.882 .32289 Mdot
.882 .32323 Mdot
.882 .32325 Mdot
.882 .32369 Mdot
.882 .32456 Mdot
.882 .32513 Mdot
.882 .32516 Mdot
.882 .32525 Mdot
.882 .32553 Mdot
.882 .32644 Mdot
.882 .32678 Mdot
.882 .32733 Mdot
.882 .32772 Mdot
.882 .3281 Mdot
.882 .32831 Mdot
.882 .32849 Mdot
.882 .32871 Mdot
.882 .32878 Mdot
.882 .32888 Mdot
.882 .32929 Mdot
.882 .32983 Mdot
.882 .33025 Mdot
.882 .33029 Mdot
.882 .33048 Mdot
.882 .33052 Mdot
.882 .33089 Mdot
.882 .33124 Mdot
.882 .33237 Mdot
.882 .3324 Mdot
.882 .333 Mdot
.882 .3335 Mdot
.882 .33368 Mdot
.882 .33418 Mdot
.882 .33452 Mdot
.882 .33487 Mdot
.882 .33505 Mdot
.882 .33531 Mdot
.882 .33571 Mdot
.882 .33583 Mdot
.882 .33584 Mdot
.882 .33606 Mdot
.882 .33666 Mdot
.882 .33722 Mdot
.882 .33738 Mdot
.882 .33757 Mdot
.882 .33799 Mdot
.882 .33852 Mdot
.882 .33877 Mdot
.882 .33887 Mdot
.882 .33967 Mdot
.882 .33972 Mdot
.882 .33978 Mdot
.882 .33998 Mdot
.882 .34002 Mdot
.882 .34017 Mdot
.882 .34019 Mdot
.882 .34038 Mdot
.882 .34091 Mdot
.882 .3411 Mdot
.882 .34183 Mdot
.882 .34213 Mdot
.882 .3439 Mdot
.882 .34402 Mdot
.882 .34415 Mdot
.882 .34427 Mdot
.882 .34437 Mdot
.882 .34439 Mdot
.882 .3446 Mdot
.882 .34506 Mdot
.882 .34522 Mdot
.882 .34543 Mdot
.882 .34561 Mdot
.882 .34588 Mdot
.882 .34611 Mdot
.882 .34613 Mdot
.882 .34628 Mdot
.882 .34691 Mdot
.882 .34712 Mdot
.882 .34767 Mdot
.882 .34775 Mdot
.882 .3481 Mdot
.882 .3489 Mdot
.882 .34901 Mdot
.882 .34908 Mdot
.882 .34939 Mdot
.882 .34972 Mdot
.882 .35004 Mdot
.882 .35045 Mdot
.882 .35058 Mdot
.882 .35087 Mdot
.882 .35183 Mdot
.882 .35225 Mdot
.882 .3523 Mdot
.882 .35365 Mdot
.882 .35429 Mdot
.882 .35488 Mdot
.882 .35534 Mdot
.882 .35562 Mdot
.882 .3558 Mdot
.882 .35598 Mdot
.882 .35604 Mdot
.882 .35646 Mdot
.882 .3565 Mdot
.882 .35661 Mdot
.882 .35769 Mdot
.882 .35831 Mdot
.882 .35908 Mdot
.882 .35922 Mdot
.882 .35926 Mdot
.882 .36018 Mdot
.882 .3603 Mdot
.882 .36043 Mdot
.882 .36062 Mdot
.882 .36168 Mdot
.882 .36199 Mdot
.882 .36213 Mdot
.882 .36256 Mdot
.882 .36259 Mdot
.882 .36296 Mdot
.882 .36387 Mdot
.882 .36436 Mdot
.882 .36573 Mdot
.882 .3658 Mdot
.882 .36646 Mdot
.882 .36736 Mdot
.882 .3676 Mdot
.882 .36768 Mdot
.882 .36825 Mdot
.882 .36885 Mdot
.882 .3689 Mdot
.882 .36926 Mdot
.882 .36953 Mdot
.882 .36981 Mdot
.882 .37052 Mdot
.882 .37082 Mdot
.882 .37101 Mdot
.882 .37163 Mdot
.882 .37195 Mdot
.882 .37233 Mdot
.882 .3729 Mdot
.882 .37318 Mdot
.882 .37412 Mdot
.882 .3747 Mdot
.882 .37476 Mdot
.882 .37483 Mdot
.882 .37489 Mdot
.882 .37512 Mdot
.882 .37606 Mdot
.882 .37614 Mdot
.882 .37625 Mdot
.882 .37673 Mdot
.882 .37679 Mdot
.882 .37699 Mdot
.882 .37706 Mdot
.882 .37737 Mdot
.882 .37766 Mdot
.882 .378 Mdot
.882 .37817 Mdot
.882 .37826 Mdot
.882 .37871 Mdot
.882 .37936 Mdot
.882 .3797 Mdot
.882 .37992 Mdot
.882 .38006 Mdot
.882 .38007 Mdot
.882 .38065 Mdot
.882 .38129 Mdot
.882 .3814 Mdot
.882 .38174 Mdot
.882 .38202 Mdot
.882 .38244 Mdot
.882 .3826 Mdot
.882 .38306 Mdot
.882 .38327 Mdot
.882 .38404 Mdot
.882 .38435 Mdot
.882 .38493 Mdot
.882 .38543 Mdot
.882 .38592 Mdot
.882 .38598 Mdot
.882 .38665 Mdot
.882 .38678 Mdot
.882 .38703 Mdot
.882 .38721 Mdot
.882 .38765 Mdot
.882 .38818 Mdot
.882 .38892 Mdot
.882 .38952 Mdot
.882 .3898 Mdot
.882 .38988 Mdot
.882 .38994 Mdot
.882 .39008 Mdot
.882 .39025 Mdot
.882 .39082 Mdot
.882 .39092 Mdot
.882 .39147 Mdot
.882 .39179 Mdot
.882 .39197 Mdot
.882 .392 Mdot
.882 .39204 Mdot
.882 .39296 Mdot
.882 .39327 Mdot
.882 .39351 Mdot
.882 .39361 Mdot
.882 .39376 Mdot
.882 .39425 Mdot
.882 .39452 Mdot
.882 .39531 Mdot
.882 .39587 Mdot
.882 .39613 Mdot
.882 .39646 Mdot
.882 .39662 Mdot
.882 .39681 Mdot
.882 .39756 Mdot
.882 .39757 Mdot
.882 .39777 Mdot
.882 .39833 Mdot
.882 .39859 Mdot
.882 .39864 Mdot
.882 .39874 Mdot
.882 .39909 Mdot
.882 .39931 Mdot
.882 .39942 Mdot
.882 .39979 Mdot
.882 .4005 Mdot
.882 .40061 Mdot
.882 .40147 Mdot
.882 .40163 Mdot
.882 .40195 Mdot
.882 .40234 Mdot
.882 .4027 Mdot
.882 .4028 Mdot
.882 .40338 Mdot
.882 .40369 Mdot
.882 .40389 Mdot
.882 .40392 Mdot
.882 .40426 Mdot
.882 .40459 Mdot
.882 .40477 Mdot
.882 .40528 Mdot
.882 .40565 Mdot
.882 .40647 Mdot
.882 .40674 Mdot
.882 .40749 Mdot
.882 .40773 Mdot
.882 .40798 Mdot
.882 .40858 Mdot
.882 .4087 Mdot
.882 .40877 Mdot
.882 .40883 Mdot
.882 .40938 Mdot
.882 .4099 Mdot
.882 .41092 Mdot
.882 .41094 Mdot
.882 .41118 Mdot
.882 .41158 Mdot
.882 .41184 Mdot
.882 .41217 Mdot
.882 .41254 Mdot
.882 .4133 Mdot
.882 .41333 Mdot
.882 .41411 Mdot
.882 .41428 Mdot
.882 .41458 Mdot
.882 .41477 Mdot
.882 .41495 Mdot
.882 .41517 Mdot
.882 .41568 Mdot
.882 .41624 Mdot
.882 .41636 Mdot
.882 .41671 Mdot
.882 .41681 Mdot
.882 .41694 Mdot
.882 .41731 Mdot
.882 .41767 Mdot
.882 .41779 Mdot
.882 .41785 Mdot
.882 .418 Mdot
.882 .41807 Mdot
.882 .41907 Mdot
.882 .41966 Mdot
.882 .41976 Mdot
.882 .42006 Mdot
.882 .42017 Mdot
.882 .42018 Mdot
.882 .42029 Mdot
.882 .4204 Mdot
.882 .42044 Mdot
.882 .42046 Mdot
.882 .42097 Mdot
.882 .42112 Mdot
.882 .42141 Mdot
.882 .42165 Mdot
.882 .42176 Mdot
.882 .42185 Mdot
.882 .42264 Mdot
.882 .42264 Mdot
.882 .42293 Mdot
.882 .42308 Mdot
.882 .42357 Mdot
.882 .42386 Mdot
.882 .42458 Mdot
.882 .42524 Mdot
.882 .42544 Mdot
.882 .42567 Mdot
.882 .4258 Mdot
.882 .42635 Mdot
.882 .4268 Mdot
.882 .4269 Mdot
.882 .42724 Mdot
.882 .42746 Mdot
.882 .42777 Mdot
.882 .42796 Mdot
.882 .42848 Mdot
.882 .42864 Mdot
.882 .42903 Mdot
.882 .42952 Mdot
.882 .42977 Mdot
.882 .42998 Mdot
.882 .42998 Mdot
.882 .43063 Mdot
.882 .43071 Mdot
.882 .43119 Mdot
.882 .43131 Mdot
.882 .43174 Mdot
.882 .43177 Mdot
.882 .4321 Mdot
.882 .43217 Mdot
.882 .43238 Mdot
.882 .43262 Mdot
.882 .43279 Mdot
.882 .43292 Mdot
.882 .43335 Mdot
.882 .43494 Mdot
.882 .43499 Mdot
.882 .43559 Mdot
.882 .43609 Mdot
.882 .43621 Mdot
.882 .43626 Mdot
.882 .43639 Mdot
.882 .43675 Mdot
.882 .4378 Mdot
.882 .43863 Mdot
.882 .43897 Mdot
.882 .4395 Mdot
.882 .43952 Mdot
.882 .43976 Mdot
.882 .43985 Mdot
.882 .44021 Mdot
.882 .44111 Mdot
.882 .44176 Mdot
.882 .44181 Mdot
.882 .44196 Mdot
.882 .44214 Mdot
.882 .44256 Mdot
.882 .44282 Mdot
.882 .44328 Mdot
.882 .44336 Mdot
.882 .44392 Mdot
.882 .44523 Mdot
.882 .44558 Mdot
.882 .4458 Mdot
.882 .446 Mdot
.882 .44651 Mdot
.882 .44714 Mdot
.882 .44752 Mdot
.882 .44763 Mdot
.882 .4477 Mdot
.882 .44795 Mdot
.882 .44868 Mdot
.882 .4492 Mdot
.882 .44931 Mdot
.882 .4496 Mdot
.882 .44961 Mdot
.882 .44976 Mdot
.882 .45039 Mdot
.882 .45101 Mdot
.882 .4523 Mdot
.882 .4525 Mdot
.882 .45257 Mdot
.882 .4528 Mdot
.882 .45332 Mdot
.882 .45343 Mdot
.882 .45373 Mdot
.882 .45405 Mdot
.882 .45431 Mdot
.882 .45454 Mdot
.882 .45504 Mdot
.882 .45508 Mdot
.882 .45528 Mdot
.882 .45537 Mdot
.882 .45577 Mdot
.882 .4564 Mdot
.882 .45671 Mdot
.882 .45734 Mdot
.882 .45753 Mdot
.882 .45822 Mdot
.882 .45921 Mdot
.882 .4599 Mdot
.882 .46 Mdot
.882 .46001 Mdot
.882 .46073 Mdot
.882 .46243 Mdot
.882 .46263 Mdot
.882 .46294 Mdot
.882 .4631 Mdot
.882 .46317 Mdot
.882 .46389 Mdot
.882 .46447 Mdot
.882 .46487 Mdot
.882 .46491 Mdot
.882 .46492 Mdot
.882 .46505 Mdot
.882 .46522 Mdot
.882 .46559 Mdot
.882 .46571 Mdot
.882 .46591 Mdot
.882 .46695 Mdot
.882 .46732 Mdot
.882 .46737 Mdot
.882 .46794 Mdot
.882 .46808 Mdot
.882 .46905 Mdot
.882 .46942 Mdot
.882 .47038 Mdot
.882 .47045 Mdot
.882 .47052 Mdot
.882 .4708 Mdot
.882 .47083 Mdot
.882 .47123 Mdot
.882 .47129 Mdot
.882 .47171 Mdot
.882 .47203 Mdot
.882 .47239 Mdot
.882 .47261 Mdot
.882 .47268 Mdot
.882 .47319 Mdot
.882 .47349 Mdot
.882 .47358 Mdot
.882 .47384 Mdot
.882 .47387 Mdot
.882 .4739 Mdot
.882 .47407 Mdot
.882 .47428 Mdot
.882 .47429 Mdot
.882 .47451 Mdot
.882 .47473 Mdot
.882 .47514 Mdot
.882 .47611 Mdot
.882 .47659 Mdot
.882 .47683 Mdot
.882 .47785 Mdot
.882 .47806 Mdot
.882 .47838 Mdot
.882 .47933 Mdot
.882 .47939 Mdot
.882 .47949 Mdot
.882 .47961 Mdot
.882 .47967 Mdot
.882 .47999 Mdot
.882 .48023 Mdot
.882 .48034 Mdot
.882 .48093 Mdot
.882 .48127 Mdot
.882 .48131 Mdot
.882 .48158 Mdot
.882 .48164 Mdot
.882 .48188 Mdot
.882 .482 Mdot
.882 .4821 Mdot
.882 .48219 Mdot
.882 .48262 Mdot
.882 .48342 Mdot
.882 .48343 Mdot
.882 .4836 Mdot
.882 .48378 Mdot
.882 .48405 Mdot
.882 .48423 Mdot
.882 .48442 Mdot
.882 .48515 Mdot
.882 .48536 Mdot
.882 .4857 Mdot
.882 .48589 Mdot
.882 .48624 Mdot
.882 .4865 Mdot
.882 .48687 Mdot
.882 .48708 Mdot
.882 .48731 Mdot
.882 .48749 Mdot
.882 .48804 Mdot
.882 .48823 Mdot
.882 .48834 Mdot
.882 .48849 Mdot
.882 .48855 Mdot
.882 .48886 Mdot
.882 .48895 Mdot
.882 .48897 Mdot
.882 .48918 Mdot
.882 .48987 Mdot
.882 .49033 Mdot
.882 .49065 Mdot
.882 .49127 Mdot
.882 .49187 Mdot
.882 .49276 Mdot
.882 .49288 Mdot
.882 .49308 Mdot
.882 .49395 Mdot
.882 .49401 Mdot
.882 .49445 Mdot
.882 .4948 Mdot
.882 .49501 Mdot
.882 .49506 Mdot
.882 .49512 Mdot
.882 .49634 Mdot
.882 .49678 Mdot
.882 .49706 Mdot
.882 .49722 Mdot
.882 .49728 Mdot
.882 .49765 Mdot
.882 .49768 Mdot
.882 .49817 Mdot
.882 .49834 Mdot
.882 .4984 Mdot
.882 .49852 Mdot
.882 .49874 Mdot
.882 .49881 Mdot
.882 .49955 Mdot
.882 .50014 Mdot
.882 .5005 Mdot
.882 .50121 Mdot
.882 .50141 Mdot
.882 .50152 Mdot
.882 .50179 Mdot
.882 .5019 Mdot
.882 .50223 Mdot
.882 .50239 Mdot
.882 .50259 Mdot
.882 .50319 Mdot
.882 .50326 Mdot
.882 .50341 Mdot
.882 .50371 Mdot
.882 .50375 Mdot
.882 .50377 Mdot
.882 .50396 Mdot
.882 .50491 Mdot
.882 .50492 Mdot
.882 .50553 Mdot
.882 .50689 Mdot
.882 .50714 Mdot
.882 .50733 Mdot
.882 .50762 Mdot
.882 .50778 Mdot
.882 .50784 Mdot
.882 .50846 Mdot
.882 .50885 Mdot
.882 .50908 Mdot
.882 .50979 Mdot
.882 .51038 Mdot
.882 .51087 Mdot
.882 .51115 Mdot
.882 .51119 Mdot
.882 .51179 Mdot
.882 .51181 Mdot
.882 .51208 Mdot
.882 .51343 Mdot
.882 .51382 Mdot
.882 .51407 Mdot
.882 .51493 Mdot
.882 .51558 Mdot
.882 .51559 Mdot
.882 .51594 Mdot
.882 .5167 Mdot
.882 .51693 Mdot
.882 .51728 Mdot
.882 .51736 Mdot
.882 .51836 Mdot
.882 .51839 Mdot
.882 .51862 Mdot
.882 .51866 Mdot
.882 .51917 Mdot
.882 .51929 Mdot
.882 .52 Mdot
.882 .52002 Mdot
.882 .52049 Mdot
.882 .52053 Mdot
.882 .52095 Mdot
.882 .52103 Mdot
.882 .52108 Mdot
.882 .5215 Mdot
.882 .52166 Mdot
.882 .52229 Mdot
.882 .52266 Mdot
.882 .52299 Mdot
.882 .52355 Mdot
.882 .5237 Mdot
.882 .52388 Mdot
.882 .52445 Mdot
.882 .52459 Mdot
.882 .52648 Mdot
.882 .52723 Mdot
.882 .52729 Mdot
.882 .52739 Mdot
.882 .5276 Mdot
.882 .52786 Mdot
.882 .52788 Mdot
.882 .52811 Mdot
.882 .52864 Mdot
.882 .5287 Mdot
.882 .52927 Mdot
.882 .52939 Mdot
.882 .5296 Mdot
.882 .53036 Mdot
.882 .53066 Mdot
.882 .53081 Mdot
.882 .53119 Mdot
.882 .53133 Mdot
.882 .5314 Mdot
.882 .53176 Mdot
.882 .53233 Mdot
.882 .53288 Mdot
.882 .53398 Mdot
.882 .53459 Mdot
.884 .13607 Mdot
.884 .13607 Mdot
.884 .13618 Mdot
.884 .13636 Mdot
.884 .13887 Mdot
.884 .13924 Mdot
.884 .13958 Mdot
.884 .14048 Mdot
.884 .14088 Mdot
.884 .14251 Mdot
.884 .14252 Mdot
.884 .14256 Mdot
.884 .14307 Mdot
.884 .14395 Mdot
.884 .14475 Mdot
.884 .14502 Mdot
.884 .14572 Mdot
.884 .14716 Mdot
.884 .14751 Mdot
.884 .14855 Mdot
.884 .14903 Mdot
.884 .15047 Mdot
.884 .1506 Mdot
.884 .15085 Mdot
.884 .15144 Mdot
.884 .15176 Mdot
.884 .15207 Mdot
.884 .15229 Mdot
.884 .15239 Mdot
.884 .15285 Mdot
.884 .15312 Mdot
.884 .15318 Mdot
.884 .15388 Mdot
.884 .15433 Mdot
.884 .15652 Mdot
.884 .1566 Mdot
.884 .15796 Mdot
.884 .15818 Mdot
.884 .15876 Mdot
.884 .15925 Mdot
.884 .15964 Mdot
.884 .15994 Mdot
.884 .16066 Mdot
.884 .1608 Mdot
.884 .16092 Mdot
.884 .16108 Mdot
.884 .16133 Mdot
.884 .1619 Mdot
.884 .16203 Mdot
.884 .16204 Mdot
.884 .16273 Mdot
.884 .16289 Mdot
.884 .16315 Mdot
.884 .16318 Mdot
.884 .16374 Mdot
.884 .16395 Mdot
.884 .16469 Mdot
.884 .16485 Mdot
.884 .16612 Mdot
.884 .16623 Mdot
.884 .16772 Mdot
.884 .16784 Mdot
.884 .16804 Mdot
.884 .16923 Mdot
.884 .17017 Mdot
.884 .17048 Mdot
.884 .17065 Mdot
.884 .17087 Mdot
.884 .17152 Mdot
.884 .17187 Mdot
.884 .172 Mdot
.884 .17265 Mdot
.884 .17342 Mdot
.884 .1738 Mdot
.884 .17395 Mdot
.884 .17421 Mdot
.884 .17571 Mdot
.884 .17632 Mdot
.884 .17692 Mdot
.884 .177 Mdot
.884 .17723 Mdot
.884 .17749 Mdot
.884 .17753 Mdot
.884 .17778 Mdot
.884 .1784 Mdot
.884 .17846 Mdot
.884 .17854 Mdot
.884 .1786 Mdot
.884 .17924 Mdot
.884 .18007 Mdot
.884 .18033 Mdot
.884 .18062 Mdot
.884 .1807 Mdot
.884 .18279 Mdot
.884 .18324 Mdot
.884 .18337 Mdot
.884 .18369 Mdot
.884 .18423 Mdot
.884 .1843 Mdot
.884 .18441 Mdot
.884 .18446 Mdot
.884 .18456 Mdot
.884 .18493 Mdot
.884 .18594 Mdot
.884 .18607 Mdot
.884 .18706 Mdot
.884 .18824 Mdot
.884 .18838 Mdot
.884 .18853 Mdot
.884 .18902 Mdot
.884 .18928 Mdot
.884 .18929 Mdot
.884 .18931 Mdot
.884 .19085 Mdot
.884 .19109 Mdot
.884 .19121 Mdot
.884 .19126 Mdot
.884 .19154 Mdot
.884 .19158 Mdot
.884 .19166 Mdot
.884 .19167 Mdot
.884 .19256 Mdot
.884 .19476 Mdot
.884 .19602 Mdot
.884 .19615 Mdot
.884 .19653 Mdot
.884 .19694 Mdot
.884 .19726 Mdot
.884 .19735 Mdot
.884 .19864 Mdot
.884 .19975 Mdot
.884 .20144 Mdot
.884 .20298 Mdot
.884 .20387 Mdot
.884 .20495 Mdot
.884 .20497 Mdot
.884 .20755 Mdot
.884 .20866 Mdot
.884 .20903 Mdot
.884 .20915 Mdot
.884 .21044 Mdot
.884 .21094 Mdot
.884 .21095 Mdot
.884 .21148 Mdot
.884 .21153 Mdot
.884 .21218 Mdot
.884 .21563 Mdot
.884 .21628 Mdot
.884 .21633 Mdot
.884 .21815 Mdot
.884 .21843 Mdot
.884 .22044 Mdot
.884 .22073 Mdot
.884 .22102 Mdot
.884 .22245 Mdot
.884 .22252 Mdot
.884 .22298 Mdot
.884 .22313 Mdot
.884 .22402 Mdot
.884 .22778 Mdot
.884 .22803 Mdot
.884 .2287 Mdot
.884 .22891 Mdot
.884 .22895 Mdot
.884 .22926 Mdot
.884 .22926 Mdot
.884 .22947 Mdot
.884 .22952 Mdot
.884 .22978 Mdot
.884 .23008 Mdot
.884 .23009 Mdot
.884 .23057 Mdot
.884 .23247 Mdot
.884 .23304 Mdot
.884 .23316 Mdot
.884 .23421 Mdot
.884 .23421 Mdot
.884 .23467 Mdot
.884 .23488 Mdot
.884 .23509 Mdot
.884 .23547 Mdot
.884 .23624 Mdot
.884 .2368 Mdot
.884 .23691 Mdot
.884 .23705 Mdot
.884 .23706 Mdot
.884 .23728 Mdot
.884 .23748 Mdot
.884 .23759 Mdot
.884 .23777 Mdot
.884 .23779 Mdot
.884 .23887 Mdot
.884 .23956 Mdot
.884 .23975 Mdot
.884 .24065 Mdot
.884 .24068 Mdot
.884 .24074 Mdot
.884 .24161 Mdot
.884 .24164 Mdot
.884 .24195 Mdot
.884 .24251 Mdot
.884 .2432 Mdot
.884 .24341 Mdot
.884 .24359 Mdot
.884 .24366 Mdot
.884 .24386 Mdot
.884 .24391 Mdot
.884 .24438 Mdot
.884 .24461 Mdot
.884 .24509 Mdot
.884 .2456 Mdot
.884 .24634 Mdot
.884 .24695 Mdot
.884 .24748 Mdot
.884 .24831 Mdot
.884 .24835 Mdot
.884 .24888 Mdot
.884 .24889 Mdot
.884 .24904 Mdot
.884 .24905 Mdot
.884 .2495 Mdot
.884 .24975 Mdot
.884 .25044 Mdot
.884 .25046 Mdot
.884 .25123 Mdot
.884 .25134 Mdot
.884 .25218 Mdot
.884 .254 Mdot
.884 .25407 Mdot
.884 .2544 Mdot
.884 .25474 Mdot
.884 .25496 Mdot
.884 .25521 Mdot
.884 .2554 Mdot
.884 .25644 Mdot
.884 .25673 Mdot
.884 .25682 Mdot
.884 .25685 Mdot
.884 .2569 Mdot
.884 .25702 Mdot
.884 .25716 Mdot
.884 .25747 Mdot
.884 .25756 Mdot
.884 .25795 Mdot
.884 .25813 Mdot
.884 .25895 Mdot
.884 .259 Mdot
.884 .25901 Mdot
.884 .25941 Mdot
.884 .25952 Mdot
.884 .26076 Mdot
.884 .26155 Mdot
.884 .26174 Mdot
.884 .26357 Mdot
.884 .26439 Mdot
.884 .26491 Mdot
.884 .26497 Mdot
.884 .2651 Mdot
.884 .26511 Mdot
.884 .26542 Mdot
.884 .26556 Mdot
.884 .26563 Mdot
.884 .26614 Mdot
.884 .26618 Mdot
.884 .2665 Mdot
.884 .26797 Mdot
.884 .2683 Mdot
.884 .26836 Mdot
.884 .26853 Mdot
.884 .26938 Mdot
.884 .27025 Mdot
.884 .27074 Mdot
.884 .27094 Mdot
.884 .27147 Mdot
.884 .27173 Mdot
.884 .27185 Mdot
.884 .27274 Mdot
.884 .27299 Mdot
.884 .27321 Mdot
.884 .27344 Mdot
.884 .27344 Mdot
.884 .27349 Mdot
.884 .27367 Mdot
.884 .27394 Mdot
.884 .27411 Mdot
.884 .27493 Mdot
.884 .27508 Mdot
.884 .2751 Mdot
.884 .27516 Mdot
.884 .27518 Mdot
.884 .27524 Mdot
.884 .27553 Mdot
.884 .27571 Mdot
.884 .27641 Mdot
.884 .27669 Mdot
.884 .2771 Mdot
.884 .27714 Mdot
.884 .2772 Mdot
.884 .27732 Mdot
.884 .27818 Mdot
.884 .27856 Mdot
.884 .27935 Mdot
.884 .27987 Mdot
.884 .27988 Mdot
.884 .28016 Mdot
.884 .28241 Mdot
.884 .28259 Mdot
.884 .28392 Mdot
.884 .28523 Mdot
.884 .28544 Mdot
.884 .28546 Mdot
.884 .28563 Mdot
.884 .28579 Mdot
.884 .2862 Mdot
.884 .28624 Mdot
.884 .28754 Mdot
.884 .28789 Mdot
.884 .28818 Mdot
.884 .28867 Mdot
.884 .28956 Mdot
.884 .29011 Mdot
.884 .29036 Mdot
.884 .2904 Mdot
.884 .29081 Mdot
.884 .29194 Mdot
.884 .29255 Mdot
.884 .29256 Mdot
.884 .2928 Mdot
.884 .29289 Mdot
.884 .29395 Mdot
.884 .29415 Mdot
.884 .29417 Mdot
.884 .29435 Mdot
.884 .29445 Mdot
.884 .29463 Mdot
.884 .2953 Mdot
.884 .29533 Mdot
.884 .29598 Mdot
.884 .29624 Mdot
.884 .29641 Mdot
.884 .29671 Mdot
.884 .2969 Mdot
.884 .29746 Mdot
.884 .29751 Mdot
.884 .29809 Mdot
.884 .29813 Mdot
.884 .29824 Mdot
.884 .29867 Mdot
.884 .29897 Mdot
.884 .29935 Mdot
.884 .29942 Mdot
.884 .29945 Mdot
.884 .29993 Mdot
.884 .30037 Mdot
.884 .30043 Mdot
.884 .30066 Mdot
.884 .30073 Mdot
.884 .30091 Mdot
.884 .301 Mdot
.884 .30105 Mdot
.884 .30128 Mdot
.884 .30132 Mdot
.884 .3015 Mdot
.884 .30158 Mdot
.884 .30163 Mdot
.884 .30167 Mdot
.884 .30204 Mdot
.884 .30217 Mdot
.884 .30251 Mdot
.884 .30258 Mdot
.884 .30301 Mdot
.884 .30304 Mdot
.884 .30411 Mdot
.884 .30413 Mdot
.884 .30421 Mdot
.884 .30436 Mdot
.884 .30446 Mdot
.884 .30493 Mdot
.884 .30544 Mdot
.884 .30559 Mdot
.884 .30603 Mdot
.884 .3068 Mdot
.884 .30706 Mdot
.884 .30734 Mdot
.884 .30751 Mdot
.884 .30752 Mdot
.884 .30804 Mdot
.884 .30817 Mdot
.884 .30846 Mdot
.884 .30857 Mdot
.884 .30954 Mdot
.884 .30958 Mdot
.884 .30981 Mdot
.884 .3099 Mdot
.884 .31071 Mdot
.884 .31187 Mdot
.884 .31267 Mdot
.884 .3129 Mdot
.884 .31347 Mdot
.884 .31442 Mdot
.884 .31454 Mdot
.884 .31473 Mdot
.884 .31483 Mdot
.884 .315 Mdot
.884 .31551 Mdot
.884 .31565 Mdot
.884 .31707 Mdot
.884 .31745 Mdot
.884 .31768 Mdot
.884 .31812 Mdot
.884 .31847 Mdot
.884 .31943 Mdot
.884 .32082 Mdot
.884 .32087 Mdot
.884 .32095 Mdot
.884 .32152 Mdot
.884 .32176 Mdot
.884 .32201 Mdot
.884 .32288 Mdot
.884 .32291 Mdot
.884 .32306 Mdot
.884 .32308 Mdot
.884 .32335 Mdot
.884 .32337 Mdot
.884 .3234 Mdot
.884 .32362 Mdot
.884 .32389 Mdot
.884 .32397 Mdot
.884 .3249 Mdot
.884 .32528 Mdot
.884 .32529 Mdot
.884 .32532 Mdot
.884 .32577 Mdot
.884 .32581 Mdot
.884 .32613 Mdot
.884 .32655 Mdot
.884 .32675 Mdot
.884 .32684 Mdot
.884 .32734 Mdot
.884 .32741 Mdot
.884 .32747 Mdot
.884 .32756 Mdot
.884 .32757 Mdot
.884 .3276 Mdot
.884 .3276 Mdot
.884 .32789 Mdot
.884 .32915 Mdot
.884 .32939 Mdot
.884 .32942 Mdot
.884 .33018 Mdot
.884 .33185 Mdot
.884 .33268 Mdot
.884 .33303 Mdot
.884 .33376 Mdot
.884 .33526 Mdot
.884 .33549 Mdot
.884 .33607 Mdot
.884 .33616 Mdot
.884 .3369 Mdot
.884 .33745 Mdot
.884 .33747 Mdot
.884 .33761 Mdot
.884 .33766 Mdot
.884 .33795 Mdot
.884 .33915 Mdot
.884 .33945 Mdot
.884 .33971 Mdot
.884 .33989 Mdot
.884 .33989 Mdot
.884 .34065 Mdot
.884 .34087 Mdot
.884 .34136 Mdot
.884 .34149 Mdot
.884 .34186 Mdot
.884 .34204 Mdot
.884 .34212 Mdot
.884 .34235 Mdot
.884 .34292 Mdot
.884 .34357 Mdot
.884 .34485 Mdot
.884 .34573 Mdot
.884 .3464 Mdot
.884 .34756 Mdot
.884 .34841 Mdot
.884 .34844 Mdot
.884 .34847 Mdot
.884 .34855 Mdot
.884 .34914 Mdot
.884 .3506 Mdot
.884 .35105 Mdot
.884 .35109 Mdot
.884 .35126 Mdot
.884 .35144 Mdot
.884 .35154 Mdot
.884 .35211 Mdot
.884 .35219 Mdot
.884 .35376 Mdot
.884 .35434 Mdot
.884 .35493 Mdot
.884 .35565 Mdot
.884 .35711 Mdot
.884 .3576 Mdot
.884 .35785 Mdot
.884 .35827 Mdot
.884 .35847 Mdot
.884 .35917 Mdot
.884 .36048 Mdot
.884 .36054 Mdot
.884 .36076 Mdot
.884 .36111 Mdot
.884 .36146 Mdot
.884 .36164 Mdot
.884 .36166 Mdot
.884 .36169 Mdot
.884 .36207 Mdot
.884 .36208 Mdot
.884 .36259 Mdot
.884 .36268 Mdot
.884 .36276 Mdot
.884 .36279 Mdot
.884 .36323 Mdot
.884 .36358 Mdot
.884 .36383 Mdot
.884 .3646 Mdot
.884 .36496 Mdot
.884 .36531 Mdot
.884 .36542 Mdot
.884 .36568 Mdot
.884 .36772 Mdot
.884 .36892 Mdot
.884 .36958 Mdot
.884 .36963 Mdot
.884 .36981 Mdot
.884 .36992 Mdot
.884 .37022 Mdot
.884 .37035 Mdot
.884 .37108 Mdot
.884 .37118 Mdot
.884 .37166 Mdot
.884 .37167 Mdot
.884 .37271 Mdot
.884 .37424 Mdot
.884 .3744 Mdot
.884 .37487 Mdot
.884 .37496 Mdot
.884 .37526 Mdot
.884 .37533 Mdot
.884 .3757 Mdot
.884 .3771 Mdot
.884 .37774 Mdot
.884 .37776 Mdot
.884 .37844 Mdot
.884 .37893 Mdot
.884 .37895 Mdot
.884 .37945 Mdot
.884 .38076 Mdot
.884 .38119 Mdot
.884 .38199 Mdot
.884 .38211 Mdot
.884 .38292 Mdot
.884 .38304 Mdot
.884 .38319 Mdot
.884 .38327 Mdot
.884 .38453 Mdot
.884 .38459 Mdot
.884 .38476 Mdot
.884 .38552 Mdot
.884 .38601 Mdot
.884 .38633 Mdot
.884 .38647 Mdot
.884 .38713 Mdot
.884 .38713 Mdot
.884 .38751 Mdot
.884 .38809 Mdot
.884 .38823 Mdot
.884 .38889 Mdot
.884 .38977 Mdot
.884 .39025 Mdot
.884 .39097 Mdot
.884 .39113 Mdot
.884 .39141 Mdot
.884 .39177 Mdot
.884 .39186 Mdot
.884 .39227 Mdot
.884 .39254 Mdot
.884 .39304 Mdot
.884 .39341 Mdot
.884 .39349 Mdot
.884 .39382 Mdot
.884 .39403 Mdot
.884 .39404 Mdot
.884 .39441 Mdot
.884 .39449 Mdot
.884 .39467 Mdot
.884 .39495 Mdot
.884 .39547 Mdot
.884 .3955 Mdot
.884 .39622 Mdot
.884 .39635 Mdot
.884 .3974 Mdot
.884 .39764 Mdot
.884 .39868 Mdot
.884 .39933 Mdot
.884 .39935 Mdot
.884 .39971 Mdot
.884 .4005 Mdot
.884 .40071 Mdot
.884 .40075 Mdot
.884 .40092 Mdot
.884 .40133 Mdot
.884 .40219 Mdot
.884 .40278 Mdot
.884 .40279 Mdot
.884 .40353 Mdot
.884 .4036 Mdot
.884 .40383 Mdot
.884 .40393 Mdot
.884 .40396 Mdot
.884 .40434 Mdot
.884 .40502 Mdot
.884 .40617 Mdot
.884 .40631 Mdot
.884 .40638 Mdot
.884 .40657 Mdot
.884 .40678 Mdot
.884 .40736 Mdot
.884 .40756 Mdot
.884 .4078 Mdot
.884 .40782 Mdot
.884 .4082 Mdot
.884 .40821 Mdot
.884 .40842 Mdot
.884 .40856 Mdot
.884 .40875 Mdot
.884 .40908 Mdot
.884 .40911 Mdot
.884 .40985 Mdot
.884 .4106 Mdot
.884 .41101 Mdot
.884 .41225 Mdot
.884 .41258 Mdot
.884 .41291 Mdot
.884 .4138 Mdot
.884 .41384 Mdot
.884 .41417 Mdot
.884 .41422 Mdot
.884 .41432 Mdot
.884 .4147 Mdot
.884 .41586 Mdot
.884 .4159 Mdot
.884 .41592 Mdot
.884 .41593 Mdot
.884 .41707 Mdot
.884 .41745 Mdot
.884 .41867 Mdot
.884 .41904 Mdot
.884 .41936 Mdot
.884 .4195 Mdot
.884 .41954 Mdot
.884 .41985 Mdot
.884 .41993 Mdot
.884 .4202 Mdot
.884 .42032 Mdot
.884 .42076 Mdot
.884 .42086 Mdot
.884 .42101 Mdot
.884 .42117 Mdot
.884 .42185 Mdot
.884 .42202 Mdot
.884 .42213 Mdot
.884 .42291 Mdot
.884 .42422 Mdot
.884 .42483 Mdot
.884 .4253 Mdot
.884 .42624 Mdot
.884 .42668 Mdot
.884 .4267 Mdot
.884 .42755 Mdot
.884 .42771 Mdot
.884 .42771 Mdot
.884 .42778 Mdot
.884 .42872 Mdot
.884 .42874 Mdot
.884 .42899 Mdot
.884 .42901 Mdot
.884 .42902 Mdot
.884 .42923 Mdot
.884 .42976 Mdot
.884 .42981 Mdot
.884 .42996 Mdot
.884 .43027 Mdot
.884 .43027 Mdot
.884 .43036 Mdot
.884 .43147 Mdot
.884 .43151 Mdot
.884 .43154 Mdot
.884 .43287 Mdot
.884 .43307 Mdot
.884 .43366 Mdot
.884 .43454 Mdot
.884 .43726 Mdot
.884 .43772 Mdot
.884 .43777 Mdot
.884 .4379 Mdot
.884 .43792 Mdot
.884 .43847 Mdot
.884 .43853 Mdot
.884 .43907 Mdot
.884 .43916 Mdot
.884 .43947 Mdot
.884 .43991 Mdot
.884 .44024 Mdot
.884 .44053 Mdot
.884 .44098 Mdot
.884 .4416 Mdot
.884 .44209 Mdot
.884 .44237 Mdot
.884 .44242 Mdot
.884 .44257 Mdot
.884 .4426 Mdot
.884 .44272 Mdot
.884 .44275 Mdot
.884 .4428 Mdot
.884 .4429 Mdot
.884 .44311 Mdot
.884 .44336 Mdot
.884 .44363 Mdot
.884 .44365 Mdot
.884 .4439 Mdot
.884 .44407 Mdot
.884 .44431 Mdot
.884 .44438 Mdot
.884 .4444 Mdot
.884 .44473 Mdot
.884 .44475 Mdot
.884 .44507 Mdot
.884 .44535 Mdot
.884 .44596 Mdot
.884 .44635 Mdot
.884 .44646 Mdot
.884 .44652 Mdot
.884 .44661 Mdot
.884 .44663 Mdot
.884 .44734 Mdot
.884 .44753 Mdot
.884 .44877 Mdot
.884 .44973 Mdot
.884 .45001 Mdot
.884 .45037 Mdot
.884 .4511 Mdot
.884 .45112 Mdot
.884 .45145 Mdot
.884 .45154 Mdot
.884 .45241 Mdot
.884 .4547 Mdot
.884 .455 Mdot
.884 .45615 Mdot
.884 .45627 Mdot
.884 .45706 Mdot
.884 .45716 Mdot
.884 .45732 Mdot
.884 .4574 Mdot
.884 .45741 Mdot
.884 .45796 Mdot
.884 .45821 Mdot
.884 .45834 Mdot
.884 .45834 Mdot
.884 .45924 Mdot
.884 .45931 Mdot
.884 .45986 Mdot
.884 .46112 Mdot
.884 .46125 Mdot
.884 .46227 Mdot
.884 .46245 Mdot
.884 .46247 Mdot
.884 .46276 Mdot
.884 .46305 Mdot
.884 .46305 Mdot
.884 .46313 Mdot
.884 .46317 Mdot
.884 .46346 Mdot
.884 .46392 Mdot
.884 .46496 Mdot
.884 .4665 Mdot
.884 .46651 Mdot
.884 .46738 Mdot
.884 .46755 Mdot
.884 .46769 Mdot
.884 .46773 Mdot
.884 .46774 Mdot
.884 .46779 Mdot
.884 .46865 Mdot
.884 .46911 Mdot
.884 .4693 Mdot
.884 .46934 Mdot
.884 .4709 Mdot
.884 .47134 Mdot
.884 .47135 Mdot
.884 .47174 Mdot
.884 .47213 Mdot
.884 .47214 Mdot
.884 .47222 Mdot
.884 .47253 Mdot
.884 .47256 Mdot
.884 .47302 Mdot
.884 .47332 Mdot
.884 .47409 Mdot
.884 .47478 Mdot
.884 .47504 Mdot
.884 .47507 Mdot
.884 .47518 Mdot
.884 .47522 Mdot
.884 .47533 Mdot
.884 .47584 Mdot
.884 .47615 Mdot
.884 .47635 Mdot
.884 .47739 Mdot
.884 .4775 Mdot
.884 .4779 Mdot
.884 .4785 Mdot
.884 .47862 Mdot
.884 .47868 Mdot
.884 .47879 Mdot
.884 .47892 Mdot
.884 .479 Mdot
.884 .47907 Mdot
.884 .47938 Mdot
.884 .48003 Mdot
.884 .48027 Mdot
.884 .48053 Mdot
.884 .48112 Mdot
.884 .48119 Mdot
.884 .48151 Mdot
.884 .48259 Mdot
.884 .48286 Mdot
.884 .48287 Mdot
.884 .48318 Mdot
.884 .4835 Mdot
.884 .48353 Mdot
.884 .48365 Mdot
.884 .48402 Mdot
.884 .48417 Mdot
.884 .48629 Mdot
.884 .4868 Mdot
.884 .48688 Mdot
.884 .48714 Mdot
.884 .48718 Mdot
.884 .48799 Mdot
.884 .48815 Mdot
.884 .48832 Mdot
.884 .48946 Mdot
.884 .48961 Mdot
.884 .49064 Mdot
.884 .49067 Mdot
.884 .49104 Mdot
.884 .49299 Mdot
.884 .49336 Mdot
.884 .49339 Mdot
.884 .49369 Mdot
.884 .49369 Mdot
.884 .49397 Mdot
.884 .4947 Mdot
.884 .49477 Mdot
.884 .49498 Mdot
.884 .49561 Mdot
.884 .49707 Mdot
.884 .49708 Mdot
.884 .49769 Mdot
.884 .49819 Mdot
.884 .49906 Mdot
.884 .50002 Mdot
.884 .50065 Mdot
.884 .50138 Mdot
.884 .50143 Mdot
.884 .50161 Mdot
.884 .50184 Mdot
.884 .50206 Mdot
.884 .50213 Mdot
.884 .50284 Mdot
.884 .50408 Mdot
.884 .50459 Mdot
.884 .50459 Mdot
.884 .50464 Mdot
.884 .50467 Mdot
.884 .50482 Mdot
.884 .50485 Mdot
.884 .50492 Mdot
.884 .50505 Mdot
.884 .50593 Mdot
.884 .50593 Mdot
.884 .50594 Mdot
.884 .50609 Mdot
.884 .50637 Mdot
.884 .50645 Mdot
.884 .50653 Mdot
.884 .5072 Mdot
.884 .50776 Mdot
.884 .50783 Mdot
.884 .5084 Mdot
.884 .50861 Mdot
.884 .50867 Mdot
.884 .5087 Mdot
.884 .50876 Mdot
.884 .5088 Mdot
.884 .5091 Mdot
.884 .50928 Mdot
.884 .50936 Mdot
.884 .50961 Mdot
.884 .5108 Mdot
.884 .51084 Mdot
.884 .51101 Mdot
.884 .51115 Mdot
.884 .51162 Mdot
.884 .51198 Mdot
.884 .51202 Mdot
.884 .51206 Mdot
.884 .5121 Mdot
.884 .51245 Mdot
.884 .51259 Mdot
.884 .51261 Mdot
.884 .51276 Mdot
.884 .51289 Mdot
.884 .51293 Mdot
.884 .51327 Mdot
.884 .51362 Mdot
.884 .51446 Mdot
.884 .51461 Mdot
.884 .5147 Mdot
.884 .51491 Mdot
.884 .51535 Mdot
.884 .51571 Mdot
.884 .51579 Mdot
.884 .51599 Mdot
.884 .51635 Mdot
.884 .51648 Mdot
.884 .51658 Mdot
.884 .51675 Mdot
.884 .51728 Mdot
.884 .51796 Mdot
.884 .51807 Mdot
.884 .51814 Mdot
.884 .51898 Mdot
.884 .51904 Mdot
.884 .51976 Mdot
.884 .51985 Mdot
.884 .52027 Mdot
.884 .52039 Mdot
.884 .5207 Mdot
.884 .52072 Mdot
.884 .52087 Mdot
.884 .52096 Mdot
.884 .52135 Mdot
.884 .52136 Mdot
.884 .52143 Mdot
.884 .52175 Mdot
.884 .52189 Mdot
.884 .52198 Mdot
.884 .52205 Mdot
.884 .52213 Mdot
.884 .52254 Mdot
.884 .52271 Mdot
.884 .52293 Mdot
.884 .52321 Mdot
.884 .52353 Mdot
.884 .52366 Mdot
.884 .52443 Mdot
.884 .52447 Mdot
.884 .52571 Mdot
.884 .52596 Mdot
.884 .52636 Mdot
.884 .5264 Mdot
.884 .52654 Mdot
.884 .52681 Mdot
.884 .52686 Mdot
.884 .52699 Mdot
.884 .52716 Mdot
.884 .52734 Mdot
.884 .52768 Mdot
.884 .52782 Mdot
.884 .52789 Mdot
.884 .52871 Mdot
.884 .52898 Mdot
.884 .52957 Mdot
.884 .52976 Mdot
.884 .53058 Mdot
.884 .53098 Mdot
.884 .53113 Mdot
.884 .53158 Mdot
.884 .53208 Mdot
.884 .53237 Mdot
.884 .53239 Mdot
.884 .5324 Mdot
.884 .53332 Mdot
.884 .53355 Mdot
.884 .53405 Mdot
.884 .53424 Mdot
.884 .53446 Mdot
.884 .53588 Mdot
.884 .53597 Mdot
.884 .53604 Mdot
.884 .53604 Mdot
.886 .13397 Mdot
.886 .134 Mdot
.886 .13404 Mdot
.886 .13488 Mdot
.886 .13514 Mdot
.886 .13519 Mdot
.886 .13576 Mdot
.886 .13668 Mdot
.886 .13798 Mdot
.886 .13875 Mdot
.886 .1389 Mdot
.886 .13935 Mdot
.886 .13964 Mdot
.886 .13964 Mdot
.886 .14011 Mdot
.886 .14011 Mdot
.886 .14032 Mdot
.886 .14051 Mdot
.886 .14068 Mdot
.886 .14093 Mdot
.886 .14167 Mdot
.886 .14175 Mdot
.886 .14345 Mdot
.886 .14524 Mdot
.886 .14721 Mdot
.886 .14773 Mdot
.886 .14775 Mdot
.886 .14812 Mdot
.886 .14927 Mdot
.886 .15024 Mdot
.886 .15035 Mdot
.886 .15064 Mdot
.886 .15089 Mdot
.886 .15229 Mdot
.886 .15245 Mdot
.886 .15362 Mdot
.886 .15474 Mdot
.886 .15526 Mdot
.886 .15658 Mdot
.886 .15736 Mdot
.886 .15814 Mdot
.886 .15957 Mdot
.886 .15977 Mdot
.886 .1602 Mdot
.886 .16024 Mdot
.886 .16072 Mdot
.886 .16142 Mdot
.886 .16397 Mdot
.886 .1642 Mdot
.886 .1645 Mdot
.886 .16567 Mdot
.886 .16575 Mdot
.886 .16584 Mdot
.886 .16604 Mdot
.886 .16605 Mdot
.886 .16616 Mdot
.886 .16633 Mdot
.886 .1664 Mdot
.886 .16651 Mdot
.886 .16732 Mdot
.886 .16785 Mdot
.886 .16832 Mdot
.886 .17049 Mdot
.886 .17079 Mdot
.886 .17088 Mdot
.886 .17135 Mdot
.886 .17149 Mdot
.886 .17171 Mdot
.886 .17265 Mdot
.886 .17284 Mdot
.886 .17443 Mdot
.886 .17532 Mdot
.886 .17547 Mdot
.886 .17623 Mdot
.886 .17744 Mdot
.886 .17817 Mdot
.886 .17825 Mdot
.886 .17992 Mdot
.886 .18031 Mdot
.886 .18085 Mdot
.886 .1812 Mdot
.886 .18136 Mdot
.886 .18208 Mdot
.886 .1823 Mdot
.886 .18395 Mdot
.886 .18414 Mdot
.886 .18583 Mdot
.886 .186 Mdot
.886 .18659 Mdot
.886 .18691 Mdot
.886 .18729 Mdot
.886 .18781 Mdot
.886 .18783 Mdot
.886 .18791 Mdot
.886 .18815 Mdot
.886 .18818 Mdot
.886 .18863 Mdot
.886 .18962 Mdot
.886 .19052 Mdot
.886 .1912 Mdot
.886 .19173 Mdot
.886 .19204 Mdot
.886 .19213 Mdot
.886 .19245 Mdot
.886 .19258 Mdot
.886 .19266 Mdot
.886 .19337 Mdot
.886 .1943 Mdot
.886 .19451 Mdot
.886 .19481 Mdot
.886 .19542 Mdot
.886 .19657 Mdot
.886 .1972 Mdot
.886 .19729 Mdot
.886 .19754 Mdot
.886 .19773 Mdot
.886 .19882 Mdot
.886 .19929 Mdot
.886 .19941 Mdot
.886 .20142 Mdot
.886 .20152 Mdot
.886 .20168 Mdot
.886 .2026 Mdot
.886 .20297 Mdot
.886 .2043 Mdot
.886 .20482 Mdot
.886 .20546 Mdot
.886 .20689 Mdot
.886 .20805 Mdot
.886 .20809 Mdot
.886 .20969 Mdot
.886 .2099 Mdot
.886 .21001 Mdot
.886 .21093 Mdot
.886 .21104 Mdot
.886 .21285 Mdot
.886 .21311 Mdot
.886 .21554 Mdot
.886 .21589 Mdot
.886 .21613 Mdot
.886 .21642 Mdot
.886 .2165 Mdot
.886 .21652 Mdot
.886 .21665 Mdot
.886 .2175 Mdot
.886 .21782 Mdot
.886 .21811 Mdot
.886 .21815 Mdot
.886 .21883 Mdot
.886 .21924 Mdot
.886 .21948 Mdot
.886 .21979 Mdot
.886 .22022 Mdot
.886 .22091 Mdot
.886 .22114 Mdot
.886 .22124 Mdot
.886 .22189 Mdot
.886 .222 Mdot
.886 .22299 Mdot
.886 .22351 Mdot
.886 .2239 Mdot
.886 .22489 Mdot
.886 .22596 Mdot
.886 .22603 Mdot
.886 .22608 Mdot
.886 .22616 Mdot
.886 .2267 Mdot
.886 .22707 Mdot
.886 .22739 Mdot
.886 .22764 Mdot
.886 .22765 Mdot
.886 .2281 Mdot
.886 .22819 Mdot
.886 .22839 Mdot
.886 .2292 Mdot
.886 .22965 Mdot
.886 .23054 Mdot
.886 .23083 Mdot
.886 .23127 Mdot
.886 .23203 Mdot
.886 .23306 Mdot
.886 .23313 Mdot
.886 .23416 Mdot
.886 .23451 Mdot
.886 .23466 Mdot
.886 .23476 Mdot
.886 .23533 Mdot
.886 .23557 Mdot
.886 .23608 Mdot
.886 .23609 Mdot
.886 .23687 Mdot
.886 .23691 Mdot
.886 .23692 Mdot
.886 .23728 Mdot
.886 .23762 Mdot
.886 .23763 Mdot
.886 .23792 Mdot
.886 .23837 Mdot
.886 .23967 Mdot
.886 .23969 Mdot
.886 .23982 Mdot
.886 .24011 Mdot
.886 .2411 Mdot
.886 .24283 Mdot
.886 .24383 Mdot
.886 .24519 Mdot
.886 .24599 Mdot
.886 .246 Mdot
.886 .24651 Mdot
.886 .2467 Mdot
.886 .24674 Mdot
.886 .24706 Mdot
.886 .24775 Mdot
.886 .24796 Mdot
.886 .24922 Mdot
.886 .24949 Mdot
.886 .25041 Mdot
.886 .25042 Mdot
.886 .25045 Mdot
.886 .25063 Mdot
.886 .25104 Mdot
.886 .2511 Mdot
.886 .25125 Mdot
.886 .25183 Mdot
.886 .25292 Mdot
.886 .25302 Mdot
.886 .25306 Mdot
.886 .25315 Mdot
.886 .25412 Mdot
.886 .25486 Mdot
.886 .25506 Mdot
.886 .25511 Mdot
.886 .25557 Mdot
.886 .25588 Mdot
.886 .25601 Mdot
.886 .25609 Mdot
.886 .25638 Mdot
.886 .25821 Mdot
.886 .25851 Mdot
.886 .25878 Mdot
.886 .25961 Mdot
.886 .26085 Mdot
.886 .26172 Mdot
.886 .2621 Mdot
.886 .26253 Mdot
.886 .26284 Mdot
.886 .26377 Mdot
.886 .26388 Mdot
.886 .265 Mdot
.886 .2654 Mdot
.886 .2661 Mdot
.886 .26646 Mdot
.886 .26748 Mdot
.886 .26794 Mdot
.886 .26887 Mdot
.886 .26899 Mdot
.886 .26966 Mdot
.886 .27078 Mdot
.886 .27085 Mdot
.886 .27141 Mdot
.886 .27176 Mdot
.886 .27214 Mdot
.886 .27232 Mdot
.886 .27252 Mdot
.886 .27259 Mdot
.886 .27297 Mdot
.886 .27344 Mdot
.886 .27425 Mdot
.886 .27468 Mdot
.886 .27587 Mdot
.886 .27666 Mdot
.886 .2769 Mdot
.886 .27776 Mdot
.886 .27812 Mdot
.886 .2792 Mdot
.886 .2796 Mdot
.886 .27992 Mdot
.886 .28014 Mdot
.886 .28103 Mdot
.886 .28167 Mdot
.886 .28198 Mdot
.886 .2822 Mdot
.886 .28234 Mdot
.886 .28252 Mdot
.886 .28286 Mdot
.886 .28287 Mdot
.886 .28307 Mdot
.886 .28334 Mdot
.886 .28338 Mdot
.886 .28339 Mdot
.886 .28351 Mdot
.886 .28358 Mdot
.886 .28369 Mdot
.886 .28455 Mdot
.886 .28513 Mdot
.886 .28516 Mdot
.886 .28607 Mdot
.886 .2869 Mdot
.886 .28727 Mdot
.886 .28819 Mdot
.886 .28954 Mdot
.886 .2901 Mdot
.886 .29076 Mdot
.886 .29118 Mdot
.886 .29128 Mdot
.886 .29145 Mdot
.886 .29226 Mdot
.886 .29242 Mdot
.886 .29249 Mdot
.886 .29252 Mdot
.886 .29252 Mdot
.886 .29291 Mdot
.886 .2931 Mdot
.886 .29369 Mdot
.886 .29376 Mdot
.886 .29428 Mdot
.886 .29458 Mdot
.886 .29463 Mdot
.886 .29491 Mdot
.886 .29504 Mdot
.886 .29557 Mdot
.886 .29583 Mdot
.886 .29679 Mdot
.886 .29772 Mdot
.886 .29905 Mdot
.886 .29931 Mdot
.886 .29942 Mdot
.886 .29946 Mdot
.886 .29952 Mdot
.886 .29958 Mdot
.886 .29995 Mdot
.886 .30093 Mdot
.886 .30131 Mdot
.886 .30222 Mdot
.886 .30247 Mdot
.886 .30289 Mdot
.886 .30306 Mdot
.886 .30384 Mdot
.886 .30436 Mdot
.886 .30449 Mdot
.886 .30517 Mdot
.886 .30529 Mdot
.886 .30546 Mdot
.886 .30608 Mdot
.886 .30746 Mdot
.886 .30759 Mdot
.886 .30772 Mdot
.886 .30815 Mdot
.886 .3084 Mdot
.886 .30881 Mdot
.886 .3091 Mdot
.886 .30965 Mdot
.886 .30972 Mdot
.886 .30973 Mdot
.886 .31001 Mdot
.886 .31009 Mdot
.886 .31011 Mdot
.886 .31129 Mdot
.886 .31143 Mdot
.886 .31153 Mdot
.886 .31153 Mdot
.886 .31168 Mdot
.886 .31174 Mdot
.886 .31186 Mdot
.886 .31217 Mdot
.886 .3122 Mdot
.886 .31274 Mdot
.886 .3146 Mdot
.886 .31494 Mdot
.886 .31511 Mdot
.886 .31561 Mdot
.886 .31598 Mdot
.886 .31742 Mdot
.886 .31788 Mdot
.886 .31794 Mdot
.886 .31808 Mdot
.886 .31824 Mdot
.886 .31928 Mdot
.886 .31935 Mdot
.886 .31984 Mdot
.886 .31994 Mdot
.886 .32003 Mdot
.886 .32005 Mdot
.886 .32051 Mdot
.886 .32066 Mdot
.886 .32135 Mdot
.886 .32145 Mdot
.886 .32148 Mdot
.886 .32162 Mdot
.886 .32174 Mdot
.886 .32204 Mdot
.886 .3221 Mdot
.886 .32289 Mdot
.886 .32294 Mdot
.886 .32318 Mdot
.886 .3238 Mdot
.886 .32465 Mdot
.886 .32504 Mdot
.886 .32624 Mdot
.886 .32658 Mdot
.886 .3267 Mdot
.886 .32699 Mdot
.886 .32744 Mdot
.886 .32773 Mdot
.886 .32824 Mdot
.886 .32834 Mdot
.886 .32839 Mdot
.886 .32841 Mdot
.886 .32894 Mdot
.886 .329 Mdot
.886 .3291 Mdot
.886 .32966 Mdot
.886 .32989 Mdot
.886 .32997 Mdot
.886 .33003 Mdot
.886 .33037 Mdot
.886 .33052 Mdot
.886 .33056 Mdot
.886 .33123 Mdot
.886 .33129 Mdot
.886 .33158 Mdot
.886 .3317 Mdot
.886 .33228 Mdot
.886 .33294 Mdot
.886 .33331 Mdot
.886 .33384 Mdot
.886 .3339 Mdot
.886 .33394 Mdot
.886 .33492 Mdot
.886 .33598 Mdot
.886 .33643 Mdot
.886 .33675 Mdot
.886 .33696 Mdot
.886 .33748 Mdot
.886 .33751 Mdot
.886 .33776 Mdot
.886 .33807 Mdot
.886 .33824 Mdot
.886 .33868 Mdot
.886 .33902 Mdot
.886 .33937 Mdot
.886 .33956 Mdot
.886 .34048 Mdot
.886 .34071 Mdot
.886 .34095 Mdot
.886 .34179 Mdot
.886 .342 Mdot
.886 .34338 Mdot
.886 .34384 Mdot
.886 .3454 Mdot
.886 .34556 Mdot
.886 .34562 Mdot
.886 .34564 Mdot
.886 .34574 Mdot
.886 .34603 Mdot
.886 .347 Mdot
.886 .3476 Mdot
.886 .34765 Mdot
.886 .3483 Mdot
.886 .34871 Mdot
.886 .34929 Mdot
.886 .35067 Mdot
.886 .35109 Mdot
.886 .35158 Mdot
.886 .35239 Mdot
.886 .35272 Mdot
.886 .35331 Mdot
.886 .35372 Mdot
.886 .35378 Mdot
.886 .35491 Mdot
.886 .35516 Mdot
.886 .35524 Mdot
.886 .3562 Mdot
.886 .35676 Mdot
.886 .35731 Mdot
.886 .35737 Mdot
.886 .35787 Mdot
.886 .35884 Mdot
.886 .35926 Mdot
.886 .35944 Mdot
.886 .36018 Mdot
.886 .36021 Mdot
.886 .36022 Mdot
.886 .3604 Mdot
.886 .36059 Mdot
.886 .36078 Mdot
.886 .36102 Mdot
.886 .36127 Mdot
.886 .36157 Mdot
.886 .3623 Mdot
.886 .36241 Mdot
.886 .36242 Mdot
.886 .36244 Mdot
.886 .36258 Mdot
.886 .36261 Mdot
.886 .36424 Mdot
.886 .36501 Mdot
.886 .36506 Mdot
.886 .3654 Mdot
.886 .36567 Mdot
.886 .36569 Mdot
.886 .36581 Mdot
.886 .36582 Mdot
.886 .36627 Mdot
.886 .36627 Mdot
.886 .36648 Mdot
.886 .36665 Mdot
.886 .36741 Mdot
.886 .36769 Mdot
.886 .36918 Mdot
.886 .3694 Mdot
.886 .36952 Mdot
.886 .36998 Mdot
.886 .37057 Mdot
.886 .37106 Mdot
.886 .3711 Mdot
.886 .37119 Mdot
.886 .37159 Mdot
.886 .37162 Mdot
.886 .37183 Mdot
.886 .37214 Mdot
.886 .37227 Mdot
.886 .37232 Mdot
.886 .37254 Mdot
.886 .37406 Mdot
.886 .3743 Mdot
.886 .37453 Mdot
.886 .37454 Mdot
.886 .37462 Mdot
.886 .37514 Mdot
.886 .37519 Mdot
.886 .37549 Mdot
.886 .37641 Mdot
.886 .37705 Mdot
.886 .37713 Mdot
.886 .37713 Mdot
.886 .37757 Mdot
.886 .37776 Mdot
.886 .37811 Mdot
.886 .37887 Mdot
.886 .38009 Mdot
.886 .38017 Mdot
.886 .3805 Mdot
.886 .38067 Mdot
.886 .38133 Mdot
.886 .38153 Mdot
.886 .38183 Mdot
.886 .38203 Mdot
.886 .38221 Mdot
.886 .38244 Mdot
.886 .38306 Mdot
.886 .38343 Mdot
.886 .38351 Mdot
.886 .38352 Mdot
.886 .38356 Mdot
.886 .3837 Mdot
.886 .38377 Mdot
.886 .38415 Mdot
.886 .3847 Mdot
.886 .38524 Mdot
.886 .3854 Mdot
.886 .38547 Mdot
.886 .38633 Mdot
.886 .38664 Mdot
.886 .38714 Mdot
.886 .38716 Mdot
.886 .3885 Mdot
.886 .38878 Mdot
.886 .38905 Mdot
.886 .38917 Mdot
.886 .38919 Mdot
.886 .3892 Mdot
.886 .38921 Mdot
.886 .38925 Mdot
.886 .3894 Mdot
.886 .38982 Mdot
.886 .39009 Mdot
.886 .39036 Mdot
.886 .39078 Mdot
.886 .39087 Mdot
.886 .391 Mdot
.886 .391 Mdot
.886 .39151 Mdot
.886 .39154 Mdot
.886 .39158 Mdot
.886 .39202 Mdot
.886 .39204 Mdot
.886 .39233 Mdot
.886 .3924 Mdot
.886 .39245 Mdot
.886 .39284 Mdot
.886 .39299 Mdot
.886 .39334 Mdot
.886 .39335 Mdot
.886 .39335 Mdot
.886 .39358 Mdot
.886 .39374 Mdot
.886 .39449 Mdot
.886 .39479 Mdot
.886 .39496 Mdot
.886 .39545 Mdot
.886 .39558 Mdot
.886 .39619 Mdot
.886 .39645 Mdot
.886 .39653 Mdot
.886 .39655 Mdot
.886 .39655 Mdot
.886 .3966 Mdot
.886 .39681 Mdot
.886 .39716 Mdot
.886 .39729 Mdot
.886 .39767 Mdot
.886 .39778 Mdot
.886 .39844 Mdot
.886 .3998 Mdot
.886 .40015 Mdot
.886 .4002 Mdot
.886 .40108 Mdot
.886 .40161 Mdot
.886 .40162 Mdot
.886 .40175 Mdot
.886 .40314 Mdot
.886 .40328 Mdot
.886 .40356 Mdot
.886 .40358 Mdot
.886 .40419 Mdot
.886 .40445 Mdot
.886 .40452 Mdot
.886 .40464 Mdot
.886 .40548 Mdot
.886 .40564 Mdot
.886 .40607 Mdot
.886 .40616 Mdot
.886 .40628 Mdot
.886 .40654 Mdot
.886 .40661 Mdot
.886 .40662 Mdot
.886 .40677 Mdot
.886 .40697 Mdot
.886 .40699 Mdot
.886 .40743 Mdot
.886 .40837 Mdot
.886 .40844 Mdot
.886 .40845 Mdot
.886 .40853 Mdot
.886 .40893 Mdot
.886 .40911 Mdot
.886 .40925 Mdot
.886 .4096 Mdot
.886 .4097 Mdot
.886 .40972 Mdot
.886 .41014 Mdot
.886 .41024 Mdot
.886 .41048 Mdot
.886 .41102 Mdot
.886 .41165 Mdot
.886 .41197 Mdot
.886 .41255 Mdot
.886 .41269 Mdot
.886 .41333 Mdot
.886 .41336 Mdot
.886 .4136 Mdot
.886 .41412 Mdot
.886 .41485 Mdot
.886 .41587 Mdot
.886 .4162 Mdot
.886 .41682 Mdot
.886 .41716 Mdot
.886 .41793 Mdot
.886 .41794 Mdot
.886 .41806 Mdot
.886 .41894 Mdot
.886 .4192 Mdot
.886 .42071 Mdot
.886 .42084 Mdot
.886 .42136 Mdot
.886 .42146 Mdot
.886 .42237 Mdot
.886 .42251 Mdot
.886 .42253 Mdot
.886 .42294 Mdot
.886 .42313 Mdot
.886 .42338 Mdot
.886 .42453 Mdot
.886 .42455 Mdot
.886 .42546 Mdot
.886 .42579 Mdot
.886 .42586 Mdot
.886 .42605 Mdot
.886 .42643 Mdot
.886 .42646 Mdot
.886 .42654 Mdot
.886 .42677 Mdot
.886 .42731 Mdot
.886 .42765 Mdot
.886 .42769 Mdot
.886 .42774 Mdot
.886 .42803 Mdot
.886 .42845 Mdot
.886 .42861 Mdot
.886 .42868 Mdot
.886 .42955 Mdot
.886 .43025 Mdot
.886 .4306 Mdot
.886 .43074 Mdot
.886 .43141 Mdot
.886 .43163 Mdot
.886 .43202 Mdot
.886 .43237 Mdot
.886 .43238 Mdot
.886 .43243 Mdot
.886 .43276 Mdot
.886 .43348 Mdot
.886 .43359 Mdot
.886 .43385 Mdot
.886 .43466 Mdot
.886 .43487 Mdot
.886 .43516 Mdot
.886 .43649 Mdot
.886 .4368 Mdot
.886 .43681 Mdot
.886 .43699 Mdot
.886 .43705 Mdot
.886 .43718 Mdot
.886 .43718 Mdot
.886 .43723 Mdot
.886 .43798 Mdot
.886 .43799 Mdot
.886 .4382 Mdot
.886 .43824 Mdot
.886 .43871 Mdot
.886 .43894 Mdot
.886 .43933 Mdot
.886 .4394 Mdot
.886 .44025 Mdot
.886 .4406 Mdot
.886 .4407 Mdot
.886 .44077 Mdot
.886 .44152 Mdot
.886 .44205 Mdot
.886 .44229 Mdot
.886 .44243 Mdot
.886 .44295 Mdot
.886 .44371 Mdot
.886 .44395 Mdot
.886 .44399 Mdot
.886 .44401 Mdot
.886 .44422 Mdot
.886 .44549 Mdot
.886 .44604 Mdot
.886 .44618 Mdot
.886 .44648 Mdot
.886 .44671 Mdot
.886 .44691 Mdot
.886 .44721 Mdot
.886 .44724 Mdot
.886 .44758 Mdot
.886 .4479 Mdot
.886 .44792 Mdot
.886 .44796 Mdot
.886 .44866 Mdot
.886 .44927 Mdot
.886 .44959 Mdot
.886 .45035 Mdot
.886 .45086 Mdot
.886 .45206 Mdot
.886 .4524 Mdot
.886 .45295 Mdot
.886 .45306 Mdot
.886 .45308 Mdot
.886 .45385 Mdot
.886 .45403 Mdot
.886 .45439 Mdot
.886 .45501 Mdot
.886 .45603 Mdot
.886 .45623 Mdot
.886 .45672 Mdot
.886 .45685 Mdot
.886 .4573 Mdot
.886 .45821 Mdot
.886 .45894 Mdot
.886 .4593 Mdot
.886 .45941 Mdot
.886 .46013 Mdot
.886 .46017 Mdot
.886 .4608 Mdot
.886 .46118 Mdot
.886 .46177 Mdot
.886 .46261 Mdot
.886 .46321 Mdot
.886 .46344 Mdot
.886 .46407 Mdot
.886 .46483 Mdot
.886 .46507 Mdot
.886 .46529 Mdot
.886 .46648 Mdot
.886 .46727 Mdot
.886 .4683 Mdot
.886 .46846 Mdot
.886 .46858 Mdot
.886 .46901 Mdot
.886 .46957 Mdot
.886 .47017 Mdot
.886 .47019 Mdot
.886 .47025 Mdot
.886 .47087 Mdot
.886 .47119 Mdot
.886 .47131 Mdot
.886 .47154 Mdot
.886 .47166 Mdot
.886 .47234 Mdot
.886 .47305 Mdot
.886 .47317 Mdot
.886 .47356 Mdot
.886 .47374 Mdot
.886 .47376 Mdot
.886 .47387 Mdot
.886 .47416 Mdot
.886 .47461 Mdot
.886 .47538 Mdot
.886 .47692 Mdot
.886 .47748 Mdot
.886 .47773 Mdot
.886 .47888 Mdot
.886 .47931 Mdot
.886 .48018 Mdot
.886 .48056 Mdot
.886 .48084 Mdot
.886 .48146 Mdot
.886 .48204 Mdot
.886 .48247 Mdot
.886 .48288 Mdot
.886 .48338 Mdot
.886 .4841 Mdot
.886 .48451 Mdot
.886 .48466 Mdot
.886 .48484 Mdot
.886 .48505 Mdot
.886 .48546 Mdot
.886 .48607 Mdot
.886 .48663 Mdot
.886 .48685 Mdot
.886 .48714 Mdot
.886 .4877 Mdot
.886 .48776 Mdot
.886 .48813 Mdot
.886 .48819 Mdot
.886 .48832 Mdot
.886 .4887 Mdot
.886 .48895 Mdot
.886 .48912 Mdot
.886 .48926 Mdot
.886 .48949 Mdot
.886 .48987 Mdot
.886 .48989 Mdot
.886 .49006 Mdot
.886 .49024 Mdot
.886 .49072 Mdot
.886 .49079 Mdot
.886 .49081 Mdot
.886 .49085 Mdot
.886 .49101 Mdot
.886 .49115 Mdot
.886 .49135 Mdot
.886 .49272 Mdot
.886 .49286 Mdot
.886 .49388 Mdot
.886 .49395 Mdot
.886 .49447 Mdot
.886 .49453 Mdot
.886 .49465 Mdot
.886 .49555 Mdot
.886 .49557 Mdot
.886 .49623 Mdot
.886 .49703 Mdot
.886 .4974 Mdot
.886 .49769 Mdot
.886 .49844 Mdot
.886 .49865 Mdot
.886 .49916 Mdot
.886 .49926 Mdot
.886 .49931 Mdot
.886 .50045 Mdot
.886 .50051 Mdot
.886 .50078 Mdot
.886 .5014 Mdot
.886 .50151 Mdot
.886 .50164 Mdot
.886 .5017 Mdot
.886 .50205 Mdot
.886 .5027 Mdot
.886 .50305 Mdot
.886 .50321 Mdot
.886 .50333 Mdot
.886 .50386 Mdot
.886 .50426 Mdot
.886 .5043 Mdot
.886 .50438 Mdot
.886 .50456 Mdot
.886 .50461 Mdot
.886 .50478 Mdot
.886 .50508 Mdot
.886 .50547 Mdot
.886 .50597 Mdot
.886 .50653 Mdot
.886 .50678 Mdot
.886 .5068 Mdot
.886 .50694 Mdot
.886 .50698 Mdot
.886 .50699 Mdot
.886 .50729 Mdot
.886 .5075 Mdot
.886 .50768 Mdot
.886 .50801 Mdot
.886 .50811 Mdot
.886 .50907 Mdot
.886 .50917 Mdot
.886 .5101 Mdot
.886 .51023 Mdot
.886 .51063 Mdot
.886 .51072 Mdot
.886 .51092 Mdot
.886 .51123 Mdot
.886 .51145 Mdot
.886 .51239 Mdot
.886 .51243 Mdot
.886 .51285 Mdot
.886 .51353 Mdot
.886 .51396 Mdot
.886 .51404 Mdot
.886 .51455 Mdot
.886 .51544 Mdot
.886 .51555 Mdot
.886 .51608 Mdot
.886 .5162 Mdot
.886 .51629 Mdot
.886 .51655 Mdot
.886 .5166 Mdot
.886 .51677 Mdot
.886 .51799 Mdot
.886 .51826 Mdot
.886 .51856 Mdot
.886 .51902 Mdot
.886 .51908 Mdot
.886 .51912 Mdot
.886 .51921 Mdot
.886 .51928 Mdot
.886 .51928 Mdot
.886 .51939 Mdot
.886 .51945 Mdot
.886 .51949 Mdot
.886 .52015 Mdot
.886 .52032 Mdot
.886 .52045 Mdot
.886 .52188 Mdot
.886 .52228 Mdot
.886 .52255 Mdot
.886 .52257 Mdot
.886 .52282 Mdot
.886 .52293 Mdot
.886 .52374 Mdot
.886 .52418 Mdot
.886 .52462 Mdot
.886 .52536 Mdot
.886 .52566 Mdot
.886 .52629 Mdot
.886 .52695 Mdot
.886 .52704 Mdot
.886 .52783 Mdot
.886 .52797 Mdot
.886 .52814 Mdot
.886 .5282 Mdot
.886 .52874 Mdot
.886 .52939 Mdot
.886 .5296 Mdot
.886 .52962 Mdot
.886 .52991 Mdot
.886 .53102 Mdot
.886 .53203 Mdot
.886 .53299 Mdot
.886 .53303 Mdot
.886 .53345 Mdot
.886 .53359 Mdot
.886 .53369 Mdot
.886 .5338 Mdot
.886 .53391 Mdot
.886 .53392 Mdot
.886 .53418 Mdot
.886 .53418 Mdot
.886 .53434 Mdot
.886 .5346 Mdot
.886 .53468 Mdot
.886 .53512 Mdot
.886 .53585 Mdot
.886 .53637 Mdot
.886 .53669 Mdot
.886 .53672 Mdot
.886 .53687 Mdot
.886 .53734 Mdot
.886 .53736 Mdot
.886 .53738 Mdot
.888 .13278 Mdot
.888 .13454 Mdot
.888 .13479 Mdot
.888 .13489 Mdot
.888 .13492 Mdot
.888 .13602 Mdot
.888 .13613 Mdot
.888 .13651 Mdot
.888 .13739 Mdot
.888 .13785 Mdot
.888 .13998 Mdot
.888 .14037 Mdot
.888 .14089 Mdot
.888 .14093 Mdot
.888 .14303 Mdot
.888 .14397 Mdot
.888 .14428 Mdot
.888 .14653 Mdot
.888 .14692 Mdot
.888 .14748 Mdot
.888 .14896 Mdot
.888 .1494 Mdot
.888 .15028 Mdot
.888 .15048 Mdot
.888 .1505 Mdot
.888 .15054 Mdot
.888 .15072 Mdot
.888 .15112 Mdot
.888 .15162 Mdot
.888 .15247 Mdot
.888 .15293 Mdot
.888 .15482 Mdot
.888 .15496 Mdot
.888 .15584 Mdot
.888 .15643 Mdot
.888 .15676 Mdot
.888 .15701 Mdot
.888 .1576 Mdot
.888 .15842 Mdot
.888 .1593 Mdot
.888 .15956 Mdot
.888 .15977 Mdot
.888 .16069 Mdot
.888 .1607 Mdot
.888 .16086 Mdot
.888 .16177 Mdot
.888 .16199 Mdot
.888 .16256 Mdot
.888 .16373 Mdot
.888 .16383 Mdot
.888 .16485 Mdot
.888 .16663 Mdot
.888 .1668 Mdot
.888 .16741 Mdot
.888 .16779 Mdot
.888 .16984 Mdot
.888 .17009 Mdot
.888 .17028 Mdot
.888 .17057 Mdot
.888 .17085 Mdot
.888 .17085 Mdot
.888 .17087 Mdot
.888 .17152 Mdot
.888 .17165 Mdot
.888 .17239 Mdot
.888 .17269 Mdot
.888 .17305 Mdot
.888 .17516 Mdot
.888 .17551 Mdot
.888 .1759 Mdot
.888 .1761 Mdot
.888 .17657 Mdot
.888 .17741 Mdot
.888 .17748 Mdot
.888 .17752 Mdot
.888 .17806 Mdot
.888 .17923 Mdot
.888 .17978 Mdot
.888 .1803 Mdot
.888 .18068 Mdot
.888 .18132 Mdot
.888 .18293 Mdot
.888 .18339 Mdot
.888 .18411 Mdot
.888 .1843 Mdot
.888 .18648 Mdot
.888 .18763 Mdot
.888 .18773 Mdot
.888 .18785 Mdot
.888 .18787 Mdot
.888 .18942 Mdot
.888 .18949 Mdot
.888 .18989 Mdot
.888 .19106 Mdot
.888 .19156 Mdot
.888 .19176 Mdot
.888 .19211 Mdot
.888 .19229 Mdot
.888 .19288 Mdot
.888 .19332 Mdot
.888 .19342 Mdot
.888 .19352 Mdot
.888 .19505 Mdot
.888 .19538 Mdot
.888 .1962 Mdot
.888 .1964 Mdot
.888 .19718 Mdot
.888 .19801 Mdot
.888 .19875 Mdot
.888 .19878 Mdot
.888 .19972 Mdot
.888 .19977 Mdot
.888 .20036 Mdot
.888 .20198 Mdot
.888 .20216 Mdot
.888 .20273 Mdot
.888 .20325 Mdot
.888 .20403 Mdot
.888 .205 Mdot
.888 .20571 Mdot
.888 .20699 Mdot
.888 .20711 Mdot
.888 .20798 Mdot
.888 .20874 Mdot
.888 .20937 Mdot
.888 .21052 Mdot
.888 .21149 Mdot
.888 .21183 Mdot
.888 .21229 Mdot
.888 .21367 Mdot
.888 .21448 Mdot
.888 .21509 Mdot
.888 .21531 Mdot
.888 .21579 Mdot
.888 .21723 Mdot
.888 .218 Mdot
.888 .21809 Mdot
.888 .21831 Mdot
.888 .21852 Mdot
.888 .21915 Mdot
.888 .21941 Mdot
.888 .21949 Mdot
.888 .22022 Mdot
.888 .22069 Mdot
.888 .22147 Mdot
.888 .22264 Mdot
.888 .2238 Mdot
.888 .22416 Mdot
.888 .22439 Mdot
.888 .22453 Mdot
.888 .22521 Mdot
.888 .22618 Mdot
.888 .22713 Mdot
.888 .22716 Mdot
.888 .22753 Mdot
.888 .22775 Mdot
.888 .22797 Mdot
.888 .22815 Mdot
.888 .2282 Mdot
.888 .22842 Mdot
.888 .22902 Mdot
.888 .22909 Mdot
.888 .22978 Mdot
.888 .23015 Mdot
.888 .23035 Mdot
.888 .23059 Mdot
.888 .23103 Mdot
.888 .23256 Mdot
.888 .23258 Mdot
.888 .23259 Mdot
.888 .23272 Mdot
.888 .23311 Mdot
.888 .2334 Mdot
.888 .23342 Mdot
.888 .23352 Mdot
.888 .23429 Mdot
.888 .23448 Mdot
.888 .23461 Mdot
.888 .23561 Mdot
.888 .23673 Mdot
.888 .23692 Mdot
.888 .23719 Mdot
.888 .23746 Mdot
.888 .23787 Mdot
.888 .23799 Mdot
.888 .23817 Mdot
.888 .2383 Mdot
.888 .23873 Mdot
.888 .23879 Mdot
.888 .23887 Mdot
.888 .23925 Mdot
.888 .24127 Mdot
.888 .24157 Mdot
.888 .24174 Mdot
.888 .24261 Mdot
.888 .24383 Mdot
.888 .24428 Mdot
.888 .24473 Mdot
.888 .24474 Mdot
.888 .24482 Mdot
.888 .24684 Mdot
.888 .24738 Mdot
.888 .24791 Mdot
.888 .24876 Mdot
.888 .24882 Mdot
.888 .24905 Mdot
.888 .24933 Mdot
.888 .24951 Mdot
.888 .24956 Mdot
.888 .24991 Mdot
.888 .2505 Mdot
.888 .25064 Mdot
.888 .25108 Mdot
.888 .25109 Mdot
.888 .25164 Mdot
.888 .25168 Mdot
.888 .25228 Mdot
.888 .25255 Mdot
.888 .25258 Mdot
.888 .25313 Mdot
.888 .25383 Mdot
.888 .25392 Mdot
.888 .25487 Mdot
.888 .25523 Mdot
.888 .25548 Mdot
.888 .25583 Mdot
.888 .25586 Mdot
.888 .25595 Mdot
.888 .25626 Mdot
.888 .25697 Mdot
.888 .25746 Mdot
.888 .2575 Mdot
.888 .25781 Mdot
.888 .25785 Mdot
.888 .25936 Mdot
.888 .25983 Mdot
.888 .26019 Mdot
.888 .26166 Mdot
.888 .26207 Mdot
.888 .26217 Mdot
.888 .26284 Mdot
.888 .26354 Mdot
.888 .26379 Mdot
.888 .26492 Mdot
.888 .26511 Mdot
.888 .26534 Mdot
.888 .2654 Mdot
.888 .26622 Mdot
.888 .26641 Mdot
.888 .26675 Mdot
.888 .267 Mdot
.888 .26742 Mdot
.888 .26752 Mdot
.888 .26758 Mdot
.888 .26824 Mdot
.888 .26848 Mdot
.888 .26861 Mdot
.888 .26919 Mdot
.888 .26994 Mdot
.888 .2715 Mdot
.888 .27158 Mdot
.888 .27179 Mdot
.888 .27196 Mdot
.888 .27196 Mdot
.888 .27234 Mdot
.888 .27261 Mdot
.888 .2727 Mdot
.888 .27314 Mdot
.888 .27331 Mdot
.888 .27397 Mdot
.888 .27398 Mdot
.888 .27426 Mdot
.888 .27493 Mdot
.888 .27588 Mdot
.888 .27628 Mdot
.888 .27645 Mdot
.888 .27651 Mdot
.888 .27687 Mdot
.888 .27719 Mdot
.888 .27729 Mdot
.888 .27766 Mdot
.888 .27784 Mdot
.888 .27872 Mdot
.888 .27894 Mdot
.888 .27936 Mdot
.888 .27955 Mdot
.888 .27986 Mdot
.888 .28135 Mdot
.888 .28198 Mdot
.888 .28209 Mdot
.888 .28229 Mdot
.888 .28338 Mdot
.888 .28357 Mdot
.888 .28426 Mdot
.888 .28452 Mdot
.888 .28482 Mdot
.888 .28519 Mdot
.888 .2859 Mdot
.888 .28635 Mdot
.888 .28657 Mdot
.888 .28688 Mdot
.888 .28823 Mdot
.888 .28855 Mdot
.888 .28936 Mdot
.888 .29021 Mdot
.888 .29028 Mdot
.888 .29041 Mdot
.888 .29066 Mdot
.888 .29083 Mdot
.888 .29099 Mdot
.888 .29151 Mdot
.888 .292 Mdot
.888 .29201 Mdot
.888 .29205 Mdot
.888 .29208 Mdot
.888 .29314 Mdot
.888 .2932 Mdot
.888 .29342 Mdot
.888 .29457 Mdot
.888 .29474 Mdot
.888 .29529 Mdot
.888 .29559 Mdot
.888 .29573 Mdot
.888 .2958 Mdot
.888 .29592 Mdot
.888 .2967 Mdot
.888 .29682 Mdot
.888 .29739 Mdot
.888 .29772 Mdot
.888 .29837 Mdot
.888 .29849 Mdot
.888 .29966 Mdot
.888 .30021 Mdot
.888 .30028 Mdot
.888 .30062 Mdot
.888 .30091 Mdot
.888 .30098 Mdot
.888 .30134 Mdot
.888 .3016 Mdot
.888 .30179 Mdot
.888 .30187 Mdot
.888 .30197 Mdot
.888 .30216 Mdot
.888 .30308 Mdot
.888 .30366 Mdot
.888 .30378 Mdot
.888 .30385 Mdot
.888 .30386 Mdot
.888 .30392 Mdot
.888 .30481 Mdot
.888 .30499 Mdot
.888 .30582 Mdot
.888 .3069 Mdot
.888 .30786 Mdot
.888 .30801 Mdot
.888 .30829 Mdot
.888 .30844 Mdot
.888 .3088 Mdot
.888 .30883 Mdot
.888 .30947 Mdot
.888 .31048 Mdot
.888 .3106 Mdot
.888 .31098 Mdot
.888 .31221 Mdot
.888 .31233 Mdot
.888 .31251 Mdot
.888 .31317 Mdot
.888 .31347 Mdot
.888 .31428 Mdot
.888 .31505 Mdot
.888 .31519 Mdot
.888 .31555 Mdot
.888 .3159 Mdot
.888 .31616 Mdot
.888 .31691 Mdot
.888 .31695 Mdot
.888 .31833 Mdot
.888 .31877 Mdot
.888 .31882 Mdot
.888 .31936 Mdot
.888 .31977 Mdot
.888 .32009 Mdot
.888 .32065 Mdot
.888 .32071 Mdot
.888 .32175 Mdot
.888 .32181 Mdot
.888 .3219 Mdot
.888 .32199 Mdot
.888 .32199 Mdot
.888 .3222 Mdot
.888 .32224 Mdot
.888 .32248 Mdot
.888 .32336 Mdot
.888 .32407 Mdot
.888 .32409 Mdot
.888 .32428 Mdot
.888 .32499 Mdot
.888 .32511 Mdot
.888 .32531 Mdot
.888 .32582 Mdot
.888 .32695 Mdot
.888 .3279 Mdot
.888 .32803 Mdot
.888 .32862 Mdot
.888 .32879 Mdot
.888 .32915 Mdot
.888 .32966 Mdot
.888 .32977 Mdot
.888 .33009 Mdot
.888 .33034 Mdot
.888 .3306 Mdot
.888 .33085 Mdot
.888 .33114 Mdot
.888 .33135 Mdot
.888 .33186 Mdot
.888 .33192 Mdot
.888 .3321 Mdot
.888 .33227 Mdot
.888 .33345 Mdot
.888 .33376 Mdot
.888 .33401 Mdot
.888 .33498 Mdot
.888 .33557 Mdot
.888 .33609 Mdot
.888 .33624 Mdot
.888 .3367 Mdot
.888 .33694 Mdot
.888 .33697 Mdot
.888 .33704 Mdot
.888 .33739 Mdot
.888 .33765 Mdot
.888 .33779 Mdot
.888 .33841 Mdot
.888 .33878 Mdot
.888 .33889 Mdot
.888 .33901 Mdot
.888 .33923 Mdot
.888 .33984 Mdot
.888 .34025 Mdot
.888 .34043 Mdot
.888 .34093 Mdot
.888 .34157 Mdot
.888 .34161 Mdot
.888 .34183 Mdot
.888 .34186 Mdot
.888 .34217 Mdot
.888 .34328 Mdot
.888 .34334 Mdot
.888 .34338 Mdot
.888 .34368 Mdot
.888 .34432 Mdot
.888 .34441 Mdot
.888 .34642 Mdot
.888 .34687 Mdot
.888 .34695 Mdot
.888 .34729 Mdot
.888 .34762 Mdot
.888 .34791 Mdot
.888 .3483 Mdot
.888 .34863 Mdot
.888 .34874 Mdot
.888 .34946 Mdot
.888 .34956 Mdot
.888 .35094 Mdot
.888 .35266 Mdot
.888 .35287 Mdot
.888 .35393 Mdot
.888 .35425 Mdot
.888 .35442 Mdot
.888 .35499 Mdot
.888 .35547 Mdot
.888 .35549 Mdot
.888 .35571 Mdot
.888 .35591 Mdot
.888 .35619 Mdot
.888 .35626 Mdot
.888 .35641 Mdot
.888 .35726 Mdot
.888 .35767 Mdot
.888 .35795 Mdot
.888 .35824 Mdot
.888 .35861 Mdot
.888 .35878 Mdot
.888 .35931 Mdot
.888 .35986 Mdot
.888 .3599 Mdot
.888 .36043 Mdot
.888 .36076 Mdot
.888 .36122 Mdot
.888 .36161 Mdot
.888 .36211 Mdot
.888 .36222 Mdot
.888 .36246 Mdot
.888 .363 Mdot
.888 .36323 Mdot
.888 .36351 Mdot
.888 .36418 Mdot
.888 .36478 Mdot
.888 .36562 Mdot
.888 .36574 Mdot
.888 .36642 Mdot
.888 .3669 Mdot
.888 .36806 Mdot
.888 .36891 Mdot
.888 .36908 Mdot
.888 .36931 Mdot
.888 .3695 Mdot
.888 .36991 Mdot
.888 .37058 Mdot
.888 .37096 Mdot
.888 .37182 Mdot
.888 .37234 Mdot
.888 .37264 Mdot
.888 .37272 Mdot
.888 .37288 Mdot
.888 .37304 Mdot
.888 .37354 Mdot
.888 .37364 Mdot
.888 .37372 Mdot
.888 .37438 Mdot
.888 .37443 Mdot
.888 .37487 Mdot
.888 .37492 Mdot
.888 .37527 Mdot
.888 .37531 Mdot
.888 .37537 Mdot
.888 .37576 Mdot
.888 .37592 Mdot
.888 .3762 Mdot
.888 .37621 Mdot
.888 .37631 Mdot
.888 .37668 Mdot
.888 .37699 Mdot
.888 .3778 Mdot
.888 .37825 Mdot
.888 .37839 Mdot
.888 .37862 Mdot
.888 .3797 Mdot
.888 .38019 Mdot
.888 .38037 Mdot
.888 .38053 Mdot
.888 .38078 Mdot
.888 .38157 Mdot
.888 .38191 Mdot
.888 .38235 Mdot
.888 .38263 Mdot
.888 .38291 Mdot
.888 .38298 Mdot
.888 .38307 Mdot
.888 .384 Mdot
.888 .38415 Mdot
.888 .38484 Mdot
.888 .38604 Mdot
.888 .38609 Mdot
.888 .38625 Mdot
.888 .38631 Mdot
.888 .38653 Mdot
.888 .38669 Mdot
.888 .3871 Mdot
.888 .3871 Mdot
.888 .38735 Mdot
.888 .38786 Mdot
.888 .38842 Mdot
.888 .38855 Mdot
.888 .38914 Mdot
.888 .38923 Mdot
.888 .38928 Mdot
.888 .38984 Mdot
.888 .39023 Mdot
.888 .39028 Mdot
.888 .39055 Mdot
.888 .39079 Mdot
.888 .39123 Mdot
.888 .39155 Mdot
.888 .39172 Mdot
.888 .39196 Mdot
.888 .39202 Mdot
.888 .3924 Mdot
.888 .3925 Mdot
.888 .39268 Mdot
.888 .39292 Mdot
.888 .39306 Mdot
.888 .39324 Mdot
.888 .39346 Mdot
.888 .39378 Mdot
.888 .39381 Mdot
.888 .39386 Mdot
.888 .39426 Mdot
.888 .39457 Mdot
.888 .395 Mdot
.888 .39532 Mdot
.888 .39545 Mdot
.888 .39548 Mdot
.888 .39557 Mdot
.888 .39627 Mdot
.888 .39666 Mdot
.888 .39727 Mdot
.888 .39732 Mdot
.888 .39736 Mdot
.888 .39752 Mdot
.888 .39768 Mdot
.888 .39811 Mdot
.888 .39856 Mdot
.888 .39879 Mdot
.888 .39889 Mdot
.888 .39978 Mdot
.888 .40069 Mdot
.888 .40113 Mdot
.888 .40114 Mdot
.888 .4016 Mdot
.888 .40164 Mdot
.888 .40166 Mdot
.888 .40186 Mdot
.888 .40189 Mdot
.888 .40214 Mdot
.888 .40254 Mdot
.888 .40258 Mdot
.888 .40263 Mdot
.888 .40292 Mdot
.888 .40301 Mdot
.888 .4031 Mdot
.888 .40314 Mdot
.888 .40331 Mdot
.888 .40468 Mdot
.888 .40502 Mdot
.888 .40515 Mdot
.888 .40525 Mdot
.888 .40637 Mdot
.888 .40665 Mdot
.888 .40703 Mdot
.888 .40829 Mdot
.888 .40844 Mdot
.888 .40857 Mdot
.888 .40901 Mdot
.888 .40907 Mdot
.888 .40936 Mdot
.888 .40958 Mdot
.888 .40983 Mdot
.888 .41032 Mdot
.888 .41034 Mdot
.888 .41095 Mdot
.888 .41104 Mdot
.888 .41125 Mdot
.888 .41157 Mdot
.888 .4118 Mdot
.888 .41237 Mdot
.888 .41256 Mdot
.888 .41268 Mdot
.888 .4128 Mdot
.888 .41281 Mdot
.888 .41308 Mdot
.888 .4134 Mdot
.888 .4135 Mdot
.888 .41428 Mdot
.888 .41619 Mdot
.888 .4166 Mdot
.888 .41685 Mdot
.888 .41707 Mdot
.888 .41761 Mdot
.888 .41765 Mdot
.888 .4179 Mdot
.888 .41909 Mdot
.888 .41945 Mdot
.888 .41964 Mdot
.888 .4203 Mdot
.888 .42047 Mdot
.888 .42049 Mdot
.888 .421 Mdot
.888 .42128 Mdot
.888 .42161 Mdot
.888 .42196 Mdot
.888 .42208 Mdot
.888 .42214 Mdot
.888 .42242 Mdot
.888 .42276 Mdot
.888 .42285 Mdot
.888 .42323 Mdot
.888 .42324 Mdot
.888 .42338 Mdot
.888 .42364 Mdot
.888 .42373 Mdot
.888 .4249 Mdot
.888 .42503 Mdot
.888 .42521 Mdot
.888 .4261 Mdot
.888 .42639 Mdot
.888 .42668 Mdot
.888 .42681 Mdot
.888 .42696 Mdot
.888 .42734 Mdot
.888 .42793 Mdot
.888 .42826 Mdot
.888 .42887 Mdot
.888 .42979 Mdot
.888 .43037 Mdot
.888 .43048 Mdot
.888 .43049 Mdot
.888 .43089 Mdot
.888 .43139 Mdot
.888 .43166 Mdot
.888 .43171 Mdot
.888 .4318 Mdot
.888 .43238 Mdot
.888 .43241 Mdot
.888 .43273 Mdot
.888 .43314 Mdot
.888 .43344 Mdot
.888 .43347 Mdot
.888 .43372 Mdot
.888 .4345 Mdot
.888 .43452 Mdot
.888 .43494 Mdot
.888 .43549 Mdot
.888 .43557 Mdot
.888 .43663 Mdot
.888 .437 Mdot
.888 .4371 Mdot
.888 .43717 Mdot
.888 .43786 Mdot
.888 .43814 Mdot
.888 .43907 Mdot
.888 .43929 Mdot
.888 .43938 Mdot
.888 .43953 Mdot
.888 .44076 Mdot
.888 .44124 Mdot
.888 .44184 Mdot
.888 .44187 Mdot
.888 .44231 Mdot
.888 .44293 Mdot
.888 .44299 Mdot
.888 .44304 Mdot
.888 .44314 Mdot
.888 .44353 Mdot
.888 .4437 Mdot
.888 .44393 Mdot
.888 .44489 Mdot
.888 .44496 Mdot
.888 .44533 Mdot
.888 .44551 Mdot
.888 .44584 Mdot
.888 .4459 Mdot
.888 .44641 Mdot
.888 .44645 Mdot
.888 .44653 Mdot
.888 .4471 Mdot
.888 .44791 Mdot
.888 .4485 Mdot
.888 .44921 Mdot
.888 .44944 Mdot
.888 .44952 Mdot
.888 .45003 Mdot
.888 .45049 Mdot
.888 .45067 Mdot
.888 .45143 Mdot
.888 .45173 Mdot
.888 .45239 Mdot
.888 .45291 Mdot
.888 .4533 Mdot
.888 .45341 Mdot
.888 .45402 Mdot
.888 .45413 Mdot
.888 .45419 Mdot
.888 .45539 Mdot
.888 .45565 Mdot
.888 .4559 Mdot
.888 .45603 Mdot
.888 .45652 Mdot
.888 .45662 Mdot
.888 .45689 Mdot
.888 .45707 Mdot
.888 .45727 Mdot
.888 .4573 Mdot
.888 .45816 Mdot
.888 .45907 Mdot
.888 .45917 Mdot
.888 .45942 Mdot
.888 .45947 Mdot
.888 .45983 Mdot
.888 .45993 Mdot
.888 .46004 Mdot
.888 .46139 Mdot
.888 .46172 Mdot
.888 .46193 Mdot
.888 .4623 Mdot
.888 .46233 Mdot
.888 .46276 Mdot
.888 .46306 Mdot
.888 .46353 Mdot
.888 .46369 Mdot
.888 .4638 Mdot
.888 .46497 Mdot
.888 .46535 Mdot
.888 .4654 Mdot
.888 .46563 Mdot
.888 .46666 Mdot
.888 .4678 Mdot
.888 .46797 Mdot
.888 .46799 Mdot
.888 .46925 Mdot
.888 .46945 Mdot
.888 .47004 Mdot
.888 .47074 Mdot
.888 .47076 Mdot
.888 .47091 Mdot
.888 .47125 Mdot
.888 .47128 Mdot
.888 .47158 Mdot
.888 .47159 Mdot
.888 .47184 Mdot
.888 .47225 Mdot
.888 .47245 Mdot
.888 .47258 Mdot
.888 .47273 Mdot
.888 .4729 Mdot
.888 .47337 Mdot
.888 .47367 Mdot
.888 .47398 Mdot
.888 .47516 Mdot
.888 .47516 Mdot
.888 .47567 Mdot
.888 .47685 Mdot
.888 .47694 Mdot
.888 .47712 Mdot
.888 .47825 Mdot
.888 .47854 Mdot
.888 .47878 Mdot
.888 .47886 Mdot
.888 .47896 Mdot
.888 .47926 Mdot
.888 .47956 Mdot
.888 .47967 Mdot
.888 .4803 Mdot
.888 .48086 Mdot
.888 .48094 Mdot
.888 .48104 Mdot
.888 .48148 Mdot
.888 .48153 Mdot
.888 .48171 Mdot
.888 .48193 Mdot
.888 .482 Mdot
.888 .48202 Mdot
.888 .48313 Mdot
.888 .48359 Mdot
.888 .48397 Mdot
.888 .48401 Mdot
.888 .48435 Mdot
.888 .48473 Mdot
.888 .48506 Mdot
.888 .48508 Mdot
.888 .48561 Mdot
.888 .48616 Mdot
.888 .48654 Mdot
.888 .48675 Mdot
.888 .48695 Mdot
.888 .4876 Mdot
.888 .48826 Mdot
.888 .4887 Mdot
.888 .48896 Mdot
.888 .48938 Mdot
.888 .48942 Mdot
.888 .48957 Mdot
.888 .48992 Mdot
.888 .49004 Mdot
.888 .49016 Mdot
.888 .49021 Mdot
.888 .49065 Mdot
.888 .49146 Mdot
.888 .49173 Mdot
.888 .49186 Mdot
.888 .4922 Mdot
.888 .49265 Mdot
.888 .49343 Mdot
.888 .49369 Mdot
.888 .49388 Mdot
.888 .49443 Mdot
.888 .49507 Mdot
.888 .49543 Mdot
.888 .49586 Mdot
.888 .49635 Mdot
.888 .49642 Mdot
.888 .49713 Mdot
.888 .49754 Mdot
.888 .49808 Mdot
.888 .49852 Mdot
.888 .49881 Mdot
.888 .49913 Mdot
.888 .49924 Mdot
.888 .50015 Mdot
.888 .50048 Mdot
.888 .50051 Mdot
.888 .50104 Mdot
.888 .50105 Mdot
.888 .50147 Mdot
.888 .50194 Mdot
.888 .50238 Mdot
.888 .50249 Mdot
.888 .50295 Mdot
.888 .50314 Mdot
.888 .504 Mdot
.888 .50405 Mdot
.888 .50411 Mdot
.888 .50436 Mdot
.888 .50469 Mdot
.888 .50479 Mdot
.888 .50499 Mdot
.888 .5051 Mdot
.888 .50539 Mdot
.888 .50604 Mdot
.888 .50627 Mdot
.888 .50631 Mdot
.888 .50718 Mdot
.888 .50719 Mdot
.888 .50726 Mdot
.888 .50732 Mdot
.888 .50796 Mdot
.888 .50919 Mdot
.888 .5093 Mdot
.888 .5097 Mdot
.888 .50996 Mdot
.888 .51087 Mdot
.888 .51123 Mdot
.888 .51144 Mdot
.888 .51174 Mdot
.888 .51204 Mdot
.888 .51271 Mdot
.888 .51301 Mdot
.888 .51303 Mdot
.888 .51307 Mdot
.888 .51355 Mdot
.888 .51381 Mdot
.888 .51392 Mdot
.888 .51414 Mdot
.888 .51434 Mdot
.888 .51552 Mdot
.888 .51573 Mdot
.888 .5159 Mdot
.888 .51632 Mdot
.888 .51639 Mdot
.888 .51675 Mdot
.888 .51676 Mdot
.888 .51677 Mdot
.888 .51692 Mdot
.888 .51709 Mdot
.888 .51719 Mdot
.888 .51733 Mdot
.888 .51849 Mdot
.888 .5187 Mdot
.888 .51904 Mdot
.888 .51914 Mdot
.888 .52014 Mdot
.888 .52072 Mdot
.888 .52077 Mdot
.888 .52143 Mdot
.888 .52175 Mdot
.888 .52188 Mdot
.888 .52239 Mdot
.888 .52248 Mdot
.888 .52248 Mdot
.888 .523 Mdot
.888 .52312 Mdot
.888 .52327 Mdot
.888 .52376 Mdot
.888 .52422 Mdot
.888 .52456 Mdot
.888 .52469 Mdot
.888 .52488 Mdot
.888 .52522 Mdot
.888 .52571 Mdot
.888 .52579 Mdot
.888 .52685 Mdot
.888 .52712 Mdot
.888 .52759 Mdot
.888 .52787 Mdot
.888 .5281 Mdot
.888 .5282 Mdot
.888 .52822 Mdot
.888 .52823 Mdot
.888 .52835 Mdot
.888 .52884 Mdot
.888 .52909 Mdot
.888 .52992 Mdot
.888 .53024 Mdot
.888 .53046 Mdot
.888 .53173 Mdot
.888 .5319 Mdot
.888 .53243 Mdot
.888 .53361 Mdot
.888 .53364 Mdot
.888 .53393 Mdot
.888 .53414 Mdot
.888 .53535 Mdot
.888 .53561 Mdot
.888 .5361 Mdot
.888 .53631 Mdot
.888 .53638 Mdot
.888 .537 Mdot
.888 .53701 Mdot
.888 .53707 Mdot
.888 .53721 Mdot
.888 .5382 Mdot
.89 .13074 Mdot
.89 .13101 Mdot
.89 .13176 Mdot
.89 .13243 Mdot
.89 .13253 Mdot
.89 .13432 Mdot
.89 .13439 Mdot
.89 .13456 Mdot
.89 .13486 Mdot
.89 .13546 Mdot
.89 .13556 Mdot
.89 .13601 Mdot
.89 .13682 Mdot
.89 .13713 Mdot
.89 .13853 Mdot
.89 .13886 Mdot
.89 .1396 Mdot
.89 .14001 Mdot
.89 .14008 Mdot
.89 .14132 Mdot
.89 .14172 Mdot
.89 .14277 Mdot
.89 .14359 Mdot
.89 .14422 Mdot
.89 .14458 Mdot
.89 .14535 Mdot
.89 .14619 Mdot
.89 .14636 Mdot
.89 .14649 Mdot
.89 .14656 Mdot
.89 .14751 Mdot
.89 .14797 Mdot
.89 .14809 Mdot
.89 .14858 Mdot
.89 .14961 Mdot
.89 .14989 Mdot
.89 .15003 Mdot
.89 .153 Mdot
.89 .15357 Mdot
.89 .15358 Mdot
.89 .15367 Mdot
.89 .15472 Mdot
.89 .15486 Mdot
.89 .15519 Mdot
.89 .1553 Mdot
.89 .15546 Mdot
.89 .15619 Mdot
.89 .15821 Mdot
.89 .15822 Mdot
.89 .15878 Mdot
.89 .15915 Mdot
.89 .1596 Mdot
.89 .15989 Mdot
.89 .1619 Mdot
.89 .16207 Mdot
.89 .16239 Mdot
.89 .16284 Mdot
.89 .16354 Mdot
.89 .16371 Mdot
.89 .16376 Mdot
.89 .16673 Mdot
.89 .16697 Mdot
.89 .16825 Mdot
.89 .16914 Mdot
.89 .16957 Mdot
.89 .16957 Mdot
.89 .16979 Mdot
.89 .17021 Mdot
.89 .17054 Mdot
.89 .17214 Mdot
.89 .17243 Mdot
.89 .173 Mdot
.89 .17335 Mdot
.89 .17346 Mdot
.89 .17369 Mdot
.89 .1745 Mdot
.89 .17537 Mdot
.89 .17601 Mdot
.89 .1763 Mdot
.89 .177 Mdot
.89 .17896 Mdot
.89 .17961 Mdot
.89 .18071 Mdot
.89 .1812 Mdot
.89 .18136 Mdot
.89 .18358 Mdot
.89 .18369 Mdot
.89 .18459 Mdot
.89 .18569 Mdot
.89 .18605 Mdot
.89 .18614 Mdot
.89 .18792 Mdot
.89 .18828 Mdot
.89 .18855 Mdot
.89 .19027 Mdot
.89 .19035 Mdot
.89 .19149 Mdot
.89 .1915 Mdot
.89 .19186 Mdot
.89 .19259 Mdot
.89 .19261 Mdot
.89 .19294 Mdot
.89 .19394 Mdot
.89 .19465 Mdot
.89 .19474 Mdot
.89 .19675 Mdot
.89 .19876 Mdot
.89 .1989 Mdot
.89 .19895 Mdot
.89 .19978 Mdot
.89 .20044 Mdot
.89 .20076 Mdot
.89 .20223 Mdot
.89 .20247 Mdot
.89 .20398 Mdot
.89 .2051 Mdot
.89 .20615 Mdot
.89 .20635 Mdot
.89 .20642 Mdot
.89 .20754 Mdot
.89 .20853 Mdot
.89 .20865 Mdot
.89 .21038 Mdot
.89 .21088 Mdot
.89 .21151 Mdot
.89 .21196 Mdot
.89 .21263 Mdot
.89 .2128 Mdot
.89 .21388 Mdot
.89 .21447 Mdot
.89 .21469 Mdot
.89 .21502 Mdot
.89 .21577 Mdot
.89 .2163 Mdot
.89 .21698 Mdot
.89 .21874 Mdot
.89 .21891 Mdot
.89 .21893 Mdot
.89 .21992 Mdot
.89 .22023 Mdot
.89 .22051 Mdot
.89 .22124 Mdot
.89 .22171 Mdot
.89 .22226 Mdot
.89 .22306 Mdot
.89 .22424 Mdot
.89 .22429 Mdot
.89 .22443 Mdot
.89 .22458 Mdot
.89 .22554 Mdot
.89 .22588 Mdot
.89 .22638 Mdot
.89 .2267 Mdot
.89 .22761 Mdot
.89 .22774 Mdot
.89 .22803 Mdot
.89 .22804 Mdot
.89 .22858 Mdot
.89 .22922 Mdot
.89 .22944 Mdot
.89 .22964 Mdot
.89 .22969 Mdot
.89 .22983 Mdot
.89 .23035 Mdot
.89 .23048 Mdot
.89 .23062 Mdot
.89 .23158 Mdot
.89 .23186 Mdot
.89 .23199 Mdot
.89 .23206 Mdot
.89 .23261 Mdot
.89 .23357 Mdot
.89 .23382 Mdot
.89 .23436 Mdot
.89 .23456 Mdot
.89 .23463 Mdot
.89 .23467 Mdot
.89 .23474 Mdot
.89 .23511 Mdot
.89 .23565 Mdot
.89 .23569 Mdot
.89 .23569 Mdot
.89 .237 Mdot
.89 .23773 Mdot
.89 .23787 Mdot
.89 .23931 Mdot
.89 .23934 Mdot
.89 .23941 Mdot
.89 .23999 Mdot
.89 .24006 Mdot
.89 .24008 Mdot
.89 .24078 Mdot
.89 .24178 Mdot
.89 .24265 Mdot
.89 .24307 Mdot
.89 .24315 Mdot
.89 .24344 Mdot
.89 .24412 Mdot
.89 .24448 Mdot
.89 .24485 Mdot
.89 .24524 Mdot
.89 .24588 Mdot
.89 .24606 Mdot
.89 .24613 Mdot
.89 .24724 Mdot
.89 .24764 Mdot
.89 .24773 Mdot
.89 .24774 Mdot
.89 .24803 Mdot
.89 .24875 Mdot
.89 .24904 Mdot
.89 .24913 Mdot
.89 .24927 Mdot
.89 .24939 Mdot
.89 .24942 Mdot
.89 .2498 Mdot
.89 .25027 Mdot
.89 .25073 Mdot
.89 .25108 Mdot
.89 .25191 Mdot
.89 .25212 Mdot
.89 .25219 Mdot
.89 .25237 Mdot
.89 .25264 Mdot
.89 .253 Mdot
.89 .25313 Mdot
.89 .25346 Mdot
.89 .25448 Mdot
.89 .25483 Mdot
.89 .25532 Mdot
.89 .25549 Mdot
.89 .25555 Mdot
.89 .25557 Mdot
.89 .25584 Mdot
.89 .25813 Mdot
.89 .25919 Mdot
.89 .26051 Mdot
.89 .26064 Mdot
.89 .26085 Mdot
.89 .26139 Mdot
.89 .2615 Mdot
.89 .2617 Mdot
.89 .26187 Mdot
.89 .26189 Mdot
.89 .26205 Mdot
.89 .2628 Mdot
.89 .26303 Mdot
.89 .26392 Mdot
.89 .26417 Mdot
.89 .26476 Mdot
.89 .26479 Mdot
.89 .26497 Mdot
.89 .2652 Mdot
.89 .26525 Mdot
.89 .26557 Mdot
.89 .26654 Mdot
.89 .26698 Mdot
.89 .2671 Mdot
.89 .26723 Mdot
.89 .26786 Mdot
.89 .2682 Mdot
.89 .26933 Mdot
.89 .27005 Mdot
.89 .27014 Mdot
.89 .27016 Mdot
.89 .27106 Mdot
.89 .27115 Mdot
.89 .2712 Mdot
.89 .27181 Mdot
.89 .27196 Mdot
.89 .27252 Mdot
.89 .27261 Mdot
.89 .27261 Mdot
.89 .27264 Mdot
.89 .27312 Mdot
.89 .27449 Mdot
.89 .27505 Mdot
.89 .27524 Mdot
.89 .27527 Mdot
.89 .27641 Mdot
.89 .27671 Mdot
.89 .27677 Mdot
.89 .277 Mdot
.89 .27758 Mdot
.89 .27762 Mdot
.89 .2781 Mdot
.89 .27839 Mdot
.89 .27883 Mdot
.89 .27951 Mdot
.89 .27961 Mdot
.89 .27992 Mdot
.89 .28001 Mdot
.89 .2812 Mdot
.89 .28129 Mdot
.89 .2817 Mdot
.89 .28171 Mdot
.89 .28176 Mdot
.89 .28232 Mdot
.89 .2827 Mdot
.89 .28294 Mdot
.89 .28311 Mdot
.89 .2833 Mdot
.89 .28363 Mdot
.89 .28404 Mdot
.89 .28498 Mdot
.89 .2853 Mdot
.89 .28567 Mdot
.89 .28574 Mdot
.89 .28607 Mdot
.89 .28801 Mdot
.89 .2887 Mdot
.89 .28934 Mdot
.89 .28959 Mdot
.89 .29025 Mdot
.89 .29036 Mdot
.89 .29036 Mdot
.89 .29072 Mdot
.89 .29075 Mdot
.89 .29137 Mdot
.89 .29149 Mdot
.89 .29208 Mdot
.89 .29361 Mdot
.89 .29432 Mdot
.89 .29494 Mdot
.89 .29545 Mdot
.89 .29647 Mdot
.89 .29708 Mdot
.89 .29728 Mdot
.89 .29742 Mdot
.89 .29769 Mdot
.89 .29911 Mdot
.89 .29913 Mdot
.89 .29918 Mdot
.89 .30043 Mdot
.89 .30069 Mdot
.89 .30086 Mdot
.89 .30173 Mdot
.89 .30178 Mdot
.89 .30182 Mdot
.89 .30192 Mdot
.89 .30197 Mdot
.89 .30233 Mdot
.89 .30251 Mdot
.89 .30358 Mdot
.89 .30406 Mdot
.89 .30454 Mdot
.89 .30457 Mdot
.89 .30461 Mdot
.89 .30492 Mdot
.89 .30517 Mdot
.89 .30548 Mdot
.89 .3062 Mdot
.89 .30708 Mdot
.89 .30801 Mdot
.89 .30823 Mdot
.89 .30841 Mdot
.89 .30897 Mdot
.89 .30945 Mdot
.89 .30986 Mdot
.89 .31018 Mdot
.89 .31039 Mdot
.89 .31101 Mdot
.89 .31106 Mdot
.89 .31135 Mdot
.89 .31152 Mdot
.89 .31178 Mdot
.89 .31187 Mdot
.89 .31242 Mdot
.89 .31265 Mdot
.89 .31278 Mdot
.89 .31281 Mdot
.89 .31332 Mdot
.89 .31365 Mdot
.89 .31411 Mdot
.89 .31474 Mdot
.89 .31515 Mdot
.89 .3153 Mdot
.89 .31549 Mdot
.89 .3159 Mdot
.89 .31594 Mdot
.89 .31707 Mdot
.89 .31709 Mdot
.89 .31789 Mdot
.89 .31853 Mdot
.89 .31882 Mdot
.89 .31906 Mdot
.89 .31969 Mdot
.89 .31974 Mdot
.89 .31985 Mdot
.89 .31999 Mdot
.89 .32122 Mdot
.89 .32129 Mdot
.89 .3217 Mdot
.89 .32211 Mdot
.89 .32218 Mdot
.89 .32242 Mdot
.89 .32302 Mdot
.89 .3232 Mdot
.89 .3233 Mdot
.89 .32334 Mdot
.89 .32341 Mdot
.89 .32367 Mdot
.89 .32415 Mdot
.89 .32424 Mdot
.89 .32528 Mdot
.89 .32563 Mdot
.89 .32583 Mdot
.89 .32653 Mdot
.89 .32657 Mdot
.89 .32685 Mdot
.89 .3272 Mdot
.89 .32734 Mdot
.89 .3281 Mdot
.89 .32938 Mdot
.89 .32938 Mdot
.89 .32949 Mdot
.89 .33003 Mdot
.89 .33133 Mdot
.89 .33137 Mdot
.89 .33165 Mdot
.89 .33186 Mdot
.89 .33196 Mdot
.89 .33242 Mdot
.89 .3325 Mdot
.89 .33297 Mdot
.89 .33374 Mdot
.89 .33445 Mdot
.89 .33499 Mdot
.89 .33515 Mdot
.89 .33549 Mdot
.89 .3357 Mdot
.89 .33635 Mdot
.89 .33686 Mdot
.89 .338 Mdot
.89 .33874 Mdot
.89 .34004 Mdot
.89 .34014 Mdot
.89 .34094 Mdot
.89 .34109 Mdot
.89 .34134 Mdot
.89 .34169 Mdot
.89 .34231 Mdot
.89 .34256 Mdot
.89 .34265 Mdot
.89 .34266 Mdot
.89 .34297 Mdot
.89 .34413 Mdot
.89 .34436 Mdot
.89 .34531 Mdot
.89 .34533 Mdot
.89 .34543 Mdot
.89 .34576 Mdot
.89 .34587 Mdot
.89 .34625 Mdot
.89 .34722 Mdot
.89 .34731 Mdot
.89 .34773 Mdot
.89 .34849 Mdot
.89 .34859 Mdot
.89 .34891 Mdot
.89 .3504 Mdot
.89 .35082 Mdot
.89 .35086 Mdot
.89 .35109 Mdot
.89 .35113 Mdot
.89 .35161 Mdot
.89 .35289 Mdot
.89 .35294 Mdot
.89 .35313 Mdot
.89 .35324 Mdot
.89 .3536 Mdot
.89 .35464 Mdot
.89 .35541 Mdot
.89 .35546 Mdot
.89 .35583 Mdot
.89 .35595 Mdot
.89 .35622 Mdot
.89 .35681 Mdot
.89 .35737 Mdot
.89 .35751 Mdot
.89 .35782 Mdot
.89 .35795 Mdot
.89 .35811 Mdot
.89 .35824 Mdot
.89 .35971 Mdot
.89 .35991 Mdot
.89 .36035 Mdot
.89 .36056 Mdot
.89 .36148 Mdot
.89 .363 Mdot
.89 .36302 Mdot
.89 .36341 Mdot
.89 .36389 Mdot
.89 .36471 Mdot
.89 .36472 Mdot
.89 .36473 Mdot
.89 .36483 Mdot
.89 .36501 Mdot
.89 .36523 Mdot
.89 .36581 Mdot
.89 .36611 Mdot
.89 .36656 Mdot
.89 .36692 Mdot
.89 .367 Mdot
.89 .36731 Mdot
.89 .36732 Mdot
.89 .36759 Mdot
.89 .36773 Mdot
.89 .36793 Mdot
.89 .36806 Mdot
.89 .3683 Mdot
.89 .36892 Mdot
.89 .36922 Mdot
.89 .36951 Mdot
.89 .37028 Mdot
.89 .3706 Mdot
.89 .37063 Mdot
.89 .37067 Mdot
.89 .37093 Mdot
.89 .37126 Mdot
.89 .37143 Mdot
.89 .37259 Mdot
.89 .37353 Mdot
.89 .37369 Mdot
.89 .37448 Mdot
.89 .37475 Mdot
.89 .37592 Mdot
.89 .3762 Mdot
.89 .37644 Mdot
.89 .37684 Mdot
.89 .37728 Mdot
.89 .37759 Mdot
.89 .37772 Mdot
.89 .37788 Mdot
.89 .37818 Mdot
.89 .37821 Mdot
.89 .37834 Mdot
.89 .37919 Mdot
.89 .37942 Mdot
.89 .37997 Mdot
.89 .38053 Mdot
.89 .38077 Mdot
.89 .38102 Mdot
.89 .38121 Mdot
.89 .38139 Mdot
.89 .38143 Mdot
.89 .38162 Mdot
.89 .38233 Mdot
.89 .38268 Mdot
.89 .38317 Mdot
.89 .38329 Mdot
.89 .38371 Mdot
.89 .38387 Mdot
.89 .38414 Mdot
.89 .3844 Mdot
.89 .38453 Mdot
.89 .38461 Mdot
.89 .38522 Mdot
.89 .38556 Mdot
.89 .38566 Mdot
.89 .38654 Mdot
.89 .38724 Mdot
.89 .38767 Mdot
.89 .38777 Mdot
.89 .388 Mdot
.89 .38827 Mdot
.89 .38834 Mdot
.89 .38897 Mdot
.89 .38898 Mdot
.89 .38938 Mdot
.89 .38992 Mdot
.89 .38998 Mdot
.89 .39032 Mdot
.89 .39059 Mdot
.89 .39116 Mdot
.89 .39149 Mdot
.89 .39205 Mdot
.89 .39319 Mdot
.89 .39367 Mdot
.89 .39389 Mdot
.89 .39419 Mdot
.89 .39442 Mdot
.89 .39442 Mdot
.89 .39477 Mdot
.89 .39539 Mdot
.89 .39579 Mdot
.89 .39628 Mdot
.89 .39653 Mdot
.89 .39687 Mdot
.89 .39692 Mdot
.89 .39699 Mdot
.89 .39729 Mdot
.89 .39738 Mdot
.89 .39761 Mdot
.89 .39795 Mdot
.89 .39855 Mdot
.89 .39866 Mdot
.89 .39868 Mdot
.89 .39878 Mdot
.89 .39903 Mdot
.89 .39979 Mdot
.89 .39992 Mdot
.89 .40039 Mdot
.89 .40074 Mdot
.89 .40082 Mdot
.89 .40099 Mdot
.89 .40124 Mdot
.89 .40146 Mdot
.89 .4016 Mdot
.89 .40176 Mdot
.89 .40256 Mdot
.89 .40301 Mdot
.89 .40427 Mdot
.89 .40456 Mdot
.89 .40472 Mdot
.89 .40474 Mdot
.89 .40535 Mdot
.89 .40568 Mdot
.89 .40604 Mdot
.89 .40617 Mdot
.89 .40624 Mdot
.89 .40635 Mdot
.89 .40643 Mdot
.89 .40658 Mdot
.89 .40681 Mdot
.89 .40701 Mdot
.89 .40727 Mdot
.89 .40776 Mdot
.89 .40798 Mdot
.89 .40804 Mdot
.89 .40805 Mdot
.89 .40805 Mdot
.89 .40878 Mdot
.89 .409 Mdot
.89 .40986 Mdot
.89 .41039 Mdot
.89 .4105 Mdot
.89 .41168 Mdot
.89 .41176 Mdot
.89 .41192 Mdot
.89 .4121 Mdot
.89 .41217 Mdot
.89 .41249 Mdot
.89 .41282 Mdot
.89 .41328 Mdot
.89 .41371 Mdot
.89 .41449 Mdot
.89 .41455 Mdot
.89 .41467 Mdot
.89 .41469 Mdot
.89 .41568 Mdot
.89 .4157 Mdot
.89 .41584 Mdot
.89 .41586 Mdot
.89 .41609 Mdot
.89 .41711 Mdot
.89 .41759 Mdot
.89 .41782 Mdot
.89 .41787 Mdot
.89 .41842 Mdot
.89 .4187 Mdot
.89 .41888 Mdot
.89 .41894 Mdot
.89 .41948 Mdot
.89 .42027 Mdot
.89 .42044 Mdot
.89 .42099 Mdot
.89 .42118 Mdot
.89 .42132 Mdot
.89 .42141 Mdot
.89 .42185 Mdot
.89 .42191 Mdot
.89 .42306 Mdot
.89 .4237 Mdot
.89 .42398 Mdot
.89 .42435 Mdot
.89 .42447 Mdot
.89 .42505 Mdot
.89 .42588 Mdot
.89 .42615 Mdot
.89 .42619 Mdot
.89 .42651 Mdot
.89 .42663 Mdot
.89 .42784 Mdot
.89 .42862 Mdot
.89 .42932 Mdot
.89 .42948 Mdot
.89 .4295 Mdot
.89 .42989 Mdot
.89 .43001 Mdot
.89 .4302 Mdot
.89 .43079 Mdot
.89 .43125 Mdot
.89 .43129 Mdot
.89 .43131 Mdot
.89 .43137 Mdot
.89 .43181 Mdot
.89 .43194 Mdot
.89 .43198 Mdot
.89 .43222 Mdot
.89 .43244 Mdot
.89 .43249 Mdot
.89 .43317 Mdot
.89 .43331 Mdot
.89 .43383 Mdot
.89 .43399 Mdot
.89 .43436 Mdot
.89 .43482 Mdot
.89 .43545 Mdot
.89 .43547 Mdot
.89 .43589 Mdot
.89 .43613 Mdot
.89 .43648 Mdot
.89 .43673 Mdot
.89 .43692 Mdot
.89 .43721 Mdot
.89 .43722 Mdot
.89 .4373 Mdot
.89 .43743 Mdot
.89 .43774 Mdot
.89 .43779 Mdot
.89 .43793 Mdot
.89 .43822 Mdot
.89 .43857 Mdot
.89 .43887 Mdot
.89 .4391 Mdot
.89 .43937 Mdot
.89 .43968 Mdot
.89 .4399 Mdot
.89 .44092 Mdot
.89 .44133 Mdot
.89 .4415 Mdot
.89 .44164 Mdot
.89 .44182 Mdot
.89 .44184 Mdot
.89 .44185 Mdot
.89 .44212 Mdot
.89 .44299 Mdot
.89 .4433 Mdot
.89 .44332 Mdot
.89 .4434 Mdot
.89 .44343 Mdot
.89 .44392 Mdot
.89 .44417 Mdot
.89 .44486 Mdot
.89 .4449 Mdot
.89 .4476 Mdot
.89 .448 Mdot
.89 .44925 Mdot
.89 .44962 Mdot
.89 .44989 Mdot
.89 .4504 Mdot
.89 .45075 Mdot
.89 .45223 Mdot
.89 .45246 Mdot
.89 .45284 Mdot
.89 .45337 Mdot
.89 .4536 Mdot
.89 .45379 Mdot
.89 .45389 Mdot
.89 .45399 Mdot
.89 .45412 Mdot
.89 .45434 Mdot
.89 .45465 Mdot
.89 .45468 Mdot
.89 .45469 Mdot
.89 .45492 Mdot
.89 .45496 Mdot
.89 .45592 Mdot
.89 .4563 Mdot
.89 .45671 Mdot
.89 .45698 Mdot
.89 .45746 Mdot
.89 .45766 Mdot
.89 .4583 Mdot
.89 .45832 Mdot
.89 .45842 Mdot
.89 .45874 Mdot
.89 .45978 Mdot
.89 .45979 Mdot
.89 .45984 Mdot
.89 .46016 Mdot
.89 .46058 Mdot
.89 .46066 Mdot
.89 .46123 Mdot
.89 .46164 Mdot
.89 .46227 Mdot
.89 .46246 Mdot
.89 .46282 Mdot
.89 .46289 Mdot
.89 .46295 Mdot
.89 .46375 Mdot
.89 .46395 Mdot
.89 .46419 Mdot
.89 .46518 Mdot
.89 .46531 Mdot
.89 .46592 Mdot
.89 .46603 Mdot
.89 .4661 Mdot
.89 .46652 Mdot
.89 .46659 Mdot
.89 .46733 Mdot
.89 .46793 Mdot
.89 .46921 Mdot
.89 .46938 Mdot
.89 .46941 Mdot
.89 .46998 Mdot
.89 .47055 Mdot
.89 .47074 Mdot
.89 .47101 Mdot
.89 .47117 Mdot
.89 .47126 Mdot
.89 .47209 Mdot
.89 .47235 Mdot
.89 .4726 Mdot
.89 .47282 Mdot
.89 .47298 Mdot
.89 .4736 Mdot
.89 .47377 Mdot
.89 .47377 Mdot
.89 .47382 Mdot
.89 .47467 Mdot
.89 .47471 Mdot
.89 .47539 Mdot
.89 .4756 Mdot
.89 .47618 Mdot
.89 .47635 Mdot
.89 .47639 Mdot
.89 .47712 Mdot
.89 .47808 Mdot
.89 .47812 Mdot
.89 .47845 Mdot
.89 .47848 Mdot
.89 .4785 Mdot
.89 .48054 Mdot
.89 .48056 Mdot
.89 .48107 Mdot
.89 .48111 Mdot
.89 .48113 Mdot
.89 .48117 Mdot
.89 .48128 Mdot
.89 .48158 Mdot
.89 .48173 Mdot
.89 .48261 Mdot
.89 .48269 Mdot
.89 .48284 Mdot
.89 .48346 Mdot
.89 .48353 Mdot
.89 .4839 Mdot
.89 .48405 Mdot
.89 .48417 Mdot
.89 .48484 Mdot
.89 .48558 Mdot
.89 .48576 Mdot
.89 .48605 Mdot
.89 .48624 Mdot
.89 .48678 Mdot
.89 .48694 Mdot
.89 .48808 Mdot
.89 .48907 Mdot
.89 .48922 Mdot
.89 .4894 Mdot
.89 .48995 Mdot
.89 .48996 Mdot
.89 .49006 Mdot
.89 .49104 Mdot
.89 .49143 Mdot
.89 .49173 Mdot
.89 .49215 Mdot
.89 .49233 Mdot
.89 .49246 Mdot
.89 .49279 Mdot
.89 .49339 Mdot
.89 .49349 Mdot
.89 .49387 Mdot
.89 .49412 Mdot
.89 .49447 Mdot
.89 .49475 Mdot
.89 .49573 Mdot
.89 .49579 Mdot
.89 .49635 Mdot
.89 .49698 Mdot
.89 .49701 Mdot
.89 .49713 Mdot
.89 .49772 Mdot
.89 .49835 Mdot
.89 .4992 Mdot
.89 .49933 Mdot
.89 .50016 Mdot
.89 .50034 Mdot
.89 .50071 Mdot
.89 .50118 Mdot
.89 .5012 Mdot
.89 .50128 Mdot
.89 .50241 Mdot
.89 .50354 Mdot
.89 .50359 Mdot
.89 .50399 Mdot
.89 .50455 Mdot
.89 .50474 Mdot
.89 .50475 Mdot
.89 .50516 Mdot
.89 .50536 Mdot
.89 .50537 Mdot
.89 .50601 Mdot
.89 .50605 Mdot
.89 .50702 Mdot
.89 .50717 Mdot
.89 .50737 Mdot
.89 .50837 Mdot
.89 .50842 Mdot
.89 .50862 Mdot
.89 .50924 Mdot
.89 .50975 Mdot
.89 .50981 Mdot
.89 .51106 Mdot
.89 .51115 Mdot
.89 .51142 Mdot
.89 .51204 Mdot
.89 .5124 Mdot
.89 .51351 Mdot
.89 .5139 Mdot
.89 .51406 Mdot
.89 .51442 Mdot
.89 .51491 Mdot
.89 .51536 Mdot
.89 .5155 Mdot
.89 .51556 Mdot
.89 .51575 Mdot
.89 .51607 Mdot
.89 .51624 Mdot
.89 .51714 Mdot
.89 .51732 Mdot
.89 .51756 Mdot
.89 .51768 Mdot
.89 .51768 Mdot
.89 .51792 Mdot
.89 .51842 Mdot
.89 .51842 Mdot
.89 .51914 Mdot
.89 .51928 Mdot
.89 .52095 Mdot
.89 .52098 Mdot
.89 .52107 Mdot
.89 .52146 Mdot
.89 .52171 Mdot
.89 .5219 Mdot
.89 .52199 Mdot
.89 .52312 Mdot
.89 .52328 Mdot
.89 .52353 Mdot
.89 .52374 Mdot
.89 .52405 Mdot
.89 .52406 Mdot
.89 .5252 Mdot
.89 .52561 Mdot
.89 .52569 Mdot
.89 .52576 Mdot
.89 .52595 Mdot
.89 .52602 Mdot
.89 .52662 Mdot
.89 .52667 Mdot
.89 .52667 Mdot
.89 .52699 Mdot
.89 .52866 Mdot
.89 .52874 Mdot
.89 .52889 Mdot
.89 .52947 Mdot
.89 .52975 Mdot
.89 .52982 Mdot
.89 .53008 Mdot
.89 .53061 Mdot
.89 .53065 Mdot
.89 .53072 Mdot
.89 .53081 Mdot
.89 .53129 Mdot
.89 .53172 Mdot
.89 .53192 Mdot
.89 .53227 Mdot
.89 .53274 Mdot
.89 .53333 Mdot
.89 .53355 Mdot
.89 .53425 Mdot
.89 .53429 Mdot
.89 .53452 Mdot
.89 .53493 Mdot
.89 .53512 Mdot
.89 .53591 Mdot
.89 .53608 Mdot
.89 .53653 Mdot
.89 .53679 Mdot
.89 .53684 Mdot
.89 .53718 Mdot
.89 .53735 Mdot
.89 .53745 Mdot
.89 .53748 Mdot
.89 .53849 Mdot
.89 .53855 Mdot
.89 .53892 Mdot
.89 .53935 Mdot
.89 .5395 Mdot
.892 .12879 Mdot
.892 .1289 Mdot
.892 .12894 Mdot
.892 .13051 Mdot
.892 .13104 Mdot
.892 .13282 Mdot
.892 .13312 Mdot
.892 .1338 Mdot
.892 .13469 Mdot
.892 .13601 Mdot
.892 .13618 Mdot
.892 .13677 Mdot
.892 .13725 Mdot
.892 .13743 Mdot
.892 .13791 Mdot
.892 .13865 Mdot
.892 .13885 Mdot
.892 .13886 Mdot
.892 .13906 Mdot
.892 .13915 Mdot
.892 .14003 Mdot
.892 .14137 Mdot
.892 .14162 Mdot
.892 .14222 Mdot
.892 .14437 Mdot
.892 .14461 Mdot
.892 .14855 Mdot
.892 .14964 Mdot
.892 .14965 Mdot
.892 .14971 Mdot
.892 .15039 Mdot
.892 .15078 Mdot
.892 .15093 Mdot
.892 .15104 Mdot
.892 .15131 Mdot
.892 .152 Mdot
.892 .15299 Mdot
.892 .15501 Mdot
.892 .1555 Mdot
.892 .15561 Mdot
.892 .1559 Mdot
.892 .1564 Mdot
.892 .15699 Mdot
.892 .16005 Mdot
.892 .16019 Mdot
.892 .16089 Mdot
.892 .16172 Mdot
.892 .16246 Mdot
.892 .16294 Mdot
.892 .1644 Mdot
.892 .168 Mdot
.892 .16886 Mdot
.892 .16922 Mdot
.892 .16971 Mdot
.892 .17055 Mdot
.892 .17124 Mdot
.892 .17146 Mdot
.892 .17164 Mdot
.892 .17202 Mdot
.892 .17372 Mdot
.892 .17406 Mdot
.892 .17434 Mdot
.892 .17529 Mdot
.892 .17619 Mdot
.892 .17632 Mdot
.892 .17721 Mdot
.892 .17725 Mdot
.892 .17818 Mdot
.892 .17847 Mdot
.892 .1785 Mdot
.892 .17895 Mdot
.892 .1796 Mdot
.892 .18015 Mdot
.892 .18044 Mdot
.892 .1809 Mdot
.892 .18102 Mdot
.892 .18174 Mdot
.892 .18239 Mdot
.892 .18362 Mdot
.892 .18381 Mdot
.892 .1841 Mdot
.892 .1844 Mdot
.892 .185 Mdot
.892 .18567 Mdot
.892 .18593 Mdot
.892 .18615 Mdot
.892 .18719 Mdot
.892 .18749 Mdot
.892 .18805 Mdot
.892 .18883 Mdot
.892 .18908 Mdot
.892 .18988 Mdot
.892 .18993 Mdot
.892 .19075 Mdot
.892 .19198 Mdot
.892 .19199 Mdot
.892 .19333 Mdot
.892 .19342 Mdot
.892 .19413 Mdot
.892 .19466 Mdot
.892 .19534 Mdot
.892 .19542 Mdot
.892 .1958 Mdot
.892 .19603 Mdot
.892 .19611 Mdot
.892 .19621 Mdot
.892 .19639 Mdot
.892 .19681 Mdot
.892 .1969 Mdot
.892 .19716 Mdot
.892 .19792 Mdot
.892 .19825 Mdot
.892 .20157 Mdot
.892 .2022 Mdot
.892 .20233 Mdot
.892 .20288 Mdot
.892 .20356 Mdot
.892 .20373 Mdot
.892 .20424 Mdot
.892 .2046 Mdot
.892 .2059 Mdot
.892 .20679 Mdot
.892 .20735 Mdot
.892 .20824 Mdot
.892 .21128 Mdot
.892 .2114 Mdot
.892 .21143 Mdot
.892 .21202 Mdot
.892 .21243 Mdot
.892 .21325 Mdot
.892 .21419 Mdot
.892 .21486 Mdot
.892 .21513 Mdot
.892 .21559 Mdot
.892 .21608 Mdot
.892 .21616 Mdot
.892 .21733 Mdot
.892 .21776 Mdot
.892 .21823 Mdot
.892 .21841 Mdot
.892 .2185 Mdot
.892 .21851 Mdot
.892 .21852 Mdot
.892 .21902 Mdot
.892 .21952 Mdot
.892 .22005 Mdot
.892 .22036 Mdot
.892 .22099 Mdot
.892 .2211 Mdot
.892 .22128 Mdot
.892 .22223 Mdot
.892 .22244 Mdot
.892 .22283 Mdot
.892 .22348 Mdot
.892 .22395 Mdot
.892 .22457 Mdot
.892 .22471 Mdot
.892 .22542 Mdot
.892 .22546 Mdot
.892 .22564 Mdot
.892 .22595 Mdot
.892 .22616 Mdot
.892 .22708 Mdot
.892 .22716 Mdot
.892 .22767 Mdot
.892 .22835 Mdot
.892 .22875 Mdot
.892 .22974 Mdot
.892 .23011 Mdot
.892 .23016 Mdot
.892 .2311 Mdot
.892 .2314 Mdot
.892 .23162 Mdot
.892 .23177 Mdot
.892 .23246 Mdot
.892 .23252 Mdot
.892 .23256 Mdot
.892 .23331 Mdot
.892 .23364 Mdot
.892 .2345 Mdot
.892 .23515 Mdot
.892 .23581 Mdot
.892 .23617 Mdot
.892 .23618 Mdot
.892 .23654 Mdot
.892 .2367 Mdot
.892 .23676 Mdot
.892 .23696 Mdot
.892 .23726 Mdot
.892 .23749 Mdot
.892 .23827 Mdot
.892 .2385 Mdot
.892 .23887 Mdot
.892 .23908 Mdot
.892 .23948 Mdot
.892 .2405 Mdot
.892 .24067 Mdot
.892 .24096 Mdot
.892 .2411 Mdot
.892 .24122 Mdot
.892 .24201 Mdot
.892 .24203 Mdot
.892 .24219 Mdot
.892 .24435 Mdot
.892 .24493 Mdot
.892 .24543 Mdot
.892 .24586 Mdot
.892 .24597 Mdot
.892 .24601 Mdot
.892 .24611 Mdot
.892 .24612 Mdot
.892 .24618 Mdot
.892 .24645 Mdot
.892 .24689 Mdot
.892 .24759 Mdot
.892 .24865 Mdot
.892 .2505 Mdot
.892 .25052 Mdot
.892 .25229 Mdot
.892 .25267 Mdot
.892 .25348 Mdot
.892 .25409 Mdot
.892 .25483 Mdot
.892 .25536 Mdot
.892 .25542 Mdot
.892 .25544 Mdot
.892 .25555 Mdot
.892 .25676 Mdot
.892 .25746 Mdot
.892 .25772 Mdot
.892 .25791 Mdot
.892 .25792 Mdot
.892 .25838 Mdot
.892 .25841 Mdot
.892 .25843 Mdot
.892 .2588 Mdot
.892 .25915 Mdot
.892 .25922 Mdot
.892 .25938 Mdot
.892 .25962 Mdot
.892 .26139 Mdot
.892 .26163 Mdot
.892 .26181 Mdot
.892 .26205 Mdot
.892 .26253 Mdot
.892 .26277 Mdot
.892 .26277 Mdot
.892 .2635 Mdot
.892 .26428 Mdot
.892 .265 Mdot
.892 .26556 Mdot
.892 .26557 Mdot
.892 .26564 Mdot
.892 .26588 Mdot
.892 .26607 Mdot
.892 .26659 Mdot
.892 .26659 Mdot
.892 .26724 Mdot
.892 .26747 Mdot
.892 .2677 Mdot
.892 .26783 Mdot
.892 .26854 Mdot
.892 .26859 Mdot
.892 .26861 Mdot
.892 .26872 Mdot
.892 .26884 Mdot
.892 .26885 Mdot
.892 .27064 Mdot
.892 .27246 Mdot
.892 .27292 Mdot
.892 .27399 Mdot
.892 .274 Mdot
.892 .27424 Mdot
.892 .27447 Mdot
.892 .27479 Mdot
.892 .2751 Mdot
.892 .27542 Mdot
.892 .27549 Mdot
.892 .27696 Mdot
.892 .27772 Mdot
.892 .27774 Mdot
.892 .27829 Mdot
.892 .2785 Mdot
.892 .27898 Mdot
.892 .27914 Mdot
.892 .27947 Mdot
.892 .28002 Mdot
.892 .28014 Mdot
.892 .2806 Mdot
.892 .2808 Mdot
.892 .28138 Mdot
.892 .28175 Mdot
.892 .28212 Mdot
.892 .28253 Mdot
.892 .28274 Mdot
.892 .28329 Mdot
.892 .28506 Mdot
.892 .28534 Mdot
.892 .28775 Mdot
.892 .28809 Mdot
.892 .28817 Mdot
.892 .28839 Mdot
.892 .28851 Mdot
.892 .28904 Mdot
.892 .28926 Mdot
.892 .28972 Mdot
.892 .2901 Mdot
.892 .29036 Mdot
.892 .29038 Mdot
.892 .2907 Mdot
.892 .29095 Mdot
.892 .29122 Mdot
.892 .29155 Mdot
.892 .29161 Mdot
.892 .2917 Mdot
.892 .29228 Mdot
.892 .29234 Mdot
.892 .29273 Mdot
.892 .29293 Mdot
.892 .29316 Mdot
.892 .2932 Mdot
.892 .29381 Mdot
.892 .29395 Mdot
.892 .29436 Mdot
.892 .29463 Mdot
.892 .29468 Mdot
.892 .29534 Mdot
.892 .29599 Mdot
.892 .2961 Mdot
.892 .29623 Mdot
.892 .29686 Mdot
.892 .29838 Mdot
.892 .29899 Mdot
.892 .29948 Mdot
.892 .29975 Mdot
.892 .30071 Mdot
.892 .30105 Mdot
.892 .30114 Mdot
.892 .30118 Mdot
.892 .30133 Mdot
.892 .30278 Mdot
.892 .30299 Mdot
.892 .30302 Mdot
.892 .3046 Mdot
.892 .30467 Mdot
.892 .30535 Mdot
.892 .30562 Mdot
.892 .30631 Mdot
.892 .30634 Mdot
.892 .30641 Mdot
.892 .30647 Mdot
.892 .30685 Mdot
.892 .30691 Mdot
.892 .30706 Mdot
.892 .3073 Mdot
.892 .30772 Mdot
.892 .30886 Mdot
.892 .30982 Mdot
.892 .30986 Mdot
.892 .30987 Mdot
.892 .31036 Mdot
.892 .31109 Mdot
.892 .31118 Mdot
.892 .3114 Mdot
.892 .31214 Mdot
.892 .31269 Mdot
.892 .31299 Mdot
.892 .31336 Mdot
.892 .31385 Mdot
.892 .31603 Mdot
.892 .31638 Mdot
.892 .31673 Mdot
.892 .31678 Mdot
.892 .31681 Mdot
.892 .3169 Mdot
.892 .31712 Mdot
.892 .31743 Mdot
.892 .3185 Mdot
.892 .31969 Mdot
.892 .32017 Mdot
.892 .32055 Mdot
.892 .32176 Mdot
.892 .32214 Mdot
.892 .32242 Mdot
.892 .32268 Mdot
.892 .32295 Mdot
.892 .32323 Mdot
.892 .32394 Mdot
.892 .32414 Mdot
.892 .32443 Mdot
.892 .32505 Mdot
.892 .32534 Mdot
.892 .32543 Mdot
.892 .32579 Mdot
.892 .32596 Mdot
.892 .32605 Mdot
.892 .3272 Mdot
.892 .3273 Mdot
.892 .32748 Mdot
.892 .32827 Mdot
.892 .32877 Mdot
.892 .32968 Mdot
.892 .3301 Mdot
.892 .33052 Mdot
.892 .33073 Mdot
.892 .33076 Mdot
.892 .33095 Mdot
.892 .33098 Mdot
.892 .33106 Mdot
.892 .3312 Mdot
.892 .33154 Mdot
.892 .33269 Mdot
.892 .33289 Mdot
.892 .33293 Mdot
.892 .3331 Mdot
.892 .33332 Mdot
.892 .33337 Mdot
.892 .33353 Mdot
.892 .33364 Mdot
.892 .33451 Mdot
.892 .33479 Mdot
.892 .33574 Mdot
.892 .33579 Mdot
.892 .33597 Mdot
.892 .33636 Mdot
.892 .33695 Mdot
.892 .3371 Mdot
.892 .33725 Mdot
.892 .33778 Mdot
.892 .33802 Mdot
.892 .33818 Mdot
.892 .33833 Mdot
.892 .3385 Mdot
.892 .33883 Mdot
.892 .33958 Mdot
.892 .33972 Mdot
.892 .33996 Mdot
.892 .3402 Mdot
.892 .34071 Mdot
.892 .34154 Mdot
.892 .34213 Mdot
.892 .34218 Mdot
.892 .34242 Mdot
.892 .34324 Mdot
.892 .34375 Mdot
.892 .34381 Mdot
.892 .34441 Mdot
.892 .34448 Mdot
.892 .34507 Mdot
.892 .34613 Mdot
.892 .34632 Mdot
.892 .34661 Mdot
.892 .34664 Mdot
.892 .34669 Mdot
.892 .34669 Mdot
.892 .34671 Mdot
.892 .34715 Mdot
.892 .34748 Mdot
.892 .34807 Mdot
.892 .34807 Mdot
.892 .34863 Mdot
.892 .34919 Mdot
.892 .34943 Mdot
.892 .34959 Mdot
.892 .3504 Mdot
.892 .35162 Mdot
.892 .35185 Mdot
.892 .35192 Mdot
.892 .3524 Mdot
.892 .35282 Mdot
.892 .35312 Mdot
.892 .35347 Mdot
.892 .35376 Mdot
.892 .35379 Mdot
.892 .35497 Mdot
.892 .35545 Mdot
.892 .3556 Mdot
.892 .3557 Mdot
.892 .35579 Mdot
.892 .35701 Mdot
.892 .35717 Mdot
.892 .35738 Mdot
.892 .35752 Mdot
.892 .35813 Mdot
.892 .35819 Mdot
.892 .35837 Mdot
.892 .35892 Mdot
.892 .35901 Mdot
.892 .35988 Mdot
.892 .35997 Mdot
.892 .36051 Mdot
.892 .3607 Mdot
.892 .36078 Mdot
.892 .36119 Mdot
.892 .36121 Mdot
.892 .3614 Mdot
.892 .36236 Mdot
.892 .36239 Mdot
.892 .36243 Mdot
.892 .36354 Mdot
.892 .36538 Mdot
.892 .3656 Mdot
.892 .36563 Mdot
.892 .36565 Mdot
.892 .36584 Mdot
.892 .36671 Mdot
.892 .36743 Mdot
.892 .3677 Mdot
.892 .36781 Mdot
.892 .3689 Mdot
.892 .369 Mdot
.892 .37045 Mdot
.892 .37058 Mdot
.892 .37092 Mdot
.892 .3712 Mdot
.892 .3713 Mdot
.892 .37149 Mdot
.892 .37161 Mdot
.892 .37178 Mdot
.892 .37225 Mdot
.892 .37308 Mdot
.892 .37389 Mdot
.892 .37395 Mdot
.892 .37402 Mdot
.892 .37409 Mdot
.892 .37419 Mdot
.892 .37486 Mdot
.892 .37492 Mdot
.892 .37532 Mdot
.892 .37556 Mdot
.892 .37617 Mdot
.892 .37641 Mdot
.892 .37687 Mdot
.892 .37695 Mdot
.892 .37757 Mdot
.892 .37759 Mdot
.892 .37778 Mdot
.892 .37811 Mdot
.892 .37826 Mdot
.892 .37827 Mdot
.892 .37829 Mdot
.892 .37829 Mdot
.892 .37854 Mdot
.892 .3792 Mdot
.892 .38008 Mdot
.892 .38051 Mdot
.892 .38104 Mdot
.892 .38109 Mdot
.892 .38153 Mdot
.892 .38158 Mdot
.892 .38169 Mdot
.892 .38188 Mdot
.892 .38216 Mdot
.892 .38271 Mdot
.892 .38285 Mdot
.892 .38291 Mdot
.892 .38324 Mdot
.892 .3843 Mdot
.892 .38493 Mdot
.892 .3853 Mdot
.892 .3859 Mdot
.892 .38599 Mdot
.892 .38602 Mdot
.892 .38612 Mdot
.892 .38714 Mdot
.892 .38716 Mdot
.892 .38729 Mdot
.892 .38736 Mdot
.892 .388 Mdot
.892 .38821 Mdot
.892 .38891 Mdot
.892 .3891 Mdot
.892 .38935 Mdot
.892 .38943 Mdot
.892 .39011 Mdot
.892 .39061 Mdot
.892 .39068 Mdot
.892 .391 Mdot
.892 .39107 Mdot
.892 .39134 Mdot
.892 .39156 Mdot
.892 .39193 Mdot
.892 .39357 Mdot
.892 .39372 Mdot
.892 .39426 Mdot
.892 .39463 Mdot
.892 .39492 Mdot
.892 .39532 Mdot
.892 .3958 Mdot
.892 .39584 Mdot
.892 .39592 Mdot
.892 .39649 Mdot
.892 .39655 Mdot
.892 .39661 Mdot
.892 .39751 Mdot
.892 .39833 Mdot
.892 .39871 Mdot
.892 .39887 Mdot
.892 .39897 Mdot
.892 .39906 Mdot
.892 .39931 Mdot
.892 .39964 Mdot
.892 .40074 Mdot
.892 .40089 Mdot
.892 .40127 Mdot
.892 .40128 Mdot
.892 .40168 Mdot
.892 .40193 Mdot
.892 .40241 Mdot
.892 .40254 Mdot
.892 .40277 Mdot
.892 .4028 Mdot
.892 .40318 Mdot
.892 .40327 Mdot
.892 .40335 Mdot
.892 .40462 Mdot
.892 .40469 Mdot
.892 .4048 Mdot
.892 .40485 Mdot
.892 .40501 Mdot
.892 .40527 Mdot
.892 .40609 Mdot
.892 .40675 Mdot
.892 .40682 Mdot
.892 .40786 Mdot
.892 .40798 Mdot
.892 .40915 Mdot
.892 .40977 Mdot
.892 .40979 Mdot
.892 .40981 Mdot
.892 .41035 Mdot
.892 .41045 Mdot
.892 .41046 Mdot
.892 .4107 Mdot
.892 .41074 Mdot
.892 .41085 Mdot
.892 .4112 Mdot
.892 .41169 Mdot
.892 .41174 Mdot
.892 .41214 Mdot
.892 .41218 Mdot
.892 .41252 Mdot
.892 .41272 Mdot
.892 .41281 Mdot
.892 .41354 Mdot
.892 .4136 Mdot
.892 .41368 Mdot
.892 .41395 Mdot
.892 .41461 Mdot
.892 .41463 Mdot
.892 .41499 Mdot
.892 .41539 Mdot
.892 .4157 Mdot
.892 .41697 Mdot
.892 .41751 Mdot
.892 .41782 Mdot
.892 .41815 Mdot
.892 .41833 Mdot
.892 .41858 Mdot
.892 .41859 Mdot
.892 .4186 Mdot
.892 .41862 Mdot
.892 .41864 Mdot
.892 .4188 Mdot
.892 .41891 Mdot
.892 .4195 Mdot
.892 .41983 Mdot
.892 .41987 Mdot
.892 .42021 Mdot
.892 .42024 Mdot
.892 .42053 Mdot
.892 .42099 Mdot
.892 .42112 Mdot
.892 .42195 Mdot
.892 .42236 Mdot
.892 .42346 Mdot
.892 .42388 Mdot
.892 .42438 Mdot
.892 .4246 Mdot
.892 .4247 Mdot
.892 .42542 Mdot
.892 .42591 Mdot
.892 .42609 Mdot
.892 .42621 Mdot
.892 .42631 Mdot
.892 .42633 Mdot
.892 .42644 Mdot
.892 .42708 Mdot
.892 .42728 Mdot
.892 .42735 Mdot
.892 .42752 Mdot
.892 .42754 Mdot
.892 .42766 Mdot
.892 .42789 Mdot
.892 .42813 Mdot
.892 .42892 Mdot
.892 .42936 Mdot
.892 .43016 Mdot
.892 .43021 Mdot
.892 .43051 Mdot
.892 .43072 Mdot
.892 .43107 Mdot
.892 .43124 Mdot
.892 .43174 Mdot
.892 .43205 Mdot
.892 .43235 Mdot
.892 .43257 Mdot
.892 .43517 Mdot
.892 .43534 Mdot
.892 .43536 Mdot
.892 .43538 Mdot
.892 .43728 Mdot
.892 .43749 Mdot
.892 .43796 Mdot
.892 .43855 Mdot
.892 .43923 Mdot
.892 .43926 Mdot
.892 .44067 Mdot
.892 .44081 Mdot
.892 .44114 Mdot
.892 .44117 Mdot
.892 .44123 Mdot
.892 .44162 Mdot
.892 .44177 Mdot
.892 .44309 Mdot
.892 .44402 Mdot
.892 .44412 Mdot
.892 .44418 Mdot
.892 .44437 Mdot
.892 .44491 Mdot
.892 .44652 Mdot
.892 .44688 Mdot
.892 .44695 Mdot
.892 .44701 Mdot
.892 .44777 Mdot
.892 .44824 Mdot
.892 .44858 Mdot
.892 .4486 Mdot
.892 .44873 Mdot
.892 .44906 Mdot
.892 .44909 Mdot
.892 .44942 Mdot
.892 .44947 Mdot
.892 .4495 Mdot
.892 .44984 Mdot
.892 .44998 Mdot
.892 .45016 Mdot
.892 .45031 Mdot
.892 .45078 Mdot
.892 .45091 Mdot
.892 .4512 Mdot
.892 .45127 Mdot
.892 .45144 Mdot
.892 .45163 Mdot
.892 .45298 Mdot
.892 .45314 Mdot
.892 .45413 Mdot
.892 .45444 Mdot
.892 .45456 Mdot
.892 .45479 Mdot
.892 .4552 Mdot
.892 .45553 Mdot
.892 .45564 Mdot
.892 .45589 Mdot
.892 .45596 Mdot
.892 .45627 Mdot
.892 .45655 Mdot
.892 .45682 Mdot
.892 .45725 Mdot
.892 .45725 Mdot
.892 .45855 Mdot
.892 .45872 Mdot
.892 .4589 Mdot
.892 .45907 Mdot
.892 .45934 Mdot
.892 .45994 Mdot
.892 .4602 Mdot
.892 .46122 Mdot
.892 .46223 Mdot
.892 .46223 Mdot
.892 .4623 Mdot
.892 .46236 Mdot
.892 .46237 Mdot
.892 .4628 Mdot
.892 .46287 Mdot
.892 .46313 Mdot
.892 .46349 Mdot
.892 .46402 Mdot
.892 .46407 Mdot
.892 .46407 Mdot
.892 .46479 Mdot
.892 .46522 Mdot
.892 .46563 Mdot
.892 .46563 Mdot
.892 .46577 Mdot
.892 .46604 Mdot
.892 .46617 Mdot
.892 .46628 Mdot
.892 .46753 Mdot
.892 .46762 Mdot
.892 .46766 Mdot
.892 .46786 Mdot
.892 .46807 Mdot
.892 .46809 Mdot
.892 .46835 Mdot
.892 .46979 Mdot
.892 .47008 Mdot
.892 .4705 Mdot
.892 .47129 Mdot
.892 .47151 Mdot
.892 .4725 Mdot
.892 .47251 Mdot
.892 .47355 Mdot
.892 .47414 Mdot
.892 .47453 Mdot
.892 .47493 Mdot
.892 .47497 Mdot
.892 .47497 Mdot
.892 .47505 Mdot
.892 .47511 Mdot
.892 .47535 Mdot
.892 .47563 Mdot
.892 .47596 Mdot
.892 .47726 Mdot
.892 .47727 Mdot
.892 .47771 Mdot
.892 .47786 Mdot
.892 .47812 Mdot
.892 .47869 Mdot
.892 .47891 Mdot
.892 .47903 Mdot
.892 .47924 Mdot
.892 .4798 Mdot
.892 .47993 Mdot
.892 .4801 Mdot
.892 .48021 Mdot
.892 .48111 Mdot
.892 .48257 Mdot
.892 .48259 Mdot
.892 .48301 Mdot
.892 .48309 Mdot
.892 .48391 Mdot
.892 .48394 Mdot
.892 .48415 Mdot
.892 .48493 Mdot
.892 .48531 Mdot
.892 .48564 Mdot
.892 .48616 Mdot
.892 .48645 Mdot
.892 .48655 Mdot
.892 .48697 Mdot
.892 .48705 Mdot
.892 .48739 Mdot
.892 .48765 Mdot
.892 .48802 Mdot
.892 .48824 Mdot
.892 .48899 Mdot
.892 .48905 Mdot
.892 .48941 Mdot
.892 .48958 Mdot
.892 .48988 Mdot
.892 .49016 Mdot
.892 .49044 Mdot
.892 .49044 Mdot
.892 .49086 Mdot
.892 .49111 Mdot
.892 .49176 Mdot
.892 .4918 Mdot
.892 .49208 Mdot
.892 .49234 Mdot
.892 .49249 Mdot
.892 .49287 Mdot
.892 .49339 Mdot
.892 .49385 Mdot
.892 .49408 Mdot
.892 .49441 Mdot
.892 .4945 Mdot
.892 .4962 Mdot
.892 .4967 Mdot
.892 .49701 Mdot
.892 .49751 Mdot
.892 .49824 Mdot
.892 .49844 Mdot
.892 .49873 Mdot
.892 .49882 Mdot
.892 .49921 Mdot
.892 .49951 Mdot
.892 .49958 Mdot
.892 .49994 Mdot
.892 .5018 Mdot
.892 .50199 Mdot
.892 .50241 Mdot
.892 .50256 Mdot
.892 .50261 Mdot
.892 .50284 Mdot
.892 .50294 Mdot
.892 .503 Mdot
.892 .50305 Mdot
.892 .50317 Mdot
.892 .50338 Mdot
.892 .50343 Mdot
.892 .50381 Mdot
.892 .50411 Mdot
.892 .50451 Mdot
.892 .50456 Mdot
.892 .50531 Mdot
.892 .50532 Mdot
.892 .506 Mdot
.892 .50646 Mdot
.892 .50649 Mdot
.892 .50694 Mdot
.892 .50708 Mdot
.892 .50752 Mdot
.892 .50783 Mdot
.892 .508 Mdot
.892 .50858 Mdot
.892 .5087 Mdot
.892 .50885 Mdot
.892 .50923 Mdot
.892 .50956 Mdot
.892 .50973 Mdot
.892 .50989 Mdot
.892 .51 Mdot
.892 .51069 Mdot
.892 .51105 Mdot
.892 .51146 Mdot
.892 .51153 Mdot
.892 .51178 Mdot
.892 .51194 Mdot
.892 .51226 Mdot
.892 .51262 Mdot
.892 .51287 Mdot
.892 .51289 Mdot
.892 .51305 Mdot
.892 .51357 Mdot
.892 .5136 Mdot
.892 .51409 Mdot
.892 .51417 Mdot
.892 .51467 Mdot
.892 .5152 Mdot
.892 .51536 Mdot
.892 .51555 Mdot
.892 .5165 Mdot
.892 .51671 Mdot
.892 .51681 Mdot
.892 .51694 Mdot
.892 .51733 Mdot
.892 .5178 Mdot
.892 .51807 Mdot
.892 .51827 Mdot
.892 .51876 Mdot
.892 .52077 Mdot
.892 .52159 Mdot
.892 .52186 Mdot
.892 .52228 Mdot
.892 .52274 Mdot
.892 .52313 Mdot
.892 .52321 Mdot
.892 .52493 Mdot
.892 .52526 Mdot
.892 .52554 Mdot
.892 .5257 Mdot
.892 .52576 Mdot
.892 .52604 Mdot
.892 .52717 Mdot
.892 .52773 Mdot
.892 .52811 Mdot
.892 .52826 Mdot
.892 .52832 Mdot
.892 .52841 Mdot
.892 .52863 Mdot
.892 .52901 Mdot
.892 .52904 Mdot
.892 .52905 Mdot
.892 .52966 Mdot
.892 .53187 Mdot
.892 .532 Mdot
.892 .53321 Mdot
.892 .53355 Mdot
.892 .53368 Mdot
.892 .53443 Mdot
.892 .53493 Mdot
.892 .53498 Mdot
.892 .53509 Mdot
.892 .5351 Mdot
.892 .53521 Mdot
.892 .53562 Mdot
.892 .53589 Mdot
.892 .53599 Mdot
.892 .53626 Mdot
.892 .53659 Mdot
.892 .53669 Mdot
.892 .53743 Mdot
.892 .53793 Mdot
.892 .53831 Mdot
.892 .53847 Mdot
.892 .53948 Mdot
.892 .53977 Mdot
.892 .54065 Mdot
.892 .54068 Mdot
.892 .54073 Mdot
.894 .12786 Mdot
.894 .12814 Mdot
.894 .12832 Mdot
.894 .13161 Mdot
.894 .13182 Mdot
.894 .13209 Mdot
.894 .13348 Mdot
.894 .13437 Mdot
.894 .13571 Mdot
.894 .13617 Mdot
.894 .1364 Mdot
.894 .1366 Mdot
.894 .13695 Mdot
.894 .13736 Mdot
.894 .13809 Mdot
.894 .1383 Mdot
.894 .13948 Mdot
.894 .13985 Mdot
.894 .13993 Mdot
.894 .14077 Mdot
.894 .14134 Mdot
.894 .14183 Mdot
.894 .14225 Mdot
.894 .14229 Mdot
.894 .14256 Mdot
.894 .14277 Mdot
.894 .14646 Mdot
.894 .14647 Mdot
.894 .14656 Mdot
.894 .14676 Mdot
.894 .14758 Mdot
.894 .14815 Mdot
.894 .14819 Mdot
.894 .14843 Mdot
.894 .14977 Mdot
.894 .15043 Mdot
.894 .15105 Mdot
.894 .15184 Mdot
.894 .15256 Mdot
.894 .15266 Mdot
.894 .15355 Mdot
.894 .15435 Mdot
.894 .1546 Mdot
.894 .15755 Mdot
.894 .15898 Mdot
.894 .15946 Mdot
.894 .16004 Mdot
.894 .16033 Mdot
.894 .16094 Mdot
.894 .16108 Mdot
.894 .16176 Mdot
.894 .16201 Mdot
.894 .16254 Mdot
.894 .163 Mdot
.894 .16322 Mdot
.894 .16469 Mdot
.894 .16522 Mdot
.894 .16549 Mdot
.894 .16569 Mdot
.894 .16575 Mdot
.894 .16597 Mdot
.894 .16753 Mdot
.894 .16894 Mdot
.894 .16922 Mdot
.894 .16959 Mdot
.894 .16962 Mdot
.894 .16978 Mdot
.894 .16999 Mdot
.894 .17142 Mdot
.894 .17177 Mdot
.894 .17184 Mdot
.894 .17213 Mdot
.894 .17367 Mdot
.894 .17383 Mdot
.894 .17393 Mdot
.894 .1771 Mdot
.894 .17743 Mdot
.894 .17832 Mdot
.894 .17938 Mdot
.894 .18202 Mdot
.894 .18204 Mdot
.894 .1832 Mdot
.894 .18412 Mdot
.894 .18427 Mdot
.894 .18456 Mdot
.894 .1846 Mdot
.894 .18512 Mdot
.894 .18607 Mdot
.894 .18637 Mdot
.894 .18651 Mdot
.894 .18723 Mdot
.894 .18799 Mdot
.894 .18875 Mdot
.894 .18985 Mdot
.894 .19031 Mdot
.894 .19248 Mdot
.894 .19365 Mdot
.894 .19368 Mdot
.894 .19606 Mdot
.894 .19743 Mdot
.894 .19845 Mdot
.894 .19881 Mdot
.894 .19892 Mdot
.894 .19959 Mdot
.894 .20022 Mdot
.894 .20091 Mdot
.894 .20295 Mdot
.894 .20318 Mdot
.894 .20496 Mdot
.894 .20623 Mdot
.894 .2063 Mdot
.894 .20646 Mdot
.894 .20658 Mdot
.894 .20667 Mdot
.894 .2077 Mdot
.894 .20806 Mdot
.894 .20806 Mdot
.894 .20924 Mdot
.894 .2094 Mdot
.894 .20959 Mdot
.894 .21145 Mdot
.894 .21227 Mdot
.894 .21231 Mdot
.894 .21294 Mdot
.894 .21371 Mdot
.894 .21421 Mdot
.894 .2157 Mdot
.894 .21627 Mdot
.894 .21628 Mdot
.894 .21702 Mdot
.894 .21744 Mdot
.894 .21751 Mdot
.894 .21784 Mdot
.894 .21816 Mdot
.894 .21912 Mdot
.894 .21928 Mdot
.894 .21948 Mdot
.894 .22007 Mdot
.894 .22067 Mdot
.894 .22081 Mdot
.894 .22196 Mdot
.894 .22289 Mdot
.894 .22316 Mdot
.894 .22372 Mdot
.894 .2241 Mdot
.894 .22441 Mdot
.894 .22458 Mdot
.894 .22459 Mdot
.894 .2247 Mdot
.894 .22507 Mdot
.894 .22512 Mdot
.894 .22598 Mdot
.894 .22707 Mdot
.894 .22718 Mdot
.894 .22723 Mdot
.894 .22756 Mdot
.894 .22761 Mdot
.894 .22791 Mdot
.894 .22865 Mdot
.894 .22903 Mdot
.894 .23073 Mdot
.894 .23105 Mdot
.894 .23106 Mdot
.894 .23188 Mdot
.894 .23203 Mdot
.894 .23228 Mdot
.894 .23264 Mdot
.894 .23286 Mdot
.894 .23293 Mdot
.894 .23327 Mdot
.894 .23373 Mdot
.894 .23375 Mdot
.894 .234 Mdot
.894 .23431 Mdot
.894 .23433 Mdot
.894 .23479 Mdot
.894 .23481 Mdot
.894 .23531 Mdot
.894 .23568 Mdot
.894 .2358 Mdot
.894 .23642 Mdot
.894 .23665 Mdot
.894 .23723 Mdot
.894 .23779 Mdot
.894 .23785 Mdot
.894 .238 Mdot
.894 .23803 Mdot
.894 .23841 Mdot
.894 .23846 Mdot
.894 .23859 Mdot
.894 .23875 Mdot
.894 .23887 Mdot
.894 .2401 Mdot
.894 .24028 Mdot
.894 .24087 Mdot
.894 .24112 Mdot
.894 .24151 Mdot
.894 .24186 Mdot
.894 .242 Mdot
.894 .24217 Mdot
.894 .24252 Mdot
.894 .24276 Mdot
.894 .24283 Mdot
.894 .24331 Mdot
.894 .24368 Mdot
.894 .24382 Mdot
.894 .24387 Mdot
.894 .24442 Mdot
.894 .24492 Mdot
.894 .24779 Mdot
.894 .24815 Mdot
.894 .24893 Mdot
.894 .24902 Mdot
.894 .2491 Mdot
.894 .25028 Mdot
.894 .25029 Mdot
.894 .25034 Mdot
.894 .25045 Mdot
.894 .25045 Mdot
.894 .25081 Mdot
.894 .25224 Mdot
.894 .25227 Mdot
.894 .25308 Mdot
.894 .2533 Mdot
.894 .25337 Mdot
.894 .25353 Mdot
.894 .2538 Mdot
.894 .2539 Mdot
.894 .25495 Mdot
.894 .25619 Mdot
.894 .25655 Mdot
.894 .25738 Mdot
.894 .25849 Mdot
.894 .2586 Mdot
.894 .25947 Mdot
.894 .25968 Mdot
.894 .2599 Mdot
.894 .26079 Mdot
.894 .26086 Mdot
.894 .26118 Mdot
.894 .26137 Mdot
.894 .26148 Mdot
.894 .26201 Mdot
.894 .26295 Mdot
.894 .26299 Mdot
.894 .2643 Mdot
.894 .26438 Mdot
.894 .26439 Mdot
.894 .26483 Mdot
.894 .26486 Mdot
.894 .26566 Mdot
.894 .26601 Mdot
.894 .26618 Mdot
.894 .26732 Mdot
.894 .26768 Mdot
.894 .26805 Mdot
.894 .26903 Mdot
.894 .26953 Mdot
.894 .26986 Mdot
.894 .26997 Mdot
.894 .27011 Mdot
.894 .27097 Mdot
.894 .27138 Mdot
.894 .27141 Mdot
.894 .27165 Mdot
.894 .27266 Mdot
.894 .27342 Mdot
.894 .27352 Mdot
.894 .27373 Mdot
.894 .27456 Mdot
.894 .27507 Mdot
.894 .27525 Mdot
.894 .27583 Mdot
.894 .27583 Mdot
.894 .27598 Mdot
.894 .27616 Mdot
.894 .27641 Mdot
.894 .27764 Mdot
.894 .27808 Mdot
.894 .27821 Mdot
.894 .27859 Mdot
.894 .27887 Mdot
.894 .27899 Mdot
.894 .27903 Mdot
.894 .27956 Mdot
.894 .27985 Mdot
.894 .28021 Mdot
.894 .28025 Mdot
.894 .28068 Mdot
.894 .28073 Mdot
.894 .28104 Mdot
.894 .28126 Mdot
.894 .28162 Mdot
.894 .28163 Mdot
.894 .28267 Mdot
.894 .28287 Mdot
.894 .28288 Mdot
.894 .28382 Mdot
.894 .2843 Mdot
.894 .28466 Mdot
.894 .28477 Mdot
.894 .28516 Mdot
.894 .28572 Mdot
.894 .28643 Mdot
.894 .28665 Mdot
.894 .28709 Mdot
.894 .28752 Mdot
.894 .28795 Mdot
.894 .28869 Mdot
.894 .2887 Mdot
.894 .28975 Mdot
.894 .28989 Mdot
.894 .29023 Mdot
.894 .29047 Mdot
.894 .29098 Mdot
.894 .29137 Mdot
.894 .29154 Mdot
.894 .29164 Mdot
.894 .29168 Mdot
.894 .29197 Mdot
.894 .29233 Mdot
.894 .29234 Mdot
.894 .29378 Mdot
.894 .2949 Mdot
.894 .29543 Mdot
.894 .29552 Mdot
.894 .29566 Mdot
.894 .29617 Mdot
.894 .29623 Mdot
.894 .29634 Mdot
.894 .29643 Mdot
.894 .29743 Mdot
.894 .29745 Mdot
.894 .29759 Mdot
.894 .29822 Mdot
.894 .29868 Mdot
.894 .29893 Mdot
.894 .29921 Mdot
.894 .2994 Mdot
.894 .30124 Mdot
.894 .30155 Mdot
.894 .30337 Mdot
.894 .30468 Mdot
.894 .30491 Mdot
.894 .30506 Mdot
.894 .30524 Mdot
.894 .30565 Mdot
.894 .30608 Mdot
.894 .30631 Mdot
.894 .30655 Mdot
.894 .30661 Mdot
.894 .30683 Mdot
.894 .30724 Mdot
.894 .30752 Mdot
.894 .30804 Mdot
.894 .30914 Mdot
.894 .31011 Mdot
.894 .3102 Mdot
.894 .31128 Mdot
.894 .31144 Mdot
.894 .31271 Mdot
.894 .31296 Mdot
.894 .31338 Mdot
.894 .31386 Mdot
.894 .31389 Mdot
.894 .31462 Mdot
.894 .31463 Mdot
.894 .31478 Mdot
.894 .31593 Mdot
.894 .31593 Mdot
.894 .31596 Mdot
.894 .31628 Mdot
.894 .31646 Mdot
.894 .31647 Mdot
.894 .31655 Mdot
.894 .31697 Mdot
.894 .31717 Mdot
.894 .31737 Mdot
.894 .31761 Mdot
.894 .31787 Mdot
.894 .3184 Mdot
.894 .31848 Mdot
.894 .3194 Mdot
.894 .31985 Mdot
.894 .32027 Mdot
.894 .3205 Mdot
.894 .32079 Mdot
.894 .32096 Mdot
.894 .3211 Mdot
.894 .32163 Mdot
.894 .32188 Mdot
.894 .32203 Mdot
.894 .32252 Mdot
.894 .32317 Mdot
.894 .32329 Mdot
.894 .32385 Mdot
.894 .32444 Mdot
.894 .32452 Mdot
.894 .32552 Mdot
.894 .3259 Mdot
.894 .32623 Mdot
.894 .32786 Mdot
.894 .32832 Mdot
.894 .32846 Mdot
.894 .32868 Mdot
.894 .33032 Mdot
.894 .33219 Mdot
.894 .33234 Mdot
.894 .33255 Mdot
.894 .3336 Mdot
.894 .33465 Mdot
.894 .3347 Mdot
.894 .33476 Mdot
.894 .3352 Mdot
.894 .3352 Mdot
.894 .33562 Mdot
.894 .33568 Mdot
.894 .33626 Mdot
.894 .33697 Mdot
.894 .33712 Mdot
.894 .33759 Mdot
.894 .33877 Mdot
.894 .33896 Mdot
.894 .33992 Mdot
.894 .34031 Mdot
.894 .34053 Mdot
.894 .34119 Mdot
.894 .3413 Mdot
.894 .34141 Mdot
.894 .34229 Mdot
.894 .34239 Mdot
.894 .3427 Mdot
.894 .34296 Mdot
.894 .34323 Mdot
.894 .34341 Mdot
.894 .34388 Mdot
.894 .34407 Mdot
.894 .34452 Mdot
.894 .34457 Mdot
.894 .34469 Mdot
.894 .3448 Mdot
.894 .34528 Mdot
.894 .34546 Mdot
.894 .34577 Mdot
.894 .34639 Mdot
.894 .3464 Mdot
.894 .34657 Mdot
.894 .34763 Mdot
.894 .34803 Mdot
.894 .34846 Mdot
.894 .34902 Mdot
.894 .35101 Mdot
.894 .35128 Mdot
.894 .35169 Mdot
.894 .35191 Mdot
.894 .35238 Mdot
.894 .35279 Mdot
.894 .35282 Mdot
.894 .35297 Mdot
.894 .35333 Mdot
.894 .35385 Mdot
.894 .35396 Mdot
.894 .35427 Mdot
.894 .35443 Mdot
.894 .35488 Mdot
.894 .35564 Mdot
.894 .35574 Mdot
.894 .35622 Mdot
.894 .3564 Mdot
.894 .35714 Mdot
.894 .35726 Mdot
.894 .35735 Mdot
.894 .35756 Mdot
.894 .35777 Mdot
.894 .35793 Mdot
.894 .3581 Mdot
.894 .35821 Mdot
.894 .35978 Mdot
.894 .36005 Mdot
.894 .36042 Mdot
.894 .36042 Mdot
.894 .36075 Mdot
.894 .3608 Mdot
.894 .36126 Mdot
.894 .36131 Mdot
.894 .36156 Mdot
.894 .36253 Mdot
.894 .36278 Mdot
.894 .36281 Mdot
.894 .36315 Mdot
.894 .36316 Mdot
.894 .3634 Mdot
.894 .36354 Mdot
.894 .36435 Mdot
.894 .36501 Mdot
.894 .36542 Mdot
.894 .36593 Mdot
.894 .36601 Mdot
.894 .36647 Mdot
.894 .36749 Mdot
.894 .36754 Mdot
.894 .36793 Mdot
.894 .36801 Mdot
.894 .36814 Mdot
.894 .36853 Mdot
.894 .36853 Mdot
.894 .36913 Mdot
.894 .36926 Mdot
.894 .36933 Mdot
.894 .36939 Mdot
.894 .37017 Mdot
.894 .37051 Mdot
.894 .37085 Mdot
.894 .371 Mdot
.894 .37142 Mdot
.894 .37194 Mdot
.894 .37216 Mdot
.894 .37282 Mdot
.894 .37286 Mdot
.894 .37344 Mdot
.894 .37403 Mdot
.894 .37407 Mdot
.894 .37483 Mdot
.894 .37497 Mdot
.894 .3751 Mdot
.894 .37512 Mdot
.894 .3753 Mdot
.894 .37645 Mdot
.894 .37684 Mdot
.894 .37719 Mdot
.894 .37731 Mdot
.894 .3779 Mdot
.894 .37794 Mdot
.894 .37797 Mdot
.894 .37818 Mdot
.894 .37847 Mdot
.894 .37898 Mdot
.894 .37991 Mdot
.894 .38019 Mdot
.894 .38034 Mdot
.894 .38047 Mdot
.894 .38048 Mdot
.894 .38084 Mdot
.894 .3819 Mdot
.894 .38213 Mdot
.894 .38296 Mdot
.894 .38312 Mdot
.894 .38314 Mdot
.894 .38321 Mdot
.894 .38379 Mdot
.894 .38383 Mdot
.894 .38429 Mdot
.894 .38442 Mdot
.894 .38527 Mdot
.894 .38539 Mdot
.894 .38562 Mdot
.894 .38591 Mdot
.894 .38617 Mdot
.894 .38673 Mdot
.894 .38693 Mdot
.894 .38741 Mdot
.894 .38799 Mdot
.894 .38841 Mdot
.894 .38895 Mdot
.894 .38909 Mdot
.894 .38913 Mdot
.894 .38965 Mdot
.894 .38996 Mdot
.894 .38996 Mdot
.894 .39017 Mdot
.894 .39018 Mdot
.894 .39032 Mdot
.894 .39067 Mdot
.894 .39083 Mdot
.894 .39091 Mdot
.894 .39109 Mdot
.894 .39245 Mdot
.894 .39418 Mdot
.894 .39441 Mdot
.894 .39461 Mdot
.894 .39469 Mdot
.894 .39527 Mdot
.894 .39537 Mdot
.894 .39591 Mdot
.894 .39661 Mdot
.894 .39693 Mdot
.894 .39708 Mdot
.894 .39723 Mdot
.894 .39736 Mdot
.894 .39791 Mdot
.894 .39798 Mdot
.894 .39824 Mdot
.894 .39826 Mdot
.894 .39863 Mdot
.894 .39864 Mdot
.894 .39919 Mdot
.894 .40012 Mdot
.894 .40019 Mdot
.894 .40043 Mdot
.894 .40095 Mdot
.894 .4014 Mdot
.894 .40151 Mdot
.894 .40153 Mdot
.894 .40215 Mdot
.894 .40301 Mdot
.894 .40319 Mdot
.894 .40327 Mdot
.894 .40372 Mdot
.894 .40405 Mdot
.894 .40437 Mdot
.894 .4044 Mdot
.894 .40476 Mdot
.894 .40489 Mdot
.894 .40541 Mdot
.894 .4055 Mdot
.894 .40588 Mdot
.894 .40631 Mdot
.894 .40635 Mdot
.894 .40638 Mdot
.894 .40679 Mdot
.894 .4068 Mdot
.894 .40701 Mdot
.894 .40735 Mdot
.894 .40738 Mdot
.894 .40821 Mdot
.894 .40825 Mdot
.894 .40853 Mdot
.894 .40876 Mdot
.894 .40913 Mdot
.894 .40958 Mdot
.894 .40966 Mdot
.894 .4098 Mdot
.894 .41001 Mdot
.894 .41069 Mdot
.894 .41083 Mdot
.894 .41086 Mdot
.894 .41112 Mdot
.894 .41115 Mdot
.894 .41154 Mdot
.894 .41257 Mdot
.894 .41263 Mdot
.894 .41305 Mdot
.894 .41358 Mdot
.894 .41368 Mdot
.894 .41395 Mdot
.894 .414 Mdot
.894 .41468 Mdot
.894 .41477 Mdot
.894 .41494 Mdot
.894 .41501 Mdot
.894 .4153 Mdot
.894 .4155 Mdot
.894 .41558 Mdot
.894 .4156 Mdot
.894 .41583 Mdot
.894 .41609 Mdot
.894 .41659 Mdot
.894 .41771 Mdot
.894 .41802 Mdot
.894 .41826 Mdot
.894 .41907 Mdot
.894 .41918 Mdot
.894 .41952 Mdot
.894 .4197 Mdot
.894 .42007 Mdot
.894 .42013 Mdot
.894 .42019 Mdot
.894 .42022 Mdot
.894 .42084 Mdot
.894 .4211 Mdot
.894 .42124 Mdot
.894 .42141 Mdot
.894 .42147 Mdot
.894 .42203 Mdot
.894 .42208 Mdot
.894 .42245 Mdot
.894 .42258 Mdot
.894 .4228 Mdot
.894 .42344 Mdot
.894 .4241 Mdot
.894 .42436 Mdot
.894 .42445 Mdot
.894 .42484 Mdot
.894 .42517 Mdot
.894 .4252 Mdot
.894 .42544 Mdot
.894 .42544 Mdot
.894 .42568 Mdot
.894 .42633 Mdot
.894 .42704 Mdot
.894 .42712 Mdot
.894 .42816 Mdot
.894 .42921 Mdot
.894 .42928 Mdot
.894 .43045 Mdot
.894 .43085 Mdot
.894 .43145 Mdot
.894 .43179 Mdot
.894 .4321 Mdot
.894 .43253 Mdot
.894 .4328 Mdot
.894 .4334 Mdot
.894 .43349 Mdot
.894 .43366 Mdot
.894 .43379 Mdot
.894 .43402 Mdot
.894 .43541 Mdot
.894 .43552 Mdot
.894 .43563 Mdot
.894 .43587 Mdot
.894 .43591 Mdot
.894 .43592 Mdot
.894 .43602 Mdot
.894 .43621 Mdot
.894 .43621 Mdot
.894 .43686 Mdot
.894 .43694 Mdot
.894 .43695 Mdot
.894 .43764 Mdot
.894 .43788 Mdot
.894 .43801 Mdot
.894 .43873 Mdot
.894 .43881 Mdot
.894 .43942 Mdot
.894 .43947 Mdot
.894 .44062 Mdot
.894 .44092 Mdot
.894 .4413 Mdot
.894 .44143 Mdot
.894 .44146 Mdot
.894 .44159 Mdot
.894 .44172 Mdot
.894 .44219 Mdot
.894 .44238 Mdot
.894 .4425 Mdot
.894 .44324 Mdot
.894 .44425 Mdot
.894 .44443 Mdot
.894 .44586 Mdot
.894 .44612 Mdot
.894 .44647 Mdot
.894 .44655 Mdot
.894 .44656 Mdot
.894 .44712 Mdot
.894 .44717 Mdot
.894 .44723 Mdot
.894 .44768 Mdot
.894 .4486 Mdot
.894 .44941 Mdot
.894 .44985 Mdot
.894 .44995 Mdot
.894 .45059 Mdot
.894 .45078 Mdot
.894 .45086 Mdot
.894 .45144 Mdot
.894 .45145 Mdot
.894 .4521 Mdot
.894 .45234 Mdot
.894 .45259 Mdot
.894 .45271 Mdot
.894 .45311 Mdot
.894 .45471 Mdot
.894 .45482 Mdot
.894 .4554 Mdot
.894 .4554 Mdot
.894 .4556 Mdot
.894 .45573 Mdot
.894 .4559 Mdot
.894 .45593 Mdot
.894 .45619 Mdot
.894 .45656 Mdot
.894 .45687 Mdot
.894 .45694 Mdot
.894 .4571 Mdot
.894 .45731 Mdot
.894 .45856 Mdot
.894 .45864 Mdot
.894 .45864 Mdot
.894 .45896 Mdot
.894 .45981 Mdot
.894 .45999 Mdot
.894 .46098 Mdot
.894 .46111 Mdot
.894 .46113 Mdot
.894 .46136 Mdot
.894 .46192 Mdot
.894 .46198 Mdot
.894 .46217 Mdot
.894 .46245 Mdot
.894 .46299 Mdot
.894 .4632 Mdot
.894 .4634 Mdot
.894 .46404 Mdot
.894 .46413 Mdot
.894 .46433 Mdot
.894 .46477 Mdot
.894 .46504 Mdot
.894 .46509 Mdot
.894 .46582 Mdot
.894 .46637 Mdot
.894 .46667 Mdot
.894 .46701 Mdot
.894 .46705 Mdot
.894 .46767 Mdot
.894 .46779 Mdot
.894 .46828 Mdot
.894 .46942 Mdot
.894 .47032 Mdot
.894 .47091 Mdot
.894 .47111 Mdot
.894 .47136 Mdot
.894 .47183 Mdot
.894 .47283 Mdot
.894 .47289 Mdot
.894 .47359 Mdot
.894 .47363 Mdot
.894 .47368 Mdot
.894 .47412 Mdot
.894 .47432 Mdot
.894 .47593 Mdot
.894 .47621 Mdot
.894 .47651 Mdot
.894 .47654 Mdot
.894 .47727 Mdot
.894 .47746 Mdot
.894 .47764 Mdot
.894 .47783 Mdot
.894 .47819 Mdot
.894 .47852 Mdot
.894 .47931 Mdot
.894 .47938 Mdot
.894 .47957 Mdot
.894 .47978 Mdot
.894 .47988 Mdot
.894 .48023 Mdot
.894 .48055 Mdot
.894 .48068 Mdot
.894 .48103 Mdot
.894 .48158 Mdot
.894 .48159 Mdot
.894 .48185 Mdot
.894 .48186 Mdot
.894 .48218 Mdot
.894 .48219 Mdot
.894 .48263 Mdot
.894 .48267 Mdot
.894 .48314 Mdot
.894 .48368 Mdot
.894 .48386 Mdot
.894 .48482 Mdot
.894 .48544 Mdot
.894 .48561 Mdot
.894 .48564 Mdot
.894 .48582 Mdot
.894 .48585 Mdot
.894 .48652 Mdot
.894 .487 Mdot
.894 .48703 Mdot
.894 .48724 Mdot
.894 .4873 Mdot
.894 .4874 Mdot
.894 .4881 Mdot
.894 .48825 Mdot
.894 .48877 Mdot
.894 .48941 Mdot
.894 .48949 Mdot
.894 .48982 Mdot
.894 .49016 Mdot
.894 .49027 Mdot
.894 .49036 Mdot
.894 .4909 Mdot
.894 .4913 Mdot
.894 .49194 Mdot
.894 .49195 Mdot
.894 .49227 Mdot
.894 .4931 Mdot
.894 .49338 Mdot
.894 .49382 Mdot
.894 .49417 Mdot
.894 .49419 Mdot
.894 .49465 Mdot
.894 .49569 Mdot
.894 .49579 Mdot
.894 .49588 Mdot
.894 .49654 Mdot
.894 .49654 Mdot
.894 .49674 Mdot
.894 .49732 Mdot
.894 .49737 Mdot
.894 .49744 Mdot
.894 .49753 Mdot
.894 .49757 Mdot
.894 .49828 Mdot
.894 .49927 Mdot
.894 .4994 Mdot
.894 .50054 Mdot
.894 .50093 Mdot
.894 .50128 Mdot
.894 .50166 Mdot
.894 .50172 Mdot
.894 .50192 Mdot
.894 .50249 Mdot
.894 .50326 Mdot
.894 .50459 Mdot
.894 .5046 Mdot
.894 .50526 Mdot
.894 .50647 Mdot
.894 .50673 Mdot
.894 .50734 Mdot
.894 .50777 Mdot
.894 .50819 Mdot
.894 .5086 Mdot
.894 .50867 Mdot
.894 .50884 Mdot
.894 .50937 Mdot
.894 .50966 Mdot
.894 .50969 Mdot
.894 .50985 Mdot
.894 .50993 Mdot
.894 .51045 Mdot
.894 .5111 Mdot
.894 .5111 Mdot
.894 .51258 Mdot
.894 .51317 Mdot
.894 .51368 Mdot
.894 .51386 Mdot
.894 .51563 Mdot
.894 .51569 Mdot
.894 .51577 Mdot
.894 .51664 Mdot
.894 .5168 Mdot
.894 .51684 Mdot
.894 .51704 Mdot
.894 .51784 Mdot
.894 .51795 Mdot
.894 .51804 Mdot
.894 .51806 Mdot
.894 .51826 Mdot
.894 .51842 Mdot
.894 .51921 Mdot
.894 .52008 Mdot
.894 .52021 Mdot
.894 .52024 Mdot
.894 .52035 Mdot
.894 .5205 Mdot
.894 .5208 Mdot
.894 .52162 Mdot
.894 .52175 Mdot
.894 .522 Mdot
.894 .5223 Mdot
.894 .52244 Mdot
.894 .52282 Mdot
.894 .5229 Mdot
.894 .52324 Mdot
.894 .5234 Mdot
.894 .52372 Mdot
.894 .52399 Mdot
.894 .52479 Mdot
.894 .52644 Mdot
.894 .52658 Mdot
.894 .52703 Mdot
.894 .52753 Mdot
.894 .52758 Mdot
.894 .52798 Mdot
.894 .52843 Mdot
.894 .52877 Mdot
.894 .52915 Mdot
.894 .52989 Mdot
.894 .53003 Mdot
.894 .53005 Mdot
.894 .53037 Mdot
.894 .53083 Mdot
.894 .53094 Mdot
.894 .53099 Mdot
.894 .53099 Mdot
.894 .53306 Mdot
.894 .53317 Mdot
.894 .53333 Mdot
.894 .53335 Mdot
.894 .53358 Mdot
.894 .53386 Mdot
.894 .53418 Mdot
.894 .53465 Mdot
.894 .53469 Mdot
.894 .5349 Mdot
.894 .53556 Mdot
.894 .53568 Mdot
.894 .53609 Mdot
.894 .53631 Mdot
.894 .53651 Mdot
.894 .53662 Mdot
.894 .53675 Mdot
.894 .53701 Mdot
.894 .53776 Mdot
.894 .53825 Mdot
.894 .53903 Mdot
.894 .53918 Mdot
.894 .5393 Mdot
.894 .54114 Mdot
.894 .54124 Mdot
.894 .5414 Mdot
.896 .12657 Mdot
.896 .1268 Mdot
.896 .12701 Mdot
.896 .12773 Mdot
.896 .12838 Mdot
.896 .12948 Mdot
.896 .12957 Mdot
.896 .13058 Mdot
.896 .13105 Mdot
.896 .13258 Mdot
.896 .13311 Mdot
.896 .13364 Mdot
.896 .13396 Mdot
.896 .13436 Mdot
.896 .13444 Mdot
.896 .13457 Mdot
.896 .1348 Mdot
.896 .13556 Mdot
.896 .13587 Mdot
.896 .13789 Mdot
.896 .13791 Mdot
.896 .13817 Mdot
.896 .13932 Mdot
.896 .13984 Mdot
.896 .14002 Mdot
.896 .14007 Mdot
.896 .14054 Mdot
.896 .14093 Mdot
.896 .14181 Mdot
.896 .14501 Mdot
.896 .14514 Mdot
.896 .14574 Mdot
.896 .14595 Mdot
.896 .14602 Mdot
.896 .14603 Mdot
.896 .14606 Mdot
.896 .14658 Mdot
.896 .14697 Mdot
.896 .14727 Mdot
.896 .14833 Mdot
.896 .14877 Mdot
.896 .15065 Mdot
.896 .15066 Mdot
.896 .15119 Mdot
.896 .15282 Mdot
.896 .15326 Mdot
.896 .15353 Mdot
.896 .15398 Mdot
.896 .15401 Mdot
.896 .15415 Mdot
.896 .15561 Mdot
.896 .1562 Mdot
.896 .15702 Mdot
.896 .15741 Mdot
.896 .15754 Mdot
.896 .15889 Mdot
.896 .15955 Mdot
.896 .15969 Mdot
.896 .16222 Mdot
.896 .16359 Mdot
.896 .16415 Mdot
.896 .16464 Mdot
.896 .16687 Mdot
.896 .16786 Mdot
.896 .16788 Mdot
.896 .1681 Mdot
.896 .16921 Mdot
.896 .16952 Mdot
.896 .17007 Mdot
.896 .17088 Mdot
.896 .17129 Mdot
.896 .17324 Mdot
.896 .17364 Mdot
.896 .17481 Mdot
.896 .17521 Mdot
.896 .17552 Mdot
.896 .17561 Mdot
.896 .17678 Mdot
.896 .17795 Mdot
.896 .17973 Mdot
.896 .18044 Mdot
.896 .18079 Mdot
.896 .18088 Mdot
.896 .18109 Mdot
.896 .18163 Mdot
.896 .18199 Mdot
.896 .18286 Mdot
.896 .1832 Mdot
.896 .18429 Mdot
.896 .18442 Mdot
.896 .18442 Mdot
.896 .1847 Mdot
.896 .18504 Mdot
.896 .18539 Mdot
.896 .18712 Mdot
.896 .18721 Mdot
.896 .18743 Mdot
.896 .18838 Mdot
.896 .18902 Mdot
.896 .18908 Mdot
.896 .18909 Mdot
.896 .18929 Mdot
.896 .18971 Mdot
.896 .18976 Mdot
.896 .19018 Mdot
.896 .19052 Mdot
.896 .19063 Mdot
.896 .19064 Mdot
.896 .19128 Mdot
.896 .19259 Mdot
.896 .19328 Mdot
.896 .19343 Mdot
.896 .19346 Mdot
.896 .196 Mdot
.896 .19614 Mdot
.896 .19616 Mdot
.896 .19636 Mdot
.896 .19678 Mdot
.896 .1989 Mdot
.896 .20007 Mdot
.896 .20041 Mdot
.896 .20046 Mdot
.896 .20073 Mdot
.896 .20098 Mdot
.896 .20099 Mdot
.896 .20103 Mdot
.896 .20131 Mdot
.896 .20386 Mdot
.896 .20498 Mdot
.896 .20586 Mdot
.896 .20602 Mdot
.896 .20719 Mdot
.896 .2074 Mdot
.896 .20758 Mdot
.896 .2092 Mdot
.896 .212 Mdot
.896 .21505 Mdot
.896 .21515 Mdot
.896 .2152 Mdot
.896 .21558 Mdot
.896 .21594 Mdot
.896 .21723 Mdot
.896 .218 Mdot
.896 .2184 Mdot
.896 .2186 Mdot
.896 .21933 Mdot
.896 .22037 Mdot
.896 .22053 Mdot
.896 .22063 Mdot
.896 .22144 Mdot
.896 .22153 Mdot
.896 .22234 Mdot
.896 .2227 Mdot
.896 .22311 Mdot
.896 .22319 Mdot
.896 .22366 Mdot
.896 .22432 Mdot
.896 .22508 Mdot
.896 .22548 Mdot
.896 .22556 Mdot
.896 .22566 Mdot
.896 .22568 Mdot
.896 .22594 Mdot
.896 .22608 Mdot
.896 .22639 Mdot
.896 .22688 Mdot
.896 .22783 Mdot
.896 .22793 Mdot
.896 .2284 Mdot
.896 .2285 Mdot
.896 .22884 Mdot
.896 .22911 Mdot
.896 .22912 Mdot
.896 .22926 Mdot
.896 .2295 Mdot
.896 .2299 Mdot
.896 .23058 Mdot
.896 .23102 Mdot
.896 .23128 Mdot
.896 .2313 Mdot
.896 .23182 Mdot
.896 .23296 Mdot
.896 .23544 Mdot
.896 .23548 Mdot
.896 .23594 Mdot
.896 .23621 Mdot
.896 .23714 Mdot
.896 .23733 Mdot
.896 .23768 Mdot
.896 .238 Mdot
.896 .23845 Mdot
.896 .23894 Mdot
.896 .23926 Mdot
.896 .23935 Mdot
.896 .24004 Mdot
.896 .2402 Mdot
.896 .24089 Mdot
.896 .24158 Mdot
.896 .24197 Mdot
.896 .24224 Mdot
.896 .24228 Mdot
.896 .24228 Mdot
.896 .24248 Mdot
.896 .24404 Mdot
.896 .24467 Mdot
.896 .24515 Mdot
.896 .24601 Mdot
.896 .24629 Mdot
.896 .24718 Mdot
.896 .24787 Mdot
.896 .2482 Mdot
.896 .24844 Mdot
.896 .24876 Mdot
.896 .24928 Mdot
.896 .24935 Mdot
.896 .2495 Mdot
.896 .24956 Mdot
.896 .24988 Mdot
.896 .25001 Mdot
.896 .25001 Mdot
.896 .25003 Mdot
.896 .25009 Mdot
.896 .25054 Mdot
.896 .25079 Mdot
.896 .25099 Mdot
.896 .25102 Mdot
.896 .25118 Mdot
.896 .25172 Mdot
.896 .25226 Mdot
.896 .25254 Mdot
.896 .25265 Mdot
.896 .25302 Mdot
.896 .25304 Mdot
.896 .25355 Mdot
.896 .25365 Mdot
.896 .25374 Mdot
.896 .25415 Mdot
.896 .25494 Mdot
.896 .25521 Mdot
.896 .25591 Mdot
.896 .25627 Mdot
.896 .25683 Mdot
.896 .25775 Mdot
.896 .25832 Mdot
.896 .25832 Mdot
.896 .25928 Mdot
.896 .25945 Mdot
.896 .2601 Mdot
.896 .26113 Mdot
.896 .26221 Mdot
.896 .26289 Mdot
.896 .26298 Mdot
.896 .26341 Mdot
.896 .26348 Mdot
.896 .26428 Mdot
.896 .26433 Mdot
.896 .26459 Mdot
.896 .26474 Mdot
.896 .26515 Mdot
.896 .26548 Mdot
.896 .26585 Mdot
.896 .26649 Mdot
.896 .26665 Mdot
.896 .2672 Mdot
.896 .26772 Mdot
.896 .26825 Mdot
.896 .26904 Mdot
.896 .26953 Mdot
.896 .26972 Mdot
.896 .26972 Mdot
.896 .26984 Mdot
.896 .27036 Mdot
.896 .27042 Mdot
.896 .2705 Mdot
.896 .27067 Mdot
.896 .27233 Mdot
.896 .27307 Mdot
.896 .27308 Mdot
.896 .27317 Mdot
.896 .27329 Mdot
.896 .27426 Mdot
.896 .2745 Mdot
.896 .27467 Mdot
.896 .27496 Mdot
.896 .27671 Mdot
.896 .27717 Mdot
.896 .27736 Mdot
.896 .27802 Mdot
.896 .2783 Mdot
.896 .27866 Mdot
.896 .27904 Mdot
.896 .28063 Mdot
.896 .2815 Mdot
.896 .2825 Mdot
.896 .28337 Mdot
.896 .28393 Mdot
.896 .28504 Mdot
.896 .28601 Mdot
.896 .28609 Mdot
.896 .28622 Mdot
.896 .28658 Mdot
.896 .28724 Mdot
.896 .28737 Mdot
.896 .28833 Mdot
.896 .28895 Mdot
.896 .28916 Mdot
.896 .28919 Mdot
.896 .28957 Mdot
.896 .28964 Mdot
.896 .28966 Mdot
.896 .28986 Mdot
.896 .29079 Mdot
.896 .2909 Mdot
.896 .29109 Mdot
.896 .29147 Mdot
.896 .29157 Mdot
.896 .29196 Mdot
.896 .29213 Mdot
.896 .29255 Mdot
.896 .2931 Mdot
.896 .29383 Mdot
.896 .29445 Mdot
.896 .29457 Mdot
.896 .2953 Mdot
.896 .29582 Mdot
.896 .29624 Mdot
.896 .29624 Mdot
.896 .29655 Mdot
.896 .2974 Mdot
.896 .29879 Mdot
.896 .2995 Mdot
.896 .29962 Mdot
.896 .29988 Mdot
.896 .30051 Mdot
.896 .3016 Mdot
.896 .30219 Mdot
.896 .30233 Mdot
.896 .30287 Mdot
.896 .30303 Mdot
.896 .30305 Mdot
.896 .30436 Mdot
.896 .30463 Mdot
.896 .30497 Mdot
.896 .30513 Mdot
.896 .30549 Mdot
.896 .30661 Mdot
.896 .30665 Mdot
.896 .30723 Mdot
.896 .30786 Mdot
.896 .3082 Mdot
.896 .30874 Mdot
.896 .3091 Mdot
.896 .31036 Mdot
.896 .31043 Mdot
.896 .31085 Mdot
.896 .31122 Mdot
.896 .31169 Mdot
.896 .31233 Mdot
.896 .31249 Mdot
.896 .31259 Mdot
.896 .31271 Mdot
.896 .31285 Mdot
.896 .31309 Mdot
.896 .31318 Mdot
.896 .31381 Mdot
.896 .31382 Mdot
.896 .31448 Mdot
.896 .31449 Mdot
.896 .31464 Mdot
.896 .31603 Mdot
.896 .31607 Mdot
.896 .31626 Mdot
.896 .31632 Mdot
.896 .31635 Mdot
.896 .31664 Mdot
.896 .31674 Mdot
.896 .31779 Mdot
.896 .31796 Mdot
.896 .31847 Mdot
.896 .3186 Mdot
.896 .31869 Mdot
.896 .31883 Mdot
.896 .31883 Mdot
.896 .31933 Mdot
.896 .31994 Mdot
.896 .32035 Mdot
.896 .32056 Mdot
.896 .32139 Mdot
.896 .32182 Mdot
.896 .32214 Mdot
.896 .32322 Mdot
.896 .32366 Mdot
.896 .32383 Mdot
.896 .32422 Mdot
.896 .32531 Mdot
.896 .32544 Mdot
.896 .32553 Mdot
.896 .32592 Mdot
.896 .32706 Mdot
.896 .32717 Mdot
.896 .3272 Mdot
.896 .32755 Mdot
.896 .32827 Mdot
.896 .32831 Mdot
.896 .32839 Mdot
.896 .32915 Mdot
.896 .32917 Mdot
.896 .32924 Mdot
.896 .32976 Mdot
.896 .32995 Mdot
.896 .32997 Mdot
.896 .3301 Mdot
.896 .33024 Mdot
.896 .33085 Mdot
.896 .33111 Mdot
.896 .33112 Mdot
.896 .33191 Mdot
.896 .33195 Mdot
.896 .33196 Mdot
.896 .33328 Mdot
.896 .33346 Mdot
.896 .33346 Mdot
.896 .33348 Mdot
.896 .33356 Mdot
.896 .33471 Mdot
.896 .33498 Mdot
.896 .33503 Mdot
.896 .3354 Mdot
.896 .33552 Mdot
.896 .33784 Mdot
.896 .33895 Mdot
.896 .33917 Mdot
.896 .33958 Mdot
.896 .33983 Mdot
.896 .33986 Mdot
.896 .34022 Mdot
.896 .34052 Mdot
.896 .34097 Mdot
.896 .34112 Mdot
.896 .34115 Mdot
.896 .34115 Mdot
.896 .34128 Mdot
.896 .34185 Mdot
.896 .34214 Mdot
.896 .34281 Mdot
.896 .3429 Mdot
.896 .34342 Mdot
.896 .34478 Mdot
.896 .34563 Mdot
.896 .34632 Mdot
.896 .34687 Mdot
.896 .34721 Mdot
.896 .34748 Mdot
.896 .34757 Mdot
.896 .34785 Mdot
.896 .34806 Mdot
.896 .34834 Mdot
.896 .3485 Mdot
.896 .34852 Mdot
.896 .34859 Mdot
.896 .34909 Mdot
.896 .34952 Mdot
.896 .34983 Mdot
.896 .34989 Mdot
.896 .35057 Mdot
.896 .35068 Mdot
.896 .35085 Mdot
.896 .35187 Mdot
.896 .35332 Mdot
.896 .35344 Mdot
.896 .35366 Mdot
.896 .35386 Mdot
.896 .35487 Mdot
.896 .3549 Mdot
.896 .35568 Mdot
.896 .35594 Mdot
.896 .35704 Mdot
.896 .35725 Mdot
.896 .35745 Mdot
.896 .35754 Mdot
.896 .35765 Mdot
.896 .35964 Mdot
.896 .35997 Mdot
.896 .36 Mdot
.896 .36032 Mdot
.896 .36066 Mdot
.896 .36086 Mdot
.896 .36114 Mdot
.896 .36143 Mdot
.896 .36146 Mdot
.896 .36152 Mdot
.896 .36179 Mdot
.896 .36198 Mdot
.896 .36238 Mdot
.896 .363 Mdot
.896 .36313 Mdot
.896 .36322 Mdot
.896 .36426 Mdot
.896 .36498 Mdot
.896 .36601 Mdot
.896 .36702 Mdot
.896 .36752 Mdot
.896 .36779 Mdot
.896 .36826 Mdot
.896 .36881 Mdot
.896 .37109 Mdot
.896 .37218 Mdot
.896 .37225 Mdot
.896 .3734 Mdot
.896 .37367 Mdot
.896 .37371 Mdot
.896 .3739 Mdot
.896 .37399 Mdot
.896 .37423 Mdot
.896 .37425 Mdot
.896 .37466 Mdot
.896 .37472 Mdot
.896 .37475 Mdot
.896 .37532 Mdot
.896 .37608 Mdot
.896 .37642 Mdot
.896 .3765 Mdot
.896 .37665 Mdot
.896 .3771 Mdot
.896 .37733 Mdot
.896 .37763 Mdot
.896 .37766 Mdot
.896 .37872 Mdot
.896 .379 Mdot
.896 .37972 Mdot
.896 .37981 Mdot
.896 .38008 Mdot
.896 .3809 Mdot
.896 .38107 Mdot
.896 .38138 Mdot
.896 .38219 Mdot
.896 .38297 Mdot
.896 .38325 Mdot
.896 .38333 Mdot
.896 .38343 Mdot
.896 .38344 Mdot
.896 .38354 Mdot
.896 .3836 Mdot
.896 .38372 Mdot
.896 .38431 Mdot
.896 .38453 Mdot
.896 .38485 Mdot
.896 .38517 Mdot
.896 .38532 Mdot
.896 .38541 Mdot
.896 .38572 Mdot
.896 .38677 Mdot
.896 .38679 Mdot
.896 .38715 Mdot
.896 .38724 Mdot
.896 .38741 Mdot
.896 .38742 Mdot
.896 .38756 Mdot
.896 .38799 Mdot
.896 .38817 Mdot
.896 .38831 Mdot
.896 .38848 Mdot
.896 .38915 Mdot
.896 .38954 Mdot
.896 .39025 Mdot
.896 .39033 Mdot
.896 .39062 Mdot
.896 .39072 Mdot
.896 .39132 Mdot
.896 .39144 Mdot
.896 .39152 Mdot
.896 .3917 Mdot
.896 .39185 Mdot
.896 .39218 Mdot
.896 .3924 Mdot
.896 .39255 Mdot
.896 .39274 Mdot
.896 .39277 Mdot
.896 .3928 Mdot
.896 .3929 Mdot
.896 .39319 Mdot
.896 .39323 Mdot
.896 .39347 Mdot
.896 .39364 Mdot
.896 .3937 Mdot
.896 .39404 Mdot
.896 .39422 Mdot
.896 .39441 Mdot
.896 .39445 Mdot
.896 .39452 Mdot
.896 .39485 Mdot
.896 .39491 Mdot
.896 .39512 Mdot
.896 .39551 Mdot
.896 .3961 Mdot
.896 .39638 Mdot
.896 .39662 Mdot
.896 .3967 Mdot
.896 .3968 Mdot
.896 .39684 Mdot
.896 .39704 Mdot
.896 .39764 Mdot
.896 .39782 Mdot
.896 .39813 Mdot
.896 .39831 Mdot
.896 .39843 Mdot
.896 .39883 Mdot
.896 .39892 Mdot
.896 .39892 Mdot
.896 .39897 Mdot
.896 .39918 Mdot
.896 .39962 Mdot
.896 .40024 Mdot
.896 .40033 Mdot
.896 .40094 Mdot
.896 .40155 Mdot
.896 .40214 Mdot
.896 .40233 Mdot
.896 .40245 Mdot
.896 .4027 Mdot
.896 .40279 Mdot
.896 .40283 Mdot
.896 .40302 Mdot
.896 .40377 Mdot
.896 .40378 Mdot
.896 .40405 Mdot
.896 .40405 Mdot
.896 .40437 Mdot
.896 .40452 Mdot
.896 .40516 Mdot
.896 .4052 Mdot
.896 .40581 Mdot
.896 .40708 Mdot
.896 .40765 Mdot
.896 .4078 Mdot
.896 .40808 Mdot
.896 .40864 Mdot
.896 .40922 Mdot
.896 .40962 Mdot
.896 .41025 Mdot
.896 .41032 Mdot
.896 .41067 Mdot
.896 .41089 Mdot
.896 .411 Mdot
.896 .41115 Mdot
.896 .41118 Mdot
.896 .4112 Mdot
.896 .41136 Mdot
.896 .41152 Mdot
.896 .41163 Mdot
.896 .41202 Mdot
.896 .41331 Mdot
.896 .41342 Mdot
.896 .41365 Mdot
.896 .41426 Mdot
.896 .41484 Mdot
.896 .41486 Mdot
.896 .41542 Mdot
.896 .41566 Mdot
.896 .41573 Mdot
.896 .41653 Mdot
.896 .4171 Mdot
.896 .4172 Mdot
.896 .41726 Mdot
.896 .41764 Mdot
.896 .41767 Mdot
.896 .41785 Mdot
.896 .4185 Mdot
.896 .41878 Mdot
.896 .41913 Mdot
.896 .41963 Mdot
.896 .42002 Mdot
.896 .42125 Mdot
.896 .42154 Mdot
.896 .42159 Mdot
.896 .42196 Mdot
.896 .42212 Mdot
.896 .42245 Mdot
.896 .42251 Mdot
.896 .42252 Mdot
.896 .42253 Mdot
.896 .42286 Mdot
.896 .42362 Mdot
.896 .42374 Mdot
.896 .42436 Mdot
.896 .42566 Mdot
.896 .42573 Mdot
.896 .42675 Mdot
.896 .4268 Mdot
.896 .42681 Mdot
.896 .4269 Mdot
.896 .42764 Mdot
.896 .42765 Mdot
.896 .42767 Mdot
.896 .42811 Mdot
.896 .42826 Mdot
.896 .4286 Mdot
.896 .42868 Mdot
.896 .42916 Mdot
.896 .4292 Mdot
.896 .42971 Mdot
.896 .43123 Mdot
.896 .43128 Mdot
.896 .43135 Mdot
.896 .43252 Mdot
.896 .43312 Mdot
.896 .4333 Mdot
.896 .43354 Mdot
.896 .43412 Mdot
.896 .43505 Mdot
.896 .43517 Mdot
.896 .43546 Mdot
.896 .43555 Mdot
.896 .43614 Mdot
.896 .43635 Mdot
.896 .43637 Mdot
.896 .43641 Mdot
.896 .43651 Mdot
.896 .43731 Mdot
.896 .43739 Mdot
.896 .43777 Mdot
.896 .43812 Mdot
.896 .43817 Mdot
.896 .43838 Mdot
.896 .43845 Mdot
.896 .43922 Mdot
.896 .43942 Mdot
.896 .4397 Mdot
.896 .4404 Mdot
.896 .4406 Mdot
.896 .4409 Mdot
.896 .44109 Mdot
.896 .44177 Mdot
.896 .44179 Mdot
.896 .44241 Mdot
.896 .44271 Mdot
.896 .44289 Mdot
.896 .44305 Mdot
.896 .44379 Mdot
.896 .44426 Mdot
.896 .44519 Mdot
.896 .44555 Mdot
.896 .44569 Mdot
.896 .44693 Mdot
.896 .4474 Mdot
.896 .44757 Mdot
.896 .44758 Mdot
.896 .44781 Mdot
.896 .44858 Mdot
.896 .44892 Mdot
.896 .44964 Mdot
.896 .44997 Mdot
.896 .45024 Mdot
.896 .45045 Mdot
.896 .45056 Mdot
.896 .45062 Mdot
.896 .45114 Mdot
.896 .45125 Mdot
.896 .45126 Mdot
.896 .45164 Mdot
.896 .45199 Mdot
.896 .4526 Mdot
.896 .45297 Mdot
.896 .45317 Mdot
.896 .45324 Mdot
.896 .45329 Mdot
.896 .45383 Mdot
.896 .45444 Mdot
.896 .45629 Mdot
.896 .45739 Mdot
.896 .45759 Mdot
.896 .45775 Mdot
.896 .45811 Mdot
.896 .45822 Mdot
.896 .45847 Mdot
.896 .45945 Mdot
.896 .45961 Mdot
.896 .46038 Mdot
.896 .46045 Mdot
.896 .4605 Mdot
.896 .46092 Mdot
.896 .46194 Mdot
.896 .46202 Mdot
.896 .46231 Mdot
.896 .46237 Mdot
.896 .46248 Mdot
.896 .46275 Mdot
.896 .46349 Mdot
.896 .46409 Mdot
.896 .46418 Mdot
.896 .46454 Mdot
.896 .46474 Mdot
.896 .46493 Mdot
.896 .46516 Mdot
.896 .46589 Mdot
.896 .46619 Mdot
.896 .46717 Mdot
.896 .46774 Mdot
.896 .4681 Mdot
.896 .46905 Mdot
.896 .46957 Mdot
.896 .46988 Mdot
.896 .47008 Mdot
.896 .47047 Mdot
.896 .47129 Mdot
.896 .47134 Mdot
.896 .4714 Mdot
.896 .47169 Mdot
.896 .47169 Mdot
.896 .4719 Mdot
.896 .47196 Mdot
.896 .47272 Mdot
.896 .47283 Mdot
.896 .47294 Mdot
.896 .47308 Mdot
.896 .47338 Mdot
.896 .47363 Mdot
.896 .47375 Mdot
.896 .47378 Mdot
.896 .47407 Mdot
.896 .47457 Mdot
.896 .47496 Mdot
.896 .47545 Mdot
.896 .47561 Mdot
.896 .47609 Mdot
.896 .47635 Mdot
.896 .47671 Mdot
.896 .47769 Mdot
.896 .47769 Mdot
.896 .47771 Mdot
.896 .47786 Mdot
.896 .47808 Mdot
.896 .47894 Mdot
.896 .47982 Mdot
.896 .48026 Mdot
.896 .48045 Mdot
.896 .48055 Mdot
.896 .48108 Mdot
.896 .48289 Mdot
.896 .48382 Mdot
.896 .48397 Mdot
.896 .48422 Mdot
.896 .48503 Mdot
.896 .48519 Mdot
.896 .48538 Mdot
.896 .4857 Mdot
.896 .48655 Mdot
.896 .48673 Mdot
.896 .48695 Mdot
.896 .48696 Mdot
.896 .48702 Mdot
.896 .48707 Mdot
.896 .48728 Mdot
.896 .48771 Mdot
.896 .48808 Mdot
.896 .48838 Mdot
.896 .48862 Mdot
.896 .48927 Mdot
.896 .48932 Mdot
.896 .48977 Mdot
.896 .4905 Mdot
.896 .4909 Mdot
.896 .49124 Mdot
.896 .4928 Mdot
.896 .49288 Mdot
.896 .49458 Mdot
.896 .49615 Mdot
.896 .49705 Mdot
.896 .49715 Mdot
.896 .49727 Mdot
.896 .49792 Mdot
.896 .49801 Mdot
.896 .4985 Mdot
.896 .49913 Mdot
.896 .50055 Mdot
.896 .50071 Mdot
.896 .50073 Mdot
.896 .50074 Mdot
.896 .50087 Mdot
.896 .50102 Mdot
.896 .50105 Mdot
.896 .50124 Mdot
.896 .50189 Mdot
.896 .50308 Mdot
.896 .50331 Mdot
.896 .50343 Mdot
.896 .50343 Mdot
.896 .50351 Mdot
.896 .50493 Mdot
.896 .50495 Mdot
.896 .50503 Mdot
.896 .50542 Mdot
.896 .50615 Mdot
.896 .50651 Mdot
.896 .50651 Mdot
.896 .50657 Mdot
.896 .50676 Mdot
.896 .507 Mdot
.896 .50702 Mdot
.896 .50726 Mdot
.896 .50737 Mdot
.896 .50738 Mdot
.896 .50741 Mdot
.896 .50777 Mdot
.896 .5083 Mdot
.896 .50842 Mdot
.896 .50847 Mdot
.896 .50944 Mdot
.896 .50963 Mdot
.896 .50982 Mdot
.896 .50997 Mdot
.896 .50998 Mdot
.896 .51005 Mdot
.896 .51066 Mdot
.896 .51085 Mdot
.896 .51133 Mdot
.896 .51154 Mdot
.896 .51184 Mdot
.896 .51195 Mdot
.896 .512 Mdot
.896 .5122 Mdot
.896 .51259 Mdot
.896 .51359 Mdot
.896 .51424 Mdot
.896 .51489 Mdot
.896 .51494 Mdot
.896 .51511 Mdot
.896 .51534 Mdot
.896 .51599 Mdot
.896 .51622 Mdot
.896 .5173 Mdot
.896 .51753 Mdot
.896 .51799 Mdot
.896 .51829 Mdot
.896 .51846 Mdot
.896 .51909 Mdot
.896 .51921 Mdot
.896 .51922 Mdot
.896 .51977 Mdot
.896 .52102 Mdot
.896 .52129 Mdot
.896 .5216 Mdot
.896 .52237 Mdot
.896 .52378 Mdot
.896 .52385 Mdot
.896 .52422 Mdot
.896 .52497 Mdot
.896 .52505 Mdot
.896 .52527 Mdot
.896 .52573 Mdot
.896 .52605 Mdot
.896 .52687 Mdot
.896 .52695 Mdot
.896 .52696 Mdot
.896 .52721 Mdot
.896 .52737 Mdot
.896 .52761 Mdot
.896 .52852 Mdot
.896 .52882 Mdot
.896 .52882 Mdot
.896 .52987 Mdot
.896 .53012 Mdot
.896 .5307 Mdot
.896 .53087 Mdot
.896 .53109 Mdot
.896 .53138 Mdot
.896 .5314 Mdot
.896 .53141 Mdot
.896 .53145 Mdot
.896 .53156 Mdot
.896 .5319 Mdot
.896 .53197 Mdot
.896 .53375 Mdot
.896 .53425 Mdot
.896 .53446 Mdot
.896 .53473 Mdot
.896 .53475 Mdot
.896 .53485 Mdot
.896 .53515 Mdot
.896 .53579 Mdot
.896 .53593 Mdot
.896 .53594 Mdot
.896 .53707 Mdot
.896 .53724 Mdot
.896 .53767 Mdot
.896 .53779 Mdot
.896 .53787 Mdot
.896 .53791 Mdot
.896 .53813 Mdot
.896 .53831 Mdot
.896 .53861 Mdot
.896 .5389 Mdot
.896 .53976 Mdot
.896 .54002 Mdot
.896 .54059 Mdot
.896 .54064 Mdot
.896 .54125 Mdot
.896 .54161 Mdot
.896 .54201 Mdot
.896 .54213 Mdot
.896 .54226 Mdot
.898 .12296 Mdot
.898 .12424 Mdot
.898 .12648 Mdot
.898 .1272 Mdot
.898 .12873 Mdot
.898 .13032 Mdot
.898 .13315 Mdot
.898 .13323 Mdot
.898 .13348 Mdot
.898 .13435 Mdot
.898 .13582 Mdot
.898 .13639 Mdot
.898 .13701 Mdot
.898 .13716 Mdot
.898 .13748 Mdot
.898 .13812 Mdot
.898 .13853 Mdot
.898 .13868 Mdot
.898 .13964 Mdot
.898 .13986 Mdot
.898 .1409 Mdot
.898 .14197 Mdot
.898 .14271 Mdot
.898 .14281 Mdot
.898 .14338 Mdot
.898 .1434 Mdot
.898 .14399 Mdot
.898 .1449 Mdot
.898 .14509 Mdot
.898 .14614 Mdot
.898 .14755 Mdot
.898 .1478 Mdot
.898 .14885 Mdot
.898 .14927 Mdot
.898 .14934 Mdot
.898 .14937 Mdot
.898 .14946 Mdot
.898 .14985 Mdot
.898 .15045 Mdot
.898 .15066 Mdot
.898 .15088 Mdot
.898 .15096 Mdot
.898 .15274 Mdot
.898 .15279 Mdot
.898 .15393 Mdot
.898 .1543 Mdot
.898 .15435 Mdot
.898 .1545 Mdot
.898 .15461 Mdot
.898 .15473 Mdot
.898 .15503 Mdot
.898 .15557 Mdot
.898 .15569 Mdot
.898 .15586 Mdot
.898 .15617 Mdot
.898 .15627 Mdot
.898 .15844 Mdot
.898 .15952 Mdot
.898 .16205 Mdot
.898 .16241 Mdot
.898 .16267 Mdot
.898 .16307 Mdot
.898 .16323 Mdot
.898 .16413 Mdot
.898 .1655 Mdot
.898 .16614 Mdot
.898 .16725 Mdot
.898 .16967 Mdot
.898 .17009 Mdot
.898 .17026 Mdot
.898 .17087 Mdot
.898 .17148 Mdot
.898 .17198 Mdot
.898 .17212 Mdot
.898 .1728 Mdot
.898 .1732 Mdot
.898 .17328 Mdot
.898 .17339 Mdot
.898 .17349 Mdot
.898 .17358 Mdot
.898 .17418 Mdot
.898 .17437 Mdot
.898 .1754 Mdot
.898 .1755 Mdot
.898 .17601 Mdot
.898 .17661 Mdot
.898 .17793 Mdot
.898 .1808 Mdot
.898 .18144 Mdot
.898 .18161 Mdot
.898 .18168 Mdot
.898 .18299 Mdot
.898 .18323 Mdot
.898 .18356 Mdot
.898 .1844 Mdot
.898 .18445 Mdot
.898 .18467 Mdot
.898 .18584 Mdot
.898 .18736 Mdot
.898 .18745 Mdot
.898 .18773 Mdot
.898 .18908 Mdot
.898 .18935 Mdot
.898 .19012 Mdot
.898 .19017 Mdot
.898 .19045 Mdot
.898 .19064 Mdot
.898 .1908 Mdot
.898 .19138 Mdot
.898 .19157 Mdot
.898 .19217 Mdot
.898 .19256 Mdot
.898 .19295 Mdot
.898 .19373 Mdot
.898 .19398 Mdot
.898 .19476 Mdot
.898 .1954 Mdot
.898 .19583 Mdot
.898 .19596 Mdot
.898 .19685 Mdot
.898 .19692 Mdot
.898 .19702 Mdot
.898 .19727 Mdot
.898 .19732 Mdot
.898 .19933 Mdot
.898 .2002 Mdot
.898 .20075 Mdot
.898 .20103 Mdot
.898 .20157 Mdot
.898 .20159 Mdot
.898 .2024 Mdot
.898 .20384 Mdot
.898 .20567 Mdot
.898 .20602 Mdot
.898 .20837 Mdot
.898 .20868 Mdot
.898 .20894 Mdot
.898 .20912 Mdot
.898 .2098 Mdot
.898 .2098 Mdot
.898 .21114 Mdot
.898 .21142 Mdot
.898 .21271 Mdot
.898 .21393 Mdot
.898 .21433 Mdot
.898 .21483 Mdot
.898 .21544 Mdot
.898 .21566 Mdot
.898 .21674 Mdot
.898 .21716 Mdot
.898 .21743 Mdot
.898 .21805 Mdot
.898 .21869 Mdot
.898 .21948 Mdot
.898 .21963 Mdot
.898 .21999 Mdot
.898 .22001 Mdot
.898 .22054 Mdot
.898 .22069 Mdot
.898 .22077 Mdot
.898 .2213 Mdot
.898 .22234 Mdot
.898 .22317 Mdot
.898 .2259 Mdot
.898 .22609 Mdot
.898 .22644 Mdot
.898 .22651 Mdot
.898 .22685 Mdot
.898 .22742 Mdot
.898 .22745 Mdot
.898 .22756 Mdot
.898 .22764 Mdot
.898 .22801 Mdot
.898 .22808 Mdot
.898 .22886 Mdot
.898 .22917 Mdot
.898 .22928 Mdot
.898 .22958 Mdot
.898 .23111 Mdot
.898 .23204 Mdot
.898 .23222 Mdot
.898 .23246 Mdot
.898 .23325 Mdot
.898 .23348 Mdot
.898 .23379 Mdot
.898 .23436 Mdot
.898 .23463 Mdot
.898 .2352 Mdot
.898 .23543 Mdot
.898 .23576 Mdot
.898 .236 Mdot
.898 .23636 Mdot
.898 .23661 Mdot
.898 .23667 Mdot
.898 .23709 Mdot
.898 .23735 Mdot
.898 .23748 Mdot
.898 .23872 Mdot
.898 .23908 Mdot
.898 .23948 Mdot
.898 .24034 Mdot
.898 .24081 Mdot
.898 .24125 Mdot
.898 .24134 Mdot
.898 .24152 Mdot
.898 .24163 Mdot
.898 .24234 Mdot
.898 .24241 Mdot
.898 .24326 Mdot
.898 .24459 Mdot
.898 .24477 Mdot
.898 .24581 Mdot
.898 .24583 Mdot
.898 .24583 Mdot
.898 .24594 Mdot
.898 .24669 Mdot
.898 .2469 Mdot
.898 .24854 Mdot
.898 .2486 Mdot
.898 .24887 Mdot
.898 .24905 Mdot
.898 .25013 Mdot
.898 .25039 Mdot
.898 .2505 Mdot
.898 .25064 Mdot
.898 .25075 Mdot
.898 .25328 Mdot
.898 .25373 Mdot
.898 .25379 Mdot
.898 .25388 Mdot
.898 .25416 Mdot
.898 .25426 Mdot
.898 .25463 Mdot
.898 .25479 Mdot
.898 .25528 Mdot
.898 .25562 Mdot
.898 .25637 Mdot
.898 .25649 Mdot
.898 .25656 Mdot
.898 .25662 Mdot
.898 .25671 Mdot
.898 .25741 Mdot
.898 .25759 Mdot
.898 .25796 Mdot
.898 .25829 Mdot
.898 .25836 Mdot
.898 .2585 Mdot
.898 .25859 Mdot
.898 .25888 Mdot
.898 .25919 Mdot
.898 .25927 Mdot
.898 .2594 Mdot
.898 .26068 Mdot
.898 .2614 Mdot
.898 .26229 Mdot
.898 .26261 Mdot
.898 .26269 Mdot
.898 .26314 Mdot
.898 .26325 Mdot
.898 .26384 Mdot
.898 .26399 Mdot
.898 .26438 Mdot
.898 .26449 Mdot
.898 .26474 Mdot
.898 .26486 Mdot
.898 .26536 Mdot
.898 .26541 Mdot
.898 .2655 Mdot
.898 .26565 Mdot
.898 .26577 Mdot
.898 .2658 Mdot
.898 .26597 Mdot
.898 .26619 Mdot
.898 .26673 Mdot
.898 .26695 Mdot
.898 .26741 Mdot
.898 .26769 Mdot
.898 .26779 Mdot
.898 .26791 Mdot
.898 .26821 Mdot
.898 .26862 Mdot
.898 .26878 Mdot
.898 .26894 Mdot
.898 .26897 Mdot
.898 .27022 Mdot
.898 .27069 Mdot
.898 .27129 Mdot
.898 .27152 Mdot
.898 .27261 Mdot
.898 .27263 Mdot
.898 .27285 Mdot
.898 .27297 Mdot
.898 .27414 Mdot
.898 .27441 Mdot
.898 .27467 Mdot
.898 .27478 Mdot
.898 .27538 Mdot
.898 .2757 Mdot
.898 .27719 Mdot
.898 .27754 Mdot
.898 .27767 Mdot
.898 .27858 Mdot
.898 .27932 Mdot
.898 .27956 Mdot
.898 .27967 Mdot
.898 .27997 Mdot
.898 .28036 Mdot
.898 .28044 Mdot
.898 .28091 Mdot
.898 .28116 Mdot
.898 .28144 Mdot
.898 .28299 Mdot
.898 .28307 Mdot
.898 .28502 Mdot
.898 .28544 Mdot
.898 .28553 Mdot
.898 .2857 Mdot
.898 .28661 Mdot
.898 .28668 Mdot
.898 .28672 Mdot
.898 .28674 Mdot
.898 .28701 Mdot
.898 .28763 Mdot
.898 .28795 Mdot
.898 .28807 Mdot
.898 .28837 Mdot
.898 .28861 Mdot
.898 .28866 Mdot
.898 .28915 Mdot
.898 .28968 Mdot
.898 .29086 Mdot
.898 .29144 Mdot
.898 .2926 Mdot
.898 .29301 Mdot
.898 .2932 Mdot
.898 .29371 Mdot
.898 .29376 Mdot
.898 .29401 Mdot
.898 .29407 Mdot
.898 .29419 Mdot
.898 .2944 Mdot
.898 .29479 Mdot
.898 .29498 Mdot
.898 .29503 Mdot
.898 .29516 Mdot
.898 .29626 Mdot
.898 .29646 Mdot
.898 .29688 Mdot
.898 .29716 Mdot
.898 .29721 Mdot
.898 .29742 Mdot
.898 .29753 Mdot
.898 .29831 Mdot
.898 .29864 Mdot
.898 .29935 Mdot
.898 .2995 Mdot
.898 .2997 Mdot
.898 .29979 Mdot
.898 .29987 Mdot
.898 .29991 Mdot
.898 .30004 Mdot
.898 .30041 Mdot
.898 .30096 Mdot
.898 .30112 Mdot
.898 .30131 Mdot
.898 .30146 Mdot
.898 .30147 Mdot
.898 .30149 Mdot
.898 .30162 Mdot
.898 .30194 Mdot
.898 .30284 Mdot
.898 .30312 Mdot
.898 .30331 Mdot
.898 .30331 Mdot
.898 .30349 Mdot
.898 .30375 Mdot
.898 .3044 Mdot
.898 .30477 Mdot
.898 .30548 Mdot
.898 .30736 Mdot
.898 .30786 Mdot
.898 .30925 Mdot
.898 .30964 Mdot
.898 .31084 Mdot
.898 .31106 Mdot
.898 .31291 Mdot
.898 .31293 Mdot
.898 .31301 Mdot
.898 .31328 Mdot
.898 .31374 Mdot
.898 .31411 Mdot
.898 .31415 Mdot
.898 .31425 Mdot
.898 .31445 Mdot
.898 .31458 Mdot
.898 .31492 Mdot
.898 .31531 Mdot
.898 .31587 Mdot
.898 .31661 Mdot
.898 .31693 Mdot
.898 .31737 Mdot
.898 .31796 Mdot
.898 .31834 Mdot
.898 .31841 Mdot
.898 .319 Mdot
.898 .31946 Mdot
.898 .31956 Mdot
.898 .31986 Mdot
.898 .31995 Mdot
.898 .32007 Mdot
.898 .32206 Mdot
.898 .32348 Mdot
.898 .32479 Mdot
.898 .32495 Mdot
.898 .32535 Mdot
.898 .32541 Mdot
.898 .32544 Mdot
.898 .32601 Mdot
.898 .32604 Mdot
.898 .32768 Mdot
.898 .32788 Mdot
.898 .32793 Mdot
.898 .32836 Mdot
.898 .32843 Mdot
.898 .3288 Mdot
.898 .32881 Mdot
.898 .32888 Mdot
.898 .32924 Mdot
.898 .32974 Mdot
.898 .32983 Mdot
.898 .33033 Mdot
.898 .33057 Mdot
.898 .33058 Mdot
.898 .33067 Mdot
.898 .33096 Mdot
.898 .33121 Mdot
.898 .33169 Mdot
.898 .33201 Mdot
.898 .33221 Mdot
.898 .33234 Mdot
.898 .3328 Mdot
.898 .33342 Mdot
.898 .33412 Mdot
.898 .33412 Mdot
.898 .33482 Mdot
.898 .33539 Mdot
.898 .3355 Mdot
.898 .33623 Mdot
.898 .33667 Mdot
.898 .33667 Mdot
.898 .33709 Mdot
.898 .33757 Mdot
.898 .33807 Mdot
.898 .33923 Mdot
.898 .33983 Mdot
.898 .34 Mdot
.898 .34005 Mdot
.898 .34023 Mdot
.898 .34166 Mdot
.898 .34183 Mdot
.898 .34196 Mdot
.898 .34214 Mdot
.898 .34234 Mdot
.898 .34258 Mdot
.898 .34268 Mdot
.898 .34271 Mdot
.898 .34328 Mdot
.898 .34356 Mdot
.898 .34411 Mdot
.898 .34479 Mdot
.898 .345 Mdot
.898 .34564 Mdot
.898 .34614 Mdot
.898 .34628 Mdot
.898 .3465 Mdot
.898 .34784 Mdot
.898 .34884 Mdot
.898 .34925 Mdot
.898 .34929 Mdot
.898 .34933 Mdot
.898 .35031 Mdot
.898 .35034 Mdot
.898 .35057 Mdot
.898 .35173 Mdot
.898 .3518 Mdot
.898 .35294 Mdot
.898 .35324 Mdot
.898 .35347 Mdot
.898 .35439 Mdot
.898 .35573 Mdot
.898 .3558 Mdot
.898 .35615 Mdot
.898 .35662 Mdot
.898 .357 Mdot
.898 .35756 Mdot
.898 .35767 Mdot
.898 .35771 Mdot
.898 .3583 Mdot
.898 .35833 Mdot
.898 .35855 Mdot
.898 .35936 Mdot
.898 .36048 Mdot
.898 .36052 Mdot
.898 .36061 Mdot
.898 .36094 Mdot
.898 .36127 Mdot
.898 .36234 Mdot
.898 .36253 Mdot
.898 .36308 Mdot
.898 .36309 Mdot
.898 .36354 Mdot
.898 .36367 Mdot
.898 .36387 Mdot
.898 .36457 Mdot
.898 .36493 Mdot
.898 .36504 Mdot
.898 .36509 Mdot
.898 .3651 Mdot
.898 .3658 Mdot
.898 .36692 Mdot
.898 .3675 Mdot
.898 .36762 Mdot
.898 .36799 Mdot
.898 .36806 Mdot
.898 .36864 Mdot
.898 .36905 Mdot
.898 .36938 Mdot
.898 .36955 Mdot
.898 .36978 Mdot
.898 .37032 Mdot
.898 .37191 Mdot
.898 .37251 Mdot
.898 .3727 Mdot
.898 .37322 Mdot
.898 .37329 Mdot
.898 .3737 Mdot
.898 .37411 Mdot
.898 .37412 Mdot
.898 .37431 Mdot
.898 .37446 Mdot
.898 .37521 Mdot
.898 .37561 Mdot
.898 .37564 Mdot
.898 .376 Mdot
.898 .37628 Mdot
.898 .37755 Mdot
.898 .37831 Mdot
.898 .37878 Mdot
.898 .37894 Mdot
.898 .3799 Mdot
.898 .38105 Mdot
.898 .38114 Mdot
.898 .38121 Mdot
.898 .38193 Mdot
.898 .38219 Mdot
.898 .38248 Mdot
.898 .38253 Mdot
.898 .38338 Mdot
.898 .38342 Mdot
.898 .38353 Mdot
.898 .38437 Mdot
.898 .38465 Mdot
.898 .3848 Mdot
.898 .38538 Mdot
.898 .38574 Mdot
.898 .38604 Mdot
.898 .3862 Mdot
.898 .38627 Mdot
.898 .38748 Mdot
.898 .38761 Mdot
.898 .38767 Mdot
.898 .38772 Mdot
.898 .38808 Mdot
.898 .3882 Mdot
.898 .38911 Mdot
.898 .38979 Mdot
.898 .39004 Mdot
.898 .3911 Mdot
.898 .39136 Mdot
.898 .39181 Mdot
.898 .39247 Mdot
.898 .3931 Mdot
.898 .394 Mdot
.898 .39435 Mdot
.898 .39471 Mdot
.898 .39497 Mdot
.898 .39511 Mdot
.898 .3957 Mdot
.898 .39584 Mdot
.898 .39673 Mdot
.898 .39679 Mdot
.898 .39699 Mdot
.898 .39702 Mdot
.898 .39712 Mdot
.898 .3978 Mdot
.898 .39784 Mdot
.898 .39793 Mdot
.898 .39829 Mdot
.898 .39933 Mdot
.898 .39988 Mdot
.898 .40007 Mdot
.898 .40021 Mdot
.898 .40062 Mdot
.898 .40066 Mdot
.898 .40188 Mdot
.898 .40336 Mdot
.898 .40352 Mdot
.898 .40372 Mdot
.898 .40438 Mdot
.898 .40446 Mdot
.898 .40457 Mdot
.898 .4048 Mdot
.898 .40502 Mdot
.898 .40536 Mdot
.898 .40579 Mdot
.898 .40698 Mdot
.898 .40711 Mdot
.898 .4072 Mdot
.898 .40739 Mdot
.898 .40762 Mdot
.898 .40794 Mdot
.898 .40818 Mdot
.898 .40857 Mdot
.898 .4092 Mdot
.898 .40962 Mdot
.898 .40968 Mdot
.898 .40988 Mdot
.898 .41038 Mdot
.898 .4107 Mdot
.898 .41112 Mdot
.898 .41172 Mdot
.898 .4119 Mdot
.898 .41209 Mdot
.898 .41213 Mdot
.898 .41216 Mdot
.898 .41278 Mdot
.898 .41324 Mdot
.898 .41335 Mdot
.898 .4137 Mdot
.898 .41378 Mdot
.898 .41409 Mdot
.898 .41431 Mdot
.898 .41457 Mdot
.898 .41476 Mdot
.898 .4148 Mdot
.898 .41606 Mdot
.898 .41619 Mdot
.898 .41635 Mdot
.898 .41703 Mdot
.898 .41768 Mdot
.898 .41839 Mdot
.898 .41841 Mdot
.898 .41994 Mdot
.898 .42014 Mdot
.898 .42042 Mdot
.898 .42078 Mdot
.898 .42127 Mdot
.898 .42158 Mdot
.898 .42174 Mdot
.898 .42205 Mdot
.898 .42226 Mdot
.898 .42264 Mdot
.898 .42353 Mdot
.898 .42366 Mdot
.898 .42491 Mdot
.898 .42518 Mdot
.898 .42541 Mdot
.898 .42607 Mdot
.898 .42613 Mdot
.898 .42683 Mdot
.898 .42757 Mdot
.898 .4279 Mdot
.898 .42819 Mdot
.898 .42846 Mdot
.898 .4288 Mdot
.898 .42881 Mdot
.898 .42955 Mdot
.898 .42975 Mdot
.898 .42979 Mdot
.898 .4298 Mdot
.898 .43 Mdot
.898 .43028 Mdot
.898 .43042 Mdot
.898 .43134 Mdot
.898 .43135 Mdot
.898 .43168 Mdot
.898 .43172 Mdot
.898 .43276 Mdot
.898 .43466 Mdot
.898 .43478 Mdot
.898 .43526 Mdot
.898 .43559 Mdot
.898 .43562 Mdot
.898 .43659 Mdot
.898 .437 Mdot
.898 .43731 Mdot
.898 .43753 Mdot
.898 .4379 Mdot
.898 .43798 Mdot
.898 .43819 Mdot
.898 .43844 Mdot
.898 .43863 Mdot
.898 .43865 Mdot
.898 .43967 Mdot
.898 .4398 Mdot
.898 .44046 Mdot
.898 .44068 Mdot
.898 .44173 Mdot
.898 .44318 Mdot
.898 .44374 Mdot
.898 .44399 Mdot
.898 .44409 Mdot
.898 .44425 Mdot
.898 .44475 Mdot
.898 .44493 Mdot
.898 .445 Mdot
.898 .44502 Mdot
.898 .4451 Mdot
.898 .4453 Mdot
.898 .4456 Mdot
.898 .44588 Mdot
.898 .44595 Mdot
.898 .44677 Mdot
.898 .44721 Mdot
.898 .44739 Mdot
.898 .44757 Mdot
.898 .44781 Mdot
.898 .4486 Mdot
.898 .44863 Mdot
.898 .44873 Mdot
.898 .44895 Mdot
.898 .44907 Mdot
.898 .44917 Mdot
.898 .44934 Mdot
.898 .44962 Mdot
.898 .44995 Mdot
.898 .4506 Mdot
.898 .45092 Mdot
.898 .45158 Mdot
.898 .45188 Mdot
.898 .45217 Mdot
.898 .45231 Mdot
.898 .45248 Mdot
.898 .45254 Mdot
.898 .45272 Mdot
.898 .45306 Mdot
.898 .45322 Mdot
.898 .45323 Mdot
.898 .45329 Mdot
.898 .4538 Mdot
.898 .45394 Mdot
.898 .45418 Mdot
.898 .4553 Mdot
.898 .45646 Mdot
.898 .45677 Mdot
.898 .45715 Mdot
.898 .45722 Mdot
.898 .45776 Mdot
.898 .45827 Mdot
.898 .45834 Mdot
.898 .45853 Mdot
.898 .45937 Mdot
.898 .45954 Mdot
.898 .45994 Mdot
.898 .46008 Mdot
.898 .46023 Mdot
.898 .46088 Mdot
.898 .46107 Mdot
.898 .46108 Mdot
.898 .46169 Mdot
.898 .46182 Mdot
.898 .46215 Mdot
.898 .46242 Mdot
.898 .46311 Mdot
.898 .4633 Mdot
.898 .46377 Mdot
.898 .46398 Mdot
.898 .46424 Mdot
.898 .46487 Mdot
.898 .46496 Mdot
.898 .46512 Mdot
.898 .4654 Mdot
.898 .46561 Mdot
.898 .46567 Mdot
.898 .46588 Mdot
.898 .46596 Mdot
.898 .4663 Mdot
.898 .46636 Mdot
.898 .46683 Mdot
.898 .46733 Mdot
.898 .46773 Mdot
.898 .46855 Mdot
.898 .46889 Mdot
.898 .46902 Mdot
.898 .46906 Mdot
.898 .46924 Mdot
.898 .46945 Mdot
.898 .46999 Mdot
.898 .47073 Mdot
.898 .47101 Mdot
.898 .47109 Mdot
.898 .4713 Mdot
.898 .47136 Mdot
.898 .47151 Mdot
.898 .47156 Mdot
.898 .47332 Mdot
.898 .47339 Mdot
.898 .47346 Mdot
.898 .4736 Mdot
.898 .4742 Mdot
.898 .47445 Mdot
.898 .47552 Mdot
.898 .47593 Mdot
.898 .476 Mdot
.898 .4779 Mdot
.898 .47794 Mdot
.898 .47833 Mdot
.898 .4784 Mdot
.898 .47854 Mdot
.898 .47879 Mdot
.898 .47905 Mdot
.898 .47995 Mdot
.898 .48064 Mdot
.898 .48109 Mdot
.898 .48113 Mdot
.898 .48147 Mdot
.898 .4816 Mdot
.898 .48178 Mdot
.898 .4827 Mdot
.898 .48287 Mdot
.898 .48344 Mdot
.898 .48367 Mdot
.898 .48419 Mdot
.898 .48521 Mdot
.898 .48527 Mdot
.898 .48544 Mdot
.898 .48588 Mdot
.898 .48612 Mdot
.898 .48623 Mdot
.898 .48656 Mdot
.898 .48675 Mdot
.898 .48679 Mdot
.898 .48699 Mdot
.898 .48709 Mdot
.898 .48861 Mdot
.898 .48965 Mdot
.898 .48995 Mdot
.898 .48999 Mdot
.898 .49008 Mdot
.898 .49037 Mdot
.898 .49038 Mdot
.898 .49058 Mdot
.898 .49111 Mdot
.898 .49146 Mdot
.898 .49181 Mdot
.898 .49196 Mdot
.898 .4928 Mdot
.898 .49326 Mdot
.898 .49354 Mdot
.898 .49375 Mdot
.898 .49443 Mdot
.898 .49531 Mdot
.898 .49605 Mdot
.898 .49606 Mdot
.898 .49654 Mdot
.898 .49668 Mdot
.898 .49685 Mdot
.898 .49816 Mdot
.898 .49836 Mdot
.898 .49937 Mdot
.898 .50018 Mdot
.898 .50063 Mdot
.898 .50064 Mdot
.898 .50094 Mdot
.898 .50109 Mdot
.898 .5014 Mdot
.898 .50189 Mdot
.898 .503 Mdot
.898 .50303 Mdot
.898 .50317 Mdot
.898 .50323 Mdot
.898 .50327 Mdot
.898 .50376 Mdot
.898 .50383 Mdot
.898 .50407 Mdot
.898 .50443 Mdot
.898 .50487 Mdot
.898 .505 Mdot
.898 .50544 Mdot
.898 .50566 Mdot
.898 .50587 Mdot
.898 .50621 Mdot
.898 .50631 Mdot
.898 .50664 Mdot
.898 .50673 Mdot
.898 .50683 Mdot
.898 .50699 Mdot
.898 .50701 Mdot
.898 .50744 Mdot
.898 .50759 Mdot
.898 .50835 Mdot
.898 .5085 Mdot
.898 .50855 Mdot
.898 .5094 Mdot
.898 .51005 Mdot
.898 .51017 Mdot
.898 .5102 Mdot
.898 .51067 Mdot
.898 .51085 Mdot
.898 .51098 Mdot
.898 .51172 Mdot
.898 .51175 Mdot
.898 .51185 Mdot
.898 .5122 Mdot
.898 .5138 Mdot
.898 .51454 Mdot
.898 .51487 Mdot
.898 .51515 Mdot
.898 .51521 Mdot
.898 .51578 Mdot
.898 .51589 Mdot
.898 .51622 Mdot
.898 .51628 Mdot
.898 .51633 Mdot
.898 .51639 Mdot
.898 .51644 Mdot
.898 .51665 Mdot
.898 .51704 Mdot
.898 .51711 Mdot
.898 .51739 Mdot
.898 .51773 Mdot
.898 .51807 Mdot
.898 .51817 Mdot
.898 .5184 Mdot
.898 .51975 Mdot
.898 .52036 Mdot
.898 .52072 Mdot
.898 .52148 Mdot
.898 .52199 Mdot
.898 .52207 Mdot
.898 .5223 Mdot
.898 .52244 Mdot
.898 .52265 Mdot
.898 .52405 Mdot
.898 .52465 Mdot
.898 .52586 Mdot
.898 .52591 Mdot
.898 .52609 Mdot
.898 .52618 Mdot
.898 .52625 Mdot
.898 .52655 Mdot
.898 .52672 Mdot
.898 .52678 Mdot
.898 .52685 Mdot
.898 .52693 Mdot
.898 .52696 Mdot
.898 .52716 Mdot
.898 .5278 Mdot
.898 .52783 Mdot
.898 .52882 Mdot
.898 .52886 Mdot
.898 .52898 Mdot
.898 .5291 Mdot
.898 .52944 Mdot
.898 .52966 Mdot
.898 .5297 Mdot
.898 .52972 Mdot
.898 .52976 Mdot
.898 .52999 Mdot
.898 .53058 Mdot
.898 .53072 Mdot
.898 .5315 Mdot
.898 .53209 Mdot
.898 .53219 Mdot
.898 .5327 Mdot
.898 .53303 Mdot
.898 .53304 Mdot
.898 .53336 Mdot
.898 .53341 Mdot
.898 .53382 Mdot
.898 .53442 Mdot
.898 .535 Mdot
.898 .53512 Mdot
.898 .53566 Mdot
.898 .53574 Mdot
.898 .53597 Mdot
.898 .53632 Mdot
.898 .5365 Mdot
.898 .53658 Mdot
.898 .53693 Mdot
.898 .53725 Mdot
.898 .53807 Mdot
.898 .53855 Mdot
.898 .53869 Mdot
.898 .53874 Mdot
.898 .54031 Mdot
.898 .5412 Mdot
.898 .54205 Mdot
.898 .54245 Mdot
.898 .5437 Mdot
.898 .54441 Mdot
.9 .12208 Mdot
.9 .12254 Mdot
.9 .12391 Mdot
.9 .12501 Mdot
.9 .12516 Mdot
.9 .1267 Mdot
.9 .12746 Mdot
.9 .12764 Mdot
.9 .12765 Mdot
.9 .12933 Mdot
.9 .12939 Mdot
.9 .13005 Mdot
.9 .13123 Mdot
.9 .13129 Mdot
.9 .13232 Mdot
.9 .13301 Mdot
.9 .13332 Mdot
.9 .13352 Mdot
.9 .13395 Mdot
.9 .13471 Mdot
.9 .13609 Mdot
.9 .13638 Mdot
.9 .13681 Mdot
.9 .13737 Mdot
.9 .13742 Mdot
.9 .13799 Mdot
.9 .13848 Mdot
.9 .13888 Mdot
.9 .14029 Mdot
.9 .14037 Mdot
.9 .14052 Mdot
.9 .14142 Mdot
.9 .14194 Mdot
.9 .14268 Mdot
.9 .14306 Mdot
.9 .14346 Mdot
.9 .14398 Mdot
.9 .14418 Mdot
.9 .14478 Mdot
.9 .14491 Mdot
.9 .14494 Mdot
.9 .14505 Mdot
.9 .1452 Mdot
.9 .14555 Mdot
.9 .14557 Mdot
.9 .14578 Mdot
.9 .14658 Mdot
.9 .14795 Mdot
.9 .14819 Mdot
.9 .14871 Mdot
.9 .14915 Mdot
.9 .1516 Mdot
.9 .15203 Mdot
.9 .15268 Mdot
.9 .15273 Mdot
.9 .15353 Mdot
.9 .15386 Mdot
.9 .15474 Mdot
.9 .15589 Mdot
.9 .15659 Mdot
.9 .15752 Mdot
.9 .15804 Mdot
.9 .15887 Mdot
.9 .15953 Mdot
.9 .16148 Mdot
.9 .16169 Mdot
.9 .16174 Mdot
.9 .16338 Mdot
.9 .16386 Mdot
.9 .16532 Mdot
.9 .16556 Mdot
.9 .16798 Mdot
.9 .168 Mdot
.9 .16915 Mdot
.9 .17232 Mdot
.9 .17314 Mdot
.9 .17315 Mdot
.9 .17383 Mdot
.9 .1746 Mdot
.9 .17508 Mdot
.9 .17551 Mdot
.9 .17599 Mdot
.9 .17623 Mdot
.9 .17636 Mdot
.9 .17744 Mdot
.9 .17786 Mdot
.9 .17887 Mdot
.9 .18055 Mdot
.9 .18067 Mdot
.9 .18271 Mdot
.9 .18282 Mdot
.9 .18439 Mdot
.9 .18767 Mdot
.9 .1878 Mdot
.9 .19004 Mdot
.9 .19054 Mdot
.9 .1906 Mdot
.9 .19094 Mdot
.9 .1929 Mdot
.9 .19384 Mdot
.9 .19388 Mdot
.9 .19421 Mdot
.9 .19518 Mdot
.9 .19583 Mdot
.9 .19596 Mdot
.9 .19623 Mdot
.9 .19693 Mdot
.9 .19833 Mdot
.9 .19929 Mdot
.9 .19947 Mdot
.9 .19969 Mdot
.9 .20035 Mdot
.9 .20058 Mdot
.9 .20108 Mdot
.9 .20192 Mdot
.9 .20216 Mdot
.9 .2038 Mdot
.9 .20434 Mdot
.9 .20473 Mdot
.9 .20483 Mdot
.9 .20568 Mdot
.9 .20585 Mdot
.9 .20682 Mdot
.9 .20698 Mdot
.9 .20797 Mdot
.9 .20803 Mdot
.9 .2088 Mdot
.9 .20966 Mdot
.9 .20981 Mdot
.9 .20985 Mdot
.9 .21003 Mdot
.9 .21006 Mdot
.9 .21103 Mdot
.9 .21127 Mdot
.9 .21163 Mdot
.9 .21199 Mdot
.9 .21224 Mdot
.9 .21271 Mdot
.9 .21324 Mdot
.9 .21352 Mdot
.9 .21373 Mdot
.9 .21432 Mdot
.9 .21629 Mdot
.9 .2176 Mdot
.9 .21765 Mdot
.9 .21767 Mdot
.9 .21799 Mdot
.9 .21799 Mdot
.9 .2192 Mdot
.9 .21921 Mdot
.9 .21946 Mdot
.9 .2195 Mdot
.9 .21973 Mdot
.9 .2207 Mdot
.9 .2207 Mdot
.9 .22102 Mdot
.9 .22112 Mdot
.9 .22142 Mdot
.9 .22146 Mdot
.9 .22217 Mdot
.9 .22231 Mdot
.9 .22247 Mdot
.9 .22257 Mdot
.9 .22292 Mdot
.9 .22336 Mdot
.9 .22374 Mdot
.9 .22424 Mdot
.9 .22444 Mdot
.9 .22455 Mdot
.9 .22641 Mdot
.9 .22713 Mdot
.9 .22765 Mdot
.9 .2278 Mdot
.9 .22787 Mdot
.9 .22821 Mdot
.9 .2283 Mdot
.9 .22856 Mdot
.9 .22865 Mdot
.9 .22866 Mdot
.9 .22933 Mdot
.9 .23055 Mdot
.9 .2307 Mdot
.9 .23141 Mdot
.9 .23206 Mdot
.9 .23269 Mdot
.9 .23296 Mdot
.9 .2332 Mdot
.9 .23371 Mdot
.9 .23449 Mdot
.9 .23549 Mdot
.9 .23559 Mdot
.9 .23594 Mdot
.9 .23601 Mdot
.9 .23661 Mdot
.9 .23688 Mdot
.9 .23749 Mdot
.9 .23764 Mdot
.9 .23821 Mdot
.9 .23871 Mdot
.9 .24075 Mdot
.9 .24078 Mdot
.9 .2409 Mdot
.9 .24116 Mdot
.9 .24131 Mdot
.9 .24158 Mdot
.9 .24268 Mdot
.9 .24279 Mdot
.9 .24294 Mdot
.9 .24371 Mdot
.9 .24379 Mdot
.9 .24386 Mdot
.9 .24394 Mdot
.9 .24506 Mdot
.9 .24574 Mdot
.9 .246 Mdot
.9 .24623 Mdot
.9 .24645 Mdot
.9 .24718 Mdot
.9 .24738 Mdot
.9 .24754 Mdot
.9 .24775 Mdot
.9 .24781 Mdot
.9 .24883 Mdot
.9 .24906 Mdot
.9 .24911 Mdot
.9 .24915 Mdot
.9 .24923 Mdot
.9 .24932 Mdot
.9 .24958 Mdot
.9 .24986 Mdot
.9 .25022 Mdot
.9 .25025 Mdot
.9 .25063 Mdot
.9 .25205 Mdot
.9 .25207 Mdot
.9 .2533 Mdot
.9 .25358 Mdot
.9 .25373 Mdot
.9 .25439 Mdot
.9 .25454 Mdot
.9 .25497 Mdot
.9 .25591 Mdot
.9 .25633 Mdot
.9 .25659 Mdot
.9 .2567 Mdot
.9 .25695 Mdot
.9 .25838 Mdot
.9 .25858 Mdot
.9 .25902 Mdot
.9 .25963 Mdot
.9 .26001 Mdot
.9 .26084 Mdot
.9 .2611 Mdot
.9 .26111 Mdot
.9 .26187 Mdot
.9 .26305 Mdot
.9 .26314 Mdot
.9 .26371 Mdot
.9 .26458 Mdot
.9 .26478 Mdot
.9 .26513 Mdot
.9 .26517 Mdot
.9 .26518 Mdot
.9 .26529 Mdot
.9 .26562 Mdot
.9 .26642 Mdot
.9 .26676 Mdot
.9 .26707 Mdot
.9 .26721 Mdot
.9 .26782 Mdot
.9 .2679 Mdot
.9 .26884 Mdot
.9 .2699 Mdot
.9 .27009 Mdot
.9 .27109 Mdot
.9 .27175 Mdot
.9 .27177 Mdot
.9 .27203 Mdot
.9 .2727 Mdot
.9 .27334 Mdot
.9 .27367 Mdot
.9 .2739 Mdot
.9 .27419 Mdot
.9 .27539 Mdot
.9 .27586 Mdot
.9 .27644 Mdot
.9 .27655 Mdot
.9 .27671 Mdot
.9 .27832 Mdot
.9 .27835 Mdot
.9 .2789 Mdot
.9 .2789 Mdot
.9 .2792 Mdot
.9 .27928 Mdot
.9 .27936 Mdot
.9 .27985 Mdot
.9 .28151 Mdot
.9 .28188 Mdot
.9 .28224 Mdot
.9 .2823 Mdot
.9 .28281 Mdot
.9 .28313 Mdot
.9 .28318 Mdot
.9 .28348 Mdot
.9 .28353 Mdot
.9 .28383 Mdot
.9 .28462 Mdot
.9 .28511 Mdot
.9 .28551 Mdot
.9 .2858 Mdot
.9 .28623 Mdot
.9 .28645 Mdot
.9 .28653 Mdot
.9 .28657 Mdot
.9 .28707 Mdot
.9 .28717 Mdot
.9 .28719 Mdot
.9 .2882 Mdot
.9 .29059 Mdot
.9 .29062 Mdot
.9 .29129 Mdot
.9 .29181 Mdot
.9 .29225 Mdot
.9 .29258 Mdot
.9 .29262 Mdot
.9 .2927 Mdot
.9 .29298 Mdot
.9 .29383 Mdot
.9 .29516 Mdot
.9 .29599 Mdot
.9 .29709 Mdot
.9 .29824 Mdot
.9 .2984 Mdot
.9 .29868 Mdot
.9 .2989 Mdot
.9 .29963 Mdot
.9 .29988 Mdot
.9 .29989 Mdot
.9 .30009 Mdot
.9 .30111 Mdot
.9 .30209 Mdot
.9 .30225 Mdot
.9 .30251 Mdot
.9 .30274 Mdot
.9 .30298 Mdot
.9 .30321 Mdot
.9 .30337 Mdot
.9 .30364 Mdot
.9 .30415 Mdot
.9 .30427 Mdot
.9 .30442 Mdot
.9 .30479 Mdot
.9 .30492 Mdot
.9 .30501 Mdot
.9 .30544 Mdot
.9 .30567 Mdot
.9 .30688 Mdot
.9 .30762 Mdot
.9 .30762 Mdot
.9 .30768 Mdot
.9 .30838 Mdot
.9 .31006 Mdot
.9 .3102 Mdot
.9 .31062 Mdot
.9 .31096 Mdot
.9 .31148 Mdot
.9 .3123 Mdot
.9 .31231 Mdot
.9 .31288 Mdot
.9 .3129 Mdot
.9 .31322 Mdot
.9 .31343 Mdot
.9 .31353 Mdot
.9 .31359 Mdot
.9 .31362 Mdot
.9 .31478 Mdot
.9 .31479 Mdot
.9 .31568 Mdot
.9 .3157 Mdot
.9 .31653 Mdot
.9 .31682 Mdot
.9 .31706 Mdot
.9 .3171 Mdot
.9 .31711 Mdot
.9 .31719 Mdot
.9 .31731 Mdot
.9 .31737 Mdot
.9 .31762 Mdot
.9 .31804 Mdot
.9 .31812 Mdot
.9 .31841 Mdot
.9 .31917 Mdot
.9 .31987 Mdot
.9 .32014 Mdot
.9 .32141 Mdot
.9 .32162 Mdot
.9 .32222 Mdot
.9 .32228 Mdot
.9 .3228 Mdot
.9 .32295 Mdot
.9 .32348 Mdot
.9 .32422 Mdot
.9 .32459 Mdot
.9 .32582 Mdot
.9 .32582 Mdot
.9 .32603 Mdot
.9 .32627 Mdot
.9 .32655 Mdot
.9 .32728 Mdot
.9 .32814 Mdot
.9 .32929 Mdot
.9 .3303 Mdot
.9 .33034 Mdot
.9 .33103 Mdot
.9 .33121 Mdot
.9 .33131 Mdot
.9 .33192 Mdot
.9 .33262 Mdot
.9 .33395 Mdot
.9 .33401 Mdot
.9 .33422 Mdot
.9 .33444 Mdot
.9 .3347 Mdot
.9 .33528 Mdot
.9 .33545 Mdot
.9 .3356 Mdot
.9 .33714 Mdot
.9 .3372 Mdot
.9 .33721 Mdot
.9 .3377 Mdot
.9 .33781 Mdot
.9 .33803 Mdot
.9 .33834 Mdot
.9 .33853 Mdot
.9 .33956 Mdot
.9 .34004 Mdot
.9 .34013 Mdot
.9 .34072 Mdot
.9 .34073 Mdot
.9 .34095 Mdot
.9 .34118 Mdot
.9 .34143 Mdot
.9 .34159 Mdot
.9 .34248 Mdot
.9 .34271 Mdot
.9 .34295 Mdot
.9 .3438 Mdot
.9 .3442 Mdot
.9 .34428 Mdot
.9 .34522 Mdot
.9 .34686 Mdot
.9 .34694 Mdot
.9 .34728 Mdot
.9 .34767 Mdot
.9 .34838 Mdot
.9 .34867 Mdot
.9 .34878 Mdot
.9 .34886 Mdot
.9 .34928 Mdot
.9 .35017 Mdot
.9 .35064 Mdot
.9 .35069 Mdot
.9 .3509 Mdot
.9 .35168 Mdot
.9 .35212 Mdot
.9 .35251 Mdot
.9 .35289 Mdot
.9 .35436 Mdot
.9 .35485 Mdot
.9 .35504 Mdot
.9 .35506 Mdot
.9 .35605 Mdot
.9 .35674 Mdot
.9 .35684 Mdot
.9 .35692 Mdot
.9 .3577 Mdot
.9 .35773 Mdot
.9 .35778 Mdot
.9 .35846 Mdot
.9 .35875 Mdot
.9 .35926 Mdot
.9 .35949 Mdot
.9 .35967 Mdot
.9 .35987 Mdot
.9 .35989 Mdot
.9 .35998 Mdot
.9 .36022 Mdot
.9 .3605 Mdot
.9 .36079 Mdot
.9 .36083 Mdot
.9 .36098 Mdot
.9 .36101 Mdot
.9 .36133 Mdot
.9 .36228 Mdot
.9 .36258 Mdot
.9 .36268 Mdot
.9 .36373 Mdot
.9 .36407 Mdot
.9 .36457 Mdot
.9 .36463 Mdot
.9 .36562 Mdot
.9 .36589 Mdot
.9 .36596 Mdot
.9 .36629 Mdot
.9 .36634 Mdot
.9 .36645 Mdot
.9 .36649 Mdot
.9 .36709 Mdot
.9 .36808 Mdot
.9 .36825 Mdot
.9 .36835 Mdot
.9 .36852 Mdot
.9 .36877 Mdot
.9 .36895 Mdot
.9 .36895 Mdot
.9 .36917 Mdot
.9 .36954 Mdot
.9 .36982 Mdot
.9 .37025 Mdot
.9 .37041 Mdot
.9 .37054 Mdot
.9 .37065 Mdot
.9 .37089 Mdot
.9 .3711 Mdot
.9 .37183 Mdot
.9 .37206 Mdot
.9 .37245 Mdot
.9 .37256 Mdot
.9 .37294 Mdot
.9 .37401 Mdot
.9 .37455 Mdot
.9 .37504 Mdot
.9 .37547 Mdot
.9 .37586 Mdot
.9 .37596 Mdot
.9 .37681 Mdot
.9 .37686 Mdot
.9 .37733 Mdot
.9 .37736 Mdot
.9 .37754 Mdot
.9 .37768 Mdot
.9 .37943 Mdot
.9 .3799 Mdot
.9 .37999 Mdot
.9 .38003 Mdot
.9 .3806 Mdot
.9 .38062 Mdot
.9 .38129 Mdot
.9 .38196 Mdot
.9 .38279 Mdot
.9 .38281 Mdot
.9 .38326 Mdot
.9 .38333 Mdot
.9 .38345 Mdot
.9 .38348 Mdot
.9 .38356 Mdot
.9 .38375 Mdot
.9 .38379 Mdot
.9 .38419 Mdot
.9 .38464 Mdot
.9 .38492 Mdot
.9 .38548 Mdot
.9 .38549 Mdot
.9 .38604 Mdot
.9 .38607 Mdot
.9 .38625 Mdot
.9 .38625 Mdot
.9 .38674 Mdot
.9 .38678 Mdot
.9 .38685 Mdot
.9 .38714 Mdot
.9 .38813 Mdot
.9 .38826 Mdot
.9 .38839 Mdot
.9 .38842 Mdot
.9 .38868 Mdot
.9 .38885 Mdot
.9 .38895 Mdot
.9 .38949 Mdot
.9 .39027 Mdot
.9 .39076 Mdot
.9 .39096 Mdot
.9 .39187 Mdot
.9 .39221 Mdot
.9 .39242 Mdot
.9 .39576 Mdot
.9 .39677 Mdot
.9 .39707 Mdot
.9 .39715 Mdot
.9 .39777 Mdot
.9 .398 Mdot
.9 .39827 Mdot
.9 .39839 Mdot
.9 .39901 Mdot
.9 .39916 Mdot
.9 .39941 Mdot
.9 .39963 Mdot
.9 .39976 Mdot
.9 .39981 Mdot
.9 .39982 Mdot
.9 .40065 Mdot
.9 .40102 Mdot
.9 .40206 Mdot
.9 .40303 Mdot
.9 .40321 Mdot
.9 .40323 Mdot
.9 .40348 Mdot
.9 .40352 Mdot
.9 .40399 Mdot
.9 .40404 Mdot
.9 .40426 Mdot
.9 .4045 Mdot
.9 .40477 Mdot
.9 .40594 Mdot
.9 .40628 Mdot
.9 .4068 Mdot
.9 .40693 Mdot
.9 .407 Mdot
.9 .40707 Mdot
.9 .40755 Mdot
.9 .40788 Mdot
.9 .40788 Mdot
.9 .40798 Mdot
.9 .40821 Mdot
.9 .40827 Mdot
.9 .40891 Mdot
.9 .40925 Mdot
.9 .40927 Mdot
.9 .41028 Mdot
.9 .41032 Mdot
.9 .41078 Mdot
.9 .41158 Mdot
.9 .41211 Mdot
.9 .41229 Mdot
.9 .41231 Mdot
.9 .41239 Mdot
.9 .41273 Mdot
.9 .41286 Mdot
.9 .41291 Mdot
.9 .41292 Mdot
.9 .41304 Mdot
.9 .41314 Mdot
.9 .41326 Mdot
.9 .41409 Mdot
.9 .41411 Mdot
.9 .41413 Mdot
.9 .41461 Mdot
.9 .41561 Mdot
.9 .41571 Mdot
.9 .41599 Mdot
.9 .41681 Mdot
.9 .41701 Mdot
.9 .41791 Mdot
.9 .41802 Mdot
.9 .41805 Mdot
.9 .41909 Mdot
.9 .41915 Mdot
.9 .41931 Mdot
.9 .42015 Mdot
.9 .42159 Mdot
.9 .42163 Mdot
.9 .42185 Mdot
.9 .42232 Mdot
.9 .42259 Mdot
.9 .42308 Mdot
.9 .42331 Mdot
.9 .42356 Mdot
.9 .42389 Mdot
.9 .42394 Mdot
.9 .42478 Mdot
.9 .42488 Mdot
.9 .42506 Mdot
.9 .42524 Mdot
.9 .42552 Mdot
.9 .42641 Mdot
.9 .42659 Mdot
.9 .42691 Mdot
.9 .42705 Mdot
.9 .42718 Mdot
.9 .42729 Mdot
.9 .42733 Mdot
.9 .42806 Mdot
.9 .42895 Mdot
.9 .42933 Mdot
.9 .42991 Mdot
.9 .43055 Mdot
.9 .43103 Mdot
.9 .43144 Mdot
.9 .43184 Mdot
.9 .43184 Mdot
.9 .43253 Mdot
.9 .43273 Mdot
.9 .43314 Mdot
.9 .43343 Mdot
.9 .43352 Mdot
.9 .43381 Mdot
.9 .43384 Mdot
.9 .43418 Mdot
.9 .43429 Mdot
.9 .43515 Mdot
.9 .43554 Mdot
.9 .43596 Mdot
.9 .43612 Mdot
.9 .43616 Mdot
.9 .4364 Mdot
.9 .43654 Mdot
.9 .43663 Mdot
.9 .43668 Mdot
.9 .43671 Mdot
.9 .43684 Mdot
.9 .437 Mdot
.9 .43746 Mdot
.9 .43748 Mdot
.9 .43797 Mdot
.9 .43798 Mdot
.9 .43862 Mdot
.9 .43864 Mdot
.9 .43867 Mdot
.9 .43902 Mdot
.9 .43903 Mdot
.9 .43935 Mdot
.9 .43936 Mdot
.9 .43981 Mdot
.9 .4401 Mdot
.9 .44028 Mdot
.9 .4406 Mdot
.9 .44192 Mdot
.9 .44195 Mdot
.9 .44237 Mdot
.9 .44345 Mdot
.9 .44353 Mdot
.9 .44373 Mdot
.9 .44381 Mdot
.9 .44416 Mdot
.9 .4444 Mdot
.9 .44453 Mdot
.9 .44467 Mdot
.9 .44494 Mdot
.9 .44502 Mdot
.9 .44613 Mdot
.9 .44639 Mdot
.9 .4468 Mdot
.9 .44692 Mdot
.9 .44717 Mdot
.9 .4478 Mdot
.9 .44841 Mdot
.9 .44887 Mdot
.9 .44961 Mdot
.9 .45009 Mdot
.9 .45028 Mdot
.9 .45031 Mdot
.9 .45049 Mdot
.9 .45074 Mdot
.9 .45103 Mdot
.9 .45274 Mdot
.9 .4533 Mdot
.9 .45331 Mdot
.9 .45337 Mdot
.9 .45365 Mdot
.9 .45367 Mdot
.9 .45371 Mdot
.9 .45424 Mdot
.9 .45446 Mdot
.9 .45473 Mdot
.9 .45517 Mdot
.9 .45534 Mdot
.9 .45536 Mdot
.9 .45556 Mdot
.9 .45574 Mdot
.9 .45605 Mdot
.9 .45625 Mdot
.9 .45646 Mdot
.9 .45738 Mdot
.9 .45774 Mdot
.9 .45791 Mdot
.9 .45821 Mdot
.9 .45823 Mdot
.9 .45913 Mdot
.9 .45921 Mdot
.9 .45928 Mdot
.9 .4596 Mdot
.9 .46068 Mdot
.9 .46082 Mdot
.9 .461 Mdot
.9 .46172 Mdot
.9 .46188 Mdot
.9 .46225 Mdot
.9 .46291 Mdot
.9 .46402 Mdot
.9 .46406 Mdot
.9 .46441 Mdot
.9 .46448 Mdot
.9 .46484 Mdot
.9 .46529 Mdot
.9 .46547 Mdot
.9 .46553 Mdot
.9 .46556 Mdot
.9 .46575 Mdot
.9 .46635 Mdot
.9 .46779 Mdot
.9 .46794 Mdot
.9 .4684 Mdot
.9 .46862 Mdot
.9 .46895 Mdot
.9 .4692 Mdot
.9 .46931 Mdot
.9 .4701 Mdot
.9 .4703 Mdot
.9 .47045 Mdot
.9 .47152 Mdot
.9 .47189 Mdot
.9 .47198 Mdot
.9 .47213 Mdot
.9 .47282 Mdot
.9 .47404 Mdot
.9 .47439 Mdot
.9 .47443 Mdot
.9 .47518 Mdot
.9 .47533 Mdot
.9 .47553 Mdot
.9 .47606 Mdot
.9 .47618 Mdot
.9 .47733 Mdot
.9 .47737 Mdot
.9 .47741 Mdot
.9 .47789 Mdot
.9 .47803 Mdot
.9 .47864 Mdot
.9 .47879 Mdot
.9 .47909 Mdot
.9 .48023 Mdot
.9 .48083 Mdot
.9 .48125 Mdot
.9 .48174 Mdot
.9 .48178 Mdot
.9 .48343 Mdot
.9 .48358 Mdot
.9 .48393 Mdot
.9 .48429 Mdot
.9 .48477 Mdot
.9 .48582 Mdot
.9 .48582 Mdot
.9 .48602 Mdot
.9 .48626 Mdot
.9 .4863 Mdot
.9 .48667 Mdot
.9 .48827 Mdot
.9 .48855 Mdot
.9 .48877 Mdot
.9 .48901 Mdot
.9 .4892 Mdot
.9 .48926 Mdot
.9 .48943 Mdot
.9 .48982 Mdot
.9 .48984 Mdot
.9 .49024 Mdot
.9 .49024 Mdot
.9 .49078 Mdot
.9 .49091 Mdot
.9 .49093 Mdot
.9 .49107 Mdot
.9 .49107 Mdot
.9 .49193 Mdot
.9 .49197 Mdot
.9 .49378 Mdot
.9 .49411 Mdot
.9 .49468 Mdot
.9 .49494 Mdot
.9 .49508 Mdot
.9 .49528 Mdot
.9 .49562 Mdot
.9 .49615 Mdot
.9 .49617 Mdot
.9 .49627 Mdot
.9 .49629 Mdot
.9 .49637 Mdot
.9 .49728 Mdot
.9 .49786 Mdot
.9 .49795 Mdot
.9 .49849 Mdot
.9 .49858 Mdot
.9 .49906 Mdot
.9 .49911 Mdot
.9 .49933 Mdot
.9 .49963 Mdot
.9 .50054 Mdot
.9 .50067 Mdot
.9 .50114 Mdot
.9 .50142 Mdot
.9 .50155 Mdot
.9 .50191 Mdot
.9 .50203 Mdot
.9 .50214 Mdot
.9 .50267 Mdot
.9 .50345 Mdot
.9 .50384 Mdot
.9 .50399 Mdot
.9 .50406 Mdot
.9 .50442 Mdot
.9 .50496 Mdot
.9 .50514 Mdot
.9 .50517 Mdot
.9 .50569 Mdot
.9 .50678 Mdot
.9 .50696 Mdot
.9 .507 Mdot
.9 .50727 Mdot
.9 .50852 Mdot
.9 .50859 Mdot
.9 .51041 Mdot
.9 .51129 Mdot
.9 .51135 Mdot
.9 .51248 Mdot
.9 .51255 Mdot
.9 .51348 Mdot
.9 .51404 Mdot
.9 .51428 Mdot
.9 .51488 Mdot
.9 .51495 Mdot
.9 .51508 Mdot
.9 .51535 Mdot
.9 .51559 Mdot
.9 .51585 Mdot
.9 .51628 Mdot
.9 .51666 Mdot
.9 .51667 Mdot
.9 .51712 Mdot
.9 .51888 Mdot
.9 .51952 Mdot
.9 .51953 Mdot
.9 .52088 Mdot
.9 .52101 Mdot
.9 .52182 Mdot
.9 .52209 Mdot
.9 .523 Mdot
.9 .52302 Mdot
.9 .52314 Mdot
.9 .52422 Mdot
.9 .52459 Mdot
.9 .52505 Mdot
.9 .52534 Mdot
.9 .52586 Mdot
.9 .52625 Mdot
.9 .52689 Mdot
.9 .52738 Mdot
.9 .52756 Mdot
.9 .528 Mdot
.9 .52803 Mdot
.9 .52839 Mdot
.9 .52863 Mdot
.9 .52999 Mdot
.9 .53023 Mdot
.9 .53053 Mdot
.9 .53066 Mdot
.9 .53142 Mdot
.9 .53187 Mdot
.9 .53198 Mdot
.9 .53199 Mdot
.9 .53219 Mdot
.9 .53227 Mdot
.9 .53233 Mdot
.9 .53235 Mdot
.9 .53242 Mdot
.9 .53275 Mdot
.9 .53287 Mdot
.9 .53315 Mdot
.9 .53338 Mdot
.9 .53358 Mdot
.9 .534 Mdot
.9 .53429 Mdot
.9 .53479 Mdot
.9 .53487 Mdot
.9 .53491 Mdot
.9 .5357 Mdot
.9 .53592 Mdot
.9 .53619 Mdot
.9 .53651 Mdot
.9 .53654 Mdot
.9 .53684 Mdot
.9 .53709 Mdot
.9 .53725 Mdot
.9 .53802 Mdot
.9 .53844 Mdot
.9 .53868 Mdot
.9 .53878 Mdot
.9 .53896 Mdot
.9 .53934 Mdot
.9 .53991 Mdot
.9 .53995 Mdot
.9 .54061 Mdot
.9 .54097 Mdot
.9 .541 Mdot
.9 .54194 Mdot
.9 .54194 Mdot
.9 .54204 Mdot
.9 .54246 Mdot
.9 .54332 Mdot
.9 .54341 Mdot
.9 .54401 Mdot
.9 .54477 Mdot
.9 .54503 Mdot
.902 .12091 Mdot
.902 .12092 Mdot
.902 .12201 Mdot
.902 .12222 Mdot
.902 .12353 Mdot
.902 .12495 Mdot
.902 .12516 Mdot
.902 .12537 Mdot
.902 .1257 Mdot
.902 .12579 Mdot
.902 .12589 Mdot
.902 .12591 Mdot
.902 .12632 Mdot
.902 .12688 Mdot
.902 .12706 Mdot
.902 .12747 Mdot
.902 .12748 Mdot
.902 .12761 Mdot
.902 .12806 Mdot
.902 .12883 Mdot
.902 .12937 Mdot
.902 .13041 Mdot
.902 .13074 Mdot
.902 .13181 Mdot
.902 .13264 Mdot
.902 .13278 Mdot
.902 .13382 Mdot
.902 .13446 Mdot
.902 .13464 Mdot
.902 .13595 Mdot
.902 .13842 Mdot
.902 .14 Mdot
.902 .14028 Mdot
.902 .14088 Mdot
.902 .14119 Mdot
.902 .14257 Mdot
.902 .14277 Mdot
.902 .14367 Mdot
.902 .14395 Mdot
.902 .14446 Mdot
.902 .14514 Mdot
.902 .14552 Mdot
.902 .14617 Mdot
.902 .14691 Mdot
.902 .14733 Mdot
.902 .14924 Mdot
.902 .14926 Mdot
.902 .1513 Mdot
.902 .15174 Mdot
.902 .15196 Mdot
.902 .15206 Mdot
.902 .15303 Mdot
.902 .15343 Mdot
.902 .155 Mdot
.902 .15562 Mdot
.902 .15578 Mdot
.902 .15787 Mdot
.902 .15815 Mdot
.902 .15818 Mdot
.902 .15884 Mdot
.902 .16067 Mdot
.902 .16105 Mdot
.902 .16254 Mdot
.902 .1643 Mdot
.902 .16444 Mdot
.902 .16449 Mdot
.902 .16482 Mdot
.902 .16504 Mdot
.902 .16566 Mdot
.902 .16665 Mdot
.902 .16716 Mdot
.902 .16758 Mdot
.902 .16769 Mdot
.902 .1679 Mdot
.902 .16883 Mdot
.902 .16921 Mdot
.902 .17043 Mdot
.902 .17197 Mdot
.902 .17266 Mdot
.902 .17308 Mdot
.902 .1739 Mdot
.902 .17418 Mdot
.902 .17422 Mdot
.902 .17461 Mdot
.902 .17591 Mdot
.902 .17708 Mdot
.902 .17791 Mdot
.902 .17928 Mdot
.902 .17967 Mdot
.902 .1799 Mdot
.902 .18017 Mdot
.902 .18086 Mdot
.902 .18089 Mdot
.902 .18111 Mdot
.902 .18154 Mdot
.902 .18305 Mdot
.902 .18402 Mdot
.902 .18447 Mdot
.902 .18485 Mdot
.902 .18564 Mdot
.902 .18594 Mdot
.902 .18598 Mdot
.902 .1865 Mdot
.902 .18699 Mdot
.902 .18737 Mdot
.902 .18826 Mdot
.902 .18938 Mdot
.902 .19055 Mdot
.902 .19135 Mdot
.902 .19197 Mdot
.902 .19249 Mdot
.902 .19282 Mdot
.902 .19324 Mdot
.902 .19605 Mdot
.902 .19646 Mdot
.902 .19777 Mdot
.902 .199 Mdot
.902 .19965 Mdot
.902 .19967 Mdot
.902 .1997 Mdot
.902 .19999 Mdot
.902 .20062 Mdot
.902 .20078 Mdot
.902 .20162 Mdot
.902 .20271 Mdot
.902 .20284 Mdot
.902 .20297 Mdot
.902 .20355 Mdot
.902 .20366 Mdot
.902 .20376 Mdot
.902 .20467 Mdot
.902 .20571 Mdot
.902 .20605 Mdot
.902 .20615 Mdot
.902 .20615 Mdot
.902 .20617 Mdot
.902 .20628 Mdot
.902 .20631 Mdot
.902 .20696 Mdot
.902 .20713 Mdot
.902 .2081 Mdot
.902 .20816 Mdot
.902 .20827 Mdot
.902 .20866 Mdot
.902 .21061 Mdot
.902 .21102 Mdot
.902 .21116 Mdot
.902 .21208 Mdot
.902 .21213 Mdot
.902 .21276 Mdot
.902 .21358 Mdot
.902 .21396 Mdot
.902 .21433 Mdot
.902 .21459 Mdot
.902 .21493 Mdot
.902 .2151 Mdot
.902 .21527 Mdot
.902 .21531 Mdot
.902 .21605 Mdot
.902 .21706 Mdot
.902 .21739 Mdot
.902 .21812 Mdot
.902 .21814 Mdot
.902 .21837 Mdot
.902 .21918 Mdot
.902 .21988 Mdot
.902 .21991 Mdot
.902 .22016 Mdot
.902 .22057 Mdot
.902 .22103 Mdot
.902 .22156 Mdot
.902 .22212 Mdot
.902 .22317 Mdot
.902 .22342 Mdot
.902 .22347 Mdot
.902 .22362 Mdot
.902 .22403 Mdot
.902 .22505 Mdot
.902 .22596 Mdot
.902 .22604 Mdot
.902 .22636 Mdot
.902 .22644 Mdot
.902 .22667 Mdot
.902 .22745 Mdot
.902 .2277 Mdot
.902 .22882 Mdot
.902 .22958 Mdot
.902 .23073 Mdot
.902 .23106 Mdot
.902 .23131 Mdot
.902 .23286 Mdot
.902 .23336 Mdot
.902 .23342 Mdot
.902 .23347 Mdot
.902 .23374 Mdot
.902 .23382 Mdot
.902 .23431 Mdot
.902 .2367 Mdot
.902 .23692 Mdot
.902 .23768 Mdot
.902 .23788 Mdot
.902 .23798 Mdot
.902 .23835 Mdot
.902 .23857 Mdot
.902 .23946 Mdot
.902 .24027 Mdot
.902 .24031 Mdot
.902 .24074 Mdot
.902 .24094 Mdot
.902 .24124 Mdot
.902 .24231 Mdot
.902 .24232 Mdot
.902 .24246 Mdot
.902 .24288 Mdot
.902 .24311 Mdot
.902 .24479 Mdot
.902 .24489 Mdot
.902 .24506 Mdot
.902 .24536 Mdot
.902 .24542 Mdot
.902 .24573 Mdot
.902 .24661 Mdot
.902 .24676 Mdot
.902 .24734 Mdot
.902 .24771 Mdot
.902 .24786 Mdot
.902 .24878 Mdot
.902 .25 Mdot
.902 .25013 Mdot
.902 .25047 Mdot
.902 .25051 Mdot
.902 .25068 Mdot
.902 .25082 Mdot
.902 .25141 Mdot
.902 .25175 Mdot
.902 .25176 Mdot
.902 .25185 Mdot
.902 .25186 Mdot
.902 .2532 Mdot
.902 .25374 Mdot
.902 .25396 Mdot
.902 .25415 Mdot
.902 .25507 Mdot
.902 .25539 Mdot
.902 .25572 Mdot
.902 .25635 Mdot
.902 .2574 Mdot
.902 .25743 Mdot
.902 .25799 Mdot
.902 .25804 Mdot
.902 .25866 Mdot
.902 .2589 Mdot
.902 .25911 Mdot
.902 .26063 Mdot
.902 .26094 Mdot
.902 .26112 Mdot
.902 .26124 Mdot
.902 .26125 Mdot
.902 .26191 Mdot
.902 .26231 Mdot
.902 .26237 Mdot
.902 .26248 Mdot
.902 .26276 Mdot
.902 .26326 Mdot
.902 .26348 Mdot
.902 .26423 Mdot
.902 .26429 Mdot
.902 .26464 Mdot
.902 .26495 Mdot
.902 .26538 Mdot
.902 .26565 Mdot
.902 .26671 Mdot
.902 .26679 Mdot
.902 .26698 Mdot
.902 .26769 Mdot
.902 .26779 Mdot
.902 .2683 Mdot
.902 .26888 Mdot
.902 .26891 Mdot
.902 .2692 Mdot
.902 .26929 Mdot
.902 .26941 Mdot
.902 .27015 Mdot
.902 .27156 Mdot
.902 .27177 Mdot
.902 .27269 Mdot
.902 .27296 Mdot
.902 .27303 Mdot
.902 .27314 Mdot
.902 .27324 Mdot
.902 .27347 Mdot
.902 .27353 Mdot
.902 .27427 Mdot
.902 .27453 Mdot
.902 .27472 Mdot
.902 .27669 Mdot
.902 .27671 Mdot
.902 .27711 Mdot
.902 .27769 Mdot
.902 .27801 Mdot
.902 .27869 Mdot
.902 .2787 Mdot
.902 .28033 Mdot
.902 .28089 Mdot
.902 .28138 Mdot
.902 .28232 Mdot
.902 .28292 Mdot
.902 .28295 Mdot
.902 .28306 Mdot
.902 .28366 Mdot
.902 .28372 Mdot
.902 .2839 Mdot
.902 .28431 Mdot
.902 .28457 Mdot
.902 .28482 Mdot
.902 .2849 Mdot
.902 .28512 Mdot
.902 .2855 Mdot
.902 .2859 Mdot
.902 .28702 Mdot
.902 .28712 Mdot
.902 .28728 Mdot
.902 .28772 Mdot
.902 .28869 Mdot
.902 .28881 Mdot
.902 .28896 Mdot
.902 .28912 Mdot
.902 .28922 Mdot
.902 .28972 Mdot
.902 .29049 Mdot
.902 .29068 Mdot
.902 .29091 Mdot
.902 .29106 Mdot
.902 .29186 Mdot
.902 .29261 Mdot
.902 .29273 Mdot
.902 .29343 Mdot
.902 .29427 Mdot
.902 .29439 Mdot
.902 .29468 Mdot
.902 .29474 Mdot
.902 .2949 Mdot
.902 .29536 Mdot
.902 .29562 Mdot
.902 .29574 Mdot
.902 .29678 Mdot
.902 .2969 Mdot
.902 .29766 Mdot
.902 .2984 Mdot
.902 .29954 Mdot
.902 .29957 Mdot
.902 .29964 Mdot
.902 .29978 Mdot
.902 .3004 Mdot
.902 .30041 Mdot
.902 .30112 Mdot
.902 .30155 Mdot
.902 .30188 Mdot
.902 .30203 Mdot
.902 .3024 Mdot
.902 .30246 Mdot
.902 .30288 Mdot
.902 .30298 Mdot
.902 .30316 Mdot
.902 .30515 Mdot
.902 .30551 Mdot
.902 .30576 Mdot
.902 .30692 Mdot
.902 .30722 Mdot
.902 .30728 Mdot
.902 .30745 Mdot
.902 .30758 Mdot
.902 .30759 Mdot
.902 .30761 Mdot
.902 .30871 Mdot
.902 .30911 Mdot
.902 .30912 Mdot
.902 .31062 Mdot
.902 .31108 Mdot
.902 .31152 Mdot
.902 .31158 Mdot
.902 .31165 Mdot
.902 .31175 Mdot
.902 .31229 Mdot
.902 .3123 Mdot
.902 .31234 Mdot
.902 .31271 Mdot
.902 .31288 Mdot
.902 .3132 Mdot
.902 .3133 Mdot
.902 .31393 Mdot
.902 .31444 Mdot
.902 .3145 Mdot
.902 .3149 Mdot
.902 .31566 Mdot
.902 .31615 Mdot
.902 .31727 Mdot
.902 .31772 Mdot
.902 .31804 Mdot
.902 .3184 Mdot
.902 .32015 Mdot
.902 .32027 Mdot
.902 .32075 Mdot
.902 .32094 Mdot
.902 .32163 Mdot
.902 .32172 Mdot
.902 .32193 Mdot
.902 .32307 Mdot
.902 .32361 Mdot
.902 .32367 Mdot
.902 .32384 Mdot
.902 .32433 Mdot
.902 .32462 Mdot
.902 .32549 Mdot
.902 .32618 Mdot
.902 .32631 Mdot
.902 .32656 Mdot
.902 .32665 Mdot
.902 .32718 Mdot
.902 .32779 Mdot
.902 .32821 Mdot
.902 .32841 Mdot
.902 .3287 Mdot
.902 .32878 Mdot
.902 .32937 Mdot
.902 .32981 Mdot
.902 .32992 Mdot
.902 .33026 Mdot
.902 .33097 Mdot
.902 .33132 Mdot
.902 .33192 Mdot
.902 .3325 Mdot
.902 .33337 Mdot
.902 .33447 Mdot
.902 .33448 Mdot
.902 .33477 Mdot
.902 .33541 Mdot
.902 .33545 Mdot
.902 .3357 Mdot
.902 .33602 Mdot
.902 .33647 Mdot
.902 .33647 Mdot
.902 .33672 Mdot
.902 .33677 Mdot
.902 .33709 Mdot
.902 .33784 Mdot
.902 .33829 Mdot
.902 .33831 Mdot
.902 .34078 Mdot
.902 .34104 Mdot
.902 .34179 Mdot
.902 .34184 Mdot
.902 .34258 Mdot
.902 .34278 Mdot
.902 .34344 Mdot
.902 .3442 Mdot
.902 .34483 Mdot
.902 .34495 Mdot
.902 .34497 Mdot
.902 .34695 Mdot
.902 .34697 Mdot
.902 .34716 Mdot
.902 .34758 Mdot
.902 .34834 Mdot
.902 .34837 Mdot
.902 .34843 Mdot
.902 .34854 Mdot
.902 .3489 Mdot
.902 .34895 Mdot
.902 .35009 Mdot
.902 .35038 Mdot
.902 .35048 Mdot
.902 .35122 Mdot
.902 .3515 Mdot
.902 .3519 Mdot
.902 .3524 Mdot
.902 .35274 Mdot
.902 .35321 Mdot
.902 .35331 Mdot
.902 .3534 Mdot
.902 .3534 Mdot
.902 .35387 Mdot
.902 .35409 Mdot
.902 .35434 Mdot
.902 .35467 Mdot
.902 .35508 Mdot
.902 .35538 Mdot
.902 .35557 Mdot
.902 .35575 Mdot
.902 .35587 Mdot
.902 .35657 Mdot
.902 .35706 Mdot
.902 .3574 Mdot
.902 .35926 Mdot
.902 .35944 Mdot
.902 .35988 Mdot
.902 .36006 Mdot
.902 .36007 Mdot
.902 .3601 Mdot
.902 .36031 Mdot
.902 .36036 Mdot
.902 .36153 Mdot
.902 .36183 Mdot
.902 .36192 Mdot
.902 .36251 Mdot
.902 .36281 Mdot
.902 .36355 Mdot
.902 .36358 Mdot
.902 .36369 Mdot
.902 .36374 Mdot
.902 .36388 Mdot
.902 .36436 Mdot
.902 .36459 Mdot
.902 .36517 Mdot
.902 .36518 Mdot
.902 .36579 Mdot
.902 .36593 Mdot
.902 .36622 Mdot
.902 .36689 Mdot
.902 .36708 Mdot
.902 .36725 Mdot
.902 .36743 Mdot
.902 .3676 Mdot
.902 .36811 Mdot
.902 .36885 Mdot
.902 .36909 Mdot
.902 .3691 Mdot
.902 .36959 Mdot
.902 .37027 Mdot
.902 .37075 Mdot
.902 .37085 Mdot
.902 .37198 Mdot
.902 .37339 Mdot
.902 .37347 Mdot
.902 .3735 Mdot
.902 .37413 Mdot
.902 .37415 Mdot
.902 .37483 Mdot
.902 .37493 Mdot
.902 .3753 Mdot
.902 .3759 Mdot
.902 .37599 Mdot
.902 .3762 Mdot
.902 .37651 Mdot
.902 .37659 Mdot
.902 .3767 Mdot
.902 .37784 Mdot
.902 .37792 Mdot
.902 .37889 Mdot
.902 .37974 Mdot
.902 .37974 Mdot
.902 .38022 Mdot
.902 .38033 Mdot
.902 .38113 Mdot
.902 .38166 Mdot
.902 .38169 Mdot
.902 .38172 Mdot
.902 .38211 Mdot
.902 .38223 Mdot
.902 .38284 Mdot
.902 .38357 Mdot
.902 .38433 Mdot
.902 .38452 Mdot
.902 .38461 Mdot
.902 .38484 Mdot
.902 .38489 Mdot
.902 .38533 Mdot
.902 .38534 Mdot
.902 .38552 Mdot
.902 .38586 Mdot
.902 .38608 Mdot
.902 .38669 Mdot
.902 .3869 Mdot
.902 .38786 Mdot
.902 .38789 Mdot
.902 .38888 Mdot
.902 .38923 Mdot
.902 .38996 Mdot
.902 .39024 Mdot
.902 .39042 Mdot
.902 .39076 Mdot
.902 .39122 Mdot
.902 .39128 Mdot
.902 .39131 Mdot
.902 .39153 Mdot
.902 .39159 Mdot
.902 .39232 Mdot
.902 .39309 Mdot
.902 .39391 Mdot
.902 .39417 Mdot
.902 .39448 Mdot
.902 .39493 Mdot
.902 .3958 Mdot
.902 .39594 Mdot
.902 .39642 Mdot
.902 .39652 Mdot
.902 .39667 Mdot
.902 .39708 Mdot
.902 .39782 Mdot
.902 .39848 Mdot
.902 .39894 Mdot
.902 .39913 Mdot
.902 .39924 Mdot
.902 .39964 Mdot
.902 .39969 Mdot
.902 .39979 Mdot
.902 .40062 Mdot
.902 .40095 Mdot
.902 .40124 Mdot
.902 .40156 Mdot
.902 .40207 Mdot
.902 .40234 Mdot
.902 .40339 Mdot
.902 .40402 Mdot
.902 .40441 Mdot
.902 .405 Mdot
.902 .40545 Mdot
.902 .4058 Mdot
.902 .40585 Mdot
.902 .40759 Mdot
.902 .40796 Mdot
.902 .40824 Mdot
.902 .40907 Mdot
.902 .40916 Mdot
.902 .40926 Mdot
.902 .40935 Mdot
.902 .40946 Mdot
.902 .40983 Mdot
.902 .40999 Mdot
.902 .41007 Mdot
.902 .41041 Mdot
.902 .41041 Mdot
.902 .41086 Mdot
.902 .4112 Mdot
.902 .41131 Mdot
.902 .41172 Mdot
.902 .41188 Mdot
.902 .41222 Mdot
.902 .41359 Mdot
.902 .41491 Mdot
.902 .41518 Mdot
.902 .41557 Mdot
.902 .41601 Mdot
.902 .41623 Mdot
.902 .41694 Mdot
.902 .41694 Mdot
.902 .41699 Mdot
.902 .41704 Mdot
.902 .4173 Mdot
.902 .41749 Mdot
.902 .41799 Mdot
.902 .41814 Mdot
.902 .41855 Mdot
.902 .41943 Mdot
.902 .41963 Mdot
.902 .42016 Mdot
.902 .4205 Mdot
.902 .42051 Mdot
.902 .42161 Mdot
.902 .42169 Mdot
.902 .42204 Mdot
.902 .42246 Mdot
.902 .42283 Mdot
.902 .42337 Mdot
.902 .42379 Mdot
.902 .42393 Mdot
.902 .4253 Mdot
.902 .42531 Mdot
.902 .42556 Mdot
.902 .42598 Mdot
.902 .42618 Mdot
.902 .42632 Mdot
.902 .42632 Mdot
.902 .42675 Mdot
.902 .42689 Mdot
.902 .42726 Mdot
.902 .42742 Mdot
.902 .42852 Mdot
.902 .42918 Mdot
.902 .42937 Mdot
.902 .42976 Mdot
.902 .42995 Mdot
.902 .43026 Mdot
.902 .43059 Mdot
.902 .43063 Mdot
.902 .43079 Mdot
.902 .4309 Mdot
.902 .43147 Mdot
.902 .43177 Mdot
.902 .43181 Mdot
.902 .43195 Mdot
.902 .43305 Mdot
.902 .43332 Mdot
.902 .43438 Mdot
.902 .4345 Mdot
.902 .43503 Mdot
.902 .4353 Mdot
.902 .43654 Mdot
.902 .43671 Mdot
.902 .43696 Mdot
.902 .43759 Mdot
.902 .43882 Mdot
.902 .43917 Mdot
.902 .4394 Mdot
.902 .4397 Mdot
.902 .43972 Mdot
.902 .44002 Mdot
.902 .44008 Mdot
.902 .44015 Mdot
.902 .44039 Mdot
.902 .44065 Mdot
.902 .44149 Mdot
.902 .44171 Mdot
.902 .44233 Mdot
.902 .44234 Mdot
.902 .44241 Mdot
.902 .4425 Mdot
.902 .44253 Mdot
.902 .4427 Mdot
.902 .44334 Mdot
.902 .44368 Mdot
.902 .44489 Mdot
.902 .44494 Mdot
.902 .44541 Mdot
.902 .44568 Mdot
.902 .44591 Mdot
.902 .44631 Mdot
.902 .44666 Mdot
.902 .44677 Mdot
.902 .44679 Mdot
.902 .44783 Mdot
.902 .44826 Mdot
.902 .44832 Mdot
.902 .4489 Mdot
.902 .44911 Mdot
.902 .44936 Mdot
.902 .44945 Mdot
.902 .44949 Mdot
.902 .44965 Mdot
.902 .44971 Mdot
.902 .45063 Mdot
.902 .45105 Mdot
.902 .45158 Mdot
.902 .45251 Mdot
.902 .45257 Mdot
.902 .45266 Mdot
.902 .4528 Mdot
.902 .45335 Mdot
.902 .45359 Mdot
.902 .45368 Mdot
.902 .45479 Mdot
.902 .45523 Mdot
.902 .45546 Mdot
.902 .45556 Mdot
.902 .4556 Mdot
.902 .45593 Mdot
.902 .45599 Mdot
.902 .45601 Mdot
.902 .45634 Mdot
.902 .45713 Mdot
.902 .45744 Mdot
.902 .45835 Mdot
.902 .4589 Mdot
.902 .45922 Mdot
.902 .45945 Mdot
.902 .45946 Mdot
.902 .46066 Mdot
.902 .4608 Mdot
.902 .46137 Mdot
.902 .46143 Mdot
.902 .46149 Mdot
.902 .46168 Mdot
.902 .46219 Mdot
.902 .4623 Mdot
.902 .46308 Mdot
.902 .46349 Mdot
.902 .46356 Mdot
.902 .46379 Mdot
.902 .46411 Mdot
.902 .46445 Mdot
.902 .46484 Mdot
.902 .46495 Mdot
.902 .46499 Mdot
.902 .46558 Mdot
.902 .46573 Mdot
.902 .46614 Mdot
.902 .46633 Mdot
.902 .46678 Mdot
.902 .46691 Mdot
.902 .46718 Mdot
.902 .4674 Mdot
.902 .46802 Mdot
.902 .46802 Mdot
.902 .46819 Mdot
.902 .46836 Mdot
.902 .46921 Mdot
.902 .46932 Mdot
.902 .46946 Mdot
.902 .4698 Mdot
.902 .46982 Mdot
.902 .47073 Mdot
.902 .47108 Mdot
.902 .47126 Mdot
.902 .47144 Mdot
.902 .47195 Mdot
.902 .47218 Mdot
.902 .47323 Mdot
.902 .47328 Mdot
.902 .47328 Mdot
.902 .47347 Mdot
.902 .4738 Mdot
.902 .47397 Mdot
.902 .47399 Mdot
.902 .47418 Mdot
.902 .47552 Mdot
.902 .47605 Mdot
.902 .47613 Mdot
.902 .4768 Mdot
.902 .47699 Mdot
.902 .47709 Mdot
.902 .47714 Mdot
.902 .47807 Mdot
.902 .47844 Mdot
.902 .47851 Mdot
.902 .47928 Mdot
.902 .47963 Mdot
.902 .47965 Mdot
.902 .48009 Mdot
.902 .48059 Mdot
.902 .48071 Mdot
.902 .48091 Mdot
.902 .48109 Mdot
.902 .48151 Mdot
.902 .48163 Mdot
.902 .48295 Mdot
.902 .48322 Mdot
.902 .48327 Mdot
.902 .48342 Mdot
.902 .48348 Mdot
.902 .48376 Mdot
.902 .48462 Mdot
.902 .486 Mdot
.902 .48719 Mdot
.902 .48731 Mdot
.902 .48736 Mdot
.902 .48754 Mdot
.902 .48808 Mdot
.902 .48887 Mdot
.902 .48896 Mdot
.902 .48913 Mdot
.902 .48971 Mdot
.902 .49031 Mdot
.902 .4908 Mdot
.902 .49093 Mdot
.902 .49095 Mdot
.902 .49388 Mdot
.902 .4949 Mdot
.902 .49525 Mdot
.902 .49528 Mdot
.902 .49578 Mdot
.902 .49609 Mdot
.902 .49745 Mdot
.902 .49748 Mdot
.902 .49802 Mdot
.902 .49811 Mdot
.902 .49855 Mdot
.902 .49856 Mdot
.902 .49856 Mdot
.902 .49862 Mdot
.902 .49881 Mdot
.902 .49938 Mdot
.902 .49989 Mdot
.902 .49994 Mdot
.902 .5 Mdot
.902 .50032 Mdot
.902 .5004 Mdot
.902 .50047 Mdot
.902 .50107 Mdot
.902 .50154 Mdot
.902 .50163 Mdot
.902 .50198 Mdot
.902 .50214 Mdot
.902 .50215 Mdot
.902 .50216 Mdot
.902 .50253 Mdot
.902 .50321 Mdot
.902 .50393 Mdot
.902 .50416 Mdot
.902 .50572 Mdot
.902 .50595 Mdot
.902 .50613 Mdot
.902 .50642 Mdot
.902 .50676 Mdot
.902 .50721 Mdot
.902 .50786 Mdot
.902 .50848 Mdot
.902 .50897 Mdot
.902 .50918 Mdot
.902 .50945 Mdot
.902 .50974 Mdot
.902 .50976 Mdot
.902 .50993 Mdot
.902 .51037 Mdot
.902 .51058 Mdot
.902 .51083 Mdot
.902 .51136 Mdot
.902 .51221 Mdot
.902 .51244 Mdot
.902 .51256 Mdot
.902 .51258 Mdot
.902 .51296 Mdot
.902 .51311 Mdot
.902 .51324 Mdot
.902 .51346 Mdot
.902 .51422 Mdot
.902 .51468 Mdot
.902 .51532 Mdot
.902 .51605 Mdot
.902 .51626 Mdot
.902 .51628 Mdot
.902 .51644 Mdot
.902 .51689 Mdot
.902 .51713 Mdot
.902 .51751 Mdot
.902 .51836 Mdot
.902 .51904 Mdot
.902 .51925 Mdot
.902 .51976 Mdot
.902 .51988 Mdot
.902 .51994 Mdot
.902 .52018 Mdot
.902 .52046 Mdot
.902 .52101 Mdot
.902 .52135 Mdot
.902 .52147 Mdot
.902 .52166 Mdot
.902 .52168 Mdot
.902 .52176 Mdot
.902 .52274 Mdot
.902 .52356 Mdot
.902 .52377 Mdot
.902 .52479 Mdot
.902 .52515 Mdot
.902 .52517 Mdot
.902 .52533 Mdot
.902 .52648 Mdot
.902 .52657 Mdot
.902 .52691 Mdot
.902 .52779 Mdot
.902 .52801 Mdot
.902 .52855 Mdot
.902 .5286 Mdot
.902 .52872 Mdot
.902 .52896 Mdot
.902 .5301 Mdot
.902 .53011 Mdot
.902 .53116 Mdot
.902 .5314 Mdot
.902 .53181 Mdot
.902 .53217 Mdot
.902 .53238 Mdot
.902 .53276 Mdot
.902 .53304 Mdot
.902 .5332 Mdot
.902 .53369 Mdot
.902 .53381 Mdot
.902 .53457 Mdot
.902 .53474 Mdot
.902 .53507 Mdot
.902 .53523 Mdot
.902 .53611 Mdot
.902 .53748 Mdot
.902 .5382 Mdot
.902 .5383 Mdot
.902 .53865 Mdot
.902 .53923 Mdot
.902 .53931 Mdot
.902 .53977 Mdot
.902 .54036 Mdot
.902 .54055 Mdot
.902 .54112 Mdot
.902 .54142 Mdot
.902 .54185 Mdot
.902 .5421 Mdot
.902 .54217 Mdot
.902 .54218 Mdot
.902 .5424 Mdot
.902 .5425 Mdot
.902 .54281 Mdot
.902 .54304 Mdot
.902 .54305 Mdot
.902 .54311 Mdot
.902 .54316 Mdot
.902 .54334 Mdot
.902 .54346 Mdot
.902 .54357 Mdot
.902 .54436 Mdot
.902 .54508 Mdot
.902 .5452 Mdot
.902 .5458 Mdot
.902 .54581 Mdot
.904 .11851 Mdot
.904 .1201 Mdot
.904 .12244 Mdot
.904 .12256 Mdot
.904 .1254 Mdot
.904 .12547 Mdot
.904 .12563 Mdot
.904 .12619 Mdot
.904 .12842 Mdot
.904 .12891 Mdot
.904 .12911 Mdot
.904 .1293 Mdot
.904 .1312 Mdot
.904 .13138 Mdot
.904 .13185 Mdot
.904 .13236 Mdot
.904 .13321 Mdot
.904 .13359 Mdot
.904 .1339 Mdot
.904 .13409 Mdot
.904 .13459 Mdot
.904 .13579 Mdot
.904 .13672 Mdot
.904 .13747 Mdot
.904 .13761 Mdot
.904 .13791 Mdot
.904 .13803 Mdot
.904 .14203 Mdot
.904 .14204 Mdot
.904 .14467 Mdot
.904 .1459 Mdot
.904 .14602 Mdot
.904 .14687 Mdot
.904 .14723 Mdot
.904 .14736 Mdot
.904 .14777 Mdot
.904 .14817 Mdot
.904 .14946 Mdot
.904 .14962 Mdot
.904 .14962 Mdot
.904 .14964 Mdot
.904 .15028 Mdot
.904 .15028 Mdot
.904 .15051 Mdot
.904 .15071 Mdot
.904 .15095 Mdot
.904 .15122 Mdot
.904 .15179 Mdot
.904 .15229 Mdot
.904 .15261 Mdot
.904 .15297 Mdot
.904 .15387 Mdot
.904 .15399 Mdot
.904 .15469 Mdot
.904 .15474 Mdot
.904 .15661 Mdot
.904 .15721 Mdot
.904 .1575 Mdot
.904 .15804 Mdot
.904 .1604 Mdot
.904 .16193 Mdot
.904 .16215 Mdot
.904 .16266 Mdot
.904 .16362 Mdot
.904 .16474 Mdot
.904 .16513 Mdot
.904 .16733 Mdot
.904 .16807 Mdot
.904 .1715 Mdot
.904 .1718 Mdot
.904 .172 Mdot
.904 .17298 Mdot
.904 .17503 Mdot
.904 .17508 Mdot
.904 .17697 Mdot
.904 .17736 Mdot
.904 .17763 Mdot
.904 .1794 Mdot
.904 .17978 Mdot
.904 .17993 Mdot
.904 .18045 Mdot
.904 .18141 Mdot
.904 .18312 Mdot
.904 .18348 Mdot
.904 .1847 Mdot
.904 .18479 Mdot
.904 .18636 Mdot
.904 .18716 Mdot
.904 .18768 Mdot
.904 .18858 Mdot
.904 .18904 Mdot
.904 .1893 Mdot
.904 .18932 Mdot
.904 .19243 Mdot
.904 .19401 Mdot
.904 .19449 Mdot
.904 .19472 Mdot
.904 .19509 Mdot
.904 .19671 Mdot
.904 .19779 Mdot
.904 .19867 Mdot
.904 .19867 Mdot
.904 .19954 Mdot
.904 .20081 Mdot
.904 .20088 Mdot
.904 .2012 Mdot
.904 .20122 Mdot
.904 .20135 Mdot
.904 .2015 Mdot
.904 .20162 Mdot
.904 .2017 Mdot
.904 .20238 Mdot
.904 .20294 Mdot
.904 .20316 Mdot
.904 .20329 Mdot
.904 .20402 Mdot
.904 .20432 Mdot
.904 .20452 Mdot
.904 .20524 Mdot
.904 .20586 Mdot
.904 .20596 Mdot
.904 .20619 Mdot
.904 .20623 Mdot
.904 .20702 Mdot
.904 .20863 Mdot
.904 .20891 Mdot
.904 .20949 Mdot
.904 .20958 Mdot
.904 .20969 Mdot
.904 .20972 Mdot
.904 .21001 Mdot
.904 .21129 Mdot
.904 .21151 Mdot
.904 .21151 Mdot
.904 .21174 Mdot
.904 .2125 Mdot
.904 .21357 Mdot
.904 .21359 Mdot
.904 .21468 Mdot
.904 .21483 Mdot
.904 .21497 Mdot
.904 .21519 Mdot
.904 .21525 Mdot
.904 .21534 Mdot
.904 .21626 Mdot
.904 .21671 Mdot
.904 .21671 Mdot
.904 .21751 Mdot
.904 .21778 Mdot
.904 .21813 Mdot
.904 .21885 Mdot
.904 .21887 Mdot
.904 .22029 Mdot
.904 .22034 Mdot
.904 .22118 Mdot
.904 .22154 Mdot
.904 .22189 Mdot
.904 .22203 Mdot
.904 .22434 Mdot
.904 .22477 Mdot
.904 .22531 Mdot
.904 .22564 Mdot
.904 .22586 Mdot
.904 .22649 Mdot
.904 .22661 Mdot
.904 .22742 Mdot
.904 .22753 Mdot
.904 .22786 Mdot
.904 .22849 Mdot
.904 .22895 Mdot
.904 .22934 Mdot
.904 .22965 Mdot
.904 .23021 Mdot
.904 .23054 Mdot
.904 .23146 Mdot
.904 .23178 Mdot
.904 .2318 Mdot
.904 .23181 Mdot
.904 .23183 Mdot
.904 .23184 Mdot
.904 .23362 Mdot
.904 .23382 Mdot
.904 .23432 Mdot
.904 .23483 Mdot
.904 .2353 Mdot
.904 .23555 Mdot
.904 .2365 Mdot
.904 .23666 Mdot
.904 .23678 Mdot
.904 .23692 Mdot
.904 .23745 Mdot
.904 .23749 Mdot
.904 .23767 Mdot
.904 .23795 Mdot
.904 .23798 Mdot
.904 .23922 Mdot
.904 .24005 Mdot
.904 .24005 Mdot
.904 .24005 Mdot
.904 .24071 Mdot
.904 .24075 Mdot
.904 .24139 Mdot
.904 .24275 Mdot
.904 .24287 Mdot
.904 .2449 Mdot
.904 .24492 Mdot
.904 .24518 Mdot
.904 .24774 Mdot
.904 .24968 Mdot
.904 .25001 Mdot
.904 .2519 Mdot
.904 .25212 Mdot
.904 .25242 Mdot
.904 .25273 Mdot
.904 .25311 Mdot
.904 .25336 Mdot
.904 .25348 Mdot
.904 .25365 Mdot
.904 .25382 Mdot
.904 .25395 Mdot
.904 .2541 Mdot
.904 .25422 Mdot
.904 .2543 Mdot
.904 .25453 Mdot
.904 .255 Mdot
.904 .25513 Mdot
.904 .25528 Mdot
.904 .25555 Mdot
.904 .25587 Mdot
.904 .25601 Mdot
.904 .2568 Mdot
.904 .25726 Mdot
.904 .25747 Mdot
.904 .25751 Mdot
.904 .25798 Mdot
.904 .25808 Mdot
.904 .25823 Mdot
.904 .25833 Mdot
.904 .25862 Mdot
.904 .25862 Mdot
.904 .25865 Mdot
.904 .25865 Mdot
.904 .25868 Mdot
.904 .25896 Mdot
.904 .25912 Mdot
.904 .25962 Mdot
.904 .25964 Mdot
.904 .25981 Mdot
.904 .25981 Mdot
.904 .26024 Mdot
.904 .2606 Mdot
.904 .26103 Mdot
.904 .26112 Mdot
.904 .26152 Mdot
.904 .2617 Mdot
.904 .26198 Mdot
.904 .26229 Mdot
.904 .26235 Mdot
.904 .26255 Mdot
.904 .26344 Mdot
.904 .26403 Mdot
.904 .26426 Mdot
.904 .26468 Mdot
.904 .26527 Mdot
.904 .26529 Mdot
.904 .26546 Mdot
.904 .26564 Mdot
.904 .2661 Mdot
.904 .2663 Mdot
.904 .2664 Mdot
.904 .26653 Mdot
.904 .26657 Mdot
.904 .26675 Mdot
.904 .26735 Mdot
.904 .26779 Mdot
.904 .26787 Mdot
.904 .26802 Mdot
.904 .2683 Mdot
.904 .26974 Mdot
.904 .27123 Mdot
.904 .27126 Mdot
.904 .27168 Mdot
.904 .27187 Mdot
.904 .27209 Mdot
.904 .27234 Mdot
.904 .27287 Mdot
.904 .27309 Mdot
.904 .27346 Mdot
.904 .27384 Mdot
.904 .274 Mdot
.904 .2746 Mdot
.904 .27461 Mdot
.904 .27582 Mdot
.904 .27592 Mdot
.904 .2762 Mdot
.904 .2776 Mdot
.904 .27812 Mdot
.904 .27879 Mdot
.904 .2789 Mdot
.904 .27923 Mdot
.904 .27969 Mdot
.904 .27985 Mdot
.904 .28018 Mdot
.904 .28019 Mdot
.904 .28075 Mdot
.904 .28082 Mdot
.904 .28089 Mdot
.904 .28128 Mdot
.904 .28219 Mdot
.904 .28243 Mdot
.904 .28252 Mdot
.904 .28255 Mdot
.904 .28296 Mdot
.904 .28311 Mdot
.904 .28388 Mdot
.904 .28393 Mdot
.904 .28397 Mdot
.904 .28397 Mdot
.904 .28407 Mdot
.904 .28409 Mdot
.904 .28448 Mdot
.904 .28475 Mdot
.904 .28502 Mdot
.904 .28535 Mdot
.904 .28584 Mdot
.904 .28596 Mdot
.904 .28617 Mdot
.904 .28666 Mdot
.904 .28761 Mdot
.904 .28769 Mdot
.904 .28783 Mdot
.904 .28827 Mdot
.904 .28851 Mdot
.904 .28939 Mdot
.904 .29003 Mdot
.904 .29064 Mdot
.904 .29198 Mdot
.904 .29261 Mdot
.904 .29297 Mdot
.904 .29306 Mdot
.904 .29411 Mdot
.904 .29501 Mdot
.904 .29547 Mdot
.904 .29592 Mdot
.904 .29645 Mdot
.904 .29743 Mdot
.904 .29819 Mdot
.904 .2982 Mdot
.904 .29842 Mdot
.904 .29845 Mdot
.904 .29873 Mdot
.904 .29884 Mdot
.904 .29894 Mdot
.904 .29909 Mdot
.904 .29935 Mdot
.904 .29948 Mdot
.904 .29975 Mdot
.904 .29975 Mdot
.904 .30032 Mdot
.904 .30044 Mdot
.904 .30048 Mdot
.904 .30059 Mdot
.904 .30085 Mdot
.904 .30089 Mdot
.904 .30127 Mdot
.904 .30207 Mdot
.904 .30334 Mdot
.904 .3037 Mdot
.904 .30398 Mdot
.904 .30435 Mdot
.904 .3045 Mdot
.904 .30456 Mdot
.904 .30466 Mdot
.904 .30519 Mdot
.904 .30533 Mdot
.904 .30539 Mdot
.904 .30603 Mdot
.904 .30709 Mdot
.904 .30714 Mdot
.904 .30803 Mdot
.904 .30807 Mdot
.904 .30878 Mdot
.904 .30927 Mdot
.904 .31223 Mdot
.904 .31247 Mdot
.904 .31315 Mdot
.904 .3133 Mdot
.904 .31342 Mdot
.904 .31436 Mdot
.904 .31462 Mdot
.904 .31592 Mdot
.904 .31597 Mdot
.904 .31609 Mdot
.904 .31732 Mdot
.904 .3192 Mdot
.904 .31947 Mdot
.904 .31959 Mdot
.904 .31965 Mdot
.904 .31984 Mdot
.904 .31984 Mdot
.904 .31998 Mdot
.904 .32013 Mdot
.904 .32178 Mdot
.904 .32205 Mdot
.904 .32222 Mdot
.904 .32363 Mdot
.904 .32427 Mdot
.904 .32506 Mdot
.904 .32649 Mdot
.904 .32743 Mdot
.904 .32801 Mdot
.904 .32813 Mdot
.904 .32821 Mdot
.904 .32887 Mdot
.904 .32891 Mdot
.904 .32907 Mdot
.904 .32989 Mdot
.904 .33037 Mdot
.904 .3304 Mdot
.904 .33128 Mdot
.904 .33178 Mdot
.904 .33337 Mdot
.904 .33465 Mdot
.904 .33555 Mdot
.904 .33557 Mdot
.904 .33595 Mdot
.904 .33602 Mdot
.904 .33606 Mdot
.904 .33638 Mdot
.904 .33695 Mdot
.904 .33769 Mdot
.904 .33778 Mdot
.904 .33798 Mdot
.904 .33803 Mdot
.904 .33857 Mdot
.904 .33888 Mdot
.904 .33975 Mdot
.904 .34016 Mdot
.904 .34041 Mdot
.904 .34082 Mdot
.904 .34083 Mdot
.904 .3425 Mdot
.904 .34263 Mdot
.904 .34296 Mdot
.904 .34377 Mdot
.904 .34403 Mdot
.904 .34478 Mdot
.904 .34478 Mdot
.904 .34479 Mdot
.904 .34571 Mdot
.904 .34622 Mdot
.904 .34666 Mdot
.904 .34667 Mdot
.904 .3473 Mdot
.904 .3473 Mdot
.904 .34751 Mdot
.904 .34887 Mdot
.904 .35035 Mdot
.904 .35118 Mdot
.904 .3513 Mdot
.904 .35141 Mdot
.904 .35156 Mdot
.904 .35164 Mdot
.904 .35188 Mdot
.904 .35192 Mdot
.904 .35214 Mdot
.904 .35243 Mdot
.904 .35257 Mdot
.904 .35263 Mdot
.904 .35279 Mdot
.904 .353 Mdot
.904 .35314 Mdot
.904 .35329 Mdot
.904 .35401 Mdot
.904 .35502 Mdot
.904 .35502 Mdot
.904 .35508 Mdot
.904 .35527 Mdot
.904 .35542 Mdot
.904 .35547 Mdot
.904 .35566 Mdot
.904 .35586 Mdot
.904 .35639 Mdot
.904 .35698 Mdot
.904 .35753 Mdot
.904 .35788 Mdot
.904 .35825 Mdot
.904 .35919 Mdot
.904 .35929 Mdot
.904 .35943 Mdot
.904 .35948 Mdot
.904 .3603 Mdot
.904 .36031 Mdot
.904 .36048 Mdot
.904 .3609 Mdot
.904 .36098 Mdot
.904 .36185 Mdot
.904 .36206 Mdot
.904 .3624 Mdot
.904 .36349 Mdot
.904 .36456 Mdot
.904 .36516 Mdot
.904 .36532 Mdot
.904 .36549 Mdot
.904 .36557 Mdot
.904 .36578 Mdot
.904 .36579 Mdot
.904 .36583 Mdot
.904 .36678 Mdot
.904 .36686 Mdot
.904 .36702 Mdot
.904 .36723 Mdot
.904 .36729 Mdot
.904 .36781 Mdot
.904 .36783 Mdot
.904 .3681 Mdot
.904 .37012 Mdot
.904 .37052 Mdot
.904 .37053 Mdot
.904 .37094 Mdot
.904 .3716 Mdot
.904 .37164 Mdot
.904 .37171 Mdot
.904 .37176 Mdot
.904 .3718 Mdot
.904 .37231 Mdot
.904 .37287 Mdot
.904 .37307 Mdot
.904 .37425 Mdot
.904 .37427 Mdot
.904 .37521 Mdot
.904 .37537 Mdot
.904 .37585 Mdot
.904 .37624 Mdot
.904 .37652 Mdot
.904 .37668 Mdot
.904 .37677 Mdot
.904 .37695 Mdot
.904 .37718 Mdot
.904 .3772 Mdot
.904 .37726 Mdot
.904 .37728 Mdot
.904 .37744 Mdot
.904 .37813 Mdot
.904 .37879 Mdot
.904 .37911 Mdot
.904 .37978 Mdot
.904 .37992 Mdot
.904 .37992 Mdot
.904 .38105 Mdot
.904 .38137 Mdot
.904 .38186 Mdot
.904 .38249 Mdot
.904 .38255 Mdot
.904 .38346 Mdot
.904 .38378 Mdot
.904 .38383 Mdot
.904 .38463 Mdot
.904 .38539 Mdot
.904 .38568 Mdot
.904 .3857 Mdot
.904 .38577 Mdot
.904 .38607 Mdot
.904 .38639 Mdot
.904 .38648 Mdot
.904 .388 Mdot
.904 .38865 Mdot
.904 .3887 Mdot
.904 .3891 Mdot
.904 .38926 Mdot
.904 .38928 Mdot
.904 .38955 Mdot
.904 .39118 Mdot
.904 .39177 Mdot
.904 .39185 Mdot
.904 .39188 Mdot
.904 .39295 Mdot
.904 .39372 Mdot
.904 .39374 Mdot
.904 .39432 Mdot
.904 .3945 Mdot
.904 .39472 Mdot
.904 .39504 Mdot
.904 .39548 Mdot
.904 .39607 Mdot
.904 .39608 Mdot
.904 .39613 Mdot
.904 .39646 Mdot
.904 .39752 Mdot
.904 .39761 Mdot
.904 .39783 Mdot
.904 .39928 Mdot
.904 .39945 Mdot
.904 .39949 Mdot
.904 .3995 Mdot
.904 .39966 Mdot
.904 .40008 Mdot
.904 .40072 Mdot
.904 .40123 Mdot
.904 .40206 Mdot
.904 .40276 Mdot
.904 .40331 Mdot
.904 .40367 Mdot
.904 .40415 Mdot
.904 .40419 Mdot
.904 .40433 Mdot
.904 .40448 Mdot
.904 .40493 Mdot
.904 .4052 Mdot
.904 .40529 Mdot
.904 .40647 Mdot
.904 .40658 Mdot
.904 .40717 Mdot
.904 .4072 Mdot
.904 .40722 Mdot
.904 .40726 Mdot
.904 .40728 Mdot
.904 .40922 Mdot
.904 .40937 Mdot
.904 .40995 Mdot
.904 .4105 Mdot
.904 .4105 Mdot
.904 .41062 Mdot
.904 .41067 Mdot
.904 .41085 Mdot
.904 .41118 Mdot
.904 .41177 Mdot
.904 .41256 Mdot
.904 .41268 Mdot
.904 .41353 Mdot
.904 .41399 Mdot
.904 .41402 Mdot
.904 .41409 Mdot
.904 .41467 Mdot
.904 .4157 Mdot
.904 .41599 Mdot
.904 .41621 Mdot
.904 .41632 Mdot
.904 .41642 Mdot
.904 .41646 Mdot
.904 .41741 Mdot
.904 .4175 Mdot
.904 .41757 Mdot
.904 .41781 Mdot
.904 .41833 Mdot
.904 .41837 Mdot
.904 .41845 Mdot
.904 .41904 Mdot
.904 .42061 Mdot
.904 .42107 Mdot
.904 .42108 Mdot
.904 .42132 Mdot
.904 .42211 Mdot
.904 .42212 Mdot
.904 .42212 Mdot
.904 .42254 Mdot
.904 .42313 Mdot
.904 .42331 Mdot
.904 .42338 Mdot
.904 .42431 Mdot
.904 .42454 Mdot
.904 .42555 Mdot
.904 .42585 Mdot
.904 .42588 Mdot
.904 .42599 Mdot
.904 .42604 Mdot
.904 .42645 Mdot
.904 .42677 Mdot
.904 .42694 Mdot
.904 .427 Mdot
.904 .42721 Mdot
.904 .42723 Mdot
.904 .42773 Mdot
.904 .42843 Mdot
.904 .42931 Mdot
.904 .42959 Mdot
.904 .4309 Mdot
.904 .43092 Mdot
.904 .43128 Mdot
.904 .43133 Mdot
.904 .4314 Mdot
.904 .43347 Mdot
.904 .43382 Mdot
.904 .43484 Mdot
.904 .43575 Mdot
.904 .43584 Mdot
.904 .43591 Mdot
.904 .43602 Mdot
.904 .43605 Mdot
.904 .43612 Mdot
.904 .43731 Mdot
.904 .43806 Mdot
.904 .43808 Mdot
.904 .4388 Mdot
.904 .43953 Mdot
.904 .44012 Mdot
.904 .44245 Mdot
.904 .44294 Mdot
.904 .44297 Mdot
.904 .44355 Mdot
.904 .44391 Mdot
.904 .44394 Mdot
.904 .44402 Mdot
.904 .4444 Mdot
.904 .44448 Mdot
.904 .44468 Mdot
.904 .44484 Mdot
.904 .44504 Mdot
.904 .44574 Mdot
.904 .44619 Mdot
.904 .4464 Mdot
.904 .44656 Mdot
.904 .44662 Mdot
.904 .44664 Mdot
.904 .44671 Mdot
.904 .44702 Mdot
.904 .44702 Mdot
.904 .44718 Mdot
.904 .44725 Mdot
.904 .44748 Mdot
.904 .44753 Mdot
.904 .44774 Mdot
.904 .44776 Mdot
.904 .44788 Mdot
.904 .44831 Mdot
.904 .44885 Mdot
.904 .44914 Mdot
.904 .44939 Mdot
.904 .44965 Mdot
.904 .45015 Mdot
.904 .45073 Mdot
.904 .45078 Mdot
.904 .45098 Mdot
.904 .4524 Mdot
.904 .45275 Mdot
.904 .45324 Mdot
.904 .45338 Mdot
.904 .45362 Mdot
.904 .45369 Mdot
.904 .45374 Mdot
.904 .45453 Mdot
.904 .45472 Mdot
.904 .45499 Mdot
.904 .45517 Mdot
.904 .45532 Mdot
.904 .45547 Mdot
.904 .45569 Mdot
.904 .4557 Mdot
.904 .45575 Mdot
.904 .45576 Mdot
.904 .4558 Mdot
.904 .45623 Mdot
.904 .45631 Mdot
.904 .45654 Mdot
.904 .45656 Mdot
.904 .4566 Mdot
.904 .4575 Mdot
.904 .45754 Mdot
.904 .45785 Mdot
.904 .45785 Mdot
.904 .45803 Mdot
.904 .45812 Mdot
.904 .45838 Mdot
.904 .45856 Mdot
.904 .45862 Mdot
.904 .45928 Mdot
.904 .46005 Mdot
.904 .46021 Mdot
.904 .46026 Mdot
.904 .46093 Mdot
.904 .46094 Mdot
.904 .46127 Mdot
.904 .46156 Mdot
.904 .46177 Mdot
.904 .46233 Mdot
.904 .46244 Mdot
.904 .46255 Mdot
.904 .4628 Mdot
.904 .46363 Mdot
.904 .46442 Mdot
.904 .46458 Mdot
.904 .46495 Mdot
.904 .46528 Mdot
.904 .46538 Mdot
.904 .46547 Mdot
.904 .46564 Mdot
.904 .46589 Mdot
.904 .46599 Mdot
.904 .46609 Mdot
.904 .4661 Mdot
.904 .46666 Mdot
.904 .46771 Mdot
.904 .46775 Mdot
.904 .46792 Mdot
.904 .46807 Mdot
.904 .46839 Mdot
.904 .46921 Mdot
.904 .46922 Mdot
.904 .4695 Mdot
.904 .46959 Mdot
.904 .46974 Mdot
.904 .46976 Mdot
.904 .46999 Mdot
.904 .47007 Mdot
.904 .47013 Mdot
.904 .47039 Mdot
.904 .47041 Mdot
.904 .47053 Mdot
.904 .47078 Mdot
.904 .47129 Mdot
.904 .47147 Mdot
.904 .4717 Mdot
.904 .47178 Mdot
.904 .47221 Mdot
.904 .47227 Mdot
.904 .47236 Mdot
.904 .47243 Mdot
.904 .47262 Mdot
.904 .47268 Mdot
.904 .47282 Mdot
.904 .47303 Mdot
.904 .4732 Mdot
.904 .47454 Mdot
.904 .47579 Mdot
.904 .47721 Mdot
.904 .47849 Mdot
.904 .47855 Mdot
.904 .47931 Mdot
.904 .47966 Mdot
.904 .47968 Mdot
.904 .48005 Mdot
.904 .48005 Mdot
.904 .48005 Mdot
.904 .48051 Mdot
.904 .48119 Mdot
.904 .48121 Mdot
.904 .48146 Mdot
.904 .48185 Mdot
.904 .48201 Mdot
.904 .48253 Mdot
.904 .48293 Mdot
.904 .48321 Mdot
.904 .48349 Mdot
.904 .48458 Mdot
.904 .48459 Mdot
.904 .4846 Mdot
.904 .48461 Mdot
.904 .48462 Mdot
.904 .48597 Mdot
.904 .48644 Mdot
.904 .48679 Mdot
.904 .48697 Mdot
.904 .48748 Mdot
.904 .4879 Mdot
.904 .4885 Mdot
.904 .48873 Mdot
.904 .49001 Mdot
.904 .49095 Mdot
.904 .49176 Mdot
.904 .49177 Mdot
.904 .49217 Mdot
.904 .49236 Mdot
.904 .49251 Mdot
.904 .49296 Mdot
.904 .49296 Mdot
.904 .49371 Mdot
.904 .4938 Mdot
.904 .49408 Mdot
.904 .49468 Mdot
.904 .49469 Mdot
.904 .49528 Mdot
.904 .4957 Mdot
.904 .49583 Mdot
.904 .49583 Mdot
.904 .49595 Mdot
.904 .49666 Mdot
.904 .49682 Mdot
.904 .4969 Mdot
.904 .49727 Mdot
.904 .49742 Mdot
.904 .49832 Mdot
.904 .49875 Mdot
.904 .49877 Mdot
.904 .4989 Mdot
.904 .49896 Mdot
.904 .4997 Mdot
.904 .49981 Mdot
.904 .49997 Mdot
.904 .50038 Mdot
.904 .50045 Mdot
.904 .50057 Mdot
.904 .50126 Mdot
.904 .5013 Mdot
.904 .50137 Mdot
.904 .50145 Mdot
.904 .50152 Mdot
.904 .50153 Mdot
.904 .50171 Mdot
.904 .50175 Mdot
.904 .50245 Mdot
.904 .50293 Mdot
.904 .50293 Mdot
.904 .50342 Mdot
.904 .50401 Mdot
.904 .50492 Mdot
.904 .50512 Mdot
.904 .50525 Mdot
.904 .50551 Mdot
.904 .50639 Mdot
.904 .5081 Mdot
.904 .50811 Mdot
.904 .50826 Mdot
.904 .50851 Mdot
.904 .50901 Mdot
.904 .5093 Mdot
.904 .50974 Mdot
.904 .51061 Mdot
.904 .51066 Mdot
.904 .51133 Mdot
.904 .51153 Mdot
.904 .51248 Mdot
.904 .51301 Mdot
.904 .5133 Mdot
.904 .51338 Mdot
.904 .51359 Mdot
.904 .51457 Mdot
.904 .51472 Mdot
.904 .51494 Mdot
.904 .51598 Mdot
.904 .51601 Mdot
.904 .51714 Mdot
.904 .51768 Mdot
.904 .51779 Mdot
.904 .51796 Mdot
.904 .51986 Mdot
.904 .52027 Mdot
.904 .52149 Mdot
.904 .5217 Mdot
.904 .52232 Mdot
.904 .52285 Mdot
.904 .52313 Mdot
.904 .5241 Mdot
.904 .52541 Mdot
.904 .5257 Mdot
.904 .52586 Mdot
.904 .5262 Mdot
.904 .52723 Mdot
.904 .52726 Mdot
.904 .52764 Mdot
.904 .52771 Mdot
.904 .52821 Mdot
.904 .52841 Mdot
.904 .52859 Mdot
.904 .52886 Mdot
.904 .52918 Mdot
.904 .52933 Mdot
.904 .52946 Mdot
.904 .52957 Mdot
.904 .5297 Mdot
.904 .5297 Mdot
.904 .53005 Mdot
.904 .53006 Mdot
.904 .53006 Mdot
.904 .53015 Mdot
.904 .53086 Mdot
.904 .53109 Mdot
.904 .53131 Mdot
.904 .53139 Mdot
.904 .53158 Mdot
.904 .53205 Mdot
.904 .53212 Mdot
.904 .5328 Mdot
.904 .53426 Mdot
.904 .53426 Mdot
.904 .53647 Mdot
.904 .53654 Mdot
.904 .5367 Mdot
.904 .53678 Mdot
.904 .5372 Mdot
.904 .53771 Mdot
.904 .53837 Mdot
.904 .53865 Mdot
.904 .53875 Mdot
.904 .53893 Mdot
.904 .53914 Mdot
.904 .53961 Mdot
.904 .53989 Mdot
.904 .54015 Mdot
.904 .54025 Mdot
.904 .5413 Mdot
.904 .54141 Mdot
.904 .54152 Mdot
.904 .54179 Mdot
.904 .54302 Mdot
.904 .54333 Mdot
.904 .54342 Mdot
.904 .54346 Mdot
.904 .54503 Mdot
.904 .54509 Mdot
.904 .54639 Mdot
.904 .54727 Mdot
.906 .11541 Mdot
.906 .11599 Mdot
.906 .11606 Mdot
.906 .11608 Mdot
.906 .11615 Mdot
.906 .11657 Mdot
.906 .11748 Mdot
.906 .11809 Mdot
.906 .11895 Mdot
.906 .12031 Mdot
.906 .12128 Mdot
.906 .12193 Mdot
.906 .12229 Mdot
.906 .12264 Mdot
.906 .12286 Mdot
.906 .12353 Mdot
.906 .12435 Mdot
.906 .12481 Mdot
.906 .12623 Mdot
.906 .12627 Mdot
.906 .1271 Mdot
.906 .12726 Mdot
.906 .12798 Mdot
.906 .12888 Mdot
.906 .1299 Mdot
.906 .13059 Mdot
.906 .13091 Mdot
.906 .13302 Mdot
.906 .13336 Mdot
.906 .13441 Mdot
.906 .13505 Mdot
.906 .13549 Mdot
.906 .13609 Mdot
.906 .13636 Mdot
.906 .13708 Mdot
.906 .13729 Mdot
.906 .13897 Mdot
.906 .13904 Mdot
.906 .13929 Mdot
.906 .14278 Mdot
.906 .14287 Mdot
.906 .14313 Mdot
.906 .14378 Mdot
.906 .1438 Mdot
.906 .14531 Mdot
.906 .14562 Mdot
.906 .14677 Mdot
.906 .14683 Mdot
.906 .14696 Mdot
.906 .14702 Mdot
.906 .14811 Mdot
.906 .14821 Mdot
.906 .14955 Mdot
.906 .14981 Mdot
.906 .15144 Mdot
.906 .15326 Mdot
.906 .15329 Mdot
.906 .15331 Mdot
.906 .1545 Mdot
.906 .15468 Mdot
.906 .15501 Mdot
.906 .15537 Mdot
.906 .15574 Mdot
.906 .15689 Mdot
.906 .157 Mdot
.906 .1582 Mdot
.906 .15923 Mdot
.906 .15994 Mdot
.906 .16054 Mdot
.906 .16058 Mdot
.906 .1609 Mdot
.906 .16097 Mdot
.906 .16125 Mdot
.906 .16193 Mdot
.906 .16209 Mdot
.906 .16282 Mdot
.906 .1635 Mdot
.906 .16573 Mdot
.906 .16623 Mdot
.906 .16642 Mdot
.906 .16703 Mdot
.906 .17216 Mdot
.906 .1722 Mdot
.906 .17346 Mdot
.906 .17688 Mdot
.906 .17735 Mdot
.906 .17736 Mdot
.906 .17736 Mdot
.906 .17754 Mdot
.906 .17837 Mdot
.906 .17936 Mdot
.906 .17951 Mdot
.906 .17966 Mdot
.906 .17998 Mdot
.906 .18119 Mdot
.906 .18122 Mdot
.906 .1815 Mdot
.906 .18232 Mdot
.906 .18285 Mdot
.906 .18426 Mdot
.906 .1852 Mdot
.906 .18525 Mdot
.906 .18709 Mdot
.906 .18788 Mdot
.906 .18912 Mdot
.906 .18927 Mdot
.906 .18959 Mdot
.906 .19014 Mdot
.906 .19037 Mdot
.906 .1906 Mdot
.906 .19116 Mdot
.906 .19175 Mdot
.906 .19247 Mdot
.906 .19307 Mdot
.906 .1934 Mdot
.906 .19379 Mdot
.906 .19386 Mdot
.906 .19603 Mdot
.906 .19643 Mdot
.906 .19712 Mdot
.906 .19717 Mdot
.906 .19823 Mdot
.906 .19836 Mdot
.906 .19839 Mdot
.906 .19851 Mdot
.906 .19854 Mdot
.906 .19904 Mdot
.906 .19927 Mdot
.906 .19991 Mdot
.906 .20093 Mdot
.906 .20204 Mdot
.906 .20259 Mdot
.906 .20358 Mdot
.906 .20419 Mdot
.906 .20477 Mdot
.906 .20522 Mdot
.906 .20606 Mdot
.906 .20674 Mdot
.906 .20692 Mdot
.906 .20722 Mdot
.906 .20759 Mdot
.906 .2078 Mdot
.906 .20781 Mdot
.906 .20786 Mdot
.906 .20879 Mdot
.906 .20898 Mdot
.906 .20963 Mdot
.906 .20977 Mdot
.906 .21016 Mdot
.906 .21027 Mdot
.906 .21067 Mdot
.906 .21113 Mdot
.906 .21127 Mdot
.906 .21162 Mdot
.906 .21182 Mdot
.906 .21189 Mdot
.906 .21196 Mdot
.906 .21205 Mdot
.906 .21249 Mdot
.906 .21252 Mdot
.906 .21252 Mdot
.906 .21267 Mdot
.906 .21338 Mdot
.906 .21358 Mdot
.906 .21398 Mdot
.906 .2142 Mdot
.906 .21594 Mdot
.906 .21617 Mdot
.906 .21677 Mdot
.906 .21685 Mdot
.906 .21698 Mdot
.906 .21836 Mdot
.906 .21865 Mdot
.906 .21972 Mdot
.906 .21994 Mdot
.906 .22132 Mdot
.906 .22158 Mdot
.906 .22316 Mdot
.906 .22335 Mdot
.906 .22343 Mdot
.906 .22394 Mdot
.906 .22433 Mdot
.906 .22451 Mdot
.906 .22468 Mdot
.906 .22527 Mdot
.906 .22538 Mdot
.906 .2261 Mdot
.906 .22726 Mdot
.906 .2278 Mdot
.906 .22812 Mdot
.906 .22908 Mdot
.906 .22933 Mdot
.906 .22969 Mdot
.906 .23005 Mdot
.906 .23027 Mdot
.906 .23037 Mdot
.906 .23161 Mdot
.906 .23187 Mdot
.906 .23188 Mdot
.906 .2322 Mdot
.906 .23263 Mdot
.906 .23276 Mdot
.906 .23328 Mdot
.906 .23356 Mdot
.906 .23376 Mdot
.906 .23387 Mdot
.906 .23464 Mdot
.906 .23513 Mdot
.906 .23603 Mdot
.906 .23644 Mdot
.906 .23682 Mdot
.906 .23721 Mdot
.906 .23789 Mdot
.906 .23847 Mdot
.906 .23925 Mdot
.906 .23945 Mdot
.906 .23987 Mdot
.906 .23999 Mdot
.906 .24017 Mdot
.906 .24034 Mdot
.906 .24045 Mdot
.906 .24192 Mdot
.906 .24211 Mdot
.906 .24317 Mdot
.906 .24329 Mdot
.906 .24359 Mdot
.906 .24445 Mdot
.906 .24448 Mdot
.906 .2446 Mdot
.906 .24469 Mdot
.906 .24469 Mdot
.906 .24518 Mdot
.906 .24677 Mdot
.906 .24692 Mdot
.906 .24693 Mdot
.906 .24741 Mdot
.906 .24767 Mdot
.906 .2485 Mdot
.906 .24858 Mdot
.906 .24862 Mdot
.906 .24903 Mdot
.906 .25067 Mdot
.906 .25102 Mdot
.906 .25135 Mdot
.906 .25192 Mdot
.906 .25211 Mdot
.906 .25399 Mdot
.906 .2541 Mdot
.906 .25433 Mdot
.906 .25434 Mdot
.906 .25445 Mdot
.906 .25454 Mdot
.906 .25642 Mdot
.906 .25661 Mdot
.906 .25741 Mdot
.906 .25806 Mdot
.906 .25877 Mdot
.906 .25903 Mdot
.906 .25914 Mdot
.906 .25927 Mdot
.906 .25949 Mdot
.906 .2595 Mdot
.906 .26114 Mdot
.906 .26221 Mdot
.906 .26223 Mdot
.906 .26246 Mdot
.906 .26378 Mdot
.906 .26445 Mdot
.906 .26575 Mdot
.906 .26582 Mdot
.906 .26586 Mdot
.906 .26597 Mdot
.906 .26638 Mdot
.906 .26732 Mdot
.906 .268 Mdot
.906 .26833 Mdot
.906 .26894 Mdot
.906 .26958 Mdot
.906 .27026 Mdot
.906 .27029 Mdot
.906 .27032 Mdot
.906 .27072 Mdot
.906 .27104 Mdot
.906 .2711 Mdot
.906 .27233 Mdot
.906 .27254 Mdot
.906 .27359 Mdot
.906 .27393 Mdot
.906 .27462 Mdot
.906 .27465 Mdot
.906 .27472 Mdot
.906 .27658 Mdot
.906 .27738 Mdot
.906 .27786 Mdot
.906 .2787 Mdot
.906 .27894 Mdot
.906 .27902 Mdot
.906 .27961 Mdot
.906 .27973 Mdot
.906 .28001 Mdot
.906 .28006 Mdot
.906 .28006 Mdot
.906 .28023 Mdot
.906 .28027 Mdot
.906 .28044 Mdot
.906 .28078 Mdot
.906 .28119 Mdot
.906 .28148 Mdot
.906 .28156 Mdot
.906 .28176 Mdot
.906 .28242 Mdot
.906 .28308 Mdot
.906 .28431 Mdot
.906 .28475 Mdot
.906 .28508 Mdot
.906 .28574 Mdot
.906 .28687 Mdot
.906 .28836 Mdot
.906 .28909 Mdot
.906 .28926 Mdot
.906 .2895 Mdot
.906 .2896 Mdot
.906 .29011 Mdot
.906 .29016 Mdot
.906 .29071 Mdot
.906 .29195 Mdot
.906 .2941 Mdot
.906 .29416 Mdot
.906 .29431 Mdot
.906 .29519 Mdot
.906 .29542 Mdot
.906 .29546 Mdot
.906 .29578 Mdot
.906 .29629 Mdot
.906 .2966 Mdot
.906 .29697 Mdot
.906 .297 Mdot
.906 .29735 Mdot
.906 .29767 Mdot
.906 .29773 Mdot
.906 .29811 Mdot
.906 .30001 Mdot
.906 .30008 Mdot
.906 .30043 Mdot
.906 .30119 Mdot
.906 .3013 Mdot
.906 .30236 Mdot
.906 .30244 Mdot
.906 .30427 Mdot
.906 .30491 Mdot
.906 .30553 Mdot
.906 .30602 Mdot
.906 .30633 Mdot
.906 .30677 Mdot
.906 .30716 Mdot
.906 .30743 Mdot
.906 .30754 Mdot
.906 .30765 Mdot
.906 .30785 Mdot
.906 .30856 Mdot
.906 .309 Mdot
.906 .30941 Mdot
.906 .30943 Mdot
.906 .30943 Mdot
.906 .30946 Mdot
.906 .30976 Mdot
.906 .31011 Mdot
.906 .31058 Mdot
.906 .31125 Mdot
.906 .31203 Mdot
.906 .31248 Mdot
.906 .31305 Mdot
.906 .31332 Mdot
.906 .31359 Mdot
.906 .31417 Mdot
.906 .31438 Mdot
.906 .31523 Mdot
.906 .31555 Mdot
.906 .31574 Mdot
.906 .31588 Mdot
.906 .31606 Mdot
.906 .31614 Mdot
.906 .31636 Mdot
.906 .31642 Mdot
.906 .31694 Mdot
.906 .31812 Mdot
.906 .3184 Mdot
.906 .31841 Mdot
.906 .31887 Mdot
.906 .31933 Mdot
.906 .31937 Mdot
.906 .31972 Mdot
.906 .31975 Mdot
.906 .32016 Mdot
.906 .32024 Mdot
.906 .32073 Mdot
.906 .3213 Mdot
.906 .3213 Mdot
.906 .32182 Mdot
.906 .32193 Mdot
.906 .32332 Mdot
.906 .3235 Mdot
.906 .32352 Mdot
.906 .32364 Mdot
.906 .32372 Mdot
.906 .32441 Mdot
.906 .32548 Mdot
.906 .32704 Mdot
.906 .32706 Mdot
.906 .32848 Mdot
.906 .32862 Mdot
.906 .32863 Mdot
.906 .32863 Mdot
.906 .32893 Mdot
.906 .32933 Mdot
.906 .32943 Mdot
.906 .3298 Mdot
.906 .33073 Mdot
.906 .33102 Mdot
.906 .33159 Mdot
.906 .33183 Mdot
.906 .33221 Mdot
.906 .33226 Mdot
.906 .33235 Mdot
.906 .33259 Mdot
.906 .33266 Mdot
.906 .33283 Mdot
.906 .33301 Mdot
.906 .33323 Mdot
.906 .33341 Mdot
.906 .33351 Mdot
.906 .33363 Mdot
.906 .33444 Mdot
.906 .33523 Mdot
.906 .3355 Mdot
.906 .3368 Mdot
.906 .33711 Mdot
.906 .33757 Mdot
.906 .33772 Mdot
.906 .3379 Mdot
.906 .3385 Mdot
.906 .33891 Mdot
.906 .33906 Mdot
.906 .33919 Mdot
.906 .33933 Mdot
.906 .34258 Mdot
.906 .34293 Mdot
.906 .34299 Mdot
.906 .34325 Mdot
.906 .34347 Mdot
.906 .34383 Mdot
.906 .34399 Mdot
.906 .34409 Mdot
.906 .34446 Mdot
.906 .34523 Mdot
.906 .34523 Mdot
.906 .34533 Mdot
.906 .34566 Mdot
.906 .34584 Mdot
.906 .3465 Mdot
.906 .34724 Mdot
.906 .34748 Mdot
.906 .34754 Mdot
.906 .34776 Mdot
.906 .34781 Mdot
.906 .34871 Mdot
.906 .3488 Mdot
.906 .34906 Mdot
.906 .34914 Mdot
.906 .34928 Mdot
.906 .35004 Mdot
.906 .35029 Mdot
.906 .35096 Mdot
.906 .35214 Mdot
.906 .35321 Mdot
.906 .35415 Mdot
.906 .35447 Mdot
.906 .35448 Mdot
.906 .35515 Mdot
.906 .35574 Mdot
.906 .35603 Mdot
.906 .35694 Mdot
.906 .35706 Mdot
.906 .35794 Mdot
.906 .35804 Mdot
.906 .35826 Mdot
.906 .35909 Mdot
.906 .35949 Mdot
.906 .35991 Mdot
.906 .35997 Mdot
.906 .36002 Mdot
.906 .36144 Mdot
.906 .36164 Mdot
.906 .36266 Mdot
.906 .36298 Mdot
.906 .36353 Mdot
.906 .36418 Mdot
.906 .3642 Mdot
.906 .36425 Mdot
.906 .36452 Mdot
.906 .36458 Mdot
.906 .3646 Mdot
.906 .36469 Mdot
.906 .36517 Mdot
.906 .36527 Mdot
.906 .36611 Mdot
.906 .36634 Mdot
.906 .36638 Mdot
.906 .36672 Mdot
.906 .36766 Mdot
.906 .36781 Mdot
.906 .36791 Mdot
.906 .36816 Mdot
.906 .36824 Mdot
.906 .36828 Mdot
.906 .36831 Mdot
.906 .36886 Mdot
.906 .36906 Mdot
.906 .3692 Mdot
.906 .36964 Mdot
.906 .36978 Mdot
.906 .37062 Mdot
.906 .37072 Mdot
.906 .37087 Mdot
.906 .3715 Mdot
.906 .37158 Mdot
.906 .37187 Mdot
.906 .372 Mdot
.906 .37212 Mdot
.906 .37214 Mdot
.906 .37229 Mdot
.906 .37308 Mdot
.906 .37314 Mdot
.906 .37314 Mdot
.906 .37341 Mdot
.906 .37374 Mdot
.906 .3747 Mdot
.906 .37506 Mdot
.906 .37567 Mdot
.906 .37579 Mdot
.906 .37583 Mdot
.906 .37593 Mdot
.906 .37598 Mdot
.906 .37619 Mdot
.906 .37671 Mdot
.906 .37742 Mdot
.906 .37783 Mdot
.906 .37788 Mdot
.906 .37907 Mdot
.906 .37933 Mdot
.906 .37976 Mdot
.906 .37989 Mdot
.906 .38084 Mdot
.906 .38099 Mdot
.906 .38122 Mdot
.906 .38257 Mdot
.906 .38304 Mdot
.906 .38363 Mdot
.906 .38372 Mdot
.906 .3841 Mdot
.906 .38424 Mdot
.906 .38555 Mdot
.906 .38586 Mdot
.906 .38619 Mdot
.906 .38659 Mdot
.906 .38677 Mdot
.906 .38678 Mdot
.906 .38706 Mdot
.906 .38795 Mdot
.906 .38844 Mdot
.906 .38908 Mdot
.906 .3891 Mdot
.906 .38956 Mdot
.906 .38968 Mdot
.906 .39113 Mdot
.906 .39145 Mdot
.906 .39203 Mdot
.906 .39241 Mdot
.906 .39241 Mdot
.906 .39249 Mdot
.906 .39277 Mdot
.906 .39292 Mdot
.906 .39312 Mdot
.906 .39373 Mdot
.906 .39383 Mdot
.906 .39415 Mdot
.906 .39434 Mdot
.906 .39453 Mdot
.906 .39466 Mdot
.906 .39481 Mdot
.906 .39486 Mdot
.906 .39487 Mdot
.906 .39489 Mdot
.906 .39491 Mdot
.906 .395 Mdot
.906 .39517 Mdot
.906 .39528 Mdot
.906 .39551 Mdot
.906 .39585 Mdot
.906 .39619 Mdot
.906 .39624 Mdot
.906 .39644 Mdot
.906 .39677 Mdot
.906 .39694 Mdot
.906 .39774 Mdot
.906 .39806 Mdot
.906 .39843 Mdot
.906 .3987 Mdot
.906 .39919 Mdot
.906 .39934 Mdot
.906 .39935 Mdot
.906 .39985 Mdot
.906 .40002 Mdot
.906 .40082 Mdot
.906 .40109 Mdot
.906 .40141 Mdot
.906 .40167 Mdot
.906 .40315 Mdot
.906 .4036 Mdot
.906 .40426 Mdot
.906 .40428 Mdot
.906 .40451 Mdot
.906 .4049 Mdot
.906 .4053 Mdot
.906 .40533 Mdot
.906 .40539 Mdot
.906 .40547 Mdot
.906 .40654 Mdot
.906 .40742 Mdot
.906 .40773 Mdot
.906 .4082 Mdot
.906 .40821 Mdot
.906 .4088 Mdot
.906 .40905 Mdot
.906 .40954 Mdot
.906 .40956 Mdot
.906 .40957 Mdot
.906 .40981 Mdot
.906 .40989 Mdot
.906 .41062 Mdot
.906 .41075 Mdot
.906 .41121 Mdot
.906 .41127 Mdot
.906 .41163 Mdot
.906 .41178 Mdot
.906 .41182 Mdot
.906 .41322 Mdot
.906 .41411 Mdot
.906 .41414 Mdot
.906 .4144 Mdot
.906 .41508 Mdot
.906 .41526 Mdot
.906 .41574 Mdot
.906 .41632 Mdot
.906 .41647 Mdot
.906 .41717 Mdot
.906 .41717 Mdot
.906 .41787 Mdot
.906 .41911 Mdot
.906 .41962 Mdot
.906 .42004 Mdot
.906 .42016 Mdot
.906 .4203 Mdot
.906 .42157 Mdot
.906 .42194 Mdot
.906 .42204 Mdot
.906 .42227 Mdot
.906 .4227 Mdot
.906 .4229 Mdot
.906 .42305 Mdot
.906 .42324 Mdot
.906 .42351 Mdot
.906 .42354 Mdot
.906 .42374 Mdot
.906 .42568 Mdot
.906 .42576 Mdot
.906 .42642 Mdot
.906 .4265 Mdot
.906 .42675 Mdot
.906 .42779 Mdot
.906 .42868 Mdot
.906 .42874 Mdot
.906 .4289 Mdot
.906 .42912 Mdot
.906 .42921 Mdot
.906 .42938 Mdot
.906 .42943 Mdot
.906 .42946 Mdot
.906 .42967 Mdot
.906 .43079 Mdot
.906 .431 Mdot
.906 .43105 Mdot
.906 .43127 Mdot
.906 .43144 Mdot
.906 .43144 Mdot
.906 .43144 Mdot
.906 .43231 Mdot
.906 .43317 Mdot
.906 .43377 Mdot
.906 .43426 Mdot
.906 .43426 Mdot
.906 .43436 Mdot
.906 .43519 Mdot
.906 .43548 Mdot
.906 .43548 Mdot
.906 .43579 Mdot
.906 .43607 Mdot
.906 .43611 Mdot
.906 .43634 Mdot
.906 .43635 Mdot
.906 .43657 Mdot
.906 .43682 Mdot
.906 .43708 Mdot
.906 .43723 Mdot
.906 .43833 Mdot
.906 .43837 Mdot
.906 .43847 Mdot
.906 .43855 Mdot
.906 .43866 Mdot
.906 .43883 Mdot
.906 .4393 Mdot
.906 .44035 Mdot
.906 .4406 Mdot
.906 .4414 Mdot
.906 .44165 Mdot
.906 .44202 Mdot
.906 .44227 Mdot
.906 .44291 Mdot
.906 .44301 Mdot
.906 .44308 Mdot
.906 .44313 Mdot
.906 .44328 Mdot
.906 .4435 Mdot
.906 .44374 Mdot
.906 .44391 Mdot
.906 .44418 Mdot
.906 .44453 Mdot
.906 .44488 Mdot
.906 .44589 Mdot
.906 .44652 Mdot
.906 .44658 Mdot
.906 .447 Mdot
.906 .44828 Mdot
.906 .44849 Mdot
.906 .44852 Mdot
.906 .4487 Mdot
.906 .44889 Mdot
.906 .44891 Mdot
.906 .44911 Mdot
.906 .44929 Mdot
.906 .44957 Mdot
.906 .44974 Mdot
.906 .44977 Mdot
.906 .44989 Mdot
.906 .45038 Mdot
.906 .45046 Mdot
.906 .45049 Mdot
.906 .45168 Mdot
.906 .45267 Mdot
.906 .45269 Mdot
.906 .45303 Mdot
.906 .45325 Mdot
.906 .45448 Mdot
.906 .45511 Mdot
.906 .45547 Mdot
.906 .45565 Mdot
.906 .45694 Mdot
.906 .45741 Mdot
.906 .45761 Mdot
.906 .45785 Mdot
.906 .45803 Mdot
.906 .45812 Mdot
.906 .45824 Mdot
.906 .45824 Mdot
.906 .45827 Mdot
.906 .45899 Mdot
.906 .45972 Mdot
.906 .46123 Mdot
.906 .46124 Mdot
.906 .46162 Mdot
.906 .46181 Mdot
.906 .46318 Mdot
.906 .46322 Mdot
.906 .46339 Mdot
.906 .46361 Mdot
.906 .46363 Mdot
.906 .46527 Mdot
.906 .46579 Mdot
.906 .46602 Mdot
.906 .46686 Mdot
.906 .46723 Mdot
.906 .46808 Mdot
.906 .46809 Mdot
.906 .46868 Mdot
.906 .46959 Mdot
.906 .46971 Mdot
.906 .46978 Mdot
.906 .46999 Mdot
.906 .47038 Mdot
.906 .47074 Mdot
.906 .47232 Mdot
.906 .47244 Mdot
.906 .47366 Mdot
.906 .47426 Mdot
.906 .47446 Mdot
.906 .47536 Mdot
.906 .47566 Mdot
.906 .47612 Mdot
.906 .47653 Mdot
.906 .47749 Mdot
.906 .47776 Mdot
.906 .47776 Mdot
.906 .47781 Mdot
.906 .47788 Mdot
.906 .47789 Mdot
.906 .47837 Mdot
.906 .47853 Mdot
.906 .4786 Mdot
.906 .47918 Mdot
.906 .47929 Mdot
.906 .48016 Mdot
.906 .48025 Mdot
.906 .48065 Mdot
.906 .48076 Mdot
.906 .48119 Mdot
.906 .48151 Mdot
.906 .48189 Mdot
.906 .48254 Mdot
.906 .48373 Mdot
.906 .48379 Mdot
.906 .48406 Mdot
.906 .48442 Mdot
.906 .48465 Mdot
.906 .48483 Mdot
.906 .48483 Mdot
.906 .48567 Mdot
.906 .48572 Mdot
.906 .48584 Mdot
.906 .48624 Mdot
.906 .4869 Mdot
.906 .48708 Mdot
.906 .48738 Mdot
.906 .48802 Mdot
.906 .48842 Mdot
.906 .4889 Mdot
.906 .489 Mdot
.906 .48921 Mdot
.906 .48964 Mdot
.906 .49066 Mdot
.906 .49154 Mdot
.906 .49305 Mdot
.906 .4935 Mdot
.906 .49363 Mdot
.906 .49471 Mdot
.906 .49493 Mdot
.906 .49543 Mdot
.906 .49551 Mdot
.906 .49551 Mdot
.906 .49553 Mdot
.906 .49577 Mdot
.906 .49582 Mdot
.906 .4959 Mdot
.906 .49601 Mdot
.906 .4962 Mdot
.906 .49628 Mdot
.906 .49682 Mdot
.906 .49703 Mdot
.906 .49757 Mdot
.906 .49809 Mdot
.906 .49812 Mdot
.906 .49824 Mdot
.906 .49844 Mdot
.906 .49861 Mdot
.906 .49871 Mdot
.906 .49954 Mdot
.906 .49979 Mdot
.906 .50011 Mdot
.906 .50099 Mdot
.906 .50247 Mdot
.906 .50295 Mdot
.906 .50323 Mdot
.906 .50401 Mdot
.906 .50439 Mdot
.906 .50462 Mdot
.906 .50581 Mdot
.906 .50585 Mdot
.906 .50606 Mdot
.906 .50625 Mdot
.906 .50658 Mdot
.906 .50698 Mdot
.906 .5073 Mdot
.906 .50761 Mdot
.906 .50774 Mdot
.906 .50786 Mdot
.906 .50817 Mdot
.906 .50834 Mdot
.906 .50843 Mdot
.906 .50911 Mdot
.906 .50955 Mdot
.906 .51057 Mdot
.906 .51059 Mdot
.906 .51111 Mdot
.906 .51189 Mdot
.906 .51218 Mdot
.906 .51263 Mdot
.906 .51279 Mdot
.906 .51281 Mdot
.906 .51347 Mdot
.906 .51365 Mdot
.906 .51373 Mdot
.906 .51381 Mdot
.906 .51436 Mdot
.906 .51482 Mdot
.906 .51492 Mdot
.906 .51492 Mdot
.906 .51492 Mdot
.906 .51518 Mdot
.906 .51707 Mdot
.906 .51776 Mdot
.906 .51779 Mdot
.906 .52062 Mdot
.906 .52096 Mdot
.906 .52106 Mdot
.906 .52133 Mdot
.906 .52257 Mdot
.906 .52294 Mdot
.906 .52334 Mdot
.906 .52343 Mdot
.906 .52381 Mdot
.906 .52396 Mdot
.906 .524 Mdot
.906 .52418 Mdot
.906 .5242 Mdot
.906 .52453 Mdot
.906 .52492 Mdot
.906 .52549 Mdot
.906 .52615 Mdot
.906 .52622 Mdot
.906 .52685 Mdot
.906 .52705 Mdot
.906 .52725 Mdot
.906 .52744 Mdot
.906 .52754 Mdot
.906 .52819 Mdot
.906 .5282 Mdot
.906 .52822 Mdot
.906 .52922 Mdot
.906 .53012 Mdot
.906 .53027 Mdot
.906 .531 Mdot
.906 .53106 Mdot
.906 .53166 Mdot
.906 .5317 Mdot
.906 .53177 Mdot
.906 .5318 Mdot
.906 .53243 Mdot
.906 .53261 Mdot
.906 .53344 Mdot
.906 .53345 Mdot
.906 .53381 Mdot
.906 .53395 Mdot
.906 .534 Mdot
.906 .53593 Mdot
.906 .53607 Mdot
.906 .5361 Mdot
.906 .53703 Mdot
.906 .53715 Mdot
.906 .53755 Mdot
.906 .5377 Mdot
.906 .53802 Mdot
.906 .53827 Mdot
.906 .53862 Mdot
.906 .5392 Mdot
.906 .53939 Mdot
.906 .54055 Mdot
.906 .54073 Mdot
.906 .54111 Mdot
.906 .54167 Mdot
.906 .54217 Mdot
.906 .54257 Mdot
.906 .54265 Mdot
.906 .54311 Mdot
.906 .54314 Mdot
.906 .54392 Mdot
.906 .54417 Mdot
.906 .54462 Mdot
.906 .545 Mdot
.906 .54512 Mdot
.906 .54531 Mdot
.906 .54551 Mdot
.906 .54587 Mdot
.906 .5464 Mdot
.906 .54716 Mdot
.906 .54763 Mdot
.906 .54796 Mdot
.906 .54847 Mdot
.906 .5487 Mdot
.906 .54874 Mdot
.906 .54875 Mdot
.906 .54879 Mdot
.906 .54911 Mdot
.908 .11555 Mdot
.908 .11671 Mdot
.908 .11743 Mdot
.908 .11789 Mdot
.908 .11955 Mdot
.908 .12167 Mdot
.908 .12177 Mdot
.908 .12246 Mdot
.908 .12354 Mdot
.908 .12413 Mdot
.908 .12526 Mdot
.908 .12529 Mdot
.908 .12544 Mdot
.908 .12571 Mdot
.908 .12606 Mdot
.908 .12612 Mdot
.908 .12658 Mdot
.908 .12668 Mdot
.908 .12676 Mdot
.908 .1275 Mdot
.908 .12823 Mdot
.908 .12846 Mdot
.908 .12887 Mdot
.908 .1294 Mdot
.908 .12952 Mdot
.908 .12977 Mdot
.908 .12993 Mdot
.908 .13099 Mdot
.908 .13118 Mdot
.908 .13279 Mdot
.908 .13294 Mdot
.908 .13614 Mdot
.908 .13614 Mdot
.908 .13672 Mdot
.908 .13846 Mdot
.908 .13985 Mdot
.908 .14252 Mdot
.908 .1427 Mdot
.908 .14287 Mdot
.908 .14383 Mdot
.908 .14412 Mdot
.908 .14503 Mdot
.908 .14563 Mdot
.908 .14584 Mdot
.908 .14597 Mdot
.908 .14608 Mdot
.908 .14734 Mdot
.908 .14779 Mdot
.908 .14877 Mdot
.908 .14937 Mdot
.908 .14959 Mdot
.908 .15087 Mdot
.908 .15103 Mdot
.908 .1511 Mdot
.908 .15199 Mdot
.908 .15327 Mdot
.908 .15517 Mdot
.908 .15544 Mdot
.908 .15557 Mdot
.908 .1556 Mdot
.908 .15795 Mdot
.908 .15834 Mdot
.908 .1585 Mdot
.908 .15879 Mdot
.908 .15918 Mdot
.908 .15948 Mdot
.908 .16039 Mdot
.908 .16045 Mdot
.908 .16213 Mdot
.908 .16288 Mdot
.908 .16307 Mdot
.908 .16361 Mdot
.908 .1649 Mdot
.908 .16512 Mdot
.908 .16594 Mdot
.908 .16695 Mdot
.908 .17008 Mdot
.908 .17009 Mdot
.908 .17011 Mdot
.908 .17016 Mdot
.908 .17122 Mdot
.908 .17221 Mdot
.908 .17437 Mdot
.908 .17455 Mdot
.908 .17575 Mdot
.908 .17772 Mdot
.908 .17896 Mdot
.908 .17923 Mdot
.908 .1794 Mdot
.908 .18011 Mdot
.908 .18014 Mdot
.908 .18041 Mdot
.908 .18106 Mdot
.908 .18159 Mdot
.908 .1823 Mdot
.908 .18259 Mdot
.908 .18531 Mdot
.908 .18594 Mdot
.908 .18664 Mdot
.908 .18664 Mdot
.908 .18682 Mdot
.908 .18738 Mdot
.908 .1921 Mdot
.908 .19339 Mdot
.908 .19436 Mdot
.908 .19446 Mdot
.908 .19459 Mdot
.908 .19612 Mdot
.908 .19714 Mdot
.908 .19763 Mdot
.908 .19783 Mdot
.908 .1981 Mdot
.908 .19816 Mdot
.908 .19876 Mdot
.908 .19942 Mdot
.908 .19994 Mdot
.908 .20053 Mdot
.908 .2008 Mdot
.908 .20125 Mdot
.908 .20147 Mdot
.908 .20208 Mdot
.908 .20225 Mdot
.908 .20281 Mdot
.908 .20296 Mdot
.908 .20323 Mdot
.908 .20509 Mdot
.908 .2057 Mdot
.908 .20596 Mdot
.908 .20766 Mdot
.908 .20799 Mdot
.908 .20879 Mdot
.908 .20895 Mdot
.908 .20912 Mdot
.908 .20923 Mdot
.908 .20927 Mdot
.908 .21038 Mdot
.908 .21055 Mdot
.908 .21233 Mdot
.908 .21246 Mdot
.908 .21327 Mdot
.908 .2134 Mdot
.908 .21367 Mdot
.908 .21547 Mdot
.908 .21552 Mdot
.908 .2158 Mdot
.908 .21587 Mdot
.908 .21628 Mdot
.908 .21634 Mdot
.908 .21666 Mdot
.908 .21692 Mdot
.908 .21693 Mdot
.908 .21703 Mdot
.908 .21774 Mdot
.908 .21785 Mdot
.908 .21804 Mdot
.908 .21819 Mdot
.908 .21883 Mdot
.908 .21912 Mdot
.908 .21954 Mdot
.908 .22085 Mdot
.908 .2209 Mdot
.908 .22127 Mdot
.908 .22201 Mdot
.908 .22209 Mdot
.908 .22238 Mdot
.908 .22298 Mdot
.908 .22321 Mdot
.908 .22325 Mdot
.908 .22335 Mdot
.908 .22365 Mdot
.908 .22394 Mdot
.908 .22395 Mdot
.908 .22496 Mdot
.908 .22587 Mdot
.908 .22592 Mdot
.908 .22602 Mdot
.908 .22621 Mdot
.908 .2263 Mdot
.908 .2265 Mdot
.908 .22692 Mdot
.908 .22818 Mdot
.908 .22826 Mdot
.908 .2288 Mdot
.908 .22914 Mdot
.908 .2294 Mdot
.908 .22964 Mdot
.908 .23022 Mdot
.908 .23069 Mdot
.908 .23293 Mdot
.908 .23299 Mdot
.908 .23336 Mdot
.908 .2341 Mdot
.908 .23522 Mdot
.908 .23523 Mdot
.908 .23593 Mdot
.908 .23628 Mdot
.908 .23712 Mdot
.908 .23743 Mdot
.908 .23847 Mdot
.908 .23872 Mdot
.908 .23914 Mdot
.908 .23944 Mdot
.908 .23957 Mdot
.908 .24013 Mdot
.908 .24196 Mdot
.908 .24203 Mdot
.908 .24234 Mdot
.908 .24252 Mdot
.908 .24267 Mdot
.908 .24332 Mdot
.908 .24491 Mdot
.908 .24492 Mdot
.908 .2452 Mdot
.908 .24581 Mdot
.908 .24595 Mdot
.908 .24599 Mdot
.908 .24646 Mdot
.908 .24666 Mdot
.908 .2468 Mdot
.908 .24713 Mdot
.908 .24745 Mdot
.908 .24876 Mdot
.908 .2492 Mdot
.908 .24971 Mdot
.908 .24976 Mdot
.908 .25035 Mdot
.908 .25098 Mdot
.908 .25124 Mdot
.908 .25131 Mdot
.908 .25132 Mdot
.908 .25136 Mdot
.908 .25153 Mdot
.908 .25162 Mdot
.908 .25245 Mdot
.908 .25284 Mdot
.908 .25306 Mdot
.908 .25307 Mdot
.908 .25311 Mdot
.908 .25327 Mdot
.908 .25331 Mdot
.908 .25361 Mdot
.908 .25425 Mdot
.908 .25488 Mdot
.908 .2549 Mdot
.908 .25556 Mdot
.908 .25622 Mdot
.908 .25629 Mdot
.908 .25637 Mdot
.908 .25761 Mdot
.908 .25816 Mdot
.908 .25882 Mdot
.908 .25892 Mdot
.908 .25926 Mdot
.908 .25957 Mdot
.908 .25964 Mdot
.908 .26198 Mdot
.908 .26224 Mdot
.908 .26227 Mdot
.908 .26238 Mdot
.908 .2626 Mdot
.908 .26352 Mdot
.908 .26359 Mdot
.908 .26383 Mdot
.908 .26395 Mdot
.908 .26401 Mdot
.908 .26404 Mdot
.908 .26414 Mdot
.908 .26453 Mdot
.908 .26534 Mdot
.908 .26557 Mdot
.908 .26633 Mdot
.908 .26695 Mdot
.908 .26715 Mdot
.908 .26784 Mdot
.908 .26784 Mdot
.908 .26861 Mdot
.908 .26931 Mdot
.908 .26945 Mdot
.908 .26947 Mdot
.908 .26969 Mdot
.908 .26978 Mdot
.908 .26978 Mdot
.908 .27026 Mdot
.908 .27051 Mdot
.908 .27056 Mdot
.908 .27066 Mdot
.908 .27306 Mdot
.908 .27329 Mdot
.908 .27483 Mdot
.908 .27537 Mdot
.908 .27543 Mdot
.908 .27551 Mdot
.908 .27554 Mdot
.908 .27583 Mdot
.908 .27614 Mdot
.908 .27635 Mdot
.908 .27706 Mdot
.908 .2776 Mdot
.908 .27835 Mdot
.908 .27859 Mdot
.908 .27926 Mdot
.908 .27938 Mdot
.908 .27962 Mdot
.908 .28059 Mdot
.908 .28074 Mdot
.908 .28108 Mdot
.908 .28242 Mdot
.908 .28324 Mdot
.908 .28378 Mdot
.908 .28412 Mdot
.908 .28427 Mdot
.908 .28504 Mdot
.908 .28511 Mdot
.908 .2858 Mdot
.908 .28745 Mdot
.908 .28766 Mdot
.908 .28786 Mdot
.908 .28868 Mdot
.908 .28914 Mdot
.908 .28934 Mdot
.908 .28942 Mdot
.908 .28965 Mdot
.908 .29117 Mdot
.908 .29183 Mdot
.908 .29398 Mdot
.908 .29404 Mdot
.908 .29443 Mdot
.908 .29578 Mdot
.908 .29598 Mdot
.908 .29615 Mdot
.908 .29686 Mdot
.908 .29687 Mdot
.908 .29691 Mdot
.908 .29699 Mdot
.908 .29796 Mdot
.908 .29825 Mdot
.908 .2983 Mdot
.908 .29894 Mdot
.908 .29923 Mdot
.908 .29937 Mdot
.908 .29975 Mdot
.908 .29989 Mdot
.908 .30007 Mdot
.908 .30043 Mdot
.908 .30072 Mdot
.908 .30078 Mdot
.908 .30206 Mdot
.908 .30276 Mdot
.908 .30277 Mdot
.908 .30374 Mdot
.908 .30465 Mdot
.908 .30477 Mdot
.908 .30481 Mdot
.908 .30497 Mdot
.908 .3051 Mdot
.908 .30538 Mdot
.908 .30563 Mdot
.908 .30567 Mdot
.908 .3058 Mdot
.908 .30582 Mdot
.908 .30606 Mdot
.908 .30691 Mdot
.908 .30715 Mdot
.908 .3078 Mdot
.908 .30901 Mdot
.908 .31074 Mdot
.908 .31096 Mdot
.908 .31109 Mdot
.908 .31227 Mdot
.908 .31281 Mdot
.908 .31298 Mdot
.908 .31334 Mdot
.908 .31338 Mdot
.908 .31347 Mdot
.908 .31378 Mdot
.908 .31423 Mdot
.908 .3147 Mdot
.908 .31507 Mdot
.908 .31512 Mdot
.908 .31561 Mdot
.908 .3168 Mdot
.908 .31775 Mdot
.908 .31856 Mdot
.908 .31905 Mdot
.908 .31957 Mdot
.908 .31961 Mdot
.908 .32064 Mdot
.908 .32071 Mdot
.908 .32116 Mdot
.908 .32182 Mdot
.908 .32336 Mdot
.908 .3235 Mdot
.908 .3237 Mdot
.908 .32398 Mdot
.908 .324 Mdot
.908 .32451 Mdot
.908 .32474 Mdot
.908 .32479 Mdot
.908 .32566 Mdot
.908 .32597 Mdot
.908 .32692 Mdot
.908 .32692 Mdot
.908 .32693 Mdot
.908 .32694 Mdot
.908 .32727 Mdot
.908 .32827 Mdot
.908 .32864 Mdot
.908 .32924 Mdot
.908 .32961 Mdot
.908 .32969 Mdot
.908 .32996 Mdot
.908 .33041 Mdot
.908 .33062 Mdot
.908 .33194 Mdot
.908 .332 Mdot
.908 .33217 Mdot
.908 .33399 Mdot
.908 .33431 Mdot
.908 .33482 Mdot
.908 .33541 Mdot
.908 .33544 Mdot
.908 .33582 Mdot
.908 .33623 Mdot
.908 .33644 Mdot
.908 .33667 Mdot
.908 .33684 Mdot
.908 .33689 Mdot
.908 .33772 Mdot
.908 .33841 Mdot
.908 .33879 Mdot
.908 .33919 Mdot
.908 .34095 Mdot
.908 .34113 Mdot
.908 .34137 Mdot
.908 .3417 Mdot
.908 .34269 Mdot
.908 .34278 Mdot
.908 .34307 Mdot
.908 .34415 Mdot
.908 .34454 Mdot
.908 .34473 Mdot
.908 .34498 Mdot
.908 .34515 Mdot
.908 .3453 Mdot
.908 .34598 Mdot
.908 .346 Mdot
.908 .34689 Mdot
.908 .34725 Mdot
.908 .34734 Mdot
.908 .34766 Mdot
.908 .34773 Mdot
.908 .34786 Mdot
.908 .34799 Mdot
.908 .34816 Mdot
.908 .34893 Mdot
.908 .34988 Mdot
.908 .35014 Mdot
.908 .35108 Mdot
.908 .35126 Mdot
.908 .35145 Mdot
.908 .35153 Mdot
.908 .35162 Mdot
.908 .35164 Mdot
.908 .35208 Mdot
.908 .3521 Mdot
.908 .35216 Mdot
.908 .35263 Mdot
.908 .35264 Mdot
.908 .35304 Mdot
.908 .35346 Mdot
.908 .35386 Mdot
.908 .35497 Mdot
.908 .35527 Mdot
.908 .35541 Mdot
.908 .35629 Mdot
.908 .35635 Mdot
.908 .35656 Mdot
.908 .35656 Mdot
.908 .35705 Mdot
.908 .35706 Mdot
.908 .35815 Mdot
.908 .35821 Mdot
.908 .35884 Mdot
.908 .35886 Mdot
.908 .35889 Mdot
.908 .35908 Mdot
.908 .36043 Mdot
.908 .36154 Mdot
.908 .36201 Mdot
.908 .36257 Mdot
.908 .36288 Mdot
.908 .36463 Mdot
.908 .36503 Mdot
.908 .3651 Mdot
.908 .3657 Mdot
.908 .3658 Mdot
.908 .36624 Mdot
.908 .36645 Mdot
.908 .36715 Mdot
.908 .36715 Mdot
.908 .36745 Mdot
.908 .36776 Mdot
.908 .36795 Mdot
.908 .36802 Mdot
.908 .36868 Mdot
.908 .37004 Mdot
.908 .37036 Mdot
.908 .37037 Mdot
.908 .37077 Mdot
.908 .37257 Mdot
.908 .3735 Mdot
.908 .37359 Mdot
.908 .37382 Mdot
.908 .37383 Mdot
.908 .375 Mdot
.908 .37518 Mdot
.908 .37529 Mdot
.908 .37532 Mdot
.908 .3754 Mdot
.908 .37554 Mdot
.908 .3756 Mdot
.908 .376 Mdot
.908 .37602 Mdot
.908 .37662 Mdot
.908 .37706 Mdot
.908 .37718 Mdot
.908 .3773 Mdot
.908 .3775 Mdot
.908 .37775 Mdot
.908 .37796 Mdot
.908 .37808 Mdot
.908 .37896 Mdot
.908 .37929 Mdot
.908 .37938 Mdot
.908 .37988 Mdot
.908 .38001 Mdot
.908 .38005 Mdot
.908 .38077 Mdot
.908 .38087 Mdot
.908 .38144 Mdot
.908 .38186 Mdot
.908 .38192 Mdot
.908 .38194 Mdot
.908 .38197 Mdot
.908 .38211 Mdot
.908 .38211 Mdot
.908 .3824 Mdot
.908 .3834 Mdot
.908 .38361 Mdot
.908 .38395 Mdot
.908 .38397 Mdot
.908 .38416 Mdot
.908 .38423 Mdot
.908 .38538 Mdot
.908 .38591 Mdot
.908 .38627 Mdot
.908 .38668 Mdot
.908 .38714 Mdot
.908 .38765 Mdot
.908 .38777 Mdot
.908 .38832 Mdot
.908 .3886 Mdot
.908 .38906 Mdot
.908 .38911 Mdot
.908 .38915 Mdot
.908 .38924 Mdot
.908 .38936 Mdot
.908 .38955 Mdot
.908 .38968 Mdot
.908 .38972 Mdot
.908 .38981 Mdot
.908 .38989 Mdot
.908 .38996 Mdot
.908 .39117 Mdot
.908 .3913 Mdot
.908 .39178 Mdot
.908 .39183 Mdot
.908 .39274 Mdot
.908 .39293 Mdot
.908 .39334 Mdot
.908 .39341 Mdot
.908 .39351 Mdot
.908 .39357 Mdot
.908 .39359 Mdot
.908 .39414 Mdot
.908 .39467 Mdot
.908 .39469 Mdot
.908 .39606 Mdot
.908 .39609 Mdot
.908 .39652 Mdot
.908 .39705 Mdot
.908 .39805 Mdot
.908 .39808 Mdot
.908 .39818 Mdot
.908 .3982 Mdot
.908 .39827 Mdot
.908 .39838 Mdot
.908 .39844 Mdot
.908 .39851 Mdot
.908 .39879 Mdot
.908 .39895 Mdot
.908 .39925 Mdot
.908 .39932 Mdot
.908 .3996 Mdot
.908 .40008 Mdot
.908 .40124 Mdot
.908 .40135 Mdot
.908 .40221 Mdot
.908 .40237 Mdot
.908 .40244 Mdot
.908 .40251 Mdot
.908 .4035 Mdot
.908 .4041 Mdot
.908 .40459 Mdot
.908 .40465 Mdot
.908 .40477 Mdot
.908 .40491 Mdot
.908 .40502 Mdot
.908 .40509 Mdot
.908 .40515 Mdot
.908 .40539 Mdot
.908 .40573 Mdot
.908 .40595 Mdot
.908 .40606 Mdot
.908 .40611 Mdot
.908 .40618 Mdot
.908 .40628 Mdot
.908 .40693 Mdot
.908 .40711 Mdot
.908 .40762 Mdot
.908 .40861 Mdot
.908 .40883 Mdot
.908 .40976 Mdot
.908 .4106 Mdot
.908 .41099 Mdot
.908 .41111 Mdot
.908 .41135 Mdot
.908 .41177 Mdot
.908 .41199 Mdot
.908 .41296 Mdot
.908 .41313 Mdot
.908 .41505 Mdot
.908 .41515 Mdot
.908 .41517 Mdot
.908 .41518 Mdot
.908 .41553 Mdot
.908 .41556 Mdot
.908 .41617 Mdot
.908 .41644 Mdot
.908 .41655 Mdot
.908 .41707 Mdot
.908 .41838 Mdot
.908 .4186 Mdot
.908 .41889 Mdot
.908 .4189 Mdot
.908 .41914 Mdot
.908 .41916 Mdot
.908 .41921 Mdot
.908 .41925 Mdot
.908 .41936 Mdot
.908 .42011 Mdot
.908 .42106 Mdot
.908 .42116 Mdot
.908 .42134 Mdot
.908 .42151 Mdot
.908 .42226 Mdot
.908 .42264 Mdot
.908 .42272 Mdot
.908 .42281 Mdot
.908 .42295 Mdot
.908 .42306 Mdot
.908 .42386 Mdot
.908 .42403 Mdot
.908 .42408 Mdot
.908 .42462 Mdot
.908 .42622 Mdot
.908 .42643 Mdot
.908 .42681 Mdot
.908 .42727 Mdot
.908 .42739 Mdot
.908 .42752 Mdot
.908 .42763 Mdot
.908 .42786 Mdot
.908 .42807 Mdot
.908 .42808 Mdot
.908 .42841 Mdot
.908 .42869 Mdot
.908 .42887 Mdot
.908 .42987 Mdot
.908 .42996 Mdot
.908 .42999 Mdot
.908 .43072 Mdot
.908 .43084 Mdot
.908 .43108 Mdot
.908 .43123 Mdot
.908 .43128 Mdot
.908 .43148 Mdot
.908 .43181 Mdot
.908 .43275 Mdot
.908 .43276 Mdot
.908 .43328 Mdot
.908 .43393 Mdot
.908 .43396 Mdot
.908 .43437 Mdot
.908 .43438 Mdot
.908 .43453 Mdot
.908 .43464 Mdot
.908 .43472 Mdot
.908 .43557 Mdot
.908 .43593 Mdot
.908 .43618 Mdot
.908 .43622 Mdot
.908 .43679 Mdot
.908 .43736 Mdot
.908 .43949 Mdot
.908 .43975 Mdot
.908 .44021 Mdot
.908 .44024 Mdot
.908 .44053 Mdot
.908 .44083 Mdot
.908 .44147 Mdot
.908 .44155 Mdot
.908 .44262 Mdot
.908 .44329 Mdot
.908 .44378 Mdot
.908 .44424 Mdot
.908 .44438 Mdot
.908 .44439 Mdot
.908 .44446 Mdot
.908 .44448 Mdot
.908 .44462 Mdot
.908 .44478 Mdot
.908 .44493 Mdot
.908 .44496 Mdot
.908 .44552 Mdot
.908 .44606 Mdot
.908 .44606 Mdot
.908 .44645 Mdot
.908 .44716 Mdot
.908 .44734 Mdot
.908 .44754 Mdot
.908 .44764 Mdot
.908 .44772 Mdot
.908 .44793 Mdot
.908 .448 Mdot
.908 .44852 Mdot
.908 .44855 Mdot
.908 .44871 Mdot
.908 .4497 Mdot
.908 .44979 Mdot
.908 .44991 Mdot
.908 .45065 Mdot
.908 .45086 Mdot
.908 .4509 Mdot
.908 .45208 Mdot
.908 .45328 Mdot
.908 .45341 Mdot
.908 .45356 Mdot
.908 .45382 Mdot
.908 .45438 Mdot
.908 .4554 Mdot
.908 .45582 Mdot
.908 .45625 Mdot
.908 .45681 Mdot
.908 .458 Mdot
.908 .45819 Mdot
.908 .45827 Mdot
.908 .4588 Mdot
.908 .45937 Mdot
.908 .4595 Mdot
.908 .46072 Mdot
.908 .46107 Mdot
.908 .46111 Mdot
.908 .46115 Mdot
.908 .46229 Mdot
.908 .46242 Mdot
.908 .46374 Mdot
.908 .46422 Mdot
.908 .46427 Mdot
.908 .4644 Mdot
.908 .4644 Mdot
.908 .46448 Mdot
.908 .46487 Mdot
.908 .46529 Mdot
.908 .46529 Mdot
.908 .46567 Mdot
.908 .46578 Mdot
.908 .46654 Mdot
.908 .46667 Mdot
.908 .46712 Mdot
.908 .46733 Mdot
.908 .46738 Mdot
.908 .46743 Mdot
.908 .4675 Mdot
.908 .46763 Mdot
.908 .46767 Mdot
.908 .46818 Mdot
.908 .46838 Mdot
.908 .46985 Mdot
.908 .4702 Mdot
.908 .47026 Mdot
.908 .47092 Mdot
.908 .47165 Mdot
.908 .47169 Mdot
.908 .47241 Mdot
.908 .47243 Mdot
.908 .47278 Mdot
.908 .47313 Mdot
.908 .47329 Mdot
.908 .4734 Mdot
.908 .47343 Mdot
.908 .47422 Mdot
.908 .47427 Mdot
.908 .47439 Mdot
.908 .47439 Mdot
.908 .47443 Mdot
.908 .47457 Mdot
.908 .47492 Mdot
.908 .47525 Mdot
.908 .4758 Mdot
.908 .47695 Mdot
.908 .47706 Mdot
.908 .47732 Mdot
.908 .47734 Mdot
.908 .47742 Mdot
.908 .47776 Mdot
.908 .47792 Mdot
.908 .47792 Mdot
.908 .47879 Mdot
.908 .47915 Mdot
.908 .47923 Mdot
.908 .47933 Mdot
.908 .4795 Mdot
.908 .48055 Mdot
.908 .48086 Mdot
.908 .4811 Mdot
.908 .48133 Mdot
.908 .48146 Mdot
.908 .48204 Mdot
.908 .48221 Mdot
.908 .48287 Mdot
.908 .48387 Mdot
.908 .48428 Mdot
.908 .48448 Mdot
.908 .48452 Mdot
.908 .48575 Mdot
.908 .48601 Mdot
.908 .48633 Mdot
.908 .48679 Mdot
.908 .48709 Mdot
.908 .48713 Mdot
.908 .48782 Mdot
.908 .48806 Mdot
.908 .48817 Mdot
.908 .48832 Mdot
.908 .48837 Mdot
.908 .48891 Mdot
.908 .48947 Mdot
.908 .48979 Mdot
.908 .48985 Mdot
.908 .49033 Mdot
.908 .49049 Mdot
.908 .49114 Mdot
.908 .49212 Mdot
.908 .49228 Mdot
.908 .49288 Mdot
.908 .49333 Mdot
.908 .49348 Mdot
.908 .49365 Mdot
.908 .49391 Mdot
.908 .49512 Mdot
.908 .49534 Mdot
.908 .49579 Mdot
.908 .49684 Mdot
.908 .49755 Mdot
.908 .49757 Mdot
.908 .49781 Mdot
.908 .49825 Mdot
.908 .49843 Mdot
.908 .49951 Mdot
.908 .50087 Mdot
.908 .50102 Mdot
.908 .5011 Mdot
.908 .50141 Mdot
.908 .50184 Mdot
.908 .50221 Mdot
.908 .50236 Mdot
.908 .50297 Mdot
.908 .50333 Mdot
.908 .50366 Mdot
.908 .5037 Mdot
.908 .50395 Mdot
.908 .50422 Mdot
.908 .50478 Mdot
.908 .50563 Mdot
.908 .5057 Mdot
.908 .50576 Mdot
.908 .50629 Mdot
.908 .507 Mdot
.908 .5096 Mdot
.908 .5099 Mdot
.908 .51001 Mdot
.908 .51001 Mdot
.908 .51039 Mdot
.908 .51074 Mdot
.908 .51224 Mdot
.908 .5124 Mdot
.908 .51279 Mdot
.908 .51308 Mdot
.908 .51344 Mdot
.908 .51359 Mdot
.908 .5136 Mdot
.908 .51399 Mdot
.908 .51409 Mdot
.908 .51423 Mdot
.908 .51492 Mdot
.908 .516 Mdot
.908 .51666 Mdot
.908 .51676 Mdot
.908 .51795 Mdot
.908 .51849 Mdot
.908 .51908 Mdot
.908 .51911 Mdot
.908 .51912 Mdot
.908 .51912 Mdot
.908 .52085 Mdot
.908 .5214 Mdot
.908 .52185 Mdot
.908 .52198 Mdot
.908 .52269 Mdot
.908 .52299 Mdot
.908 .52309 Mdot
.908 .5235 Mdot
.908 .52443 Mdot
.908 .52446 Mdot
.908 .52496 Mdot
.908 .52513 Mdot
.908 .52534 Mdot
.908 .5255 Mdot
.908 .52559 Mdot
.908 .5258 Mdot
.908 .5271 Mdot
.908 .52711 Mdot
.908 .52719 Mdot
.908 .52733 Mdot
.908 .52838 Mdot
.908 .52909 Mdot
.908 .52958 Mdot
.908 .52961 Mdot
.908 .5297 Mdot
.908 .53041 Mdot
.908 .53053 Mdot
.908 .53086 Mdot
.908 .5314 Mdot
.908 .53165 Mdot
.908 .53234 Mdot
.908 .5324 Mdot
.908 .53247 Mdot
.908 .53259 Mdot
.908 .53292 Mdot
.908 .53342 Mdot
.908 .53358 Mdot
.908 .53411 Mdot
.908 .5342 Mdot
.908 .5343 Mdot
.908 .53577 Mdot
.908 .53654 Mdot
.908 .53749 Mdot
.908 .53781 Mdot
.908 .53781 Mdot
.908 .53958 Mdot
.908 .53966 Mdot
.908 .54055 Mdot
.908 .54065 Mdot
.908 .54123 Mdot
.908 .54132 Mdot
.908 .54146 Mdot
.908 .54153 Mdot
.908 .54182 Mdot
.908 .54205 Mdot
.908 .54217 Mdot
.908 .54257 Mdot
.908 .54298 Mdot
.908 .54303 Mdot
.908 .54308 Mdot
.908 .54333 Mdot
.908 .54336 Mdot
.908 .54356 Mdot
.908 .5437 Mdot
.908 .54379 Mdot
.908 .5438 Mdot
.908 .54443 Mdot
.908 .54475 Mdot
.908 .54535 Mdot
.908 .54573 Mdot
.908 .54578 Mdot
.908 .54695 Mdot
.908 .54786 Mdot
.908 .54812 Mdot
.908 .54851 Mdot
.908 .54915 Mdot
.91 .11348 Mdot
.91 .11512 Mdot
.91 .11709 Mdot
.91 .11751 Mdot
.91 .11759 Mdot
.91 .11841 Mdot
.91 .12075 Mdot
.91 .12202 Mdot
.91 .12315 Mdot
.91 .12337 Mdot
.91 .12401 Mdot
.91 .12519 Mdot
.91 .12769 Mdot
.91 .12875 Mdot
.91 .12969 Mdot
.91 .12971 Mdot
.91 .1307 Mdot
.91 .13146 Mdot
.91 .13229 Mdot
.91 .13273 Mdot
.91 .13382 Mdot
.91 .13424 Mdot
.91 .13501 Mdot
.91 .13733 Mdot
.91 .13862 Mdot
.91 .14005 Mdot
.91 .14125 Mdot
.91 .14127 Mdot
.91 .14203 Mdot
.91 .14408 Mdot
.91 .14443 Mdot
.91 .14661 Mdot
.91 .1481 Mdot
.91 .14854 Mdot
.91 .14887 Mdot
.91 .14935 Mdot
.91 .15013 Mdot
.91 .15111 Mdot
.91 .1513 Mdot
.91 .15132 Mdot
.91 .15185 Mdot
.91 .15201 Mdot
.91 .15209 Mdot
.91 .15362 Mdot
.91 .15446 Mdot
.91 .15566 Mdot
.91 .15779 Mdot
.91 .15805 Mdot
.91 .1582 Mdot
.91 .15826 Mdot
.91 .15876 Mdot
.91 .1607 Mdot
.91 .1617 Mdot
.91 .16369 Mdot
.91 .16417 Mdot
.91 .16441 Mdot
.91 .16561 Mdot
.91 .16611 Mdot
.91 .16642 Mdot
.91 .16659 Mdot
.91 .16676 Mdot
.91 .16766 Mdot
.91 .16861 Mdot
.91 .16905 Mdot
.91 .17036 Mdot
.91 .17094 Mdot
.91 .17183 Mdot
.91 .17227 Mdot
.91 .17287 Mdot
.91 .17325 Mdot
.91 .17391 Mdot
.91 .17562 Mdot
.91 .17577 Mdot
.91 .17715 Mdot
.91 .17875 Mdot
.91 .17879 Mdot
.91 .1795 Mdot
.91 .18059 Mdot
.91 .18414 Mdot
.91 .1845 Mdot
.91 .18514 Mdot
.91 .18745 Mdot
.91 .1881 Mdot
.91 .18988 Mdot
.91 .18992 Mdot
.91 .18994 Mdot
.91 .19028 Mdot
.91 .19033 Mdot
.91 .19051 Mdot
.91 .19059 Mdot
.91 .19223 Mdot
.91 .19235 Mdot
.91 .19235 Mdot
.91 .19264 Mdot
.91 .19293 Mdot
.91 .19402 Mdot
.91 .19411 Mdot
.91 .19447 Mdot
.91 .19454 Mdot
.91 .19508 Mdot
.91 .19515 Mdot
.91 .19543 Mdot
.91 .19619 Mdot
.91 .19745 Mdot
.91 .1982 Mdot
.91 .20104 Mdot
.91 .20159 Mdot
.91 .20167 Mdot
.91 .2018 Mdot
.91 .20194 Mdot
.91 .20195 Mdot
.91 .20199 Mdot
.91 .20236 Mdot
.91 .20344 Mdot
.91 .20419 Mdot
.91 .20444 Mdot
.91 .20515 Mdot
.91 .20516 Mdot
.91 .20517 Mdot
.91 .20687 Mdot
.91 .20769 Mdot
.91 .20839 Mdot
.91 .20864 Mdot
.91 .21001 Mdot
.91 .2107 Mdot
.91 .21168 Mdot
.91 .21207 Mdot
.91 .21246 Mdot
.91 .21339 Mdot
.91 .21363 Mdot
.91 .21493 Mdot
.91 .21501 Mdot
.91 .21523 Mdot
.91 .21577 Mdot
.91 .21578 Mdot
.91 .21593 Mdot
.91 .21613 Mdot
.91 .21636 Mdot
.91 .21653 Mdot
.91 .21761 Mdot
.91 .21791 Mdot
.91 .21836 Mdot
.91 .21876 Mdot
.91 .21913 Mdot
.91 .22009 Mdot
.91 .22019 Mdot
.91 .22034 Mdot
.91 .22043 Mdot
.91 .22073 Mdot
.91 .2213 Mdot
.91 .22154 Mdot
.91 .2216 Mdot
.91 .22161 Mdot
.91 .22188 Mdot
.91 .22201 Mdot
.91 .22208 Mdot
.91 .22227 Mdot
.91 .22308 Mdot
.91 .22343 Mdot
.91 .22368 Mdot
.91 .22398 Mdot
.91 .224 Mdot
.91 .22432 Mdot
.91 .22512 Mdot
.91 .2258 Mdot
.91 .22592 Mdot
.91 .22613 Mdot
.91 .2272 Mdot
.91 .22767 Mdot
.91 .22832 Mdot
.91 .22871 Mdot
.91 .22951 Mdot
.91 .22993 Mdot
.91 .23139 Mdot
.91 .23148 Mdot
.91 .23224 Mdot
.91 .23253 Mdot
.91 .23264 Mdot
.91 .23285 Mdot
.91 .23286 Mdot
.91 .23364 Mdot
.91 .2357 Mdot
.91 .2359 Mdot
.91 .23591 Mdot
.91 .23594 Mdot
.91 .2363 Mdot
.91 .2365 Mdot
.91 .23745 Mdot
.91 .23787 Mdot
.91 .23787 Mdot
.91 .23874 Mdot
.91 .2399 Mdot
.91 .24023 Mdot
.91 .24038 Mdot
.91 .24159 Mdot
.91 .24227 Mdot
.91 .24243 Mdot
.91 .24245 Mdot
.91 .24265 Mdot
.91 .24282 Mdot
.91 .24439 Mdot
.91 .24477 Mdot
.91 .245 Mdot
.91 .24505 Mdot
.91 .24596 Mdot
.91 .2461 Mdot
.91 .24643 Mdot
.91 .24647 Mdot
.91 .24709 Mdot
.91 .24777 Mdot
.91 .24929 Mdot
.91 .25016 Mdot
.91 .25079 Mdot
.91 .25108 Mdot
.91 .25158 Mdot
.91 .25328 Mdot
.91 .25476 Mdot
.91 .25481 Mdot
.91 .25519 Mdot
.91 .25537 Mdot
.91 .25546 Mdot
.91 .25596 Mdot
.91 .25745 Mdot
.91 .25748 Mdot
.91 .25755 Mdot
.91 .25773 Mdot
.91 .25828 Mdot
.91 .25887 Mdot
.91 .25912 Mdot
.91 .25926 Mdot
.91 .25937 Mdot
.91 .25961 Mdot
.91 .25964 Mdot
.91 .25976 Mdot
.91 .26028 Mdot
.91 .26042 Mdot
.91 .26076 Mdot
.91 .26086 Mdot
.91 .26117 Mdot
.91 .26131 Mdot
.91 .26175 Mdot
.91 .2621 Mdot
.91 .26239 Mdot
.91 .26275 Mdot
.91 .26289 Mdot
.91 .26293 Mdot
.91 .26295 Mdot
.91 .263 Mdot
.91 .26328 Mdot
.91 .2633 Mdot
.91 .26333 Mdot
.91 .26362 Mdot
.91 .26395 Mdot
.91 .26399 Mdot
.91 .2641 Mdot
.91 .26429 Mdot
.91 .26459 Mdot
.91 .26474 Mdot
.91 .26494 Mdot
.91 .26504 Mdot
.91 .26509 Mdot
.91 .2655 Mdot
.91 .26604 Mdot
.91 .26619 Mdot
.91 .26622 Mdot
.91 .26627 Mdot
.91 .26639 Mdot
.91 .26685 Mdot
.91 .26751 Mdot
.91 .26805 Mdot
.91 .26891 Mdot
.91 .26902 Mdot
.91 .26906 Mdot
.91 .26942 Mdot
.91 .27017 Mdot
.91 .27124 Mdot
.91 .27163 Mdot
.91 .27197 Mdot
.91 .27209 Mdot
.91 .27311 Mdot
.91 .27346 Mdot
.91 .2739 Mdot
.91 .27458 Mdot
.91 .27505 Mdot
.91 .27511 Mdot
.91 .27535 Mdot
.91 .27559 Mdot
.91 .27586 Mdot
.91 .27597 Mdot
.91 .27641 Mdot
.91 .2765 Mdot
.91 .27677 Mdot
.91 .27687 Mdot
.91 .27716 Mdot
.91 .27727 Mdot
.91 .278 Mdot
.91 .27806 Mdot
.91 .2784 Mdot
.91 .27889 Mdot
.91 .2797 Mdot
.91 .2804 Mdot
.91 .28167 Mdot
.91 .28222 Mdot
.91 .28233 Mdot
.91 .28235 Mdot
.91 .28245 Mdot
.91 .28348 Mdot
.91 .28408 Mdot
.91 .28431 Mdot
.91 .2844 Mdot
.91 .28442 Mdot
.91 .28585 Mdot
.91 .28598 Mdot
.91 .28672 Mdot
.91 .28761 Mdot
.91 .28879 Mdot
.91 .28934 Mdot
.91 .28935 Mdot
.91 .29025 Mdot
.91 .29081 Mdot
.91 .29101 Mdot
.91 .29112 Mdot
.91 .29131 Mdot
.91 .29144 Mdot
.91 .29188 Mdot
.91 .29241 Mdot
.91 .2927 Mdot
.91 .29307 Mdot
.91 .29317 Mdot
.91 .29332 Mdot
.91 .2948 Mdot
.91 .29555 Mdot
.91 .2956 Mdot
.91 .29742 Mdot
.91 .29747 Mdot
.91 .29764 Mdot
.91 .29799 Mdot
.91 .29822 Mdot
.91 .29905 Mdot
.91 .29971 Mdot
.91 .29982 Mdot
.91 .30067 Mdot
.91 .30103 Mdot
.91 .30146 Mdot
.91 .30185 Mdot
.91 .30256 Mdot
.91 .30324 Mdot
.91 .30337 Mdot
.91 .30386 Mdot
.91 .30416 Mdot
.91 .30444 Mdot
.91 .30552 Mdot
.91 .30648 Mdot
.91 .30757 Mdot
.91 .30784 Mdot
.91 .30856 Mdot
.91 .31034 Mdot
.91 .31143 Mdot
.91 .31158 Mdot
.91 .31253 Mdot
.91 .31326 Mdot
.91 .31332 Mdot
.91 .31352 Mdot
.91 .31463 Mdot
.91 .31524 Mdot
.91 .31577 Mdot
.91 .31648 Mdot
.91 .31661 Mdot
.91 .31873 Mdot
.91 .31896 Mdot
.91 .32079 Mdot
.91 .32092 Mdot
.91 .32102 Mdot
.91 .3217 Mdot
.91 .32176 Mdot
.91 .322 Mdot
.91 .32246 Mdot
.91 .32271 Mdot
.91 .32307 Mdot
.91 .32372 Mdot
.91 .32386 Mdot
.91 .32401 Mdot
.91 .3249 Mdot
.91 .3255 Mdot
.91 .32564 Mdot
.91 .32571 Mdot
.91 .32637 Mdot
.91 .32642 Mdot
.91 .32711 Mdot
.91 .32769 Mdot
.91 .3291 Mdot
.91 .32956 Mdot
.91 .33027 Mdot
.91 .33167 Mdot
.91 .33197 Mdot
.91 .33287 Mdot
.91 .33341 Mdot
.91 .33342 Mdot
.91 .33352 Mdot
.91 .33359 Mdot
.91 .33362 Mdot
.91 .33411 Mdot
.91 .33415 Mdot
.91 .33415 Mdot
.91 .33424 Mdot
.91 .33433 Mdot
.91 .33465 Mdot
.91 .33468 Mdot
.91 .33481 Mdot
.91 .33696 Mdot
.91 .3378 Mdot
.91 .33802 Mdot
.91 .33802 Mdot
.91 .33802 Mdot
.91 .33853 Mdot
.91 .33907 Mdot
.91 .33999 Mdot
.91 .34097 Mdot
.91 .34106 Mdot
.91 .34122 Mdot
.91 .34127 Mdot
.91 .34145 Mdot
.91 .34178 Mdot
.91 .34187 Mdot
.91 .342 Mdot
.91 .34256 Mdot
.91 .34272 Mdot
.91 .34296 Mdot
.91 .34298 Mdot
.91 .34306 Mdot
.91 .3431 Mdot
.91 .34313 Mdot
.91 .34361 Mdot
.91 .34501 Mdot
.91 .34631 Mdot
.91 .34638 Mdot
.91 .34638 Mdot
.91 .34724 Mdot
.91 .3473 Mdot
.91 .34731 Mdot
.91 .34748 Mdot
.91 .34789 Mdot
.91 .3485 Mdot
.91 .34865 Mdot
.91 .34901 Mdot
.91 .34927 Mdot
.91 .34927 Mdot
.91 .34934 Mdot
.91 .34986 Mdot
.91 .35068 Mdot
.91 .35088 Mdot
.91 .35203 Mdot
.91 .3538 Mdot
.91 .35383 Mdot
.91 .35438 Mdot
.91 .35446 Mdot
.91 .3547 Mdot
.91 .35483 Mdot
.91 .35497 Mdot
.91 .35521 Mdot
.91 .35546 Mdot
.91 .35548 Mdot
.91 .35556 Mdot
.91 .35566 Mdot
.91 .35576 Mdot
.91 .35581 Mdot
.91 .35623 Mdot
.91 .35645 Mdot
.91 .35726 Mdot
.91 .35742 Mdot
.91 .35819 Mdot
.91 .35877 Mdot
.91 .35921 Mdot
.91 .35953 Mdot
.91 .35956 Mdot
.91 .36001 Mdot
.91 .36131 Mdot
.91 .36132 Mdot
.91 .36135 Mdot
.91 .36194 Mdot
.91 .36242 Mdot
.91 .36291 Mdot
.91 .36327 Mdot
.91 .36436 Mdot
.91 .36444 Mdot
.91 .36531 Mdot
.91 .36587 Mdot
.91 .36589 Mdot
.91 .36594 Mdot
.91 .36656 Mdot
.91 .36659 Mdot
.91 .36696 Mdot
.91 .36721 Mdot
.91 .36767 Mdot
.91 .3679 Mdot
.91 .37014 Mdot
.91 .37043 Mdot
.91 .37073 Mdot
.91 .37125 Mdot
.91 .37141 Mdot
.91 .37237 Mdot
.91 .373 Mdot
.91 .3732 Mdot
.91 .37322 Mdot
.91 .37351 Mdot
.91 .37385 Mdot
.91 .3739 Mdot
.91 .37441 Mdot
.91 .37461 Mdot
.91 .37483 Mdot
.91 .37557 Mdot
.91 .37621 Mdot
.91 .3763 Mdot
.91 .37673 Mdot
.91 .37696 Mdot
.91 .37872 Mdot
.91 .37911 Mdot
.91 .37926 Mdot
.91 .37954 Mdot
.91 .37962 Mdot
.91 .37965 Mdot
.91 .37967 Mdot
.91 .38063 Mdot
.91 .38065 Mdot
.91 .38091 Mdot
.91 .38093 Mdot
.91 .38098 Mdot
.91 .38111 Mdot
.91 .38129 Mdot
.91 .38145 Mdot
.91 .38154 Mdot
.91 .3817 Mdot
.91 .38201 Mdot
.91 .38236 Mdot
.91 .38307 Mdot
.91 .38316 Mdot
.91 .38394 Mdot
.91 .38398 Mdot
.91 .38439 Mdot
.91 .38452 Mdot
.91 .38462 Mdot
.91 .38535 Mdot
.91 .38549 Mdot
.91 .38564 Mdot
.91 .38608 Mdot
.91 .38636 Mdot
.91 .38674 Mdot
.91 .38816 Mdot
.91 .3885 Mdot
.91 .38869 Mdot
.91 .38875 Mdot
.91 .38884 Mdot
.91 .38894 Mdot
.91 .38911 Mdot
.91 .38924 Mdot
.91 .38966 Mdot
.91 .39041 Mdot
.91 .39066 Mdot
.91 .3907 Mdot
.91 .3911 Mdot
.91 .39113 Mdot
.91 .39124 Mdot
.91 .39127 Mdot
.91 .39151 Mdot
.91 .39176 Mdot
.91 .39199 Mdot
.91 .39213 Mdot
.91 .39246 Mdot
.91 .3925 Mdot
.91 .39272 Mdot
.91 .39344 Mdot
.91 .39394 Mdot
.91 .39402 Mdot
.91 .39415 Mdot
.91 .39458 Mdot
.91 .39464 Mdot
.91 .39486 Mdot
.91 .39503 Mdot
.91 .39522 Mdot
.91 .39529 Mdot
.91 .39557 Mdot
.91 .39561 Mdot
.91 .39581 Mdot
.91 .39593 Mdot
.91 .3962 Mdot
.91 .39627 Mdot
.91 .39659 Mdot
.91 .39698 Mdot
.91 .3971 Mdot
.91 .39765 Mdot
.91 .39787 Mdot
.91 .39811 Mdot
.91 .39825 Mdot
.91 .39889 Mdot
.91 .39911 Mdot
.91 .39916 Mdot
.91 .39949 Mdot
.91 .40047 Mdot
.91 .40087 Mdot
.91 .40095 Mdot
.91 .40143 Mdot
.91 .40156 Mdot
.91 .40181 Mdot
.91 .40223 Mdot
.91 .40229 Mdot
.91 .40268 Mdot
.91 .40312 Mdot
.91 .40318 Mdot
.91 .40336 Mdot
.91 .40343 Mdot
.91 .40347 Mdot
.91 .40415 Mdot
.91 .40418 Mdot
.91 .40422 Mdot
.91 .40467 Mdot
.91 .40564 Mdot
.91 .40605 Mdot
.91 .4064 Mdot
.91 .40681 Mdot
.91 .40704 Mdot
.91 .40735 Mdot
.91 .40754 Mdot
.91 .4077 Mdot
.91 .40782 Mdot
.91 .40816 Mdot
.91 .40878 Mdot
.91 .40907 Mdot
.91 .40923 Mdot
.91 .41062 Mdot
.91 .41114 Mdot
.91 .41134 Mdot
.91 .41136 Mdot
.91 .41173 Mdot
.91 .41174 Mdot
.91 .41205 Mdot
.91 .41257 Mdot
.91 .41317 Mdot
.91 .41336 Mdot
.91 .41363 Mdot
.91 .4139 Mdot
.91 .41522 Mdot
.91 .4154 Mdot
.91 .41564 Mdot
.91 .41638 Mdot
.91 .41647 Mdot
.91 .41691 Mdot
.91 .41726 Mdot
.91 .41729 Mdot
.91 .41734 Mdot
.91 .41787 Mdot
.91 .418 Mdot
.91 .41805 Mdot
.91 .41837 Mdot
.91 .41934 Mdot
.91 .41997 Mdot
.91 .42008 Mdot
.91 .42053 Mdot
.91 .42082 Mdot
.91 .42085 Mdot
.91 .42086 Mdot
.91 .421 Mdot
.91 .42128 Mdot
.91 .42161 Mdot
.91 .42184 Mdot
.91 .42193 Mdot
.91 .42197 Mdot
.91 .42244 Mdot
.91 .42245 Mdot
.91 .42248 Mdot
.91 .42423 Mdot
.91 .42427 Mdot
.91 .42432 Mdot
.91 .42446 Mdot
.91 .42455 Mdot
.91 .42497 Mdot
.91 .42515 Mdot
.91 .42525 Mdot
.91 .42542 Mdot
.91 .42596 Mdot
.91 .42704 Mdot
.91 .42762 Mdot
.91 .42887 Mdot
.91 .42916 Mdot
.91 .42916 Mdot
.91 .42918 Mdot
.91 .42956 Mdot
.91 .42957 Mdot
.91 .42987 Mdot
.91 .43036 Mdot
.91 .43053 Mdot
.91 .43169 Mdot
.91 .43271 Mdot
.91 .43303 Mdot
.91 .43341 Mdot
.91 .43344 Mdot
.91 .4338 Mdot
.91 .43384 Mdot
.91 .43392 Mdot
.91 .43474 Mdot
.91 .43482 Mdot
.91 .43545 Mdot
.91 .43559 Mdot
.91 .43584 Mdot
.91 .43597 Mdot
.91 .43601 Mdot
.91 .43638 Mdot
.91 .43643 Mdot
.91 .4365 Mdot
.91 .43751 Mdot
.91 .43764 Mdot
.91 .43887 Mdot
.91 .43926 Mdot
.91 .43956 Mdot
.91 .4405 Mdot
.91 .44104 Mdot
.91 .44157 Mdot
.91 .44165 Mdot
.91 .44323 Mdot
.91 .44437 Mdot
.91 .4449 Mdot
.91 .44564 Mdot
.91 .44581 Mdot
.91 .44607 Mdot
.91 .44691 Mdot
.91 .44736 Mdot
.91 .44803 Mdot
.91 .44809 Mdot
.91 .4489 Mdot
.91 .44923 Mdot
.91 .44932 Mdot
.91 .44934 Mdot
.91 .45037 Mdot
.91 .4516 Mdot
.91 .45168 Mdot
.91 .45194 Mdot
.91 .4521 Mdot
.91 .45239 Mdot
.91 .4527 Mdot
.91 .45287 Mdot
.91 .45379 Mdot
.91 .45409 Mdot
.91 .45473 Mdot
.91 .45563 Mdot
.91 .45649 Mdot
.91 .4565 Mdot
.91 .45655 Mdot
.91 .45667 Mdot
.91 .45701 Mdot
.91 .45757 Mdot
.91 .45763 Mdot
.91 .45764 Mdot
.91 .458 Mdot
.91 .45908 Mdot
.91 .45953 Mdot
.91 .4598 Mdot
.91 .45998 Mdot
.91 .46002 Mdot
.91 .46042 Mdot
.91 .46048 Mdot
.91 .46069 Mdot
.91 .46084 Mdot
.91 .46089 Mdot
.91 .46147 Mdot
.91 .46164 Mdot
.91 .46189 Mdot
.91 .46227 Mdot
.91 .46251 Mdot
.91 .4627 Mdot
.91 .46326 Mdot
.91 .46333 Mdot
.91 .46352 Mdot
.91 .46432 Mdot
.91 .46473 Mdot
.91 .46495 Mdot
.91 .46501 Mdot
.91 .46548 Mdot
.91 .46614 Mdot
.91 .4664 Mdot
.91 .46646 Mdot
.91 .46649 Mdot
.91 .4665 Mdot
.91 .46659 Mdot
.91 .46688 Mdot
.91 .46711 Mdot
.91 .46714 Mdot
.91 .46719 Mdot
.91 .46765 Mdot
.91 .46771 Mdot
.91 .46774 Mdot
.91 .46792 Mdot
.91 .4681 Mdot
.91 .46826 Mdot
.91 .4683 Mdot
.91 .46832 Mdot
.91 .46839 Mdot
.91 .46859 Mdot
.91 .46875 Mdot
.91 .46894 Mdot
.91 .46919 Mdot
.91 .46943 Mdot
.91 .46949 Mdot
.91 .46968 Mdot
.91 .46975 Mdot
.91 .4701 Mdot
.91 .47012 Mdot
.91 .47025 Mdot
.91 .47031 Mdot
.91 .47039 Mdot
.91 .47115 Mdot
.91 .47125 Mdot
.91 .47131 Mdot
.91 .47212 Mdot
.91 .4724 Mdot
.91 .47245 Mdot
.91 .47255 Mdot
.91 .47276 Mdot
.91 .4736 Mdot
.91 .47453 Mdot
.91 .47481 Mdot
.91 .47579 Mdot
.91 .47663 Mdot
.91 .477 Mdot
.91 .47734 Mdot
.91 .47754 Mdot
.91 .47762 Mdot
.91 .47828 Mdot
.91 .47849 Mdot
.91 .47944 Mdot
.91 .47955 Mdot
.91 .47956 Mdot
.91 .47965 Mdot
.91 .48002 Mdot
.91 .48069 Mdot
.91 .48095 Mdot
.91 .48159 Mdot
.91 .48207 Mdot
.91 .4823 Mdot
.91 .48282 Mdot
.91 .48293 Mdot
.91 .48313 Mdot
.91 .48314 Mdot
.91 .48315 Mdot
.91 .48326 Mdot
.91 .48482 Mdot
.91 .48482 Mdot
.91 .48494 Mdot
.91 .485 Mdot
.91 .48563 Mdot
.91 .48643 Mdot
.91 .48731 Mdot
.91 .48767 Mdot
.91 .48852 Mdot
.91 .48863 Mdot
.91 .48907 Mdot
.91 .48951 Mdot
.91 .48986 Mdot
.91 .49 Mdot
.91 .49019 Mdot
.91 .49074 Mdot
.91 .49078 Mdot
.91 .49085 Mdot
.91 .491 Mdot
.91 .49101 Mdot
.91 .49104 Mdot
.91 .49117 Mdot
.91 .49148 Mdot
.91 .49165 Mdot
.91 .49178 Mdot
.91 .49183 Mdot
.91 .49236 Mdot
.91 .49256 Mdot
.91 .49279 Mdot
.91 .49303 Mdot
.91 .4932 Mdot
.91 .49379 Mdot
.91 .49389 Mdot
.91 .49401 Mdot
.91 .49412 Mdot
.91 .49421 Mdot
.91 .49451 Mdot
.91 .49462 Mdot
.91 .49467 Mdot
.91 .49552 Mdot
.91 .49645 Mdot
.91 .49699 Mdot
.91 .49812 Mdot
.91 .49826 Mdot
.91 .4991 Mdot
.91 .50003 Mdot
.91 .50004 Mdot
.91 .50004 Mdot
.91 .50044 Mdot
.91 .50057 Mdot
.91 .50157 Mdot
.91 .50178 Mdot
.91 .50181 Mdot
.91 .50196 Mdot
.91 .502 Mdot
.91 .50386 Mdot
.91 .50496 Mdot
.91 .50539 Mdot
.91 .50554 Mdot
.91 .50557 Mdot
.91 .50587 Mdot
.91 .50611 Mdot
.91 .50616 Mdot
.91 .50676 Mdot
.91 .50692 Mdot
.91 .50707 Mdot
.91 .50707 Mdot
.91 .50714 Mdot
.91 .50804 Mdot
.91 .50809 Mdot
.91 .50819 Mdot
.91 .50822 Mdot
.91 .5084 Mdot
.91 .50841 Mdot
.91 .50843 Mdot
.91 .50941 Mdot
.91 .50977 Mdot
.91 .51104 Mdot
.91 .51139 Mdot
.91 .51159 Mdot
.91 .51354 Mdot
.91 .51413 Mdot
.91 .51453 Mdot
.91 .51455 Mdot
.91 .51543 Mdot
.91 .51619 Mdot
.91 .51627 Mdot
.91 .51721 Mdot
.91 .51757 Mdot
.91 .51778 Mdot
.91 .51811 Mdot
.91 .51835 Mdot
.91 .51884 Mdot
.91 .51916 Mdot
.91 .51988 Mdot
.91 .52012 Mdot
.91 .52064 Mdot
.91 .52114 Mdot
.91 .52123 Mdot
.91 .52133 Mdot
.91 .5215 Mdot
.91 .52177 Mdot
.91 .52243 Mdot
.91 .52256 Mdot
.91 .52282 Mdot
.91 .52392 Mdot
.91 .52447 Mdot
.91 .52553 Mdot
.91 .52581 Mdot
.91 .52584 Mdot
.91 .52592 Mdot
.91 .52607 Mdot
.91 .52723 Mdot
.91 .52789 Mdot
.91 .52836 Mdot
.91 .5292 Mdot
.91 .52924 Mdot
.91 .52933 Mdot
.91 .52962 Mdot
.91 .52963 Mdot
.91 .52974 Mdot
.91 .53027 Mdot
.91 .5307 Mdot
.91 .53097 Mdot
.91 .53115 Mdot
.91 .53139 Mdot
.91 .53221 Mdot
.91 .53341 Mdot
.91 .5336 Mdot
.91 .53472 Mdot
.91 .53514 Mdot
.91 .53515 Mdot
.91 .53581 Mdot
.91 .5366 Mdot
.91 .53731 Mdot
.91 .53858 Mdot
.91 .53901 Mdot
.91 .53924 Mdot
.91 .53983 Mdot
.91 .54007 Mdot
.91 .54053 Mdot
.91 .54095 Mdot
.91 .5415 Mdot
.91 .5415 Mdot
.91 .54202 Mdot
.91 .5426 Mdot
.91 .54398 Mdot
.91 .54463 Mdot
.91 .54498 Mdot
.91 .5451 Mdot
.91 .54572 Mdot
.91 .54642 Mdot
.91 .5477 Mdot
.91 .54815 Mdot
.91 .5482 Mdot
.91 .54843 Mdot
.91 .54951 Mdot
.91 .55041 Mdot
.912 .11036 Mdot
.912 .11133 Mdot
.912 .11144 Mdot
.912 .11201 Mdot
.912 .11269 Mdot
.912 .1139 Mdot
.912 .11435 Mdot
.912 .11532 Mdot
.912 .11679 Mdot
.912 .11798 Mdot
.912 .11832 Mdot
.912 .11915 Mdot
.912 .12124 Mdot
.912 .12142 Mdot
.912 .12344 Mdot
.912 .12772 Mdot
.912 .12872 Mdot
.912 .13111 Mdot
.912 .13153 Mdot
.912 .13171 Mdot
.912 .13278 Mdot
.912 .13288 Mdot
.912 .13438 Mdot
.912 .13466 Mdot
.912 .13517 Mdot
.912 .13676 Mdot
.912 .13681 Mdot
.912 .13731 Mdot
.912 .13752 Mdot
.912 .13928 Mdot
.912 .13948 Mdot
.912 .14005 Mdot
.912 .14132 Mdot
.912 .14192 Mdot
.912 .14205 Mdot
.912 .14228 Mdot
.912 .14356 Mdot
.912 .1454 Mdot
.912 .14576 Mdot
.912 .14649 Mdot
.912 .14818 Mdot
.912 .14915 Mdot
.912 .14977 Mdot
.912 .14981 Mdot
.912 .15078 Mdot
.912 .15138 Mdot
.912 .15159 Mdot
.912 .15197 Mdot
.912 .15255 Mdot
.912 .1535 Mdot
.912 .15414 Mdot
.912 .15456 Mdot
.912 .15463 Mdot
.912 .1549 Mdot
.912 .15582 Mdot
.912 .15636 Mdot
.912 .15756 Mdot
.912 .15839 Mdot
.912 .15893 Mdot
.912 .15911 Mdot
.912 .15927 Mdot
.912 .16096 Mdot
.912 .1615 Mdot
.912 .16236 Mdot
.912 .16286 Mdot
.912 .16304 Mdot
.912 .16515 Mdot
.912 .16621 Mdot
.912 .16785 Mdot
.912 .16822 Mdot
.912 .16917 Mdot
.912 .16952 Mdot
.912 .16962 Mdot
.912 .16978 Mdot
.912 .16979 Mdot
.912 .17148 Mdot
.912 .17152 Mdot
.912 .17279 Mdot
.912 .17325 Mdot
.912 .17546 Mdot
.912 .17675 Mdot
.912 .17765 Mdot
.912 .17791 Mdot
.912 .18011 Mdot
.912 .18055 Mdot
.912 .1817 Mdot
.912 .18179 Mdot
.912 .18237 Mdot
.912 .18243 Mdot
.912 .18388 Mdot
.912 .18389 Mdot
.912 .18493 Mdot
.912 .18634 Mdot
.912 .18667 Mdot
.912 .18753 Mdot
.912 .18871 Mdot
.912 .18917 Mdot
.912 .18931 Mdot
.912 .19046 Mdot
.912 .19073 Mdot
.912 .19087 Mdot
.912 .19094 Mdot
.912 .19114 Mdot
.912 .19178 Mdot
.912 .1919 Mdot
.912 .19218 Mdot
.912 .19311 Mdot
.912 .19329 Mdot
.912 .19341 Mdot
.912 .19401 Mdot
.912 .19442 Mdot
.912 .19451 Mdot
.912 .19483 Mdot
.912 .19494 Mdot
.912 .19495 Mdot
.912 .19563 Mdot
.912 .19616 Mdot
.912 .19644 Mdot
.912 .19676 Mdot
.912 .19687 Mdot
.912 .19701 Mdot
.912 .1974 Mdot
.912 .19822 Mdot
.912 .19862 Mdot
.912 .19886 Mdot
.912 .20007 Mdot
.912 .20025 Mdot
.912 .20089 Mdot
.912 .20106 Mdot
.912 .20148 Mdot
.912 .2021 Mdot
.912 .2025 Mdot
.912 .20307 Mdot
.912 .20323 Mdot
.912 .20334 Mdot
.912 .20369 Mdot
.912 .2043 Mdot
.912 .20494 Mdot
.912 .20521 Mdot
.912 .20536 Mdot
.912 .20628 Mdot
.912 .20648 Mdot
.912 .20781 Mdot
.912 .20875 Mdot
.912 .20886 Mdot
.912 .20902 Mdot
.912 .20934 Mdot
.912 .2106 Mdot
.912 .2117 Mdot
.912 .21243 Mdot
.912 .21258 Mdot
.912 .21294 Mdot
.912 .21303 Mdot
.912 .21318 Mdot
.912 .21359 Mdot
.912 .21365 Mdot
.912 .21414 Mdot
.912 .21455 Mdot
.912 .21565 Mdot
.912 .21605 Mdot
.912 .21853 Mdot
.912 .21895 Mdot
.912 .21909 Mdot
.912 .22035 Mdot
.912 .22083 Mdot
.912 .22084 Mdot
.912 .22101 Mdot
.912 .22171 Mdot
.912 .22173 Mdot
.912 .22215 Mdot
.912 .22267 Mdot
.912 .22395 Mdot
.912 .22445 Mdot
.912 .22489 Mdot
.912 .22497 Mdot
.912 .2255 Mdot
.912 .22586 Mdot
.912 .22702 Mdot
.912 .22766 Mdot
.912 .22778 Mdot
.912 .22811 Mdot
.912 .22877 Mdot
.912 .2291 Mdot
.912 .23006 Mdot
.912 .23026 Mdot
.912 .23047 Mdot
.912 .23052 Mdot
.912 .23081 Mdot
.912 .23127 Mdot
.912 .23266 Mdot
.912 .23271 Mdot
.912 .23299 Mdot
.912 .23304 Mdot
.912 .23342 Mdot
.912 .23349 Mdot
.912 .23377 Mdot
.912 .23425 Mdot
.912 .23443 Mdot
.912 .23454 Mdot
.912 .23478 Mdot
.912 .23481 Mdot
.912 .23511 Mdot
.912 .23561 Mdot
.912 .23619 Mdot
.912 .23661 Mdot
.912 .23728 Mdot
.912 .23732 Mdot
.912 .23742 Mdot
.912 .23804 Mdot
.912 .23809 Mdot
.912 .23833 Mdot
.912 .23871 Mdot
.912 .23931 Mdot
.912 .24008 Mdot
.912 .24051 Mdot
.912 .24073 Mdot
.912 .24159 Mdot
.912 .24177 Mdot
.912 .24192 Mdot
.912 .24214 Mdot
.912 .24217 Mdot
.912 .24228 Mdot
.912 .2429 Mdot
.912 .2429 Mdot
.912 .24307 Mdot
.912 .24333 Mdot
.912 .24404 Mdot
.912 .24418 Mdot
.912 .24467 Mdot
.912 .24471 Mdot
.912 .24545 Mdot
.912 .24565 Mdot
.912 .24599 Mdot
.912 .24673 Mdot
.912 .24698 Mdot
.912 .24717 Mdot
.912 .24722 Mdot
.912 .24739 Mdot
.912 .24862 Mdot
.912 .2492 Mdot
.912 .24958 Mdot
.912 .24973 Mdot
.912 .2499 Mdot
.912 .25197 Mdot
.912 .25204 Mdot
.912 .25285 Mdot
.912 .25309 Mdot
.912 .25374 Mdot
.912 .25392 Mdot
.912 .25434 Mdot
.912 .25666 Mdot
.912 .25758 Mdot
.912 .25778 Mdot
.912 .25781 Mdot
.912 .25787 Mdot
.912 .25816 Mdot
.912 .25885 Mdot
.912 .25989 Mdot
.912 .25993 Mdot
.912 .26018 Mdot
.912 .26105 Mdot
.912 .26112 Mdot
.912 .26136 Mdot
.912 .26149 Mdot
.912 .26219 Mdot
.912 .2629 Mdot
.912 .26309 Mdot
.912 .26378 Mdot
.912 .26399 Mdot
.912 .26438 Mdot
.912 .26447 Mdot
.912 .26507 Mdot
.912 .2651 Mdot
.912 .26516 Mdot
.912 .26613 Mdot
.912 .26685 Mdot
.912 .26747 Mdot
.912 .26756 Mdot
.912 .26786 Mdot
.912 .26828 Mdot
.912 .26864 Mdot
.912 .26903 Mdot
.912 .26979 Mdot
.912 .2698 Mdot
.912 .26991 Mdot
.912 .27023 Mdot
.912 .27042 Mdot
.912 .27065 Mdot
.912 .27102 Mdot
.912 .27103 Mdot
.912 .27126 Mdot
.912 .27191 Mdot
.912 .27201 Mdot
.912 .27209 Mdot
.912 .27232 Mdot
.912 .27265 Mdot
.912 .27307 Mdot
.912 .27415 Mdot
.912 .2748 Mdot
.912 .27496 Mdot
.912 .27499 Mdot
.912 .27512 Mdot
.912 .27527 Mdot
.912 .27621 Mdot
.912 .27677 Mdot
.912 .27776 Mdot
.912 .27809 Mdot
.912 .27822 Mdot
.912 .27838 Mdot
.912 .27851 Mdot
.912 .27858 Mdot
.912 .28086 Mdot
.912 .28146 Mdot
.912 .28184 Mdot
.912 .28202 Mdot
.912 .28215 Mdot
.912 .28239 Mdot
.912 .28245 Mdot
.912 .28281 Mdot
.912 .28344 Mdot
.912 .28399 Mdot
.912 .28402 Mdot
.912 .2849 Mdot
.912 .28494 Mdot
.912 .28525 Mdot
.912 .28586 Mdot
.912 .28657 Mdot
.912 .28731 Mdot
.912 .28911 Mdot
.912 .29051 Mdot
.912 .29104 Mdot
.912 .2916 Mdot
.912 .29173 Mdot
.912 .29213 Mdot
.912 .29294 Mdot
.912 .29358 Mdot
.912 .29404 Mdot
.912 .29471 Mdot
.912 .29476 Mdot
.912 .29498 Mdot
.912 .29522 Mdot
.912 .29559 Mdot
.912 .29575 Mdot
.912 .29645 Mdot
.912 .29673 Mdot
.912 .29708 Mdot
.912 .29726 Mdot
.912 .29755 Mdot
.912 .29757 Mdot
.912 .29775 Mdot
.912 .29855 Mdot
.912 .29982 Mdot
.912 .30066 Mdot
.912 .30072 Mdot
.912 .30125 Mdot
.912 .30146 Mdot
.912 .30148 Mdot
.912 .30305 Mdot
.912 .30389 Mdot
.912 .30419 Mdot
.912 .30548 Mdot
.912 .30614 Mdot
.912 .30712 Mdot
.912 .30792 Mdot
.912 .30835 Mdot
.912 .30892 Mdot
.912 .30909 Mdot
.912 .30941 Mdot
.912 .31027 Mdot
.912 .31068 Mdot
.912 .31118 Mdot
.912 .31191 Mdot
.912 .31237 Mdot
.912 .31262 Mdot
.912 .31331 Mdot
.912 .31622 Mdot
.912 .3164 Mdot
.912 .31672 Mdot
.912 .31675 Mdot
.912 .3172 Mdot
.912 .31728 Mdot
.912 .31744 Mdot
.912 .31808 Mdot
.912 .31891 Mdot
.912 .31929 Mdot
.912 .31947 Mdot
.912 .31951 Mdot
.912 .31996 Mdot
.912 .32051 Mdot
.912 .32062 Mdot
.912 .32135 Mdot
.912 .32238 Mdot
.912 .32249 Mdot
.912 .32314 Mdot
.912 .32327 Mdot
.912 .32329 Mdot
.912 .32337 Mdot
.912 .32458 Mdot
.912 .32519 Mdot
.912 .32561 Mdot
.912 .32576 Mdot
.912 .32677 Mdot
.912 .32737 Mdot
.912 .32776 Mdot
.912 .32784 Mdot
.912 .32784 Mdot
.912 .32836 Mdot
.912 .32875 Mdot
.912 .32955 Mdot
.912 .32994 Mdot
.912 .33021 Mdot
.912 .33095 Mdot
.912 .33108 Mdot
.912 .33142 Mdot
.912 .33145 Mdot
.912 .33163 Mdot
.912 .33164 Mdot
.912 .33208 Mdot
.912 .3324 Mdot
.912 .33292 Mdot
.912 .33318 Mdot
.912 .33371 Mdot
.912 .33406 Mdot
.912 .33418 Mdot
.912 .33485 Mdot
.912 .33491 Mdot
.912 .33512 Mdot
.912 .33525 Mdot
.912 .33528 Mdot
.912 .33541 Mdot
.912 .33577 Mdot
.912 .33599 Mdot
.912 .33603 Mdot
.912 .33614 Mdot
.912 .33651 Mdot
.912 .33768 Mdot
.912 .3379 Mdot
.912 .33822 Mdot
.912 .33841 Mdot
.912 .33881 Mdot
.912 .33887 Mdot
.912 .33927 Mdot
.912 .33955 Mdot
.912 .33959 Mdot
.912 .34011 Mdot
.912 .34044 Mdot
.912 .34066 Mdot
.912 .34071 Mdot
.912 .34103 Mdot
.912 .34175 Mdot
.912 .3425 Mdot
.912 .34266 Mdot
.912 .34304 Mdot
.912 .34324 Mdot
.912 .34345 Mdot
.912 .34346 Mdot
.912 .34358 Mdot
.912 .3447 Mdot
.912 .34557 Mdot
.912 .34567 Mdot
.912 .34608 Mdot
.912 .3461 Mdot
.912 .34619 Mdot
.912 .34676 Mdot
.912 .34685 Mdot
.912 .34697 Mdot
.912 .34722 Mdot
.912 .34739 Mdot
.912 .34763 Mdot
.912 .3478 Mdot
.912 .34793 Mdot
.912 .3491 Mdot
.912 .34943 Mdot
.912 .34982 Mdot
.912 .34982 Mdot
.912 .34987 Mdot
.912 .35016 Mdot
.912 .35021 Mdot
.912 .35035 Mdot
.912 .35059 Mdot
.912 .3511 Mdot
.912 .35257 Mdot
.912 .35281 Mdot
.912 .35313 Mdot
.912 .35396 Mdot
.912 .3543 Mdot
.912 .35461 Mdot
.912 .35537 Mdot
.912 .35589 Mdot
.912 .35609 Mdot
.912 .35651 Mdot
.912 .35702 Mdot
.912 .35723 Mdot
.912 .35745 Mdot
.912 .35756 Mdot
.912 .35816 Mdot
.912 .35828 Mdot
.912 .35854 Mdot
.912 .35857 Mdot
.912 .35866 Mdot
.912 .35876 Mdot
.912 .35941 Mdot
.912 .35946 Mdot
.912 .35983 Mdot
.912 .36044 Mdot
.912 .36052 Mdot
.912 .36169 Mdot
.912 .36201 Mdot
.912 .36217 Mdot
.912 .36244 Mdot
.912 .36295 Mdot
.912 .36317 Mdot
.912 .36413 Mdot
.912 .36446 Mdot
.912 .3645 Mdot
.912 .36462 Mdot
.912 .36486 Mdot
.912 .36541 Mdot
.912 .36555 Mdot
.912 .3657 Mdot
.912 .366 Mdot
.912 .36693 Mdot
.912 .36742 Mdot
.912 .36824 Mdot
.912 .36863 Mdot
.912 .36883 Mdot
.912 .36912 Mdot
.912 .36971 Mdot
.912 .37034 Mdot
.912 .37098 Mdot
.912 .37186 Mdot
.912 .37202 Mdot
.912 .37285 Mdot
.912 .37298 Mdot
.912 .37371 Mdot
.912 .37401 Mdot
.912 .37437 Mdot
.912 .37503 Mdot
.912 .37535 Mdot
.912 .37562 Mdot
.912 .37586 Mdot
.912 .37628 Mdot
.912 .37643 Mdot
.912 .37644 Mdot
.912 .37672 Mdot
.912 .37746 Mdot
.912 .37754 Mdot
.912 .37758 Mdot
.912 .37847 Mdot
.912 .37865 Mdot
.912 .37879 Mdot
.912 .37887 Mdot
.912 .37922 Mdot
.912 .37992 Mdot
.912 .38083 Mdot
.912 .38084 Mdot
.912 .38123 Mdot
.912 .38174 Mdot
.912 .38196 Mdot
.912 .38196 Mdot
.912 .38234 Mdot
.912 .38384 Mdot
.912 .38412 Mdot
.912 .38425 Mdot
.912 .38446 Mdot
.912 .38648 Mdot
.912 .38664 Mdot
.912 .38682 Mdot
.912 .38725 Mdot
.912 .38749 Mdot
.912 .38832 Mdot
.912 .38953 Mdot
.912 .38979 Mdot
.912 .38995 Mdot
.912 .39066 Mdot
.912 .39069 Mdot
.912 .391 Mdot
.912 .39128 Mdot
.912 .39155 Mdot
.912 .39218 Mdot
.912 .39227 Mdot
.912 .39231 Mdot
.912 .39302 Mdot
.912 .39308 Mdot
.912 .39402 Mdot
.912 .39469 Mdot
.912 .39636 Mdot
.912 .39727 Mdot
.912 .39773 Mdot
.912 .39808 Mdot
.912 .39823 Mdot
.912 .39895 Mdot
.912 .39919 Mdot
.912 .39985 Mdot
.912 .40067 Mdot
.912 .40077 Mdot
.912 .40196 Mdot
.912 .40208 Mdot
.912 .40215 Mdot
.912 .40231 Mdot
.912 .40313 Mdot
.912 .40334 Mdot
.912 .40346 Mdot
.912 .40395 Mdot
.912 .40395 Mdot
.912 .40446 Mdot
.912 .40503 Mdot
.912 .40508 Mdot
.912 .40515 Mdot
.912 .40576 Mdot
.912 .40637 Mdot
.912 .40668 Mdot
.912 .40714 Mdot
.912 .4075 Mdot
.912 .40786 Mdot
.912 .40826 Mdot
.912 .40833 Mdot
.912 .40888 Mdot
.912 .40936 Mdot
.912 .40971 Mdot
.912 .41086 Mdot
.912 .41131 Mdot
.912 .41209 Mdot
.912 .41225 Mdot
.912 .41234 Mdot
.912 .41241 Mdot
.912 .41271 Mdot
.912 .41285 Mdot
.912 .41293 Mdot
.912 .41364 Mdot
.912 .41376 Mdot
.912 .41428 Mdot
.912 .41514 Mdot
.912 .41547 Mdot
.912 .41567 Mdot
.912 .41611 Mdot
.912 .41618 Mdot
.912 .41638 Mdot
.912 .41672 Mdot
.912 .41678 Mdot
.912 .41701 Mdot
.912 .41752 Mdot
.912 .41763 Mdot
.912 .41869 Mdot
.912 .41945 Mdot
.912 .42025 Mdot
.912 .42067 Mdot
.912 .42075 Mdot
.912 .42093 Mdot
.912 .42096 Mdot
.912 .42096 Mdot
.912 .42135 Mdot
.912 .42206 Mdot
.912 .42216 Mdot
.912 .42229 Mdot
.912 .42258 Mdot
.912 .423 Mdot
.912 .42301 Mdot
.912 .42329 Mdot
.912 .42438 Mdot
.912 .42467 Mdot
.912 .42578 Mdot
.912 .42595 Mdot
.912 .42657 Mdot
.912 .42659 Mdot
.912 .42674 Mdot
.912 .42696 Mdot
.912 .42699 Mdot
.912 .42732 Mdot
.912 .42854 Mdot
.912 .42886 Mdot
.912 .42895 Mdot
.912 .42901 Mdot
.912 .42913 Mdot
.912 .42916 Mdot
.912 .42953 Mdot
.912 .4296 Mdot
.912 .42979 Mdot
.912 .43051 Mdot
.912 .43092 Mdot
.912 .43093 Mdot
.912 .43103 Mdot
.912 .43104 Mdot
.912 .43123 Mdot
.912 .4313 Mdot
.912 .43171 Mdot
.912 .43207 Mdot
.912 .43251 Mdot
.912 .43301 Mdot
.912 .43301 Mdot
.912 .43326 Mdot
.912 .4336 Mdot
.912 .43415 Mdot
.912 .43423 Mdot
.912 .4348 Mdot
.912 .43546 Mdot
.912 .43558 Mdot
.912 .43594 Mdot
.912 .436 Mdot
.912 .43657 Mdot
.912 .43733 Mdot
.912 .43758 Mdot
.912 .43791 Mdot
.912 .43836 Mdot
.912 .43871 Mdot
.912 .4388 Mdot
.912 .43909 Mdot
.912 .43911 Mdot
.912 .43938 Mdot
.912 .44098 Mdot
.912 .44135 Mdot
.912 .44214 Mdot
.912 .44242 Mdot
.912 .44311 Mdot
.912 .44329 Mdot
.912 .44338 Mdot
.912 .4437 Mdot
.912 .44437 Mdot
.912 .4449 Mdot
.912 .44527 Mdot
.912 .44597 Mdot
.912 .44746 Mdot
.912 .44747 Mdot
.912 .44759 Mdot
.912 .44837 Mdot
.912 .44907 Mdot
.912 .4495 Mdot
.912 .45007 Mdot
.912 .4506 Mdot
.912 .45069 Mdot
.912 .45089 Mdot
.912 .45103 Mdot
.912 .45115 Mdot
.912 .45179 Mdot
.912 .45214 Mdot
.912 .45259 Mdot
.912 .4528 Mdot
.912 .45288 Mdot
.912 .45348 Mdot
.912 .45523 Mdot
.912 .45563 Mdot
.912 .45602 Mdot
.912 .45655 Mdot
.912 .45705 Mdot
.912 .45735 Mdot
.912 .45769 Mdot
.912 .45792 Mdot
.912 .45806 Mdot
.912 .45813 Mdot
.912 .45823 Mdot
.912 .45877 Mdot
.912 .46002 Mdot
.912 .46006 Mdot
.912 .46021 Mdot
.912 .46132 Mdot
.912 .46191 Mdot
.912 .46199 Mdot
.912 .462 Mdot
.912 .46209 Mdot
.912 .46244 Mdot
.912 .46327 Mdot
.912 .46345 Mdot
.912 .46361 Mdot
.912 .46367 Mdot
.912 .46403 Mdot
.912 .46415 Mdot
.912 .46416 Mdot
.912 .46436 Mdot
.912 .46459 Mdot
.912 .46483 Mdot
.912 .46546 Mdot
.912 .46566 Mdot
.912 .46605 Mdot
.912 .46611 Mdot
.912 .46645 Mdot
.912 .46737 Mdot
.912 .4674 Mdot
.912 .46775 Mdot
.912 .46813 Mdot
.912 .46851 Mdot
.912 .469 Mdot
.912 .46939 Mdot
.912 .46946 Mdot
.912 .4701 Mdot
.912 .47026 Mdot
.912 .47083 Mdot
.912 .47137 Mdot
.912 .4714 Mdot
.912 .47142 Mdot
.912 .47153 Mdot
.912 .47203 Mdot
.912 .4733 Mdot
.912 .47353 Mdot
.912 .47412 Mdot
.912 .47457 Mdot
.912 .47461 Mdot
.912 .47574 Mdot
.912 .47591 Mdot
.912 .47644 Mdot
.912 .47721 Mdot
.912 .47724 Mdot
.912 .47788 Mdot
.912 .47818 Mdot
.912 .47858 Mdot
.912 .47861 Mdot
.912 .47887 Mdot
.912 .47895 Mdot
.912 .47948 Mdot
.912 .47957 Mdot
.912 .47958 Mdot
.912 .47997 Mdot
.912 .48 Mdot
.912 .4802 Mdot
.912 .48029 Mdot
.912 .48077 Mdot
.912 .48089 Mdot
.912 .48112 Mdot
.912 .48154 Mdot
.912 .48221 Mdot
.912 .48224 Mdot
.912 .48266 Mdot
.912 .48302 Mdot
.912 .48325 Mdot
.912 .48357 Mdot
.912 .48385 Mdot
.912 .48401 Mdot
.912 .48403 Mdot
.912 .48416 Mdot
.912 .48432 Mdot
.912 .48458 Mdot
.912 .48477 Mdot
.912 .48498 Mdot
.912 .48516 Mdot
.912 .48519 Mdot
.912 .48595 Mdot
.912 .4862 Mdot
.912 .48637 Mdot
.912 .48639 Mdot
.912 .48714 Mdot
.912 .48732 Mdot
.912 .48793 Mdot
.912 .48892 Mdot
.912 .48912 Mdot
.912 .4894 Mdot
.912 .48945 Mdot
.912 .48969 Mdot
.912 .48997 Mdot
.912 .49095 Mdot
.912 .49118 Mdot
.912 .4912 Mdot
.912 .49158 Mdot
.912 .49168 Mdot
.912 .49194 Mdot
.912 .49263 Mdot
.912 .4927 Mdot
.912 .49294 Mdot
.912 .49429 Mdot
.912 .49451 Mdot
.912 .49512 Mdot
.912 .49534 Mdot
.912 .49561 Mdot
.912 .49565 Mdot
.912 .49587 Mdot
.912 .496 Mdot
.912 .4962 Mdot
.912 .49628 Mdot
.912 .49668 Mdot
.912 .49728 Mdot
.912 .49824 Mdot
.912 .4983 Mdot
.912 .49881 Mdot
.912 .49954 Mdot
.912 .49965 Mdot
.912 .50016 Mdot
.912 .50039 Mdot
.912 .50074 Mdot
.912 .50127 Mdot
.912 .50132 Mdot
.912 .50173 Mdot
.912 .50194 Mdot
.912 .50229 Mdot
.912 .50251 Mdot
.912 .50296 Mdot
.912 .50306 Mdot
.912 .50372 Mdot
.912 .50385 Mdot
.912 .50452 Mdot
.912 .50474 Mdot
.912 .50481 Mdot
.912 .50488 Mdot
.912 .5052 Mdot
.912 .50587 Mdot
.912 .50587 Mdot
.912 .50593 Mdot
.912 .50611 Mdot
.912 .50616 Mdot
.912 .50638 Mdot
.912 .50677 Mdot
.912 .50687 Mdot
.912 .50754 Mdot
.912 .5076 Mdot
.912 .5081 Mdot
.912 .50818 Mdot
.912 .50833 Mdot
.912 .50896 Mdot
.912 .50929 Mdot
.912 .50993 Mdot
.912 .5104 Mdot
.912 .51058 Mdot
.912 .51136 Mdot
.912 .51193 Mdot
.912 .51194 Mdot
.912 .51273 Mdot
.912 .51276 Mdot
.912 .51308 Mdot
.912 .51313 Mdot
.912 .51376 Mdot
.912 .514 Mdot
.912 .51521 Mdot
.912 .51535 Mdot
.912 .51584 Mdot
.912 .51655 Mdot
.912 .51776 Mdot
.912 .51801 Mdot
.912 .51871 Mdot
.912 .51873 Mdot
.912 .51966 Mdot
.912 .51966 Mdot
.912 .51975 Mdot
.912 .51981 Mdot
.912 .52 Mdot
.912 .52052 Mdot
.912 .52072 Mdot
.912 .52162 Mdot
.912 .5222 Mdot
.912 .52336 Mdot
.912 .52346 Mdot
.912 .52373 Mdot
.912 .52421 Mdot
.912 .5245 Mdot
.912 .52543 Mdot
.912 .52551 Mdot
.912 .52561 Mdot
.912 .52591 Mdot
.912 .52636 Mdot
.912 .52702 Mdot
.912 .52732 Mdot
.912 .52782 Mdot
.912 .52797 Mdot
.912 .52801 Mdot
.912 .52824 Mdot
.912 .52859 Mdot
.912 .52911 Mdot
.912 .52943 Mdot
.912 .52964 Mdot
.912 .52975 Mdot
.912 .53008 Mdot
.912 .53061 Mdot
.912 .53064 Mdot
.912 .53097 Mdot
.912 .5315 Mdot
.912 .53243 Mdot
.912 .53283 Mdot
.912 .53303 Mdot
.912 .53404 Mdot
.912 .53474 Mdot
.912 .53487 Mdot
.912 .53494 Mdot
.912 .53526 Mdot
.912 .53596 Mdot
.912 .53628 Mdot
.912 .53639 Mdot
.912 .53735 Mdot
.912 .53747 Mdot
.912 .53774 Mdot
.912 .53777 Mdot
.912 .53864 Mdot
.912 .53892 Mdot
.912 .53907 Mdot
.912 .53989 Mdot
.912 .53995 Mdot
.912 .54054 Mdot
.912 .54064 Mdot
.912 .54086 Mdot
.912 .54217 Mdot
.912 .54272 Mdot
.912 .54507 Mdot
.912 .54618 Mdot
.912 .54628 Mdot
.912 .54742 Mdot
.912 .54788 Mdot
.912 .54806 Mdot
.912 .54872 Mdot
.912 .54952 Mdot
.912 .55006 Mdot
.912 .5503 Mdot
.912 .55097 Mdot
.912 .55134 Mdot
.912 .55165 Mdot
.912 .55171 Mdot
.912 .55224 Mdot
.914 .10761 Mdot
.914 .10796 Mdot
.914 .11023 Mdot
.914 .11026 Mdot
.914 .11041 Mdot
.914 .1121 Mdot
.914 .11213 Mdot
.914 .11327 Mdot
.914 .11421 Mdot
.914 .11423 Mdot
.914 .11533 Mdot
.914 .11566 Mdot
.914 .11695 Mdot
.914 .11843 Mdot
.914 .12037 Mdot
.914 .12184 Mdot
.914 .12252 Mdot
.914 .12358 Mdot
.914 .12478 Mdot
.914 .12563 Mdot
.914 .12611 Mdot
.914 .12612 Mdot
.914 .12794 Mdot
.914 .1283 Mdot
.914 .12924 Mdot
.914 .12974 Mdot
.914 .13054 Mdot
.914 .13229 Mdot
.914 .13307 Mdot
.914 .13311 Mdot
.914 .13425 Mdot
.914 .13463 Mdot
.914 .13495 Mdot
.914 .13535 Mdot
.914 .13539 Mdot
.914 .13602 Mdot
.914 .13718 Mdot
.914 .13761 Mdot
.914 .13832 Mdot
.914 .13855 Mdot
.914 .13877 Mdot
.914 .14074 Mdot
.914 .14234 Mdot
.914 .14275 Mdot
.914 .14778 Mdot
.914 .14868 Mdot
.914 .14909 Mdot
.914 .14915 Mdot
.914 .14971 Mdot
.914 .15149 Mdot
.914 .15162 Mdot
.914 .15246 Mdot
.914 .153 Mdot
.914 .15309 Mdot
.914 .15334 Mdot
.914 .15393 Mdot
.914 .15428 Mdot
.914 .15511 Mdot
.914 .15545 Mdot
.914 .15564 Mdot
.914 .15573 Mdot
.914 .15597 Mdot
.914 .15616 Mdot
.914 .1568 Mdot
.914 .15716 Mdot
.914 .15725 Mdot
.914 .15792 Mdot
.914 .15792 Mdot
.914 .15808 Mdot
.914 .15846 Mdot
.914 .15849 Mdot
.914 .15884 Mdot
.914 .15904 Mdot
.914 .16005 Mdot
.914 .16025 Mdot
.914 .16054 Mdot
.914 .1629 Mdot
.914 .16372 Mdot
.914 .16626 Mdot
.914 .16747 Mdot
.914 .16767 Mdot
.914 .16782 Mdot
.914 .17037 Mdot
.914 .17064 Mdot
.914 .1717 Mdot
.914 .17231 Mdot
.914 .17429 Mdot
.914 .17764 Mdot
.914 .17855 Mdot
.914 .17906 Mdot
.914 .17914 Mdot
.914 .17914 Mdot
.914 .17944 Mdot
.914 .1795 Mdot
.914 .17965 Mdot
.914 .18015 Mdot
.914 .18028 Mdot
.914 .18095 Mdot
.914 .18102 Mdot
.914 .18186 Mdot
.914 .18283 Mdot
.914 .183 Mdot
.914 .18345 Mdot
.914 .18354 Mdot
.914 .18398 Mdot
.914 .18406 Mdot
.914 .18437 Mdot
.914 .18453 Mdot
.914 .18516 Mdot
.914 .18529 Mdot
.914 .18638 Mdot
.914 .18772 Mdot
.914 .18782 Mdot
.914 .18798 Mdot
.914 .188 Mdot
.914 .18826 Mdot
.914 .18867 Mdot
.914 .18931 Mdot
.914 .18938 Mdot
.914 .18964 Mdot
.914 .19024 Mdot
.914 .19028 Mdot
.914 .19162 Mdot
.914 .19274 Mdot
.914 .19278 Mdot
.914 .19287 Mdot
.914 .19325 Mdot
.914 .19333 Mdot
.914 .19384 Mdot
.914 .19393 Mdot
.914 .19418 Mdot
.914 .19488 Mdot
.914 .19658 Mdot
.914 .19663 Mdot
.914 .19731 Mdot
.914 .1977 Mdot
.914 .19864 Mdot
.914 .19924 Mdot
.914 .19935 Mdot
.914 .19993 Mdot
.914 .20159 Mdot
.914 .20193 Mdot
.914 .20235 Mdot
.914 .20238 Mdot
.914 .20247 Mdot
.914 .20251 Mdot
.914 .203 Mdot
.914 .20419 Mdot
.914 .20431 Mdot
.914 .20538 Mdot
.914 .20544 Mdot
.914 .20715 Mdot
.914 .20715 Mdot
.914 .20786 Mdot
.914 .20886 Mdot
.914 .20922 Mdot
.914 .20948 Mdot
.914 .20959 Mdot
.914 .20998 Mdot
.914 .21054 Mdot
.914 .21072 Mdot
.914 .21117 Mdot
.914 .21154 Mdot
.914 .21178 Mdot
.914 .21234 Mdot
.914 .21279 Mdot
.914 .21279 Mdot
.914 .21372 Mdot
.914 .21425 Mdot
.914 .21514 Mdot
.914 .21514 Mdot
.914 .21592 Mdot
.914 .21593 Mdot
.914 .21647 Mdot
.914 .21694 Mdot
.914 .21744 Mdot
.914 .21748 Mdot
.914 .21799 Mdot
.914 .21805 Mdot
.914 .21815 Mdot
.914 .21835 Mdot
.914 .21836 Mdot
.914 .21839 Mdot
.914 .21841 Mdot
.914 .22059 Mdot
.914 .22169 Mdot
.914 .22169 Mdot
.914 .22228 Mdot
.914 .22236 Mdot
.914 .22248 Mdot
.914 .22305 Mdot
.914 .22384 Mdot
.914 .22406 Mdot
.914 .22498 Mdot
.914 .22524 Mdot
.914 .2257 Mdot
.914 .22644 Mdot
.914 .22891 Mdot
.914 .22895 Mdot
.914 .22918 Mdot
.914 .22964 Mdot
.914 .23032 Mdot
.914 .23107 Mdot
.914 .23114 Mdot
.914 .23181 Mdot
.914 .23229 Mdot
.914 .23236 Mdot
.914 .23268 Mdot
.914 .233 Mdot
.914 .23322 Mdot
.914 .23347 Mdot
.914 .23353 Mdot
.914 .23384 Mdot
.914 .23393 Mdot
.914 .23451 Mdot
.914 .23524 Mdot
.914 .2353 Mdot
.914 .23557 Mdot
.914 .23584 Mdot
.914 .23646 Mdot
.914 .2371 Mdot
.914 .23859 Mdot
.914 .23937 Mdot
.914 .23953 Mdot
.914 .24062 Mdot
.914 .24066 Mdot
.914 .24109 Mdot
.914 .24149 Mdot
.914 .24232 Mdot
.914 .24276 Mdot
.914 .24378 Mdot
.914 .24472 Mdot
.914 .24473 Mdot
.914 .24491 Mdot
.914 .24501 Mdot
.914 .24509 Mdot
.914 .24523 Mdot
.914 .24639 Mdot
.914 .24641 Mdot
.914 .24718 Mdot
.914 .24789 Mdot
.914 .24802 Mdot
.914 .24847 Mdot
.914 .24876 Mdot
.914 .24892 Mdot
.914 .24942 Mdot
.914 .24959 Mdot
.914 .25147 Mdot
.914 .25173 Mdot
.914 .25313 Mdot
.914 .25444 Mdot
.914 .25483 Mdot
.914 .25562 Mdot
.914 .25598 Mdot
.914 .25636 Mdot
.914 .25682 Mdot
.914 .25691 Mdot
.914 .25768 Mdot
.914 .25795 Mdot
.914 .25941 Mdot
.914 .2596 Mdot
.914 .26036 Mdot
.914 .26047 Mdot
.914 .26149 Mdot
.914 .26207 Mdot
.914 .26237 Mdot
.914 .26255 Mdot
.914 .26302 Mdot
.914 .26311 Mdot
.914 .26314 Mdot
.914 .26328 Mdot
.914 .26343 Mdot
.914 .26474 Mdot
.914 .26497 Mdot
.914 .265 Mdot
.914 .26536 Mdot
.914 .26559 Mdot
.914 .26571 Mdot
.914 .26652 Mdot
.914 .2666 Mdot
.914 .2675 Mdot
.914 .26767 Mdot
.914 .26788 Mdot
.914 .26811 Mdot
.914 .26812 Mdot
.914 .26856 Mdot
.914 .26862 Mdot
.914 .2689 Mdot
.914 .26921 Mdot
.914 .26985 Mdot
.914 .27128 Mdot
.914 .27136 Mdot
.914 .27188 Mdot
.914 .27197 Mdot
.914 .27199 Mdot
.914 .27232 Mdot
.914 .27234 Mdot
.914 .27248 Mdot
.914 .27293 Mdot
.914 .27327 Mdot
.914 .27445 Mdot
.914 .27487 Mdot
.914 .27511 Mdot
.914 .27528 Mdot
.914 .27551 Mdot
.914 .27584 Mdot
.914 .27649 Mdot
.914 .2765 Mdot
.914 .27657 Mdot
.914 .27678 Mdot
.914 .27747 Mdot
.914 .27753 Mdot
.914 .27774 Mdot
.914 .27818 Mdot
.914 .27855 Mdot
.914 .27866 Mdot
.914 .27913 Mdot
.914 .27986 Mdot
.914 .27986 Mdot
.914 .28038 Mdot
.914 .28039 Mdot
.914 .28075 Mdot
.914 .28127 Mdot
.914 .28129 Mdot
.914 .2822 Mdot
.914 .28281 Mdot
.914 .28385 Mdot
.914 .28402 Mdot
.914 .28414 Mdot
.914 .28451 Mdot
.914 .28559 Mdot
.914 .28565 Mdot
.914 .28568 Mdot
.914 .2864 Mdot
.914 .28678 Mdot
.914 .28696 Mdot
.914 .28709 Mdot
.914 .28714 Mdot
.914 .28814 Mdot
.914 .28816 Mdot
.914 .28827 Mdot
.914 .29029 Mdot
.914 .29079 Mdot
.914 .29163 Mdot
.914 .29174 Mdot
.914 .2921 Mdot
.914 .29396 Mdot
.914 .29432 Mdot
.914 .29444 Mdot
.914 .2946 Mdot
.914 .2946 Mdot
.914 .29518 Mdot
.914 .29528 Mdot
.914 .29568 Mdot
.914 .29597 Mdot
.914 .29648 Mdot
.914 .29722 Mdot
.914 .29724 Mdot
.914 .29926 Mdot
.914 .29974 Mdot
.914 .30115 Mdot
.914 .30135 Mdot
.914 .30157 Mdot
.914 .30168 Mdot
.914 .30202 Mdot
.914 .30279 Mdot
.914 .30451 Mdot
.914 .30641 Mdot
.914 .30767 Mdot
.914 .30768 Mdot
.914 .30831 Mdot
.914 .30881 Mdot
.914 .30887 Mdot
.914 .30965 Mdot
.914 .30984 Mdot
.914 .31053 Mdot
.914 .31109 Mdot
.914 .31144 Mdot
.914 .31205 Mdot
.914 .31215 Mdot
.914 .31253 Mdot
.914 .31356 Mdot
.914 .314 Mdot
.914 .3142 Mdot
.914 .31452 Mdot
.914 .31513 Mdot
.914 .31528 Mdot
.914 .31528 Mdot
.914 .31582 Mdot
.914 .31593 Mdot
.914 .31621 Mdot
.914 .31636 Mdot
.914 .31713 Mdot
.914 .31736 Mdot
.914 .31792 Mdot
.914 .31805 Mdot
.914 .31859 Mdot
.914 .31872 Mdot
.914 .31893 Mdot
.914 .319 Mdot
.914 .31907 Mdot
.914 .32026 Mdot
.914 .32176 Mdot
.914 .32203 Mdot
.914 .32234 Mdot
.914 .32287 Mdot
.914 .32316 Mdot
.914 .32332 Mdot
.914 .32335 Mdot
.914 .3236 Mdot
.914 .32396 Mdot
.914 .32406 Mdot
.914 .32414 Mdot
.914 .32427 Mdot
.914 .32446 Mdot
.914 .32457 Mdot
.914 .3246 Mdot
.914 .32484 Mdot
.914 .32497 Mdot
.914 .32513 Mdot
.914 .32549 Mdot
.914 .32558 Mdot
.914 .32629 Mdot
.914 .32653 Mdot
.914 .32771 Mdot
.914 .32852 Mdot
.914 .32892 Mdot
.914 .32969 Mdot
.914 .3307 Mdot
.914 .33097 Mdot
.914 .33115 Mdot
.914 .33115 Mdot
.914 .3313 Mdot
.914 .33145 Mdot
.914 .33149 Mdot
.914 .33169 Mdot
.914 .33171 Mdot
.914 .33196 Mdot
.914 .33246 Mdot
.914 .3326 Mdot
.914 .33271 Mdot
.914 .33331 Mdot
.914 .33379 Mdot
.914 .33388 Mdot
.914 .334 Mdot
.914 .33447 Mdot
.914 .33448 Mdot
.914 .33539 Mdot
.914 .33557 Mdot
.914 .33565 Mdot
.914 .3367 Mdot
.914 .33737 Mdot
.914 .33797 Mdot
.914 .33809 Mdot
.914 .33814 Mdot
.914 .33829 Mdot
.914 .34004 Mdot
.914 .34015 Mdot
.914 .34023 Mdot
.914 .34038 Mdot
.914 .3406 Mdot
.914 .34108 Mdot
.914 .34122 Mdot
.914 .34192 Mdot
.914 .34216 Mdot
.914 .34232 Mdot
.914 .34246 Mdot
.914 .34277 Mdot
.914 .34406 Mdot
.914 .34508 Mdot
.914 .34604 Mdot
.914 .34605 Mdot
.914 .34717 Mdot
.914 .34726 Mdot
.914 .34849 Mdot
.914 .34922 Mdot
.914 .35005 Mdot
.914 .35077 Mdot
.914 .35086 Mdot
.914 .35093 Mdot
.914 .35203 Mdot
.914 .35218 Mdot
.914 .35223 Mdot
.914 .35329 Mdot
.914 .35414 Mdot
.914 .35426 Mdot
.914 .35517 Mdot
.914 .35606 Mdot
.914 .35627 Mdot
.914 .35633 Mdot
.914 .35695 Mdot
.914 .35705 Mdot
.914 .3577 Mdot
.914 .35778 Mdot
.914 .35792 Mdot
.914 .35801 Mdot
.914 .35872 Mdot
.914 .3589 Mdot
.914 .36009 Mdot
.914 .3603 Mdot
.914 .36065 Mdot
.914 .36093 Mdot
.914 .36107 Mdot
.914 .36129 Mdot
.914 .36129 Mdot
.914 .36199 Mdot
.914 .36217 Mdot
.914 .36253 Mdot
.914 .36268 Mdot
.914 .36302 Mdot
.914 .36325 Mdot
.914 .36336 Mdot
.914 .36347 Mdot
.914 .36377 Mdot
.914 .36381 Mdot
.914 .36441 Mdot
.914 .36481 Mdot
.914 .36565 Mdot
.914 .3657 Mdot
.914 .36587 Mdot
.914 .3659 Mdot
.914 .36602 Mdot
.914 .36611 Mdot
.914 .36648 Mdot
.914 .36649 Mdot
.914 .36772 Mdot
.914 .36778 Mdot
.914 .36867 Mdot
.914 .36961 Mdot
.914 .36961 Mdot
.914 .36995 Mdot
.914 .3702 Mdot
.914 .37026 Mdot
.914 .37074 Mdot
.914 .37095 Mdot
.914 .37166 Mdot
.914 .37268 Mdot
.914 .37272 Mdot
.914 .37302 Mdot
.914 .37383 Mdot
.914 .37452 Mdot
.914 .37464 Mdot
.914 .37479 Mdot
.914 .37494 Mdot
.914 .37497 Mdot
.914 .37597 Mdot
.914 .3762 Mdot
.914 .3765 Mdot
.914 .37668 Mdot
.914 .3768 Mdot
.914 .3768 Mdot
.914 .37703 Mdot
.914 .37728 Mdot
.914 .37743 Mdot
.914 .37763 Mdot
.914 .3785 Mdot
.914 .37868 Mdot
.914 .3793 Mdot
.914 .37946 Mdot
.914 .38109 Mdot
.914 .3811 Mdot
.914 .38251 Mdot
.914 .38254 Mdot
.914 .38352 Mdot
.914 .38439 Mdot
.914 .3853 Mdot
.914 .38536 Mdot
.914 .38566 Mdot
.914 .38603 Mdot
.914 .38607 Mdot
.914 .38631 Mdot
.914 .38641 Mdot
.914 .38659 Mdot
.914 .38696 Mdot
.914 .38698 Mdot
.914 .38704 Mdot
.914 .38707 Mdot
.914 .38786 Mdot
.914 .38815 Mdot
.914 .38965 Mdot
.914 .3897 Mdot
.914 .39012 Mdot
.914 .39026 Mdot
.914 .39037 Mdot
.914 .39055 Mdot
.914 .39086 Mdot
.914 .39105 Mdot
.914 .39306 Mdot
.914 .39307 Mdot
.914 .39361 Mdot
.914 .39414 Mdot
.914 .39428 Mdot
.914 .39433 Mdot
.914 .39436 Mdot
.914 .39451 Mdot
.914 .39554 Mdot
.914 .397 Mdot
.914 .39701 Mdot
.914 .39741 Mdot
.914 .39891 Mdot
.914 .39908 Mdot
.914 .39918 Mdot
.914 .39924 Mdot
.914 .39931 Mdot
.914 .39955 Mdot
.914 .39957 Mdot
.914 .40039 Mdot
.914 .40055 Mdot
.914 .40153 Mdot
.914 .40155 Mdot
.914 .40176 Mdot
.914 .40523 Mdot
.914 .40557 Mdot
.914 .40615 Mdot
.914 .40626 Mdot
.914 .40634 Mdot
.914 .40647 Mdot
.914 .40667 Mdot
.914 .40676 Mdot
.914 .40693 Mdot
.914 .4076 Mdot
.914 .4077 Mdot
.914 .40778 Mdot
.914 .40883 Mdot
.914 .41021 Mdot
.914 .41035 Mdot
.914 .41053 Mdot
.914 .41105 Mdot
.914 .41157 Mdot
.914 .41245 Mdot
.914 .4125 Mdot
.914 .41256 Mdot
.914 .41258 Mdot
.914 .41267 Mdot
.914 .4127 Mdot
.914 .41316 Mdot
.914 .41338 Mdot
.914 .41371 Mdot
.914 .41373 Mdot
.914 .41389 Mdot
.914 .41414 Mdot
.914 .41432 Mdot
.914 .4144 Mdot
.914 .4146 Mdot
.914 .4147 Mdot
.914 .41509 Mdot
.914 .41528 Mdot
.914 .41543 Mdot
.914 .41562 Mdot
.914 .41574 Mdot
.914 .41649 Mdot
.914 .4174 Mdot
.914 .41783 Mdot
.914 .41795 Mdot
.914 .41843 Mdot
.914 .41893 Mdot
.914 .419 Mdot
.914 .42007 Mdot
.914 .42079 Mdot
.914 .42084 Mdot
.914 .42123 Mdot
.914 .42342 Mdot
.914 .42343 Mdot
.914 .42395 Mdot
.914 .42539 Mdot
.914 .42568 Mdot
.914 .4264 Mdot
.914 .42671 Mdot
.914 .42767 Mdot
.914 .42775 Mdot
.914 .42784 Mdot
.914 .42817 Mdot
.914 .42854 Mdot
.914 .42925 Mdot
.914 .42976 Mdot
.914 .43013 Mdot
.914 .43039 Mdot
.914 .43078 Mdot
.914 .43086 Mdot
.914 .43127 Mdot
.914 .43128 Mdot
.914 .43149 Mdot
.914 .43158 Mdot
.914 .43182 Mdot
.914 .43237 Mdot
.914 .43279 Mdot
.914 .43345 Mdot
.914 .43462 Mdot
.914 .43467 Mdot
.914 .43496 Mdot
.914 .43516 Mdot
.914 .43517 Mdot
.914 .43523 Mdot
.914 .43545 Mdot
.914 .43551 Mdot
.914 .4357 Mdot
.914 .43584 Mdot
.914 .4361 Mdot
.914 .43671 Mdot
.914 .43818 Mdot
.914 .43822 Mdot
.914 .43826 Mdot
.914 .43874 Mdot
.914 .43881 Mdot
.914 .43966 Mdot
.914 .44067 Mdot
.914 .44096 Mdot
.914 .4412 Mdot
.914 .44197 Mdot
.914 .44202 Mdot
.914 .44236 Mdot
.914 .44255 Mdot
.914 .44285 Mdot
.914 .44323 Mdot
.914 .44333 Mdot
.914 .44376 Mdot
.914 .44379 Mdot
.914 .44407 Mdot
.914 .44441 Mdot
.914 .44442 Mdot
.914 .44614 Mdot
.914 .44751 Mdot
.914 .44776 Mdot
.914 .44788 Mdot
.914 .44798 Mdot
.914 .45012 Mdot
.914 .45013 Mdot
.914 .45054 Mdot
.914 .45082 Mdot
.914 .45097 Mdot
.914 .4512 Mdot
.914 .45125 Mdot
.914 .45157 Mdot
.914 .45166 Mdot
.914 .45294 Mdot
.914 .45319 Mdot
.914 .45365 Mdot
.914 .45392 Mdot
.914 .45503 Mdot
.914 .45509 Mdot
.914 .4551 Mdot
.914 .45565 Mdot
.914 .45575 Mdot
.914 .45585 Mdot
.914 .45605 Mdot
.914 .45645 Mdot
.914 .45646 Mdot
.914 .45709 Mdot
.914 .45729 Mdot
.914 .45735 Mdot
.914 .45745 Mdot
.914 .45802 Mdot
.914 .45835 Mdot
.914 .45886 Mdot
.914 .45935 Mdot
.914 .45963 Mdot
.914 .45963 Mdot
.914 .46003 Mdot
.914 .46029 Mdot
.914 .46079 Mdot
.914 .46143 Mdot
.914 .46183 Mdot
.914 .46201 Mdot
.914 .46236 Mdot
.914 .46375 Mdot
.914 .46395 Mdot
.914 .464 Mdot
.914 .46433 Mdot
.914 .46563 Mdot
.914 .46578 Mdot
.914 .46581 Mdot
.914 .46605 Mdot
.914 .46618 Mdot
.914 .46689 Mdot
.914 .46737 Mdot
.914 .46744 Mdot
.914 .46756 Mdot
.914 .46776 Mdot
.914 .46862 Mdot
.914 .4687 Mdot
.914 .46878 Mdot
.914 .4688 Mdot
.914 .46884 Mdot
.914 .4691 Mdot
.914 .4692 Mdot
.914 .46936 Mdot
.914 .47082 Mdot
.914 .47176 Mdot
.914 .47219 Mdot
.914 .47223 Mdot
.914 .47248 Mdot
.914 .47269 Mdot
.914 .47289 Mdot
.914 .47332 Mdot
.914 .47354 Mdot
.914 .47425 Mdot
.914 .47502 Mdot
.914 .47516 Mdot
.914 .47619 Mdot
.914 .47628 Mdot
.914 .47655 Mdot
.914 .4768 Mdot
.914 .47712 Mdot
.914 .47751 Mdot
.914 .47793 Mdot
.914 .47794 Mdot
.914 .47857 Mdot
.914 .47869 Mdot
.914 .47875 Mdot
.914 .47885 Mdot
.914 .47886 Mdot
.914 .47937 Mdot
.914 .47993 Mdot
.914 .48017 Mdot
.914 .4811 Mdot
.914 .48169 Mdot
.914 .48302 Mdot
.914 .48371 Mdot
.914 .48386 Mdot
.914 .4848 Mdot
.914 .48498 Mdot
.914 .48501 Mdot
.914 .48527 Mdot
.914 .48544 Mdot
.914 .48561 Mdot
.914 .48565 Mdot
.914 .48592 Mdot
.914 .48673 Mdot
.914 .48735 Mdot
.914 .48748 Mdot
.914 .48751 Mdot
.914 .48926 Mdot
.914 .48951 Mdot
.914 .49028 Mdot
.914 .49071 Mdot
.914 .49102 Mdot
.914 .49113 Mdot
.914 .49145 Mdot
.914 .49206 Mdot
.914 .49325 Mdot
.914 .49326 Mdot
.914 .49339 Mdot
.914 .49348 Mdot
.914 .49378 Mdot
.914 .49405 Mdot
.914 .49431 Mdot
.914 .4946 Mdot
.914 .49503 Mdot
.914 .49504 Mdot
.914 .49514 Mdot
.914 .49552 Mdot
.914 .49632 Mdot
.914 .49632 Mdot
.914 .49657 Mdot
.914 .497 Mdot
.914 .49721 Mdot
.914 .49745 Mdot
.914 .49786 Mdot
.914 .49807 Mdot
.914 .49813 Mdot
.914 .49828 Mdot
.914 .49847 Mdot
.914 .49941 Mdot
.914 .49941 Mdot
.914 .50034 Mdot
.914 .50038 Mdot
.914 .50103 Mdot
.914 .50168 Mdot
.914 .50194 Mdot
.914 .50197 Mdot
.914 .50201 Mdot
.914 .50204 Mdot
.914 .50226 Mdot
.914 .50336 Mdot
.914 .50367 Mdot
.914 .50457 Mdot
.914 .50479 Mdot
.914 .5065 Mdot
.914 .50664 Mdot
.914 .50669 Mdot
.914 .50697 Mdot
.914 .50701 Mdot
.914 .50722 Mdot
.914 .5079 Mdot
.914 .50864 Mdot
.914 .50866 Mdot
.914 .50951 Mdot
.914 .50974 Mdot
.914 .50988 Mdot
.914 .50989 Mdot
.914 .50998 Mdot
.914 .51004 Mdot
.914 .51077 Mdot
.914 .51136 Mdot
.914 .51187 Mdot
.914 .51204 Mdot
.914 .51208 Mdot
.914 .51232 Mdot
.914 .51237 Mdot
.914 .51262 Mdot
.914 .51271 Mdot
.914 .51324 Mdot
.914 .5137 Mdot
.914 .51374 Mdot
.914 .51411 Mdot
.914 .51418 Mdot
.914 .51445 Mdot
.914 .51454 Mdot
.914 .51457 Mdot
.914 .51473 Mdot
.914 .51473 Mdot
.914 .51477 Mdot
.914 .51505 Mdot
.914 .51555 Mdot
.914 .51738 Mdot
.914 .51847 Mdot
.914 .5188 Mdot
.914 .51938 Mdot
.914 .51953 Mdot
.914 .52092 Mdot
.914 .521 Mdot
.914 .52111 Mdot
.914 .52178 Mdot
.914 .52317 Mdot
.914 .52361 Mdot
.914 .5249 Mdot
.914 .52506 Mdot
.914 .52517 Mdot
.914 .52572 Mdot
.914 .52583 Mdot
.914 .52603 Mdot
.914 .52605 Mdot
.914 .52625 Mdot
.914 .52634 Mdot
.914 .52634 Mdot
.914 .5267 Mdot
.914 .52675 Mdot
.914 .52695 Mdot
.914 .5273 Mdot
.914 .5274 Mdot
.914 .52754 Mdot
.914 .52759 Mdot
.914 .52769 Mdot
.914 .52787 Mdot
.914 .52833 Mdot
.914 .52852 Mdot
.914 .52885 Mdot
.914 .52898 Mdot
.914 .52903 Mdot
.914 .52932 Mdot
.914 .52979 Mdot
.914 .52986 Mdot
.914 .53083 Mdot
.914 .53113 Mdot
.914 .53117 Mdot
.914 .53139 Mdot
.914 .53189 Mdot
.914 .53464 Mdot
.914 .53486 Mdot
.914 .53574 Mdot
.914 .53681 Mdot
.914 .53693 Mdot
.914 .53706 Mdot
.914 .53745 Mdot
.914 .53768 Mdot
.914 .53832 Mdot
.914 .53866 Mdot
.914 .53868 Mdot
.914 .5389 Mdot
.914 .53908 Mdot
.914 .53929 Mdot
.914 .53991 Mdot
.914 .53993 Mdot
.914 .54036 Mdot
.914 .54132 Mdot
.914 .54175 Mdot
.914 .54203 Mdot
.914 .54254 Mdot
.914 .54274 Mdot
.914 .54374 Mdot
.914 .54374 Mdot
.914 .544 Mdot
.914 .54447 Mdot
.914 .54512 Mdot
.914 .54571 Mdot
.914 .54608 Mdot
.914 .54688 Mdot
.914 .54794 Mdot
.914 .54875 Mdot
.914 .54946 Mdot
.914 .54964 Mdot
.914 .55024 Mdot
.914 .55025 Mdot
.914 .55076 Mdot
.914 .55139 Mdot
.914 .5514 Mdot
.914 .55233 Mdot
.914 .55241 Mdot
.914 .55243 Mdot
.914 .55367 Mdot
.914 .55386 Mdot
.916 .10573 Mdot
.916 .10647 Mdot
.916 .10686 Mdot
.916 .10813 Mdot
.916 .10834 Mdot
.916 .1089 Mdot
.916 .10913 Mdot
.916 .10937 Mdot
.916 .1098 Mdot
.916 .10995 Mdot
.916 .10997 Mdot
.916 .11034 Mdot
.916 .11053 Mdot
.916 .1107 Mdot
.916 .11071 Mdot
.916 .11143 Mdot
.916 .11165 Mdot
.916 .11297 Mdot
.916 .11315 Mdot
.916 .11404 Mdot
.916 .11438 Mdot
.916 .11535 Mdot
.916 .11618 Mdot
.916 .11764 Mdot
.916 .11768 Mdot
.916 .11819 Mdot
.916 .11834 Mdot
.916 .11868 Mdot
.916 .11878 Mdot
.916 .11886 Mdot
.916 .12087 Mdot
.916 .12304 Mdot
.916 .12359 Mdot
.916 .12452 Mdot
.916 .12495 Mdot
.916 .12561 Mdot
.916 .12587 Mdot
.916 .12632 Mdot
.916 .12672 Mdot
.916 .12753 Mdot
.916 .12887 Mdot
.916 .12973 Mdot
.916 .13062 Mdot
.916 .1316 Mdot
.916 .13308 Mdot
.916 .13319 Mdot
.916 .13446 Mdot
.916 .13553 Mdot
.916 .13664 Mdot
.916 .13689 Mdot
.916 .13789 Mdot
.916 .13928 Mdot
.916 .13993 Mdot
.916 .14074 Mdot
.916 .1419 Mdot
.916 .14204 Mdot
.916 .14235 Mdot
.916 .14386 Mdot
.916 .14404 Mdot
.916 .14448 Mdot
.916 .14591 Mdot
.916 .14688 Mdot
.916 .14868 Mdot
.916 .14902 Mdot
.916 .15112 Mdot
.916 .15229 Mdot
.916 .15282 Mdot
.916 .15343 Mdot
.916 .15387 Mdot
.916 .15389 Mdot
.916 .15506 Mdot
.916 .15528 Mdot
.916 .15557 Mdot
.916 .15661 Mdot
.916 .159 Mdot
.916 .15901 Mdot
.916 .16184 Mdot
.916 .16237 Mdot
.916 .16477 Mdot
.916 .16703 Mdot
.916 .16767 Mdot
.916 .17013 Mdot
.916 .17149 Mdot
.916 .17165 Mdot
.916 .17235 Mdot
.916 .17288 Mdot
.916 .17323 Mdot
.916 .17434 Mdot
.916 .1751 Mdot
.916 .17551 Mdot
.916 .17557 Mdot
.916 .17628 Mdot
.916 .17643 Mdot
.916 .17645 Mdot
.916 .17655 Mdot
.916 .17658 Mdot
.916 .17787 Mdot
.916 .17867 Mdot
.916 .17889 Mdot
.916 .179 Mdot
.916 .17931 Mdot
.916 .17967 Mdot
.916 .18146 Mdot
.916 .18167 Mdot
.916 .182 Mdot
.916 .18275 Mdot
.916 .18281 Mdot
.916 .18315 Mdot
.916 .18343 Mdot
.916 .18353 Mdot
.916 .1836 Mdot
.916 .18489 Mdot
.916 .18537 Mdot
.916 .18574 Mdot
.916 .18584 Mdot
.916 .18624 Mdot
.916 .18649 Mdot
.916 .18675 Mdot
.916 .18727 Mdot
.916 .18767 Mdot
.916 .18768 Mdot
.916 .18812 Mdot
.916 .18817 Mdot
.916 .1884 Mdot
.916 .18843 Mdot
.916 .18864 Mdot
.916 .1889 Mdot
.916 .18894 Mdot
.916 .18918 Mdot
.916 .18922 Mdot
.916 .18979 Mdot
.916 .1899 Mdot
.916 .19024 Mdot
.916 .19055 Mdot
.916 .19058 Mdot
.916 .19094 Mdot
.916 .1919 Mdot
.916 .19197 Mdot
.916 .1923 Mdot
.916 .19259 Mdot
.916 .1926 Mdot
.916 .19472 Mdot
.916 .19472 Mdot
.916 .19494 Mdot
.916 .19496 Mdot
.916 .19506 Mdot
.916 .19552 Mdot
.916 .19567 Mdot
.916 .19578 Mdot
.916 .19616 Mdot
.916 .19663 Mdot
.916 .19669 Mdot
.916 .19683 Mdot
.916 .19731 Mdot
.916 .19904 Mdot
.916 .19909 Mdot
.916 .19957 Mdot
.916 .20009 Mdot
.916 .2006 Mdot
.916 .20111 Mdot
.916 .20164 Mdot
.916 .20328 Mdot
.916 .20335 Mdot
.916 .20377 Mdot
.916 .20414 Mdot
.916 .20428 Mdot
.916 .20455 Mdot
.916 .20457 Mdot
.916 .20491 Mdot
.916 .20518 Mdot
.916 .20535 Mdot
.916 .20536 Mdot
.916 .20551 Mdot
.916 .20651 Mdot
.916 .20737 Mdot
.916 .20749 Mdot
.916 .20833 Mdot
.916 .20835 Mdot
.916 .20918 Mdot
.916 .20919 Mdot
.916 .20923 Mdot
.916 .20924 Mdot
.916 .21228 Mdot
.916 .21268 Mdot
.916 .21283 Mdot
.916 .21316 Mdot
.916 .21331 Mdot
.916 .21417 Mdot
.916 .21588 Mdot
.916 .21666 Mdot
.916 .21762 Mdot
.916 .21788 Mdot
.916 .21812 Mdot
.916 .21835 Mdot
.916 .21864 Mdot
.916 .21917 Mdot
.916 .21991 Mdot
.916 .22087 Mdot
.916 .2214 Mdot
.916 .22182 Mdot
.916 .22225 Mdot
.916 .22227 Mdot
.916 .2223 Mdot
.916 .22297 Mdot
.916 .22304 Mdot
.916 .22362 Mdot
.916 .22373 Mdot
.916 .22384 Mdot
.916 .22428 Mdot
.916 .22432 Mdot
.916 .22542 Mdot
.916 .22549 Mdot
.916 .22607 Mdot
.916 .22689 Mdot
.916 .22705 Mdot
.916 .22716 Mdot
.916 .22813 Mdot
.916 .22879 Mdot
.916 .22885 Mdot
.916 .22945 Mdot
.916 .22971 Mdot
.916 .23108 Mdot
.916 .23123 Mdot
.916 .23155 Mdot
.916 .23176 Mdot
.916 .23223 Mdot
.916 .23257 Mdot
.916 .2326 Mdot
.916 .23334 Mdot
.916 .23401 Mdot
.916 .23408 Mdot
.916 .23435 Mdot
.916 .23525 Mdot
.916 .23605 Mdot
.916 .23808 Mdot
.916 .23815 Mdot
.916 .23831 Mdot
.916 .23853 Mdot
.916 .23881 Mdot
.916 .23965 Mdot
.916 .2398 Mdot
.916 .23989 Mdot
.916 .24037 Mdot
.916 .24051 Mdot
.916 .24177 Mdot
.916 .24255 Mdot
.916 .24264 Mdot
.916 .24292 Mdot
.916 .24411 Mdot
.916 .2447 Mdot
.916 .24559 Mdot
.916 .24629 Mdot
.916 .2464 Mdot
.916 .24772 Mdot
.916 .24798 Mdot
.916 .24819 Mdot
.916 .24853 Mdot
.916 .24862 Mdot
.916 .24884 Mdot
.916 .24911 Mdot
.916 .24964 Mdot
.916 .2498 Mdot
.916 .25074 Mdot
.916 .2513 Mdot
.916 .25164 Mdot
.916 .25209 Mdot
.916 .25244 Mdot
.916 .25507 Mdot
.916 .25528 Mdot
.916 .25622 Mdot
.916 .25626 Mdot
.916 .2568 Mdot
.916 .25685 Mdot
.916 .25838 Mdot
.916 .25881 Mdot
.916 .26014 Mdot
.916 .26077 Mdot
.916 .26152 Mdot
.916 .26462 Mdot
.916 .26478 Mdot
.916 .26479 Mdot
.916 .26675 Mdot
.916 .26718 Mdot
.916 .26772 Mdot
.916 .26884 Mdot
.916 .26886 Mdot
.916 .2691 Mdot
.916 .26966 Mdot
.916 .26968 Mdot
.916 .26973 Mdot
.916 .27183 Mdot
.916 .27184 Mdot
.916 .27194 Mdot
.916 .27224 Mdot
.916 .27269 Mdot
.916 .27277 Mdot
.916 .27467 Mdot
.916 .2749 Mdot
.916 .27532 Mdot
.916 .27629 Mdot
.916 .27772 Mdot
.916 .27788 Mdot
.916 .27905 Mdot
.916 .27906 Mdot
.916 .28018 Mdot
.916 .28031 Mdot
.916 .28105 Mdot
.916 .28151 Mdot
.916 .28269 Mdot
.916 .2828 Mdot
.916 .28288 Mdot
.916 .28304 Mdot
.916 .28305 Mdot
.916 .28424 Mdot
.916 .28458 Mdot
.916 .28483 Mdot
.916 .28492 Mdot
.916 .285 Mdot
.916 .28522 Mdot
.916 .28656 Mdot
.916 .2876 Mdot
.916 .2877 Mdot
.916 .28813 Mdot
.916 .28856 Mdot
.916 .28861 Mdot
.916 .28884 Mdot
.916 .28896 Mdot
.916 .28962 Mdot
.916 .29004 Mdot
.916 .29275 Mdot
.916 .29375 Mdot
.916 .29447 Mdot
.916 .29478 Mdot
.916 .29486 Mdot
.916 .29493 Mdot
.916 .29766 Mdot
.916 .29808 Mdot
.916 .29885 Mdot
.916 .29944 Mdot
.916 .29963 Mdot
.916 .30005 Mdot
.916 .30035 Mdot
.916 .30042 Mdot
.916 .30075 Mdot
.916 .30148 Mdot
.916 .30192 Mdot
.916 .30221 Mdot
.916 .30338 Mdot
.916 .30349 Mdot
.916 .30363 Mdot
.916 .30403 Mdot
.916 .30447 Mdot
.916 .30512 Mdot
.916 .30572 Mdot
.916 .30574 Mdot
.916 .30592 Mdot
.916 .30607 Mdot
.916 .30608 Mdot
.916 .30652 Mdot
.916 .30705 Mdot
.916 .30715 Mdot
.916 .30837 Mdot
.916 .30854 Mdot
.916 .30885 Mdot
.916 .30929 Mdot
.916 .30941 Mdot
.916 .30977 Mdot
.916 .31048 Mdot
.916 .31071 Mdot
.916 .31078 Mdot
.916 .31098 Mdot
.916 .31102 Mdot
.916 .31114 Mdot
.916 .31119 Mdot
.916 .31124 Mdot
.916 .31125 Mdot
.916 .31146 Mdot
.916 .31153 Mdot
.916 .31192 Mdot
.916 .31198 Mdot
.916 .31263 Mdot
.916 .31352 Mdot
.916 .31362 Mdot
.916 .31508 Mdot
.916 .31549 Mdot
.916 .31569 Mdot
.916 .31626 Mdot
.916 .31666 Mdot
.916 .31692 Mdot
.916 .31795 Mdot
.916 .31832 Mdot
.916 .32019 Mdot
.916 .32058 Mdot
.916 .32067 Mdot
.916 .32112 Mdot
.916 .32118 Mdot
.916 .32203 Mdot
.916 .32256 Mdot
.916 .32266 Mdot
.916 .32329 Mdot
.916 .32364 Mdot
.916 .32379 Mdot
.916 .32398 Mdot
.916 .32411 Mdot
.916 .32411 Mdot
.916 .32564 Mdot
.916 .32648 Mdot
.916 .32736 Mdot
.916 .32803 Mdot
.916 .32822 Mdot
.916 .32895 Mdot
.916 .3294 Mdot
.916 .32961 Mdot
.916 .32988 Mdot
.916 .33021 Mdot
.916 .33057 Mdot
.916 .33084 Mdot
.916 .33086 Mdot
.916 .33087 Mdot
.916 .3315 Mdot
.916 .33156 Mdot
.916 .3316 Mdot
.916 .33239 Mdot
.916 .33249 Mdot
.916 .33271 Mdot
.916 .33291 Mdot
.916 .33297 Mdot
.916 .33335 Mdot
.916 .33349 Mdot
.916 .3336 Mdot
.916 .33383 Mdot
.916 .3339 Mdot
.916 .33433 Mdot
.916 .33441 Mdot
.916 .33546 Mdot
.916 .33564 Mdot
.916 .33565 Mdot
.916 .33628 Mdot
.916 .33656 Mdot
.916 .33685 Mdot
.916 .33691 Mdot
.916 .33757 Mdot
.916 .33772 Mdot
.916 .33818 Mdot
.916 .33897 Mdot
.916 .33932 Mdot
.916 .33945 Mdot
.916 .33979 Mdot
.916 .34005 Mdot
.916 .34008 Mdot
.916 .34059 Mdot
.916 .3406 Mdot
.916 .3406 Mdot
.916 .34163 Mdot
.916 .34182 Mdot
.916 .34325 Mdot
.916 .34341 Mdot
.916 .34435 Mdot
.916 .34448 Mdot
.916 .34449 Mdot
.916 .34489 Mdot
.916 .34492 Mdot
.916 .34509 Mdot
.916 .3451 Mdot
.916 .34545 Mdot
.916 .34562 Mdot
.916 .34586 Mdot
.916 .34594 Mdot
.916 .34623 Mdot
.916 .34643 Mdot
.916 .34711 Mdot
.916 .34779 Mdot
.916 .34799 Mdot
.916 .34809 Mdot
.916 .34835 Mdot
.916 .34922 Mdot
.916 .34927 Mdot
.916 .34942 Mdot
.916 .34992 Mdot
.916 .35117 Mdot
.916 .35164 Mdot
.916 .35234 Mdot
.916 .3524 Mdot
.916 .35248 Mdot
.916 .35269 Mdot
.916 .35297 Mdot
.916 .35337 Mdot
.916 .35432 Mdot
.916 .35525 Mdot
.916 .35537 Mdot
.916 .35618 Mdot
.916 .35715 Mdot
.916 .35716 Mdot
.916 .35837 Mdot
.916 .35844 Mdot
.916 .35929 Mdot
.916 .35951 Mdot
.916 .36017 Mdot
.916 .36029 Mdot
.916 .36106 Mdot
.916 .36174 Mdot
.916 .36178 Mdot
.916 .362 Mdot
.916 .36214 Mdot
.916 .36249 Mdot
.916 .36252 Mdot
.916 .3626 Mdot
.916 .36305 Mdot
.916 .36316 Mdot
.916 .36364 Mdot
.916 .36395 Mdot
.916 .36398 Mdot
.916 .36424 Mdot
.916 .36425 Mdot
.916 .36436 Mdot
.916 .36468 Mdot
.916 .36549 Mdot
.916 .366 Mdot
.916 .36609 Mdot
.916 .36612 Mdot
.916 .36708 Mdot
.916 .36754 Mdot
.916 .36766 Mdot
.916 .36777 Mdot
.916 .36787 Mdot
.916 .36873 Mdot
.916 .36885 Mdot
.916 .36935 Mdot
.916 .36936 Mdot
.916 .36941 Mdot
.916 .36946 Mdot
.916 .36946 Mdot
.916 .37014 Mdot
.916 .37097 Mdot
.916 .371 Mdot
.916 .37106 Mdot
.916 .37108 Mdot
.916 .37122 Mdot
.916 .37261 Mdot
.916 .37394 Mdot
.916 .37421 Mdot
.916 .37483 Mdot
.916 .37665 Mdot
.916 .37684 Mdot
.916 .37703 Mdot
.916 .37739 Mdot
.916 .37766 Mdot
.916 .37827 Mdot
.916 .37854 Mdot
.916 .37926 Mdot
.916 .38005 Mdot
.916 .38011 Mdot
.916 .38053 Mdot
.916 .38119 Mdot
.916 .38189 Mdot
.916 .38233 Mdot
.916 .38237 Mdot
.916 .38252 Mdot
.916 .38289 Mdot
.916 .38303 Mdot
.916 .38324 Mdot
.916 .38343 Mdot
.916 .38468 Mdot
.916 .38506 Mdot
.916 .38616 Mdot
.916 .3863 Mdot
.916 .38643 Mdot
.916 .38692 Mdot
.916 .38731 Mdot
.916 .38735 Mdot
.916 .38777 Mdot
.916 .38813 Mdot
.916 .38831 Mdot
.916 .38834 Mdot
.916 .38855 Mdot
.916 .38887 Mdot
.916 .38928 Mdot
.916 .38976 Mdot
.916 .39062 Mdot
.916 .3915 Mdot
.916 .39164 Mdot
.916 .39184 Mdot
.916 .39205 Mdot
.916 .39218 Mdot
.916 .39219 Mdot
.916 .39239 Mdot
.916 .39299 Mdot
.916 .39336 Mdot
.916 .39366 Mdot
.916 .39403 Mdot
.916 .39413 Mdot
.916 .39439 Mdot
.916 .39491 Mdot
.916 .39495 Mdot
.916 .39501 Mdot
.916 .39511 Mdot
.916 .39535 Mdot
.916 .39599 Mdot
.916 .39606 Mdot
.916 .39625 Mdot
.916 .39627 Mdot
.916 .39633 Mdot
.916 .39637 Mdot
.916 .39641 Mdot
.916 .39652 Mdot
.916 .39656 Mdot
.916 .39691 Mdot
.916 .39704 Mdot
.916 .39743 Mdot
.916 .39763 Mdot
.916 .39783 Mdot
.916 .3982 Mdot
.916 .39863 Mdot
.916 .39864 Mdot
.916 .39871 Mdot
.916 .39882 Mdot
.916 .39893 Mdot
.916 .39901 Mdot
.916 .39996 Mdot
.916 .40045 Mdot
.916 .40062 Mdot
.916 .40073 Mdot
.916 .40085 Mdot
.916 .4013 Mdot
.916 .40185 Mdot
.916 .40192 Mdot
.916 .40252 Mdot
.916 .40341 Mdot
.916 .40363 Mdot
.916 .40371 Mdot
.916 .40391 Mdot
.916 .40399 Mdot
.916 .40402 Mdot
.916 .40426 Mdot
.916 .40464 Mdot
.916 .40499 Mdot
.916 .40526 Mdot
.916 .40569 Mdot
.916 .40686 Mdot
.916 .40691 Mdot
.916 .40701 Mdot
.916 .40811 Mdot
.916 .40845 Mdot
.916 .40859 Mdot
.916 .40932 Mdot
.916 .41008 Mdot
.916 .41067 Mdot
.916 .41104 Mdot
.916 .4111 Mdot
.916 .4111 Mdot
.916 .41137 Mdot
.916 .41144 Mdot
.916 .41196 Mdot
.916 .41209 Mdot
.916 .41234 Mdot
.916 .41286 Mdot
.916 .41293 Mdot
.916 .41321 Mdot
.916 .41365 Mdot
.916 .41382 Mdot
.916 .41389 Mdot
.916 .41454 Mdot
.916 .41479 Mdot
.916 .41504 Mdot
.916 .41523 Mdot
.916 .41647 Mdot
.916 .41659 Mdot
.916 .41706 Mdot
.916 .41709 Mdot
.916 .41776 Mdot
.916 .41873 Mdot
.916 .42004 Mdot
.916 .42019 Mdot
.916 .42038 Mdot
.916 .42077 Mdot
.916 .42102 Mdot
.916 .42171 Mdot
.916 .42198 Mdot
.916 .42206 Mdot
.916 .42287 Mdot
.916 .42392 Mdot
.916 .42405 Mdot
.916 .42415 Mdot
.916 .42434 Mdot
.916 .42474 Mdot
.916 .42526 Mdot
.916 .42535 Mdot
.916 .42613 Mdot
.916 .42623 Mdot
.916 .42679 Mdot
.916 .42708 Mdot
.916 .42723 Mdot
.916 .42768 Mdot
.916 .42811 Mdot
.916 .42836 Mdot
.916 .429 Mdot
.916 .4295 Mdot
.916 .43061 Mdot
.916 .43067 Mdot
.916 .4311 Mdot
.916 .43176 Mdot
.916 .4321 Mdot
.916 .43211 Mdot
.916 .43227 Mdot
.916 .43247 Mdot
.916 .43279 Mdot
.916 .43496 Mdot
.916 .43579 Mdot
.916 .43605 Mdot
.916 .43693 Mdot
.916 .43742 Mdot
.916 .43767 Mdot
.916 .43895 Mdot
.916 .43916 Mdot
.916 .43986 Mdot
.916 .44157 Mdot
.916 .44206 Mdot
.916 .44242 Mdot
.916 .44245 Mdot
.916 .44266 Mdot
.916 .4427 Mdot
.916 .44282 Mdot
.916 .44288 Mdot
.916 .44307 Mdot
.916 .44324 Mdot
.916 .44362 Mdot
.916 .44412 Mdot
.916 .44439 Mdot
.916 .44511 Mdot
.916 .4454 Mdot
.916 .44564 Mdot
.916 .44564 Mdot
.916 .44573 Mdot
.916 .44582 Mdot
.916 .44583 Mdot
.916 .44675 Mdot
.916 .44697 Mdot
.916 .44711 Mdot
.916 .44815 Mdot
.916 .44855 Mdot
.916 .44873 Mdot
.916 .44877 Mdot
.916 .44893 Mdot
.916 .44916 Mdot
.916 .44958 Mdot
.916 .45 Mdot
.916 .45023 Mdot
.916 .45176 Mdot
.916 .45181 Mdot
.916 .45197 Mdot
.916 .45291 Mdot
.916 .45439 Mdot
.916 .45498 Mdot
.916 .45505 Mdot
.916 .45517 Mdot
.916 .4552 Mdot
.916 .45543 Mdot
.916 .45567 Mdot
.916 .45572 Mdot
.916 .45629 Mdot
.916 .45714 Mdot
.916 .45718 Mdot
.916 .45723 Mdot
.916 .45737 Mdot
.916 .45821 Mdot
.916 .45821 Mdot
.916 .4583 Mdot
.916 .45834 Mdot
.916 .45841 Mdot
.916 .45905 Mdot
.916 .4593 Mdot
.916 .4597 Mdot
.916 .45977 Mdot
.916 .46103 Mdot
.916 .46112 Mdot
.916 .4619 Mdot
.916 .46242 Mdot
.916 .46266 Mdot
.916 .46386 Mdot
.916 .46427 Mdot
.916 .46433 Mdot
.916 .46548 Mdot
.916 .46582 Mdot
.916 .46595 Mdot
.916 .46687 Mdot
.916 .46817 Mdot
.916 .46818 Mdot
.916 .46996 Mdot
.916 .47144 Mdot
.916 .47167 Mdot
.916 .47254 Mdot
.916 .47283 Mdot
.916 .47285 Mdot
.916 .47336 Mdot
.916 .47511 Mdot
.916 .47584 Mdot
.916 .47635 Mdot
.916 .47644 Mdot
.916 .47673 Mdot
.916 .47688 Mdot
.916 .477 Mdot
.916 .47723 Mdot
.916 .47821 Mdot
.916 .47827 Mdot
.916 .47914 Mdot
.916 .48027 Mdot
.916 .48032 Mdot
.916 .48074 Mdot
.916 .48143 Mdot
.916 .48177 Mdot
.916 .48181 Mdot
.916 .4819 Mdot
.916 .48235 Mdot
.916 .48263 Mdot
.916 .48271 Mdot
.916 .4843 Mdot
.916 .48479 Mdot
.916 .48497 Mdot
.916 .48534 Mdot
.916 .48574 Mdot
.916 .48576 Mdot
.916 .48595 Mdot
.916 .48649 Mdot
.916 .48657 Mdot
.916 .48732 Mdot
.916 .48747 Mdot
.916 .48782 Mdot
.916 .48819 Mdot
.916 .48872 Mdot
.916 .48886 Mdot
.916 .48931 Mdot
.916 .48963 Mdot
.916 .49026 Mdot
.916 .49029 Mdot
.916 .49059 Mdot
.916 .49065 Mdot
.916 .49096 Mdot
.916 .491 Mdot
.916 .49137 Mdot
.916 .49138 Mdot
.916 .4914 Mdot
.916 .49163 Mdot
.916 .49215 Mdot
.916 .49336 Mdot
.916 .49365 Mdot
.916 .49392 Mdot
.916 .49627 Mdot
.916 .49654 Mdot
.916 .49662 Mdot
.916 .49684 Mdot
.916 .4985 Mdot
.916 .4985 Mdot
.916 .49853 Mdot
.916 .49898 Mdot
.916 .49899 Mdot
.916 .49945 Mdot
.916 .49952 Mdot
.916 .49998 Mdot
.916 .50062 Mdot
.916 .50086 Mdot
.916 .50105 Mdot
.916 .50128 Mdot
.916 .50148 Mdot
.916 .50265 Mdot
.916 .50294 Mdot
.916 .50349 Mdot
.916 .50377 Mdot
.916 .50406 Mdot
.916 .50527 Mdot
.916 .50538 Mdot
.916 .50564 Mdot
.916 .50584 Mdot
.916 .5059 Mdot
.916 .50599 Mdot
.916 .50629 Mdot
.916 .5063 Mdot
.916 .50642 Mdot
.916 .50758 Mdot
.916 .50758 Mdot
.916 .50792 Mdot
.916 .50848 Mdot
.916 .50911 Mdot
.916 .50957 Mdot
.916 .50974 Mdot
.916 .50985 Mdot
.916 .50987 Mdot
.916 .51 Mdot
.916 .51027 Mdot
.916 .51077 Mdot
.916 .51091 Mdot
.916 .51132 Mdot
.916 .51153 Mdot
.916 .51179 Mdot
.916 .51249 Mdot
.916 .51259 Mdot
.916 .51274 Mdot
.916 .51295 Mdot
.916 .51337 Mdot
.916 .51354 Mdot
.916 .51464 Mdot
.916 .51483 Mdot
.916 .515 Mdot
.916 .51506 Mdot
.916 .51518 Mdot
.916 .51562 Mdot
.916 .51632 Mdot
.916 .51634 Mdot
.916 .51639 Mdot
.916 .51641 Mdot
.916 .51648 Mdot
.916 .51687 Mdot
.916 .51691 Mdot
.916 .51713 Mdot
.916 .51755 Mdot
.916 .51815 Mdot
.916 .51834 Mdot
.916 .51863 Mdot
.916 .51902 Mdot
.916 .5191 Mdot
.916 .51984 Mdot
.916 .52119 Mdot
.916 .52154 Mdot
.916 .52277 Mdot
.916 .52408 Mdot
.916 .52437 Mdot
.916 .52592 Mdot
.916 .52592 Mdot
.916 .52722 Mdot
.916 .52779 Mdot
.916 .52795 Mdot
.916 .52807 Mdot
.916 .52871 Mdot
.916 .52872 Mdot
.916 .52896 Mdot
.916 .5293 Mdot
.916 .52958 Mdot
.916 .53022 Mdot
.916 .53137 Mdot
.916 .53155 Mdot
.916 .53253 Mdot
.916 .53306 Mdot
.916 .53385 Mdot
.916 .53408 Mdot
.916 .53419 Mdot
.916 .53501 Mdot
.916 .53518 Mdot
.916 .53525 Mdot
.916 .53589 Mdot
.916 .53633 Mdot
.916 .53668 Mdot
.916 .53744 Mdot
.916 .53799 Mdot
.916 .53813 Mdot
.916 .53873 Mdot
.916 .53932 Mdot
.916 .54001 Mdot
.916 .54007 Mdot
.916 .54088 Mdot
.916 .54141 Mdot
.916 .5419 Mdot
.916 .54237 Mdot
.916 .5431 Mdot
.916 .54354 Mdot
.916 .54376 Mdot
.916 .544 Mdot
.916 .54414 Mdot
.916 .54451 Mdot
.916 .54474 Mdot
.916 .54525 Mdot
.916 .54555 Mdot
.916 .54673 Mdot
.916 .54783 Mdot
.916 .54787 Mdot
.916 .54793 Mdot
.916 .54812 Mdot
.916 .5482 Mdot
.916 .54847 Mdot
.916 .54849 Mdot
.916 .54929 Mdot
.916 .54974 Mdot
.916 .55027 Mdot
.916 .55046 Mdot
.916 .55094 Mdot
.916 .55104 Mdot
.916 .55177 Mdot
.916 .55189 Mdot
.916 .55228 Mdot
.916 .55229 Mdot
.916 .55238 Mdot
.916 .55248 Mdot
.916 .55268 Mdot
.916 .5527 Mdot
.916 .55278 Mdot
.916 .55301 Mdot
.916 .55314 Mdot
.916 .55326 Mdot
.916 .55357 Mdot
.916 .55369 Mdot
.916 .55438 Mdot
.916 .55459 Mdot
.916 .555 Mdot
.918 .10443 Mdot
.918 .10602 Mdot
.918 .10839 Mdot
.918 .10892 Mdot
.918 .10918 Mdot
.918 .10953 Mdot
.918 .11201 Mdot
.918 .11248 Mdot
.918 .11289 Mdot
.918 .11358 Mdot
.918 .11408 Mdot
.918 .11418 Mdot
.918 .11425 Mdot
.918 .11473 Mdot
.918 .11706 Mdot
.918 .11804 Mdot
.918 .1183 Mdot
.918 .11936 Mdot
.918 .12121 Mdot
.918 .12186 Mdot
.918 .12331 Mdot
.918 .12414 Mdot
.918 .12514 Mdot
.918 .12824 Mdot
.918 .12832 Mdot
.918 .12862 Mdot
.918 .12923 Mdot
.918 .13009 Mdot
.918 .1303 Mdot
.918 .13177 Mdot
.918 .13313 Mdot
.918 .13435 Mdot
.918 .13456 Mdot
.918 .13461 Mdot
.918 .13593 Mdot
.918 .13606 Mdot
.918 .13636 Mdot
.918 .13671 Mdot
.918 .13689 Mdot
.918 .13796 Mdot
.918 .139 Mdot
.918 .13952 Mdot
.918 .13977 Mdot
.918 .14058 Mdot
.918 .14122 Mdot
.918 .14219 Mdot
.918 .14335 Mdot
.918 .14418 Mdot
.918 .14518 Mdot
.918 .14596 Mdot
.918 .14632 Mdot
.918 .14665 Mdot
.918 .14713 Mdot
.918 .14756 Mdot
.918 .14757 Mdot
.918 .14769 Mdot
.918 .148 Mdot
.918 .14896 Mdot
.918 .14898 Mdot
.918 .14965 Mdot
.918 .15099 Mdot
.918 .15133 Mdot
.918 .15148 Mdot
.918 .15211 Mdot
.918 .15246 Mdot
.918 .15334 Mdot
.918 .15663 Mdot
.918 .15694 Mdot
.918 .15737 Mdot
.918 .15868 Mdot
.918 .16083 Mdot
.918 .16087 Mdot
.918 .1616 Mdot
.918 .16481 Mdot
.918 .16733 Mdot
.918 .16753 Mdot
.918 .16771 Mdot
.918 .16793 Mdot
.918 .16853 Mdot
.918 .16895 Mdot
.918 .16953 Mdot
.918 .1704 Mdot
.918 .17082 Mdot
.918 .17299 Mdot
.918 .17366 Mdot
.918 .17393 Mdot
.918 .17441 Mdot
.918 .17451 Mdot
.918 .17943 Mdot
.918 .17967 Mdot
.918 .18111 Mdot
.918 .18195 Mdot
.918 .18229 Mdot
.918 .18235 Mdot
.918 .18257 Mdot
.918 .18272 Mdot
.918 .18464 Mdot
.918 .18578 Mdot
.918 .1866 Mdot
.918 .18671 Mdot
.918 .18685 Mdot
.918 .18768 Mdot
.918 .18791 Mdot
.918 .18805 Mdot
.918 .18815 Mdot
.918 .1888 Mdot
.918 .18884 Mdot
.918 .18901 Mdot
.918 .18919 Mdot
.918 .19229 Mdot
.918 .19282 Mdot
.918 .19332 Mdot
.918 .19335 Mdot
.918 .19338 Mdot
.918 .19359 Mdot
.918 .19422 Mdot
.918 .19496 Mdot
.918 .19596 Mdot
.918 .19623 Mdot
.918 .19627 Mdot
.918 .19715 Mdot
.918 .19733 Mdot
.918 .19745 Mdot
.918 .19835 Mdot
.918 .19893 Mdot
.918 .1991 Mdot
.918 .20119 Mdot
.918 .20155 Mdot
.918 .20262 Mdot
.918 .20277 Mdot
.918 .20441 Mdot
.918 .2049 Mdot
.918 .20684 Mdot
.918 .20692 Mdot
.918 .2075 Mdot
.918 .20819 Mdot
.918 .20865 Mdot
.918 .20917 Mdot
.918 .20945 Mdot
.918 .21024 Mdot
.918 .21026 Mdot
.918 .21144 Mdot
.918 .21147 Mdot
.918 .21163 Mdot
.918 .21207 Mdot
.918 .2141 Mdot
.918 .21442 Mdot
.918 .21456 Mdot
.918 .21473 Mdot
.918 .21491 Mdot
.918 .21502 Mdot
.918 .21544 Mdot
.918 .21558 Mdot
.918 .21562 Mdot
.918 .21621 Mdot
.918 .21639 Mdot
.918 .2164 Mdot
.918 .21663 Mdot
.918 .21745 Mdot
.918 .21767 Mdot
.918 .21781 Mdot
.918 .21813 Mdot
.918 .21821 Mdot
.918 .21958 Mdot
.918 .21998 Mdot
.918 .22013 Mdot
.918 .22083 Mdot
.918 .22232 Mdot
.918 .22273 Mdot
.918 .22286 Mdot
.918 .22314 Mdot
.918 .22315 Mdot
.918 .22329 Mdot
.918 .22332 Mdot
.918 .22384 Mdot
.918 .22472 Mdot
.918 .22497 Mdot
.918 .22588 Mdot
.918 .22596 Mdot
.918 .22609 Mdot
.918 .22655 Mdot
.918 .22687 Mdot
.918 .22694 Mdot
.918 .22717 Mdot
.918 .22729 Mdot
.918 .22899 Mdot
.918 .2295 Mdot
.918 .22962 Mdot
.918 .23011 Mdot
.918 .23091 Mdot
.918 .23153 Mdot
.918 .23212 Mdot
.918 .2326 Mdot
.918 .23281 Mdot
.918 .23318 Mdot
.918 .23323 Mdot
.918 .23437 Mdot
.918 .23475 Mdot
.918 .23485 Mdot
.918 .23552 Mdot
.918 .23563 Mdot
.918 .23594 Mdot
.918 .23727 Mdot
.918 .2375 Mdot
.918 .23805 Mdot
.918 .23829 Mdot
.918 .23858 Mdot
.918 .23861 Mdot
.918 .23869 Mdot
.918 .23902 Mdot
.918 .23929 Mdot
.918 .23939 Mdot
.918 .23991 Mdot
.918 .24014 Mdot
.918 .24038 Mdot
.918 .241 Mdot
.918 .24265 Mdot
.918 .24291 Mdot
.918 .24386 Mdot
.918 .24423 Mdot
.918 .24432 Mdot
.918 .24537 Mdot
.918 .24568 Mdot
.918 .2458 Mdot
.918 .24664 Mdot
.918 .24698 Mdot
.918 .24726 Mdot
.918 .24735 Mdot
.918 .24755 Mdot
.918 .24771 Mdot
.918 .24811 Mdot
.918 .24876 Mdot
.918 .24928 Mdot
.918 .25015 Mdot
.918 .25035 Mdot
.918 .25071 Mdot
.918 .25089 Mdot
.918 .25146 Mdot
.918 .25147 Mdot
.918 .25241 Mdot
.918 .25241 Mdot
.918 .25242 Mdot
.918 .25274 Mdot
.918 .25419 Mdot
.918 .25426 Mdot
.918 .25446 Mdot
.918 .25568 Mdot
.918 .25578 Mdot
.918 .25635 Mdot
.918 .25644 Mdot
.918 .25695 Mdot
.918 .25713 Mdot
.918 .25783 Mdot
.918 .2583 Mdot
.918 .25862 Mdot
.918 .25863 Mdot
.918 .25886 Mdot
.918 .25908 Mdot
.918 .25943 Mdot
.918 .25995 Mdot
.918 .26016 Mdot
.918 .26042 Mdot
.918 .26048 Mdot
.918 .26119 Mdot
.918 .26123 Mdot
.918 .26167 Mdot
.918 .26234 Mdot
.918 .26245 Mdot
.918 .26279 Mdot
.918 .26315 Mdot
.918 .2633 Mdot
.918 .26379 Mdot
.918 .26413 Mdot
.918 .26434 Mdot
.918 .26453 Mdot
.918 .26492 Mdot
.918 .26543 Mdot
.918 .26553 Mdot
.918 .26553 Mdot
.918 .26581 Mdot
.918 .26692 Mdot
.918 .26697 Mdot
.918 .26706 Mdot
.918 .26762 Mdot
.918 .26843 Mdot
.918 .2691 Mdot
.918 .26924 Mdot
.918 .26942 Mdot
.918 .26963 Mdot
.918 .27051 Mdot
.918 .27124 Mdot
.918 .27215 Mdot
.918 .27298 Mdot
.918 .27302 Mdot
.918 .27334 Mdot
.918 .27416 Mdot
.918 .2749 Mdot
.918 .27527 Mdot
.918 .27568 Mdot
.918 .2757 Mdot
.918 .27584 Mdot
.918 .27646 Mdot
.918 .27662 Mdot
.918 .2768 Mdot
.918 .2775 Mdot
.918 .27803 Mdot
.918 .27836 Mdot
.918 .27903 Mdot
.918 .28073 Mdot
.918 .28135 Mdot
.918 .28228 Mdot
.918 .28298 Mdot
.918 .28304 Mdot
.918 .28306 Mdot
.918 .28321 Mdot
.918 .28337 Mdot
.918 .28439 Mdot
.918 .28462 Mdot
.918 .2853 Mdot
.918 .28563 Mdot
.918 .28621 Mdot
.918 .28633 Mdot
.918 .28974 Mdot
.918 .29012 Mdot
.918 .29029 Mdot
.918 .29042 Mdot
.918 .29066 Mdot
.918 .29077 Mdot
.918 .29385 Mdot
.918 .29492 Mdot
.918 .29529 Mdot
.918 .29552 Mdot
.918 .29562 Mdot
.918 .29602 Mdot
.918 .29621 Mdot
.918 .2966 Mdot
.918 .29663 Mdot
.918 .29664 Mdot
.918 .29676 Mdot
.918 .29711 Mdot
.918 .29788 Mdot
.918 .29823 Mdot
.918 .29871 Mdot
.918 .29895 Mdot
.918 .2998 Mdot
.918 .29986 Mdot
.918 .30049 Mdot
.918 .30055 Mdot
.918 .30132 Mdot
.918 .30176 Mdot
.918 .30207 Mdot
.918 .30234 Mdot
.918 .30237 Mdot
.918 .30358 Mdot
.918 .30383 Mdot
.918 .30426 Mdot
.918 .30532 Mdot
.918 .30654 Mdot
.918 .30657 Mdot
.918 .30704 Mdot
.918 .30718 Mdot
.918 .30792 Mdot
.918 .3081 Mdot
.918 .30896 Mdot
.918 .30943 Mdot
.918 .31114 Mdot
.918 .31137 Mdot
.918 .31247 Mdot
.918 .31268 Mdot
.918 .31287 Mdot
.918 .31302 Mdot
.918 .31371 Mdot
.918 .314 Mdot
.918 .31439 Mdot
.918 .31494 Mdot
.918 .31611 Mdot
.918 .31714 Mdot
.918 .31758 Mdot
.918 .31847 Mdot
.918 .31892 Mdot
.918 .31931 Mdot
.918 .31934 Mdot
.918 .31943 Mdot
.918 .31991 Mdot
.918 .32022 Mdot
.918 .32037 Mdot
.918 .32088 Mdot
.918 .32175 Mdot
.918 .32205 Mdot
.918 .32239 Mdot
.918 .32249 Mdot
.918 .32289 Mdot
.918 .32317 Mdot
.918 .32392 Mdot
.918 .32421 Mdot
.918 .32545 Mdot
.918 .32567 Mdot
.918 .32605 Mdot
.918 .32669 Mdot
.918 .32671 Mdot
.918 .32692 Mdot
.918 .32787 Mdot
.918 .32868 Mdot
.918 .3288 Mdot
.918 .32953 Mdot
.918 .3303 Mdot
.918 .3305 Mdot
.918 .33058 Mdot
.918 .33072 Mdot
.918 .33075 Mdot
.918 .33228 Mdot
.918 .33271 Mdot
.918 .33296 Mdot
.918 .33314 Mdot
.918 .33434 Mdot
.918 .33441 Mdot
.918 .33473 Mdot
.918 .33505 Mdot
.918 .33511 Mdot
.918 .33721 Mdot
.918 .338 Mdot
.918 .33877 Mdot
.918 .33913 Mdot
.918 .34054 Mdot
.918 .34074 Mdot
.918 .34088 Mdot
.918 .34172 Mdot
.918 .34176 Mdot
.918 .3422 Mdot
.918 .34263 Mdot
.918 .34268 Mdot
.918 .34274 Mdot
.918 .34289 Mdot
.918 .34312 Mdot
.918 .34318 Mdot
.918 .34318 Mdot
.918 .34325 Mdot
.918 .3436 Mdot
.918 .34424 Mdot
.918 .34429 Mdot
.918 .34493 Mdot
.918 .34506 Mdot
.918 .34509 Mdot
.918 .34518 Mdot
.918 .34565 Mdot
.918 .34599 Mdot
.918 .34601 Mdot
.918 .34628 Mdot
.918 .34691 Mdot
.918 .34706 Mdot
.918 .34748 Mdot
.918 .34767 Mdot
.918 .34798 Mdot
.918 .34805 Mdot
.918 .34817 Mdot
.918 .34885 Mdot
.918 .34898 Mdot
.918 .34967 Mdot
.918 .34976 Mdot
.918 .35 Mdot
.918 .35022 Mdot
.918 .35143 Mdot
.918 .35186 Mdot
.918 .35215 Mdot
.918 .35236 Mdot
.918 .35259 Mdot
.918 .35293 Mdot
.918 .35319 Mdot
.918 .35325 Mdot
.918 .35336 Mdot
.918 .35358 Mdot
.918 .35439 Mdot
.918 .35584 Mdot
.918 .35616 Mdot
.918 .35626 Mdot
.918 .35681 Mdot
.918 .35709 Mdot
.918 .35724 Mdot
.918 .35734 Mdot
.918 .3574 Mdot
.918 .35746 Mdot
.918 .35775 Mdot
.918 .35861 Mdot
.918 .35881 Mdot
.918 .35972 Mdot
.918 .35997 Mdot
.918 .36007 Mdot
.918 .36099 Mdot
.918 .3613 Mdot
.918 .36146 Mdot
.918 .36272 Mdot
.918 .363 Mdot
.918 .36342 Mdot
.918 .36389 Mdot
.918 .36392 Mdot
.918 .36505 Mdot
.918 .36524 Mdot
.918 .36616 Mdot
.918 .36686 Mdot
.918 .36702 Mdot
.918 .36745 Mdot
.918 .3676 Mdot
.918 .36813 Mdot
.918 .36859 Mdot
.918 .36867 Mdot
.918 .36912 Mdot
.918 .36993 Mdot
.918 .37078 Mdot
.918 .37135 Mdot
.918 .37174 Mdot
.918 .3718 Mdot
.918 .37225 Mdot
.918 .37346 Mdot
.918 .37371 Mdot
.918 .37374 Mdot
.918 .37389 Mdot
.918 .37417 Mdot
.918 .37452 Mdot
.918 .37559 Mdot
.918 .37571 Mdot
.918 .3759 Mdot
.918 .37597 Mdot
.918 .37625 Mdot
.918 .37705 Mdot
.918 .37709 Mdot
.918 .37959 Mdot
.918 .3805 Mdot
.918 .38079 Mdot
.918 .38091 Mdot
.918 .38131 Mdot
.918 .38136 Mdot
.918 .38138 Mdot
.918 .38162 Mdot
.918 .38163 Mdot
.918 .38171 Mdot
.918 .38194 Mdot
.918 .38227 Mdot
.918 .38247 Mdot
.918 .38251 Mdot
.918 .38274 Mdot
.918 .38324 Mdot
.918 .38351 Mdot
.918 .38358 Mdot
.918 .38381 Mdot
.918 .38411 Mdot
.918 .38467 Mdot
.918 .38483 Mdot
.918 .38496 Mdot
.918 .38499 Mdot
.918 .38501 Mdot
.918 .38537 Mdot
.918 .38543 Mdot
.918 .3858 Mdot
.918 .38607 Mdot
.918 .38694 Mdot
.918 .38733 Mdot
.918 .3876 Mdot
.918 .38781 Mdot
.918 .38819 Mdot
.918 .38833 Mdot
.918 .38915 Mdot
.918 .38998 Mdot
.918 .39009 Mdot
.918 .39044 Mdot
.918 .39085 Mdot
.918 .39159 Mdot
.918 .39186 Mdot
.918 .39198 Mdot
.918 .39211 Mdot
.918 .3922 Mdot
.918 .39293 Mdot
.918 .39315 Mdot
.918 .39318 Mdot
.918 .39403 Mdot
.918 .3947 Mdot
.918 .39481 Mdot
.918 .39527 Mdot
.918 .39531 Mdot
.918 .39533 Mdot
.918 .39562 Mdot
.918 .39587 Mdot
.918 .39626 Mdot
.918 .39635 Mdot
.918 .39656 Mdot
.918 .39662 Mdot
.918 .3967 Mdot
.918 .39682 Mdot
.918 .39687 Mdot
.918 .39721 Mdot
.918 .39737 Mdot
.918 .39738 Mdot
.918 .39741 Mdot
.918 .39766 Mdot
.918 .39771 Mdot
.918 .39808 Mdot
.918 .39854 Mdot
.918 .39868 Mdot
.918 .39908 Mdot
.918 .39912 Mdot
.918 .39919 Mdot
.918 .40004 Mdot
.918 .40023 Mdot
.918 .40028 Mdot
.918 .40074 Mdot
.918 .40147 Mdot
.918 .40241 Mdot
.918 .40256 Mdot
.918 .4028 Mdot
.918 .40302 Mdot
.918 .40309 Mdot
.918 .40348 Mdot
.918 .40365 Mdot
.918 .40423 Mdot
.918 .40435 Mdot
.918 .40479 Mdot
.918 .40483 Mdot
.918 .40498 Mdot
.918 .40501 Mdot
.918 .40522 Mdot
.918 .40545 Mdot
.918 .40595 Mdot
.918 .4073 Mdot
.918 .40806 Mdot
.918 .40812 Mdot
.918 .40871 Mdot
.918 .4089 Mdot
.918 .40905 Mdot
.918 .40928 Mdot
.918 .41019 Mdot
.918 .41043 Mdot
.918 .41165 Mdot
.918 .41193 Mdot
.918 .41219 Mdot
.918 .41279 Mdot
.918 .41288 Mdot
.918 .41326 Mdot
.918 .41376 Mdot
.918 .41386 Mdot
.918 .41448 Mdot
.918 .41475 Mdot
.918 .41513 Mdot
.918 .41582 Mdot
.918 .4159 Mdot
.918 .41607 Mdot
.918 .41658 Mdot
.918 .41726 Mdot
.918 .41737 Mdot
.918 .418 Mdot
.918 .41803 Mdot
.918 .41806 Mdot
.918 .41812 Mdot
.918 .41835 Mdot
.918 .41865 Mdot
.918 .41871 Mdot
.918 .41888 Mdot
.918 .41967 Mdot
.918 .42011 Mdot
.918 .42023 Mdot
.918 .42032 Mdot
.918 .42065 Mdot
.918 .42078 Mdot
.918 .42089 Mdot
.918 .42128 Mdot
.918 .42219 Mdot
.918 .42262 Mdot
.918 .42269 Mdot
.918 .42306 Mdot
.918 .42333 Mdot
.918 .42366 Mdot
.918 .42374 Mdot
.918 .42408 Mdot
.918 .42423 Mdot
.918 .42424 Mdot
.918 .42469 Mdot
.918 .42473 Mdot
.918 .42475 Mdot
.918 .42482 Mdot
.918 .4252 Mdot
.918 .42555 Mdot
.918 .42574 Mdot
.918 .42578 Mdot
.918 .42578 Mdot
.918 .42593 Mdot
.918 .42631 Mdot
.918 .42655 Mdot
.918 .42703 Mdot
.918 .42721 Mdot
.918 .42798 Mdot
.918 .42817 Mdot
.918 .4286 Mdot
.918 .42903 Mdot
.918 .43017 Mdot
.918 .43256 Mdot
.918 .43264 Mdot
.918 .43321 Mdot
.918 .43367 Mdot
.918 .43411 Mdot
.918 .43463 Mdot
.918 .43475 Mdot
.918 .4351 Mdot
.918 .43531 Mdot
.918 .43543 Mdot
.918 .43611 Mdot
.918 .43627 Mdot
.918 .43728 Mdot
.918 .43792 Mdot
.918 .4382 Mdot
.918 .43845 Mdot
.918 .43871 Mdot
.918 .43876 Mdot
.918 .43878 Mdot
.918 .43899 Mdot
.918 .43923 Mdot
.918 .44052 Mdot
.918 .44116 Mdot
.918 .44146 Mdot
.918 .44167 Mdot
.918 .44183 Mdot
.918 .4422 Mdot
.918 .44228 Mdot
.918 .44239 Mdot
.918 .4425 Mdot
.918 .4431 Mdot
.918 .44323 Mdot
.918 .44416 Mdot
.918 .44441 Mdot
.918 .44538 Mdot
.918 .44572 Mdot
.918 .44697 Mdot
.918 .44721 Mdot
.918 .44734 Mdot
.918 .448 Mdot
.918 .44802 Mdot
.918 .44816 Mdot
.918 .44834 Mdot
.918 .44903 Mdot
.918 .44937 Mdot
.918 .4494 Mdot
.918 .45 Mdot
.918 .45026 Mdot
.918 .45106 Mdot
.918 .45113 Mdot
.918 .45113 Mdot
.918 .45115 Mdot
.918 .45136 Mdot
.918 .45173 Mdot
.918 .45264 Mdot
.918 .45432 Mdot
.918 .45438 Mdot
.918 .45451 Mdot
.918 .45468 Mdot
.918 .45488 Mdot
.918 .45674 Mdot
.918 .45681 Mdot
.918 .45712 Mdot
.918 .4573 Mdot
.918 .45767 Mdot
.918 .45835 Mdot
.918 .45844 Mdot
.918 .45853 Mdot
.918 .45895 Mdot
.918 .45945 Mdot
.918 .45979 Mdot
.918 .46108 Mdot
.918 .46126 Mdot
.918 .46155 Mdot
.918 .46193 Mdot
.918 .46212 Mdot
.918 .46253 Mdot
.918 .46254 Mdot
.918 .46297 Mdot
.918 .46337 Mdot
.918 .46381 Mdot
.918 .46399 Mdot
.918 .46401 Mdot
.918 .46446 Mdot
.918 .46496 Mdot
.918 .46536 Mdot
.918 .46584 Mdot
.918 .46595 Mdot
.918 .46612 Mdot
.918 .46649 Mdot
.918 .46724 Mdot
.918 .46731 Mdot
.918 .46807 Mdot
.918 .46812 Mdot
.918 .46861 Mdot
.918 .46872 Mdot
.918 .46883 Mdot
.918 .46902 Mdot
.918 .46929 Mdot
.918 .46936 Mdot
.918 .46956 Mdot
.918 .4698 Mdot
.918 .47017 Mdot
.918 .47082 Mdot
.918 .47085 Mdot
.918 .47099 Mdot
.918 .47111 Mdot
.918 .47158 Mdot
.918 .47201 Mdot
.918 .47264 Mdot
.918 .47302 Mdot
.918 .47338 Mdot
.918 .4741 Mdot
.918 .47425 Mdot
.918 .47503 Mdot
.918 .47521 Mdot
.918 .47521 Mdot
.918 .47572 Mdot
.918 .47573 Mdot
.918 .47614 Mdot
.918 .47634 Mdot
.918 .47645 Mdot
.918 .47692 Mdot
.918 .47756 Mdot
.918 .47777 Mdot
.918 .47786 Mdot
.918 .47797 Mdot
.918 .47802 Mdot
.918 .47836 Mdot
.918 .47888 Mdot
.918 .47905 Mdot
.918 .47967 Mdot
.918 .48053 Mdot
.918 .48177 Mdot
.918 .4819 Mdot
.918 .48202 Mdot
.918 .48231 Mdot
.918 .48236 Mdot
.918 .48273 Mdot
.918 .48274 Mdot
.918 .48291 Mdot
.918 .48418 Mdot
.918 .48435 Mdot
.918 .48441 Mdot
.918 .48566 Mdot
.918 .48569 Mdot
.918 .48589 Mdot
.918 .486 Mdot
.918 .48659 Mdot
.918 .48692 Mdot
.918 .48736 Mdot
.918 .4877 Mdot
.918 .48797 Mdot
.918 .48889 Mdot
.918 .48896 Mdot
.918 .48913 Mdot
.918 .48955 Mdot
.918 .48962 Mdot
.918 .48966 Mdot
.918 .4903 Mdot
.918 .49106 Mdot
.918 .49116 Mdot
.918 .49131 Mdot
.918 .49138 Mdot
.918 .4916 Mdot
.918 .49241 Mdot
.918 .4928 Mdot
.918 .49288 Mdot
.918 .49309 Mdot
.918 .49384 Mdot
.918 .49388 Mdot
.918 .49406 Mdot
.918 .49414 Mdot
.918 .4947 Mdot
.918 .49483 Mdot
.918 .49483 Mdot
.918 .49493 Mdot
.918 .49527 Mdot
.918 .49535 Mdot
.918 .49558 Mdot
.918 .49564 Mdot
.918 .49574 Mdot
.918 .49583 Mdot
.918 .4959 Mdot
.918 .49663 Mdot
.918 .49719 Mdot
.918 .49743 Mdot
.918 .49751 Mdot
.918 .49817 Mdot
.918 .49876 Mdot
.918 .49905 Mdot
.918 .4993 Mdot
.918 .49967 Mdot
.918 .49999 Mdot
.918 .50225 Mdot
.918 .50291 Mdot
.918 .50311 Mdot
.918 .50425 Mdot
.918 .50434 Mdot
.918 .50579 Mdot
.918 .50596 Mdot
.918 .50725 Mdot
.918 .50737 Mdot
.918 .5074 Mdot
.918 .50767 Mdot
.918 .50796 Mdot
.918 .50965 Mdot
.918 .50974 Mdot
.918 .50984 Mdot
.918 .51027 Mdot
.918 .51034 Mdot
.918 .51092 Mdot
.918 .51106 Mdot
.918 .5115 Mdot
.918 .51212 Mdot
.918 .51317 Mdot
.918 .51326 Mdot
.918 .5134 Mdot
.918 .51359 Mdot
.918 .51405 Mdot
.918 .51483 Mdot
.918 .51764 Mdot
.918 .5177 Mdot
.918 .51796 Mdot
.918 .51811 Mdot
.918 .51847 Mdot
.918 .51965 Mdot
.918 .51988 Mdot
.918 .52036 Mdot
.918 .52067 Mdot
.918 .5209 Mdot
.918 .52123 Mdot
.918 .52135 Mdot
.918 .52144 Mdot
.918 .52155 Mdot
.918 .52293 Mdot
.918 .52468 Mdot
.918 .52507 Mdot
.918 .52509 Mdot
.918 .52627 Mdot
.918 .52698 Mdot
.918 .52721 Mdot
.918 .52738 Mdot
.918 .52917 Mdot
.918 .52965 Mdot
.918 .52984 Mdot
.918 .53019 Mdot
.918 .53027 Mdot
.918 .53045 Mdot
.918 .53118 Mdot
.918 .53155 Mdot
.918 .53156 Mdot
.918 .53208 Mdot
.918 .53225 Mdot
.918 .53232 Mdot
.918 .53232 Mdot
.918 .53255 Mdot
.918 .53282 Mdot
.918 .533 Mdot
.918 .5332 Mdot
.918 .53362 Mdot
.918 .53416 Mdot
.918 .53461 Mdot
.918 .53525 Mdot
.918 .53577 Mdot
.918 .53612 Mdot
.918 .53656 Mdot
.918 .5367 Mdot
.918 .53698 Mdot
.918 .53755 Mdot
.918 .53813 Mdot
.918 .53823 Mdot
.918 .53842 Mdot
.918 .53859 Mdot
.918 .53865 Mdot
.918 .53937 Mdot
.918 .5394 Mdot
.918 .53952 Mdot
.918 .54018 Mdot
.918 .54092 Mdot
.918 .54172 Mdot
.918 .54184 Mdot
.918 .5423 Mdot
.918 .54264 Mdot
.918 .5428 Mdot
.918 .54284 Mdot
.918 .54453 Mdot
.918 .54508 Mdot
.918 .54553 Mdot
.918 .54632 Mdot
.918 .54667 Mdot
.918 .54768 Mdot
.918 .54826 Mdot
.918 .5484 Mdot
.918 .54893 Mdot
.918 .5502 Mdot
.918 .55047 Mdot
.918 .5505 Mdot
.918 .55056 Mdot
.918 .55083 Mdot
.918 .55121 Mdot
.918 .55143 Mdot
.918 .55169 Mdot
.918 .55303 Mdot
.918 .55323 Mdot
.918 .55337 Mdot
.918 .55365 Mdot
.918 .55495 Mdot
.918 .55581 Mdot
.92 .10234 Mdot
.92 .10235 Mdot
.92 .10342 Mdot
.92 .10365 Mdot
.92 .10368 Mdot
.92 .10403 Mdot
.92 .10443 Mdot
.92 .10472 Mdot
.92 .10559 Mdot
.92 .1072 Mdot
.92 .10733 Mdot
.92 .10775 Mdot
.92 .10949 Mdot
.92 .11 Mdot
.92 .11046 Mdot
.92 .11284 Mdot
.92 .11291 Mdot
.92 .11307 Mdot
.92 .11374 Mdot
.92 .11507 Mdot
.92 .1155 Mdot
.92 .1158 Mdot
.92 .11583 Mdot
.92 .11585 Mdot
.92 .11963 Mdot
.92 .11998 Mdot
.92 .12006 Mdot
.92 .12189 Mdot
.92 .12226 Mdot
.92 .12261 Mdot
.92 .12288 Mdot
.92 .1236 Mdot
.92 .1241 Mdot
.92 .12503 Mdot
.92 .12516 Mdot
.92 .12533 Mdot
.92 .12658 Mdot
.92 .12763 Mdot
.92 .12808 Mdot
.92 .12808 Mdot
.92 .13126 Mdot
.92 .13233 Mdot
.92 .1345 Mdot
.92 .13472 Mdot
.92 .13561 Mdot
.92 .13594 Mdot
.92 .13674 Mdot
.92 .13725 Mdot
.92 .13732 Mdot
.92 .13798 Mdot
.92 .13851 Mdot
.92 .13899 Mdot
.92 .14107 Mdot
.92 .14148 Mdot
.92 .1415 Mdot
.92 .14191 Mdot
.92 .14274 Mdot
.92 .14323 Mdot
.92 .14367 Mdot
.92 .14434 Mdot
.92 .14451 Mdot
.92 .14468 Mdot
.92 .1449 Mdot
.92 .14521 Mdot
.92 .14605 Mdot
.92 .14683 Mdot
.92 .14822 Mdot
.92 .14874 Mdot
.92 .1506 Mdot
.92 .15133 Mdot
.92 .15201 Mdot
.92 .15427 Mdot
.92 .15455 Mdot
.92 .15492 Mdot
.92 .15659 Mdot
.92 .15703 Mdot
.92 .15724 Mdot
.92 .15807 Mdot
.92 .15868 Mdot
.92 .15901 Mdot
.92 .15916 Mdot
.92 .16244 Mdot
.92 .16267 Mdot
.92 .16301 Mdot
.92 .1644 Mdot
.92 .16522 Mdot
.92 .16578 Mdot
.92 .16596 Mdot
.92 .16609 Mdot
.92 .1662 Mdot
.92 .16652 Mdot
.92 .16657 Mdot
.92 .16716 Mdot
.92 .16776 Mdot
.92 .16862 Mdot
.92 .16929 Mdot
.92 .16951 Mdot
.92 .17077 Mdot
.92 .17161 Mdot
.92 .17207 Mdot
.92 .17452 Mdot
.92 .1747 Mdot
.92 .17516 Mdot
.92 .17594 Mdot
.92 .17596 Mdot
.92 .17646 Mdot
.92 .17699 Mdot
.92 .1772 Mdot
.92 .17793 Mdot
.92 .17829 Mdot
.92 .17836 Mdot
.92 .17841 Mdot
.92 .17857 Mdot
.92 .17885 Mdot
.92 .17905 Mdot
.92 .1798 Mdot
.92 .17997 Mdot
.92 .18032 Mdot
.92 .18088 Mdot
.92 .18096 Mdot
.92 .18172 Mdot
.92 .18179 Mdot
.92 .18193 Mdot
.92 .18252 Mdot
.92 .1826 Mdot
.92 .18302 Mdot
.92 .1849 Mdot
.92 .18512 Mdot
.92 .18537 Mdot
.92 .18546 Mdot
.92 .1859 Mdot
.92 .18594 Mdot
.92 .18685 Mdot
.92 .18778 Mdot
.92 .18911 Mdot
.92 .18924 Mdot
.92 .18937 Mdot
.92 .19005 Mdot
.92 .19009 Mdot
.92 .19088 Mdot
.92 .19088 Mdot
.92 .1923 Mdot
.92 .19375 Mdot
.92 .19436 Mdot
.92 .19493 Mdot
.92 .1951 Mdot
.92 .19527 Mdot
.92 .19535 Mdot
.92 .19536 Mdot
.92 .19539 Mdot
.92 .19568 Mdot
.92 .19659 Mdot
.92 .19663 Mdot
.92 .19693 Mdot
.92 .19937 Mdot
.92 .20016 Mdot
.92 .20028 Mdot
.92 .20032 Mdot
.92 .20045 Mdot
.92 .20071 Mdot
.92 .20077 Mdot
.92 .20081 Mdot
.92 .20139 Mdot
.92 .20288 Mdot
.92 .20295 Mdot
.92 .20339 Mdot
.92 .20444 Mdot
.92 .20721 Mdot
.92 .20777 Mdot
.92 .20807 Mdot
.92 .20841 Mdot
.92 .20854 Mdot
.92 .20912 Mdot
.92 .21051 Mdot
.92 .21149 Mdot
.92 .21191 Mdot
.92 .21211 Mdot
.92 .21228 Mdot
.92 .21242 Mdot
.92 .21261 Mdot
.92 .21325 Mdot
.92 .21325 Mdot
.92 .21369 Mdot
.92 .21374 Mdot
.92 .21506 Mdot
.92 .21506 Mdot
.92 .21598 Mdot
.92 .21643 Mdot
.92 .21651 Mdot
.92 .21732 Mdot
.92 .21769 Mdot
.92 .21794 Mdot
.92 .21819 Mdot
.92 .21826 Mdot
.92 .21891 Mdot
.92 .21902 Mdot
.92 .21963 Mdot
.92 .22055 Mdot
.92 .22127 Mdot
.92 .22132 Mdot
.92 .22156 Mdot
.92 .22195 Mdot
.92 .22247 Mdot
.92 .2233 Mdot
.92 .22331 Mdot
.92 .2237 Mdot
.92 .22553 Mdot
.92 .22607 Mdot
.92 .22655 Mdot
.92 .22657 Mdot
.92 .22684 Mdot
.92 .22761 Mdot
.92 .22812 Mdot
.92 .22818 Mdot
.92 .22838 Mdot
.92 .22839 Mdot
.92 .22904 Mdot
.92 .22914 Mdot
.92 .22915 Mdot
.92 .2302 Mdot
.92 .23054 Mdot
.92 .23091 Mdot
.92 .23112 Mdot
.92 .23302 Mdot
.92 .23512 Mdot
.92 .23544 Mdot
.92 .23553 Mdot
.92 .23583 Mdot
.92 .23603 Mdot
.92 .23613 Mdot
.92 .2371 Mdot
.92 .23715 Mdot
.92 .23777 Mdot
.92 .23777 Mdot
.92 .23797 Mdot
.92 .23924 Mdot
.92 .24012 Mdot
.92 .24018 Mdot
.92 .2403 Mdot
.92 .24078 Mdot
.92 .24111 Mdot
.92 .24122 Mdot
.92 .24123 Mdot
.92 .24152 Mdot
.92 .24211 Mdot
.92 .2425 Mdot
.92 .24338 Mdot
.92 .24356 Mdot
.92 .24495 Mdot
.92 .247 Mdot
.92 .24721 Mdot
.92 .24797 Mdot
.92 .248 Mdot
.92 .24806 Mdot
.92 .24876 Mdot
.92 .24921 Mdot
.92 .24946 Mdot
.92 .25027 Mdot
.92 .25028 Mdot
.92 .25119 Mdot
.92 .2517 Mdot
.92 .25174 Mdot
.92 .25198 Mdot
.92 .252 Mdot
.92 .2532 Mdot
.92 .25323 Mdot
.92 .25353 Mdot
.92 .25377 Mdot
.92 .25385 Mdot
.92 .25407 Mdot
.92 .25426 Mdot
.92 .25482 Mdot
.92 .25636 Mdot
.92 .25651 Mdot
.92 .25781 Mdot
.92 .25812 Mdot
.92 .25869 Mdot
.92 .25887 Mdot
.92 .25908 Mdot
.92 .2599 Mdot
.92 .26036 Mdot
.92 .26048 Mdot
.92 .26112 Mdot
.92 .26132 Mdot
.92 .26134 Mdot
.92 .26152 Mdot
.92 .26193 Mdot
.92 .26214 Mdot
.92 .26257 Mdot
.92 .26328 Mdot
.92 .26465 Mdot
.92 .26474 Mdot
.92 .26527 Mdot
.92 .26535 Mdot
.92 .26577 Mdot
.92 .26601 Mdot
.92 .26608 Mdot
.92 .26734 Mdot
.92 .26818 Mdot
.92 .26858 Mdot
.92 .26998 Mdot
.92 .27015 Mdot
.92 .27149 Mdot
.92 .2716 Mdot
.92 .27201 Mdot
.92 .27269 Mdot
.92 .27292 Mdot
.92 .27362 Mdot
.92 .27425 Mdot
.92 .27503 Mdot
.92 .2755 Mdot
.92 .27574 Mdot
.92 .27577 Mdot
.92 .27617 Mdot
.92 .27658 Mdot
.92 .27695 Mdot
.92 .27704 Mdot
.92 .27723 Mdot
.92 .27751 Mdot
.92 .27824 Mdot
.92 .27849 Mdot
.92 .27962 Mdot
.92 .28021 Mdot
.92 .28049 Mdot
.92 .28163 Mdot
.92 .28212 Mdot
.92 .28423 Mdot
.92 .28477 Mdot
.92 .28491 Mdot
.92 .28627 Mdot
.92 .28654 Mdot
.92 .28695 Mdot
.92 .28735 Mdot
.92 .28757 Mdot
.92 .28887 Mdot
.92 .28925 Mdot
.92 .28989 Mdot
.92 .29014 Mdot
.92 .29063 Mdot
.92 .29089 Mdot
.92 .29165 Mdot
.92 .29171 Mdot
.92 .29268 Mdot
.92 .29273 Mdot
.92 .29282 Mdot
.92 .293 Mdot
.92 .29325 Mdot
.92 .29344 Mdot
.92 .29404 Mdot
.92 .29413 Mdot
.92 .29521 Mdot
.92 .29632 Mdot
.92 .29656 Mdot
.92 .29689 Mdot
.92 .29696 Mdot
.92 .29753 Mdot
.92 .29778 Mdot
.92 .2979 Mdot
.92 .2979 Mdot
.92 .29913 Mdot
.92 .29954 Mdot
.92 .29964 Mdot
.92 .2999 Mdot
.92 .30186 Mdot
.92 .30186 Mdot
.92 .302 Mdot
.92 .30272 Mdot
.92 .30276 Mdot
.92 .3034 Mdot
.92 .30423 Mdot
.92 .30425 Mdot
.92 .30547 Mdot
.92 .30549 Mdot
.92 .30634 Mdot
.92 .3072 Mdot
.92 .30735 Mdot
.92 .30787 Mdot
.92 .30851 Mdot
.92 .30876 Mdot
.92 .30908 Mdot
.92 .30946 Mdot
.92 .30993 Mdot
.92 .31025 Mdot
.92 .31032 Mdot
.92 .31043 Mdot
.92 .31055 Mdot
.92 .31136 Mdot
.92 .3114 Mdot
.92 .31232 Mdot
.92 .31303 Mdot
.92 .3131 Mdot
.92 .3133 Mdot
.92 .31369 Mdot
.92 .31382 Mdot
.92 .31391 Mdot
.92 .31504 Mdot
.92 .3157 Mdot
.92 .31581 Mdot
.92 .31592 Mdot
.92 .31621 Mdot
.92 .31635 Mdot
.92 .31672 Mdot
.92 .31709 Mdot
.92 .31847 Mdot
.92 .31878 Mdot
.92 .31943 Mdot
.92 .32009 Mdot
.92 .32024 Mdot
.92 .32045 Mdot
.92 .32061 Mdot
.92 .32075 Mdot
.92 .32137 Mdot
.92 .32201 Mdot
.92 .32214 Mdot
.92 .32233 Mdot
.92 .32238 Mdot
.92 .32259 Mdot
.92 .32348 Mdot
.92 .32363 Mdot
.92 .3244 Mdot
.92 .3246 Mdot
.92 .32546 Mdot
.92 .32608 Mdot
.92 .32785 Mdot
.92 .32826 Mdot
.92 .32867 Mdot
.92 .32872 Mdot
.92 .32879 Mdot
.92 .32889 Mdot
.92 .3289 Mdot
.92 .32907 Mdot
.92 .3297 Mdot
.92 .32977 Mdot
.92 .33039 Mdot
.92 .33125 Mdot
.92 .3313 Mdot
.92 .33144 Mdot
.92 .33198 Mdot
.92 .33236 Mdot
.92 .33253 Mdot
.92 .33315 Mdot
.92 .33337 Mdot
.92 .3334 Mdot
.92 .33361 Mdot
.92 .33364 Mdot
.92 .33376 Mdot
.92 .33445 Mdot
.92 .33489 Mdot
.92 .3356 Mdot
.92 .33563 Mdot
.92 .33585 Mdot
.92 .33608 Mdot
.92 .3365 Mdot
.92 .33693 Mdot
.92 .33711 Mdot
.92 .33733 Mdot
.92 .3374 Mdot
.92 .3374 Mdot
.92 .33778 Mdot
.92 .33886 Mdot
.92 .33887 Mdot
.92 .33962 Mdot
.92 .33965 Mdot
.92 .34009 Mdot
.92 .34147 Mdot
.92 .3424 Mdot
.92 .34269 Mdot
.92 .34415 Mdot
.92 .34439 Mdot
.92 .34457 Mdot
.92 .34506 Mdot
.92 .34507 Mdot
.92 .34526 Mdot
.92 .34631 Mdot
.92 .34662 Mdot
.92 .34662 Mdot
.92 .34693 Mdot
.92 .34708 Mdot
.92 .3471 Mdot
.92 .34716 Mdot
.92 .34716 Mdot
.92 .34735 Mdot
.92 .34769 Mdot
.92 .34853 Mdot
.92 .34936 Mdot
.92 .34944 Mdot
.92 .34973 Mdot
.92 .34993 Mdot
.92 .34999 Mdot
.92 .35062 Mdot
.92 .35092 Mdot
.92 .35095 Mdot
.92 .35095 Mdot
.92 .35164 Mdot
.92 .35266 Mdot
.92 .35297 Mdot
.92 .35406 Mdot
.92 .35449 Mdot
.92 .35546 Mdot
.92 .35594 Mdot
.92 .35616 Mdot
.92 .35622 Mdot
.92 .35647 Mdot
.92 .35664 Mdot
.92 .35689 Mdot
.92 .35695 Mdot
.92 .35706 Mdot
.92 .35713 Mdot
.92 .3582 Mdot
.92 .35944 Mdot
.92 .35992 Mdot
.92 .36094 Mdot
.92 .36107 Mdot
.92 .36115 Mdot
.92 .36153 Mdot
.92 .36167 Mdot
.92 .36188 Mdot
.92 .36365 Mdot
.92 .36381 Mdot
.92 .36385 Mdot
.92 .36425 Mdot
.92 .36502 Mdot
.92 .36729 Mdot
.92 .36758 Mdot
.92 .36828 Mdot
.92 .36886 Mdot
.92 .3689 Mdot
.92 .36956 Mdot
.92 .36993 Mdot
.92 .37044 Mdot
.92 .37048 Mdot
.92 .37071 Mdot
.92 .37082 Mdot
.92 .37111 Mdot
.92 .37136 Mdot
.92 .37216 Mdot
.92 .37242 Mdot
.92 .37314 Mdot
.92 .37424 Mdot
.92 .37429 Mdot
.92 .37462 Mdot
.92 .37491 Mdot
.92 .37498 Mdot
.92 .37558 Mdot
.92 .37678 Mdot
.92 .37681 Mdot
.92 .37685 Mdot
.92 .37754 Mdot
.92 .37755 Mdot
.92 .37775 Mdot
.92 .37792 Mdot
.92 .37824 Mdot
.92 .37824 Mdot
.92 .37849 Mdot
.92 .37884 Mdot
.92 .37936 Mdot
.92 .37947 Mdot
.92 .38001 Mdot
.92 .38002 Mdot
.92 .38083 Mdot
.92 .38092 Mdot
.92 .38147 Mdot
.92 .38208 Mdot
.92 .38264 Mdot
.92 .383 Mdot
.92 .38306 Mdot
.92 .38335 Mdot
.92 .38336 Mdot
.92 .38469 Mdot
.92 .38504 Mdot
.92 .38511 Mdot
.92 .38587 Mdot
.92 .38601 Mdot
.92 .38648 Mdot
.92 .38653 Mdot
.92 .38711 Mdot
.92 .38717 Mdot
.92 .38729 Mdot
.92 .38752 Mdot
.92 .38819 Mdot
.92 .38865 Mdot
.92 .38912 Mdot
.92 .38923 Mdot
.92 .38962 Mdot
.92 .38991 Mdot
.92 .39044 Mdot
.92 .39063 Mdot
.92 .39142 Mdot
.92 .39175 Mdot
.92 .39272 Mdot
.92 .39345 Mdot
.92 .39385 Mdot
.92 .39404 Mdot
.92 .39406 Mdot
.92 .39409 Mdot
.92 .39478 Mdot
.92 .39487 Mdot
.92 .39531 Mdot
.92 .39603 Mdot
.92 .3961 Mdot
.92 .3967 Mdot
.92 .39687 Mdot
.92 .39698 Mdot
.92 .39708 Mdot
.92 .3974 Mdot
.92 .39849 Mdot
.92 .39851 Mdot
.92 .39852 Mdot
.92 .39862 Mdot
.92 .39924 Mdot
.92 .39995 Mdot
.92 .40077 Mdot
.92 .40092 Mdot
.92 .40219 Mdot
.92 .40226 Mdot
.92 .40229 Mdot
.92 .40261 Mdot
.92 .40263 Mdot
.92 .40337 Mdot
.92 .4036 Mdot
.92 .40449 Mdot
.92 .40452 Mdot
.92 .40472 Mdot
.92 .40502 Mdot
.92 .40644 Mdot
.92 .4065 Mdot
.92 .40711 Mdot
.92 .40737 Mdot
.92 .40749 Mdot
.92 .40787 Mdot
.92 .40789 Mdot
.92 .40856 Mdot
.92 .40892 Mdot
.92 .40908 Mdot
.92 .40926 Mdot
.92 .40928 Mdot
.92 .40988 Mdot
.92 .41042 Mdot
.92 .41114 Mdot
.92 .4112 Mdot
.92 .41135 Mdot
.92 .41183 Mdot
.92 .41221 Mdot
.92 .41252 Mdot
.92 .4129 Mdot
.92 .41306 Mdot
.92 .41429 Mdot
.92 .41471 Mdot
.92 .41493 Mdot
.92 .41504 Mdot
.92 .41612 Mdot
.92 .41619 Mdot
.92 .4164 Mdot
.92 .41707 Mdot
.92 .41733 Mdot
.92 .41871 Mdot
.92 .41885 Mdot
.92 .41949 Mdot
.92 .42025 Mdot
.92 .42084 Mdot
.92 .42101 Mdot
.92 .42157 Mdot
.92 .42194 Mdot
.92 .42194 Mdot
.92 .42196 Mdot
.92 .42212 Mdot
.92 .4225 Mdot
.92 .4226 Mdot
.92 .42326 Mdot
.92 .4239 Mdot
.92 .424 Mdot
.92 .4243 Mdot
.92 .42514 Mdot
.92 .42514 Mdot
.92 .42541 Mdot
.92 .42551 Mdot
.92 .42643 Mdot
.92 .42659 Mdot
.92 .42785 Mdot
.92 .42809 Mdot
.92 .4281 Mdot
.92 .4291 Mdot
.92 .42931 Mdot
.92 .42946 Mdot
.92 .42956 Mdot
.92 .4298 Mdot
.92 .43027 Mdot
.92 .43067 Mdot
.92 .43091 Mdot
.92 .43128 Mdot
.92 .43135 Mdot
.92 .43136 Mdot
.92 .43148 Mdot
.92 .43149 Mdot
.92 .43195 Mdot
.92 .43204 Mdot
.92 .43225 Mdot
.92 .43262 Mdot
.92 .43265 Mdot
.92 .43312 Mdot
.92 .43383 Mdot
.92 .43393 Mdot
.92 .43399 Mdot
.92 .43405 Mdot
.92 .43546 Mdot
.92 .4358 Mdot
.92 .43626 Mdot
.92 .43736 Mdot
.92 .43749 Mdot
.92 .43802 Mdot
.92 .43835 Mdot
.92 .43863 Mdot
.92 .43871 Mdot
.92 .44074 Mdot
.92 .44207 Mdot
.92 .44212 Mdot
.92 .44251 Mdot
.92 .44255 Mdot
.92 .4439 Mdot
.92 .44397 Mdot
.92 .44402 Mdot
.92 .44406 Mdot
.92 .44449 Mdot
.92 .44501 Mdot
.92 .44536 Mdot
.92 .44564 Mdot
.92 .44572 Mdot
.92 .44618 Mdot
.92 .44665 Mdot
.92 .44666 Mdot
.92 .44733 Mdot
.92 .44813 Mdot
.92 .44815 Mdot
.92 .44855 Mdot
.92 .44862 Mdot
.92 .44969 Mdot
.92 .44983 Mdot
.92 .45077 Mdot
.92 .45084 Mdot
.92 .45097 Mdot
.92 .45128 Mdot
.92 .45132 Mdot
.92 .4515 Mdot
.92 .45353 Mdot
.92 .45358 Mdot
.92 .45414 Mdot
.92 .45458 Mdot
.92 .45472 Mdot
.92 .45513 Mdot
.92 .45547 Mdot
.92 .45568 Mdot
.92 .4565 Mdot
.92 .45709 Mdot
.92 .45783 Mdot
.92 .45791 Mdot
.92 .4582 Mdot
.92 .45935 Mdot
.92 .45962 Mdot
.92 .46146 Mdot
.92 .46185 Mdot
.92 .46201 Mdot
.92 .46211 Mdot
.92 .46258 Mdot
.92 .46281 Mdot
.92 .46295 Mdot
.92 .4632 Mdot
.92 .46363 Mdot
.92 .46397 Mdot
.92 .46435 Mdot
.92 .46507 Mdot
.92 .46585 Mdot
.92 .46595 Mdot
.92 .46671 Mdot
.92 .46692 Mdot
.92 .4681 Mdot
.92 .46823 Mdot
.92 .46846 Mdot
.92 .46851 Mdot
.92 .46884 Mdot
.92 .46959 Mdot
.92 .46998 Mdot
.92 .47021 Mdot
.92 .47032 Mdot
.92 .47054 Mdot
.92 .47064 Mdot
.92 .47076 Mdot
.92 .47111 Mdot
.92 .47143 Mdot
.92 .47187 Mdot
.92 .47198 Mdot
.92 .47208 Mdot
.92 .47239 Mdot
.92 .47327 Mdot
.92 .47459 Mdot
.92 .47476 Mdot
.92 .47507 Mdot
.92 .47573 Mdot
.92 .47586 Mdot
.92 .47588 Mdot
.92 .47666 Mdot
.92 .4771 Mdot
.92 .47724 Mdot
.92 .47786 Mdot
.92 .47843 Mdot
.92 .47955 Mdot
.92 .4803 Mdot
.92 .4811 Mdot
.92 .48157 Mdot
.92 .48158 Mdot
.92 .48164 Mdot
.92 .48182 Mdot
.92 .48217 Mdot
.92 .48334 Mdot
.92 .48345 Mdot
.92 .48382 Mdot
.92 .48434 Mdot
.92 .4844 Mdot
.92 .48451 Mdot
.92 .48472 Mdot
.92 .48603 Mdot
.92 .48718 Mdot
.92 .48738 Mdot
.92 .48757 Mdot
.92 .48814 Mdot
.92 .4882 Mdot
.92 .48855 Mdot
.92 .48855 Mdot
.92 .48866 Mdot
.92 .4887 Mdot
.92 .48897 Mdot
.92 .48939 Mdot
.92 .48954 Mdot
.92 .48955 Mdot
.92 .48981 Mdot
.92 .49011 Mdot
.92 .4911 Mdot
.92 .49205 Mdot
.92 .49226 Mdot
.92 .49239 Mdot
.92 .49242 Mdot
.92 .49331 Mdot
.92 .49364 Mdot
.92 .4937 Mdot
.92 .49409 Mdot
.92 .49456 Mdot
.92 .49501 Mdot
.92 .49505 Mdot
.92 .49579 Mdot
.92 .49654 Mdot
.92 .49678 Mdot
.92 .49723 Mdot
.92 .4973 Mdot
.92 .4974 Mdot
.92 .49774 Mdot
.92 .49827 Mdot
.92 .49902 Mdot
.92 .4996 Mdot
.92 .50006 Mdot
.92 .50157 Mdot
.92 .50214 Mdot
.92 .50237 Mdot
.92 .50242 Mdot
.92 .50322 Mdot
.92 .50374 Mdot
.92 .50381 Mdot
.92 .50382 Mdot
.92 .50581 Mdot
.92 .50584 Mdot
.92 .5065 Mdot
.92 .50651 Mdot
.92 .50664 Mdot
.92 .50673 Mdot
.92 .50705 Mdot
.92 .50737 Mdot
.92 .50817 Mdot
.92 .50893 Mdot
.92 .50937 Mdot
.92 .50976 Mdot
.92 .50983 Mdot
.92 .51062 Mdot
.92 .51113 Mdot
.92 .51162 Mdot
.92 .51188 Mdot
.92 .51193 Mdot
.92 .51321 Mdot
.92 .51343 Mdot
.92 .51348 Mdot
.92 .51388 Mdot
.92 .51391 Mdot
.92 .51433 Mdot
.92 .51437 Mdot
.92 .51487 Mdot
.92 .51548 Mdot
.92 .51563 Mdot
.92 .51578 Mdot
.92 .51637 Mdot
.92 .51649 Mdot
.92 .51677 Mdot
.92 .51748 Mdot
.92 .51773 Mdot
.92 .51783 Mdot
.92 .51916 Mdot
.92 .51941 Mdot
.92 .51986 Mdot
.92 .52055 Mdot
.92 .52067 Mdot
.92 .52103 Mdot
.92 .5215 Mdot
.92 .52183 Mdot
.92 .52215 Mdot
.92 .52217 Mdot
.92 .52235 Mdot
.92 .52241 Mdot
.92 .52248 Mdot
.92 .52257 Mdot
.92 .52288 Mdot
.92 .52333 Mdot
.92 .52408 Mdot
.92 .52427 Mdot
.92 .52439 Mdot
.92 .52618 Mdot
.92 .52626 Mdot
.92 .52643 Mdot
.92 .52677 Mdot
.92 .52722 Mdot
.92 .52733 Mdot
.92 .52757 Mdot
.92 .52848 Mdot
.92 .52868 Mdot
.92 .52884 Mdot
.92 .53006 Mdot
.92 .53043 Mdot
.92 .53083 Mdot
.92 .53184 Mdot
.92 .53212 Mdot
.92 .53288 Mdot
.92 .5333 Mdot
.92 .53376 Mdot
.92 .53392 Mdot
.92 .53405 Mdot
.92 .53414 Mdot
.92 .53423 Mdot
.92 .53459 Mdot
.92 .53483 Mdot
.92 .5351 Mdot
.92 .53555 Mdot
.92 .53577 Mdot
.92 .53578 Mdot
.92 .536 Mdot
.92 .53714 Mdot
.92 .5374 Mdot
.92 .53769 Mdot
.92 .53805 Mdot
.92 .53808 Mdot
.92 .53836 Mdot
.92 .53879 Mdot
.92 .53898 Mdot
.92 .53946 Mdot
.92 .53958 Mdot
.92 .54076 Mdot
.92 .54134 Mdot
.92 .54307 Mdot
.92 .54307 Mdot
.92 .54331 Mdot
.92 .54388 Mdot
.92 .54456 Mdot
.92 .54465 Mdot
.92 .54473 Mdot
.92 .54523 Mdot
.92 .5455 Mdot
.92 .54589 Mdot
.92 .54604 Mdot
.92 .54623 Mdot
.92 .54643 Mdot
.92 .54743 Mdot
.92 .54747 Mdot
.92 .54766 Mdot
.92 .54971 Mdot
.92 .54972 Mdot
.92 .54974 Mdot
.92 .5499 Mdot
.92 .55014 Mdot
.92 .55086 Mdot
.92 .55123 Mdot
.92 .55131 Mdot
.92 .55135 Mdot
.92 .55264 Mdot
.92 .55289 Mdot
.92 .55317 Mdot
.92 .55411 Mdot
.92 .55435 Mdot
.92 .55441 Mdot
.92 .55529 Mdot
.92 .55576 Mdot
.92 .55592 Mdot
.92 .55614 Mdot
.92 .55633 Mdot
.92 .55634 Mdot
.92 .55647 Mdot
.92 .55705 Mdot
.92 .55706 Mdot
.922 .09976 Mdot
.922 .0999 Mdot
.922 .10005 Mdot
.922 .10027 Mdot
.922 .1006 Mdot
.922 .10142 Mdot
.922 .10209 Mdot
.922 .1021 Mdot
.922 .10301 Mdot
.922 .10413 Mdot
.922 .1047 Mdot
.922 .1049 Mdot
.922 .10593 Mdot
.922 .10674 Mdot
.922 .10687 Mdot
.922 .10697 Mdot
.922 .10751 Mdot
.922 .10953 Mdot
.922 .11172 Mdot
.922 .11336 Mdot
.922 .11449 Mdot
.922 .11501 Mdot
.922 .1151 Mdot
.922 .11525 Mdot
.922 .11554 Mdot
.922 .11591 Mdot
.922 .11681 Mdot
.922 .11742 Mdot
.922 .11743 Mdot
.922 .11773 Mdot
.922 .11839 Mdot
.922 .11889 Mdot
.922 .11911 Mdot
.922 .11924 Mdot
.922 .11948 Mdot
.922 .11952 Mdot
.922 .12023 Mdot
.922 .12025 Mdot
.922 .12074 Mdot
.922 .12195 Mdot
.922 .12202 Mdot
.922 .12248 Mdot
.922 .12263 Mdot
.922 .12289 Mdot
.922 .1232 Mdot
.922 .12356 Mdot
.922 .12513 Mdot
.922 .12635 Mdot
.922 .12671 Mdot
.922 .12687 Mdot
.922 .12729 Mdot
.922 .12814 Mdot
.922 .12877 Mdot
.922 .12921 Mdot
.922 .12957 Mdot
.922 .13041 Mdot
.922 .13127 Mdot
.922 .13204 Mdot
.922 .1357 Mdot
.922 .13579 Mdot
.922 .13699 Mdot
.922 .13926 Mdot
.922 .1398 Mdot
.922 .14029 Mdot
.922 .14082 Mdot
.922 .14228 Mdot
.922 .14244 Mdot
.922 .14266 Mdot
.922 .14693 Mdot
.922 .14761 Mdot
.922 .14877 Mdot
.922 .14905 Mdot
.922 .15074 Mdot
.922 .15114 Mdot
.922 .15141 Mdot
.922 .15183 Mdot
.922 .15223 Mdot
.922 .15318 Mdot
.922 .15506 Mdot
.922 .1568 Mdot
.922 .15751 Mdot
.922 .15794 Mdot
.922 .15892 Mdot
.922 .1591 Mdot
.922 .16028 Mdot
.922 .16057 Mdot
.922 .16094 Mdot
.922 .16201 Mdot
.922 .16316 Mdot
.922 .16327 Mdot
.922 .165 Mdot
.922 .16556 Mdot
.922 .16635 Mdot
.922 .16787 Mdot
.922 .16827 Mdot
.922 .16891 Mdot
.922 .16892 Mdot
.922 .1695 Mdot
.922 .17013 Mdot
.922 .1711 Mdot
.922 .17155 Mdot
.922 .17179 Mdot
.922 .17184 Mdot
.922 .17208 Mdot
.922 .1723 Mdot
.922 .17248 Mdot
.922 .17309 Mdot
.922 .17439 Mdot
.922 .17452 Mdot
.922 .17457 Mdot
.922 .17461 Mdot
.922 .17471 Mdot
.922 .17474 Mdot
.922 .17583 Mdot
.922 .17585 Mdot
.922 .17715 Mdot
.922 .17753 Mdot
.922 .17825 Mdot
.922 .17904 Mdot
.922 .17947 Mdot
.922 .1796 Mdot
.922 .18065 Mdot
.922 .18101 Mdot
.922 .18126 Mdot
.922 .18291 Mdot
.922 .18353 Mdot
.922 .18441 Mdot
.922 .18464 Mdot
.922 .18482 Mdot
.922 .18521 Mdot
.922 .18574 Mdot
.922 .18584 Mdot
.922 .18594 Mdot
.922 .18662 Mdot
.922 .18664 Mdot
.922 .18667 Mdot
.922 .18771 Mdot
.922 .18807 Mdot
.922 .18874 Mdot
.922 .18956 Mdot
.922 .18987 Mdot
.922 .1904 Mdot
.922 .19056 Mdot
.922 .19106 Mdot
.922 .19285 Mdot
.922 .19311 Mdot
.922 .19358 Mdot
.922 .1945 Mdot
.922 .19481 Mdot
.922 .19486 Mdot
.922 .19502 Mdot
.922 .19525 Mdot
.922 .19662 Mdot
.922 .19725 Mdot
.922 .19813 Mdot
.922 .19841 Mdot
.922 .19841 Mdot
.922 .19871 Mdot
.922 .19914 Mdot
.922 .19966 Mdot
.922 .19982 Mdot
.922 .20009 Mdot
.922 .20063 Mdot
.922 .20132 Mdot
.922 .20225 Mdot
.922 .20249 Mdot
.922 .20297 Mdot
.922 .20372 Mdot
.922 .20411 Mdot
.922 .20411 Mdot
.922 .20456 Mdot
.922 .20468 Mdot
.922 .20589 Mdot
.922 .2068 Mdot
.922 .20712 Mdot
.922 .20723 Mdot
.922 .20726 Mdot
.922 .20739 Mdot
.922 .20746 Mdot
.922 .2079 Mdot
.922 .20798 Mdot
.922 .20876 Mdot
.922 .20929 Mdot
.922 .20932 Mdot
.922 .21022 Mdot
.922 .21099 Mdot
.922 .21107 Mdot
.922 .21145 Mdot
.922 .21172 Mdot
.922 .21246 Mdot
.922 .21249 Mdot
.922 .21258 Mdot
.922 .21344 Mdot
.922 .21349 Mdot
.922 .21356 Mdot
.922 .21372 Mdot
.922 .21386 Mdot
.922 .21418 Mdot
.922 .21433 Mdot
.922 .21477 Mdot
.922 .21509 Mdot
.922 .21542 Mdot
.922 .21617 Mdot
.922 .21734 Mdot
.922 .21809 Mdot
.922 .21832 Mdot
.922 .21976 Mdot
.922 .22035 Mdot
.922 .22056 Mdot
.922 .22112 Mdot
.922 .22123 Mdot
.922 .22153 Mdot
.922 .22228 Mdot
.922 .2223 Mdot
.922 .22261 Mdot
.922 .22353 Mdot
.922 .22355 Mdot
.922 .22384 Mdot
.922 .22387 Mdot
.922 .22423 Mdot
.922 .22502 Mdot
.922 .22574 Mdot
.922 .22584 Mdot
.922 .22606 Mdot
.922 .22629 Mdot
.922 .2264 Mdot
.922 .2265 Mdot
.922 .22667 Mdot
.922 .22708 Mdot
.922 .22711 Mdot
.922 .22721 Mdot
.922 .22806 Mdot
.922 .22851 Mdot
.922 .22964 Mdot
.922 .23022 Mdot
.922 .23038 Mdot
.922 .23107 Mdot
.922 .23443 Mdot
.922 .23472 Mdot
.922 .236 Mdot
.922 .23687 Mdot
.922 .23712 Mdot
.922 .23718 Mdot
.922 .23782 Mdot
.922 .23798 Mdot
.922 .23969 Mdot
.922 .24019 Mdot
.922 .24037 Mdot
.922 .2411 Mdot
.922 .24277 Mdot
.922 .24285 Mdot
.922 .24326 Mdot
.922 .24362 Mdot
.922 .24438 Mdot
.922 .24538 Mdot
.922 .2455 Mdot
.922 .24611 Mdot
.922 .24627 Mdot
.922 .24652 Mdot
.922 .24656 Mdot
.922 .24721 Mdot
.922 .24726 Mdot
.922 .24768 Mdot
.922 .24834 Mdot
.922 .24836 Mdot
.922 .24973 Mdot
.922 .2499 Mdot
.922 .24994 Mdot
.922 .25022 Mdot
.922 .25025 Mdot
.922 .25064 Mdot
.922 .252 Mdot
.922 .25233 Mdot
.922 .25291 Mdot
.922 .25368 Mdot
.922 .25537 Mdot
.922 .25618 Mdot
.922 .25635 Mdot
.922 .2572 Mdot
.922 .25723 Mdot
.922 .25851 Mdot
.922 .25889 Mdot
.922 .25978 Mdot
.922 .26029 Mdot
.922 .2609 Mdot
.922 .26154 Mdot
.922 .26191 Mdot
.922 .26206 Mdot
.922 .26225 Mdot
.922 .26243 Mdot
.922 .26333 Mdot
.922 .26549 Mdot
.922 .26554 Mdot
.922 .26614 Mdot
.922 .26628 Mdot
.922 .2666 Mdot
.922 .26678 Mdot
.922 .26756 Mdot
.922 .26758 Mdot
.922 .26829 Mdot
.922 .26932 Mdot
.922 .26957 Mdot
.922 .27004 Mdot
.922 .27232 Mdot
.922 .2724 Mdot
.922 .27351 Mdot
.922 .27361 Mdot
.922 .27395 Mdot
.922 .27671 Mdot
.922 .27693 Mdot
.922 .27799 Mdot
.922 .27803 Mdot
.922 .27807 Mdot
.922 .27882 Mdot
.922 .28063 Mdot
.922 .28097 Mdot
.922 .28156 Mdot
.922 .28162 Mdot
.922 .28167 Mdot
.922 .28314 Mdot
.922 .28367 Mdot
.922 .28408 Mdot
.922 .2841 Mdot
.922 .2843 Mdot
.922 .28435 Mdot
.922 .28451 Mdot
.922 .28633 Mdot
.922 .28688 Mdot
.922 .28764 Mdot
.922 .28844 Mdot
.922 .28866 Mdot
.922 .29006 Mdot
.922 .29184 Mdot
.922 .29266 Mdot
.922 .29287 Mdot
.922 .29421 Mdot
.922 .29433 Mdot
.922 .29445 Mdot
.922 .29465 Mdot
.922 .29523 Mdot
.922 .29577 Mdot
.922 .29714 Mdot
.922 .29786 Mdot
.922 .29905 Mdot
.922 .29907 Mdot
.922 .30015 Mdot
.922 .30037 Mdot
.922 .30098 Mdot
.922 .30129 Mdot
.922 .30172 Mdot
.922 .30182 Mdot
.922 .30218 Mdot
.922 .30275 Mdot
.922 .30291 Mdot
.922 .30296 Mdot
.922 .30309 Mdot
.922 .30347 Mdot
.922 .30362 Mdot
.922 .30384 Mdot
.922 .30391 Mdot
.922 .30402 Mdot
.922 .30436 Mdot
.922 .30445 Mdot
.922 .30463 Mdot
.922 .30489 Mdot
.922 .30509 Mdot
.922 .30531 Mdot
.922 .30564 Mdot
.922 .30677 Mdot
.922 .30783 Mdot
.922 .30813 Mdot
.922 .30819 Mdot
.922 .30835 Mdot
.922 .30915 Mdot
.922 .30939 Mdot
.922 .30949 Mdot
.922 .30955 Mdot
.922 .30975 Mdot
.922 .30979 Mdot
.922 .31044 Mdot
.922 .31044 Mdot
.922 .31071 Mdot
.922 .31181 Mdot
.922 .31184 Mdot
.922 .31187 Mdot
.922 .31203 Mdot
.922 .31327 Mdot
.922 .31424 Mdot
.922 .31426 Mdot
.922 .31439 Mdot
.922 .31495 Mdot
.922 .31523 Mdot
.922 .31544 Mdot
.922 .31556 Mdot
.922 .31578 Mdot
.922 .31628 Mdot
.922 .31655 Mdot
.922 .31675 Mdot
.922 .31773 Mdot
.922 .31785 Mdot
.922 .31828 Mdot
.922 .31852 Mdot
.922 .31877 Mdot
.922 .3207 Mdot
.922 .32137 Mdot
.922 .32167 Mdot
.922 .32183 Mdot
.922 .32231 Mdot
.922 .32237 Mdot
.922 .32382 Mdot
.922 .32425 Mdot
.922 .32486 Mdot
.922 .32546 Mdot
.922 .32602 Mdot
.922 .32686 Mdot
.922 .32715 Mdot
.922 .3272 Mdot
.922 .32764 Mdot
.922 .32774 Mdot
.922 .32806 Mdot
.922 .3284 Mdot
.922 .32843 Mdot
.922 .32894 Mdot
.922 .3291 Mdot
.922 .32978 Mdot
.922 .3299 Mdot
.922 .33009 Mdot
.922 .33009 Mdot
.922 .33026 Mdot
.922 .33045 Mdot
.922 .33109 Mdot
.922 .3317 Mdot
.922 .33174 Mdot
.922 .3318 Mdot
.922 .3318 Mdot
.922 .33284 Mdot
.922 .33319 Mdot
.922 .33372 Mdot
.922 .33439 Mdot
.922 .3353 Mdot
.922 .33562 Mdot
.922 .33592 Mdot
.922 .33641 Mdot
.922 .33646 Mdot
.922 .3366 Mdot
.922 .33713 Mdot
.922 .3372 Mdot
.922 .33761 Mdot
.922 .3377 Mdot
.922 .33868 Mdot
.922 .33876 Mdot
.922 .33898 Mdot
.922 .33989 Mdot
.922 .33997 Mdot
.922 .34033 Mdot
.922 .34181 Mdot
.922 .34249 Mdot
.922 .3426 Mdot
.922 .3429 Mdot
.922 .3432 Mdot
.922 .34322 Mdot
.922 .34331 Mdot
.922 .34345 Mdot
.922 .34367 Mdot
.922 .34399 Mdot
.922 .34433 Mdot
.922 .34455 Mdot
.922 .34504 Mdot
.922 .34522 Mdot
.922 .34615 Mdot
.922 .34616 Mdot
.922 .34624 Mdot
.922 .34636 Mdot
.922 .3468 Mdot
.922 .3469 Mdot
.922 .34696 Mdot
.922 .3472 Mdot
.922 .3472 Mdot
.922 .34723 Mdot
.922 .34761 Mdot
.922 .34812 Mdot
.922 .34817 Mdot
.922 .34944 Mdot
.922 .35015 Mdot
.922 .35017 Mdot
.922 .3509 Mdot
.922 .35132 Mdot
.922 .35196 Mdot
.922 .35206 Mdot
.922 .35291 Mdot
.922 .35292 Mdot
.922 .35345 Mdot
.922 .35345 Mdot
.922 .354 Mdot
.922 .35452 Mdot
.922 .35462 Mdot
.922 .35479 Mdot
.922 .35502 Mdot
.922 .35552 Mdot
.922 .35575 Mdot
.922 .3558 Mdot
.922 .35605 Mdot
.922 .35655 Mdot
.922 .35754 Mdot
.922 .35868 Mdot
.922 .35882 Mdot
.922 .35969 Mdot
.922 .36052 Mdot
.922 .36098 Mdot
.922 .36186 Mdot
.922 .36324 Mdot
.922 .36325 Mdot
.922 .36396 Mdot
.922 .36396 Mdot
.922 .36409 Mdot
.922 .36478 Mdot
.922 .36501 Mdot
.922 .36694 Mdot
.922 .36701 Mdot
.922 .36724 Mdot
.922 .36893 Mdot
.922 .36928 Mdot
.922 .36951 Mdot
.922 .36971 Mdot
.922 .36977 Mdot
.922 .36982 Mdot
.922 .37 Mdot
.922 .37014 Mdot
.922 .37094 Mdot
.922 .3711 Mdot
.922 .37171 Mdot
.922 .37179 Mdot
.922 .37254 Mdot
.922 .37318 Mdot
.922 .37322 Mdot
.922 .37351 Mdot
.922 .37357 Mdot
.922 .3752 Mdot
.922 .37522 Mdot
.922 .37565 Mdot
.922 .37664 Mdot
.922 .3768 Mdot
.922 .37715 Mdot
.922 .3774 Mdot
.922 .37743 Mdot
.922 .37749 Mdot
.922 .37778 Mdot
.922 .37799 Mdot
.922 .3784 Mdot
.922 .37935 Mdot
.922 .37936 Mdot
.922 .3794 Mdot
.922 .37958 Mdot
.922 .38004 Mdot
.922 .38039 Mdot
.922 .3805 Mdot
.922 .38094 Mdot
.922 .38114 Mdot
.922 .38117 Mdot
.922 .38126 Mdot
.922 .38135 Mdot
.922 .38138 Mdot
.922 .38168 Mdot
.922 .38189 Mdot
.922 .38194 Mdot
.922 .38221 Mdot
.922 .38245 Mdot
.922 .38253 Mdot
.922 .38279 Mdot
.922 .38281 Mdot
.922 .38318 Mdot
.922 .38361 Mdot
.922 .38392 Mdot
.922 .38395 Mdot
.922 .3842 Mdot
.922 .3847 Mdot
.922 .38482 Mdot
.922 .38505 Mdot
.922 .3859 Mdot
.922 .3862 Mdot
.922 .38724 Mdot
.922 .38749 Mdot
.922 .38835 Mdot
.922 .38973 Mdot
.922 .39016 Mdot
.922 .39017 Mdot
.922 .39076 Mdot
.922 .3914 Mdot
.922 .39141 Mdot
.922 .39152 Mdot
.922 .3917 Mdot
.922 .39198 Mdot
.922 .39244 Mdot
.922 .3925 Mdot
.922 .39256 Mdot
.922 .39282 Mdot
.922 .39332 Mdot
.922 .3939 Mdot
.922 .3943 Mdot
.922 .39533 Mdot
.922 .39552 Mdot
.922 .39561 Mdot
.922 .39569 Mdot
.922 .39583 Mdot
.922 .39608 Mdot
.922 .39676 Mdot
.922 .39682 Mdot
.922 .39746 Mdot
.922 .3975 Mdot
.922 .398 Mdot
.922 .39808 Mdot
.922 .39812 Mdot
.922 .39936 Mdot
.922 .39977 Mdot
.922 .3998 Mdot
.922 .39984 Mdot
.922 .40009 Mdot
.922 .40024 Mdot
.922 .40034 Mdot
.922 .40039 Mdot
.922 .4004 Mdot
.922 .40075 Mdot
.922 .40107 Mdot
.922 .40252 Mdot
.922 .40266 Mdot
.922 .40339 Mdot
.922 .40384 Mdot
.922 .40403 Mdot
.922 .40444 Mdot
.922 .40446 Mdot
.922 .40486 Mdot
.922 .40507 Mdot
.922 .40525 Mdot
.922 .40538 Mdot
.922 .40556 Mdot
.922 .40585 Mdot
.922 .40597 Mdot
.922 .40608 Mdot
.922 .40631 Mdot
.922 .40637 Mdot
.922 .40656 Mdot
.922 .40694 Mdot
.922 .40745 Mdot
.922 .40779 Mdot
.922 .40798 Mdot
.922 .40799 Mdot
.922 .40813 Mdot
.922 .40894 Mdot
.922 .40919 Mdot
.922 .41026 Mdot
.922 .41028 Mdot
.922 .41104 Mdot
.922 .41108 Mdot
.922 .4121 Mdot
.922 .4124 Mdot
.922 .41363 Mdot
.922 .41367 Mdot
.922 .41521 Mdot
.922 .41567 Mdot
.922 .4176 Mdot
.922 .41814 Mdot
.922 .41971 Mdot
.922 .41986 Mdot
.922 .42013 Mdot
.922 .42035 Mdot
.922 .4204 Mdot
.922 .42127 Mdot
.922 .42174 Mdot
.922 .42179 Mdot
.922 .42236 Mdot
.922 .42276 Mdot
.922 .42316 Mdot
.922 .42385 Mdot
.922 .42387 Mdot
.922 .42435 Mdot
.922 .42437 Mdot
.922 .4245 Mdot
.922 .42483 Mdot
.922 .42494 Mdot
.922 .42494 Mdot
.922 .42545 Mdot
.922 .42554 Mdot
.922 .42593 Mdot
.922 .42611 Mdot
.922 .42641 Mdot
.922 .42648 Mdot
.922 .42653 Mdot
.922 .4267 Mdot
.922 .42687 Mdot
.922 .42693 Mdot
.922 .42729 Mdot
.922 .4281 Mdot
.922 .42829 Mdot
.922 .42895 Mdot
.922 .42957 Mdot
.922 .42979 Mdot
.922 .43012 Mdot
.922 .4302 Mdot
.922 .43022 Mdot
.922 .43049 Mdot
.922 .43082 Mdot
.922 .43197 Mdot
.922 .43216 Mdot
.922 .43272 Mdot
.922 .43311 Mdot
.922 .43365 Mdot
.922 .43375 Mdot
.922 .43382 Mdot
.922 .43427 Mdot
.922 .43492 Mdot
.922 .43521 Mdot
.922 .43524 Mdot
.922 .4354 Mdot
.922 .43616 Mdot
.922 .43682 Mdot
.922 .43705 Mdot
.922 .43784 Mdot
.922 .43787 Mdot
.922 .43822 Mdot
.922 .44005 Mdot
.922 .44029 Mdot
.922 .44088 Mdot
.922 .44099 Mdot
.922 .44141 Mdot
.922 .44153 Mdot
.922 .44159 Mdot
.922 .44171 Mdot
.922 .44216 Mdot
.922 .44223 Mdot
.922 .44277 Mdot
.922 .44344 Mdot
.922 .44353 Mdot
.922 .44416 Mdot
.922 .44431 Mdot
.922 .44431 Mdot
.922 .44544 Mdot
.922 .44553 Mdot
.922 .44556 Mdot
.922 .44572 Mdot
.922 .44721 Mdot
.922 .44746 Mdot
.922 .44779 Mdot
.922 .44788 Mdot
.922 .448 Mdot
.922 .44808 Mdot
.922 .44836 Mdot
.922 .44839 Mdot
.922 .44848 Mdot
.922 .44879 Mdot
.922 .44898 Mdot
.922 .44904 Mdot
.922 .44944 Mdot
.922 .44976 Mdot
.922 .45226 Mdot
.922 .45256 Mdot
.922 .45287 Mdot
.922 .45298 Mdot
.922 .45311 Mdot
.922 .45395 Mdot
.922 .45536 Mdot
.922 .45667 Mdot
.922 .45708 Mdot
.922 .45837 Mdot
.922 .45848 Mdot
.922 .45859 Mdot
.922 .4586 Mdot
.922 .45991 Mdot
.922 .45993 Mdot
.922 .45997 Mdot
.922 .46186 Mdot
.922 .4619 Mdot
.922 .46248 Mdot
.922 .4641 Mdot
.922 .46428 Mdot
.922 .46494 Mdot
.922 .46498 Mdot
.922 .46647 Mdot
.922 .46661 Mdot
.922 .46755 Mdot
.922 .46808 Mdot
.922 .46833 Mdot
.922 .46868 Mdot
.922 .46985 Mdot
.922 .47044 Mdot
.922 .47054 Mdot
.922 .47083 Mdot
.922 .47117 Mdot
.922 .47151 Mdot
.922 .47226 Mdot
.922 .47316 Mdot
.922 .47318 Mdot
.922 .47364 Mdot
.922 .47373 Mdot
.922 .47417 Mdot
.922 .47509 Mdot
.922 .4755 Mdot
.922 .47582 Mdot
.922 .476 Mdot
.922 .47697 Mdot
.922 .47714 Mdot
.922 .47723 Mdot
.922 .47797 Mdot
.922 .47798 Mdot
.922 .47834 Mdot
.922 .47859 Mdot
.922 .47895 Mdot
.922 .47897 Mdot
.922 .47919 Mdot
.922 .47952 Mdot
.922 .48054 Mdot
.922 .48074 Mdot
.922 .48096 Mdot
.922 .481 Mdot
.922 .48191 Mdot
.922 .4823 Mdot
.922 .48267 Mdot
.922 .48404 Mdot
.922 .48407 Mdot
.922 .4842 Mdot
.922 .48468 Mdot
.922 .48537 Mdot
.922 .48553 Mdot
.922 .48772 Mdot
.922 .48781 Mdot
.922 .48874 Mdot
.922 .48944 Mdot
.922 .4895 Mdot
.922 .48951 Mdot
.922 .48973 Mdot
.922 .48988 Mdot
.922 .48994 Mdot
.922 .49006 Mdot
.922 .49024 Mdot
.922 .49106 Mdot
.922 .49127 Mdot
.922 .49143 Mdot
.922 .49144 Mdot
.922 .49194 Mdot
.922 .49212 Mdot
.922 .49274 Mdot
.922 .49316 Mdot
.922 .49348 Mdot
.922 .49439 Mdot
.922 .4948 Mdot
.922 .49543 Mdot
.922 .49602 Mdot
.922 .49643 Mdot
.922 .49668 Mdot
.922 .49685 Mdot
.922 .49688 Mdot
.922 .49743 Mdot
.922 .49784 Mdot
.922 .49799 Mdot
.922 .49819 Mdot
.922 .49824 Mdot
.922 .49944 Mdot
.922 .50019 Mdot
.922 .50026 Mdot
.922 .50034 Mdot
.922 .50173 Mdot
.922 .50218 Mdot
.922 .50285 Mdot
.922 .50298 Mdot
.922 .50466 Mdot
.922 .50506 Mdot
.922 .50506 Mdot
.922 .50521 Mdot
.922 .50569 Mdot
.922 .50678 Mdot
.922 .5069 Mdot
.922 .50699 Mdot
.922 .50702 Mdot
.922 .50718 Mdot
.922 .50794 Mdot
.922 .50807 Mdot
.922 .50905 Mdot
.922 .50932 Mdot
.922 .5094 Mdot
.922 .50969 Mdot
.922 .5103 Mdot
.922 .51067 Mdot
.922 .51086 Mdot
.922 .51143 Mdot
.922 .51145 Mdot
.922 .51146 Mdot
.922 .51182 Mdot
.922 .51193 Mdot
.922 .51222 Mdot
.922 .51313 Mdot
.922 .51436 Mdot
.922 .51533 Mdot
.922 .51557 Mdot
.922 .51599 Mdot
.922 .51659 Mdot
.922 .5179 Mdot
.922 .51791 Mdot
.922 .51799 Mdot
.922 .51802 Mdot
.922 .51809 Mdot
.922 .51922 Mdot
.922 .51947 Mdot
.922 .51987 Mdot
.922 .5204 Mdot
.922 .52074 Mdot
.922 .52105 Mdot
.922 .52106 Mdot
.922 .52141 Mdot
.922 .52162 Mdot
.922 .52245 Mdot
.922 .52288 Mdot
.922 .52318 Mdot
.922 .52411 Mdot
.922 .52418 Mdot
.922 .5248 Mdot
.922 .52538 Mdot
.922 .52558 Mdot
.922 .52574 Mdot
.922 .52638 Mdot
.922 .52648 Mdot
.922 .52701 Mdot
.922 .52724 Mdot
.922 .52763 Mdot
.922 .52857 Mdot
.922 .52959 Mdot
.922 .5301 Mdot
.922 .53032 Mdot
.922 .53055 Mdot
.922 .5307 Mdot
.922 .53091 Mdot
.922 .53183 Mdot
.922 .53198 Mdot
.922 .53261 Mdot
.922 .53298 Mdot
.922 .53529 Mdot
.922 .53541 Mdot
.922 .5355 Mdot
.922 .53629 Mdot
.922 .53658 Mdot
.922 .53684 Mdot
.922 .53714 Mdot
.922 .53837 Mdot
.922 .53902 Mdot
.922 .53907 Mdot
.922 .54105 Mdot
.922 .54147 Mdot
.922 .54193 Mdot
.922 .54239 Mdot
.922 .54259 Mdot
.922 .54283 Mdot
.922 .54317 Mdot
.922 .54363 Mdot
.922 .54386 Mdot
.922 .54394 Mdot
.922 .54414 Mdot
.922 .5448 Mdot
.922 .54565 Mdot
.922 .54584 Mdot
.922 .54602 Mdot
.922 .54615 Mdot
.922 .54623 Mdot
.922 .54649 Mdot
.922 .54652 Mdot
.922 .54718 Mdot
.922 .54745 Mdot
.922 .54746 Mdot
.922 .54784 Mdot
.922 .54787 Mdot
.922 .54799 Mdot
.922 .54806 Mdot
.922 .54819 Mdot
.922 .54846 Mdot
.922 .54881 Mdot
.922 .54898 Mdot
.922 .54898 Mdot
.922 .54931 Mdot
.922 .5498 Mdot
.922 .55 Mdot
.922 .55016 Mdot
.922 .55024 Mdot
.922 .55029 Mdot
.922 .55057 Mdot
.922 .55118 Mdot
.922 .55207 Mdot
.922 .55326 Mdot
.922 .55435 Mdot
.922 .55465 Mdot
.922 .5547 Mdot
.922 .55477 Mdot
.922 .55521 Mdot
.922 .55577 Mdot
.922 .55588 Mdot
.922 .55619 Mdot
.922 .5568 Mdot
.922 .55729 Mdot
.922 .5573 Mdot
.922 .55766 Mdot
.922 .5581 Mdot
.922 .55828 Mdot
.922 .5584 Mdot
.922 .55848 Mdot
.922 .55856 Mdot
.924 .09907 Mdot
.924 .09917 Mdot
.924 .0992 Mdot
.924 .10047 Mdot
.924 .10058 Mdot
.924 .10183 Mdot
.924 .10348 Mdot
.924 .10443 Mdot
.924 .10459 Mdot
.924 .10487 Mdot
.924 .10536 Mdot
.924 .10557 Mdot
.924 .10598 Mdot
.924 .10604 Mdot
.924 .10617 Mdot
.924 .10657 Mdot
.924 .10817 Mdot
.924 .1102 Mdot
.924 .11024 Mdot
.924 .11158 Mdot
.924 .11182 Mdot
.924 .11217 Mdot
.924 .11238 Mdot
.924 .11253 Mdot
.924 .11357 Mdot
.924 .11489 Mdot
.924 .11504 Mdot
.924 .11634 Mdot
.924 .11697 Mdot
.924 .11965 Mdot
.924 .11992 Mdot
.924 .1211 Mdot
.924 .12252 Mdot
.924 .12328 Mdot
.924 .1241 Mdot
.924 .12515 Mdot
.924 .12541 Mdot
.924 .1266 Mdot
.924 .12958 Mdot
.924 .12958 Mdot
.924 .13005 Mdot
.924 .13296 Mdot
.924 .13399 Mdot
.924 .13439 Mdot
.924 .13467 Mdot
.924 .1358 Mdot
.924 .13656 Mdot
.924 .13768 Mdot
.924 .13837 Mdot
.924 .1411 Mdot
.924 .14112 Mdot
.924 .14163 Mdot
.924 .14242 Mdot
.924 .14275 Mdot
.924 .1437 Mdot
.924 .14534 Mdot
.924 .14734 Mdot
.924 .14749 Mdot
.924 .14766 Mdot
.924 .14841 Mdot
.924 .14867 Mdot
.924 .14871 Mdot
.924 .14926 Mdot
.924 .1494 Mdot
.924 .14981 Mdot
.924 .15036 Mdot
.924 .15079 Mdot
.924 .1516 Mdot
.924 .15294 Mdot
.924 .15304 Mdot
.924 .15346 Mdot
.924 .15427 Mdot
.924 .1546 Mdot
.924 .15499 Mdot
.924 .15529 Mdot
.924 .15678 Mdot
.924 .15724 Mdot
.924 .15733 Mdot
.924 .15914 Mdot
.924 .15948 Mdot
.924 .15989 Mdot
.924 .16148 Mdot
.924 .16174 Mdot
.924 .16174 Mdot
.924 .16253 Mdot
.924 .16327 Mdot
.924 .16555 Mdot
.924 .16643 Mdot
.924 .16723 Mdot
.924 .16744 Mdot
.924 .17013 Mdot
.924 .17061 Mdot
.924 .1708 Mdot
.924 .17084 Mdot
.924 .17202 Mdot
.924 .17208 Mdot
.924 .17212 Mdot
.924 .17318 Mdot
.924 .1734 Mdot
.924 .17366 Mdot
.924 .1741 Mdot
.924 .17567 Mdot
.924 .1757 Mdot
.924 .17602 Mdot
.924 .17708 Mdot
.924 .1771 Mdot
.924 .17871 Mdot
.924 .17875 Mdot
.924 .17994 Mdot
.924 .18017 Mdot
.924 .18021 Mdot
.924 .18051 Mdot
.924 .1808 Mdot
.924 .18132 Mdot
.924 .18222 Mdot
.924 .18261 Mdot
.924 .18337 Mdot
.924 .18344 Mdot
.924 .18348 Mdot
.924 .18372 Mdot
.924 .18379 Mdot
.924 .1838 Mdot
.924 .18421 Mdot
.924 .18446 Mdot
.924 .1845 Mdot
.924 .18537 Mdot
.924 .18646 Mdot
.924 .18677 Mdot
.924 .18739 Mdot
.924 .18742 Mdot
.924 .18743 Mdot
.924 .18811 Mdot
.924 .18847 Mdot
.924 .18868 Mdot
.924 .18877 Mdot
.924 .18939 Mdot
.924 .18956 Mdot
.924 .19117 Mdot
.924 .19125 Mdot
.924 .19133 Mdot
.924 .19258 Mdot
.924 .1935 Mdot
.924 .19363 Mdot
.924 .19372 Mdot
.924 .19376 Mdot
.924 .19383 Mdot
.924 .19394 Mdot
.924 .194 Mdot
.924 .19417 Mdot
.924 .19481 Mdot
.924 .1952 Mdot
.924 .19547 Mdot
.924 .19691 Mdot
.924 .1974 Mdot
.924 .19969 Mdot
.924 .19984 Mdot
.924 .20011 Mdot
.924 .20057 Mdot
.924 .20083 Mdot
.924 .20098 Mdot
.924 .20104 Mdot
.924 .20162 Mdot
.924 .20252 Mdot
.924 .20347 Mdot
.924 .20368 Mdot
.924 .20378 Mdot
.924 .20382 Mdot
.924 .20432 Mdot
.924 .20479 Mdot
.924 .20493 Mdot
.924 .2055 Mdot
.924 .20736 Mdot
.924 .20781 Mdot
.924 .20837 Mdot
.924 .20863 Mdot
.924 .20914 Mdot
.924 .20972 Mdot
.924 .21131 Mdot
.924 .21195 Mdot
.924 .21274 Mdot
.924 .21395 Mdot
.924 .2141 Mdot
.924 .21455 Mdot
.924 .21535 Mdot
.924 .2154 Mdot
.924 .21685 Mdot
.924 .21706 Mdot
.924 .21781 Mdot
.924 .21848 Mdot
.924 .21854 Mdot
.924 .2188 Mdot
.924 .21928 Mdot
.924 .21934 Mdot
.924 .21966 Mdot
.924 .21989 Mdot
.924 .22013 Mdot
.924 .22061 Mdot
.924 .22128 Mdot
.924 .22148 Mdot
.924 .22167 Mdot
.924 .22213 Mdot
.924 .22223 Mdot
.924 .22231 Mdot
.924 .22277 Mdot
.924 .22421 Mdot
.924 .22553 Mdot
.924 .22678 Mdot
.924 .2268 Mdot
.924 .22683 Mdot
.924 .22698 Mdot
.924 .22698 Mdot
.924 .22785 Mdot
.924 .22811 Mdot
.924 .22877 Mdot
.924 .2292 Mdot
.924 .22922 Mdot
.924 .22936 Mdot
.924 .23012 Mdot
.924 .23095 Mdot
.924 .23198 Mdot
.924 .23253 Mdot
.924 .23264 Mdot
.924 .23323 Mdot
.924 .2339 Mdot
.924 .23409 Mdot
.924 .23434 Mdot
.924 .23506 Mdot
.924 .23514 Mdot
.924 .23588 Mdot
.924 .23639 Mdot
.924 .23748 Mdot
.924 .23847 Mdot
.924 .23979 Mdot
.924 .23988 Mdot
.924 .24006 Mdot
.924 .24016 Mdot
.924 .24106 Mdot
.924 .24195 Mdot
.924 .24272 Mdot
.924 .24314 Mdot
.924 .24322 Mdot
.924 .24329 Mdot
.924 .24363 Mdot
.924 .24484 Mdot
.924 .24621 Mdot
.924 .2465 Mdot
.924 .24698 Mdot
.924 .24783 Mdot
.924 .24827 Mdot
.924 .24831 Mdot
.924 .24887 Mdot
.924 .24925 Mdot
.924 .25037 Mdot
.924 .25071 Mdot
.924 .25102 Mdot
.924 .25132 Mdot
.924 .25146 Mdot
.924 .25168 Mdot
.924 .25201 Mdot
.924 .25215 Mdot
.924 .25237 Mdot
.924 .25308 Mdot
.924 .25495 Mdot
.924 .25498 Mdot
.924 .25585 Mdot
.924 .2561 Mdot
.924 .25645 Mdot
.924 .25666 Mdot
.924 .25704 Mdot
.924 .2572 Mdot
.924 .25757 Mdot
.924 .25827 Mdot
.924 .25855 Mdot
.924 .25931 Mdot
.924 .25958 Mdot
.924 .25981 Mdot
.924 .26008 Mdot
.924 .26021 Mdot
.924 .26039 Mdot
.924 .26121 Mdot
.924 .26178 Mdot
.924 .26226 Mdot
.924 .26234 Mdot
.924 .26311 Mdot
.924 .26317 Mdot
.924 .26335 Mdot
.924 .26362 Mdot
.924 .26437 Mdot
.924 .26476 Mdot
.924 .26496 Mdot
.924 .2654 Mdot
.924 .2657 Mdot
.924 .26595 Mdot
.924 .26609 Mdot
.924 .26617 Mdot
.924 .26657 Mdot
.924 .26703 Mdot
.924 .26768 Mdot
.924 .26795 Mdot
.924 .26873 Mdot
.924 .26965 Mdot
.924 .26978 Mdot
.924 .27015 Mdot
.924 .27018 Mdot
.924 .27034 Mdot
.924 .27111 Mdot
.924 .27186 Mdot
.924 .27223 Mdot
.924 .27262 Mdot
.924 .27317 Mdot
.924 .2732 Mdot
.924 .27322 Mdot
.924 .27395 Mdot
.924 .27428 Mdot
.924 .27449 Mdot
.924 .27471 Mdot
.924 .27545 Mdot
.924 .27558 Mdot
.924 .27686 Mdot
.924 .27725 Mdot
.924 .27742 Mdot
.924 .27809 Mdot
.924 .27826 Mdot
.924 .27869 Mdot
.924 .2794 Mdot
.924 .27954 Mdot
.924 .28061 Mdot
.924 .28146 Mdot
.924 .28148 Mdot
.924 .28161 Mdot
.924 .28224 Mdot
.924 .28276 Mdot
.924 .28299 Mdot
.924 .2834 Mdot
.924 .28367 Mdot
.924 .28445 Mdot
.924 .28455 Mdot
.924 .28594 Mdot
.924 .28641 Mdot
.924 .28642 Mdot
.924 .28683 Mdot
.924 .28787 Mdot
.924 .28924 Mdot
.924 .28953 Mdot
.924 .28979 Mdot
.924 .29068 Mdot
.924 .29091 Mdot
.924 .29157 Mdot
.924 .29333 Mdot
.924 .29346 Mdot
.924 .29388 Mdot
.924 .29412 Mdot
.924 .29424 Mdot
.924 .29456 Mdot
.924 .29508 Mdot
.924 .29571 Mdot
.924 .29647 Mdot
.924 .29657 Mdot
.924 .29695 Mdot
.924 .29695 Mdot
.924 .29795 Mdot
.924 .29903 Mdot
.924 .30019 Mdot
.924 .30033 Mdot
.924 .3012 Mdot
.924 .30193 Mdot
.924 .30281 Mdot
.924 .30315 Mdot
.924 .30323 Mdot
.924 .30402 Mdot
.924 .3042 Mdot
.924 .30505 Mdot
.924 .30532 Mdot
.924 .30542 Mdot
.924 .30552 Mdot
.924 .3056 Mdot
.924 .306 Mdot
.924 .30722 Mdot
.924 .30736 Mdot
.924 .30756 Mdot
.924 .30797 Mdot
.924 .30845 Mdot
.924 .30881 Mdot
.924 .30885 Mdot
.924 .30926 Mdot
.924 .31016 Mdot
.924 .31017 Mdot
.924 .3117 Mdot
.924 .31175 Mdot
.924 .31198 Mdot
.924 .31216 Mdot
.924 .31221 Mdot
.924 .31233 Mdot
.924 .3128 Mdot
.924 .31341 Mdot
.924 .31403 Mdot
.924 .31438 Mdot
.924 .31477 Mdot
.924 .31481 Mdot
.924 .317 Mdot
.924 .31722 Mdot
.924 .31777 Mdot
.924 .31785 Mdot
.924 .31907 Mdot
.924 .32006 Mdot
.924 .32048 Mdot
.924 .32056 Mdot
.924 .32089 Mdot
.924 .32111 Mdot
.924 .32164 Mdot
.924 .3226 Mdot
.924 .3232 Mdot
.924 .32427 Mdot
.924 .32436 Mdot
.924 .32458 Mdot
.924 .32466 Mdot
.924 .32467 Mdot
.924 .32487 Mdot
.924 .32499 Mdot
.924 .32591 Mdot
.924 .3263 Mdot
.924 .32639 Mdot
.924 .32651 Mdot
.924 .3266 Mdot
.924 .32703 Mdot
.924 .32717 Mdot
.924 .32719 Mdot
.924 .32772 Mdot
.924 .32794 Mdot
.924 .32841 Mdot
.924 .32849 Mdot
.924 .32893 Mdot
.924 .33009 Mdot
.924 .33094 Mdot
.924 .3315 Mdot
.924 .33151 Mdot
.924 .33198 Mdot
.924 .3321 Mdot
.924 .33267 Mdot
.924 .33382 Mdot
.924 .33388 Mdot
.924 .3339 Mdot
.924 .33495 Mdot
.924 .33507 Mdot
.924 .33515 Mdot
.924 .33541 Mdot
.924 .33581 Mdot
.924 .33601 Mdot
.924 .33621 Mdot
.924 .33631 Mdot
.924 .33637 Mdot
.924 .33658 Mdot
.924 .33752 Mdot
.924 .33782 Mdot
.924 .33786 Mdot
.924 .33788 Mdot
.924 .3396 Mdot
.924 .33993 Mdot
.924 .33997 Mdot
.924 .34016 Mdot
.924 .3408 Mdot
.924 .34081 Mdot
.924 .34095 Mdot
.924 .34109 Mdot
.924 .34184 Mdot
.924 .34319 Mdot
.924 .34342 Mdot
.924 .3442 Mdot
.924 .3451 Mdot
.924 .34535 Mdot
.924 .34551 Mdot
.924 .34558 Mdot
.924 .34572 Mdot
.924 .34592 Mdot
.924 .34603 Mdot
.924 .34636 Mdot
.924 .34753 Mdot
.924 .34755 Mdot
.924 .34792 Mdot
.924 .34811 Mdot
.924 .34824 Mdot
.924 .34825 Mdot
.924 .34851 Mdot
.924 .34875 Mdot
.924 .34967 Mdot
.924 .34995 Mdot
.924 .35134 Mdot
.924 .35142 Mdot
.924 .3522 Mdot
.924 .35232 Mdot
.924 .35246 Mdot
.924 .35476 Mdot
.924 .35482 Mdot
.924 .35492 Mdot
.924 .35496 Mdot
.924 .35579 Mdot
.924 .35639 Mdot
.924 .35644 Mdot
.924 .35655 Mdot
.924 .35675 Mdot
.924 .35683 Mdot
.924 .35732 Mdot
.924 .35817 Mdot
.924 .35865 Mdot
.924 .35871 Mdot
.924 .35893 Mdot
.924 .35904 Mdot
.924 .36012 Mdot
.924 .36024 Mdot
.924 .36073 Mdot
.924 .36111 Mdot
.924 .36144 Mdot
.924 .36156 Mdot
.924 .36178 Mdot
.924 .36298 Mdot
.924 .36354 Mdot
.924 .36392 Mdot
.924 .36411 Mdot
.924 .36419 Mdot
.924 .36511 Mdot
.924 .36591 Mdot
.924 .36598 Mdot
.924 .36624 Mdot
.924 .3665 Mdot
.924 .36718 Mdot
.924 .36728 Mdot
.924 .36907 Mdot
.924 .36932 Mdot
.924 .3702 Mdot
.924 .37045 Mdot
.924 .37073 Mdot
.924 .37155 Mdot
.924 .37195 Mdot
.924 .37195 Mdot
.924 .3724 Mdot
.924 .37248 Mdot
.924 .37258 Mdot
.924 .37308 Mdot
.924 .37395 Mdot
.924 .37401 Mdot
.924 .37509 Mdot
.924 .37619 Mdot
.924 .37619 Mdot
.924 .37656 Mdot
.924 .37709 Mdot
.924 .37803 Mdot
.924 .37819 Mdot
.924 .3792 Mdot
.924 .37968 Mdot
.924 .38006 Mdot
.924 .38006 Mdot
.924 .38056 Mdot
.924 .38066 Mdot
.924 .38068 Mdot
.924 .38073 Mdot
.924 .38122 Mdot
.924 .38162 Mdot
.924 .38289 Mdot
.924 .38306 Mdot
.924 .3831 Mdot
.924 .38317 Mdot
.924 .3836 Mdot
.924 .384 Mdot
.924 .385 Mdot
.924 .38502 Mdot
.924 .38506 Mdot
.924 .38548 Mdot
.924 .38559 Mdot
.924 .38661 Mdot
.924 .38696 Mdot
.924 .387 Mdot
.924 .38827 Mdot
.924 .38864 Mdot
.924 .38919 Mdot
.924 .38953 Mdot
.924 .3896 Mdot
.924 .39004 Mdot
.924 .39128 Mdot
.924 .39139 Mdot
.924 .39187 Mdot
.924 .3923 Mdot
.924 .39275 Mdot
.924 .39287 Mdot
.924 .39329 Mdot
.924 .3933 Mdot
.924 .39345 Mdot
.924 .39386 Mdot
.924 .39388 Mdot
.924 .39433 Mdot
.924 .39443 Mdot
.924 .39444 Mdot
.924 .39509 Mdot
.924 .39521 Mdot
.924 .396 Mdot
.924 .39629 Mdot
.924 .39629 Mdot
.924 .39645 Mdot
.924 .39662 Mdot
.924 .39681 Mdot
.924 .39716 Mdot
.924 .39802 Mdot
.924 .3982 Mdot
.924 .3982 Mdot
.924 .39836 Mdot
.924 .39885 Mdot
.924 .3992 Mdot
.924 .3992 Mdot
.924 .39951 Mdot
.924 .39981 Mdot
.924 .39982 Mdot
.924 .40036 Mdot
.924 .40182 Mdot
.924 .40186 Mdot
.924 .40204 Mdot
.924 .40323 Mdot
.924 .40325 Mdot
.924 .40344 Mdot
.924 .40427 Mdot
.924 .40429 Mdot
.924 .40431 Mdot
.924 .40507 Mdot
.924 .40534 Mdot
.924 .40536 Mdot
.924 .40614 Mdot
.924 .40635 Mdot
.924 .40662 Mdot
.924 .40665 Mdot
.924 .40671 Mdot
.924 .40698 Mdot
.924 .40698 Mdot
.924 .40718 Mdot
.924 .40799 Mdot
.924 .40859 Mdot
.924 .40888 Mdot
.924 .40907 Mdot
.924 .40907 Mdot
.924 .41029 Mdot
.924 .41108 Mdot
.924 .41113 Mdot
.924 .41137 Mdot
.924 .41137 Mdot
.924 .41218 Mdot
.924 .41232 Mdot
.924 .41279 Mdot
.924 .41293 Mdot
.924 .41395 Mdot
.924 .41432 Mdot
.924 .41464 Mdot
.924 .41622 Mdot
.924 .41699 Mdot
.924 .41706 Mdot
.924 .41723 Mdot
.924 .41744 Mdot
.924 .41771 Mdot
.924 .41853 Mdot
.924 .41959 Mdot
.924 .41976 Mdot
.924 .41979 Mdot
.924 .42012 Mdot
.924 .42056 Mdot
.924 .42058 Mdot
.924 .42064 Mdot
.924 .42067 Mdot
.924 .42191 Mdot
.924 .42206 Mdot
.924 .42252 Mdot
.924 .42327 Mdot
.924 .42343 Mdot
.924 .42405 Mdot
.924 .4242 Mdot
.924 .42427 Mdot
.924 .42437 Mdot
.924 .42457 Mdot
.924 .42639 Mdot
.924 .42693 Mdot
.924 .42766 Mdot
.924 .42822 Mdot
.924 .42857 Mdot
.924 .42867 Mdot
.924 .4287 Mdot
.924 .42888 Mdot
.924 .4298 Mdot
.924 .42982 Mdot
.924 .43051 Mdot
.924 .43065 Mdot
.924 .43082 Mdot
.924 .43114 Mdot
.924 .43133 Mdot
.924 .43139 Mdot
.924 .433 Mdot
.924 .43325 Mdot
.924 .43326 Mdot
.924 .43356 Mdot
.924 .43465 Mdot
.924 .4353 Mdot
.924 .43607 Mdot
.924 .43628 Mdot
.924 .43684 Mdot
.924 .43695 Mdot
.924 .43696 Mdot
.924 .437 Mdot
.924 .43712 Mdot
.924 .43775 Mdot
.924 .439 Mdot
.924 .43998 Mdot
.924 .44098 Mdot
.924 .4411 Mdot
.924 .44252 Mdot
.924 .44271 Mdot
.924 .44305 Mdot
.924 .44363 Mdot
.924 .44382 Mdot
.924 .44394 Mdot
.924 .44397 Mdot
.924 .4448 Mdot
.924 .4448 Mdot
.924 .44551 Mdot
.924 .44553 Mdot
.924 .44632 Mdot
.924 .4464 Mdot
.924 .44706 Mdot
.924 .44743 Mdot
.924 .44757 Mdot
.924 .44803 Mdot
.924 .44813 Mdot
.924 .44965 Mdot
.924 .45013 Mdot
.924 .4502 Mdot
.924 .45083 Mdot
.924 .45141 Mdot
.924 .45196 Mdot
.924 .45221 Mdot
.924 .45262 Mdot
.924 .45325 Mdot
.924 .45342 Mdot
.924 .45349 Mdot
.924 .45362 Mdot
.924 .45391 Mdot
.924 .45487 Mdot
.924 .45522 Mdot
.924 .45535 Mdot
.924 .45583 Mdot
.924 .45597 Mdot
.924 .45743 Mdot
.924 .45866 Mdot
.924 .45872 Mdot
.924 .45914 Mdot
.924 .45929 Mdot
.924 .45963 Mdot
.924 .46032 Mdot
.924 .46033 Mdot
.924 .4608 Mdot
.924 .46138 Mdot
.924 .46145 Mdot
.924 .46184 Mdot
.924 .46252 Mdot
.924 .46283 Mdot
.924 .46352 Mdot
.924 .46359 Mdot
.924 .46399 Mdot
.924 .46422 Mdot
.924 .46481 Mdot
.924 .46482 Mdot
.924 .46533 Mdot
.924 .46553 Mdot
.924 .46644 Mdot
.924 .46666 Mdot
.924 .46673 Mdot
.924 .46722 Mdot
.924 .46765 Mdot
.924 .46814 Mdot
.924 .46839 Mdot
.924 .46865 Mdot
.924 .46873 Mdot
.924 .46886 Mdot
.924 .46927 Mdot
.924 .46937 Mdot
.924 .47023 Mdot
.924 .47026 Mdot
.924 .4713 Mdot
.924 .47183 Mdot
.924 .47218 Mdot
.924 .47232 Mdot
.924 .47273 Mdot
.924 .47288 Mdot
.924 .47326 Mdot
.924 .47346 Mdot
.924 .47355 Mdot
.924 .47375 Mdot
.924 .47387 Mdot
.924 .4742 Mdot
.924 .47467 Mdot
.924 .47468 Mdot
.924 .47607 Mdot
.924 .4762 Mdot
.924 .47627 Mdot
.924 .47645 Mdot
.924 .47657 Mdot
.924 .47681 Mdot
.924 .47716 Mdot
.924 .47797 Mdot
.924 .47853 Mdot
.924 .47899 Mdot
.924 .47925 Mdot
.924 .47941 Mdot
.924 .48015 Mdot
.924 .48081 Mdot
.924 .48099 Mdot
.924 .48107 Mdot
.924 .4813 Mdot
.924 .4822 Mdot
.924 .48269 Mdot
.924 .48274 Mdot
.924 .48288 Mdot
.924 .48413 Mdot
.924 .48544 Mdot
.924 .48583 Mdot
.924 .48597 Mdot
.924 .48607 Mdot
.924 .48675 Mdot
.924 .48681 Mdot
.924 .48711 Mdot
.924 .48767 Mdot
.924 .48811 Mdot
.924 .48853 Mdot
.924 .4886 Mdot
.924 .48861 Mdot
.924 .48885 Mdot
.924 .4892 Mdot
.924 .4899 Mdot
.924 .48991 Mdot
.924 .48992 Mdot
.924 .4906 Mdot
.924 .49132 Mdot
.924 .4921 Mdot
.924 .49234 Mdot
.924 .49239 Mdot
.924 .49244 Mdot
.924 .49269 Mdot
.924 .4929 Mdot
.924 .49326 Mdot
.924 .49352 Mdot
.924 .49365 Mdot
.924 .49378 Mdot
.924 .49395 Mdot
.924 .49438 Mdot
.924 .49441 Mdot
.924 .49478 Mdot
.924 .49519 Mdot
.924 .49608 Mdot
.924 .49654 Mdot
.924 .49679 Mdot
.924 .49752 Mdot
.924 .49795 Mdot
.924 .49915 Mdot
.924 .49989 Mdot
.924 .50019 Mdot
.924 .50043 Mdot
.924 .50144 Mdot
.924 .50175 Mdot
.924 .50182 Mdot
.924 .50208 Mdot
.924 .50235 Mdot
.924 .50237 Mdot
.924 .50254 Mdot
.924 .50354 Mdot
.924 .50385 Mdot
.924 .50389 Mdot
.924 .50397 Mdot
.924 .50411 Mdot
.924 .50458 Mdot
.924 .50609 Mdot
.924 .50766 Mdot
.924 .5077 Mdot
.924 .50775 Mdot
.924 .50779 Mdot
.924 .50786 Mdot
.924 .50794 Mdot
.924 .50843 Mdot
.924 .50911 Mdot
.924 .51007 Mdot
.924 .51016 Mdot
.924 .51049 Mdot
.924 .51054 Mdot
.924 .51065 Mdot
.924 .51085 Mdot
.924 .51122 Mdot
.924 .51124 Mdot
.924 .51158 Mdot
.924 .51174 Mdot
.924 .51233 Mdot
.924 .5128 Mdot
.924 .51296 Mdot
.924 .51318 Mdot
.924 .51319 Mdot
.924 .51338 Mdot
.924 .51512 Mdot
.924 .51515 Mdot
.924 .51527 Mdot
.924 .51594 Mdot
.924 .51681 Mdot
.924 .51682 Mdot
.924 .51739 Mdot
.924 .51758 Mdot
.924 .51843 Mdot
.924 .51867 Mdot
.924 .5195 Mdot
.924 .51952 Mdot
.924 .51955 Mdot
.924 .52058 Mdot
.924 .52203 Mdot
.924 .52215 Mdot
.924 .52258 Mdot
.924 .52306 Mdot
.924 .52429 Mdot
.924 .52469 Mdot
.924 .52512 Mdot
.924 .52512 Mdot
.924 .52526 Mdot
.924 .52612 Mdot
.924 .52634 Mdot
.924 .52653 Mdot
.924 .52751 Mdot
.924 .52756 Mdot
.924 .5278 Mdot
.924 .52861 Mdot
.924 .52877 Mdot
.924 .52898 Mdot
.924 .52916 Mdot
.924 .5296 Mdot
.924 .52983 Mdot
.924 .52988 Mdot
.924 .5306 Mdot
.924 .53105 Mdot
.924 .53127 Mdot
.924 .53158 Mdot
.924 .5318 Mdot
.924 .53187 Mdot
.924 .53217 Mdot
.924 .53219 Mdot
.924 .53233 Mdot
.924 .53274 Mdot
.924 .53283 Mdot
.924 .53291 Mdot
.924 .534 Mdot
.924 .53488 Mdot
.924 .5354 Mdot
.924 .53558 Mdot
.924 .536 Mdot
.924 .53628 Mdot
.924 .53629 Mdot
.924 .53777 Mdot
.924 .53814 Mdot
.924 .53875 Mdot
.924 .53916 Mdot
.924 .53977 Mdot
.924 .53992 Mdot
.924 .54013 Mdot
.924 .54069 Mdot
.924 .54227 Mdot
.924 .54252 Mdot
.924 .54252 Mdot
.924 .54413 Mdot
.924 .54478 Mdot
.924 .54492 Mdot
.924 .54549 Mdot
.924 .54593 Mdot
.924 .54634 Mdot
.924 .54711 Mdot
.924 .54775 Mdot
.924 .54789 Mdot
.924 .54935 Mdot
.924 .54969 Mdot
.924 .55039 Mdot
.924 .55047 Mdot
.924 .55118 Mdot
.924 .55126 Mdot
.924 .55175 Mdot
.924 .55183 Mdot
.924 .55194 Mdot
.924 .55213 Mdot
.924 .55226 Mdot
.924 .55298 Mdot
.924 .55301 Mdot
.924 .55411 Mdot
.924 .55497 Mdot
.924 .55519 Mdot
.924 .55526 Mdot
.924 .55529 Mdot
.924 .55551 Mdot
.924 .55563 Mdot
.924 .55589 Mdot
.924 .55605 Mdot
.924 .55613 Mdot
.924 .55665 Mdot
.924 .55754 Mdot
.924 .55821 Mdot
.924 .55828 Mdot
.924 .55896 Mdot
.924 .55897 Mdot
.924 .55903 Mdot
.926 .09574 Mdot
.926 .09575 Mdot
.926 .09597 Mdot
.926 .09634 Mdot
.926 .09645 Mdot
.926 .09744 Mdot
.926 .09752 Mdot
.926 .09889 Mdot
.926 .09904 Mdot
.926 .09948 Mdot
.926 .09973 Mdot
.926 .10044 Mdot
.926 .10131 Mdot
.926 .10177 Mdot
.926 .10229 Mdot
.926 .10249 Mdot
.926 .10275 Mdot
.926 .1063 Mdot
.926 .10681 Mdot
.926 .10717 Mdot
.926 .10777 Mdot
.926 .10795 Mdot
.926 .10941 Mdot
.926 .10953 Mdot
.926 .11009 Mdot
.926 .11009 Mdot
.926 .11134 Mdot
.926 .11141 Mdot
.926 .11375 Mdot
.926 .11382 Mdot
.926 .1141 Mdot
.926 .11423 Mdot
.926 .11517 Mdot
.926 .11535 Mdot
.926 .1158 Mdot
.926 .11638 Mdot
.926 .11639 Mdot
.926 .11707 Mdot
.926 .11715 Mdot
.926 .11779 Mdot
.926 .11791 Mdot
.926 .11809 Mdot
.926 .1189 Mdot
.926 .11897 Mdot
.926 .11902 Mdot
.926 .11947 Mdot
.926 .11962 Mdot
.926 .12032 Mdot
.926 .12163 Mdot
.926 .1221 Mdot
.926 .12236 Mdot
.926 .12376 Mdot
.926 .12377 Mdot
.926 .12426 Mdot
.926 .12434 Mdot
.926 .12455 Mdot
.926 .12655 Mdot
.926 .12903 Mdot
.926 .1301 Mdot
.926 .13045 Mdot
.926 .13155 Mdot
.926 .13323 Mdot
.926 .13367 Mdot
.926 .13392 Mdot
.926 .13418 Mdot
.926 .13564 Mdot
.926 .13617 Mdot
.926 .13668 Mdot
.926 .13671 Mdot
.926 .13754 Mdot
.926 .13765 Mdot
.926 .13803 Mdot
.926 .13807 Mdot
.926 .13853 Mdot
.926 .14002 Mdot
.926 .14012 Mdot
.926 .14112 Mdot
.926 .14124 Mdot
.926 .14381 Mdot
.926 .14457 Mdot
.926 .1447 Mdot
.926 .14523 Mdot
.926 .1458 Mdot
.926 .14711 Mdot
.926 .14986 Mdot
.926 .15147 Mdot
.926 .15195 Mdot
.926 .15236 Mdot
.926 .15284 Mdot
.926 .15402 Mdot
.926 .15408 Mdot
.926 .15544 Mdot
.926 .15635 Mdot
.926 .15681 Mdot
.926 .15772 Mdot
.926 .15825 Mdot
.926 .15826 Mdot
.926 .15938 Mdot
.926 .15941 Mdot
.926 .1612 Mdot
.926 .1613 Mdot
.926 .16199 Mdot
.926 .1626 Mdot
.926 .16344 Mdot
.926 .16354 Mdot
.926 .16478 Mdot
.926 .16479 Mdot
.926 .16519 Mdot
.926 .16588 Mdot
.926 .16608 Mdot
.926 .16617 Mdot
.926 .16698 Mdot
.926 .16723 Mdot
.926 .16791 Mdot
.926 .16796 Mdot
.926 .16806 Mdot
.926 .16946 Mdot
.926 .16955 Mdot
.926 .17032 Mdot
.926 .17061 Mdot
.926 .17088 Mdot
.926 .17151 Mdot
.926 .17171 Mdot
.926 .17181 Mdot
.926 .17217 Mdot
.926 .17222 Mdot
.926 .17334 Mdot
.926 .17347 Mdot
.926 .17396 Mdot
.926 .17508 Mdot
.926 .17594 Mdot
.926 .17619 Mdot
.926 .17628 Mdot
.926 .17686 Mdot
.926 .17691 Mdot
.926 .17718 Mdot
.926 .17727 Mdot
.926 .17739 Mdot
.926 .17749 Mdot
.926 .17776 Mdot
.926 .17851 Mdot
.926 .17887 Mdot
.926 .18068 Mdot
.926 .18068 Mdot
.926 .18118 Mdot
.926 .18386 Mdot
.926 .18404 Mdot
.926 .18432 Mdot
.926 .18511 Mdot
.926 .18527 Mdot
.926 .18563 Mdot
.926 .18564 Mdot
.926 .18595 Mdot
.926 .18684 Mdot
.926 .18687 Mdot
.926 .18705 Mdot
.926 .18739 Mdot
.926 .18817 Mdot
.926 .18836 Mdot
.926 .18887 Mdot
.926 .18956 Mdot
.926 .18957 Mdot
.926 .19008 Mdot
.926 .1901 Mdot
.926 .19031 Mdot
.926 .19134 Mdot
.926 .19136 Mdot
.926 .19181 Mdot
.926 .19366 Mdot
.926 .19379 Mdot
.926 .19443 Mdot
.926 .19452 Mdot
.926 .19553 Mdot
.926 .19557 Mdot
.926 .19676 Mdot
.926 .19731 Mdot
.926 .19752 Mdot
.926 .19754 Mdot
.926 .19778 Mdot
.926 .19788 Mdot
.926 .19796 Mdot
.926 .19814 Mdot
.926 .19826 Mdot
.926 .19878 Mdot
.926 .19895 Mdot
.926 .19902 Mdot
.926 .19924 Mdot
.926 .19928 Mdot
.926 .20039 Mdot
.926 .20077 Mdot
.926 .20109 Mdot
.926 .20192 Mdot
.926 .20206 Mdot
.926 .203 Mdot
.926 .20302 Mdot
.926 .20339 Mdot
.926 .20427 Mdot
.926 .20442 Mdot
.926 .20468 Mdot
.926 .20485 Mdot
.926 .20561 Mdot
.926 .20578 Mdot
.926 .20584 Mdot
.926 .20586 Mdot
.926 .20617 Mdot
.926 .20762 Mdot
.926 .20766 Mdot
.926 .20779 Mdot
.926 .20788 Mdot
.926 .20873 Mdot
.926 .20878 Mdot
.926 .209 Mdot
.926 .20959 Mdot
.926 .21019 Mdot
.926 .21029 Mdot
.926 .21272 Mdot
.926 .21344 Mdot
.926 .21359 Mdot
.926 .21407 Mdot
.926 .21572 Mdot
.926 .21668 Mdot
.926 .21669 Mdot
.926 .21759 Mdot
.926 .21774 Mdot
.926 .21812 Mdot
.926 .21856 Mdot
.926 .22049 Mdot
.926 .2205 Mdot
.926 .22056 Mdot
.926 .22133 Mdot
.926 .22157 Mdot
.926 .22183 Mdot
.926 .22208 Mdot
.926 .22245 Mdot
.926 .22384 Mdot
.926 .22541 Mdot
.926 .22597 Mdot
.926 .22643 Mdot
.926 .2284 Mdot
.926 .22851 Mdot
.926 .22906 Mdot
.926 .22992 Mdot
.926 .22996 Mdot
.926 .2311 Mdot
.926 .23117 Mdot
.926 .23239 Mdot
.926 .23261 Mdot
.926 .23295 Mdot
.926 .23322 Mdot
.926 .2342 Mdot
.926 .23428 Mdot
.926 .23437 Mdot
.926 .23501 Mdot
.926 .23548 Mdot
.926 .23557 Mdot
.926 .23597 Mdot
.926 .23845 Mdot
.926 .23862 Mdot
.926 .23867 Mdot
.926 .23961 Mdot
.926 .23966 Mdot
.926 .23975 Mdot
.926 .24019 Mdot
.926 .2406 Mdot
.926 .24066 Mdot
.926 .24218 Mdot
.926 .2424 Mdot
.926 .24309 Mdot
.926 .2431 Mdot
.926 .24317 Mdot
.926 .24369 Mdot
.926 .24403 Mdot
.926 .2443 Mdot
.926 .24505 Mdot
.926 .24516 Mdot
.926 .24666 Mdot
.926 .2467 Mdot
.926 .24678 Mdot
.926 .24697 Mdot
.926 .24728 Mdot
.926 .24733 Mdot
.926 .24779 Mdot
.926 .2483 Mdot
.926 .24882 Mdot
.926 .24885 Mdot
.926 .24893 Mdot
.926 .24904 Mdot
.926 .24926 Mdot
.926 .24973 Mdot
.926 .25243 Mdot
.926 .25304 Mdot
.926 .2538 Mdot
.926 .25413 Mdot
.926 .25454 Mdot
.926 .25477 Mdot
.926 .2552 Mdot
.926 .25526 Mdot
.926 .25545 Mdot
.926 .25593 Mdot
.926 .25618 Mdot
.926 .25643 Mdot
.926 .25748 Mdot
.926 .25991 Mdot
.926 .26084 Mdot
.926 .26314 Mdot
.926 .26328 Mdot
.926 .26396 Mdot
.926 .26501 Mdot
.926 .26563 Mdot
.926 .26633 Mdot
.926 .2677 Mdot
.926 .26799 Mdot
.926 .26804 Mdot
.926 .26888 Mdot
.926 .26964 Mdot
.926 .27016 Mdot
.926 .27052 Mdot
.926 .27053 Mdot
.926 .2727 Mdot
.926 .27281 Mdot
.926 .27296 Mdot
.926 .27384 Mdot
.926 .27467 Mdot
.926 .27533 Mdot
.926 .27628 Mdot
.926 .27645 Mdot
.926 .27703 Mdot
.926 .27788 Mdot
.926 .27826 Mdot
.926 .27913 Mdot
.926 .27955 Mdot
.926 .27984 Mdot
.926 .27997 Mdot
.926 .27997 Mdot
.926 .28054 Mdot
.926 .28055 Mdot
.926 .28164 Mdot
.926 .28229 Mdot
.926 .28229 Mdot
.926 .28249 Mdot
.926 .28264 Mdot
.926 .2827 Mdot
.926 .28395 Mdot
.926 .28474 Mdot
.926 .28488 Mdot
.926 .28581 Mdot
.926 .286 Mdot
.926 .28617 Mdot
.926 .28619 Mdot
.926 .28728 Mdot
.926 .28747 Mdot
.926 .2879 Mdot
.926 .28859 Mdot
.926 .28888 Mdot
.926 .28988 Mdot
.926 .28991 Mdot
.926 .29015 Mdot
.926 .29033 Mdot
.926 .29053 Mdot
.926 .29108 Mdot
.926 .29142 Mdot
.926 .29158 Mdot
.926 .29197 Mdot
.926 .29264 Mdot
.926 .29266 Mdot
.926 .29314 Mdot
.926 .2934 Mdot
.926 .29467 Mdot
.926 .29505 Mdot
.926 .29522 Mdot
.926 .29642 Mdot
.926 .29671 Mdot
.926 .29717 Mdot
.926 .29746 Mdot
.926 .29786 Mdot
.926 .29801 Mdot
.926 .29844 Mdot
.926 .29852 Mdot
.926 .29872 Mdot
.926 .29921 Mdot
.926 .29963 Mdot
.926 .29994 Mdot
.926 .30125 Mdot
.926 .30131 Mdot
.926 .30147 Mdot
.926 .30286 Mdot
.926 .30289 Mdot
.926 .30343 Mdot
.926 .30363 Mdot
.926 .30393 Mdot
.926 .30398 Mdot
.926 .30426 Mdot
.926 .30437 Mdot
.926 .3051 Mdot
.926 .30546 Mdot
.926 .30566 Mdot
.926 .30614 Mdot
.926 .30631 Mdot
.926 .30642 Mdot
.926 .30657 Mdot
.926 .30789 Mdot
.926 .30848 Mdot
.926 .30873 Mdot
.926 .30915 Mdot
.926 .30944 Mdot
.926 .30947 Mdot
.926 .30964 Mdot
.926 .30965 Mdot
.926 .30981 Mdot
.926 .31026 Mdot
.926 .31071 Mdot
.926 .31084 Mdot
.926 .31112 Mdot
.926 .31137 Mdot
.926 .31166 Mdot
.926 .31171 Mdot
.926 .31179 Mdot
.926 .31331 Mdot
.926 .31377 Mdot
.926 .31393 Mdot
.926 .31431 Mdot
.926 .315 Mdot
.926 .3151 Mdot
.926 .31559 Mdot
.926 .31577 Mdot
.926 .31599 Mdot
.926 .31618 Mdot
.926 .31621 Mdot
.926 .31626 Mdot
.926 .31652 Mdot
.926 .31667 Mdot
.926 .31671 Mdot
.926 .31691 Mdot
.926 .31729 Mdot
.926 .31743 Mdot
.926 .31751 Mdot
.926 .31792 Mdot
.926 .31806 Mdot
.926 .31873 Mdot
.926 .31987 Mdot
.926 .3208 Mdot
.926 .32168 Mdot
.926 .32169 Mdot
.926 .32197 Mdot
.926 .32208 Mdot
.926 .32209 Mdot
.926 .32266 Mdot
.926 .32301 Mdot
.926 .32376 Mdot
.926 .32398 Mdot
.926 .32402 Mdot
.926 .32553 Mdot
.926 .32614 Mdot
.926 .32639 Mdot
.926 .32715 Mdot
.926 .32755 Mdot
.926 .32797 Mdot
.926 .3283 Mdot
.926 .32883 Mdot
.926 .33028 Mdot
.926 .33059 Mdot
.926 .33124 Mdot
.926 .33127 Mdot
.926 .33184 Mdot
.926 .33205 Mdot
.926 .33237 Mdot
.926 .33255 Mdot
.926 .33349 Mdot
.926 .33355 Mdot
.926 .33388 Mdot
.926 .33398 Mdot
.926 .33451 Mdot
.926 .33549 Mdot
.926 .3358 Mdot
.926 .33595 Mdot
.926 .33596 Mdot
.926 .33631 Mdot
.926 .33632 Mdot
.926 .33726 Mdot
.926 .33852 Mdot
.926 .33855 Mdot
.926 .3392 Mdot
.926 .33936 Mdot
.926 .3395 Mdot
.926 .33952 Mdot
.926 .33992 Mdot
.926 .33993 Mdot
.926 .34074 Mdot
.926 .34156 Mdot
.926 .34183 Mdot
.926 .34185 Mdot
.926 .3427 Mdot
.926 .34612 Mdot
.926 .34612 Mdot
.926 .34614 Mdot
.926 .34636 Mdot
.926 .34709 Mdot
.926 .34755 Mdot
.926 .34772 Mdot
.926 .34846 Mdot
.926 .34959 Mdot
.926 .34965 Mdot
.926 .34983 Mdot
.926 .35014 Mdot
.926 .35016 Mdot
.926 .35173 Mdot
.926 .35186 Mdot
.926 .35271 Mdot
.926 .35288 Mdot
.926 .35328 Mdot
.926 .35331 Mdot
.926 .35375 Mdot
.926 .35393 Mdot
.926 .35394 Mdot
.926 .35408 Mdot
.926 .35423 Mdot
.926 .35441 Mdot
.926 .35451 Mdot
.926 .35464 Mdot
.926 .35561 Mdot
.926 .35592 Mdot
.926 .35605 Mdot
.926 .35645 Mdot
.926 .35652 Mdot
.926 .35788 Mdot
.926 .35859 Mdot
.926 .35879 Mdot
.926 .35928 Mdot
.926 .35988 Mdot
.926 .35998 Mdot
.926 .3606 Mdot
.926 .36071 Mdot
.926 .36142 Mdot
.926 .36167 Mdot
.926 .36238 Mdot
.926 .36243 Mdot
.926 .36342 Mdot
.926 .36346 Mdot
.926 .36414 Mdot
.926 .36489 Mdot
.926 .36516 Mdot
.926 .36577 Mdot
.926 .36606 Mdot
.926 .36635 Mdot
.926 .36654 Mdot
.926 .3667 Mdot
.926 .3668 Mdot
.926 .36684 Mdot
.926 .36825 Mdot
.926 .36856 Mdot
.926 .36867 Mdot
.926 .36872 Mdot
.926 .36907 Mdot
.926 .36919 Mdot
.926 .36928 Mdot
.926 .37121 Mdot
.926 .37197 Mdot
.926 .37205 Mdot
.926 .37216 Mdot
.926 .37229 Mdot
.926 .37246 Mdot
.926 .37254 Mdot
.926 .37347 Mdot
.926 .37403 Mdot
.926 .37404 Mdot
.926 .37412 Mdot
.926 .37417 Mdot
.926 .37438 Mdot
.926 .3744 Mdot
.926 .37452 Mdot
.926 .37562 Mdot
.926 .37562 Mdot
.926 .3759 Mdot
.926 .37674 Mdot
.926 .37692 Mdot
.926 .37733 Mdot
.926 .37864 Mdot
.926 .37989 Mdot
.926 .38118 Mdot
.926 .38142 Mdot
.926 .38274 Mdot
.926 .38275 Mdot
.926 .38303 Mdot
.926 .38392 Mdot
.926 .38467 Mdot
.926 .38697 Mdot
.926 .38749 Mdot
.926 .3875 Mdot
.926 .38864 Mdot
.926 .38875 Mdot
.926 .38877 Mdot
.926 .39006 Mdot
.926 .39045 Mdot
.926 .39072 Mdot
.926 .39092 Mdot
.926 .39099 Mdot
.926 .39135 Mdot
.926 .39143 Mdot
.926 .39185 Mdot
.926 .39223 Mdot
.926 .39259 Mdot
.926 .39481 Mdot
.926 .39481 Mdot
.926 .39514 Mdot
.926 .39581 Mdot
.926 .39583 Mdot
.926 .39593 Mdot
.926 .39608 Mdot
.926 .39629 Mdot
.926 .39694 Mdot
.926 .39704 Mdot
.926 .39737 Mdot
.926 .39759 Mdot
.926 .39775 Mdot
.926 .3978 Mdot
.926 .39781 Mdot
.926 .39783 Mdot
.926 .39785 Mdot
.926 .39794 Mdot
.926 .39824 Mdot
.926 .39829 Mdot
.926 .39864 Mdot
.926 .39876 Mdot
.926 .39926 Mdot
.926 .39944 Mdot
.926 .39944 Mdot
.926 .40064 Mdot
.926 .40104 Mdot
.926 .40131 Mdot
.926 .40151 Mdot
.926 .40154 Mdot
.926 .40201 Mdot
.926 .40277 Mdot
.926 .40339 Mdot
.926 .4034 Mdot
.926 .40492 Mdot
.926 .40596 Mdot
.926 .4068 Mdot
.926 .4075 Mdot
.926 .40817 Mdot
.926 .40888 Mdot
.926 .40965 Mdot
.926 .4098 Mdot
.926 .41046 Mdot
.926 .41047 Mdot
.926 .41059 Mdot
.926 .41066 Mdot
.926 .41096 Mdot
.926 .41147 Mdot
.926 .41167 Mdot
.926 .41218 Mdot
.926 .41328 Mdot
.926 .41334 Mdot
.926 .41457 Mdot
.926 .41462 Mdot
.926 .41481 Mdot
.926 .41545 Mdot
.926 .4156 Mdot
.926 .41692 Mdot
.926 .41695 Mdot
.926 .41786 Mdot
.926 .41792 Mdot
.926 .41825 Mdot
.926 .41889 Mdot
.926 .41938 Mdot
.926 .42121 Mdot
.926 .42136 Mdot
.926 .42151 Mdot
.926 .42217 Mdot
.926 .4227 Mdot
.926 .42355 Mdot
.926 .42356 Mdot
.926 .42373 Mdot
.926 .42447 Mdot
.926 .42521 Mdot
.926 .42572 Mdot
.926 .42573 Mdot
.926 .4282 Mdot
.926 .42864 Mdot
.926 .42907 Mdot
.926 .42938 Mdot
.926 .42947 Mdot
.926 .43103 Mdot
.926 .43122 Mdot
.926 .4313 Mdot
.926 .43147 Mdot
.926 .43229 Mdot
.926 .43306 Mdot
.926 .43316 Mdot
.926 .43333 Mdot
.926 .43576 Mdot
.926 .43598 Mdot
.926 .43639 Mdot
.926 .43652 Mdot
.926 .43685 Mdot
.926 .43767 Mdot
.926 .43769 Mdot
.926 .43781 Mdot
.926 .4384 Mdot
.926 .43878 Mdot
.926 .43892 Mdot
.926 .43893 Mdot
.926 .4394 Mdot
.926 .43991 Mdot
.926 .44096 Mdot
.926 .44118 Mdot
.926 .44122 Mdot
.926 .4413 Mdot
.926 .4415 Mdot
.926 .44161 Mdot
.926 .44172 Mdot
.926 .44186 Mdot
.926 .44188 Mdot
.926 .44291 Mdot
.926 .44427 Mdot
.926 .44434 Mdot
.926 .4445 Mdot
.926 .44463 Mdot
.926 .44478 Mdot
.926 .44485 Mdot
.926 .44509 Mdot
.926 .44534 Mdot
.926 .44543 Mdot
.926 .44552 Mdot
.926 .44554 Mdot
.926 .44569 Mdot
.926 .44638 Mdot
.926 .44709 Mdot
.926 .44732 Mdot
.926 .44827 Mdot
.926 .44834 Mdot
.926 .44849 Mdot
.926 .44868 Mdot
.926 .44909 Mdot
.926 .44996 Mdot
.926 .45067 Mdot
.926 .45084 Mdot
.926 .45107 Mdot
.926 .45171 Mdot
.926 .45179 Mdot
.926 .45201 Mdot
.926 .45257 Mdot
.926 .45497 Mdot
.926 .45518 Mdot
.926 .45527 Mdot
.926 .45545 Mdot
.926 .45575 Mdot
.926 .45609 Mdot
.926 .4561 Mdot
.926 .45664 Mdot
.926 .45717 Mdot
.926 .4575 Mdot
.926 .45811 Mdot
.926 .4583 Mdot
.926 .4588 Mdot
.926 .45888 Mdot
.926 .4593 Mdot
.926 .46009 Mdot
.926 .4602 Mdot
.926 .4602 Mdot
.926 .46055 Mdot
.926 .46145 Mdot
.926 .46145 Mdot
.926 .46152 Mdot
.926 .4619 Mdot
.926 .46237 Mdot
.926 .46335 Mdot
.926 .46345 Mdot
.926 .46431 Mdot
.926 .46476 Mdot
.926 .46524 Mdot
.926 .46655 Mdot
.926 .46675 Mdot
.926 .46789 Mdot
.926 .46808 Mdot
.926 .46882 Mdot
.926 .46919 Mdot
.926 .4701 Mdot
.926 .47046 Mdot
.926 .47054 Mdot
.926 .47178 Mdot
.926 .4743 Mdot
.926 .47443 Mdot
.926 .4748 Mdot
.926 .47506 Mdot
.926 .47518 Mdot
.926 .47541 Mdot
.926 .47599 Mdot
.926 .47632 Mdot
.926 .47778 Mdot
.926 .47803 Mdot
.926 .47821 Mdot
.926 .47825 Mdot
.926 .47855 Mdot
.926 .47883 Mdot
.926 .47907 Mdot
.926 .4791 Mdot
.926 .47942 Mdot
.926 .47944 Mdot
.926 .48025 Mdot
.926 .48031 Mdot
.926 .48071 Mdot
.926 .48104 Mdot
.926 .48136 Mdot
.926 .48293 Mdot
.926 .48317 Mdot
.926 .48324 Mdot
.926 .48378 Mdot
.926 .48387 Mdot
.926 .48543 Mdot
.926 .48608 Mdot
.926 .48612 Mdot
.926 .4867 Mdot
.926 .48684 Mdot
.926 .48703 Mdot
.926 .48714 Mdot
.926 .4878 Mdot
.926 .48846 Mdot
.926 .48848 Mdot
.926 .48924 Mdot
.926 .49061 Mdot
.926 .49091 Mdot
.926 .49176 Mdot
.926 .49251 Mdot
.926 .49271 Mdot
.926 .49298 Mdot
.926 .49311 Mdot
.926 .49353 Mdot
.926 .49356 Mdot
.926 .49357 Mdot
.926 .49461 Mdot
.926 .49615 Mdot
.926 .49738 Mdot
.926 .49913 Mdot
.926 .49945 Mdot
.926 .49989 Mdot
.926 .50052 Mdot
.926 .50147 Mdot
.926 .50151 Mdot
.926 .50201 Mdot
.926 .5021 Mdot
.926 .5028 Mdot
.926 .50352 Mdot
.926 .50442 Mdot
.926 .50502 Mdot
.926 .50504 Mdot
.926 .5052 Mdot
.926 .50574 Mdot
.926 .50578 Mdot
.926 .50583 Mdot
.926 .50596 Mdot
.926 .50597 Mdot
.926 .50608 Mdot
.926 .50638 Mdot
.926 .50703 Mdot
.926 .50704 Mdot
.926 .50759 Mdot
.926 .50764 Mdot
.926 .50905 Mdot
.926 .50998 Mdot
.926 .51026 Mdot
.926 .51027 Mdot
.926 .51064 Mdot
.926 .51092 Mdot
.926 .51102 Mdot
.926 .51172 Mdot
.926 .51174 Mdot
.926 .51239 Mdot
.926 .51239 Mdot
.926 .51267 Mdot
.926 .51325 Mdot
.926 .51335 Mdot
.926 .51479 Mdot
.926 .51506 Mdot
.926 .51507 Mdot
.926 .51604 Mdot
.926 .51624 Mdot
.926 .51679 Mdot
.926 .51684 Mdot
.926 .51696 Mdot
.926 .51713 Mdot
.926 .51744 Mdot
.926 .51749 Mdot
.926 .51869 Mdot
.926 .51903 Mdot
.926 .51951 Mdot
.926 .51963 Mdot
.926 .51985 Mdot
.926 .52002 Mdot
.926 .52066 Mdot
.926 .52107 Mdot
.926 .52112 Mdot
.926 .52193 Mdot
.926 .52233 Mdot
.926 .52246 Mdot
.926 .5229 Mdot
.926 .52432 Mdot
.926 .52437 Mdot
.926 .52483 Mdot
.926 .52516 Mdot
.926 .52553 Mdot
.926 .52558 Mdot
.926 .52655 Mdot
.926 .52656 Mdot
.926 .52717 Mdot
.926 .52718 Mdot
.926 .52746 Mdot
.926 .52795 Mdot
.926 .5282 Mdot
.926 .52869 Mdot
.926 .52943 Mdot
.926 .52946 Mdot
.926 .5301 Mdot
.926 .53035 Mdot
.926 .53058 Mdot
.926 .53083 Mdot
.926 .5317 Mdot
.926 .53319 Mdot
.926 .5339 Mdot
.926 .5342 Mdot
.926 .53449 Mdot
.926 .53456 Mdot
.926 .53497 Mdot
.926 .53636 Mdot
.926 .53642 Mdot
.926 .53696 Mdot
.926 .53702 Mdot
.926 .53782 Mdot
.926 .53807 Mdot
.926 .53809 Mdot
.926 .5383 Mdot
.926 .53836 Mdot
.926 .5388 Mdot
.926 .53882 Mdot
.926 .5391 Mdot
.926 .53938 Mdot
.926 .54017 Mdot
.926 .54031 Mdot
.926 .54045 Mdot
.926 .54069 Mdot
.926 .54159 Mdot
.926 .54219 Mdot
.926 .54238 Mdot
.926 .54295 Mdot
.926 .54429 Mdot
.926 .54537 Mdot
.926 .54548 Mdot
.926 .54553 Mdot
.926 .54579 Mdot
.926 .5458 Mdot
.926 .54655 Mdot
.926 .5467 Mdot
.926 .54695 Mdot
.926 .54766 Mdot
.926 .54803 Mdot
.926 .54811 Mdot
.926 .54836 Mdot
.926 .54839 Mdot
.926 .54842 Mdot
.926 .54886 Mdot
.926 .54896 Mdot
.926 .54902 Mdot
.926 .54937 Mdot
.926 .54941 Mdot
.926 .54978 Mdot
.926 .54978 Mdot
.926 .5501 Mdot
.926 .55034 Mdot
.926 .55043 Mdot
.926 .55094 Mdot
.926 .55101 Mdot
.926 .55116 Mdot
.926 .5512 Mdot
.926 .55247 Mdot
.926 .55251 Mdot
.926 .55318 Mdot
.926 .55318 Mdot
.926 .55348 Mdot
.926 .55355 Mdot
.926 .55433 Mdot
.926 .55443 Mdot
.926 .55475 Mdot
.926 .55495 Mdot
.926 .55523 Mdot
.926 .55714 Mdot
.926 .55728 Mdot
.926 .55739 Mdot
.926 .55767 Mdot
.926 .55792 Mdot
.926 .55839 Mdot
.926 .55877 Mdot
.926 .55891 Mdot
.926 .55915 Mdot
.926 .55923 Mdot
.926 .55997 Mdot
.926 .56001 Mdot
.926 .56055 Mdot
.926 .56061 Mdot
.926 .56081 Mdot
.926 .56092 Mdot
.926 .56093 Mdot
.928 .09385 Mdot
.928 .09388 Mdot
.928 .09603 Mdot
.928 .09652 Mdot
.928 .09659 Mdot
.928 .09699 Mdot
.928 .09724 Mdot
.928 .09739 Mdot
.928 .09767 Mdot
.928 .09814 Mdot
.928 .0985 Mdot
.928 .09886 Mdot
.928 .09932 Mdot
.928 .10037 Mdot
.928 .10069 Mdot
.928 .10103 Mdot
.928 .1017 Mdot
.928 .10231 Mdot
.928 .10245 Mdot
.928 .10321 Mdot
.928 .10472 Mdot
.928 .10573 Mdot
.928 .10575 Mdot
.928 .10804 Mdot
.928 .10846 Mdot
.928 .10879 Mdot
.928 .10964 Mdot
.928 .11116 Mdot
.928 .11125 Mdot
.928 .1123 Mdot
.928 .11262 Mdot
.928 .11303 Mdot
.928 .11495 Mdot
.928 .11506 Mdot
.928 .11553 Mdot
.928 .11682 Mdot
.928 .11762 Mdot
.928 .1179 Mdot
.928 .11797 Mdot
.928 .11835 Mdot
.928 .11848 Mdot
.928 .11873 Mdot
.928 .11894 Mdot
.928 .11904 Mdot
.928 .11974 Mdot
.928 .12062 Mdot
.928 .12076 Mdot
.928 .12168 Mdot
.928 .12201 Mdot
.928 .12441 Mdot
.928 .12501 Mdot
.928 .12533 Mdot
.928 .12588 Mdot
.928 .12593 Mdot
.928 .12712 Mdot
.928 .1274 Mdot
.928 .12745 Mdot
.928 .12748 Mdot
.928 .12817 Mdot
.928 .12861 Mdot
.928 .12898 Mdot
.928 .12954 Mdot
.928 .12988 Mdot
.928 .12993 Mdot
.928 .13038 Mdot
.928 .13047 Mdot
.928 .13149 Mdot
.928 .1321 Mdot
.928 .13297 Mdot
.928 .13334 Mdot
.928 .135 Mdot
.928 .13598 Mdot
.928 .13617 Mdot
.928 .13764 Mdot
.928 .13812 Mdot
.928 .1383 Mdot
.928 .13899 Mdot
.928 .13971 Mdot
.928 .14127 Mdot
.928 .14149 Mdot
.928 .14172 Mdot
.928 .14201 Mdot
.928 .14248 Mdot
.928 .14295 Mdot
.928 .14483 Mdot
.928 .14542 Mdot
.928 .14697 Mdot
.928 .14933 Mdot
.928 .15119 Mdot
.928 .15173 Mdot
.928 .15184 Mdot
.928 .15212 Mdot
.928 .15286 Mdot
.928 .15527 Mdot
.928 .15606 Mdot
.928 .15722 Mdot
.928 .15737 Mdot
.928 .15763 Mdot
.928 .15841 Mdot
.928 .15866 Mdot
.928 .15921 Mdot
.928 .16106 Mdot
.928 .16136 Mdot
.928 .16159 Mdot
.928 .16165 Mdot
.928 .16199 Mdot
.928 .16201 Mdot
.928 .16309 Mdot
.928 .16369 Mdot
.928 .16453 Mdot
.928 .16463 Mdot
.928 .16492 Mdot
.928 .16529 Mdot
.928 .16563 Mdot
.928 .166 Mdot
.928 .16654 Mdot
.928 .16668 Mdot
.928 .16743 Mdot
.928 .16789 Mdot
.928 .16796 Mdot
.928 .16811 Mdot
.928 .16817 Mdot
.928 .16868 Mdot
.928 .16882 Mdot
.928 .16955 Mdot
.928 .16977 Mdot
.928 .17021 Mdot
.928 .17028 Mdot
.928 .1703 Mdot
.928 .17067 Mdot
.928 .17089 Mdot
.928 .17132 Mdot
.928 .17174 Mdot
.928 .17175 Mdot
.928 .17214 Mdot
.928 .17226 Mdot
.928 .17275 Mdot
.928 .17288 Mdot
.928 .17293 Mdot
.928 .17305 Mdot
.928 .1737 Mdot
.928 .17404 Mdot
.928 .17423 Mdot
.928 .17429 Mdot
.928 .17448 Mdot
.928 .17492 Mdot
.928 .17617 Mdot
.928 .17729 Mdot
.928 .17755 Mdot
.928 .17759 Mdot
.928 .1781 Mdot
.928 .17871 Mdot
.928 .1789 Mdot
.928 .17895 Mdot
.928 .18176 Mdot
.928 .1833 Mdot
.928 .18363 Mdot
.928 .18367 Mdot
.928 .18487 Mdot
.928 .18542 Mdot
.928 .18557 Mdot
.928 .18588 Mdot
.928 .18606 Mdot
.928 .18687 Mdot
.928 .18793 Mdot
.928 .18871 Mdot
.928 .18932 Mdot
.928 .1894 Mdot
.928 .18983 Mdot
.928 .1909 Mdot
.928 .191 Mdot
.928 .19152 Mdot
.928 .19372 Mdot
.928 .19372 Mdot
.928 .19389 Mdot
.928 .19397 Mdot
.928 .19429 Mdot
.928 .19584 Mdot
.928 .196 Mdot
.928 .19642 Mdot
.928 .19703 Mdot
.928 .19719 Mdot
.928 .1976 Mdot
.928 .1986 Mdot
.928 .19934 Mdot
.928 .2002 Mdot
.928 .20076 Mdot
.928 .20096 Mdot
.928 .20122 Mdot
.928 .20182 Mdot
.928 .20265 Mdot
.928 .20301 Mdot
.928 .20385 Mdot
.928 .20423 Mdot
.928 .2045 Mdot
.928 .20451 Mdot
.928 .20571 Mdot
.928 .20599 Mdot
.928 .20622 Mdot
.928 .20636 Mdot
.928 .20706 Mdot
.928 .2073 Mdot
.928 .20777 Mdot
.928 .2078 Mdot
.928 .20815 Mdot
.928 .20834 Mdot
.928 .20964 Mdot
.928 .21029 Mdot
.928 .21107 Mdot
.928 .21127 Mdot
.928 .21153 Mdot
.928 .21324 Mdot
.928 .21385 Mdot
.928 .2152 Mdot
.928 .21638 Mdot
.928 .21662 Mdot
.928 .21764 Mdot
.928 .21831 Mdot
.928 .2185 Mdot
.928 .21941 Mdot
.928 .21954 Mdot
.928 .22002 Mdot
.928 .2209 Mdot
.928 .22104 Mdot
.928 .22114 Mdot
.928 .22186 Mdot
.928 .22188 Mdot
.928 .22267 Mdot
.928 .22296 Mdot
.928 .22334 Mdot
.928 .22345 Mdot
.928 .22386 Mdot
.928 .22395 Mdot
.928 .224 Mdot
.928 .22513 Mdot
.928 .22528 Mdot
.928 .2255 Mdot
.928 .22565 Mdot
.928 .2261 Mdot
.928 .22648 Mdot
.928 .2268 Mdot
.928 .22783 Mdot
.928 .22846 Mdot
.928 .22856 Mdot
.928 .2294 Mdot
.928 .22956 Mdot
.928 .23034 Mdot
.928 .23082 Mdot
.928 .23119 Mdot
.928 .23145 Mdot
.928 .23259 Mdot
.928 .23297 Mdot
.928 .23371 Mdot
.928 .2342 Mdot
.928 .2343 Mdot
.928 .23468 Mdot
.928 .23489 Mdot
.928 .23542 Mdot
.928 .23642 Mdot
.928 .23658 Mdot
.928 .2367 Mdot
.928 .23711 Mdot
.928 .23796 Mdot
.928 .23915 Mdot
.928 .23921 Mdot
.928 .23977 Mdot
.928 .24013 Mdot
.928 .24094 Mdot
.928 .24109 Mdot
.928 .24195 Mdot
.928 .24287 Mdot
.928 .24306 Mdot
.928 .24363 Mdot
.928 .24375 Mdot
.928 .24392 Mdot
.928 .24403 Mdot
.928 .2441 Mdot
.928 .2448 Mdot
.928 .24537 Mdot
.928 .24669 Mdot
.928 .2467 Mdot
.928 .24901 Mdot
.928 .2496 Mdot
.928 .25001 Mdot
.928 .25044 Mdot
.928 .25054 Mdot
.928 .25067 Mdot
.928 .25072 Mdot
.928 .25097 Mdot
.928 .25099 Mdot
.928 .25185 Mdot
.928 .25272 Mdot
.928 .25286 Mdot
.928 .25306 Mdot
.928 .25342 Mdot
.928 .25614 Mdot
.928 .25621 Mdot
.928 .2573 Mdot
.928 .25783 Mdot
.928 .25946 Mdot
.928 .26018 Mdot
.928 .26329 Mdot
.928 .26345 Mdot
.928 .26399 Mdot
.928 .26409 Mdot
.928 .26412 Mdot
.928 .26457 Mdot
.928 .26605 Mdot
.928 .26662 Mdot
.928 .26687 Mdot
.928 .26802 Mdot
.928 .26818 Mdot
.928 .26901 Mdot
.928 .26922 Mdot
.928 .26974 Mdot
.928 .26985 Mdot
.928 .27111 Mdot
.928 .27221 Mdot
.928 .27367 Mdot
.928 .27404 Mdot
.928 .27558 Mdot
.928 .27706 Mdot
.928 .27749 Mdot
.928 .2778 Mdot
.928 .27803 Mdot
.928 .27899 Mdot
.928 .2792 Mdot
.928 .27949 Mdot
.928 .27996 Mdot
.928 .28055 Mdot
.928 .28126 Mdot
.928 .28141 Mdot
.928 .28187 Mdot
.928 .28289 Mdot
.928 .28492 Mdot
.928 .28633 Mdot
.928 .28667 Mdot
.928 .28688 Mdot
.928 .28712 Mdot
.928 .28731 Mdot
.928 .28742 Mdot
.928 .28742 Mdot
.928 .28805 Mdot
.928 .2881 Mdot
.928 .28867 Mdot
.928 .28906 Mdot
.928 .28909 Mdot
.928 .28934 Mdot
.928 .28982 Mdot
.928 .29001 Mdot
.928 .2901 Mdot
.928 .29064 Mdot
.928 .2908 Mdot
.928 .29087 Mdot
.928 .29121 Mdot
.928 .29269 Mdot
.928 .29278 Mdot
.928 .29281 Mdot
.928 .29296 Mdot
.928 .2935 Mdot
.928 .29419 Mdot
.928 .29481 Mdot
.928 .29536 Mdot
.928 .29549 Mdot
.928 .29578 Mdot
.928 .29584 Mdot
.928 .29651 Mdot
.928 .29671 Mdot
.928 .29676 Mdot
.928 .2969 Mdot
.928 .29733 Mdot
.928 .29738 Mdot
.928 .29766 Mdot
.928 .29815 Mdot
.928 .29851 Mdot
.928 .299 Mdot
.928 .29914 Mdot
.928 .29915 Mdot
.928 .29941 Mdot
.928 .29952 Mdot
.928 .29986 Mdot
.928 .30031 Mdot
.928 .30047 Mdot
.928 .30057 Mdot
.928 .30074 Mdot
.928 .3018 Mdot
.928 .30184 Mdot
.928 .30209 Mdot
.928 .30233 Mdot
.928 .3025 Mdot
.928 .30261 Mdot
.928 .30271 Mdot
.928 .30332 Mdot
.928 .30345 Mdot
.928 .30348 Mdot
.928 .30416 Mdot
.928 .30458 Mdot
.928 .30537 Mdot
.928 .30616 Mdot
.928 .30616 Mdot
.928 .30689 Mdot
.928 .30711 Mdot
.928 .30715 Mdot
.928 .30802 Mdot
.928 .30826 Mdot
.928 .30836 Mdot
.928 .30858 Mdot
.928 .3087 Mdot
.928 .30978 Mdot
.928 .30979 Mdot
.928 .31041 Mdot
.928 .31056 Mdot
.928 .31058 Mdot
.928 .31077 Mdot
.928 .31089 Mdot
.928 .31124 Mdot
.928 .31168 Mdot
.928 .31177 Mdot
.928 .31187 Mdot
.928 .31206 Mdot
.928 .31294 Mdot
.928 .3139 Mdot
.928 .31412 Mdot
.928 .31437 Mdot
.928 .31483 Mdot
.928 .31514 Mdot
.928 .31535 Mdot
.928 .31645 Mdot
.928 .31676 Mdot
.928 .31693 Mdot
.928 .31701 Mdot
.928 .3171 Mdot
.928 .31786 Mdot
.928 .31796 Mdot
.928 .3191 Mdot
.928 .31944 Mdot
.928 .31952 Mdot
.928 .31954 Mdot
.928 .31974 Mdot
.928 .32014 Mdot
.928 .32041 Mdot
.928 .32071 Mdot
.928 .32114 Mdot
.928 .32309 Mdot
.928 .32368 Mdot
.928 .32376 Mdot
.928 .32475 Mdot
.928 .32691 Mdot
.928 .32761 Mdot
.928 .32784 Mdot
.928 .32822 Mdot
.928 .3283 Mdot
.928 .32956 Mdot
.928 .32988 Mdot
.928 .33042 Mdot
.928 .33052 Mdot
.928 .33155 Mdot
.928 .33182 Mdot
.928 .33239 Mdot
.928 .33254 Mdot
.928 .33269 Mdot
.928 .33274 Mdot
.928 .33277 Mdot
.928 .33312 Mdot
.928 .33319 Mdot
.928 .33409 Mdot
.928 .33424 Mdot
.928 .33442 Mdot
.928 .33575 Mdot
.928 .33621 Mdot
.928 .33637 Mdot
.928 .33641 Mdot
.928 .33655 Mdot
.928 .33679 Mdot
.928 .33765 Mdot
.928 .33877 Mdot
.928 .33894 Mdot
.928 .33974 Mdot
.928 .34066 Mdot
.928 .34095 Mdot
.928 .34147 Mdot
.928 .34172 Mdot
.928 .3419 Mdot
.928 .34286 Mdot
.928 .34359 Mdot
.928 .34501 Mdot
.928 .34542 Mdot
.928 .34597 Mdot
.928 .34627 Mdot
.928 .34666 Mdot
.928 .34694 Mdot
.928 .34695 Mdot
.928 .34726 Mdot
.928 .3474 Mdot
.928 .348 Mdot
.928 .34804 Mdot
.928 .34941 Mdot
.928 .35056 Mdot
.928 .35066 Mdot
.928 .35088 Mdot
.928 .35117 Mdot
.928 .35125 Mdot
.928 .35196 Mdot
.928 .35198 Mdot
.928 .35248 Mdot
.928 .3531 Mdot
.928 .35326 Mdot
.928 .35338 Mdot
.928 .3536 Mdot
.928 .35415 Mdot
.928 .35532 Mdot
.928 .356 Mdot
.928 .3569 Mdot
.928 .35739 Mdot
.928 .35786 Mdot
.928 .35897 Mdot
.928 .35902 Mdot
.928 .35917 Mdot
.928 .3592 Mdot
.928 .35977 Mdot
.928 .36001 Mdot
.928 .36039 Mdot
.928 .36087 Mdot
.928 .36199 Mdot
.928 .36309 Mdot
.928 .36353 Mdot
.928 .36398 Mdot
.928 .36419 Mdot
.928 .36525 Mdot
.928 .36576 Mdot
.928 .36589 Mdot
.928 .36645 Mdot
.928 .36646 Mdot
.928 .36673 Mdot
.928 .36691 Mdot
.928 .36696 Mdot
.928 .36698 Mdot
.928 .36751 Mdot
.928 .36828 Mdot
.928 .36887 Mdot
.928 .36919 Mdot
.928 .36959 Mdot
.928 .36972 Mdot
.928 .37015 Mdot
.928 .37016 Mdot
.928 .3703 Mdot
.928 .37041 Mdot
.928 .3717 Mdot
.928 .37215 Mdot
.928 .37247 Mdot
.928 .37302 Mdot
.928 .37304 Mdot
.928 .37307 Mdot
.928 .37338 Mdot
.928 .37366 Mdot
.928 .37373 Mdot
.928 .37393 Mdot
.928 .37408 Mdot
.928 .37449 Mdot
.928 .37481 Mdot
.928 .37555 Mdot
.928 .3765 Mdot
.928 .37771 Mdot
.928 .37821 Mdot
.928 .37908 Mdot
.928 .37912 Mdot
.928 .37914 Mdot
.928 .37924 Mdot
.928 .37952 Mdot
.928 .38001 Mdot
.928 .3802 Mdot
.928 .38031 Mdot
.928 .38152 Mdot
.928 .38167 Mdot
.928 .38306 Mdot
.928 .38317 Mdot
.928 .38357 Mdot
.928 .3843 Mdot
.928 .38434 Mdot
.928 .38486 Mdot
.928 .38614 Mdot
.928 .38676 Mdot
.928 .38681 Mdot
.928 .38698 Mdot
.928 .38876 Mdot
.928 .38892 Mdot
.928 .389 Mdot
.928 .38922 Mdot
.928 .38945 Mdot
.928 .38962 Mdot
.928 .39004 Mdot
.928 .39067 Mdot
.928 .39101 Mdot
.928 .39109 Mdot
.928 .39125 Mdot
.928 .39135 Mdot
.928 .39233 Mdot
.928 .39258 Mdot
.928 .39263 Mdot
.928 .39294 Mdot
.928 .39334 Mdot
.928 .39464 Mdot
.928 .39481 Mdot
.928 .39488 Mdot
.928 .39564 Mdot
.928 .39577 Mdot
.928 .39607 Mdot
.928 .39612 Mdot
.928 .39652 Mdot
.928 .39715 Mdot
.928 .39739 Mdot
.928 .39765 Mdot
.928 .39783 Mdot
.928 .39862 Mdot
.928 .39896 Mdot
.928 .39918 Mdot
.928 .39921 Mdot
.928 .39944 Mdot
.928 .39988 Mdot
.928 .40068 Mdot
.928 .40106 Mdot
.928 .40122 Mdot
.928 .4018 Mdot
.928 .40189 Mdot
.928 .40193 Mdot
.928 .40212 Mdot
.928 .40246 Mdot
.928 .40268 Mdot
.928 .40289 Mdot
.928 .40306 Mdot
.928 .40315 Mdot
.928 .4041 Mdot
.928 .40422 Mdot
.928 .40455 Mdot
.928 .40524 Mdot
.928 .40553 Mdot
.928 .40594 Mdot
.928 .40622 Mdot
.928 .40697 Mdot
.928 .40705 Mdot
.928 .4077 Mdot
.928 .40776 Mdot
.928 .40827 Mdot
.928 .40834 Mdot
.928 .40836 Mdot
.928 .40883 Mdot
.928 .41026 Mdot
.928 .41066 Mdot
.928 .41083 Mdot
.928 .41113 Mdot
.928 .41128 Mdot
.928 .41143 Mdot
.928 .41161 Mdot
.928 .41192 Mdot
.928 .41309 Mdot
.928 .41317 Mdot
.928 .41348 Mdot
.928 .41386 Mdot
.928 .41418 Mdot
.928 .4146 Mdot
.928 .41492 Mdot
.928 .41502 Mdot
.928 .41516 Mdot
.928 .41547 Mdot
.928 .41581 Mdot
.928 .4165 Mdot
.928 .41697 Mdot
.928 .41876 Mdot
.928 .41907 Mdot
.928 .41909 Mdot
.928 .41917 Mdot
.928 .41979 Mdot
.928 .42031 Mdot
.928 .42116 Mdot
.928 .42209 Mdot
.928 .42227 Mdot
.928 .42269 Mdot
.928 .42296 Mdot
.928 .42335 Mdot
.928 .42367 Mdot
.928 .42373 Mdot
.928 .42435 Mdot
.928 .42508 Mdot
.928 .42583 Mdot
.928 .42604 Mdot
.928 .4262 Mdot
.928 .4265 Mdot
.928 .42672 Mdot
.928 .42748 Mdot
.928 .42862 Mdot
.928 .4289 Mdot
.928 .42906 Mdot
.928 .43115 Mdot
.928 .43127 Mdot
.928 .43135 Mdot
.928 .43137 Mdot
.928 .43171 Mdot
.928 .43242 Mdot
.928 .4326 Mdot
.928 .43309 Mdot
.928 .43313 Mdot
.928 .43331 Mdot
.928 .43336 Mdot
.928 .43343 Mdot
.928 .43458 Mdot
.928 .43487 Mdot
.928 .43504 Mdot
.928 .43597 Mdot
.928 .43647 Mdot
.928 .43816 Mdot
.928 .43821 Mdot
.928 .43852 Mdot
.928 .43958 Mdot
.928 .43981 Mdot
.928 .43997 Mdot
.928 .44011 Mdot
.928 .44033 Mdot
.928 .44045 Mdot
.928 .44134 Mdot
.928 .44176 Mdot
.928 .44194 Mdot
.928 .4427 Mdot
.928 .44281 Mdot
.928 .44298 Mdot
.928 .44336 Mdot
.928 .44348 Mdot
.928 .444 Mdot
.928 .44457 Mdot
.928 .44463 Mdot
.928 .44468 Mdot
.928 .44527 Mdot
.928 .44528 Mdot
.928 .44569 Mdot
.928 .44628 Mdot
.928 .44711 Mdot
.928 .44951 Mdot
.928 .44956 Mdot
.928 .44971 Mdot
.928 .44998 Mdot
.928 .45 Mdot
.928 .45066 Mdot
.928 .4508 Mdot
.928 .45105 Mdot
.928 .45143 Mdot
.928 .45177 Mdot
.928 .45223 Mdot
.928 .45238 Mdot
.928 .45241 Mdot
.928 .45264 Mdot
.928 .45274 Mdot
.928 .45321 Mdot
.928 .45324 Mdot
.928 .45347 Mdot
.928 .45484 Mdot
.928 .4549 Mdot
.928 .45589 Mdot
.928 .45593 Mdot
.928 .45601 Mdot
.928 .45635 Mdot
.928 .45645 Mdot
.928 .45671 Mdot
.928 .45685 Mdot
.928 .45686 Mdot
.928 .45707 Mdot
.928 .45775 Mdot
.928 .45791 Mdot
.928 .45815 Mdot
.928 .45909 Mdot
.928 .46107 Mdot
.928 .46145 Mdot
.928 .46229 Mdot
.928 .46281 Mdot
.928 .46293 Mdot
.928 .4631 Mdot
.928 .46495 Mdot
.928 .46515 Mdot
.928 .46594 Mdot
.928 .46721 Mdot
.928 .46811 Mdot
.928 .46882 Mdot
.928 .46896 Mdot
.928 .46926 Mdot
.928 .4703 Mdot
.928 .47032 Mdot
.928 .47037 Mdot
.928 .47066 Mdot
.928 .47075 Mdot
.928 .47281 Mdot
.928 .47369 Mdot
.928 .4746 Mdot
.928 .47607 Mdot
.928 .47626 Mdot
.928 .47637 Mdot
.928 .47737 Mdot
.928 .47752 Mdot
.928 .47755 Mdot
.928 .47762 Mdot
.928 .47844 Mdot
.928 .47969 Mdot
.928 .48071 Mdot
.928 .48112 Mdot
.928 .48119 Mdot
.928 .48134 Mdot
.928 .48165 Mdot
.928 .48224 Mdot
.928 .48271 Mdot
.928 .48279 Mdot
.928 .48372 Mdot
.928 .48375 Mdot
.928 .48485 Mdot
.928 .48507 Mdot
.928 .48514 Mdot
.928 .48522 Mdot
.928 .48576 Mdot
.928 .48616 Mdot
.928 .48637 Mdot
.928 .48669 Mdot
.928 .48708 Mdot
.928 .48804 Mdot
.928 .48824 Mdot
.928 .4885 Mdot
.928 .49058 Mdot
.928 .49103 Mdot
.928 .49111 Mdot
.928 .49131 Mdot
.928 .49222 Mdot
.928 .49248 Mdot
.928 .49263 Mdot
.928 .49306 Mdot
.928 .49307 Mdot
.928 .49359 Mdot
.928 .49432 Mdot
.928 .49488 Mdot
.928 .49534 Mdot
.928 .49589 Mdot
.928 .49602 Mdot
.928 .49666 Mdot
.928 .49889 Mdot
.928 .4993 Mdot
.928 .50065 Mdot
.928 .50162 Mdot
.928 .50242 Mdot
.928 .50242 Mdot
.928 .50277 Mdot
.928 .50323 Mdot
.928 .50342 Mdot
.928 .50419 Mdot
.928 .50474 Mdot
.928 .5052 Mdot
.928 .5056 Mdot
.928 .50614 Mdot
.928 .50645 Mdot
.928 .50701 Mdot
.928 .50793 Mdot
.928 .5081 Mdot
.928 .50823 Mdot
.928 .50942 Mdot
.928 .5097 Mdot
.928 .51032 Mdot
.928 .51056 Mdot
.928 .51192 Mdot
.928 .51236 Mdot
.928 .51246 Mdot
.928 .51262 Mdot
.928 .5127 Mdot
.928 .513 Mdot
.928 .51384 Mdot
.928 .51622 Mdot
.928 .51632 Mdot
.928 .51665 Mdot
.928 .51692 Mdot
.928 .5186 Mdot
.928 .51873 Mdot
.928 .51884 Mdot
.928 .51937 Mdot
.928 .51943 Mdot
.928 .51946 Mdot
.928 .51953 Mdot
.928 .51979 Mdot
.928 .51986 Mdot
.928 .52007 Mdot
.928 .5203 Mdot
.928 .52065 Mdot
.928 .52085 Mdot
.928 .52086 Mdot
.928 .52113 Mdot
.928 .52165 Mdot
.928 .52203 Mdot
.928 .52211 Mdot
.928 .52317 Mdot
.928 .52355 Mdot
.928 .52375 Mdot
.928 .5239 Mdot
.928 .52396 Mdot
.928 .52441 Mdot
.928 .52473 Mdot
.928 .52532 Mdot
.928 .52533 Mdot
.928 .52567 Mdot
.928 .52583 Mdot
.928 .52683 Mdot
.928 .52712 Mdot
.928 .52726 Mdot
.928 .52768 Mdot
.928 .52781 Mdot
.928 .5279 Mdot
.928 .52852 Mdot
.928 .52895 Mdot
.928 .53025 Mdot
.928 .53064 Mdot
.928 .53079 Mdot
.928 .53086 Mdot
.928 .53114 Mdot
.928 .53215 Mdot
.928 .53342 Mdot
.928 .53426 Mdot
.928 .53457 Mdot
.928 .53559 Mdot
.928 .53584 Mdot
.928 .53609 Mdot
.928 .53625 Mdot
.928 .53637 Mdot
.928 .53649 Mdot
.928 .53733 Mdot
.928 .53772 Mdot
.928 .53809 Mdot
.928 .53819 Mdot
.928 .53845 Mdot
.928 .53924 Mdot
.928 .53934 Mdot
.928 .53987 Mdot
.928 .54076 Mdot
.928 .54096 Mdot
.928 .54143 Mdot
.928 .54176 Mdot
.928 .54231 Mdot
.928 .54236 Mdot
.928 .5426 Mdot
.928 .54263 Mdot
.928 .54281 Mdot
.928 .54311 Mdot
.928 .54331 Mdot
.928 .54355 Mdot
.928 .54392 Mdot
.928 .54394 Mdot
.928 .54396 Mdot
.928 .54411 Mdot
.928 .54475 Mdot
.928 .54478 Mdot
.928 .54508 Mdot
.928 .54525 Mdot
.928 .54558 Mdot
.928 .54687 Mdot
.928 .54705 Mdot
.928 .54754 Mdot
.928 .54762 Mdot
.928 .54809 Mdot
.928 .54847 Mdot
.928 .54852 Mdot
.928 .54864 Mdot
.928 .54877 Mdot
.928 .54884 Mdot
.928 .54904 Mdot
.928 .54908 Mdot
.928 .54923 Mdot
.928 .54966 Mdot
.928 .55036 Mdot
.928 .55061 Mdot
.928 .55067 Mdot
.928 .55171 Mdot
.928 .55193 Mdot
.928 .5521 Mdot
.928 .55266 Mdot
.928 .55271 Mdot
.928 .55353 Mdot
.928 .55399 Mdot
.928 .55417 Mdot
.928 .55439 Mdot
.928 .55563 Mdot
.928 .55564 Mdot
.928 .55618 Mdot
.928 .557 Mdot
.928 .55741 Mdot
.928 .55748 Mdot
.928 .55781 Mdot
.928 .55817 Mdot
.928 .55835 Mdot
.928 .55853 Mdot
.928 .55909 Mdot
.928 .55934 Mdot
.928 .55954 Mdot
.928 .55973 Mdot
.928 .55998 Mdot
.928 .56013 Mdot
.928 .56021 Mdot
.928 .56035 Mdot
.928 .56056 Mdot
.928 .5606 Mdot
.928 .56087 Mdot
.928 .56202 Mdot
.928 .56204 Mdot
.93 .09179 Mdot
.93 .09186 Mdot
.93 .09314 Mdot
.93 .09356 Mdot
.93 .09419 Mdot
.93 .0942 Mdot
.93 .09463 Mdot
.93 .09615 Mdot
.93 .09722 Mdot
.93 .09741 Mdot
.93 .09761 Mdot
.93 .09845 Mdot
.93 .10087 Mdot
.93 .10097 Mdot
.93 .10216 Mdot
.93 .10264 Mdot
.93 .10335 Mdot
.93 .10373 Mdot
.93 .1074 Mdot
.93 .10745 Mdot
.93 .10767 Mdot
.93 .10808 Mdot
.93 .10828 Mdot
.93 .10885 Mdot
.93 .10904 Mdot
.93 .10906 Mdot
.93 .10985 Mdot
.93 .10998 Mdot
.93 .11069 Mdot
.93 .11119 Mdot
.93 .11119 Mdot
.93 .11152 Mdot
.93 .11161 Mdot
.93 .1136 Mdot
.93 .11403 Mdot
.93 .11429 Mdot
.93 .11479 Mdot
.93 .11595 Mdot
.93 .11758 Mdot
.93 .11765 Mdot
.93 .11994 Mdot
.93 .12105 Mdot
.93 .12214 Mdot
.93 .12232 Mdot
.93 .12235 Mdot
.93 .12311 Mdot
.93 .12335 Mdot
.93 .12459 Mdot
.93 .12563 Mdot
.93 .1259 Mdot
.93 .12671 Mdot
.93 .12769 Mdot
.93 .12802 Mdot
.93 .12895 Mdot
.93 .12922 Mdot
.93 .1302 Mdot
.93 .13031 Mdot
.93 .13184 Mdot
.93 .13192 Mdot
.93 .13199 Mdot
.93 .13253 Mdot
.93 .13524 Mdot
.93 .13613 Mdot
.93 .1364 Mdot
.93 .13672 Mdot
.93 .13695 Mdot
.93 .1374 Mdot
.93 .13767 Mdot
.93 .13771 Mdot
.93 .13786 Mdot
.93 .13857 Mdot
.93 .14029 Mdot
.93 .1403 Mdot
.93 .14174 Mdot
.93 .14182 Mdot
.93 .14269 Mdot
.93 .14352 Mdot
.93 .14399 Mdot
.93 .14488 Mdot
.93 .1454 Mdot
.93 .14557 Mdot
.93 .14617 Mdot
.93 .14631 Mdot
.93 .14638 Mdot
.93 .14678 Mdot
.93 .14718 Mdot
.93 .14729 Mdot
.93 .149 Mdot
.93 .14923 Mdot
.93 .15027 Mdot
.93 .15137 Mdot
.93 .15521 Mdot
.93 .15544 Mdot
.93 .15561 Mdot
.93 .15777 Mdot
.93 .15808 Mdot
.93 .1582 Mdot
.93 .15845 Mdot
.93 .16022 Mdot
.93 .16037 Mdot
.93 .16059 Mdot
.93 .16075 Mdot
.93 .16087 Mdot
.93 .16136 Mdot
.93 .16226 Mdot
.93 .16253 Mdot
.93 .16255 Mdot
.93 .16261 Mdot
.93 .16335 Mdot
.93 .16341 Mdot
.93 .16434 Mdot
.93 .16464 Mdot
.93 .16618 Mdot
.93 .16625 Mdot
.93 .16817 Mdot
.93 .1684 Mdot
.93 .16852 Mdot
.93 .16889 Mdot
.93 .17033 Mdot
.93 .17046 Mdot
.93 .1707 Mdot
.93 .17158 Mdot
.93 .17184 Mdot
.93 .17223 Mdot
.93 .17236 Mdot
.93 .17242 Mdot
.93 .17289 Mdot
.93 .17335 Mdot
.93 .17336 Mdot
.93 .17403 Mdot
.93 .17476 Mdot
.93 .17496 Mdot
.93 .17515 Mdot
.93 .17577 Mdot
.93 .17736 Mdot
.93 .17825 Mdot
.93 .17861 Mdot
.93 .17877 Mdot
.93 .17893 Mdot
.93 .17958 Mdot
.93 .1796 Mdot
.93 .18028 Mdot
.93 .18033 Mdot
.93 .18062 Mdot
.93 .18089 Mdot
.93 .18183 Mdot
.93 .18189 Mdot
.93 .18324 Mdot
.93 .1836 Mdot
.93 .18398 Mdot
.93 .1843 Mdot
.93 .18492 Mdot
.93 .18595 Mdot
.93 .18613 Mdot
.93 .18711 Mdot
.93 .18715 Mdot
.93 .18719 Mdot
.93 .18762 Mdot
.93 .18837 Mdot
.93 .18845 Mdot
.93 .18875 Mdot
.93 .18876 Mdot
.93 .18951 Mdot
.93 .18981 Mdot
.93 .18986 Mdot
.93 .19016 Mdot
.93 .19019 Mdot
.93 .19087 Mdot
.93 .19088 Mdot
.93 .19098 Mdot
.93 .1915 Mdot
.93 .19167 Mdot
.93 .1919 Mdot
.93 .19323 Mdot
.93 .19367 Mdot
.93 .19415 Mdot
.93 .19416 Mdot
.93 .19477 Mdot
.93 .19495 Mdot
.93 .19578 Mdot
.93 .1977 Mdot
.93 .19801 Mdot
.93 .19855 Mdot
.93 .19864 Mdot
.93 .19945 Mdot
.93 .19992 Mdot
.93 .19995 Mdot
.93 .20016 Mdot
.93 .20086 Mdot
.93 .20185 Mdot
.93 .20302 Mdot
.93 .20358 Mdot
.93 .20457 Mdot
.93 .20463 Mdot
.93 .20525 Mdot
.93 .20537 Mdot
.93 .2054 Mdot
.93 .20604 Mdot
.93 .20617 Mdot
.93 .20649 Mdot
.93 .208 Mdot
.93 .2086 Mdot
.93 .20928 Mdot
.93 .20951 Mdot
.93 .20971 Mdot
.93 .21044 Mdot
.93 .21082 Mdot
.93 .21117 Mdot
.93 .2125 Mdot
.93 .21321 Mdot
.93 .21339 Mdot
.93 .21381 Mdot
.93 .21453 Mdot
.93 .21485 Mdot
.93 .21491 Mdot
.93 .21633 Mdot
.93 .21678 Mdot
.93 .21751 Mdot
.93 .21908 Mdot
.93 .21971 Mdot
.93 .22102 Mdot
.93 .22152 Mdot
.93 .22253 Mdot
.93 .22302 Mdot
.93 .22316 Mdot
.93 .22485 Mdot
.93 .22499 Mdot
.93 .22515 Mdot
.93 .22547 Mdot
.93 .22566 Mdot
.93 .2257 Mdot
.93 .22646 Mdot
.93 .22719 Mdot
.93 .22769 Mdot
.93 .2287 Mdot
.93 .22888 Mdot
.93 .22896 Mdot
.93 .22915 Mdot
.93 .22953 Mdot
.93 .22962 Mdot
.93 .22973 Mdot
.93 .23078 Mdot
.93 .23257 Mdot
.93 .23269 Mdot
.93 .23272 Mdot
.93 .23282 Mdot
.93 .23285 Mdot
.93 .23293 Mdot
.93 .23304 Mdot
.93 .23385 Mdot
.93 .23611 Mdot
.93 .23833 Mdot
.93 .23873 Mdot
.93 .23888 Mdot
.93 .23909 Mdot
.93 .2398 Mdot
.93 .24055 Mdot
.93 .24104 Mdot
.93 .24163 Mdot
.93 .24207 Mdot
.93 .24218 Mdot
.93 .24291 Mdot
.93 .2434 Mdot
.93 .24349 Mdot
.93 .24376 Mdot
.93 .24459 Mdot
.93 .24509 Mdot
.93 .24519 Mdot
.93 .24647 Mdot
.93 .24689 Mdot
.93 .24713 Mdot
.93 .24796 Mdot
.93 .24828 Mdot
.93 .2483 Mdot
.93 .24831 Mdot
.93 .24848 Mdot
.93 .24852 Mdot
.93 .24976 Mdot
.93 .25049 Mdot
.93 .25098 Mdot
.93 .25114 Mdot
.93 .25115 Mdot
.93 .25274 Mdot
.93 .25322 Mdot
.93 .25325 Mdot
.93 .25392 Mdot
.93 .25394 Mdot
.93 .25418 Mdot
.93 .2543 Mdot
.93 .25436 Mdot
.93 .25452 Mdot
.93 .25517 Mdot
.93 .25558 Mdot
.93 .25585 Mdot
.93 .25649 Mdot
.93 .25682 Mdot
.93 .25685 Mdot
.93 .25763 Mdot
.93 .25779 Mdot
.93 .25811 Mdot
.93 .25812 Mdot
.93 .25844 Mdot
.93 .25896 Mdot
.93 .25922 Mdot
.93 .25947 Mdot
.93 .25962 Mdot
.93 .25964 Mdot
.93 .25973 Mdot
.93 .25986 Mdot
.93 .26036 Mdot
.93 .26111 Mdot
.93 .2613 Mdot
.93 .26168 Mdot
.93 .2622 Mdot
.93 .26276 Mdot
.93 .26295 Mdot
.93 .26296 Mdot
.93 .26396 Mdot
.93 .26433 Mdot
.93 .26438 Mdot
.93 .26448 Mdot
.93 .26472 Mdot
.93 .26479 Mdot
.93 .26491 Mdot
.93 .26528 Mdot
.93 .26615 Mdot
.93 .26684 Mdot
.93 .26704 Mdot
.93 .26882 Mdot
.93 .26886 Mdot
.93 .26889 Mdot
.93 .26997 Mdot
.93 .26999 Mdot
.93 .27112 Mdot
.93 .27165 Mdot
.93 .27435 Mdot
.93 .27447 Mdot
.93 .27522 Mdot
.93 .27559 Mdot
.93 .27603 Mdot
.93 .27647 Mdot
.93 .27678 Mdot
.93 .27781 Mdot
.93 .27876 Mdot
.93 .28017 Mdot
.93 .2808 Mdot
.93 .28128 Mdot
.93 .28138 Mdot
.93 .28159 Mdot
.93 .28206 Mdot
.93 .2824 Mdot
.93 .2827 Mdot
.93 .28297 Mdot
.93 .28319 Mdot
.93 .28358 Mdot
.93 .28443 Mdot
.93 .28448 Mdot
.93 .28535 Mdot
.93 .28564 Mdot
.93 .28604 Mdot
.93 .28631 Mdot
.93 .28633 Mdot
.93 .28656 Mdot
.93 .28681 Mdot
.93 .28692 Mdot
.93 .28748 Mdot
.93 .28856 Mdot
.93 .28915 Mdot
.93 .28965 Mdot
.93 .28969 Mdot
.93 .2898 Mdot
.93 .29117 Mdot
.93 .29129 Mdot
.93 .29272 Mdot
.93 .29302 Mdot
.93 .29309 Mdot
.93 .29358 Mdot
.93 .29386 Mdot
.93 .29407 Mdot
.93 .29413 Mdot
.93 .29453 Mdot
.93 .29467 Mdot
.93 .29516 Mdot
.93 .2963 Mdot
.93 .29635 Mdot
.93 .29644 Mdot
.93 .29657 Mdot
.93 .29706 Mdot
.93 .29785 Mdot
.93 .29804 Mdot
.93 .29888 Mdot
.93 .29915 Mdot
.93 .30014 Mdot
.93 .30057 Mdot
.93 .3008 Mdot
.93 .30085 Mdot
.93 .30148 Mdot
.93 .30215 Mdot
.93 .30297 Mdot
.93 .30312 Mdot
.93 .30319 Mdot
.93 .30332 Mdot
.93 .30389 Mdot
.93 .30392 Mdot
.93 .30401 Mdot
.93 .30401 Mdot
.93 .30416 Mdot
.93 .3044 Mdot
.93 .30463 Mdot
.93 .30485 Mdot
.93 .30503 Mdot
.93 .3051 Mdot
.93 .30617 Mdot
.93 .30648 Mdot
.93 .30697 Mdot
.93 .3077 Mdot
.93 .30794 Mdot
.93 .308 Mdot
.93 .30805 Mdot
.93 .3088 Mdot
.93 .30893 Mdot
.93 .30893 Mdot
.93 .30977 Mdot
.93 .30979 Mdot
.93 .31016 Mdot
.93 .31028 Mdot
.93 .31103 Mdot
.93 .3124 Mdot
.93 .31277 Mdot
.93 .31311 Mdot
.93 .31428 Mdot
.93 .31448 Mdot
.93 .3147 Mdot
.93 .31476 Mdot
.93 .31503 Mdot
.93 .31676 Mdot
.93 .31723 Mdot
.93 .31823 Mdot
.93 .3186 Mdot
.93 .3189 Mdot
.93 .31955 Mdot
.93 .31963 Mdot
.93 .31987 Mdot
.93 .32015 Mdot
.93 .32059 Mdot
.93 .32088 Mdot
.93 .32091 Mdot
.93 .32137 Mdot
.93 .32139 Mdot
.93 .32259 Mdot
.93 .32267 Mdot
.93 .32276 Mdot
.93 .32303 Mdot
.93 .3233 Mdot
.93 .32379 Mdot
.93 .32379 Mdot
.93 .32421 Mdot
.93 .32448 Mdot
.93 .32512 Mdot
.93 .32549 Mdot
.93 .32555 Mdot
.93 .32567 Mdot
.93 .32578 Mdot
.93 .32699 Mdot
.93 .32817 Mdot
.93 .32884 Mdot
.93 .32904 Mdot
.93 .32955 Mdot
.93 .33014 Mdot
.93 .33047 Mdot
.93 .33074 Mdot
.93 .33129 Mdot
.93 .33291 Mdot
.93 .33302 Mdot
.93 .33321 Mdot
.93 .33335 Mdot
.93 .33354 Mdot
.93 .33487 Mdot
.93 .33515 Mdot
.93 .33536 Mdot
.93 .33545 Mdot
.93 .33553 Mdot
.93 .3358 Mdot
.93 .33631 Mdot
.93 .33651 Mdot
.93 .33704 Mdot
.93 .33771 Mdot
.93 .33786 Mdot
.93 .33841 Mdot
.93 .33842 Mdot
.93 .33844 Mdot
.93 .33983 Mdot
.93 .34039 Mdot
.93 .34048 Mdot
.93 .34103 Mdot
.93 .3411 Mdot
.93 .34208 Mdot
.93 .34237 Mdot
.93 .34239 Mdot
.93 .34257 Mdot
.93 .3426 Mdot
.93 .34353 Mdot
.93 .34373 Mdot
.93 .34386 Mdot
.93 .34428 Mdot
.93 .34487 Mdot
.93 .34611 Mdot
.93 .34675 Mdot
.93 .34756 Mdot
.93 .34832 Mdot
.93 .34847 Mdot
.93 .34848 Mdot
.93 .3487 Mdot
.93 .34935 Mdot
.93 .34947 Mdot
.93 .34961 Mdot
.93 .34995 Mdot
.93 .3506 Mdot
.93 .35149 Mdot
.93 .35213 Mdot
.93 .35225 Mdot
.93 .35394 Mdot
.93 .35507 Mdot
.93 .35565 Mdot
.93 .35584 Mdot
.93 .35664 Mdot
.93 .35671 Mdot
.93 .35676 Mdot
.93 .35681 Mdot
.93 .35711 Mdot
.93 .35738 Mdot
.93 .35748 Mdot
.93 .35785 Mdot
.93 .35794 Mdot
.93 .35832 Mdot
.93 .35835 Mdot
.93 .35888 Mdot
.93 .35919 Mdot
.93 .35925 Mdot
.93 .35925 Mdot
.93 .35964 Mdot
.93 .36094 Mdot
.93 .36279 Mdot
.93 .36454 Mdot
.93 .36496 Mdot
.93 .366 Mdot
.93 .36785 Mdot
.93 .36796 Mdot
.93 .36818 Mdot
.93 .36837 Mdot
.93 .36856 Mdot
.93 .36889 Mdot
.93 .36911 Mdot
.93 .36933 Mdot
.93 .36939 Mdot
.93 .36971 Mdot
.93 .3702 Mdot
.93 .37058 Mdot
.93 .37081 Mdot
.93 .37086 Mdot
.93 .37112 Mdot
.93 .37129 Mdot
.93 .37141 Mdot
.93 .37174 Mdot
.93 .37254 Mdot
.93 .37289 Mdot
.93 .37414 Mdot
.93 .37422 Mdot
.93 .37522 Mdot
.93 .37533 Mdot
.93 .376 Mdot
.93 .37661 Mdot
.93 .37683 Mdot
.93 .37695 Mdot
.93 .37703 Mdot
.93 .37741 Mdot
.93 .37876 Mdot
.93 .37947 Mdot
.93 .3795 Mdot
.93 .38003 Mdot
.93 .38012 Mdot
.93 .38212 Mdot
.93 .38227 Mdot
.93 .3826 Mdot
.93 .38292 Mdot
.93 .38392 Mdot
.93 .38403 Mdot
.93 .38422 Mdot
.93 .38426 Mdot
.93 .38458 Mdot
.93 .38502 Mdot
.93 .38506 Mdot
.93 .38609 Mdot
.93 .38636 Mdot
.93 .38697 Mdot
.93 .38708 Mdot
.93 .38972 Mdot
.93 .3901 Mdot
.93 .39056 Mdot
.93 .39092 Mdot
.93 .39139 Mdot
.93 .39192 Mdot
.93 .39216 Mdot
.93 .39309 Mdot
.93 .3943 Mdot
.93 .39484 Mdot
.93 .396 Mdot
.93 .3966 Mdot
.93 .39721 Mdot
.93 .39805 Mdot
.93 .3983 Mdot
.93 .39845 Mdot
.93 .39858 Mdot
.93 .39903 Mdot
.93 .39937 Mdot
.93 .4006 Mdot
.93 .40125 Mdot
.93 .40175 Mdot
.93 .40217 Mdot
.93 .40242 Mdot
.93 .40286 Mdot
.93 .40501 Mdot
.93 .40557 Mdot
.93 .40582 Mdot
.93 .40602 Mdot
.93 .40612 Mdot
.93 .40672 Mdot
.93 .40707 Mdot
.93 .40715 Mdot
.93 .40827 Mdot
.93 .40856 Mdot
.93 .40993 Mdot
.93 .40999 Mdot
.93 .41044 Mdot
.93 .41086 Mdot
.93 .41144 Mdot
.93 .4123 Mdot
.93 .41273 Mdot
.93 .41297 Mdot
.93 .41306 Mdot
.93 .4132 Mdot
.93 .41356 Mdot
.93 .41382 Mdot
.93 .41426 Mdot
.93 .41444 Mdot
.93 .41454 Mdot
.93 .41464 Mdot
.93 .4166 Mdot
.93 .41944 Mdot
.93 .41964 Mdot
.93 .41993 Mdot
.93 .42015 Mdot
.93 .4202 Mdot
.93 .42039 Mdot
.93 .42045 Mdot
.93 .42059 Mdot
.93 .42078 Mdot
.93 .42081 Mdot
.93 .42128 Mdot
.93 .4223 Mdot
.93 .42321 Mdot
.93 .42327 Mdot
.93 .42409 Mdot
.93 .4247 Mdot
.93 .42477 Mdot
.93 .42512 Mdot
.93 .42532 Mdot
.93 .42651 Mdot
.93 .42718 Mdot
.93 .42779 Mdot
.93 .42839 Mdot
.93 .42867 Mdot
.93 .43065 Mdot
.93 .43138 Mdot
.93 .43167 Mdot
.93 .43205 Mdot
.93 .4324 Mdot
.93 .43255 Mdot
.93 .43337 Mdot
.93 .43354 Mdot
.93 .4336 Mdot
.93 .43477 Mdot
.93 .43491 Mdot
.93 .43569 Mdot
.93 .43679 Mdot
.93 .43744 Mdot
.93 .43759 Mdot
.93 .4378 Mdot
.93 .43814 Mdot
.93 .43828 Mdot
.93 .43851 Mdot
.93 .43892 Mdot
.93 .43915 Mdot
.93 .44006 Mdot
.93 .44008 Mdot
.93 .44023 Mdot
.93 .44074 Mdot
.93 .4413 Mdot
.93 .4415 Mdot
.93 .44229 Mdot
.93 .44322 Mdot
.93 .44336 Mdot
.93 .44339 Mdot
.93 .44351 Mdot
.93 .44577 Mdot
.93 .44583 Mdot
.93 .4465 Mdot
.93 .44657 Mdot
.93 .447 Mdot
.93 .44798 Mdot
.93 .44856 Mdot
.93 .44859 Mdot
.93 .44881 Mdot
.93 .44914 Mdot
.93 .44914 Mdot
.93 .44919 Mdot
.93 .44921 Mdot
.93 .44952 Mdot
.93 .44958 Mdot
.93 .44962 Mdot
.93 .4497 Mdot
.93 .45014 Mdot
.93 .45084 Mdot
.93 .45176 Mdot
.93 .4519 Mdot
.93 .45235 Mdot
.93 .45246 Mdot
.93 .45288 Mdot
.93 .45326 Mdot
.93 .45329 Mdot
.93 .4539 Mdot
.93 .45417 Mdot
.93 .45424 Mdot
.93 .45446 Mdot
.93 .45448 Mdot
.93 .4546 Mdot
.93 .45502 Mdot
.93 .45521 Mdot
.93 .45745 Mdot
.93 .45833 Mdot
.93 .45839 Mdot
.93 .45866 Mdot
.93 .45964 Mdot
.93 .45967 Mdot
.93 .46013 Mdot
.93 .46034 Mdot
.93 .46045 Mdot
.93 .4606 Mdot
.93 .46076 Mdot
.93 .46137 Mdot
.93 .46196 Mdot
.93 .46272 Mdot
.93 .46323 Mdot
.93 .46442 Mdot
.93 .46462 Mdot
.93 .46502 Mdot
.93 .46509 Mdot
.93 .46654 Mdot
.93 .46683 Mdot
.93 .46743 Mdot
.93 .46744 Mdot
.93 .46804 Mdot
.93 .46806 Mdot
.93 .46902 Mdot
.93 .4695 Mdot
.93 .46996 Mdot
.93 .47023 Mdot
.93 .47027 Mdot
.93 .47045 Mdot
.93 .47048 Mdot
.93 .47068 Mdot
.93 .47121 Mdot
.93 .47122 Mdot
.93 .47132 Mdot
.93 .47162 Mdot
.93 .4719 Mdot
.93 .47288 Mdot
.93 .47295 Mdot
.93 .473 Mdot
.93 .47336 Mdot
.93 .47364 Mdot
.93 .47382 Mdot
.93 .47408 Mdot
.93 .4745 Mdot
.93 .47469 Mdot
.93 .47503 Mdot
.93 .47518 Mdot
.93 .47575 Mdot
.93 .47584 Mdot
.93 .47593 Mdot
.93 .47606 Mdot
.93 .47607 Mdot
.93 .47643 Mdot
.93 .47645 Mdot
.93 .47756 Mdot
.93 .47792 Mdot
.93 .47831 Mdot
.93 .47898 Mdot
.93 .479 Mdot
.93 .47909 Mdot
.93 .47927 Mdot
.93 .47973 Mdot
.93 .47985 Mdot
.93 .48008 Mdot
.93 .48077 Mdot
.93 .48109 Mdot
.93 .48239 Mdot
.93 .48367 Mdot
.93 .48405 Mdot
.93 .48424 Mdot
.93 .48445 Mdot
.93 .48565 Mdot
.93 .4873 Mdot
.93 .48736 Mdot
.93 .48742 Mdot
.93 .48749 Mdot
.93 .48851 Mdot
.93 .48914 Mdot
.93 .48939 Mdot
.93 .48949 Mdot
.93 .48953 Mdot
.93 .48963 Mdot
.93 .49084 Mdot
.93 .49124 Mdot
.93 .49127 Mdot
.93 .49154 Mdot
.93 .49163 Mdot
.93 .49261 Mdot
.93 .49295 Mdot
.93 .49447 Mdot
.93 .49565 Mdot
.93 .49764 Mdot
.93 .49786 Mdot
.93 .49796 Mdot
.93 .49906 Mdot
.93 .49925 Mdot
.93 .49984 Mdot
.93 .49995 Mdot
.93 .50007 Mdot
.93 .50044 Mdot
.93 .50076 Mdot
.93 .50158 Mdot
.93 .50216 Mdot
.93 .50218 Mdot
.93 .50224 Mdot
.93 .50257 Mdot
.93 .5026 Mdot
.93 .50314 Mdot
.93 .50407 Mdot
.93 .50498 Mdot
.93 .50509 Mdot
.93 .50584 Mdot
.93 .50613 Mdot
.93 .5063 Mdot
.93 .50733 Mdot
.93 .50847 Mdot
.93 .50963 Mdot
.93 .50991 Mdot
.93 .50996 Mdot
.93 .50997 Mdot
.93 .51052 Mdot
.93 .5107 Mdot
.93 .5111 Mdot
.93 .51127 Mdot
.93 .51197 Mdot
.93 .51252 Mdot
.93 .51262 Mdot
.93 .51317 Mdot
.93 .5135 Mdot
.93 .51367 Mdot
.93 .51388 Mdot
.93 .51407 Mdot
.93 .5148 Mdot
.93 .51483 Mdot
.93 .51534 Mdot
.93 .51548 Mdot
.93 .51564 Mdot
.93 .51603 Mdot
.93 .51639 Mdot
.93 .51647 Mdot
.93 .51656 Mdot
.93 .51809 Mdot
.93 .51863 Mdot
.93 .51903 Mdot
.93 .51939 Mdot
.93 .51939 Mdot
.93 .51964 Mdot
.93 .51989 Mdot
.93 .51992 Mdot
.93 .51999 Mdot
.93 .5202 Mdot
.93 .52034 Mdot
.93 .52081 Mdot
.93 .52101 Mdot
.93 .52205 Mdot
.93 .52321 Mdot
.93 .52407 Mdot
.93 .52423 Mdot
.93 .52473 Mdot
.93 .52517 Mdot
.93 .52535 Mdot
.93 .5261 Mdot
.93 .52617 Mdot
.93 .52637 Mdot
.93 .52645 Mdot
.93 .5274 Mdot
.93 .52777 Mdot
.93 .52893 Mdot
.93 .52902 Mdot
.93 .52914 Mdot
.93 .53121 Mdot
.93 .5318 Mdot
.93 .53236 Mdot
.93 .53248 Mdot
.93 .5334 Mdot
.93 .53346 Mdot
.93 .53367 Mdot
.93 .53389 Mdot
.93 .53393 Mdot
.93 .534 Mdot
.93 .53432 Mdot
.93 .53442 Mdot
.93 .5347 Mdot
.93 .53517 Mdot
.93 .53543 Mdot
.93 .53588 Mdot
.93 .53634 Mdot
.93 .53639 Mdot
.93 .53716 Mdot
.93 .53717 Mdot
.93 .53809 Mdot
.93 .53847 Mdot
.93 .53855 Mdot
.93 .53858 Mdot
.93 .53872 Mdot
.93 .53896 Mdot
.93 .53909 Mdot
.93 .53926 Mdot
.93 .5394 Mdot
.93 .53988 Mdot
.93 .54134 Mdot
.93 .54163 Mdot
.93 .54166 Mdot
.93 .54171 Mdot
.93 .54253 Mdot
.93 .54259 Mdot
.93 .54312 Mdot
.93 .54326 Mdot
.93 .54376 Mdot
.93 .54394 Mdot
.93 .54447 Mdot
.93 .5449 Mdot
.93 .54504 Mdot
.93 .5456 Mdot
.93 .54627 Mdot
.93 .5464 Mdot
.93 .54681 Mdot
.93 .54683 Mdot
.93 .54692 Mdot
.93 .54751 Mdot
.93 .5481 Mdot
.93 .54934 Mdot
.93 .54938 Mdot
.93 .55025 Mdot
.93 .55087 Mdot
.93 .55115 Mdot
.93 .55128 Mdot
.93 .55151 Mdot
.93 .55258 Mdot
.93 .55263 Mdot
.93 .55281 Mdot
.93 .55281 Mdot
.93 .55308 Mdot
.93 .55346 Mdot
.93 .55353 Mdot
.93 .55396 Mdot
.93 .55397 Mdot
.93 .55407 Mdot
.93 .55437 Mdot
.93 .55448 Mdot
.93 .5547 Mdot
.93 .55482 Mdot
.93 .55485 Mdot
.93 .55682 Mdot
.93 .55702 Mdot
.93 .55741 Mdot
.93 .55767 Mdot
.93 .55831 Mdot
.93 .55836 Mdot
.93 .55966 Mdot
.93 .56011 Mdot
.93 .56022 Mdot
.93 .56032 Mdot
.93 .5609 Mdot
.93 .56172 Mdot
.93 .56195 Mdot
.93 .56195 Mdot
.93 .56229 Mdot
.93 .56251 Mdot
.93 .5632 Mdot
.93 .56324 Mdot
.932 .09193 Mdot
.932 .0922 Mdot
.932 .09226 Mdot
.932 .09241 Mdot
.932 .09364 Mdot
.932 .09401 Mdot
.932 .09426 Mdot
.932 .09466 Mdot
.932 .09504 Mdot
.932 .09583 Mdot
.932 .09637 Mdot
.932 .09752 Mdot
.932 .09904 Mdot
.932 .09909 Mdot
.932 .09999 Mdot
.932 .10246 Mdot
.932 .10254 Mdot
.932 .10676 Mdot
.932 .10739 Mdot
.932 .10773 Mdot
.932 .10797 Mdot
.932 .10898 Mdot
.932 .10959 Mdot
.932 .11008 Mdot
.932 .1103 Mdot
.932 .11216 Mdot
.932 .11288 Mdot
.932 .11289 Mdot
.932 .11363 Mdot
.932 .11456 Mdot
.932 .1148 Mdot
.932 .11488 Mdot
.932 .11827 Mdot
.932 .11893 Mdot
.932 .119 Mdot
.932 .11987 Mdot
.932 .12011 Mdot
.932 .12055 Mdot
.932 .12169 Mdot
.932 .12186 Mdot
.932 .12304 Mdot
.932 .12351 Mdot
.932 .12356 Mdot
.932 .12387 Mdot
.932 .12454 Mdot
.932 .12486 Mdot
.932 .1254 Mdot
.932 .12586 Mdot
.932 .1263 Mdot
.932 .12679 Mdot
.932 .12823 Mdot
.932 .12853 Mdot
.932 .12868 Mdot
.932 .1288 Mdot
.932 .12924 Mdot
.932 .12963 Mdot
.932 .12965 Mdot
.932 .13111 Mdot
.932 .13121 Mdot
.932 .13128 Mdot
.932 .13397 Mdot
.932 .1347 Mdot
.932 .13523 Mdot
.932 .13761 Mdot
.932 .13769 Mdot
.932 .13839 Mdot
.932 .14028 Mdot
.932 .14032 Mdot
.932 .14137 Mdot
.932 .14271 Mdot
.932 .14282 Mdot
.932 .14321 Mdot
.932 .14348 Mdot
.932 .14467 Mdot
.932 .1479 Mdot
.932 .148 Mdot
.932 .148 Mdot
.932 .14843 Mdot
.932 .1485 Mdot
.932 .14872 Mdot
.932 .14878 Mdot
.932 .14925 Mdot
.932 .14929 Mdot
.932 .15086 Mdot
.932 .15168 Mdot
.932 .1525 Mdot
.932 .15408 Mdot
.932 .15469 Mdot
.932 .1549 Mdot
.932 .15548 Mdot
.932 .15622 Mdot
.932 .15627 Mdot
.932 .15646 Mdot
.932 .15704 Mdot
.932 .15719 Mdot
.932 .15721 Mdot
.932 .15865 Mdot
.932 .15869 Mdot
.932 .15893 Mdot
.932 .15915 Mdot
.932 .15927 Mdot
.932 .15954 Mdot
.932 .16089 Mdot
.932 .16158 Mdot
.932 .16184 Mdot
.932 .16251 Mdot
.932 .16299 Mdot
.932 .16324 Mdot
.932 .16374 Mdot
.932 .16381 Mdot
.932 .16393 Mdot
.932 .16445 Mdot
.932 .16591 Mdot
.932 .16651 Mdot
.932 .16692 Mdot
.932 .16728 Mdot
.932 .16771 Mdot
.932 .168 Mdot
.932 .16906 Mdot
.932 .17011 Mdot
.932 .17095 Mdot
.932 .17149 Mdot
.932 .17191 Mdot
.932 .17199 Mdot
.932 .17255 Mdot
.932 .17361 Mdot
.932 .17366 Mdot
.932 .17377 Mdot
.932 .17382 Mdot
.932 .17573 Mdot
.932 .17615 Mdot
.932 .17618 Mdot
.932 .17647 Mdot
.932 .17684 Mdot
.932 .17796 Mdot
.932 .17822 Mdot
.932 .17827 Mdot
.932 .17843 Mdot
.932 .17873 Mdot
.932 .17895 Mdot
.932 .17916 Mdot
.932 .1804 Mdot
.932 .18052 Mdot
.932 .18198 Mdot
.932 .1822 Mdot
.932 .18303 Mdot
.932 .18331 Mdot
.932 .1834 Mdot
.932 .18399 Mdot
.932 .18446 Mdot
.932 .18498 Mdot
.932 .18509 Mdot
.932 .18541 Mdot
.932 .18554 Mdot
.932 .18628 Mdot
.932 .18674 Mdot
.932 .18745 Mdot
.932 .18747 Mdot
.932 .18773 Mdot
.932 .18778 Mdot
.932 .18809 Mdot
.932 .18855 Mdot
.932 .18861 Mdot
.932 .18876 Mdot
.932 .19041 Mdot
.932 .19043 Mdot
.932 .19083 Mdot
.932 .19113 Mdot
.932 .19127 Mdot
.932 .19147 Mdot
.932 .19153 Mdot
.932 .19156 Mdot
.932 .19168 Mdot
.932 .19178 Mdot
.932 .19248 Mdot
.932 .19266 Mdot
.932 .19288 Mdot
.932 .19635 Mdot
.932 .19642 Mdot
.932 .19761 Mdot
.932 .1977 Mdot
.932 .19771 Mdot
.932 .19798 Mdot
.932 .19897 Mdot
.932 .19909 Mdot
.932 .20049 Mdot
.932 .20064 Mdot
.932 .20083 Mdot
.932 .20128 Mdot
.932 .20142 Mdot
.932 .20191 Mdot
.932 .20244 Mdot
.932 .20256 Mdot
.932 .20265 Mdot
.932 .20275 Mdot
.932 .20298 Mdot
.932 .20304 Mdot
.932 .20332 Mdot
.932 .20499 Mdot
.932 .2052 Mdot
.932 .2065 Mdot
.932 .2071 Mdot
.932 .20773 Mdot
.932 .20786 Mdot
.932 .20801 Mdot
.932 .20898 Mdot
.932 .20911 Mdot
.932 .20934 Mdot
.932 .20969 Mdot
.932 .2099 Mdot
.932 .21066 Mdot
.932 .21071 Mdot
.932 .21117 Mdot
.932 .21133 Mdot
.932 .2115 Mdot
.932 .21183 Mdot
.932 .212 Mdot
.932 .21412 Mdot
.932 .21422 Mdot
.932 .21444 Mdot
.932 .21589 Mdot
.932 .21663 Mdot
.932 .21706 Mdot
.932 .21742 Mdot
.932 .21751 Mdot
.932 .21761 Mdot
.932 .21787 Mdot
.932 .21817 Mdot
.932 .21844 Mdot
.932 .21944 Mdot
.932 .22002 Mdot
.932 .22104 Mdot
.932 .2213 Mdot
.932 .22189 Mdot
.932 .22205 Mdot
.932 .2227 Mdot
.932 .22351 Mdot
.932 .22362 Mdot
.932 .22537 Mdot
.932 .22631 Mdot
.932 .22643 Mdot
.932 .22687 Mdot
.932 .22715 Mdot
.932 .22734 Mdot
.932 .22738 Mdot
.932 .22752 Mdot
.932 .22819 Mdot
.932 .22891 Mdot
.932 .22895 Mdot
.932 .22935 Mdot
.932 .23168 Mdot
.932 .23186 Mdot
.932 .23192 Mdot
.932 .232 Mdot
.932 .23215 Mdot
.932 .23265 Mdot
.932 .23522 Mdot
.932 .23701 Mdot
.932 .23836 Mdot
.932 .23857 Mdot
.932 .23935 Mdot
.932 .24057 Mdot
.932 .2409 Mdot
.932 .24141 Mdot
.932 .24286 Mdot
.932 .24306 Mdot
.932 .24378 Mdot
.932 .24394 Mdot
.932 .24525 Mdot
.932 .24612 Mdot
.932 .24655 Mdot
.932 .24793 Mdot
.932 .24826 Mdot
.932 .24842 Mdot
.932 .24876 Mdot
.932 .24884 Mdot
.932 .2491 Mdot
.932 .24965 Mdot
.932 .24977 Mdot
.932 .25053 Mdot
.932 .25077 Mdot
.932 .25079 Mdot
.932 .25117 Mdot
.932 .25121 Mdot
.932 .25147 Mdot
.932 .25185 Mdot
.932 .2527 Mdot
.932 .2533 Mdot
.932 .2535 Mdot
.932 .25386 Mdot
.932 .25423 Mdot
.932 .25446 Mdot
.932 .25474 Mdot
.932 .25551 Mdot
.932 .25695 Mdot
.932 .25758 Mdot
.932 .2579 Mdot
.932 .25867 Mdot
.932 .26007 Mdot
.932 .2606 Mdot
.932 .26191 Mdot
.932 .26239 Mdot
.932 .26297 Mdot
.932 .26315 Mdot
.932 .26317 Mdot
.932 .26328 Mdot
.932 .26395 Mdot
.932 .264 Mdot
.932 .2641 Mdot
.932 .26449 Mdot
.932 .26462 Mdot
.932 .2655 Mdot
.932 .26555 Mdot
.932 .26622 Mdot
.932 .26679 Mdot
.932 .26776 Mdot
.932 .26849 Mdot
.932 .2687 Mdot
.932 .26944 Mdot
.932 .26997 Mdot
.932 .27002 Mdot
.932 .27059 Mdot
.932 .27155 Mdot
.932 .27275 Mdot
.932 .27288 Mdot
.932 .2738 Mdot
.932 .27449 Mdot
.932 .27563 Mdot
.932 .27602 Mdot
.932 .27646 Mdot
.932 .27694 Mdot
.932 .2771 Mdot
.932 .27775 Mdot
.932 .27847 Mdot
.932 .27858 Mdot
.932 .27892 Mdot
.932 .28 Mdot
.932 .28029 Mdot
.932 .28033 Mdot
.932 .28041 Mdot
.932 .28045 Mdot
.932 .28113 Mdot
.932 .28117 Mdot
.932 .28141 Mdot
.932 .28171 Mdot
.932 .28222 Mdot
.932 .28236 Mdot
.932 .28301 Mdot
.932 .28308 Mdot
.932 .2835 Mdot
.932 .28353 Mdot
.932 .28389 Mdot
.932 .28395 Mdot
.932 .28416 Mdot
.932 .28423 Mdot
.932 .28466 Mdot
.932 .28476 Mdot
.932 .28544 Mdot
.932 .2861 Mdot
.932 .28719 Mdot
.932 .28753 Mdot
.932 .28847 Mdot
.932 .28895 Mdot
.932 .29021 Mdot
.932 .29021 Mdot
.932 .29049 Mdot
.932 .29111 Mdot
.932 .29156 Mdot
.932 .2918 Mdot
.932 .2925 Mdot
.932 .29263 Mdot
.932 .29271 Mdot
.932 .29286 Mdot
.932 .29286 Mdot
.932 .29382 Mdot
.932 .29416 Mdot
.932 .29424 Mdot
.932 .29438 Mdot
.932 .29508 Mdot
.932 .29653 Mdot
.932 .2969 Mdot
.932 .29767 Mdot
.932 .29772 Mdot
.932 .29814 Mdot
.932 .29826 Mdot
.932 .29842 Mdot
.932 .2991 Mdot
.932 .29923 Mdot
.932 .29936 Mdot
.932 .29961 Mdot
.932 .29989 Mdot
.932 .30004 Mdot
.932 .30043 Mdot
.932 .30096 Mdot
.932 .3012 Mdot
.932 .30239 Mdot
.932 .30241 Mdot
.932 .30296 Mdot
.932 .30409 Mdot
.932 .30438 Mdot
.932 .30594 Mdot
.932 .30668 Mdot
.932 .30693 Mdot
.932 .30695 Mdot
.932 .30772 Mdot
.932 .30787 Mdot
.932 .30832 Mdot
.932 .3089 Mdot
.932 .30892 Mdot
.932 .3104 Mdot
.932 .31054 Mdot
.932 .31089 Mdot
.932 .311 Mdot
.932 .31118 Mdot
.932 .31129 Mdot
.932 .31201 Mdot
.932 .31343 Mdot
.932 .31467 Mdot
.932 .31485 Mdot
.932 .31494 Mdot
.932 .31548 Mdot
.932 .31562 Mdot
.932 .31568 Mdot
.932 .31622 Mdot
.932 .31643 Mdot
.932 .31664 Mdot
.932 .31691 Mdot
.932 .31798 Mdot
.932 .31817 Mdot
.932 .31851 Mdot
.932 .31864 Mdot
.932 .31901 Mdot
.932 .31949 Mdot
.932 .31959 Mdot
.932 .31987 Mdot
.932 .32043 Mdot
.932 .32085 Mdot
.932 .32093 Mdot
.932 .32101 Mdot
.932 .32125 Mdot
.932 .3217 Mdot
.932 .32271 Mdot
.932 .32354 Mdot
.932 .32357 Mdot
.932 .32377 Mdot
.932 .32432 Mdot
.932 .32463 Mdot
.932 .32504 Mdot
.932 .32651 Mdot
.932 .32666 Mdot
.932 .32674 Mdot
.932 .32691 Mdot
.932 .32736 Mdot
.932 .32846 Mdot
.932 .32852 Mdot
.932 .32869 Mdot
.932 .32892 Mdot
.932 .32897 Mdot
.932 .32914 Mdot
.932 .32961 Mdot
.932 .32968 Mdot
.932 .33025 Mdot
.932 .33109 Mdot
.932 .33112 Mdot
.932 .33209 Mdot
.932 .33229 Mdot
.932 .3329 Mdot
.932 .33314 Mdot
.932 .3336 Mdot
.932 .33391 Mdot
.932 .33397 Mdot
.932 .33452 Mdot
.932 .33465 Mdot
.932 .33483 Mdot
.932 .33538 Mdot
.932 .33662 Mdot
.932 .3367 Mdot
.932 .33672 Mdot
.932 .33689 Mdot
.932 .33721 Mdot
.932 .3373 Mdot
.932 .33734 Mdot
.932 .33789 Mdot
.932 .33797 Mdot
.932 .33874 Mdot
.932 .33886 Mdot
.932 .33905 Mdot
.932 .33914 Mdot
.932 .3412 Mdot
.932 .34168 Mdot
.932 .34205 Mdot
.932 .3422 Mdot
.932 .34224 Mdot
.932 .34226 Mdot
.932 .34236 Mdot
.932 .34238 Mdot
.932 .343 Mdot
.932 .34354 Mdot
.932 .34381 Mdot
.932 .34419 Mdot
.932 .34429 Mdot
.932 .34435 Mdot
.932 .34457 Mdot
.932 .34476 Mdot
.932 .34481 Mdot
.932 .34607 Mdot
.932 .34641 Mdot
.932 .34681 Mdot
.932 .34763 Mdot
.932 .34827 Mdot
.932 .34911 Mdot
.932 .35075 Mdot
.932 .35327 Mdot
.932 .35342 Mdot
.932 .35563 Mdot
.932 .35579 Mdot
.932 .35582 Mdot
.932 .35604 Mdot
.932 .35632 Mdot
.932 .35667 Mdot
.932 .35718 Mdot
.932 .35807 Mdot
.932 .35817 Mdot
.932 .35839 Mdot
.932 .35894 Mdot
.932 .35946 Mdot
.932 .35971 Mdot
.932 .35992 Mdot
.932 .36056 Mdot
.932 .361 Mdot
.932 .36127 Mdot
.932 .36164 Mdot
.932 .36248 Mdot
.932 .36274 Mdot
.932 .36351 Mdot
.932 .36364 Mdot
.932 .36464 Mdot
.932 .36485 Mdot
.932 .36486 Mdot
.932 .36502 Mdot
.932 .36521 Mdot
.932 .36565 Mdot
.932 .36574 Mdot
.932 .36628 Mdot
.932 .36746 Mdot
.932 .36866 Mdot
.932 .36939 Mdot
.932 .36978 Mdot
.932 .37006 Mdot
.932 .3701 Mdot
.932 .37017 Mdot
.932 .3722 Mdot
.932 .37228 Mdot
.932 .37268 Mdot
.932 .37331 Mdot
.932 .37374 Mdot
.932 .3745 Mdot
.932 .37458 Mdot
.932 .37474 Mdot
.932 .37501 Mdot
.932 .37502 Mdot
.932 .37507 Mdot
.932 .37551 Mdot
.932 .37565 Mdot
.932 .37631 Mdot
.932 .37682 Mdot
.932 .37707 Mdot
.932 .37728 Mdot
.932 .37737 Mdot
.932 .37749 Mdot
.932 .37796 Mdot
.932 .37816 Mdot
.932 .37854 Mdot
.932 .3786 Mdot
.932 .3788 Mdot
.932 .37923 Mdot
.932 .37995 Mdot
.932 .38006 Mdot
.932 .38031 Mdot
.932 .3809 Mdot
.932 .38121 Mdot
.932 .38152 Mdot
.932 .38214 Mdot
.932 .38228 Mdot
.932 .38245 Mdot
.932 .38247 Mdot
.932 .38248 Mdot
.932 .38318 Mdot
.932 .38399 Mdot
.932 .38442 Mdot
.932 .38489 Mdot
.932 .38641 Mdot
.932 .38659 Mdot
.932 .387 Mdot
.932 .38856 Mdot
.932 .38895 Mdot
.932 .3897 Mdot
.932 .39046 Mdot
.932 .39109 Mdot
.932 .39151 Mdot
.932 .39175 Mdot
.932 .39189 Mdot
.932 .39255 Mdot
.932 .39272 Mdot
.932 .39291 Mdot
.932 .3934 Mdot
.932 .39396 Mdot
.932 .39402 Mdot
.932 .39422 Mdot
.932 .39446 Mdot
.932 .39458 Mdot
.932 .39471 Mdot
.932 .39632 Mdot
.932 .39662 Mdot
.932 .3974 Mdot
.932 .39754 Mdot
.932 .3993 Mdot
.932 .39979 Mdot
.932 .40082 Mdot
.932 .40089 Mdot
.932 .40108 Mdot
.932 .40119 Mdot
.932 .40241 Mdot
.932 .40254 Mdot
.932 .4031 Mdot
.932 .40391 Mdot
.932 .40412 Mdot
.932 .40609 Mdot
.932 .40634 Mdot
.932 .40657 Mdot
.932 .407 Mdot
.932 .40738 Mdot
.932 .40738 Mdot
.932 .40749 Mdot
.932 .40854 Mdot
.932 .40912 Mdot
.932 .40935 Mdot
.932 .40946 Mdot
.932 .40981 Mdot
.932 .41012 Mdot
.932 .41017 Mdot
.932 .41069 Mdot
.932 .41105 Mdot
.932 .41112 Mdot
.932 .41135 Mdot
.932 .41138 Mdot
.932 .41162 Mdot
.932 .41207 Mdot
.932 .41264 Mdot
.932 .41285 Mdot
.932 .41398 Mdot
.932 .41402 Mdot
.932 .41404 Mdot
.932 .41479 Mdot
.932 .41543 Mdot
.932 .41684 Mdot
.932 .41756 Mdot
.932 .41914 Mdot
.932 .41948 Mdot
.932 .41959 Mdot
.932 .41973 Mdot
.932 .42001 Mdot
.932 .42047 Mdot
.932 .42095 Mdot
.932 .42123 Mdot
.932 .42156 Mdot
.932 .4244 Mdot
.932 .42528 Mdot
.932 .42573 Mdot
.932 .42607 Mdot
.932 .42759 Mdot
.932 .42889 Mdot
.932 .4289 Mdot
.932 .42895 Mdot
.932 .42907 Mdot
.932 .42926 Mdot
.932 .42952 Mdot
.932 .43068 Mdot
.932 .43126 Mdot
.932 .4316 Mdot
.932 .43184 Mdot
.932 .43198 Mdot
.932 .43294 Mdot
.932 .43341 Mdot
.932 .43344 Mdot
.932 .4336 Mdot
.932 .43495 Mdot
.932 .4357 Mdot
.932 .43574 Mdot
.932 .43611 Mdot
.932 .43624 Mdot
.932 .43633 Mdot
.932 .43695 Mdot
.932 .43728 Mdot
.932 .43733 Mdot
.932 .43819 Mdot
.932 .43842 Mdot
.932 .43858 Mdot
.932 .43898 Mdot
.932 .43945 Mdot
.932 .43998 Mdot
.932 .44036 Mdot
.932 .4404 Mdot
.932 .44163 Mdot
.932 .4417 Mdot
.932 .44188 Mdot
.932 .44198 Mdot
.932 .4427 Mdot
.932 .4428 Mdot
.932 .44282 Mdot
.932 .44332 Mdot
.932 .44361 Mdot
.932 .44376 Mdot
.932 .44442 Mdot
.932 .44519 Mdot
.932 .44598 Mdot
.932 .44605 Mdot
.932 .44685 Mdot
.932 .44716 Mdot
.932 .44791 Mdot
.932 .44805 Mdot
.932 .44943 Mdot
.932 .45004 Mdot
.932 .45035 Mdot
.932 .45098 Mdot
.932 .45112 Mdot
.932 .45161 Mdot
.932 .45184 Mdot
.932 .45197 Mdot
.932 .45204 Mdot
.932 .45256 Mdot
.932 .45263 Mdot
.932 .45285 Mdot
.932 .45329 Mdot
.932 .45427 Mdot
.932 .45464 Mdot
.932 .45472 Mdot
.932 .45476 Mdot
.932 .45546 Mdot
.932 .45554 Mdot
.932 .45603 Mdot
.932 .45673 Mdot
.932 .45688 Mdot
.932 .45832 Mdot
.932 .45909 Mdot
.932 .45944 Mdot
.932 .45981 Mdot
.932 .46009 Mdot
.932 .46027 Mdot
.932 .46048 Mdot
.932 .46109 Mdot
.932 .46117 Mdot
.932 .46144 Mdot
.932 .4616 Mdot
.932 .46173 Mdot
.932 .46175 Mdot
.932 .46212 Mdot
.932 .46214 Mdot
.932 .46356 Mdot
.932 .464 Mdot
.932 .46426 Mdot
.932 .46568 Mdot
.932 .46618 Mdot
.932 .46625 Mdot
.932 .46741 Mdot
.932 .46774 Mdot
.932 .46802 Mdot
.932 .46842 Mdot
.932 .46893 Mdot
.932 .46944 Mdot
.932 .46975 Mdot
.932 .47094 Mdot
.932 .47133 Mdot
.932 .4718 Mdot
.932 .47206 Mdot
.932 .47276 Mdot
.932 .47305 Mdot
.932 .4738 Mdot
.932 .47421 Mdot
.932 .47439 Mdot
.932 .47549 Mdot
.932 .47606 Mdot
.932 .47638 Mdot
.932 .477 Mdot
.932 .47746 Mdot
.932 .47766 Mdot
.932 .4778 Mdot
.932 .47783 Mdot
.932 .47804 Mdot
.932 .47817 Mdot
.932 .47858 Mdot
.932 .47864 Mdot
.932 .47894 Mdot
.932 .4793 Mdot
.932 .47939 Mdot
.932 .47956 Mdot
.932 .4803 Mdot
.932 .48053 Mdot
.932 .48217 Mdot
.932 .48228 Mdot
.932 .48306 Mdot
.932 .48333 Mdot
.932 .48351 Mdot
.932 .48458 Mdot
.932 .48638 Mdot
.932 .48776 Mdot
.932 .48803 Mdot
.932 .48815 Mdot
.932 .48953 Mdot
.932 .49051 Mdot
.932 .49061 Mdot
.932 .4911 Mdot
.932 .49166 Mdot
.932 .49266 Mdot
.932 .49345 Mdot
.932 .49385 Mdot
.932 .49538 Mdot
.932 .49569 Mdot
.932 .49593 Mdot
.932 .49612 Mdot
.932 .49675 Mdot
.932 .49765 Mdot
.932 .49893 Mdot
.932 .49911 Mdot
.932 .4992 Mdot
.932 .49956 Mdot
.932 .49997 Mdot
.932 .50008 Mdot
.932 .50027 Mdot
.932 .50098 Mdot
.932 .50106 Mdot
.932 .50147 Mdot
.932 .50179 Mdot
.932 .50249 Mdot
.932 .5026 Mdot
.932 .50349 Mdot
.932 .50365 Mdot
.932 .50368 Mdot
.932 .5038 Mdot
.932 .50386 Mdot
.932 .5039 Mdot
.932 .50396 Mdot
.932 .50425 Mdot
.932 .50493 Mdot
.932 .50501 Mdot
.932 .50583 Mdot
.932 .50636 Mdot
.932 .50656 Mdot
.932 .50719 Mdot
.932 .50921 Mdot
.932 .50969 Mdot
.932 .50974 Mdot
.932 .50982 Mdot
.932 .50985 Mdot
.932 .50996 Mdot
.932 .51004 Mdot
.932 .51019 Mdot
.932 .51042 Mdot
.932 .51131 Mdot
.932 .51138 Mdot
.932 .51183 Mdot
.932 .51186 Mdot
.932 .512 Mdot
.932 .51239 Mdot
.932 .51303 Mdot
.932 .5131 Mdot
.932 .51328 Mdot
.932 .51333 Mdot
.932 .51361 Mdot
.932 .51386 Mdot
.932 .51418 Mdot
.932 .51423 Mdot
.932 .51438 Mdot
.932 .51483 Mdot
.932 .51494 Mdot
.932 .51573 Mdot
.932 .51579 Mdot
.932 .51645 Mdot
.932 .51657 Mdot
.932 .51669 Mdot
.932 .51696 Mdot
.932 .5171 Mdot
.932 .5177 Mdot
.932 .5179 Mdot
.932 .51806 Mdot
.932 .51807 Mdot
.932 .5183 Mdot
.932 .51932 Mdot
.932 .51935 Mdot
.932 .51944 Mdot
.932 .52 Mdot
.932 .52057 Mdot
.932 .52086 Mdot
.932 .52131 Mdot
.932 .52245 Mdot
.932 .5226 Mdot
.932 .52283 Mdot
.932 .52324 Mdot
.932 .52463 Mdot
.932 .52469 Mdot
.932 .525 Mdot
.932 .52589 Mdot
.932 .52626 Mdot
.932 .52731 Mdot
.932 .52744 Mdot
.932 .52823 Mdot
.932 .52824 Mdot
.932 .52832 Mdot
.932 .52864 Mdot
.932 .52873 Mdot
.932 .52877 Mdot
.932 .52916 Mdot
.932 .52947 Mdot
.932 .52958 Mdot
.932 .52991 Mdot
.932 .53076 Mdot
.932 .5312 Mdot
.932 .53164 Mdot
.932 .53248 Mdot
.932 .5325 Mdot
.932 .53275 Mdot
.932 .53279 Mdot
.932 .5329 Mdot
.932 .53294 Mdot
.932 .53317 Mdot
.932 .53317 Mdot
.932 .53323 Mdot
.932 .53496 Mdot
.932 .5356 Mdot
.932 .53574 Mdot
.932 .53595 Mdot
.932 .53601 Mdot
.932 .53673 Mdot
.932 .5373 Mdot
.932 .53732 Mdot
.932 .53833 Mdot
.932 .53871 Mdot
.932 .53875 Mdot
.932 .54002 Mdot
.932 .54031 Mdot
.932 .5407 Mdot
.932 .54214 Mdot
.932 .54218 Mdot
.932 .54223 Mdot
.932 .54302 Mdot
.932 .54303 Mdot
.932 .54324 Mdot
.932 .54347 Mdot
.932 .54354 Mdot
.932 .54362 Mdot
.932 .54378 Mdot
.932 .54455 Mdot
.932 .54482 Mdot
.932 .54505 Mdot
.932 .5453 Mdot
.932 .54559 Mdot
.932 .54576 Mdot
.932 .54612 Mdot
.932 .54628 Mdot
.932 .54631 Mdot
.932 .54656 Mdot
.932 .5472 Mdot
.932 .54729 Mdot
.932 .5479 Mdot
.932 .54814 Mdot
.932 .54827 Mdot
.932 .54873 Mdot
.932 .54877 Mdot
.932 .54912 Mdot
.932 .55094 Mdot
.932 .55098 Mdot
.932 .55111 Mdot
.932 .55161 Mdot
.932 .55201 Mdot
.932 .55201 Mdot
.932 .5524 Mdot
.932 .5534 Mdot
.932 .55351 Mdot
.932 .55378 Mdot
.932 .55411 Mdot
.932 .55465 Mdot
.932 .55478 Mdot
.932 .55496 Mdot
.932 .5553 Mdot
.932 .55756 Mdot
.932 .5576 Mdot
.932 .55893 Mdot
.932 .55941 Mdot
.932 .55944 Mdot
.932 .56026 Mdot
.932 .56087 Mdot
.932 .56116 Mdot
.932 .56158 Mdot
.932 .56179 Mdot
.932 .562 Mdot
.932 .56214 Mdot
.932 .56233 Mdot
.932 .563 Mdot
.932 .56307 Mdot
.932 .56311 Mdot
.932 .56325 Mdot
.934 .08824 Mdot
.934 .08888 Mdot
.934 .09009 Mdot
.934 .09047 Mdot
.934 .09078 Mdot
.934 .09229 Mdot
.934 .0927 Mdot
.934 .09344 Mdot
.934 .09351 Mdot
.934 .09391 Mdot
.934 .09487 Mdot
.934 .0952 Mdot
.934 .09604 Mdot
.934 .09872 Mdot
.934 .10307 Mdot
.934 .10438 Mdot
.934 .10592 Mdot
.934 .10691 Mdot
.934 .10708 Mdot
.934 .10711 Mdot
.934 .10732 Mdot
.934 .10805 Mdot
.934 .1081 Mdot
.934 .11094 Mdot
.934 .11153 Mdot
.934 .11328 Mdot
.934 .11344 Mdot
.934 .11458 Mdot
.934 .11524 Mdot
.934 .11675 Mdot
.934 .11929 Mdot
.934 .11989 Mdot
.934 .11992 Mdot
.934 .12083 Mdot
.934 .121 Mdot
.934 .12141 Mdot
.934 .12226 Mdot
.934 .12268 Mdot
.934 .12271 Mdot
.934 .12359 Mdot
.934 .12491 Mdot
.934 .12521 Mdot
.934 .12562 Mdot
.934 .12613 Mdot
.934 .12654 Mdot
.934 .12659 Mdot
.934 .12682 Mdot
.934 .13011 Mdot
.934 .13118 Mdot
.934 .13392 Mdot
.934 .13393 Mdot
.934 .13401 Mdot
.934 .13406 Mdot
.934 .13579 Mdot
.934 .1368 Mdot
.934 .13681 Mdot
.934 .13874 Mdot
.934 .13975 Mdot
.934 .14001 Mdot
.934 .14012 Mdot
.934 .14079 Mdot
.934 .14296 Mdot
.934 .14428 Mdot
.934 .14544 Mdot
.934 .14567 Mdot
.934 .146 Mdot
.934 .14838 Mdot
.934 .14875 Mdot
.934 .14908 Mdot
.934 .14962 Mdot
.934 .14987 Mdot
.934 .14996 Mdot
.934 .15207 Mdot
.934 .15242 Mdot
.934 .15325 Mdot
.934 .15378 Mdot
.934 .15408 Mdot
.934 .15466 Mdot
.934 .15552 Mdot
.934 .1562 Mdot
.934 .15622 Mdot
.934 .1563 Mdot
.934 .1568 Mdot
.934 .15738 Mdot
.934 .15822 Mdot
.934 .15846 Mdot
.934 .15962 Mdot
.934 .15964 Mdot
.934 .16039 Mdot
.934 .16045 Mdot
.934 .16177 Mdot
.934 .1619 Mdot
.934 .16266 Mdot
.934 .16328 Mdot
.934 .16445 Mdot
.934 .16505 Mdot
.934 .16662 Mdot
.934 .16683 Mdot
.934 .16722 Mdot
.934 .16765 Mdot
.934 .16867 Mdot
.934 .16946 Mdot
.934 .17164 Mdot
.934 .17171 Mdot
.934 .17212 Mdot
.934 .17222 Mdot
.934 .17275 Mdot
.934 .17343 Mdot
.934 .17382 Mdot
.934 .17502 Mdot
.934 .17564 Mdot
.934 .17679 Mdot
.934 .17761 Mdot
.934 .17976 Mdot
.934 .17978 Mdot
.934 .18004 Mdot
.934 .18065 Mdot
.934 .18071 Mdot
.934 .18135 Mdot
.934 .18156 Mdot
.934 .18222 Mdot
.934 .1828 Mdot
.934 .18319 Mdot
.934 .18383 Mdot
.934 .18509 Mdot
.934 .18571 Mdot
.934 .18646 Mdot
.934 .18683 Mdot
.934 .18694 Mdot
.934 .18726 Mdot
.934 .18732 Mdot
.934 .1877 Mdot
.934 .1882 Mdot
.934 .18898 Mdot
.934 .18898 Mdot
.934 .18906 Mdot
.934 .18909 Mdot
.934 .18916 Mdot
.934 .19014 Mdot
.934 .19039 Mdot
.934 .19064 Mdot
.934 .19205 Mdot
.934 .19212 Mdot
.934 .19217 Mdot
.934 .19226 Mdot
.934 .19263 Mdot
.934 .19391 Mdot
.934 .19403 Mdot
.934 .19403 Mdot
.934 .19424 Mdot
.934 .19441 Mdot
.934 .19446 Mdot
.934 .19453 Mdot
.934 .19454 Mdot
.934 .19478 Mdot
.934 .19521 Mdot
.934 .19552 Mdot
.934 .19557 Mdot
.934 .19583 Mdot
.934 .1972 Mdot
.934 .19871 Mdot
.934 .19883 Mdot
.934 .19897 Mdot
.934 .19913 Mdot
.934 .1993 Mdot
.934 .20126 Mdot
.934 .20144 Mdot
.934 .20159 Mdot
.934 .20249 Mdot
.934 .2032 Mdot
.934 .20377 Mdot
.934 .20428 Mdot
.934 .20455 Mdot
.934 .20485 Mdot
.934 .20532 Mdot
.934 .20763 Mdot
.934 .20837 Mdot
.934 .20946 Mdot
.934 .21006 Mdot
.934 .21033 Mdot
.934 .21119 Mdot
.934 .21124 Mdot
.934 .21162 Mdot
.934 .21164 Mdot
.934 .21293 Mdot
.934 .21325 Mdot
.934 .21374 Mdot
.934 .21377 Mdot
.934 .21383 Mdot
.934 .21401 Mdot
.934 .21405 Mdot
.934 .2145 Mdot
.934 .21484 Mdot
.934 .21541 Mdot
.934 .2156 Mdot
.934 .21576 Mdot
.934 .21639 Mdot
.934 .21646 Mdot
.934 .21705 Mdot
.934 .2176 Mdot
.934 .21786 Mdot
.934 .21807 Mdot
.934 .21809 Mdot
.934 .21863 Mdot
.934 .21864 Mdot
.934 .21916 Mdot
.934 .22056 Mdot
.934 .22112 Mdot
.934 .22147 Mdot
.934 .22189 Mdot
.934 .22284 Mdot
.934 .2236 Mdot
.934 .22369 Mdot
.934 .22413 Mdot
.934 .22446 Mdot
.934 .22573 Mdot
.934 .22618 Mdot
.934 .22695 Mdot
.934 .22697 Mdot
.934 .22714 Mdot
.934 .22735 Mdot
.934 .22793 Mdot
.934 .22831 Mdot
.934 .22857 Mdot
.934 .22945 Mdot
.934 .22974 Mdot
.934 .23022 Mdot
.934 .23027 Mdot
.934 .2303 Mdot
.934 .23184 Mdot
.934 .23227 Mdot
.934 .23465 Mdot
.934 .23523 Mdot
.934 .23581 Mdot
.934 .23598 Mdot
.934 .23645 Mdot
.934 .23664 Mdot
.934 .23699 Mdot
.934 .2374 Mdot
.934 .23741 Mdot
.934 .23741 Mdot
.934 .23755 Mdot
.934 .23766 Mdot
.934 .23867 Mdot
.934 .24036 Mdot
.934 .24088 Mdot
.934 .24097 Mdot
.934 .2412 Mdot
.934 .24277 Mdot
.934 .24279 Mdot
.934 .24311 Mdot
.934 .2436 Mdot
.934 .24449 Mdot
.934 .24551 Mdot
.934 .24612 Mdot
.934 .2464 Mdot
.934 .24693 Mdot
.934 .2476 Mdot
.934 .24762 Mdot
.934 .24764 Mdot
.934 .24798 Mdot
.934 .24829 Mdot
.934 .24876 Mdot
.934 .24897 Mdot
.934 .24914 Mdot
.934 .24983 Mdot
.934 .25022 Mdot
.934 .25325 Mdot
.934 .25366 Mdot
.934 .25414 Mdot
.934 .25428 Mdot
.934 .25464 Mdot
.934 .25638 Mdot
.934 .25654 Mdot
.934 .25669 Mdot
.934 .25673 Mdot
.934 .25726 Mdot
.934 .25748 Mdot
.934 .25754 Mdot
.934 .25824 Mdot
.934 .25856 Mdot
.934 .2589 Mdot
.934 .25916 Mdot
.934 .25934 Mdot
.934 .25966 Mdot
.934 .25989 Mdot
.934 .25995 Mdot
.934 .26006 Mdot
.934 .26015 Mdot
.934 .2602 Mdot
.934 .26035 Mdot
.934 .26066 Mdot
.934 .26103 Mdot
.934 .26124 Mdot
.934 .26128 Mdot
.934 .26206 Mdot
.934 .26316 Mdot
.934 .26369 Mdot
.934 .26379 Mdot
.934 .26422 Mdot
.934 .2644 Mdot
.934 .26469 Mdot
.934 .26509 Mdot
.934 .2657 Mdot
.934 .26588 Mdot
.934 .26672 Mdot
.934 .267 Mdot
.934 .26718 Mdot
.934 .26735 Mdot
.934 .26944 Mdot
.934 .26966 Mdot
.934 .27043 Mdot
.934 .27129 Mdot
.934 .27195 Mdot
.934 .2721 Mdot
.934 .27226 Mdot
.934 .2724 Mdot
.934 .27292 Mdot
.934 .2735 Mdot
.934 .27351 Mdot
.934 .27411 Mdot
.934 .27448 Mdot
.934 .27504 Mdot
.934 .27526 Mdot
.934 .27614 Mdot
.934 .27621 Mdot
.934 .27774 Mdot
.934 .27864 Mdot
.934 .27901 Mdot
.934 .27904 Mdot
.934 .27909 Mdot
.934 .27919 Mdot
.934 .27955 Mdot
.934 .27969 Mdot
.934 .28012 Mdot
.934 .28082 Mdot
.934 .28122 Mdot
.934 .28132 Mdot
.934 .28208 Mdot
.934 .28279 Mdot
.934 .28299 Mdot
.934 .28324 Mdot
.934 .28442 Mdot
.934 .28495 Mdot
.934 .2854 Mdot
.934 .28543 Mdot
.934 .28555 Mdot
.934 .28671 Mdot
.934 .28683 Mdot
.934 .28695 Mdot
.934 .28901 Mdot
.934 .28935 Mdot
.934 .28941 Mdot
.934 .28966 Mdot
.934 .29043 Mdot
.934 .29108 Mdot
.934 .29224 Mdot
.934 .29308 Mdot
.934 .29379 Mdot
.934 .29441 Mdot
.934 .29463 Mdot
.934 .295 Mdot
.934 .29555 Mdot
.934 .29555 Mdot
.934 .29635 Mdot
.934 .29638 Mdot
.934 .29747 Mdot
.934 .29848 Mdot
.934 .29861 Mdot
.934 .29876 Mdot
.934 .29887 Mdot
.934 .29934 Mdot
.934 .2996 Mdot
.934 .29972 Mdot
.934 .30008 Mdot
.934 .3004 Mdot
.934 .30057 Mdot
.934 .30173 Mdot
.934 .30229 Mdot
.934 .3028 Mdot
.934 .30297 Mdot
.934 .30378 Mdot
.934 .304 Mdot
.934 .30407 Mdot
.934 .30412 Mdot
.934 .30647 Mdot
.934 .30724 Mdot
.934 .30757 Mdot
.934 .30784 Mdot
.934 .30798 Mdot
.934 .30831 Mdot
.934 .30874 Mdot
.934 .30883 Mdot
.934 .30894 Mdot
.934 .30929 Mdot
.934 .30992 Mdot
.934 .3112 Mdot
.934 .31143 Mdot
.934 .31192 Mdot
.934 .31417 Mdot
.934 .31455 Mdot
.934 .31499 Mdot
.934 .31533 Mdot
.934 .3156 Mdot
.934 .31714 Mdot
.934 .31747 Mdot
.934 .31809 Mdot
.934 .319 Mdot
.934 .31926 Mdot
.934 .31943 Mdot
.934 .3198 Mdot
.934 .32043 Mdot
.934 .3209 Mdot
.934 .32098 Mdot
.934 .32223 Mdot
.934 .32302 Mdot
.934 .32305 Mdot
.934 .32355 Mdot
.934 .32469 Mdot
.934 .32479 Mdot
.934 .32598 Mdot
.934 .32638 Mdot
.934 .32647 Mdot
.934 .32726 Mdot
.934 .32736 Mdot
.934 .32751 Mdot
.934 .32758 Mdot
.934 .32761 Mdot
.934 .3287 Mdot
.934 .32879 Mdot
.934 .3294 Mdot
.934 .32943 Mdot
.934 .33062 Mdot
.934 .33143 Mdot
.934 .33297 Mdot
.934 .3332 Mdot
.934 .33414 Mdot
.934 .33434 Mdot
.934 .33479 Mdot
.934 .3353 Mdot
.934 .33553 Mdot
.934 .33623 Mdot
.934 .33642 Mdot
.934 .33667 Mdot
.934 .33702 Mdot
.934 .33713 Mdot
.934 .33786 Mdot
.934 .33879 Mdot
.934 .33879 Mdot
.934 .33883 Mdot
.934 .33912 Mdot
.934 .3392 Mdot
.934 .33967 Mdot
.934 .33969 Mdot
.934 .33973 Mdot
.934 .34024 Mdot
.934 .34024 Mdot
.934 .34038 Mdot
.934 .34045 Mdot
.934 .34058 Mdot
.934 .34067 Mdot
.934 .34115 Mdot
.934 .34158 Mdot
.934 .34175 Mdot
.934 .34236 Mdot
.934 .34241 Mdot
.934 .34287 Mdot
.934 .34303 Mdot
.934 .34334 Mdot
.934 .34466 Mdot
.934 .34528 Mdot
.934 .34562 Mdot
.934 .34592 Mdot
.934 .34598 Mdot
.934 .34611 Mdot
.934 .3462 Mdot
.934 .34637 Mdot
.934 .34707 Mdot
.934 .34729 Mdot
.934 .34932 Mdot
.934 .34945 Mdot
.934 .34968 Mdot
.934 .34968 Mdot
.934 .34979 Mdot
.934 .35006 Mdot
.934 .35014 Mdot
.934 .35039 Mdot
.934 .35047 Mdot
.934 .35061 Mdot
.934 .35064 Mdot
.934 .35108 Mdot
.934 .35188 Mdot
.934 .35226 Mdot
.934 .35245 Mdot
.934 .35255 Mdot
.934 .35303 Mdot
.934 .35376 Mdot
.934 .35445 Mdot
.934 .3554 Mdot
.934 .35559 Mdot
.934 .3556 Mdot
.934 .35603 Mdot
.934 .35721 Mdot
.934 .35747 Mdot
.934 .35761 Mdot
.934 .3582 Mdot
.934 .35842 Mdot
.934 .35844 Mdot
.934 .35864 Mdot
.934 .35891 Mdot
.934 .35911 Mdot
.934 .35916 Mdot
.934 .3592 Mdot
.934 .35951 Mdot
.934 .3602 Mdot
.934 .36036 Mdot
.934 .36261 Mdot
.934 .36319 Mdot
.934 .36352 Mdot
.934 .36379 Mdot
.934 .36449 Mdot
.934 .36462 Mdot
.934 .36479 Mdot
.934 .36547 Mdot
.934 .36629 Mdot
.934 .36647 Mdot
.934 .3668 Mdot
.934 .36746 Mdot
.934 .36756 Mdot
.934 .36787 Mdot
.934 .36863 Mdot
.934 .36883 Mdot
.934 .36907 Mdot
.934 .36933 Mdot
.934 .36957 Mdot
.934 .36988 Mdot
.934 .37021 Mdot
.934 .37053 Mdot
.934 .37077 Mdot
.934 .37146 Mdot
.934 .37268 Mdot
.934 .37278 Mdot
.934 .37314 Mdot
.934 .37478 Mdot
.934 .37508 Mdot
.934 .37552 Mdot
.934 .37613 Mdot
.934 .37618 Mdot
.934 .37646 Mdot
.934 .37698 Mdot
.934 .37845 Mdot
.934 .37849 Mdot
.934 .37886 Mdot
.934 .37962 Mdot
.934 .38012 Mdot
.934 .38045 Mdot
.934 .38058 Mdot
.934 .38112 Mdot
.934 .38173 Mdot
.934 .38182 Mdot
.934 .38226 Mdot
.934 .38253 Mdot
.934 .38257 Mdot
.934 .38368 Mdot
.934 .38377 Mdot
.934 .38488 Mdot
.934 .38498 Mdot
.934 .38559 Mdot
.934 .38601 Mdot
.934 .38621 Mdot
.934 .38649 Mdot
.934 .38654 Mdot
.934 .38667 Mdot
.934 .387 Mdot
.934 .38708 Mdot
.934 .38729 Mdot
.934 .38736 Mdot
.934 .38756 Mdot
.934 .38786 Mdot
.934 .38791 Mdot
.934 .38855 Mdot
.934 .38961 Mdot
.934 .38997 Mdot
.934 .39028 Mdot
.934 .3904 Mdot
.934 .39055 Mdot
.934 .39073 Mdot
.934 .39144 Mdot
.934 .39157 Mdot
.934 .39267 Mdot
.934 .39309 Mdot
.934 .3937 Mdot
.934 .39386 Mdot
.934 .39418 Mdot
.934 .39459 Mdot
.934 .39462 Mdot
.934 .39532 Mdot
.934 .39562 Mdot
.934 .39564 Mdot
.934 .39652 Mdot
.934 .39661 Mdot
.934 .39729 Mdot
.934 .39849 Mdot
.934 .39923 Mdot
.934 .39987 Mdot
.934 .40029 Mdot
.934 .40093 Mdot
.934 .40171 Mdot
.934 .40212 Mdot
.934 .40338 Mdot
.934 .40348 Mdot
.934 .40356 Mdot
.934 .40492 Mdot
.934 .40508 Mdot
.934 .40519 Mdot
.934 .40523 Mdot
.934 .4058 Mdot
.934 .40591 Mdot
.934 .40652 Mdot
.934 .40711 Mdot
.934 .40716 Mdot
.934 .40792 Mdot
.934 .40853 Mdot
.934 .40882 Mdot
.934 .40889 Mdot
.934 .40974 Mdot
.934 .40996 Mdot
.934 .41075 Mdot
.934 .41118 Mdot
.934 .4112 Mdot
.934 .41153 Mdot
.934 .41192 Mdot
.934 .4128 Mdot
.934 .413 Mdot
.934 .41305 Mdot
.934 .4137 Mdot
.934 .4142 Mdot
.934 .41437 Mdot
.934 .41471 Mdot
.934 .41498 Mdot
.934 .41522 Mdot
.934 .41579 Mdot
.934 .41584 Mdot
.934 .41637 Mdot
.934 .41647 Mdot
.934 .41727 Mdot
.934 .41736 Mdot
.934 .41743 Mdot
.934 .41844 Mdot
.934 .41965 Mdot
.934 .41973 Mdot
.934 .42028 Mdot
.934 .42031 Mdot
.934 .42067 Mdot
.934 .4208 Mdot
.934 .42111 Mdot
.934 .42119 Mdot
.934 .42133 Mdot
.934 .42196 Mdot
.934 .42219 Mdot
.934 .4223 Mdot
.934 .42281 Mdot
.934 .42318 Mdot
.934 .42398 Mdot
.934 .42511 Mdot
.934 .4253 Mdot
.934 .42555 Mdot
.934 .42664 Mdot
.934 .42738 Mdot
.934 .42753 Mdot
.934 .42772 Mdot
.934 .42805 Mdot
.934 .42892 Mdot
.934 .42928 Mdot
.934 .42961 Mdot
.934 .4297 Mdot
.934 .42993 Mdot
.934 .43019 Mdot
.934 .43069 Mdot
.934 .43071 Mdot
.934 .43072 Mdot
.934 .43097 Mdot
.934 .43101 Mdot
.934 .43117 Mdot
.934 .43119 Mdot
.934 .43233 Mdot
.934 .43306 Mdot
.934 .43333 Mdot
.934 .43357 Mdot
.934 .43418 Mdot
.934 .43513 Mdot
.934 .43622 Mdot
.934 .43654 Mdot
.934 .43719 Mdot
.934 .43723 Mdot
.934 .43731 Mdot
.934 .43736 Mdot
.934 .43778 Mdot
.934 .44006 Mdot
.934 .44072 Mdot
.934 .44077 Mdot
.934 .44102 Mdot
.934 .44135 Mdot
.934 .44156 Mdot
.934 .44164 Mdot
.934 .44227 Mdot
.934 .44278 Mdot
.934 .44361 Mdot
.934 .44393 Mdot
.934 .44417 Mdot
.934 .44584 Mdot
.934 .44698 Mdot
.934 .44723 Mdot
.934 .44751 Mdot
.934 .4479 Mdot
.934 .44808 Mdot
.934 .44849 Mdot
.934 .44975 Mdot
.934 .44978 Mdot
.934 .44981 Mdot
.934 .45037 Mdot
.934 .45046 Mdot
.934 .45103 Mdot
.934 .45165 Mdot
.934 .45191 Mdot
.934 .4521 Mdot
.934 .45231 Mdot
.934 .45262 Mdot
.934 .4527 Mdot
.934 .45331 Mdot
.934 .45389 Mdot
.934 .45391 Mdot
.934 .45434 Mdot
.934 .45463 Mdot
.934 .45483 Mdot
.934 .45528 Mdot
.934 .45566 Mdot
.934 .45708 Mdot
.934 .45766 Mdot
.934 .45784 Mdot
.934 .45907 Mdot
.934 .45969 Mdot
.934 .46001 Mdot
.934 .4603 Mdot
.934 .46106 Mdot
.934 .46155 Mdot
.934 .46195 Mdot
.934 .46222 Mdot
.934 .46283 Mdot
.934 .4629 Mdot
.934 .46315 Mdot
.934 .46339 Mdot
.934 .46469 Mdot
.934 .4652 Mdot
.934 .46582 Mdot
.934 .46614 Mdot
.934 .46645 Mdot
.934 .46673 Mdot
.934 .4668 Mdot
.934 .46689 Mdot
.934 .46778 Mdot
.934 .4682 Mdot
.934 .46832 Mdot
.934 .46962 Mdot
.934 .47022 Mdot
.934 .47086 Mdot
.934 .47111 Mdot
.934 .47134 Mdot
.934 .47139 Mdot
.934 .47168 Mdot
.934 .47226 Mdot
.934 .47268 Mdot
.934 .47271 Mdot
.934 .47282 Mdot
.934 .47302 Mdot
.934 .47318 Mdot
.934 .47326 Mdot
.934 .47329 Mdot
.934 .47334 Mdot
.934 .47343 Mdot
.934 .47355 Mdot
.934 .47382 Mdot
.934 .47414 Mdot
.934 .47431 Mdot
.934 .47468 Mdot
.934 .47472 Mdot
.934 .47484 Mdot
.934 .47514 Mdot
.934 .47522 Mdot
.934 .47531 Mdot
.934 .47624 Mdot
.934 .47651 Mdot
.934 .47676 Mdot
.934 .47698 Mdot
.934 .47881 Mdot
.934 .47918 Mdot
.934 .4798 Mdot
.934 .47999 Mdot
.934 .48 Mdot
.934 .48001 Mdot
.934 .48037 Mdot
.934 .4808 Mdot
.934 .48113 Mdot
.934 .48167 Mdot
.934 .48215 Mdot
.934 .48241 Mdot
.934 .48343 Mdot
.934 .48356 Mdot
.934 .48388 Mdot
.934 .48479 Mdot
.934 .48546 Mdot
.934 .48569 Mdot
.934 .48587 Mdot
.934 .48597 Mdot
.934 .48623 Mdot
.934 .48632 Mdot
.934 .48663 Mdot
.934 .48694 Mdot
.934 .48844 Mdot
.934 .48927 Mdot
.934 .48931 Mdot
.934 .48957 Mdot
.934 .48972 Mdot
.934 .49019 Mdot
.934 .49034 Mdot
.934 .49054 Mdot
.934 .49085 Mdot
.934 .49096 Mdot
.934 .49105 Mdot
.934 .49106 Mdot
.934 .49147 Mdot
.934 .49172 Mdot
.934 .49239 Mdot
.934 .494 Mdot
.934 .49523 Mdot
.934 .49551 Mdot
.934 .49552 Mdot
.934 .49581 Mdot
.934 .49593 Mdot
.934 .49607 Mdot
.934 .49636 Mdot
.934 .49705 Mdot
.934 .49724 Mdot
.934 .49754 Mdot
.934 .49773 Mdot
.934 .49797 Mdot
.934 .49808 Mdot
.934 .49812 Mdot
.934 .49814 Mdot
.934 .49863 Mdot
.934 .49926 Mdot
.934 .49927 Mdot
.934 .49996 Mdot
.934 .50043 Mdot
.934 .50101 Mdot
.934 .5014 Mdot
.934 .50289 Mdot
.934 .50305 Mdot
.934 .5032 Mdot
.934 .50347 Mdot
.934 .50378 Mdot
.934 .50464 Mdot
.934 .50472 Mdot
.934 .50587 Mdot
.934 .50604 Mdot
.934 .50618 Mdot
.934 .50699 Mdot
.934 .50772 Mdot
.934 .50789 Mdot
.934 .50805 Mdot
.934 .50828 Mdot
.934 .50841 Mdot
.934 .50842 Mdot
.934 .50848 Mdot
.934 .50857 Mdot
.934 .50868 Mdot
.934 .50868 Mdot
.934 .50875 Mdot
.934 .50943 Mdot
.934 .50963 Mdot
.934 .50968 Mdot
.934 .50971 Mdot
.934 .50974 Mdot
.934 .5105 Mdot
.934 .51064 Mdot
.934 .51077 Mdot
.934 .51133 Mdot
.934 .51139 Mdot
.934 .51139 Mdot
.934 .5118 Mdot
.934 .51254 Mdot
.934 .51274 Mdot
.934 .51314 Mdot
.934 .51415 Mdot
.934 .51449 Mdot
.934 .51469 Mdot
.934 .51536 Mdot
.934 .51548 Mdot
.934 .51582 Mdot
.934 .51585 Mdot
.934 .51617 Mdot
.934 .51631 Mdot
.934 .51748 Mdot
.934 .51791 Mdot
.934 .51853 Mdot
.934 .51886 Mdot
.934 .51951 Mdot
.934 .51971 Mdot
.934 .52008 Mdot
.934 .52036 Mdot
.934 .52042 Mdot
.934 .52063 Mdot
.934 .52184 Mdot
.934 .52226 Mdot
.934 .52281 Mdot
.934 .52304 Mdot
.934 .52324 Mdot
.934 .52515 Mdot
.934 .52666 Mdot
.934 .5271 Mdot
.934 .52772 Mdot
.934 .52785 Mdot
.934 .5283 Mdot
.934 .52889 Mdot
.934 .52894 Mdot
.934 .52976 Mdot
.934 .53007 Mdot
.934 .53023 Mdot
.934 .53096 Mdot
.934 .53228 Mdot
.934 .53233 Mdot
.934 .53246 Mdot
.934 .53275 Mdot
.934 .53293 Mdot
.934 .53312 Mdot
.934 .5344 Mdot
.934 .53457 Mdot
.934 .5347 Mdot
.934 .53532 Mdot
.934 .53602 Mdot
.934 .53719 Mdot
.934 .53754 Mdot
.934 .53761 Mdot
.934 .53774 Mdot
.934 .53828 Mdot
.934 .53931 Mdot
.934 .53932 Mdot
.934 .53986 Mdot
.934 .54079 Mdot
.934 .54082 Mdot
.934 .54086 Mdot
.934 .54086 Mdot
.934 .54233 Mdot
.934 .54291 Mdot
.934 .54466 Mdot
.934 .54479 Mdot
.934 .54481 Mdot
.934 .54503 Mdot
.934 .54531 Mdot
.934 .54553 Mdot
.934 .54569 Mdot
.934 .5464 Mdot
.934 .54686 Mdot
.934 .54688 Mdot
.934 .54711 Mdot
.934 .54756 Mdot
.934 .54778 Mdot
.934 .54787 Mdot
.934 .54836 Mdot
.934 .54837 Mdot
.934 .5487 Mdot
.934 .55005 Mdot
.934 .55087 Mdot
.934 .55122 Mdot
.934 .55183 Mdot
.934 .55191 Mdot
.934 .55285 Mdot
.934 .55317 Mdot
.934 .55469 Mdot
.934 .55472 Mdot
.934 .5551 Mdot
.934 .55521 Mdot
.934 .55523 Mdot
.934 .55532 Mdot
.934 .55585 Mdot
.934 .55667 Mdot
.934 .55738 Mdot
.934 .55971 Mdot
.934 .56114 Mdot
.934 .56159 Mdot
.934 .56177 Mdot
.934 .56228 Mdot
.934 .5625 Mdot
.934 .56253 Mdot
.934 .56293 Mdot
.934 .56315 Mdot
.934 .56396 Mdot
.934 .56413 Mdot
.934 .56433 Mdot
.934 .56498 Mdot
.934 .56532 Mdot
.936 .08571 Mdot
.936 .08632 Mdot
.936 .08656 Mdot
.936 .08747 Mdot
.936 .08887 Mdot
.936 .09021 Mdot
.936 .09044 Mdot
.936 .09177 Mdot
.936 .09209 Mdot
.936 .09385 Mdot
.936 .09428 Mdot
.936 .09458 Mdot
.936 .09463 Mdot
.936 .09552 Mdot
.936 .09581 Mdot
.936 .09761 Mdot
.936 .09835 Mdot
.936 .09837 Mdot
.936 .09897 Mdot
.936 .09906 Mdot
.936 .10038 Mdot
.936 .10047 Mdot
.936 .10111 Mdot
.936 .1012 Mdot
.936 .1018 Mdot
.936 .10224 Mdot
.936 .10338 Mdot
.936 .10359 Mdot
.936 .10366 Mdot
.936 .10478 Mdot
.936 .10483 Mdot
.936 .10513 Mdot
.936 .1058 Mdot
.936 .10737 Mdot
.936 .10749 Mdot
.936 .11039 Mdot
.936 .11142 Mdot
.936 .11264 Mdot
.936 .11382 Mdot
.936 .11433 Mdot
.936 .11479 Mdot
.936 .11614 Mdot
.936 .11631 Mdot
.936 .1174 Mdot
.936 .12118 Mdot
.936 .12153 Mdot
.936 .12217 Mdot
.936 .12323 Mdot
.936 .12478 Mdot
.936 .12543 Mdot
.936 .12648 Mdot
.936 .12649 Mdot
.936 .12677 Mdot
.936 .12685 Mdot
.936 .12688 Mdot
.936 .1286 Mdot
.936 .12923 Mdot
.936 .12969 Mdot
.936 .1303 Mdot
.936 .13112 Mdot
.936 .13131 Mdot
.936 .13249 Mdot
.936 .13359 Mdot
.936 .13631 Mdot
.936 .13732 Mdot
.936 .13766 Mdot
.936 .13832 Mdot
.936 .13906 Mdot
.936 .14058 Mdot
.936 .14066 Mdot
.936 .14198 Mdot
.936 .14228 Mdot
.936 .14253 Mdot
.936 .14275 Mdot
.936 .14306 Mdot
.936 .1437 Mdot
.936 .14374 Mdot
.936 .14397 Mdot
.936 .14436 Mdot
.936 .14542 Mdot
.936 .1455 Mdot
.936 .14643 Mdot
.936 .14719 Mdot
.936 .14732 Mdot
.936 .14761 Mdot
.936 .14876 Mdot
.936 .14921 Mdot
.936 .15092 Mdot
.936 .15103 Mdot
.936 .15236 Mdot
.936 .15311 Mdot
.936 .15353 Mdot
.936 .15603 Mdot
.936 .15604 Mdot
.936 .15636 Mdot
.936 .15648 Mdot
.936 .15681 Mdot
.936 .15682 Mdot
.936 .15776 Mdot
.936 .15798 Mdot
.936 .15833 Mdot
.936 .15862 Mdot
.936 .15884 Mdot
.936 .15896 Mdot
.936 .15936 Mdot
.936 .15956 Mdot
.936 .16197 Mdot
.936 .16285 Mdot
.936 .1634 Mdot
.936 .1634 Mdot
.936 .16362 Mdot
.936 .16367 Mdot
.936 .16422 Mdot
.936 .16432 Mdot
.936 .16438 Mdot
.936 .16545 Mdot
.936 .16597 Mdot
.936 .16598 Mdot
.936 .16619 Mdot
.936 .16652 Mdot
.936 .16894 Mdot
.936 .1699 Mdot
.936 .17021 Mdot
.936 .17032 Mdot
.936 .17127 Mdot
.936 .17132 Mdot
.936 .17243 Mdot
.936 .17261 Mdot
.936 .17282 Mdot
.936 .17302 Mdot
.936 .17365 Mdot
.936 .17457 Mdot
.936 .1747 Mdot
.936 .17479 Mdot
.936 .17486 Mdot
.936 .17506 Mdot
.936 .17507 Mdot
.936 .17525 Mdot
.936 .17644 Mdot
.936 .17662 Mdot
.936 .177 Mdot
.936 .17775 Mdot
.936 .17855 Mdot
.936 .17926 Mdot
.936 .1807 Mdot
.936 .18072 Mdot
.936 .18103 Mdot
.936 .18108 Mdot
.936 .18122 Mdot
.936 .18144 Mdot
.936 .18159 Mdot
.936 .1825 Mdot
.936 .18332 Mdot
.936 .18341 Mdot
.936 .18357 Mdot
.936 .18396 Mdot
.936 .18418 Mdot
.936 .18461 Mdot
.936 .18524 Mdot
.936 .1859 Mdot
.936 .18593 Mdot
.936 .18687 Mdot
.936 .18695 Mdot
.936 .18709 Mdot
.936 .18725 Mdot
.936 .18741 Mdot
.936 .188 Mdot
.936 .18817 Mdot
.936 .18839 Mdot
.936 .18847 Mdot
.936 .18872 Mdot
.936 .18914 Mdot
.936 .18915 Mdot
.936 .18957 Mdot
.936 .18993 Mdot
.936 .19023 Mdot
.936 .19092 Mdot
.936 .19102 Mdot
.936 .19152 Mdot
.936 .19199 Mdot
.936 .19204 Mdot
.936 .19237 Mdot
.936 .19321 Mdot
.936 .19383 Mdot
.936 .19423 Mdot
.936 .1943 Mdot
.936 .1946 Mdot
.936 .19574 Mdot
.936 .19591 Mdot
.936 .19598 Mdot
.936 .19641 Mdot
.936 .19803 Mdot
.936 .19876 Mdot
.936 .1994 Mdot
.936 .20009 Mdot
.936 .20023 Mdot
.936 .20113 Mdot
.936 .20119 Mdot
.936 .2012 Mdot
.936 .20206 Mdot
.936 .20308 Mdot
.936 .20337 Mdot
.936 .20457 Mdot
.936 .20491 Mdot
.936 .20589 Mdot
.936 .20592 Mdot
.936 .20688 Mdot
.936 .20693 Mdot
.936 .20701 Mdot
.936 .20761 Mdot
.936 .20829 Mdot
.936 .20841 Mdot
.936 .20848 Mdot
.936 .20957 Mdot
.936 .21085 Mdot
.936 .21107 Mdot
.936 .21122 Mdot
.936 .21152 Mdot
.936 .21248 Mdot
.936 .2134 Mdot
.936 .21402 Mdot
.936 .21408 Mdot
.936 .21445 Mdot
.936 .21465 Mdot
.936 .21468 Mdot
.936 .21496 Mdot
.936 .21499 Mdot
.936 .21513 Mdot
.936 .21587 Mdot
.936 .21613 Mdot
.936 .21715 Mdot
.936 .21785 Mdot
.936 .21827 Mdot
.936 .22076 Mdot
.936 .22154 Mdot
.936 .22197 Mdot
.936 .22262 Mdot
.936 .22334 Mdot
.936 .22394 Mdot
.936 .22396 Mdot
.936 .22447 Mdot
.936 .22463 Mdot
.936 .22469 Mdot
.936 .22485 Mdot
.936 .22561 Mdot
.936 .22668 Mdot
.936 .2279 Mdot
.936 .22907 Mdot
.936 .22909 Mdot
.936 .22913 Mdot
.936 .22929 Mdot
.936 .2293 Mdot
.936 .22981 Mdot
.936 .22996 Mdot
.936 .2311 Mdot
.936 .23176 Mdot
.936 .23233 Mdot
.936 .23263 Mdot
.936 .23298 Mdot
.936 .23461 Mdot
.936 .23518 Mdot
.936 .23546 Mdot
.936 .2368 Mdot
.936 .23724 Mdot
.936 .23926 Mdot
.936 .23978 Mdot
.936 .24035 Mdot
.936 .2408 Mdot
.936 .24155 Mdot
.936 .24234 Mdot
.936 .24334 Mdot
.936 .24366 Mdot
.936 .24423 Mdot
.936 .24446 Mdot
.936 .24487 Mdot
.936 .24579 Mdot
.936 .2461 Mdot
.936 .24644 Mdot
.936 .2473 Mdot
.936 .24749 Mdot
.936 .24819 Mdot
.936 .2489 Mdot
.936 .24921 Mdot
.936 .24953 Mdot
.936 .24962 Mdot
.936 .25006 Mdot
.936 .25034 Mdot
.936 .25049 Mdot
.936 .25283 Mdot
.936 .25295 Mdot
.936 .25351 Mdot
.936 .25373 Mdot
.936 .25399 Mdot
.936 .25423 Mdot
.936 .2544 Mdot
.936 .25497 Mdot
.936 .25503 Mdot
.936 .2555 Mdot
.936 .2558 Mdot
.936 .25617 Mdot
.936 .25624 Mdot
.936 .25651 Mdot
.936 .25669 Mdot
.936 .25741 Mdot
.936 .2588 Mdot
.936 .25906 Mdot
.936 .25932 Mdot
.936 .2594 Mdot
.936 .25954 Mdot
.936 .26007 Mdot
.936 .26107 Mdot
.936 .26116 Mdot
.936 .26129 Mdot
.936 .26166 Mdot
.936 .26192 Mdot
.936 .26271 Mdot
.936 .26284 Mdot
.936 .26295 Mdot
.936 .26324 Mdot
.936 .2635 Mdot
.936 .26374 Mdot
.936 .26463 Mdot
.936 .26564 Mdot
.936 .26649 Mdot
.936 .26777 Mdot
.936 .26864 Mdot
.936 .26868 Mdot
.936 .2687 Mdot
.936 .26968 Mdot
.936 .2699 Mdot
.936 .27178 Mdot
.936 .27239 Mdot
.936 .27273 Mdot
.936 .27298 Mdot
.936 .27317 Mdot
.936 .27379 Mdot
.936 .2739 Mdot
.936 .27426 Mdot
.936 .27457 Mdot
.936 .27459 Mdot
.936 .27499 Mdot
.936 .27503 Mdot
.936 .27531 Mdot
.936 .27697 Mdot
.936 .27716 Mdot
.936 .27862 Mdot
.936 .27917 Mdot
.936 .27926 Mdot
.936 .27928 Mdot
.936 .27978 Mdot
.936 .27987 Mdot
.936 .28009 Mdot
.936 .28021 Mdot
.936 .28042 Mdot
.936 .28063 Mdot
.936 .28068 Mdot
.936 .28072 Mdot
.936 .28074 Mdot
.936 .28101 Mdot
.936 .28151 Mdot
.936 .28229 Mdot
.936 .2825 Mdot
.936 .28291 Mdot
.936 .28356 Mdot
.936 .28411 Mdot
.936 .28419 Mdot
.936 .28425 Mdot
.936 .28451 Mdot
.936 .28469 Mdot
.936 .28475 Mdot
.936 .2855 Mdot
.936 .28586 Mdot
.936 .2867 Mdot
.936 .28685 Mdot
.936 .28738 Mdot
.936 .28874 Mdot
.936 .28931 Mdot
.936 .28932 Mdot
.936 .28954 Mdot
.936 .29037 Mdot
.936 .29203 Mdot
.936 .29206 Mdot
.936 .29287 Mdot
.936 .29305 Mdot
.936 .29306 Mdot
.936 .29339 Mdot
.936 .29347 Mdot
.936 .29355 Mdot
.936 .29438 Mdot
.936 .29459 Mdot
.936 .29478 Mdot
.936 .29488 Mdot
.936 .29595 Mdot
.936 .29626 Mdot
.936 .29688 Mdot
.936 .29719 Mdot
.936 .29737 Mdot
.936 .29787 Mdot
.936 .29789 Mdot
.936 .29827 Mdot
.936 .29846 Mdot
.936 .2989 Mdot
.936 .29938 Mdot
.936 .30092 Mdot
.936 .30131 Mdot
.936 .30339 Mdot
.936 .30343 Mdot
.936 .30387 Mdot
.936 .30407 Mdot
.936 .30415 Mdot
.936 .30521 Mdot
.936 .3058 Mdot
.936 .30582 Mdot
.936 .30599 Mdot
.936 .306 Mdot
.936 .30708 Mdot
.936 .30729 Mdot
.936 .30779 Mdot
.936 .30788 Mdot
.936 .30826 Mdot
.936 .30936 Mdot
.936 .30961 Mdot
.936 .30996 Mdot
.936 .31029 Mdot
.936 .31069 Mdot
.936 .31107 Mdot
.936 .31223 Mdot
.936 .31233 Mdot
.936 .31259 Mdot
.936 .31267 Mdot
.936 .31318 Mdot
.936 .31397 Mdot
.936 .314 Mdot
.936 .31421 Mdot
.936 .31438 Mdot
.936 .3145 Mdot
.936 .31483 Mdot
.936 .31489 Mdot
.936 .31491 Mdot
.936 .31523 Mdot
.936 .31683 Mdot
.936 .31712 Mdot
.936 .31747 Mdot
.936 .31781 Mdot
.936 .31795 Mdot
.936 .31852 Mdot
.936 .31883 Mdot
.936 .31991 Mdot
.936 .32019 Mdot
.936 .32142 Mdot
.936 .32142 Mdot
.936 .32153 Mdot
.936 .32234 Mdot
.936 .32274 Mdot
.936 .3228 Mdot
.936 .32423 Mdot
.936 .32544 Mdot
.936 .32547 Mdot
.936 .32606 Mdot
.936 .32615 Mdot
.936 .32641 Mdot
.936 .32682 Mdot
.936 .32685 Mdot
.936 .32711 Mdot
.936 .32843 Mdot
.936 .32881 Mdot
.936 .32994 Mdot
.936 .33035 Mdot
.936 .33041 Mdot
.936 .33051 Mdot
.936 .33059 Mdot
.936 .3308 Mdot
.936 .33155 Mdot
.936 .33195 Mdot
.936 .33196 Mdot
.936 .33223 Mdot
.936 .33275 Mdot
.936 .33393 Mdot
.936 .33518 Mdot
.936 .33522 Mdot
.936 .33699 Mdot
.936 .33715 Mdot
.936 .3374 Mdot
.936 .33771 Mdot
.936 .33801 Mdot
.936 .33838 Mdot
.936 .33881 Mdot
.936 .33911 Mdot
.936 .3393 Mdot
.936 .33942 Mdot
.936 .33981 Mdot
.936 .33984 Mdot
.936 .33998 Mdot
.936 .34046 Mdot
.936 .34075 Mdot
.936 .34086 Mdot
.936 .34123 Mdot
.936 .34125 Mdot
.936 .34138 Mdot
.936 .34205 Mdot
.936 .34272 Mdot
.936 .34274 Mdot
.936 .34328 Mdot
.936 .34336 Mdot
.936 .34409 Mdot
.936 .34457 Mdot
.936 .34476 Mdot
.936 .34556 Mdot
.936 .34569 Mdot
.936 .34596 Mdot
.936 .34652 Mdot
.936 .34658 Mdot
.936 .34668 Mdot
.936 .34672 Mdot
.936 .34729 Mdot
.936 .34855 Mdot
.936 .34886 Mdot
.936 .34906 Mdot
.936 .35001 Mdot
.936 .35076 Mdot
.936 .35091 Mdot
.936 .35146 Mdot
.936 .35227 Mdot
.936 .35252 Mdot
.936 .3536 Mdot
.936 .35391 Mdot
.936 .35404 Mdot
.936 .35425 Mdot
.936 .35486 Mdot
.936 .35509 Mdot
.936 .35546 Mdot
.936 .35635 Mdot
.936 .35653 Mdot
.936 .35787 Mdot
.936 .35852 Mdot
.936 .35918 Mdot
.936 .35925 Mdot
.936 .35954 Mdot
.936 .35983 Mdot
.936 .36045 Mdot
.936 .36084 Mdot
.936 .36174 Mdot
.936 .362 Mdot
.936 .362 Mdot
.936 .36328 Mdot
.936 .36349 Mdot
.936 .36369 Mdot
.936 .3638 Mdot
.936 .36381 Mdot
.936 .36483 Mdot
.936 .36529 Mdot
.936 .36535 Mdot
.936 .36542 Mdot
.936 .36552 Mdot
.936 .36642 Mdot
.936 .36714 Mdot
.936 .36718 Mdot
.936 .36733 Mdot
.936 .36772 Mdot
.936 .36789 Mdot
.936 .36789 Mdot
.936 .36795 Mdot
.936 .36867 Mdot
.936 .37013 Mdot
.936 .37076 Mdot
.936 .37131 Mdot
.936 .37204 Mdot
.936 .37212 Mdot
.936 .3726 Mdot
.936 .37265 Mdot
.936 .37301 Mdot
.936 .37445 Mdot
.936 .37455 Mdot
.936 .3747 Mdot
.936 .37582 Mdot
.936 .37631 Mdot
.936 .3767 Mdot
.936 .37708 Mdot
.936 .37731 Mdot
.936 .37744 Mdot
.936 .37948 Mdot
.936 .37966 Mdot
.936 .38005 Mdot
.936 .38189 Mdot
.936 .38201 Mdot
.936 .38229 Mdot
.936 .38256 Mdot
.936 .38274 Mdot
.936 .38313 Mdot
.936 .38331 Mdot
.936 .38352 Mdot
.936 .38405 Mdot
.936 .38427 Mdot
.936 .38493 Mdot
.936 .38585 Mdot
.936 .38592 Mdot
.936 .38665 Mdot
.936 .38702 Mdot
.936 .38782 Mdot
.936 .38792 Mdot
.936 .38801 Mdot
.936 .38863 Mdot
.936 .38899 Mdot
.936 .38905 Mdot
.936 .38957 Mdot
.936 .38963 Mdot
.936 .38989 Mdot
.936 .39053 Mdot
.936 .39128 Mdot
.936 .39151 Mdot
.936 .39177 Mdot
.936 .39282 Mdot
.936 .39367 Mdot
.936 .39434 Mdot
.936 .39498 Mdot
.936 .39577 Mdot
.936 .39705 Mdot
.936 .40044 Mdot
.936 .40189 Mdot
.936 .4027 Mdot
.936 .4034 Mdot
.936 .40392 Mdot
.936 .40527 Mdot
.936 .4058 Mdot
.936 .40638 Mdot
.936 .40642 Mdot
.936 .40727 Mdot
.936 .40738 Mdot
.936 .40767 Mdot
.936 .40778 Mdot
.936 .40808 Mdot
.936 .40847 Mdot
.936 .40952 Mdot
.936 .40973 Mdot
.936 .41131 Mdot
.936 .41152 Mdot
.936 .41328 Mdot
.936 .41376 Mdot
.936 .4138 Mdot
.936 .41419 Mdot
.936 .4156 Mdot
.936 .41598 Mdot
.936 .41602 Mdot
.936 .41611 Mdot
.936 .41639 Mdot
.936 .41642 Mdot
.936 .4168 Mdot
.936 .41728 Mdot
.936 .41737 Mdot
.936 .41741 Mdot
.936 .41765 Mdot
.936 .41837 Mdot
.936 .41848 Mdot
.936 .41916 Mdot
.936 .41978 Mdot
.936 .42032 Mdot
.936 .42048 Mdot
.936 .42067 Mdot
.936 .42102 Mdot
.936 .42208 Mdot
.936 .42218 Mdot
.936 .42265 Mdot
.936 .42286 Mdot
.936 .4233 Mdot
.936 .42423 Mdot
.936 .42436 Mdot
.936 .42607 Mdot
.936 .42635 Mdot
.936 .42733 Mdot
.936 .42743 Mdot
.936 .42773 Mdot
.936 .42795 Mdot
.936 .42873 Mdot
.936 .42912 Mdot
.936 .42945 Mdot
.936 .43018 Mdot
.936 .43046 Mdot
.936 .43051 Mdot
.936 .43102 Mdot
.936 .43129 Mdot
.936 .43155 Mdot
.936 .43178 Mdot
.936 .43506 Mdot
.936 .43521 Mdot
.936 .43594 Mdot
.936 .43604 Mdot
.936 .43629 Mdot
.936 .4371 Mdot
.936 .43794 Mdot
.936 .43934 Mdot
.936 .4401 Mdot
.936 .44035 Mdot
.936 .44078 Mdot
.936 .44084 Mdot
.936 .4415 Mdot
.936 .44222 Mdot
.936 .44269 Mdot
.936 .44314 Mdot
.936 .44329 Mdot
.936 .44436 Mdot
.936 .4448 Mdot
.936 .44524 Mdot
.936 .44552 Mdot
.936 .44556 Mdot
.936 .44569 Mdot
.936 .44728 Mdot
.936 .44787 Mdot
.936 .44839 Mdot
.936 .4485 Mdot
.936 .44908 Mdot
.936 .44917 Mdot
.936 .45006 Mdot
.936 .45011 Mdot
.936 .45021 Mdot
.936 .45047 Mdot
.936 .45158 Mdot
.936 .45179 Mdot
.936 .45261 Mdot
.936 .45311 Mdot
.936 .45369 Mdot
.936 .45378 Mdot
.936 .45428 Mdot
.936 .45445 Mdot
.936 .45528 Mdot
.936 .45581 Mdot
.936 .45609 Mdot
.936 .45652 Mdot
.936 .45787 Mdot
.936 .45799 Mdot
.936 .45799 Mdot
.936 .4583 Mdot
.936 .45903 Mdot
.936 .4593 Mdot
.936 .45938 Mdot
.936 .46046 Mdot
.936 .4607 Mdot
.936 .46073 Mdot
.936 .46174 Mdot
.936 .46216 Mdot
.936 .46243 Mdot
.936 .4626 Mdot
.936 .46263 Mdot
.936 .46274 Mdot
.936 .46285 Mdot
.936 .46308 Mdot
.936 .46341 Mdot
.936 .4637 Mdot
.936 .46448 Mdot
.936 .46459 Mdot
.936 .46547 Mdot
.936 .46562 Mdot
.936 .46564 Mdot
.936 .46585 Mdot
.936 .46603 Mdot
.936 .46623 Mdot
.936 .46661 Mdot
.936 .46672 Mdot
.936 .46685 Mdot
.936 .46736 Mdot
.936 .46769 Mdot
.936 .469 Mdot
.936 .46901 Mdot
.936 .46904 Mdot
.936 .4695 Mdot
.936 .47118 Mdot
.936 .47165 Mdot
.936 .47192 Mdot
.936 .47213 Mdot
.936 .47262 Mdot
.936 .47276 Mdot
.936 .47303 Mdot
.936 .47308 Mdot
.936 .47361 Mdot
.936 .47401 Mdot
.936 .47415 Mdot
.936 .47429 Mdot
.936 .47551 Mdot
.936 .47589 Mdot
.936 .47605 Mdot
.936 .4763 Mdot
.936 .47673 Mdot
.936 .477 Mdot
.936 .47748 Mdot
.936 .47896 Mdot
.936 .4792 Mdot
.936 .47924 Mdot
.936 .47941 Mdot
.936 .47958 Mdot
.936 .47996 Mdot
.936 .48044 Mdot
.936 .48089 Mdot
.936 .48124 Mdot
.936 .48195 Mdot
.936 .48238 Mdot
.936 .48255 Mdot
.936 .48351 Mdot
.936 .48391 Mdot
.936 .48415 Mdot
.936 .48445 Mdot
.936 .48473 Mdot
.936 .48604 Mdot
.936 .48676 Mdot
.936 .48722 Mdot
.936 .48843 Mdot
.936 .48874 Mdot
.936 .48978 Mdot
.936 .49005 Mdot
.936 .49006 Mdot
.936 .49014 Mdot
.936 .49017 Mdot
.936 .49145 Mdot
.936 .49202 Mdot
.936 .49243 Mdot
.936 .49323 Mdot
.936 .49361 Mdot
.936 .4942 Mdot
.936 .49594 Mdot
.936 .49654 Mdot
.936 .49708 Mdot
.936 .49762 Mdot
.936 .49769 Mdot
.936 .49771 Mdot
.936 .49788 Mdot
.936 .49798 Mdot
.936 .49818 Mdot
.936 .49854 Mdot
.936 .49903 Mdot
.936 .49955 Mdot
.936 .49971 Mdot
.936 .49979 Mdot
.936 .4999 Mdot
.936 .50059 Mdot
.936 .50117 Mdot
.936 .50121 Mdot
.936 .50127 Mdot
.936 .50163 Mdot
.936 .50195 Mdot
.936 .50202 Mdot
.936 .50254 Mdot
.936 .50255 Mdot
.936 .5039 Mdot
.936 .50406 Mdot
.936 .50506 Mdot
.936 .5051 Mdot
.936 .50565 Mdot
.936 .50602 Mdot
.936 .50636 Mdot
.936 .50762 Mdot
.936 .50785 Mdot
.936 .50789 Mdot
.936 .50858 Mdot
.936 .50874 Mdot
.936 .50879 Mdot
.936 .50933 Mdot
.936 .50977 Mdot
.936 .50995 Mdot
.936 .50998 Mdot
.936 .51023 Mdot
.936 .5105 Mdot
.936 .51055 Mdot
.936 .51092 Mdot
.936 .51108 Mdot
.936 .51127 Mdot
.936 .5115 Mdot
.936 .5115 Mdot
.936 .51172 Mdot
.936 .51186 Mdot
.936 .51211 Mdot
.936 .51242 Mdot
.936 .51251 Mdot
.936 .5126 Mdot
.936 .51267 Mdot
.936 .51272 Mdot
.936 .51322 Mdot
.936 .51323 Mdot
.936 .51392 Mdot
.936 .51415 Mdot
.936 .51448 Mdot
.936 .51505 Mdot
.936 .51553 Mdot
.936 .51562 Mdot
.936 .51583 Mdot
.936 .516 Mdot
.936 .51678 Mdot
.936 .51799 Mdot
.936 .51902 Mdot
.936 .51913 Mdot
.936 .51917 Mdot
.936 .51922 Mdot
.936 .51928 Mdot
.936 .51978 Mdot
.936 .52011 Mdot
.936 .52022 Mdot
.936 .52156 Mdot
.936 .52162 Mdot
.936 .52229 Mdot
.936 .52376 Mdot
.936 .52388 Mdot
.936 .52416 Mdot
.936 .52473 Mdot
.936 .52513 Mdot
.936 .52525 Mdot
.936 .52525 Mdot
.936 .52602 Mdot
.936 .52741 Mdot
.936 .52769 Mdot
.936 .5278 Mdot
.936 .52796 Mdot
.936 .52815 Mdot
.936 .52826 Mdot
.936 .52877 Mdot
.936 .52877 Mdot
.936 .52901 Mdot
.936 .52919 Mdot
.936 .53075 Mdot
.936 .53115 Mdot
.936 .53186 Mdot
.936 .53384 Mdot
.936 .53391 Mdot
.936 .53432 Mdot
.936 .53481 Mdot
.936 .53486 Mdot
.936 .53542 Mdot
.936 .53563 Mdot
.936 .53576 Mdot
.936 .53578 Mdot
.936 .53612 Mdot
.936 .53628 Mdot
.936 .5364 Mdot
.936 .53654 Mdot
.936 .5367 Mdot
.936 .5374 Mdot
.936 .53744 Mdot
.936 .53825 Mdot
.936 .53865 Mdot
.936 .539 Mdot
.936 .53919 Mdot
.936 .53972 Mdot
.936 .54118 Mdot
.936 .54177 Mdot
.936 .5424 Mdot
.936 .54249 Mdot
.936 .54293 Mdot
.936 .54326 Mdot
.936 .54351 Mdot
.936 .54384 Mdot
.936 .54476 Mdot
.936 .54478 Mdot
.936 .54482 Mdot
.936 .54497 Mdot
.936 .54497 Mdot
.936 .54554 Mdot
.936 .54588 Mdot
.936 .54671 Mdot
.936 .54728 Mdot
.936 .54762 Mdot
.936 .5478 Mdot
.936 .54983 Mdot
.936 .5504 Mdot
.936 .5505 Mdot
.936 .55122 Mdot
.936 .55146 Mdot
.936 .55174 Mdot
.936 .55237 Mdot
.936 .55302 Mdot
.936 .55357 Mdot
.936 .55512 Mdot
.936 .55518 Mdot
.936 .55602 Mdot
.936 .55638 Mdot
.936 .55654 Mdot
.936 .55656 Mdot
.936 .55716 Mdot
.936 .5572 Mdot
.936 .55731 Mdot
.936 .55793 Mdot
.936 .55816 Mdot
.936 .55848 Mdot
.936 .55853 Mdot
.936 .55887 Mdot
.936 .55892 Mdot
.936 .55962 Mdot
.936 .55967 Mdot
.936 .55999 Mdot
.936 .56 Mdot
.936 .5604 Mdot
.936 .56136 Mdot
.936 .56151 Mdot
.936 .56199 Mdot
.936 .56201 Mdot
.936 .56217 Mdot
.936 .56241 Mdot
.936 .56335 Mdot
.936 .56352 Mdot
.936 .56423 Mdot
.936 .56435 Mdot
.936 .56507 Mdot
.936 .56581 Mdot
.936 .5663 Mdot
.936 .56643 Mdot
.936 .56675 Mdot
.938 .08366 Mdot
.938 .084 Mdot
.938 .08412 Mdot
.938 .08684 Mdot
.938 .08761 Mdot
.938 .08763 Mdot
.938 .08819 Mdot
.938 .08829 Mdot
.938 .08857 Mdot
.938 .0907 Mdot
.938 .09099 Mdot
.938 .09149 Mdot
.938 .09165 Mdot
.938 .09209 Mdot
.938 .09223 Mdot
.938 .09239 Mdot
.938 .0929 Mdot
.938 .09293 Mdot
.938 .09297 Mdot
.938 .09358 Mdot
.938 .09477 Mdot
.938 .09587 Mdot
.938 .09645 Mdot
.938 .09892 Mdot
.938 .10163 Mdot
.938 .10361 Mdot
.938 .10365 Mdot
.938 .10429 Mdot
.938 .10523 Mdot
.938 .10526 Mdot
.938 .10606 Mdot
.938 .10634 Mdot
.938 .10809 Mdot
.938 .10865 Mdot
.938 .1088 Mdot
.938 .10914 Mdot
.938 .10956 Mdot
.938 .11099 Mdot
.938 .11104 Mdot
.938 .11241 Mdot
.938 .11394 Mdot
.938 .11398 Mdot
.938 .11517 Mdot
.938 .11529 Mdot
.938 .116 Mdot
.938 .1163 Mdot
.938 .11691 Mdot
.938 .11703 Mdot
.938 .11823 Mdot
.938 .11831 Mdot
.938 .11848 Mdot
.938 .11872 Mdot
.938 .12003 Mdot
.938 .1202 Mdot
.938 .12051 Mdot
.938 .1214 Mdot
.938 .12167 Mdot
.938 .12562 Mdot
.938 .12594 Mdot
.938 .12607 Mdot
.938 .12783 Mdot
.938 .12805 Mdot
.938 .12836 Mdot
.938 .1298 Mdot
.938 .1299 Mdot
.938 .12992 Mdot
.938 .12997 Mdot
.938 .13107 Mdot
.938 .13286 Mdot
.938 .13361 Mdot
.938 .1368 Mdot
.938 .13854 Mdot
.938 .13866 Mdot
.938 .13886 Mdot
.938 .13951 Mdot
.938 .14005 Mdot
.938 .14149 Mdot
.938 .14405 Mdot
.938 .14417 Mdot
.938 .14469 Mdot
.938 .14472 Mdot
.938 .14493 Mdot
.938 .14541 Mdot
.938 .14627 Mdot
.938 .14672 Mdot
.938 .14735 Mdot
.938 .14889 Mdot
.938 .14968 Mdot
.938 .15002 Mdot
.938 .15096 Mdot
.938 .15147 Mdot
.938 .1515 Mdot
.938 .15185 Mdot
.938 .1522 Mdot
.938 .15256 Mdot
.938 .15266 Mdot
.938 .15271 Mdot
.938 .15273 Mdot
.938 .15313 Mdot
.938 .15316 Mdot
.938 .15326 Mdot
.938 .15388 Mdot
.938 .15465 Mdot
.938 .15475 Mdot
.938 .15625 Mdot
.938 .15726 Mdot
.938 .1578 Mdot
.938 .15875 Mdot
.938 .15905 Mdot
.938 .15913 Mdot
.938 .15938 Mdot
.938 .15987 Mdot
.938 .16013 Mdot
.938 .16044 Mdot
.938 .16106 Mdot
.938 .16138 Mdot
.938 .16138 Mdot
.938 .16145 Mdot
.938 .16152 Mdot
.938 .16266 Mdot
.938 .16315 Mdot
.938 .16472 Mdot
.938 .1649 Mdot
.938 .1649 Mdot
.938 .1655 Mdot
.938 .16632 Mdot
.938 .16637 Mdot
.938 .1664 Mdot
.938 .16667 Mdot
.938 .16685 Mdot
.938 .16696 Mdot
.938 .16798 Mdot
.938 .16805 Mdot
.938 .16812 Mdot
.938 .16851 Mdot
.938 .17051 Mdot
.938 .172 Mdot
.938 .17207 Mdot
.938 .17269 Mdot
.938 .17333 Mdot
.938 .17527 Mdot
.938 .1757 Mdot
.938 .17636 Mdot
.938 .1766 Mdot
.938 .17679 Mdot
.938 .17704 Mdot
.938 .17772 Mdot
.938 .17776 Mdot
.938 .17836 Mdot
.938 .17902 Mdot
.938 .18005 Mdot
.938 .18033 Mdot
.938 .18036 Mdot
.938 .18149 Mdot
.938 .18156 Mdot
.938 .18165 Mdot
.938 .1822 Mdot
.938 .18233 Mdot
.938 .18264 Mdot
.938 .18276 Mdot
.938 .1844 Mdot
.938 .18452 Mdot
.938 .18458 Mdot
.938 .18594 Mdot
.938 .18608 Mdot
.938 .1866 Mdot
.938 .18695 Mdot
.938 .187 Mdot
.938 .18765 Mdot
.938 .18793 Mdot
.938 .18882 Mdot
.938 .18882 Mdot
.938 .1891 Mdot
.938 .18989 Mdot
.938 .19055 Mdot
.938 .19094 Mdot
.938 .19121 Mdot
.938 .19185 Mdot
.938 .19219 Mdot
.938 .19264 Mdot
.938 .1946 Mdot
.938 .1947 Mdot
.938 .19471 Mdot
.938 .1951 Mdot
.938 .19533 Mdot
.938 .19541 Mdot
.938 .19651 Mdot
.938 .19693 Mdot
.938 .1976 Mdot
.938 .19775 Mdot
.938 .19799 Mdot
.938 .20086 Mdot
.938 .20093 Mdot
.938 .20174 Mdot
.938 .20259 Mdot
.938 .20266 Mdot
.938 .20317 Mdot
.938 .20338 Mdot
.938 .20411 Mdot
.938 .20472 Mdot
.938 .2053 Mdot
.938 .20545 Mdot
.938 .20609 Mdot
.938 .20642 Mdot
.938 .20662 Mdot
.938 .20665 Mdot
.938 .20673 Mdot
.938 .20743 Mdot
.938 .20761 Mdot
.938 .20824 Mdot
.938 .20868 Mdot
.938 .20891 Mdot
.938 .20906 Mdot
.938 .20923 Mdot
.938 .20938 Mdot
.938 .20983 Mdot
.938 .21024 Mdot
.938 .21042 Mdot
.938 .21047 Mdot
.938 .21073 Mdot
.938 .21137 Mdot
.938 .21228 Mdot
.938 .2126 Mdot
.938 .21319 Mdot
.938 .21379 Mdot
.938 .21469 Mdot
.938 .21475 Mdot
.938 .21486 Mdot
.938 .21537 Mdot
.938 .21607 Mdot
.938 .21691 Mdot
.938 .21841 Mdot
.938 .21859 Mdot
.938 .21949 Mdot
.938 .21991 Mdot
.938 .22049 Mdot
.938 .22194 Mdot
.938 .22277 Mdot
.938 .22337 Mdot
.938 .22362 Mdot
.938 .22364 Mdot
.938 .22691 Mdot
.938 .2272 Mdot
.938 .22734 Mdot
.938 .2279 Mdot
.938 .22813 Mdot
.938 .22928 Mdot
.938 .2304 Mdot
.938 .23049 Mdot
.938 .23062 Mdot
.938 .2308 Mdot
.938 .2308 Mdot
.938 .23084 Mdot
.938 .23093 Mdot
.938 .23123 Mdot
.938 .23157 Mdot
.938 .23283 Mdot
.938 .23299 Mdot
.938 .2335 Mdot
.938 .23359 Mdot
.938 .2343 Mdot
.938 .23438 Mdot
.938 .23521 Mdot
.938 .23563 Mdot
.938 .23614 Mdot
.938 .23635 Mdot
.938 .23659 Mdot
.938 .23672 Mdot
.938 .23765 Mdot
.938 .23776 Mdot
.938 .23822 Mdot
.938 .23879 Mdot
.938 .24374 Mdot
.938 .24437 Mdot
.938 .24472 Mdot
.938 .24476 Mdot
.938 .24543 Mdot
.938 .2458 Mdot
.938 .24608 Mdot
.938 .24616 Mdot
.938 .24644 Mdot
.938 .24664 Mdot
.938 .24702 Mdot
.938 .24707 Mdot
.938 .24724 Mdot
.938 .24743 Mdot
.938 .24761 Mdot
.938 .24801 Mdot
.938 .24822 Mdot
.938 .24883 Mdot
.938 .24984 Mdot
.938 .24991 Mdot
.938 .25029 Mdot
.938 .25195 Mdot
.938 .25254 Mdot
.938 .25264 Mdot
.938 .25294 Mdot
.938 .25366 Mdot
.938 .25436 Mdot
.938 .25524 Mdot
.938 .25735 Mdot
.938 .25757 Mdot
.938 .25855 Mdot
.938 .25856 Mdot
.938 .2586 Mdot
.938 .25863 Mdot
.938 .25867 Mdot
.938 .25899 Mdot
.938 .25991 Mdot
.938 .2615 Mdot
.938 .26179 Mdot
.938 .26226 Mdot
.938 .26236 Mdot
.938 .2629 Mdot
.938 .26307 Mdot
.938 .26317 Mdot
.938 .2633 Mdot
.938 .26335 Mdot
.938 .26345 Mdot
.938 .26353 Mdot
.938 .26384 Mdot
.938 .26394 Mdot
.938 .26615 Mdot
.938 .26642 Mdot
.938 .2668 Mdot
.938 .26758 Mdot
.938 .2678 Mdot
.938 .26791 Mdot
.938 .26855 Mdot
.938 .26882 Mdot
.938 .27031 Mdot
.938 .27126 Mdot
.938 .27132 Mdot
.938 .27198 Mdot
.938 .27236 Mdot
.938 .27263 Mdot
.938 .27332 Mdot
.938 .2735 Mdot
.938 .27359 Mdot
.938 .27364 Mdot
.938 .27421 Mdot
.938 .27438 Mdot
.938 .27444 Mdot
.938 .27463 Mdot
.938 .27467 Mdot
.938 .275 Mdot
.938 .27579 Mdot
.938 .27723 Mdot
.938 .27742 Mdot
.938 .27808 Mdot
.938 .27972 Mdot
.938 .27998 Mdot
.938 .28024 Mdot
.938 .28054 Mdot
.938 .28098 Mdot
.938 .28161 Mdot
.938 .28213 Mdot
.938 .2827 Mdot
.938 .28307 Mdot
.938 .28314 Mdot
.938 .28357 Mdot
.938 .28413 Mdot
.938 .28448 Mdot
.938 .28493 Mdot
.938 .28549 Mdot
.938 .28561 Mdot
.938 .28564 Mdot
.938 .28609 Mdot
.938 .2861 Mdot
.938 .28657 Mdot
.938 .28702 Mdot
.938 .28752 Mdot
.938 .28761 Mdot
.938 .28809 Mdot
.938 .28926 Mdot
.938 .2894 Mdot
.938 .28986 Mdot
.938 .28986 Mdot
.938 .29 Mdot
.938 .29013 Mdot
.938 .29085 Mdot
.938 .29226 Mdot
.938 .29241 Mdot
.938 .29317 Mdot
.938 .29374 Mdot
.938 .29401 Mdot
.938 .29541 Mdot
.938 .29562 Mdot
.938 .29613 Mdot
.938 .29646 Mdot
.938 .29646 Mdot
.938 .2969 Mdot
.938 .29699 Mdot
.938 .29705 Mdot
.938 .29755 Mdot
.938 .29759 Mdot
.938 .29913 Mdot
.938 .29922 Mdot
.938 .29927 Mdot
.938 .29964 Mdot
.938 .29971 Mdot
.938 .29976 Mdot
.938 .29978 Mdot
.938 .30012 Mdot
.938 .30033 Mdot
.938 .30042 Mdot
.938 .301 Mdot
.938 .30184 Mdot
.938 .30225 Mdot
.938 .30237 Mdot
.938 .30246 Mdot
.938 .3025 Mdot
.938 .30316 Mdot
.938 .30324 Mdot
.938 .30347 Mdot
.938 .30374 Mdot
.938 .30392 Mdot
.938 .3045 Mdot
.938 .30527 Mdot
.938 .30597 Mdot
.938 .30679 Mdot
.938 .30696 Mdot
.938 .30698 Mdot
.938 .30721 Mdot
.938 .30821 Mdot
.938 .30829 Mdot
.938 .30848 Mdot
.938 .3087 Mdot
.938 .30951 Mdot
.938 .30979 Mdot
.938 .30992 Mdot
.938 .31092 Mdot
.938 .31108 Mdot
.938 .31179 Mdot
.938 .31187 Mdot
.938 .31201 Mdot
.938 .31206 Mdot
.938 .31222 Mdot
.938 .31227 Mdot
.938 .31242 Mdot
.938 .31295 Mdot
.938 .31326 Mdot
.938 .31546 Mdot
.938 .31592 Mdot
.938 .31673 Mdot
.938 .31757 Mdot
.938 .31796 Mdot
.938 .3184 Mdot
.938 .31874 Mdot
.938 .31877 Mdot
.938 .31924 Mdot
.938 .32051 Mdot
.938 .32059 Mdot
.938 .32171 Mdot
.938 .3229 Mdot
.938 .32295 Mdot
.938 .32489 Mdot
.938 .32542 Mdot
.938 .32547 Mdot
.938 .32581 Mdot
.938 .32734 Mdot
.938 .32758 Mdot
.938 .32771 Mdot
.938 .32789 Mdot
.938 .32832 Mdot
.938 .32891 Mdot
.938 .32916 Mdot
.938 .32941 Mdot
.938 .32974 Mdot
.938 .32996 Mdot
.938 .33042 Mdot
.938 .33123 Mdot
.938 .33287 Mdot
.938 .33304 Mdot
.938 .33328 Mdot
.938 .33338 Mdot
.938 .33343 Mdot
.938 .33489 Mdot
.938 .33594 Mdot
.938 .33613 Mdot
.938 .3362 Mdot
.938 .33652 Mdot
.938 .33688 Mdot
.938 .33718 Mdot
.938 .33727 Mdot
.938 .33763 Mdot
.938 .33783 Mdot
.938 .33791 Mdot
.938 .33914 Mdot
.938 .33934 Mdot
.938 .33967 Mdot
.938 .34016 Mdot
.938 .34063 Mdot
.938 .34134 Mdot
.938 .34134 Mdot
.938 .34145 Mdot
.938 .34185 Mdot
.938 .34221 Mdot
.938 .34334 Mdot
.938 .34358 Mdot
.938 .34401 Mdot
.938 .34458 Mdot
.938 .34531 Mdot
.938 .34547 Mdot
.938 .34582 Mdot
.938 .34702 Mdot
.938 .34765 Mdot
.938 .34838 Mdot
.938 .3485 Mdot
.938 .34867 Mdot
.938 .34956 Mdot
.938 .35117 Mdot
.938 .35151 Mdot
.938 .35172 Mdot
.938 .35217 Mdot
.938 .35236 Mdot
.938 .35239 Mdot
.938 .35262 Mdot
.938 .35285 Mdot
.938 .35311 Mdot
.938 .35328 Mdot
.938 .35354 Mdot
.938 .35371 Mdot
.938 .35387 Mdot
.938 .35556 Mdot
.938 .35575 Mdot
.938 .35596 Mdot
.938 .35655 Mdot
.938 .3578 Mdot
.938 .35809 Mdot
.938 .35829 Mdot
.938 .35854 Mdot
.938 .3595 Mdot
.938 .35952 Mdot
.938 .36054 Mdot
.938 .36088 Mdot
.938 .36099 Mdot
.938 .36101 Mdot
.938 .36164 Mdot
.938 .36211 Mdot
.938 .3624 Mdot
.938 .36341 Mdot
.938 .36393 Mdot
.938 .36406 Mdot
.938 .3655 Mdot
.938 .36557 Mdot
.938 .36586 Mdot
.938 .36603 Mdot
.938 .36634 Mdot
.938 .36659 Mdot
.938 .36717 Mdot
.938 .36731 Mdot
.938 .36774 Mdot
.938 .36825 Mdot
.938 .36866 Mdot
.938 .36996 Mdot
.938 .37002 Mdot
.938 .37038 Mdot
.938 .3704 Mdot
.938 .37042 Mdot
.938 .37116 Mdot
.938 .37119 Mdot
.938 .37154 Mdot
.938 .37225 Mdot
.938 .37254 Mdot
.938 .37319 Mdot
.938 .37362 Mdot
.938 .37367 Mdot
.938 .37373 Mdot
.938 .37436 Mdot
.938 .37461 Mdot
.938 .37469 Mdot
.938 .37473 Mdot
.938 .37479 Mdot
.938 .37494 Mdot
.938 .37625 Mdot
.938 .37659 Mdot
.938 .37777 Mdot
.938 .37859 Mdot
.938 .37903 Mdot
.938 .37931 Mdot
.938 .37962 Mdot
.938 .3799 Mdot
.938 .38013 Mdot
.938 .38076 Mdot
.938 .38153 Mdot
.938 .38185 Mdot
.938 .38195 Mdot
.938 .38244 Mdot
.938 .38364 Mdot
.938 .38534 Mdot
.938 .38596 Mdot
.938 .38621 Mdot
.938 .38628 Mdot
.938 .38705 Mdot
.938 .38716 Mdot
.938 .38817 Mdot
.938 .38928 Mdot
.938 .38987 Mdot
.938 .38997 Mdot
.938 .39002 Mdot
.938 .39018 Mdot
.938 .39051 Mdot
.938 .39114 Mdot
.938 .39126 Mdot
.938 .39127 Mdot
.938 .39159 Mdot
.938 .39218 Mdot
.938 .39246 Mdot
.938 .39403 Mdot
.938 .39684 Mdot
.938 .39698 Mdot
.938 .39719 Mdot
.938 .39719 Mdot
.938 .39728 Mdot
.938 .39882 Mdot
.938 .39888 Mdot
.938 .39934 Mdot
.938 .39966 Mdot
.938 .39993 Mdot
.938 .40075 Mdot
.938 .4008 Mdot
.938 .40091 Mdot
.938 .40347 Mdot
.938 .40379 Mdot
.938 .40396 Mdot
.938 .40396 Mdot
.938 .40436 Mdot
.938 .40462 Mdot
.938 .40502 Mdot
.938 .40615 Mdot
.938 .40662 Mdot
.938 .40665 Mdot
.938 .40989 Mdot
.938 .4128 Mdot
.938 .41284 Mdot
.938 .41334 Mdot
.938 .41337 Mdot
.938 .41359 Mdot
.938 .41447 Mdot
.938 .41466 Mdot
.938 .41507 Mdot
.938 .41508 Mdot
.938 .41509 Mdot
.938 .41532 Mdot
.938 .4165 Mdot
.938 .41711 Mdot
.938 .41724 Mdot
.938 .41741 Mdot
.938 .4175 Mdot
.938 .41769 Mdot
.938 .41881 Mdot
.938 .41934 Mdot
.938 .4195 Mdot
.938 .41975 Mdot
.938 .42008 Mdot
.938 .4201 Mdot
.938 .42016 Mdot
.938 .42034 Mdot
.938 .42088 Mdot
.938 .42089 Mdot
.938 .42153 Mdot
.938 .42278 Mdot
.938 .42299 Mdot
.938 .42389 Mdot
.938 .42421 Mdot
.938 .42443 Mdot
.938 .42456 Mdot
.938 .42504 Mdot
.938 .42515 Mdot
.938 .42533 Mdot
.938 .42619 Mdot
.938 .42666 Mdot
.938 .42682 Mdot
.938 .42837 Mdot
.938 .42915 Mdot
.938 .42938 Mdot
.938 .43011 Mdot
.938 .43051 Mdot
.938 .43095 Mdot
.938 .4312 Mdot
.938 .43164 Mdot
.938 .43255 Mdot
.938 .43274 Mdot
.938 .43295 Mdot
.938 .43314 Mdot
.938 .43335 Mdot
.938 .43401 Mdot
.938 .43479 Mdot
.938 .43508 Mdot
.938 .43596 Mdot
.938 .43639 Mdot
.938 .43693 Mdot
.938 .43751 Mdot
.938 .43804 Mdot
.938 .43885 Mdot
.938 .4404 Mdot
.938 .44262 Mdot
.938 .44324 Mdot
.938 .44437 Mdot
.938 .44554 Mdot
.938 .44571 Mdot
.938 .44598 Mdot
.938 .44609 Mdot
.938 .44618 Mdot
.938 .4462 Mdot
.938 .44628 Mdot
.938 .44632 Mdot
.938 .44679 Mdot
.938 .44754 Mdot
.938 .44797 Mdot
.938 .44809 Mdot
.938 .44819 Mdot
.938 .44823 Mdot
.938 .44876 Mdot
.938 .4489 Mdot
.938 .44899 Mdot
.938 .44942 Mdot
.938 .4498 Mdot
.938 .45021 Mdot
.938 .45052 Mdot
.938 .45061 Mdot
.938 .45076 Mdot
.938 .45092 Mdot
.938 .45129 Mdot
.938 .45163 Mdot
.938 .45207 Mdot
.938 .45239 Mdot
.938 .45274 Mdot
.938 .45276 Mdot
.938 .4528 Mdot
.938 .45391 Mdot
.938 .45418 Mdot
.938 .45421 Mdot
.938 .45426 Mdot
.938 .45494 Mdot
.938 .45505 Mdot
.938 .4558 Mdot
.938 .45595 Mdot
.938 .45665 Mdot
.938 .45749 Mdot
.938 .45825 Mdot
.938 .45921 Mdot
.938 .45977 Mdot
.938 .46002 Mdot
.938 .46028 Mdot
.938 .46088 Mdot
.938 .46107 Mdot
.938 .46136 Mdot
.938 .46163 Mdot
.938 .46183 Mdot
.938 .46241 Mdot
.938 .46275 Mdot
.938 .46298 Mdot
.938 .46328 Mdot
.938 .46342 Mdot
.938 .46429 Mdot
.938 .46593 Mdot
.938 .46611 Mdot
.938 .46636 Mdot
.938 .46734 Mdot
.938 .46923 Mdot
.938 .46977 Mdot
.938 .46989 Mdot
.938 .4703 Mdot
.938 .47065 Mdot
.938 .47183 Mdot
.938 .47188 Mdot
.938 .47209 Mdot
.938 .47214 Mdot
.938 .47217 Mdot
.938 .47224 Mdot
.938 .47229 Mdot
.938 .47238 Mdot
.938 .47273 Mdot
.938 .47298 Mdot
.938 .47464 Mdot
.938 .47466 Mdot
.938 .4747 Mdot
.938 .47647 Mdot
.938 .47693 Mdot
.938 .47731 Mdot
.938 .47769 Mdot
.938 .47785 Mdot
.938 .47822 Mdot
.938 .47911 Mdot
.938 .47931 Mdot
.938 .48021 Mdot
.938 .48032 Mdot
.938 .48063 Mdot
.938 .48082 Mdot
.938 .48105 Mdot
.938 .48116 Mdot
.938 .48131 Mdot
.938 .48135 Mdot
.938 .4815 Mdot
.938 .48169 Mdot
.938 .48205 Mdot
.938 .48207 Mdot
.938 .48226 Mdot
.938 .48523 Mdot
.938 .48554 Mdot
.938 .48584 Mdot
.938 .48634 Mdot
.938 .48641 Mdot
.938 .48665 Mdot
.938 .48692 Mdot
.938 .48714 Mdot
.938 .48758 Mdot
.938 .48763 Mdot
.938 .488 Mdot
.938 .48806 Mdot
.938 .48841 Mdot
.938 .48908 Mdot
.938 .48927 Mdot
.938 .4895 Mdot
.938 .48966 Mdot
.938 .48971 Mdot
.938 .4903 Mdot
.938 .49091 Mdot
.938 .49141 Mdot
.938 .49331 Mdot
.938 .49422 Mdot
.938 .49499 Mdot
.938 .4953 Mdot
.938 .49552 Mdot
.938 .496 Mdot
.938 .4961 Mdot
.938 .4969 Mdot
.938 .49734 Mdot
.938 .49805 Mdot
.938 .49808 Mdot
.938 .49856 Mdot
.938 .49985 Mdot
.938 .50019 Mdot
.938 .50033 Mdot
.938 .50036 Mdot
.938 .50045 Mdot
.938 .50099 Mdot
.938 .50128 Mdot
.938 .50152 Mdot
.938 .50186 Mdot
.938 .50195 Mdot
.938 .50232 Mdot
.938 .50238 Mdot
.938 .50267 Mdot
.938 .50301 Mdot
.938 .50372 Mdot
.938 .50449 Mdot
.938 .50453 Mdot
.938 .50499 Mdot
.938 .50711 Mdot
.938 .50719 Mdot
.938 .50755 Mdot
.938 .50777 Mdot
.938 .50852 Mdot
.938 .50873 Mdot
.938 .50874 Mdot
.938 .50879 Mdot
.938 .51008 Mdot
.938 .51095 Mdot
.938 .51187 Mdot
.938 .51187 Mdot
.938 .51234 Mdot
.938 .5125 Mdot
.938 .51284 Mdot
.938 .51287 Mdot
.938 .5134 Mdot
.938 .51423 Mdot
.938 .51517 Mdot
.938 .51533 Mdot
.938 .5154 Mdot
.938 .51569 Mdot
.938 .51638 Mdot
.938 .51639 Mdot
.938 .51655 Mdot
.938 .5171 Mdot
.938 .51745 Mdot
.938 .51779 Mdot
.938 .51815 Mdot
.938 .51828 Mdot
.938 .51839 Mdot
.938 .51851 Mdot
.938 .51886 Mdot
.938 .51909 Mdot
.938 .52013 Mdot
.938 .5208 Mdot
.938 .52084 Mdot
.938 .52163 Mdot
.938 .5227 Mdot
.938 .52291 Mdot
.938 .52298 Mdot
.938 .52358 Mdot
.938 .52368 Mdot
.938 .52382 Mdot
.938 .52384 Mdot
.938 .52386 Mdot
.938 .5243 Mdot
.938 .52462 Mdot
.938 .52472 Mdot
.938 .52556 Mdot
.938 .5265 Mdot
.938 .52667 Mdot
.938 .52757 Mdot
.938 .5277 Mdot
.938 .52923 Mdot
.938 .53003 Mdot
.938 .53009 Mdot
.938 .5305 Mdot
.938 .53088 Mdot
.938 .53089 Mdot
.938 .53112 Mdot
.938 .53115 Mdot
.938 .53139 Mdot
.938 .53158 Mdot
.938 .53205 Mdot
.938 .53274 Mdot
.938 .53316 Mdot
.938 .53398 Mdot
.938 .53431 Mdot
.938 .53455 Mdot
.938 .53501 Mdot
.938 .53538 Mdot
.938 .53567 Mdot
.938 .5371 Mdot
.938 .53787 Mdot
.938 .53816 Mdot
.938 .5385 Mdot
.938 .53861 Mdot
.938 .53867 Mdot
.938 .5396 Mdot
.938 .5413 Mdot
.938 .5417 Mdot
.938 .54266 Mdot
.938 .54324 Mdot
.938 .54327 Mdot
.938 .54328 Mdot
.938 .54333 Mdot
.938 .5441 Mdot
.938 .54426 Mdot
.938 .54438 Mdot
.938 .54532 Mdot
.938 .54539 Mdot
.938 .54556 Mdot
.938 .54766 Mdot
.938 .54781 Mdot
.938 .54828 Mdot
.938 .54845 Mdot
.938 .54854 Mdot
.938 .54924 Mdot
.938 .54937 Mdot
.938 .54946 Mdot
.938 .5495 Mdot
.938 .55014 Mdot
.938 .55021 Mdot
.938 .55053 Mdot
.938 .55069 Mdot
.938 .55107 Mdot
.938 .55113 Mdot
.938 .55177 Mdot
.938 .55179 Mdot
.938 .5526 Mdot
.938 .55333 Mdot
.938 .55336 Mdot
.938 .55412 Mdot
.938 .55435 Mdot
.938 .55453 Mdot
.938 .55461 Mdot
.938 .5549 Mdot
.938 .55584 Mdot
.938 .55599 Mdot
.938 .55641 Mdot
.938 .55643 Mdot
.938 .55693 Mdot
.938 .55727 Mdot
.938 .55729 Mdot
.938 .55835 Mdot
.938 .55979 Mdot
.938 .56111 Mdot
.938 .56142 Mdot
.938 .562 Mdot
.938 .56264 Mdot
.938 .56296 Mdot
.938 .56298 Mdot
.938 .563 Mdot
.938 .56327 Mdot
.938 .56336 Mdot
.938 .56343 Mdot
.938 .56367 Mdot
.938 .56375 Mdot
.938 .56402 Mdot
.938 .56417 Mdot
.938 .56531 Mdot
.938 .56546 Mdot
.938 .56551 Mdot
.938 .56581 Mdot
.938 .56582 Mdot
.938 .56623 Mdot
.938 .56768 Mdot
.938 .56775 Mdot
.938 .56793 Mdot
.94 .0824 Mdot
.94 .08278 Mdot
.94 .08358 Mdot
.94 .08518 Mdot
.94 .0856 Mdot
.94 .08601 Mdot
.94 .08781 Mdot
.94 .08786 Mdot
.94 .08982 Mdot
.94 .0913 Mdot
.94 .09174 Mdot
.94 .09211 Mdot
.94 .09214 Mdot
.94 .09261 Mdot
.94 .09263 Mdot
.94 .09312 Mdot
.94 .09574 Mdot
.94 .09586 Mdot
.94 .09678 Mdot
.94 .09808 Mdot
.94 .0987 Mdot
.94 .0987 Mdot
.94 .09934 Mdot
.94 .09952 Mdot
.94 .10084 Mdot
.94 .10112 Mdot
.94 .10195 Mdot
.94 .10357 Mdot
.94 .10441 Mdot
.94 .10497 Mdot
.94 .1056 Mdot
.94 .10752 Mdot
.94 .11012 Mdot
.94 .11022 Mdot
.94 .11107 Mdot
.94 .11167 Mdot
.94 .11229 Mdot
.94 .11242 Mdot
.94 .11278 Mdot
.94 .11386 Mdot
.94 .11458 Mdot
.94 .11505 Mdot
.94 .11526 Mdot
.94 .11701 Mdot
.94 .11794 Mdot
.94 .11803 Mdot
.94 .11814 Mdot
.94 .11829 Mdot
.94 .11854 Mdot
.94 .11903 Mdot
.94 .1192 Mdot
.94 .12178 Mdot
.94 .12186 Mdot
.94 .12574 Mdot
.94 .12624 Mdot
.94 .1263 Mdot
.94 .12772 Mdot
.94 .12828 Mdot
.94 .12835 Mdot
.94 .12847 Mdot
.94 .12945 Mdot
.94 .13039 Mdot
.94 .13044 Mdot
.94 .13063 Mdot
.94 .13203 Mdot
.94 .13347 Mdot
.94 .13388 Mdot
.94 .13433 Mdot
.94 .13476 Mdot
.94 .13515 Mdot
.94 .13526 Mdot
.94 .13741 Mdot
.94 .13769 Mdot
.94 .13954 Mdot
.94 .14079 Mdot
.94 .14121 Mdot
.94 .14197 Mdot
.94 .14268 Mdot
.94 .14357 Mdot
.94 .14418 Mdot
.94 .14435 Mdot
.94 .14505 Mdot
.94 .14582 Mdot
.94 .14604 Mdot
.94 .14634 Mdot
.94 .1464 Mdot
.94 .14658 Mdot
.94 .14719 Mdot
.94 .14721 Mdot
.94 .14798 Mdot
.94 .14869 Mdot
.94 .14875 Mdot
.94 .14965 Mdot
.94 .14971 Mdot
.94 .1502 Mdot
.94 .15047 Mdot
.94 .15048 Mdot
.94 .15051 Mdot
.94 .15078 Mdot
.94 .15093 Mdot
.94 .15114 Mdot
.94 .15213 Mdot
.94 .15223 Mdot
.94 .15233 Mdot
.94 .1537 Mdot
.94 .15522 Mdot
.94 .15591 Mdot
.94 .15666 Mdot
.94 .1568 Mdot
.94 .157 Mdot
.94 .15701 Mdot
.94 .15792 Mdot
.94 .1587 Mdot
.94 .15914 Mdot
.94 .15952 Mdot
.94 .16022 Mdot
.94 .16022 Mdot
.94 .16025 Mdot
.94 .16027 Mdot
.94 .16116 Mdot
.94 .1612 Mdot
.94 .16132 Mdot
.94 .1617 Mdot
.94 .16183 Mdot
.94 .16212 Mdot
.94 .16422 Mdot
.94 .16437 Mdot
.94 .16454 Mdot
.94 .16485 Mdot
.94 .1661 Mdot
.94 .16704 Mdot
.94 .16713 Mdot
.94 .16726 Mdot
.94 .16728 Mdot
.94 .169 Mdot
.94 .16991 Mdot
.94 .17011 Mdot
.94 .17091 Mdot
.94 .17139 Mdot
.94 .17145 Mdot
.94 .17227 Mdot
.94 .17261 Mdot
.94 .17261 Mdot
.94 .17291 Mdot
.94 .17382 Mdot
.94 .17396 Mdot
.94 .17415 Mdot
.94 .17437 Mdot
.94 .17457 Mdot
.94 .17636 Mdot
.94 .17663 Mdot
.94 .17715 Mdot
.94 .17719 Mdot
.94 .17831 Mdot
.94 .1784 Mdot
.94 .17872 Mdot
.94 .17926 Mdot
.94 .17975 Mdot
.94 .18064 Mdot
.94 .18134 Mdot
.94 .18177 Mdot
.94 .18199 Mdot
.94 .18211 Mdot
.94 .18334 Mdot
.94 .18439 Mdot
.94 .18557 Mdot
.94 .18563 Mdot
.94 .18668 Mdot
.94 .18749 Mdot
.94 .18777 Mdot
.94 .18858 Mdot
.94 .18919 Mdot
.94 .19024 Mdot
.94 .1923 Mdot
.94 .19232 Mdot
.94 .1928 Mdot
.94 .19328 Mdot
.94 .19397 Mdot
.94 .19407 Mdot
.94 .19427 Mdot
.94 .19453 Mdot
.94 .19586 Mdot
.94 .19614 Mdot
.94 .19699 Mdot
.94 .19804 Mdot
.94 .19815 Mdot
.94 .19841 Mdot
.94 .19907 Mdot
.94 .20031 Mdot
.94 .20111 Mdot
.94 .20216 Mdot
.94 .20246 Mdot
.94 .20335 Mdot
.94 .2036 Mdot
.94 .20374 Mdot
.94 .20499 Mdot
.94 .20703 Mdot
.94 .20877 Mdot
.94 .20895 Mdot
.94 .20908 Mdot
.94 .20915 Mdot
.94 .20941 Mdot
.94 .20943 Mdot
.94 .2099 Mdot
.94 .21008 Mdot
.94 .21077 Mdot
.94 .21082 Mdot
.94 .21115 Mdot
.94 .21335 Mdot
.94 .21398 Mdot
.94 .21494 Mdot
.94 .21599 Mdot
.94 .21616 Mdot
.94 .21737 Mdot
.94 .21753 Mdot
.94 .21866 Mdot
.94 .21872 Mdot
.94 .21878 Mdot
.94 .21972 Mdot
.94 .22064 Mdot
.94 .22153 Mdot
.94 .22175 Mdot
.94 .22182 Mdot
.94 .22202 Mdot
.94 .22344 Mdot
.94 .22362 Mdot
.94 .22437 Mdot
.94 .2245 Mdot
.94 .22456 Mdot
.94 .22517 Mdot
.94 .22586 Mdot
.94 .22608 Mdot
.94 .22683 Mdot
.94 .22717 Mdot
.94 .22725 Mdot
.94 .22763 Mdot
.94 .22822 Mdot
.94 .22835 Mdot
.94 .22857 Mdot
.94 .22881 Mdot
.94 .2293 Mdot
.94 .22977 Mdot
.94 .22978 Mdot
.94 .23042 Mdot
.94 .23042 Mdot
.94 .23098 Mdot
.94 .23101 Mdot
.94 .23159 Mdot
.94 .23175 Mdot
.94 .23219 Mdot
.94 .23227 Mdot
.94 .23263 Mdot
.94 .23308 Mdot
.94 .23321 Mdot
.94 .23349 Mdot
.94 .23359 Mdot
.94 .23527 Mdot
.94 .23654 Mdot
.94 .23699 Mdot
.94 .23797 Mdot
.94 .23837 Mdot
.94 .23874 Mdot
.94 .23959 Mdot
.94 .2404 Mdot
.94 .24085 Mdot
.94 .24111 Mdot
.94 .24113 Mdot
.94 .24135 Mdot
.94 .24203 Mdot
.94 .24208 Mdot
.94 .24211 Mdot
.94 .24236 Mdot
.94 .24348 Mdot
.94 .24362 Mdot
.94 .24391 Mdot
.94 .24419 Mdot
.94 .2442 Mdot
.94 .24538 Mdot
.94 .2459 Mdot
.94 .24717 Mdot
.94 .24756 Mdot
.94 .24767 Mdot
.94 .24832 Mdot
.94 .24883 Mdot
.94 .24924 Mdot
.94 .24938 Mdot
.94 .24956 Mdot
.94 .24983 Mdot
.94 .2512 Mdot
.94 .25173 Mdot
.94 .25253 Mdot
.94 .25268 Mdot
.94 .25395 Mdot
.94 .25395 Mdot
.94 .2553 Mdot
.94 .25678 Mdot
.94 .25688 Mdot
.94 .25695 Mdot
.94 .25722 Mdot
.94 .25753 Mdot
.94 .25784 Mdot
.94 .25811 Mdot
.94 .25835 Mdot
.94 .25844 Mdot
.94 .25924 Mdot
.94 .25959 Mdot
.94 .25974 Mdot
.94 .2612 Mdot
.94 .26162 Mdot
.94 .26217 Mdot
.94 .26228 Mdot
.94 .26243 Mdot
.94 .26261 Mdot
.94 .26276 Mdot
.94 .2636 Mdot
.94 .26368 Mdot
.94 .26376 Mdot
.94 .2638 Mdot
.94 .2642 Mdot
.94 .26421 Mdot
.94 .26454 Mdot
.94 .26524 Mdot
.94 .26564 Mdot
.94 .2666 Mdot
.94 .2667 Mdot
.94 .26674 Mdot
.94 .26768 Mdot
.94 .26795 Mdot
.94 .26828 Mdot
.94 .26839 Mdot
.94 .26851 Mdot
.94 .26872 Mdot
.94 .26942 Mdot
.94 .26993 Mdot
.94 .26995 Mdot
.94 .27001 Mdot
.94 .27052 Mdot
.94 .27081 Mdot
.94 .27119 Mdot
.94 .27187 Mdot
.94 .27215 Mdot
.94 .27232 Mdot
.94 .27306 Mdot
.94 .27325 Mdot
.94 .27344 Mdot
.94 .27353 Mdot
.94 .27602 Mdot
.94 .27719 Mdot
.94 .27814 Mdot
.94 .27828 Mdot
.94 .27828 Mdot
.94 .27886 Mdot
.94 .28017 Mdot
.94 .28158 Mdot
.94 .28183 Mdot
.94 .28221 Mdot
.94 .28224 Mdot
.94 .28279 Mdot
.94 .2833 Mdot
.94 .28395 Mdot
.94 .2842 Mdot
.94 .28433 Mdot
.94 .28536 Mdot
.94 .2854 Mdot
.94 .28613 Mdot
.94 .28618 Mdot
.94 .28623 Mdot
.94 .28694 Mdot
.94 .28736 Mdot
.94 .28801 Mdot
.94 .28826 Mdot
.94 .28827 Mdot
.94 .28832 Mdot
.94 .28836 Mdot
.94 .29003 Mdot
.94 .2901 Mdot
.94 .29012 Mdot
.94 .29033 Mdot
.94 .29104 Mdot
.94 .29122 Mdot
.94 .29128 Mdot
.94 .29137 Mdot
.94 .29165 Mdot
.94 .29185 Mdot
.94 .29207 Mdot
.94 .29285 Mdot
.94 .29373 Mdot
.94 .29381 Mdot
.94 .29445 Mdot
.94 .29468 Mdot
.94 .29493 Mdot
.94 .29578 Mdot
.94 .29606 Mdot
.94 .29637 Mdot
.94 .29639 Mdot
.94 .29697 Mdot
.94 .29821 Mdot
.94 .29901 Mdot
.94 .29932 Mdot
.94 .30008 Mdot
.94 .30047 Mdot
.94 .30088 Mdot
.94 .30109 Mdot
.94 .30126 Mdot
.94 .3015 Mdot
.94 .30153 Mdot
.94 .30227 Mdot
.94 .30299 Mdot
.94 .30315 Mdot
.94 .30384 Mdot
.94 .30476 Mdot
.94 .30476 Mdot
.94 .30648 Mdot
.94 .30673 Mdot
.94 .30686 Mdot
.94 .30835 Mdot
.94 .30859 Mdot
.94 .30904 Mdot
.94 .30927 Mdot
.94 .30937 Mdot
.94 .31092 Mdot
.94 .31155 Mdot
.94 .31156 Mdot
.94 .31212 Mdot
.94 .31277 Mdot
.94 .31277 Mdot
.94 .31291 Mdot
.94 .31305 Mdot
.94 .31379 Mdot
.94 .31383 Mdot
.94 .31409 Mdot
.94 .31446 Mdot
.94 .31481 Mdot
.94 .31486 Mdot
.94 .31524 Mdot
.94 .31531 Mdot
.94 .31601 Mdot
.94 .31658 Mdot
.94 .31847 Mdot
.94 .31861 Mdot
.94 .31912 Mdot
.94 .31926 Mdot
.94 .31981 Mdot
.94 .3201 Mdot
.94 .32013 Mdot
.94 .32017 Mdot
.94 .32024 Mdot
.94 .32043 Mdot
.94 .32116 Mdot
.94 .32228 Mdot
.94 .32244 Mdot
.94 .32284 Mdot
.94 .32305 Mdot
.94 .3236 Mdot
.94 .32366 Mdot
.94 .32406 Mdot
.94 .32458 Mdot
.94 .32483 Mdot
.94 .32497 Mdot
.94 .32618 Mdot
.94 .32666 Mdot
.94 .32796 Mdot
.94 .32813 Mdot
.94 .32878 Mdot
.94 .32905 Mdot
.94 .3292 Mdot
.94 .32928 Mdot
.94 .32941 Mdot
.94 .32947 Mdot
.94 .32981 Mdot
.94 .33019 Mdot
.94 .33062 Mdot
.94 .33173 Mdot
.94 .33205 Mdot
.94 .33235 Mdot
.94 .33249 Mdot
.94 .33335 Mdot
.94 .3337 Mdot
.94 .33478 Mdot
.94 .33483 Mdot
.94 .33563 Mdot
.94 .33592 Mdot
.94 .33604 Mdot
.94 .33684 Mdot
.94 .33742 Mdot
.94 .33801 Mdot
.94 .3382 Mdot
.94 .33823 Mdot
.94 .33952 Mdot
.94 .33975 Mdot
.94 .33983 Mdot
.94 .34006 Mdot
.94 .34139 Mdot
.94 .34159 Mdot
.94 .34174 Mdot
.94 .34274 Mdot
.94 .3439 Mdot
.94 .34431 Mdot
.94 .3447 Mdot
.94 .34825 Mdot
.94 .34857 Mdot
.94 .3486 Mdot
.94 .34913 Mdot
.94 .34952 Mdot
.94 .35024 Mdot
.94 .35041 Mdot
.94 .35061 Mdot
.94 .35158 Mdot
.94 .35172 Mdot
.94 .3519 Mdot
.94 .35206 Mdot
.94 .35206 Mdot
.94 .35223 Mdot
.94 .35228 Mdot
.94 .35277 Mdot
.94 .35363 Mdot
.94 .35492 Mdot
.94 .35521 Mdot
.94 .35528 Mdot
.94 .3558 Mdot
.94 .35675 Mdot
.94 .35731 Mdot
.94 .35739 Mdot
.94 .35856 Mdot
.94 .35936 Mdot
.94 .35938 Mdot
.94 .35948 Mdot
.94 .35957 Mdot
.94 .36005 Mdot
.94 .36131 Mdot
.94 .36145 Mdot
.94 .36146 Mdot
.94 .36274 Mdot
.94 .36363 Mdot
.94 .3637 Mdot
.94 .36375 Mdot
.94 .36513 Mdot
.94 .3654 Mdot
.94 .36711 Mdot
.94 .36715 Mdot
.94 .36744 Mdot
.94 .36768 Mdot
.94 .36801 Mdot
.94 .36879 Mdot
.94 .3691 Mdot
.94 .36914 Mdot
.94 .36922 Mdot
.94 .36934 Mdot
.94 .36981 Mdot
.94 .37008 Mdot
.94 .3713 Mdot
.94 .37161 Mdot
.94 .37243 Mdot
.94 .37248 Mdot
.94 .37267 Mdot
.94 .37293 Mdot
.94 .37414 Mdot
.94 .37524 Mdot
.94 .37528 Mdot
.94 .37611 Mdot
.94 .37628 Mdot
.94 .37681 Mdot
.94 .37719 Mdot
.94 .37757 Mdot
.94 .37861 Mdot
.94 .37954 Mdot
.94 .37987 Mdot
.94 .37992 Mdot
.94 .38002 Mdot
.94 .38013 Mdot
.94 .38025 Mdot
.94 .38074 Mdot
.94 .38078 Mdot
.94 .38144 Mdot
.94 .38166 Mdot
.94 .38201 Mdot
.94 .38217 Mdot
.94 .38239 Mdot
.94 .38283 Mdot
.94 .38329 Mdot
.94 .3834 Mdot
.94 .38401 Mdot
.94 .38524 Mdot
.94 .38549 Mdot
.94 .38613 Mdot
.94 .38631 Mdot
.94 .38636 Mdot
.94 .38815 Mdot
.94 .38933 Mdot
.94 .39067 Mdot
.94 .39114 Mdot
.94 .39115 Mdot
.94 .39184 Mdot
.94 .39209 Mdot
.94 .39287 Mdot
.94 .39288 Mdot
.94 .39312 Mdot
.94 .39342 Mdot
.94 .39383 Mdot
.94 .3942 Mdot
.94 .39463 Mdot
.94 .3957 Mdot
.94 .39601 Mdot
.94 .39602 Mdot
.94 .39786 Mdot
.94 .39813 Mdot
.94 .39824 Mdot
.94 .39836 Mdot
.94 .39927 Mdot
.94 .40013 Mdot
.94 .40088 Mdot
.94 .40186 Mdot
.94 .4026 Mdot
.94 .40283 Mdot
.94 .40302 Mdot
.94 .40352 Mdot
.94 .40353 Mdot
.94 .40395 Mdot
.94 .40408 Mdot
.94 .40445 Mdot
.94 .4047 Mdot
.94 .40699 Mdot
.94 .40702 Mdot
.94 .40712 Mdot
.94 .40746 Mdot
.94 .40759 Mdot
.94 .40887 Mdot
.94 .40911 Mdot
.94 .40922 Mdot
.94 .40961 Mdot
.94 .41037 Mdot
.94 .41042 Mdot
.94 .41112 Mdot
.94 .41167 Mdot
.94 .41187 Mdot
.94 .41207 Mdot
.94 .41244 Mdot
.94 .41289 Mdot
.94 .41291 Mdot
.94 .41349 Mdot
.94 .41414 Mdot
.94 .41428 Mdot
.94 .41438 Mdot
.94 .41484 Mdot
.94 .415 Mdot
.94 .41611 Mdot
.94 .41615 Mdot
.94 .41618 Mdot
.94 .41634 Mdot
.94 .41676 Mdot
.94 .41706 Mdot
.94 .41721 Mdot
.94 .41814 Mdot
.94 .41902 Mdot
.94 .41905 Mdot
.94 .41956 Mdot
.94 .42024 Mdot
.94 .42024 Mdot
.94 .42129 Mdot
.94 .42134 Mdot
.94 .42178 Mdot
.94 .42244 Mdot
.94 .42275 Mdot
.94 .42357 Mdot
.94 .42372 Mdot
.94 .4244 Mdot
.94 .42515 Mdot
.94 .42524 Mdot
.94 .42524 Mdot
.94 .42549 Mdot
.94 .42558 Mdot
.94 .42601 Mdot
.94 .42621 Mdot
.94 .4268 Mdot
.94 .42727 Mdot
.94 .42936 Mdot
.94 .42958 Mdot
.94 .43073 Mdot
.94 .43092 Mdot
.94 .43174 Mdot
.94 .43179 Mdot
.94 .4326 Mdot
.94 .43261 Mdot
.94 .43302 Mdot
.94 .43334 Mdot
.94 .43398 Mdot
.94 .4344 Mdot
.94 .43443 Mdot
.94 .43519 Mdot
.94 .43565 Mdot
.94 .43572 Mdot
.94 .43589 Mdot
.94 .43664 Mdot
.94 .43687 Mdot
.94 .43708 Mdot
.94 .43726 Mdot
.94 .43736 Mdot
.94 .43748 Mdot
.94 .43797 Mdot
.94 .439 Mdot
.94 .43972 Mdot
.94 .43985 Mdot
.94 .44034 Mdot
.94 .44038 Mdot
.94 .44078 Mdot
.94 .44168 Mdot
.94 .44206 Mdot
.94 .44216 Mdot
.94 .44222 Mdot
.94 .44239 Mdot
.94 .44269 Mdot
.94 .4431 Mdot
.94 .44411 Mdot
.94 .44442 Mdot
.94 .44478 Mdot
.94 .44505 Mdot
.94 .44559 Mdot
.94 .44599 Mdot
.94 .44607 Mdot
.94 .44614 Mdot
.94 .44614 Mdot
.94 .44812 Mdot
.94 .44836 Mdot
.94 .44935 Mdot
.94 .4504 Mdot
.94 .45089 Mdot
.94 .45126 Mdot
.94 .45134 Mdot
.94 .45172 Mdot
.94 .45246 Mdot
.94 .45268 Mdot
.94 .45289 Mdot
.94 .45346 Mdot
.94 .45388 Mdot
.94 .45486 Mdot
.94 .45563 Mdot
.94 .45576 Mdot
.94 .45588 Mdot
.94 .45622 Mdot
.94 .45626 Mdot
.94 .45673 Mdot
.94 .45715 Mdot
.94 .45737 Mdot
.94 .45752 Mdot
.94 .4576 Mdot
.94 .45819 Mdot
.94 .45931 Mdot
.94 .45966 Mdot
.94 .46028 Mdot
.94 .46031 Mdot
.94 .46072 Mdot
.94 .46126 Mdot
.94 .46134 Mdot
.94 .46181 Mdot
.94 .46209 Mdot
.94 .46448 Mdot
.94 .46449 Mdot
.94 .46456 Mdot
.94 .46506 Mdot
.94 .46701 Mdot
.94 .46765 Mdot
.94 .46775 Mdot
.94 .46789 Mdot
.94 .46957 Mdot
.94 .4698 Mdot
.94 .46998 Mdot
.94 .47012 Mdot
.94 .47062 Mdot
.94 .47121 Mdot
.94 .47179 Mdot
.94 .47197 Mdot
.94 .47198 Mdot
.94 .47225 Mdot
.94 .47229 Mdot
.94 .47274 Mdot
.94 .47291 Mdot
.94 .47442 Mdot
.94 .47461 Mdot
.94 .47509 Mdot
.94 .47536 Mdot
.94 .47552 Mdot
.94 .47569 Mdot
.94 .47587 Mdot
.94 .47592 Mdot
.94 .47742 Mdot
.94 .4781 Mdot
.94 .47889 Mdot
.94 .47962 Mdot
.94 .47976 Mdot
.94 .47993 Mdot
.94 .48015 Mdot
.94 .48042 Mdot
.94 .48076 Mdot
.94 .48082 Mdot
.94 .48103 Mdot
.94 .48261 Mdot
.94 .48261 Mdot
.94 .48277 Mdot
.94 .48292 Mdot
.94 .483 Mdot
.94 .48359 Mdot
.94 .48372 Mdot
.94 .48374 Mdot
.94 .48377 Mdot
.94 .48425 Mdot
.94 .48439 Mdot
.94 .48571 Mdot
.94 .48645 Mdot
.94 .48669 Mdot
.94 .48825 Mdot
.94 .48831 Mdot
.94 .48845 Mdot
.94 .48853 Mdot
.94 .48923 Mdot
.94 .48932 Mdot
.94 .48963 Mdot
.94 .48964 Mdot
.94 .48994 Mdot
.94 .49028 Mdot
.94 .49029 Mdot
.94 .49053 Mdot
.94 .4908 Mdot
.94 .49142 Mdot
.94 .49163 Mdot
.94 .49185 Mdot
.94 .49225 Mdot
.94 .49237 Mdot
.94 .49273 Mdot
.94 .49306 Mdot
.94 .49356 Mdot
.94 .49441 Mdot
.94 .49451 Mdot
.94 .49455 Mdot
.94 .49467 Mdot
.94 .49514 Mdot
.94 .49563 Mdot
.94 .49613 Mdot
.94 .49617 Mdot
.94 .4962 Mdot
.94 .4968 Mdot
.94 .49688 Mdot
.94 .49817 Mdot
.94 .49869 Mdot
.94 .49902 Mdot
.94 .50039 Mdot
.94 .50076 Mdot
.94 .50112 Mdot
.94 .50129 Mdot
.94 .50347 Mdot
.94 .50421 Mdot
.94 .50497 Mdot
.94 .50596 Mdot
.94 .50717 Mdot
.94 .50817 Mdot
.94 .50903 Mdot
.94 .50933 Mdot
.94 .5097 Mdot
.94 .50995 Mdot
.94 .51021 Mdot
.94 .51022 Mdot
.94 .51131 Mdot
.94 .5122 Mdot
.94 .51263 Mdot
.94 .51278 Mdot
.94 .51321 Mdot
.94 .51376 Mdot
.94 .51564 Mdot
.94 .5157 Mdot
.94 .51605 Mdot
.94 .51642 Mdot
.94 .51689 Mdot
.94 .51715 Mdot
.94 .51761 Mdot
.94 .51766 Mdot
.94 .51825 Mdot
.94 .51869 Mdot
.94 .51965 Mdot
.94 .51976 Mdot
.94 .51998 Mdot
.94 .52053 Mdot
.94 .52087 Mdot
.94 .52134 Mdot
.94 .5216 Mdot
.94 .52202 Mdot
.94 .52213 Mdot
.94 .52353 Mdot
.94 .5236 Mdot
.94 .52415 Mdot
.94 .52482 Mdot
.94 .52498 Mdot
.94 .52508 Mdot
.94 .52515 Mdot
.94 .52643 Mdot
.94 .5265 Mdot
.94 .5267 Mdot
.94 .52726 Mdot
.94 .52728 Mdot
.94 .52786 Mdot
.94 .5285 Mdot
.94 .52899 Mdot
.94 .52899 Mdot
.94 .5291 Mdot
.94 .52917 Mdot
.94 .52994 Mdot
.94 .53075 Mdot
.94 .53148 Mdot
.94 .53211 Mdot
.94 .53222 Mdot
.94 .5323 Mdot
.94 .53245 Mdot
.94 .53246 Mdot
.94 .53247 Mdot
.94 .53261 Mdot
.94 .53287 Mdot
.94 .5329 Mdot
.94 .53341 Mdot
.94 .5342 Mdot
.94 .53454 Mdot
.94 .53463 Mdot
.94 .53466 Mdot
.94 .53482 Mdot
.94 .53494 Mdot
.94 .53535 Mdot
.94 .53572 Mdot
.94 .53614 Mdot
.94 .53739 Mdot
.94 .53762 Mdot
.94 .53828 Mdot
.94 .53927 Mdot
.94 .53942 Mdot
.94 .54056 Mdot
.94 .54062 Mdot
.94 .54082 Mdot
.94 .54105 Mdot
.94 .54129 Mdot
.94 .54151 Mdot
.94 .54227 Mdot
.94 .54302 Mdot
.94 .54312 Mdot
.94 .54315 Mdot
.94 .54365 Mdot
.94 .54417 Mdot
.94 .54423 Mdot
.94 .54427 Mdot
.94 .54457 Mdot
.94 .54532 Mdot
.94 .54536 Mdot
.94 .54562 Mdot
.94 .54768 Mdot
.94 .54773 Mdot
.94 .5491 Mdot
.94 .54919 Mdot
.94 .54945 Mdot
.94 .54959 Mdot
.94 .54967 Mdot
.94 .54972 Mdot
.94 .54977 Mdot
.94 .55026 Mdot
.94 .5512 Mdot
.94 .55131 Mdot
.94 .55156 Mdot
.94 .55194 Mdot
.94 .55252 Mdot
.94 .55271 Mdot
.94 .55278 Mdot
.94 .55311 Mdot
.94 .55342 Mdot
.94 .55388 Mdot
.94 .55393 Mdot
.94 .55531 Mdot
.94 .55634 Mdot
.94 .55667 Mdot
.94 .55697 Mdot
.94 .55741 Mdot
.94 .55827 Mdot
.94 .55872 Mdot
.94 .55887 Mdot
.94 .55957 Mdot
.94 .55966 Mdot
.94 .56 Mdot
.94 .56001 Mdot
.94 .56033 Mdot
.94 .56103 Mdot
.94 .56152 Mdot
.94 .56158 Mdot
.94 .56297 Mdot
.94 .56323 Mdot
.94 .56324 Mdot
.94 .56349 Mdot
.94 .56351 Mdot
.94 .56371 Mdot
.94 .56394 Mdot
.94 .56473 Mdot
.94 .56577 Mdot
.94 .5658 Mdot
.94 .56675 Mdot
.94 .56697 Mdot
.94 .5672 Mdot
.94 .56805 Mdot
.94 .56847 Mdot
.94 .56867 Mdot
.942 .08018 Mdot
.942 .0804 Mdot
.942 .0807 Mdot
.942 .0816 Mdot
.942 .08257 Mdot
.942 .08265 Mdot
.942 .08331 Mdot
.942 .08378 Mdot
.942 .08402 Mdot
.942 .08421 Mdot
.942 .08449 Mdot
.942 .08499 Mdot
.942 .08642 Mdot
.942 .08667 Mdot
.942 .08668 Mdot
.942 .08704 Mdot
.942 .08731 Mdot
.942 .08732 Mdot
.942 .08799 Mdot
.942 .08853 Mdot
.942 .08854 Mdot
.942 .08861 Mdot
.942 .08887 Mdot
.942 .08975 Mdot
.942 .09126 Mdot
.942 .0913 Mdot
.942 .09177 Mdot
.942 .09299 Mdot
.942 .09341 Mdot
.942 .09434 Mdot
.942 .09517 Mdot
.942 .09532 Mdot
.942 .09718 Mdot
.942 .09744 Mdot
.942 .09792 Mdot
.942 .09859 Mdot
.942 .09878 Mdot
.942 .09895 Mdot
.942 .09936 Mdot
.942 .10524 Mdot
.942 .10606 Mdot
.942 .10713 Mdot
.942 .10757 Mdot
.942 .10793 Mdot
.942 .10845 Mdot
.942 .10872 Mdot
.942 .11068 Mdot
.942 .11091 Mdot
.942 .11114 Mdot
.942 .11258 Mdot
.942 .11288 Mdot
.942 .11567 Mdot
.942 .11572 Mdot
.942 .11619 Mdot
.942 .11823 Mdot
.942 .11851 Mdot
.942 .11852 Mdot
.942 .12301 Mdot
.942 .12301 Mdot
.942 .12388 Mdot
.942 .12434 Mdot
.942 .12443 Mdot
.942 .12536 Mdot
.942 .12543 Mdot
.942 .12641 Mdot
.942 .12748 Mdot
.942 .12844 Mdot
.942 .12925 Mdot
.942 .13168 Mdot
.942 .13178 Mdot
.942 .13323 Mdot
.942 .13474 Mdot
.942 .13735 Mdot
.942 .13795 Mdot
.942 .13805 Mdot
.942 .13846 Mdot
.942 .13903 Mdot
.942 .14004 Mdot
.942 .14012 Mdot
.942 .14072 Mdot
.942 .14213 Mdot
.942 .14243 Mdot
.942 .14256 Mdot
.942 .14261 Mdot
.942 .1427 Mdot
.942 .14306 Mdot
.942 .14382 Mdot
.942 .14395 Mdot
.942 .14484 Mdot
.942 .14509 Mdot
.942 .14518 Mdot
.942 .14529 Mdot
.942 .14564 Mdot
.942 .14573 Mdot
.942 .14618 Mdot
.942 .14636 Mdot
.942 .14712 Mdot
.942 .14981 Mdot
.942 .15027 Mdot
.942 .1503 Mdot
.942 .15097 Mdot
.942 .15148 Mdot
.942 .1515 Mdot
.942 .15202 Mdot
.942 .15277 Mdot
.942 .15356 Mdot
.942 .15378 Mdot
.942 .1538 Mdot
.942 .15393 Mdot
.942 .15442 Mdot
.942 .15539 Mdot
.942 .15562 Mdot
.942 .15608 Mdot
.942 .15715 Mdot
.942 .15735 Mdot
.942 .15763 Mdot
.942 .15764 Mdot
.942 .15893 Mdot
.942 .159 Mdot
.942 .15989 Mdot
.942 .16134 Mdot
.942 .16183 Mdot
.942 .16219 Mdot
.942 .16298 Mdot
.942 .16406 Mdot
.942 .16437 Mdot
.942 .16438 Mdot
.942 .16473 Mdot
.942 .16629 Mdot
.942 .16658 Mdot
.942 .16699 Mdot
.942 .16971 Mdot
.942 .17007 Mdot
.942 .17042 Mdot
.942 .17049 Mdot
.942 .17056 Mdot
.942 .17093 Mdot
.942 .17147 Mdot
.942 .17151 Mdot
.942 .17181 Mdot
.942 .17241 Mdot
.942 .1727 Mdot
.942 .17274 Mdot
.942 .17309 Mdot
.942 .17341 Mdot
.942 .17355 Mdot
.942 .1737 Mdot
.942 .17419 Mdot
.942 .17424 Mdot
.942 .17518 Mdot
.942 .17717 Mdot
.942 .18077 Mdot
.942 .18084 Mdot
.942 .18218 Mdot
.942 .18295 Mdot
.942 .18298 Mdot
.942 .18302 Mdot
.942 .18398 Mdot
.942 .18527 Mdot
.942 .1855 Mdot
.942 .18594 Mdot
.942 .18648 Mdot
.942 .18681 Mdot
.942 .18883 Mdot
.942 .18966 Mdot
.942 .19033 Mdot
.942 .1905 Mdot
.942 .19131 Mdot
.942 .19148 Mdot
.942 .19182 Mdot
.942 .19196 Mdot
.942 .19259 Mdot
.942 .19433 Mdot
.942 .19526 Mdot
.942 .19536 Mdot
.942 .19552 Mdot
.942 .19595 Mdot
.942 .19613 Mdot
.942 .19627 Mdot
.942 .19638 Mdot
.942 .19651 Mdot
.942 .19772 Mdot
.942 .1988 Mdot
.942 .19909 Mdot
.942 .19929 Mdot
.942 .19966 Mdot
.942 .20002 Mdot
.942 .20026 Mdot
.942 .20112 Mdot
.942 .20206 Mdot
.942 .20303 Mdot
.942 .20319 Mdot
.942 .20491 Mdot
.942 .205 Mdot
.942 .20543 Mdot
.942 .2059 Mdot
.942 .20653 Mdot
.942 .20732 Mdot
.942 .20766 Mdot
.942 .20804 Mdot
.942 .20962 Mdot
.942 .20973 Mdot
.942 .2101 Mdot
.942 .21026 Mdot
.942 .21028 Mdot
.942 .21148 Mdot
.942 .21163 Mdot
.942 .21233 Mdot
.942 .21305 Mdot
.942 .21424 Mdot
.942 .21507 Mdot
.942 .21509 Mdot
.942 .21537 Mdot
.942 .21542 Mdot
.942 .21546 Mdot
.942 .21648 Mdot
.942 .21679 Mdot
.942 .2169 Mdot
.942 .21741 Mdot
.942 .21862 Mdot
.942 .21874 Mdot
.942 .21875 Mdot
.942 .21881 Mdot
.942 .21911 Mdot
.942 .21951 Mdot
.942 .21973 Mdot
.942 .21984 Mdot
.942 .22013 Mdot
.942 .22038 Mdot
.942 .22125 Mdot
.942 .2214 Mdot
.942 .22142 Mdot
.942 .22163 Mdot
.942 .22277 Mdot
.942 .22317 Mdot
.942 .22331 Mdot
.942 .22359 Mdot
.942 .22388 Mdot
.942 .22514 Mdot
.942 .22564 Mdot
.942 .22625 Mdot
.942 .22717 Mdot
.942 .22744 Mdot
.942 .22747 Mdot
.942 .22897 Mdot
.942 .22954 Mdot
.942 .2305 Mdot
.942 .23282 Mdot
.942 .23329 Mdot
.942 .23507 Mdot
.942 .23522 Mdot
.942 .23526 Mdot
.942 .23742 Mdot
.942 .23757 Mdot
.942 .23799 Mdot
.942 .23952 Mdot
.942 .23976 Mdot
.942 .24014 Mdot
.942 .24078 Mdot
.942 .24084 Mdot
.942 .2412 Mdot
.942 .24186 Mdot
.942 .2425 Mdot
.942 .24379 Mdot
.942 .24411 Mdot
.942 .24442 Mdot
.942 .24533 Mdot
.942 .24549 Mdot
.942 .24575 Mdot
.942 .24585 Mdot
.942 .24624 Mdot
.942 .24689 Mdot
.942 .24697 Mdot
.942 .24708 Mdot
.942 .2471 Mdot
.942 .24785 Mdot
.942 .24787 Mdot
.942 .2485 Mdot
.942 .24893 Mdot
.942 .25009 Mdot
.942 .25066 Mdot
.942 .25082 Mdot
.942 .25098 Mdot
.942 .2521 Mdot
.942 .25237 Mdot
.942 .25299 Mdot
.942 .25375 Mdot
.942 .25397 Mdot
.942 .25436 Mdot
.942 .25477 Mdot
.942 .25532 Mdot
.942 .25557 Mdot
.942 .25568 Mdot
.942 .25584 Mdot
.942 .25586 Mdot
.942 .25594 Mdot
.942 .25604 Mdot
.942 .25652 Mdot
.942 .25795 Mdot
.942 .25819 Mdot
.942 .25878 Mdot
.942 .25987 Mdot
.942 .25992 Mdot
.942 .26034 Mdot
.942 .26045 Mdot
.942 .26051 Mdot
.942 .26073 Mdot
.942 .26139 Mdot
.942 .26155 Mdot
.942 .26199 Mdot
.942 .26239 Mdot
.942 .26274 Mdot
.942 .26284 Mdot
.942 .26314 Mdot
.942 .26417 Mdot
.942 .26446 Mdot
.942 .26507 Mdot
.942 .26641 Mdot
.942 .26793 Mdot
.942 .26893 Mdot
.942 .26924 Mdot
.942 .26963 Mdot
.942 .26999 Mdot
.942 .2701 Mdot
.942 .27016 Mdot
.942 .27028 Mdot
.942 .27036 Mdot
.942 .2709 Mdot
.942 .27093 Mdot
.942 .2713 Mdot
.942 .27133 Mdot
.942 .27141 Mdot
.942 .27218 Mdot
.942 .27238 Mdot
.942 .27242 Mdot
.942 .27281 Mdot
.942 .27295 Mdot
.942 .27339 Mdot
.942 .27413 Mdot
.942 .2748 Mdot
.942 .27558 Mdot
.942 .2763 Mdot
.942 .27671 Mdot
.942 .27675 Mdot
.942 .27697 Mdot
.942 .27699 Mdot
.942 .27775 Mdot
.942 .27792 Mdot
.942 .27806 Mdot
.942 .27974 Mdot
.942 .28017 Mdot
.942 .28044 Mdot
.942 .28046 Mdot
.942 .28106 Mdot
.942 .28265 Mdot
.942 .28307 Mdot
.942 .28343 Mdot
.942 .2836 Mdot
.942 .28397 Mdot
.942 .28399 Mdot
.942 .28496 Mdot
.942 .28641 Mdot
.942 .28655 Mdot
.942 .28759 Mdot
.942 .28816 Mdot
.942 .28823 Mdot
.942 .28874 Mdot
.942 .29077 Mdot
.942 .29095 Mdot
.942 .29148 Mdot
.942 .29188 Mdot
.942 .29253 Mdot
.942 .29255 Mdot
.942 .29404 Mdot
.942 .29488 Mdot
.942 .29491 Mdot
.942 .29609 Mdot
.942 .29639 Mdot
.942 .29667 Mdot
.942 .29669 Mdot
.942 .29697 Mdot
.942 .29735 Mdot
.942 .29735 Mdot
.942 .29862 Mdot
.942 .2987 Mdot
.942 .3002 Mdot
.942 .30029 Mdot
.942 .30069 Mdot
.942 .30076 Mdot
.942 .30082 Mdot
.942 .30137 Mdot
.942 .30145 Mdot
.942 .3016 Mdot
.942 .30182 Mdot
.942 .30212 Mdot
.942 .30401 Mdot
.942 .30417 Mdot
.942 .30442 Mdot
.942 .30463 Mdot
.942 .30519 Mdot
.942 .30581 Mdot
.942 .30615 Mdot
.942 .30672 Mdot
.942 .30706 Mdot
.942 .30721 Mdot
.942 .30741 Mdot
.942 .30748 Mdot
.942 .30766 Mdot
.942 .30806 Mdot
.942 .3082 Mdot
.942 .30833 Mdot
.942 .3084 Mdot
.942 .30902 Mdot
.942 .30942 Mdot
.942 .31004 Mdot
.942 .31012 Mdot
.942 .31065 Mdot
.942 .31067 Mdot
.942 .31086 Mdot
.942 .31111 Mdot
.942 .3118 Mdot
.942 .31181 Mdot
.942 .31199 Mdot
.942 .31233 Mdot
.942 .31235 Mdot
.942 .31243 Mdot
.942 .3131 Mdot
.942 .31311 Mdot
.942 .31371 Mdot
.942 .31397 Mdot
.942 .31424 Mdot
.942 .31484 Mdot
.942 .31516 Mdot
.942 .31527 Mdot
.942 .31704 Mdot
.942 .3177 Mdot
.942 .31998 Mdot
.942 .31999 Mdot
.942 .32012 Mdot
.942 .32078 Mdot
.942 .32229 Mdot
.942 .32245 Mdot
.942 .32357 Mdot
.942 .3238 Mdot
.942 .32492 Mdot
.942 .32608 Mdot
.942 .32625 Mdot
.942 .32743 Mdot
.942 .32757 Mdot
.942 .32769 Mdot
.942 .32827 Mdot
.942 .32829 Mdot
.942 .33022 Mdot
.942 .33166 Mdot
.942 .33172 Mdot
.942 .3318 Mdot
.942 .33361 Mdot
.942 .3337 Mdot
.942 .3337 Mdot
.942 .3352 Mdot
.942 .33554 Mdot
.942 .33571 Mdot
.942 .33604 Mdot
.942 .33628 Mdot
.942 .33648 Mdot
.942 .3373 Mdot
.942 .33832 Mdot
.942 .33871 Mdot
.942 .33894 Mdot
.942 .33977 Mdot
.942 .33993 Mdot
.942 .34106 Mdot
.942 .34214 Mdot
.942 .34275 Mdot
.942 .3434 Mdot
.942 .34353 Mdot
.942 .34374 Mdot
.942 .34405 Mdot
.942 .34432 Mdot
.942 .34463 Mdot
.942 .34557 Mdot
.942 .3458 Mdot
.942 .34589 Mdot
.942 .34741 Mdot
.942 .34775 Mdot
.942 .34799 Mdot
.942 .34808 Mdot
.942 .34838 Mdot
.942 .34864 Mdot
.942 .34898 Mdot
.942 .34932 Mdot
.942 .34983 Mdot
.942 .35038 Mdot
.942 .35096 Mdot
.942 .35113 Mdot
.942 .35206 Mdot
.942 .35311 Mdot
.942 .35366 Mdot
.942 .35428 Mdot
.942 .35487 Mdot
.942 .35504 Mdot
.942 .35534 Mdot
.942 .35553 Mdot
.942 .35571 Mdot
.942 .35607 Mdot
.942 .35616 Mdot
.942 .35651 Mdot
.942 .35676 Mdot
.942 .35697 Mdot
.942 .35722 Mdot
.942 .35849 Mdot
.942 .3595 Mdot
.942 .36029 Mdot
.942 .36077 Mdot
.942 .36152 Mdot
.942 .36189 Mdot
.942 .36207 Mdot
.942 .36245 Mdot
.942 .36315 Mdot
.942 .36371 Mdot
.942 .36383 Mdot
.942 .36425 Mdot
.942 .36429 Mdot
.942 .36573 Mdot
.942 .3659 Mdot
.942 .3664 Mdot
.942 .36767 Mdot
.942 .36951 Mdot
.942 .3698 Mdot
.942 .37047 Mdot
.942 .37106 Mdot
.942 .37116 Mdot
.942 .37197 Mdot
.942 .3721 Mdot
.942 .37212 Mdot
.942 .37304 Mdot
.942 .37308 Mdot
.942 .37321 Mdot
.942 .37337 Mdot
.942 .37394 Mdot
.942 .37402 Mdot
.942 .37427 Mdot
.942 .37456 Mdot
.942 .37491 Mdot
.942 .37504 Mdot
.942 .37524 Mdot
.942 .37538 Mdot
.942 .37609 Mdot
.942 .37754 Mdot
.942 .37758 Mdot
.942 .37823 Mdot
.942 .37893 Mdot
.942 .3793 Mdot
.942 .37988 Mdot
.942 .3814 Mdot
.942 .38192 Mdot
.942 .38213 Mdot
.942 .38282 Mdot
.942 .38311 Mdot
.942 .38316 Mdot
.942 .38348 Mdot
.942 .38378 Mdot
.942 .38423 Mdot
.942 .38448 Mdot
.942 .38481 Mdot
.942 .38543 Mdot
.942 .38545 Mdot
.942 .38571 Mdot
.942 .3858 Mdot
.942 .38627 Mdot
.942 .38631 Mdot
.942 .38703 Mdot
.942 .3872 Mdot
.942 .38755 Mdot
.942 .3876 Mdot
.942 .38771 Mdot
.942 .38839 Mdot
.942 .38903 Mdot
.942 .38935 Mdot
.942 .39001 Mdot
.942 .39062 Mdot
.942 .39176 Mdot
.942 .39218 Mdot
.942 .39222 Mdot
.942 .3925 Mdot
.942 .39258 Mdot
.942 .39274 Mdot
.942 .39283 Mdot
.942 .39291 Mdot
.942 .39305 Mdot
.942 .3931 Mdot
.942 .39441 Mdot
.942 .39484 Mdot
.942 .39543 Mdot
.942 .39564 Mdot
.942 .39571 Mdot
.942 .39598 Mdot
.942 .39621 Mdot
.942 .39648 Mdot
.942 .39657 Mdot
.942 .39659 Mdot
.942 .39699 Mdot
.942 .39708 Mdot
.942 .39727 Mdot
.942 .39812 Mdot
.942 .39851 Mdot
.942 .39887 Mdot
.942 .39895 Mdot
.942 .39909 Mdot
.942 .39912 Mdot
.942 .39923 Mdot
.942 .39931 Mdot
.942 .39979 Mdot
.942 .40054 Mdot
.942 .40073 Mdot
.942 .40097 Mdot
.942 .40117 Mdot
.942 .40162 Mdot
.942 .40172 Mdot
.942 .40177 Mdot
.942 .40199 Mdot
.942 .40204 Mdot
.942 .40218 Mdot
.942 .40231 Mdot
.942 .40245 Mdot
.942 .40314 Mdot
.942 .40383 Mdot
.942 .40386 Mdot
.942 .40411 Mdot
.942 .40416 Mdot
.942 .40455 Mdot
.942 .40548 Mdot
.942 .40583 Mdot
.942 .406 Mdot
.942 .4067 Mdot
.942 .40675 Mdot
.942 .40678 Mdot
.942 .40697 Mdot
.942 .40744 Mdot
.942 .40746 Mdot
.942 .40771 Mdot
.942 .4079 Mdot
.942 .40824 Mdot
.942 .40841 Mdot
.942 .40854 Mdot
.942 .40878 Mdot
.942 .40894 Mdot
.942 .41005 Mdot
.942 .41085 Mdot
.942 .41116 Mdot
.942 .4121 Mdot
.942 .41324 Mdot
.942 .41332 Mdot
.942 .41342 Mdot
.942 .41368 Mdot
.942 .41383 Mdot
.942 .41401 Mdot
.942 .41431 Mdot
.942 .41446 Mdot
.942 .41497 Mdot
.942 .41498 Mdot
.942 .41505 Mdot
.942 .41548 Mdot
.942 .41554 Mdot
.942 .41585 Mdot
.942 .41801 Mdot
.942 .41837 Mdot
.942 .41915 Mdot
.942 .41944 Mdot
.942 .4204 Mdot
.942 .421 Mdot
.942 .42125 Mdot
.942 .42221 Mdot
.942 .42349 Mdot
.942 .42368 Mdot
.942 .42378 Mdot
.942 .42444 Mdot
.942 .42477 Mdot
.942 .42562 Mdot
.942 .42611 Mdot
.942 .4262 Mdot
.942 .42651 Mdot
.942 .42707 Mdot
.942 .42725 Mdot
.942 .42773 Mdot
.942 .42778 Mdot
.942 .42894 Mdot
.942 .42956 Mdot
.942 .42987 Mdot
.942 .43004 Mdot
.942 .43015 Mdot
.942 .43022 Mdot
.942 .43089 Mdot
.942 .43146 Mdot
.942 .43206 Mdot
.942 .43214 Mdot
.942 .4327 Mdot
.942 .43399 Mdot
.942 .4343 Mdot
.942 .43439 Mdot
.942 .43457 Mdot
.942 .43537 Mdot
.942 .43537 Mdot
.942 .43824 Mdot
.942 .43825 Mdot
.942 .43869 Mdot
.942 .43932 Mdot
.942 .43941 Mdot
.942 .44002 Mdot
.942 .44062 Mdot
.942 .44074 Mdot
.942 .44134 Mdot
.942 .44142 Mdot
.942 .44257 Mdot
.942 .44264 Mdot
.942 .44265 Mdot
.942 .44386 Mdot
.942 .44538 Mdot
.942 .44629 Mdot
.942 .44671 Mdot
.942 .44689 Mdot
.942 .44698 Mdot
.942 .44735 Mdot
.942 .44749 Mdot
.942 .4476 Mdot
.942 .44826 Mdot
.942 .44879 Mdot
.942 .44919 Mdot
.942 .44928 Mdot
.942 .44942 Mdot
.942 .4495 Mdot
.942 .44999 Mdot
.942 .45017 Mdot
.942 .4505 Mdot
.942 .4508 Mdot
.942 .45091 Mdot
.942 .45104 Mdot
.942 .45112 Mdot
.942 .45213 Mdot
.942 .45229 Mdot
.942 .45248 Mdot
.942 .45252 Mdot
.942 .45285 Mdot
.942 .45288 Mdot
.942 .45315 Mdot
.942 .45395 Mdot
.942 .45399 Mdot
.942 .45466 Mdot
.942 .45486 Mdot
.942 .45517 Mdot
.942 .45596 Mdot
.942 .45597 Mdot
.942 .45722 Mdot
.942 .45777 Mdot
.942 .45815 Mdot
.942 .45923 Mdot
.942 .45954 Mdot
.942 .45984 Mdot
.942 .46124 Mdot
.942 .46196 Mdot
.942 .46246 Mdot
.942 .46362 Mdot
.942 .46363 Mdot
.942 .4649 Mdot
.942 .46506 Mdot
.942 .46548 Mdot
.942 .46621 Mdot
.942 .46698 Mdot
.942 .46761 Mdot
.942 .46768 Mdot
.942 .46802 Mdot
.942 .46847 Mdot
.942 .46848 Mdot
.942 .46868 Mdot
.942 .4687 Mdot
.942 .46899 Mdot
.942 .46903 Mdot
.942 .46918 Mdot
.942 .46937 Mdot
.942 .46974 Mdot
.942 .47028 Mdot
.942 .47108 Mdot
.942 .47179 Mdot
.942 .47212 Mdot
.942 .47282 Mdot
.942 .47298 Mdot
.942 .47343 Mdot
.942 .47424 Mdot
.942 .47453 Mdot
.942 .47513 Mdot
.942 .47659 Mdot
.942 .47664 Mdot
.942 .47668 Mdot
.942 .47748 Mdot
.942 .47768 Mdot
.942 .4778 Mdot
.942 .4782 Mdot
.942 .47853 Mdot
.942 .47944 Mdot
.942 .47975 Mdot
.942 .48059 Mdot
.942 .48092 Mdot
.942 .48133 Mdot
.942 .4814 Mdot
.942 .48179 Mdot
.942 .482 Mdot
.942 .48218 Mdot
.942 .48227 Mdot
.942 .48275 Mdot
.942 .48292 Mdot
.942 .48309 Mdot
.942 .48377 Mdot
.942 .48411 Mdot
.942 .48446 Mdot
.942 .48469 Mdot
.942 .48503 Mdot
.942 .48523 Mdot
.942 .48535 Mdot
.942 .48639 Mdot
.942 .48647 Mdot
.942 .48764 Mdot
.942 .48866 Mdot
.942 .48891 Mdot
.942 .49065 Mdot
.942 .49177 Mdot
.942 .4924 Mdot
.942 .49272 Mdot
.942 .49366 Mdot
.942 .49381 Mdot
.942 .49424 Mdot
.942 .49485 Mdot
.942 .49497 Mdot
.942 .49564 Mdot
.942 .4958 Mdot
.942 .49586 Mdot
.942 .49598 Mdot
.942 .49619 Mdot
.942 .49635 Mdot
.942 .49645 Mdot
.942 .49709 Mdot
.942 .49736 Mdot
.942 .49742 Mdot
.942 .49758 Mdot
.942 .49813 Mdot
.942 .49815 Mdot
.942 .49818 Mdot
.942 .49832 Mdot
.942 .49833 Mdot
.942 .49877 Mdot
.942 .4994 Mdot
.942 .49979 Mdot
.942 .50016 Mdot
.942 .50024 Mdot
.942 .50097 Mdot
.942 .50122 Mdot
.942 .50207 Mdot
.942 .50226 Mdot
.942 .50245 Mdot
.942 .50287 Mdot
.942 .50345 Mdot
.942 .50464 Mdot
.942 .50472 Mdot
.942 .50524 Mdot
.942 .50574 Mdot
.942 .50619 Mdot
.942 .50632 Mdot
.942 .50671 Mdot
.942 .50697 Mdot
.942 .50754 Mdot
.942 .50818 Mdot
.942 .50831 Mdot
.942 .50838 Mdot
.942 .5088 Mdot
.942 .50884 Mdot
.942 .50934 Mdot
.942 .51026 Mdot
.942 .5106 Mdot
.942 .51085 Mdot
.942 .51137 Mdot
.942 .51351 Mdot
.942 .51379 Mdot
.942 .51403 Mdot
.942 .51483 Mdot
.942 .51534 Mdot
.942 .51537 Mdot
.942 .51538 Mdot
.942 .51579 Mdot
.942 .5165 Mdot
.942 .51654 Mdot
.942 .51845 Mdot
.942 .5195 Mdot
.942 .52 Mdot
.942 .52029 Mdot
.942 .52037 Mdot
.942 .52082 Mdot
.942 .52098 Mdot
.942 .5213 Mdot
.942 .52145 Mdot
.942 .52176 Mdot
.942 .52199 Mdot
.942 .52203 Mdot
.942 .52241 Mdot
.942 .52385 Mdot
.942 .52524 Mdot
.942 .52524 Mdot
.942 .52541 Mdot
.942 .52659 Mdot
.942 .52685 Mdot
.942 .52881 Mdot
.942 .52882 Mdot
.942 .52897 Mdot
.942 .52907 Mdot
.942 .52989 Mdot
.942 .53001 Mdot
.942 .53098 Mdot
.942 .5318 Mdot
.942 .5348 Mdot
.942 .53514 Mdot
.942 .53543 Mdot
.942 .53548 Mdot
.942 .53615 Mdot
.942 .53655 Mdot
.942 .53679 Mdot
.942 .53689 Mdot
.942 .53705 Mdot
.942 .53811 Mdot
.942 .53816 Mdot
.942 .53927 Mdot
.942 .53959 Mdot
.942 .54097 Mdot
.942 .54177 Mdot
.942 .54254 Mdot
.942 .5426 Mdot
.942 .54388 Mdot
.942 .54432 Mdot
.942 .54482 Mdot
.942 .54539 Mdot
.942 .54591 Mdot
.942 .54595 Mdot
.942 .54644 Mdot
.942 .54649 Mdot
.942 .54674 Mdot
.942 .54719 Mdot
.942 .5472 Mdot
.942 .54958 Mdot
.942 .54959 Mdot
.942 .54973 Mdot
.942 .55081 Mdot
.942 .55107 Mdot
.942 .55109 Mdot
.942 .55257 Mdot
.942 .55273 Mdot
.942 .5535 Mdot
.942 .55362 Mdot
.942 .55374 Mdot
.942 .55478 Mdot
.942 .55493 Mdot
.942 .5552 Mdot
.942 .55539 Mdot
.942 .55562 Mdot
.942 .55619 Mdot
.942 .55663 Mdot
.942 .55975 Mdot
.942 .55997 Mdot
.942 .56006 Mdot
.942 .56016 Mdot
.942 .56052 Mdot
.942 .56077 Mdot
.942 .56091 Mdot
.942 .56189 Mdot
.942 .56197 Mdot
.942 .56241 Mdot
.942 .56291 Mdot
.942 .56313 Mdot
.942 .56378 Mdot
.942 .56403 Mdot
.942 .56405 Mdot
.942 .56485 Mdot
.942 .56532 Mdot
.942 .56546 Mdot
.942 .56549 Mdot
.942 .5655 Mdot
.942 .56578 Mdot
.942 .56614 Mdot
.942 .56615 Mdot
.942 .56629 Mdot
.942 .56648 Mdot
.942 .56649 Mdot
.942 .56662 Mdot
.942 .56737 Mdot
.942 .56764 Mdot
.942 .56779 Mdot
.942 .56789 Mdot
.942 .56802 Mdot
.942 .56827 Mdot
.942 .56862 Mdot
.942 .56866 Mdot
.942 .56918 Mdot
.942 .56965 Mdot
.942 .56981 Mdot
.942 .56993 Mdot
.944 .08196 Mdot
.944 .08218 Mdot
.944 .08305 Mdot
.944 .08444 Mdot
.944 .08493 Mdot
.944 .08514 Mdot
.944 .08556 Mdot
.944 .08589 Mdot
.944 .0859 Mdot
.944 .08651 Mdot
.944 .08763 Mdot
.944 .08826 Mdot
.944 .08864 Mdot
.944 .09026 Mdot
.944 .09059 Mdot
.944 .0911 Mdot
.944 .09166 Mdot
.944 .09209 Mdot
.944 .09265 Mdot
.944 .09277 Mdot
.944 .09525 Mdot
.944 .09624 Mdot
.944 .09637 Mdot
.944 .09643 Mdot
.944 .0981 Mdot
.944 .09912 Mdot
.944 .09993 Mdot
.944 .10001 Mdot
.944 .10209 Mdot
.944 .10228 Mdot
.944 .10451 Mdot
.944 .10475 Mdot
.944 .10525 Mdot
.944 .10525 Mdot
.944 .1054 Mdot
.944 .10695 Mdot
.944 .10697 Mdot
.944 .10747 Mdot
.944 .10832 Mdot
.944 .10934 Mdot
.944 .11003 Mdot
.944 .11011 Mdot
.944 .11033 Mdot
.944 .11078 Mdot
.944 .11171 Mdot
.944 .11408 Mdot
.944 .11464 Mdot
.944 .11558 Mdot
.944 .12001 Mdot
.944 .12019 Mdot
.944 .12054 Mdot
.944 .12153 Mdot
.944 .12289 Mdot
.944 .12309 Mdot
.944 .12315 Mdot
.944 .12428 Mdot
.944 .12473 Mdot
.944 .12497 Mdot
.944 .12534 Mdot
.944 .12629 Mdot
.944 .12678 Mdot
.944 .12846 Mdot
.944 .12869 Mdot
.944 .12892 Mdot
.944 .12979 Mdot
.944 .13006 Mdot
.944 .13103 Mdot
.944 .13325 Mdot
.944 .13423 Mdot
.944 .13544 Mdot
.944 .13578 Mdot
.944 .13672 Mdot
.944 .13675 Mdot
.944 .13715 Mdot
.944 .13818 Mdot
.944 .13831 Mdot
.944 .13839 Mdot
.944 .14167 Mdot
.944 .14209 Mdot
.944 .14373 Mdot
.944 .14403 Mdot
.944 .14422 Mdot
.944 .14547 Mdot
.944 .14636 Mdot
.944 .14729 Mdot
.944 .14767 Mdot
.944 .14848 Mdot
.944 .14908 Mdot
.944 .14911 Mdot
.944 .15027 Mdot
.944 .15086 Mdot
.944 .15238 Mdot
.944 .15243 Mdot
.944 .15321 Mdot
.944 .15356 Mdot
.944 .15367 Mdot
.944 .15378 Mdot
.944 .154 Mdot
.944 .15405 Mdot
.944 .15429 Mdot
.944 .15451 Mdot
.944 .15635 Mdot
.944 .15658 Mdot
.944 .15734 Mdot
.944 .15796 Mdot
.944 .15802 Mdot
.944 .1587 Mdot
.944 .15893 Mdot
.944 .15958 Mdot
.944 .15999 Mdot
.944 .16079 Mdot
.944 .16101 Mdot
.944 .16186 Mdot
.944 .16209 Mdot
.944 .16261 Mdot
.944 .16309 Mdot
.944 .16415 Mdot
.944 .16455 Mdot
.944 .16652 Mdot
.944 .16677 Mdot
.944 .16685 Mdot
.944 .16808 Mdot
.944 .16864 Mdot
.944 .16873 Mdot
.944 .16887 Mdot
.944 .16895 Mdot
.944 .169 Mdot
.944 .16924 Mdot
.944 .1693 Mdot
.944 .16955 Mdot
.944 .17215 Mdot
.944 .17226 Mdot
.944 .17382 Mdot
.944 .17408 Mdot
.944 .17539 Mdot
.944 .17547 Mdot
.944 .1756 Mdot
.944 .17575 Mdot
.944 .17589 Mdot
.944 .17596 Mdot
.944 .17654 Mdot
.944 .17667 Mdot
.944 .1778 Mdot
.944 .17797 Mdot
.944 .17827 Mdot
.944 .17945 Mdot
.944 .17968 Mdot
.944 .18003 Mdot
.944 .18239 Mdot
.944 .18424 Mdot
.944 .18469 Mdot
.944 .18564 Mdot
.944 .18565 Mdot
.944 .18592 Mdot
.944 .18779 Mdot
.944 .18829 Mdot
.944 .18886 Mdot
.944 .18888 Mdot
.944 .18925 Mdot
.944 .18984 Mdot
.944 .19037 Mdot
.944 .19089 Mdot
.944 .19109 Mdot
.944 .1912 Mdot
.944 .19145 Mdot
.944 .1918 Mdot
.944 .19233 Mdot
.944 .19269 Mdot
.944 .19298 Mdot
.944 .19336 Mdot
.944 .19345 Mdot
.944 .19373 Mdot
.944 .19413 Mdot
.944 .19418 Mdot
.944 .19464 Mdot
.944 .19467 Mdot
.944 .19482 Mdot
.944 .19524 Mdot
.944 .19608 Mdot
.944 .19652 Mdot
.944 .1976 Mdot
.944 .19775 Mdot
.944 .19785 Mdot
.944 .19955 Mdot
.944 .20021 Mdot
.944 .20178 Mdot
.944 .20212 Mdot
.944 .20232 Mdot
.944 .20235 Mdot
.944 .20338 Mdot
.944 .20367 Mdot
.944 .20416 Mdot
.944 .20434 Mdot
.944 .20515 Mdot
.944 .20572 Mdot
.944 .20669 Mdot
.944 .20777 Mdot
.944 .20882 Mdot
.944 .21121 Mdot
.944 .21124 Mdot
.944 .21233 Mdot
.944 .21234 Mdot
.944 .21258 Mdot
.944 .2126 Mdot
.944 .21331 Mdot
.944 .21352 Mdot
.944 .21363 Mdot
.944 .21385 Mdot
.944 .21387 Mdot
.944 .21431 Mdot
.944 .21452 Mdot
.944 .21499 Mdot
.944 .21629 Mdot
.944 .21638 Mdot
.944 .21715 Mdot
.944 .2174 Mdot
.944 .21896 Mdot
.944 .21933 Mdot
.944 .21944 Mdot
.944 .22038 Mdot
.944 .22096 Mdot
.944 .22153 Mdot
.944 .22157 Mdot
.944 .2221 Mdot
.944 .22243 Mdot
.944 .22273 Mdot
.944 .22287 Mdot
.944 .22337 Mdot
.944 .22358 Mdot
.944 .2241 Mdot
.944 .22428 Mdot
.944 .22485 Mdot
.944 .22532 Mdot
.944 .22537 Mdot
.944 .22553 Mdot
.944 .2263 Mdot
.944 .22789 Mdot
.944 .22814 Mdot
.944 .22836 Mdot
.944 .22846 Mdot
.944 .22884 Mdot
.944 .2291 Mdot
.944 .22935 Mdot
.944 .22947 Mdot
.944 .2299 Mdot
.944 .23033 Mdot
.944 .23035 Mdot
.944 .23134 Mdot
.944 .23198 Mdot
.944 .23248 Mdot
.944 .23307 Mdot
.944 .23342 Mdot
.944 .23378 Mdot
.944 .23432 Mdot
.944 .23541 Mdot
.944 .23639 Mdot
.944 .23648 Mdot
.944 .2367 Mdot
.944 .23695 Mdot
.944 .23771 Mdot
.944 .23851 Mdot
.944 .23962 Mdot
.944 .24036 Mdot
.944 .24038 Mdot
.944 .24053 Mdot
.944 .24064 Mdot
.944 .24069 Mdot
.944 .24185 Mdot
.944 .24247 Mdot
.944 .24264 Mdot
.944 .24264 Mdot
.944 .24321 Mdot
.944 .24329 Mdot
.944 .24361 Mdot
.944 .24484 Mdot
.944 .24506 Mdot
.944 .24511 Mdot
.944 .24587 Mdot
.944 .24618 Mdot
.944 .24642 Mdot
.944 .24704 Mdot
.944 .24782 Mdot
.944 .24786 Mdot
.944 .24806 Mdot
.944 .24821 Mdot
.944 .24859 Mdot
.944 .24917 Mdot
.944 .25049 Mdot
.944 .25319 Mdot
.944 .25341 Mdot
.944 .2544 Mdot
.944 .25481 Mdot
.944 .25521 Mdot
.944 .25612 Mdot
.944 .25638 Mdot
.944 .25642 Mdot
.944 .25702 Mdot
.944 .25741 Mdot
.944 .25809 Mdot
.944 .2583 Mdot
.944 .25832 Mdot
.944 .25885 Mdot
.944 .25922 Mdot
.944 .25984 Mdot
.944 .26023 Mdot
.944 .26029 Mdot
.944 .26105 Mdot
.944 .26158 Mdot
.944 .26179 Mdot
.944 .26325 Mdot
.944 .26348 Mdot
.944 .2638 Mdot
.944 .2641 Mdot
.944 .26485 Mdot
.944 .26501 Mdot
.944 .26574 Mdot
.944 .26698 Mdot
.944 .26713 Mdot
.944 .26726 Mdot
.944 .26732 Mdot
.944 .26805 Mdot
.944 .2684 Mdot
.944 .26845 Mdot
.944 .26884 Mdot
.944 .26902 Mdot
.944 .2695 Mdot
.944 .27065 Mdot
.944 .27133 Mdot
.944 .27175 Mdot
.944 .27176 Mdot
.944 .27207 Mdot
.944 .27274 Mdot
.944 .274 Mdot
.944 .27419 Mdot
.944 .27462 Mdot
.944 .27472 Mdot
.944 .27534 Mdot
.944 .27619 Mdot
.944 .27672 Mdot
.944 .27685 Mdot
.944 .27686 Mdot
.944 .27705 Mdot
.944 .27727 Mdot
.944 .27737 Mdot
.944 .27769 Mdot
.944 .27771 Mdot
.944 .27777 Mdot
.944 .27823 Mdot
.944 .2785 Mdot
.944 .27864 Mdot
.944 .28016 Mdot
.944 .2814 Mdot
.944 .28212 Mdot
.944 .28256 Mdot
.944 .28385 Mdot
.944 .28399 Mdot
.944 .28417 Mdot
.944 .28452 Mdot
.944 .28516 Mdot
.944 .28527 Mdot
.944 .28557 Mdot
.944 .28656 Mdot
.944 .2868 Mdot
.944 .28699 Mdot
.944 .2874 Mdot
.944 .28798 Mdot
.944 .28812 Mdot
.944 .28818 Mdot
.944 .28821 Mdot
.944 .28834 Mdot
.944 .289 Mdot
.944 .29051 Mdot
.944 .29092 Mdot
.944 .29252 Mdot
.944 .29285 Mdot
.944 .29296 Mdot
.944 .29297 Mdot
.944 .29394 Mdot
.944 .29484 Mdot
.944 .29491 Mdot
.944 .29528 Mdot
.944 .29627 Mdot
.944 .29679 Mdot
.944 .29685 Mdot
.944 .29723 Mdot
.944 .29751 Mdot
.944 .29761 Mdot
.944 .29765 Mdot
.944 .30043 Mdot
.944 .30132 Mdot
.944 .30176 Mdot
.944 .3018 Mdot
.944 .30194 Mdot
.944 .30263 Mdot
.944 .30352 Mdot
.944 .30427 Mdot
.944 .30432 Mdot
.944 .3046 Mdot
.944 .30533 Mdot
.944 .30549 Mdot
.944 .30577 Mdot
.944 .30591 Mdot
.944 .306 Mdot
.944 .30646 Mdot
.944 .30656 Mdot
.944 .30705 Mdot
.944 .30723 Mdot
.944 .30732 Mdot
.944 .3075 Mdot
.944 .30763 Mdot
.944 .30827 Mdot
.944 .31106 Mdot
.944 .31137 Mdot
.944 .31195 Mdot
.944 .31216 Mdot
.944 .31265 Mdot
.944 .31378 Mdot
.944 .3141 Mdot
.944 .3151 Mdot
.944 .31559 Mdot
.944 .3161 Mdot
.944 .31613 Mdot
.944 .31671 Mdot
.944 .31739 Mdot
.944 .3176 Mdot
.944 .31807 Mdot
.944 .31822 Mdot
.944 .31846 Mdot
.944 .31874 Mdot
.944 .31894 Mdot
.944 .31902 Mdot
.944 .31915 Mdot
.944 .31941 Mdot
.944 .32007 Mdot
.944 .32023 Mdot
.944 .32049 Mdot
.944 .32262 Mdot
.944 .32293 Mdot
.944 .32306 Mdot
.944 .32323 Mdot
.944 .3235 Mdot
.944 .32364 Mdot
.944 .32417 Mdot
.944 .32424 Mdot
.944 .32483 Mdot
.944 .32573 Mdot
.944 .32607 Mdot
.944 .32616 Mdot
.944 .32683 Mdot
.944 .32689 Mdot
.944 .32853 Mdot
.944 .33083 Mdot
.944 .33129 Mdot
.944 .33193 Mdot
.944 .33324 Mdot
.944 .33369 Mdot
.944 .33478 Mdot
.944 .33547 Mdot
.944 .33556 Mdot
.944 .33564 Mdot
.944 .3364 Mdot
.944 .3373 Mdot
.944 .33742 Mdot
.944 .33743 Mdot
.944 .33759 Mdot
.944 .33763 Mdot
.944 .33795 Mdot
.944 .33808 Mdot
.944 .33841 Mdot
.944 .34148 Mdot
.944 .34188 Mdot
.944 .34221 Mdot
.944 .34242 Mdot
.944 .3435 Mdot
.944 .34355 Mdot
.944 .34424 Mdot
.944 .34484 Mdot
.944 .34535 Mdot
.944 .34578 Mdot
.944 .34605 Mdot
.944 .34636 Mdot
.944 .34733 Mdot
.944 .34771 Mdot
.944 .34771 Mdot
.944 .34791 Mdot
.944 .348 Mdot
.944 .34819 Mdot
.944 .34838 Mdot
.944 .34899 Mdot
.944 .34906 Mdot
.944 .35006 Mdot
.944 .35022 Mdot
.944 .35073 Mdot
.944 .35115 Mdot
.944 .35128 Mdot
.944 .352 Mdot
.944 .35216 Mdot
.944 .35234 Mdot
.944 .35269 Mdot
.944 .35297 Mdot
.944 .35346 Mdot
.944 .35355 Mdot
.944 .35411 Mdot
.944 .35441 Mdot
.944 .35447 Mdot
.944 .35476 Mdot
.944 .35551 Mdot
.944 .35555 Mdot
.944 .35558 Mdot
.944 .35609 Mdot
.944 .3563 Mdot
.944 .35641 Mdot
.944 .35676 Mdot
.944 .35713 Mdot
.944 .3572 Mdot
.944 .35737 Mdot
.944 .35797 Mdot
.944 .35992 Mdot
.944 .36 Mdot
.944 .36001 Mdot
.944 .36028 Mdot
.944 .36047 Mdot
.944 .36096 Mdot
.944 .36151 Mdot
.944 .36208 Mdot
.944 .36216 Mdot
.944 .36306 Mdot
.944 .36349 Mdot
.944 .36354 Mdot
.944 .36367 Mdot
.944 .36431 Mdot
.944 .3644 Mdot
.944 .36494 Mdot
.944 .36531 Mdot
.944 .36574 Mdot
.944 .36588 Mdot
.944 .36666 Mdot
.944 .36701 Mdot
.944 .3677 Mdot
.944 .36779 Mdot
.944 .36789 Mdot
.944 .36818 Mdot
.944 .36853 Mdot
.944 .3687 Mdot
.944 .36886 Mdot
.944 .36892 Mdot
.944 .36896 Mdot
.944 .37026 Mdot
.944 .37091 Mdot
.944 .37145 Mdot
.944 .37272 Mdot
.944 .37344 Mdot
.944 .37426 Mdot
.944 .37437 Mdot
.944 .37533 Mdot
.944 .37542 Mdot
.944 .37711 Mdot
.944 .37717 Mdot
.944 .37768 Mdot
.944 .37786 Mdot
.944 .3792 Mdot
.944 .37954 Mdot
.944 .38024 Mdot
.944 .38119 Mdot
.944 .38156 Mdot
.944 .38218 Mdot
.944 .38221 Mdot
.944 .38278 Mdot
.944 .38279 Mdot
.944 .38407 Mdot
.944 .38481 Mdot
.944 .38515 Mdot
.944 .3857 Mdot
.944 .38575 Mdot
.944 .38658 Mdot
.944 .38709 Mdot
.944 .3878 Mdot
.944 .38782 Mdot
.944 .38797 Mdot
.944 .38803 Mdot
.944 .38815 Mdot
.944 .38828 Mdot
.944 .38833 Mdot
.944 .38933 Mdot
.944 .38965 Mdot
.944 .38967 Mdot
.944 .39006 Mdot
.944 .39027 Mdot
.944 .39067 Mdot
.944 .39071 Mdot
.944 .39122 Mdot
.944 .39136 Mdot
.944 .39155 Mdot
.944 .39194 Mdot
.944 .39284 Mdot
.944 .39339 Mdot
.944 .39474 Mdot
.944 .39529 Mdot
.944 .39545 Mdot
.944 .39546 Mdot
.944 .39612 Mdot
.944 .39691 Mdot
.944 .39693 Mdot
.944 .39738 Mdot
.944 .39881 Mdot
.944 .3992 Mdot
.944 .39942 Mdot
.944 .40012 Mdot
.944 .40032 Mdot
.944 .40054 Mdot
.944 .40091 Mdot
.944 .40103 Mdot
.944 .40124 Mdot
.944 .40224 Mdot
.944 .40266 Mdot
.944 .40302 Mdot
.944 .40339 Mdot
.944 .40411 Mdot
.944 .40518 Mdot
.944 .40526 Mdot
.944 .40609 Mdot
.944 .40626 Mdot
.944 .40688 Mdot
.944 .40695 Mdot
.944 .40698 Mdot
.944 .40744 Mdot
.944 .40772 Mdot
.944 .40847 Mdot
.944 .40865 Mdot
.944 .40904 Mdot
.944 .40972 Mdot
.944 .40973 Mdot
.944 .41003 Mdot
.944 .41005 Mdot
.944 .41038 Mdot
.944 .41108 Mdot
.944 .41144 Mdot
.944 .41233 Mdot
.944 .41243 Mdot
.944 .41273 Mdot
.944 .41363 Mdot
.944 .41418 Mdot
.944 .41467 Mdot
.944 .41636 Mdot
.944 .4171 Mdot
.944 .41719 Mdot
.944 .41746 Mdot
.944 .41767 Mdot
.944 .41772 Mdot
.944 .41808 Mdot
.944 .41826 Mdot
.944 .41868 Mdot
.944 .41876 Mdot
.944 .41898 Mdot
.944 .41947 Mdot
.944 .41951 Mdot
.944 .41992 Mdot
.944 .41995 Mdot
.944 .42017 Mdot
.944 .42065 Mdot
.944 .42069 Mdot
.944 .42099 Mdot
.944 .42128 Mdot
.944 .4218 Mdot
.944 .42183 Mdot
.944 .42318 Mdot
.944 .42328 Mdot
.944 .42351 Mdot
.944 .42369 Mdot
.944 .42375 Mdot
.944 .42386 Mdot
.944 .42414 Mdot
.944 .42417 Mdot
.944 .42491 Mdot
.944 .42552 Mdot
.944 .42585 Mdot
.944 .42648 Mdot
.944 .42698 Mdot
.944 .42763 Mdot
.944 .42805 Mdot
.944 .42815 Mdot
.944 .42831 Mdot
.944 .42918 Mdot
.944 .42932 Mdot
.944 .42983 Mdot
.944 .43122 Mdot
.944 .43139 Mdot
.944 .43323 Mdot
.944 .4334 Mdot
.944 .43364 Mdot
.944 .43366 Mdot
.944 .43382 Mdot
.944 .4343 Mdot
.944 .43474 Mdot
.944 .43479 Mdot
.944 .43573 Mdot
.944 .43597 Mdot
.944 .43666 Mdot
.944 .43724 Mdot
.944 .43846 Mdot
.944 .43933 Mdot
.944 .43977 Mdot
.944 .44042 Mdot
.944 .44074 Mdot
.944 .44077 Mdot
.944 .44105 Mdot
.944 .44127 Mdot
.944 .44136 Mdot
.944 .44294 Mdot
.944 .44329 Mdot
.944 .44354 Mdot
.944 .44425 Mdot
.944 .44436 Mdot
.944 .44472 Mdot
.944 .44503 Mdot
.944 .44504 Mdot
.944 .44611 Mdot
.944 .44627 Mdot
.944 .44687 Mdot
.944 .44755 Mdot
.944 .44771 Mdot
.944 .44919 Mdot
.944 .44953 Mdot
.944 .4496 Mdot
.944 .4497 Mdot
.944 .44975 Mdot
.944 .45114 Mdot
.944 .45128 Mdot
.944 .45171 Mdot
.944 .45218 Mdot
.944 .45264 Mdot
.944 .45334 Mdot
.944 .45482 Mdot
.944 .45489 Mdot
.944 .45504 Mdot
.944 .45527 Mdot
.944 .45555 Mdot
.944 .45607 Mdot
.944 .45627 Mdot
.944 .4573 Mdot
.944 .45736 Mdot
.944 .45975 Mdot
.944 .45983 Mdot
.944 .45987 Mdot
.944 .45994 Mdot
.944 .46025 Mdot
.944 .46056 Mdot
.944 .46122 Mdot
.944 .46177 Mdot
.944 .46196 Mdot
.944 .46213 Mdot
.944 .46343 Mdot
.944 .46408 Mdot
.944 .46496 Mdot
.944 .46538 Mdot
.944 .46556 Mdot
.944 .46584 Mdot
.944 .46663 Mdot
.944 .46725 Mdot
.944 .46735 Mdot
.944 .46801 Mdot
.944 .46837 Mdot
.944 .46853 Mdot
.944 .46876 Mdot
.944 .46973 Mdot
.944 .46998 Mdot
.944 .47008 Mdot
.944 .47049 Mdot
.944 .47088 Mdot
.944 .47099 Mdot
.944 .47106 Mdot
.944 .47219 Mdot
.944 .47259 Mdot
.944 .47275 Mdot
.944 .47292 Mdot
.944 .47381 Mdot
.944 .4742 Mdot
.944 .4746 Mdot
.944 .47464 Mdot
.944 .47485 Mdot
.944 .47565 Mdot
.944 .47577 Mdot
.944 .47613 Mdot
.944 .47634 Mdot
.944 .47665 Mdot
.944 .47668 Mdot
.944 .47681 Mdot
.944 .47751 Mdot
.944 .47825 Mdot
.944 .47837 Mdot
.944 .47979 Mdot
.944 .4805 Mdot
.944 .4808 Mdot
.944 .48119 Mdot
.944 .48162 Mdot
.944 .48195 Mdot
.944 .48208 Mdot
.944 .48279 Mdot
.944 .48344 Mdot
.944 .48365 Mdot
.944 .48396 Mdot
.944 .48404 Mdot
.944 .48437 Mdot
.944 .48499 Mdot
.944 .48501 Mdot
.944 .48507 Mdot
.944 .48515 Mdot
.944 .48556 Mdot
.944 .48657 Mdot
.944 .48697 Mdot
.944 .4871 Mdot
.944 .48722 Mdot
.944 .48727 Mdot
.944 .48778 Mdot
.944 .48865 Mdot
.944 .48884 Mdot
.944 .48902 Mdot
.944 .48994 Mdot
.944 .49046 Mdot
.944 .49099 Mdot
.944 .49113 Mdot
.944 .49127 Mdot
.944 .49147 Mdot
.944 .49152 Mdot
.944 .49163 Mdot
.944 .49177 Mdot
.944 .49302 Mdot
.944 .49313 Mdot
.944 .49338 Mdot
.944 .49368 Mdot
.944 .49378 Mdot
.944 .49416 Mdot
.944 .4945 Mdot
.944 .49483 Mdot
.944 .49514 Mdot
.944 .49544 Mdot
.944 .49574 Mdot
.944 .49732 Mdot
.944 .49746 Mdot
.944 .49791 Mdot
.944 .4986 Mdot
.944 .49896 Mdot
.944 .49919 Mdot
.944 .49932 Mdot
.944 .49949 Mdot
.944 .49986 Mdot
.944 .49988 Mdot
.944 .50001 Mdot
.944 .50001 Mdot
.944 .50059 Mdot
.944 .5006 Mdot
.944 .50187 Mdot
.944 .50243 Mdot
.944 .503 Mdot
.944 .50351 Mdot
.944 .50424 Mdot
.944 .50433 Mdot
.944 .5046 Mdot
.944 .5053 Mdot
.944 .50542 Mdot
.944 .5056 Mdot
.944 .50643 Mdot
.944 .50678 Mdot
.944 .50773 Mdot
.944 .50781 Mdot
.944 .50838 Mdot
.944 .50938 Mdot
.944 .50962 Mdot
.944 .50965 Mdot
.944 .50986 Mdot
.944 .51001 Mdot
.944 .51026 Mdot
.944 .51041 Mdot
.944 .5106 Mdot
.944 .51088 Mdot
.944 .5112 Mdot
.944 .51126 Mdot
.944 .51137 Mdot
.944 .51164 Mdot
.944 .51223 Mdot
.944 .51274 Mdot
.944 .51301 Mdot
.944 .51587 Mdot
.944 .51743 Mdot
.944 .51805 Mdot
.944 .51821 Mdot
.944 .5183 Mdot
.944 .51889 Mdot
.944 .51897 Mdot
.944 .51927 Mdot
.944 .51931 Mdot
.944 .51953 Mdot
.944 .51957 Mdot
.944 .52041 Mdot
.944 .52123 Mdot
.944 .52267 Mdot
.944 .5228 Mdot
.944 .52283 Mdot
.944 .52299 Mdot
.944 .5231 Mdot
.944 .52345 Mdot
.944 .5241 Mdot
.944 .52427 Mdot
.944 .52532 Mdot
.944 .52553 Mdot
.944 .52609 Mdot
.944 .52634 Mdot
.944 .52719 Mdot
.944 .52795 Mdot
.944 .52842 Mdot
.944 .52878 Mdot
.944 .52954 Mdot
.944 .52966 Mdot
.944 .53064 Mdot
.944 .53088 Mdot
.944 .5309 Mdot
.944 .53102 Mdot
.944 .53108 Mdot
.944 .53132 Mdot
.944 .53174 Mdot
.944 .53257 Mdot
.944 .53542 Mdot
.944 .53608 Mdot
.944 .53619 Mdot
.944 .53917 Mdot
.944 .53921 Mdot
.944 .53928 Mdot
.944 .53983 Mdot
.944 .54004 Mdot
.944 .54006 Mdot
.944 .54055 Mdot
.944 .54073 Mdot
.944 .54137 Mdot
.944 .54189 Mdot
.944 .54307 Mdot
.944 .54359 Mdot
.944 .54373 Mdot
.944 .54419 Mdot
.944 .54431 Mdot
.944 .54443 Mdot
.944 .54532 Mdot
.944 .54558 Mdot
.944 .54608 Mdot
.944 .54628 Mdot
.944 .54641 Mdot
.944 .54665 Mdot
.944 .54724 Mdot
.944 .54727 Mdot
.944 .54738 Mdot
.944 .5481 Mdot
.944 .54863 Mdot
.944 .54881 Mdot
.944 .54891 Mdot
.944 .55125 Mdot
.944 .55175 Mdot
.944 .55205 Mdot
.944 .5533 Mdot
.944 .5538 Mdot
.944 .55403 Mdot
.944 .55415 Mdot
.944 .55419 Mdot
.944 .55456 Mdot
.944 .5551 Mdot
.944 .55555 Mdot
.944 .55582 Mdot
.944 .55582 Mdot
.944 .55665 Mdot
.944 .55672 Mdot
.944 .55673 Mdot
.944 .55699 Mdot
.944 .55712 Mdot
.944 .5583 Mdot
.944 .5584 Mdot
.944 .5595 Mdot
.944 .55954 Mdot
.944 .55997 Mdot
.944 .56051 Mdot
.944 .56139 Mdot
.944 .56143 Mdot
.944 .56149 Mdot
.944 .56202 Mdot
.944 .56333 Mdot
.944 .5634 Mdot
.944 .5637 Mdot
.944 .56392 Mdot
.944 .56422 Mdot
.944 .56449 Mdot
.944 .56467 Mdot
.944 .56552 Mdot
.944 .56573 Mdot
.944 .56606 Mdot
.944 .56665 Mdot
.944 .56697 Mdot
.944 .56698 Mdot
.944 .56715 Mdot
.944 .56738 Mdot
.944 .56749 Mdot
.944 .56775 Mdot
.944 .56848 Mdot
.944 .56894 Mdot
.944 .56906 Mdot
.946 .07848 Mdot
.946 .0786 Mdot
.946 .08048 Mdot
.946 .0805 Mdot
.946 .08099 Mdot
.946 .081 Mdot
.946 .08116 Mdot
.946 .08173 Mdot
.946 .08206 Mdot
.946 .08207 Mdot
.946 .08247 Mdot
.946 .08304 Mdot
.946 .08414 Mdot
.946 .08531 Mdot
.946 .08646 Mdot
.946 .08659 Mdot
.946 .0892 Mdot
.946 .08973 Mdot
.946 .09081 Mdot
.946 .09184 Mdot
.946 .09412 Mdot
.946 .09669 Mdot
.946 .09929 Mdot
.946 .1005 Mdot
.946 .10163 Mdot
.946 .10221 Mdot
.946 .10284 Mdot
.946 .10311 Mdot
.946 .10412 Mdot
.946 .10618 Mdot
.946 .1063 Mdot
.946 .10808 Mdot
.946 .10809 Mdot
.946 .10833 Mdot
.946 .10879 Mdot
.946 .10905 Mdot
.946 .10919 Mdot
.946 .10929 Mdot
.946 .10953 Mdot
.946 .11124 Mdot
.946 .1113 Mdot
.946 .1134 Mdot
.946 .11346 Mdot
.946 .11399 Mdot
.946 .11437 Mdot
.946 .11532 Mdot
.946 .1156 Mdot
.946 .11612 Mdot
.946 .11618 Mdot
.946 .11665 Mdot
.946 .11703 Mdot
.946 .11834 Mdot
.946 .11899 Mdot
.946 .1192 Mdot
.946 .12052 Mdot
.946 .12188 Mdot
.946 .12406 Mdot
.946 .12522 Mdot
.946 .12553 Mdot
.946 .12582 Mdot
.946 .12658 Mdot
.946 .12745 Mdot
.946 .13058 Mdot
.946 .13103 Mdot
.946 .13276 Mdot
.946 .13282 Mdot
.946 .13284 Mdot
.946 .13333 Mdot
.946 .13384 Mdot
.946 .13528 Mdot
.946 .13536 Mdot
.946 .13559 Mdot
.946 .13687 Mdot
.946 .13883 Mdot
.946 .13911 Mdot
.946 .13913 Mdot
.946 .13918 Mdot
.946 .14 Mdot
.946 .14012 Mdot
.946 .14012 Mdot
.946 .14017 Mdot
.946 .14038 Mdot
.946 .14043 Mdot
.946 .14055 Mdot
.946 .14151 Mdot
.946 .14152 Mdot
.946 .14213 Mdot
.946 .14216 Mdot
.946 .14262 Mdot
.946 .14291 Mdot
.946 .14399 Mdot
.946 .14403 Mdot
.946 .14435 Mdot
.946 .14477 Mdot
.946 .14514 Mdot
.946 .14607 Mdot
.946 .148 Mdot
.946 .14825 Mdot
.946 .14828 Mdot
.946 .14892 Mdot
.946 .14893 Mdot
.946 .15045 Mdot
.946 .15057 Mdot
.946 .1507 Mdot
.946 .15086 Mdot
.946 .15107 Mdot
.946 .15114 Mdot
.946 .15145 Mdot
.946 .15167 Mdot
.946 .1517 Mdot
.946 .15181 Mdot
.946 .15201 Mdot
.946 .15287 Mdot
.946 .15287 Mdot
.946 .15326 Mdot
.946 .15373 Mdot
.946 .15565 Mdot
.946 .15582 Mdot
.946 .15664 Mdot
.946 .15668 Mdot
.946 .15729 Mdot
.946 .15869 Mdot
.946 .15925 Mdot
.946 .15971 Mdot
.946 .16064 Mdot
.946 .16103 Mdot
.946 .16149 Mdot
.946 .16312 Mdot
.946 .16467 Mdot
.946 .16495 Mdot
.946 .16527 Mdot
.946 .1656 Mdot
.946 .16661 Mdot
.946 .1678 Mdot
.946 .16829 Mdot
.946 .16944 Mdot
.946 .16958 Mdot
.946 .16974 Mdot
.946 .16981 Mdot
.946 .17272 Mdot
.946 .17456 Mdot
.946 .17474 Mdot
.946 .17478 Mdot
.946 .17523 Mdot
.946 .17551 Mdot
.946 .17567 Mdot
.946 .17572 Mdot
.946 .17644 Mdot
.946 .17671 Mdot
.946 .17683 Mdot
.946 .17703 Mdot
.946 .17735 Mdot
.946 .17916 Mdot
.946 .17931 Mdot
.946 .17953 Mdot
.946 .18005 Mdot
.946 .18025 Mdot
.946 .18098 Mdot
.946 .18144 Mdot
.946 .18178 Mdot
.946 .18195 Mdot
.946 .18307 Mdot
.946 .18313 Mdot
.946 .18387 Mdot
.946 .18459 Mdot
.946 .18603 Mdot
.946 .18658 Mdot
.946 .18776 Mdot
.946 .18782 Mdot
.946 .18799 Mdot
.946 .18804 Mdot
.946 .18944 Mdot
.946 .19103 Mdot
.946 .19136 Mdot
.946 .19138 Mdot
.946 .19142 Mdot
.946 .19184 Mdot
.946 .19199 Mdot
.946 .19262 Mdot
.946 .19263 Mdot
.946 .19271 Mdot
.946 .19291 Mdot
.946 .19319 Mdot
.946 .19325 Mdot
.946 .19345 Mdot
.946 .19366 Mdot
.946 .1941 Mdot
.946 .19469 Mdot
.946 .19522 Mdot
.946 .19526 Mdot
.946 .19734 Mdot
.946 .19745 Mdot
.946 .20108 Mdot
.946 .20143 Mdot
.946 .20154 Mdot
.946 .2024 Mdot
.946 .20243 Mdot
.946 .20254 Mdot
.946 .20319 Mdot
.946 .20326 Mdot
.946 .20335 Mdot
.946 .20485 Mdot
.946 .20505 Mdot
.946 .20513 Mdot
.946 .20557 Mdot
.946 .20559 Mdot
.946 .20657 Mdot
.946 .20669 Mdot
.946 .20695 Mdot
.946 .20744 Mdot
.946 .20757 Mdot
.946 .20767 Mdot
.946 .20829 Mdot
.946 .20833 Mdot
.946 .20885 Mdot
.946 .20891 Mdot
.946 .20939 Mdot
.946 .20961 Mdot
.946 .20993 Mdot
.946 .21016 Mdot
.946 .21078 Mdot
.946 .2108 Mdot
.946 .21162 Mdot
.946 .212 Mdot
.946 .2124 Mdot
.946 .21316 Mdot
.946 .21381 Mdot
.946 .21489 Mdot
.946 .2154 Mdot
.946 .21544 Mdot
.946 .21554 Mdot
.946 .21585 Mdot
.946 .21748 Mdot
.946 .2187 Mdot
.946 .21901 Mdot
.946 .21972 Mdot
.946 .2216 Mdot
.946 .22193 Mdot
.946 .22199 Mdot
.946 .22287 Mdot
.946 .22379 Mdot
.946 .22394 Mdot
.946 .22403 Mdot
.946 .22438 Mdot
.946 .22439 Mdot
.946 .22459 Mdot
.946 .22492 Mdot
.946 .22496 Mdot
.946 .22589 Mdot
.946 .22595 Mdot
.946 .22607 Mdot
.946 .22634 Mdot
.946 .22637 Mdot
.946 .22655 Mdot
.946 .22781 Mdot
.946 .22801 Mdot
.946 .2282 Mdot
.946 .22825 Mdot
.946 .22871 Mdot
.946 .2296 Mdot
.946 .23097 Mdot
.946 .23394 Mdot
.946 .23397 Mdot
.946 .23479 Mdot
.946 .23586 Mdot
.946 .23597 Mdot
.946 .23614 Mdot
.946 .23799 Mdot
.946 .23802 Mdot
.946 .23805 Mdot
.946 .23816 Mdot
.946 .23821 Mdot
.946 .23913 Mdot
.946 .2401 Mdot
.946 .2413 Mdot
.946 .24155 Mdot
.946 .24186 Mdot
.946 .24281 Mdot
.946 .24298 Mdot
.946 .24324 Mdot
.946 .24342 Mdot
.946 .2436 Mdot
.946 .24582 Mdot
.946 .24756 Mdot
.946 .24758 Mdot
.946 .24868 Mdot
.946 .24954 Mdot
.946 .25007 Mdot
.946 .25007 Mdot
.946 .25011 Mdot
.946 .25021 Mdot
.946 .25055 Mdot
.946 .25176 Mdot
.946 .25197 Mdot
.946 .25199 Mdot
.946 .25207 Mdot
.946 .25246 Mdot
.946 .25257 Mdot
.946 .2528 Mdot
.946 .25295 Mdot
.946 .25326 Mdot
.946 .25462 Mdot
.946 .25464 Mdot
.946 .25509 Mdot
.946 .25537 Mdot
.946 .25579 Mdot
.946 .25583 Mdot
.946 .25591 Mdot
.946 .25668 Mdot
.946 .25671 Mdot
.946 .25726 Mdot
.946 .25931 Mdot
.946 .25938 Mdot
.946 .25998 Mdot
.946 .26079 Mdot
.946 .26117 Mdot
.946 .26148 Mdot
.946 .2627 Mdot
.946 .26324 Mdot
.946 .26468 Mdot
.946 .26476 Mdot
.946 .2669 Mdot
.946 .26736 Mdot
.946 .26742 Mdot
.946 .26754 Mdot
.946 .2678 Mdot
.946 .26796 Mdot
.946 .26839 Mdot
.946 .26863 Mdot
.946 .26865 Mdot
.946 .26946 Mdot
.946 .27046 Mdot
.946 .27153 Mdot
.946 .27176 Mdot
.946 .272 Mdot
.946 .27209 Mdot
.946 .27215 Mdot
.946 .2723 Mdot
.946 .27263 Mdot
.946 .27269 Mdot
.946 .27283 Mdot
.946 .27342 Mdot
.946 .27384 Mdot
.946 .27388 Mdot
.946 .2741 Mdot
.946 .27447 Mdot
.946 .2761 Mdot
.946 .27611 Mdot
.946 .27684 Mdot
.946 .27701 Mdot
.946 .27772 Mdot
.946 .27812 Mdot
.946 .27852 Mdot
.946 .27868 Mdot
.946 .27908 Mdot
.946 .27949 Mdot
.946 .27986 Mdot
.946 .28125 Mdot
.946 .28128 Mdot
.946 .28136 Mdot
.946 .28156 Mdot
.946 .28157 Mdot
.946 .28162 Mdot
.946 .28169 Mdot
.946 .28182 Mdot
.946 .28239 Mdot
.946 .28323 Mdot
.946 .28331 Mdot
.946 .28363 Mdot
.946 .2841 Mdot
.946 .28439 Mdot
.946 .28448 Mdot
.946 .2867 Mdot
.946 .28711 Mdot
.946 .28794 Mdot
.946 .28818 Mdot
.946 .28827 Mdot
.946 .28842 Mdot
.946 .28844 Mdot
.946 .28904 Mdot
.946 .2902 Mdot
.946 .29032 Mdot
.946 .29041 Mdot
.946 .2908 Mdot
.946 .29111 Mdot
.946 .29154 Mdot
.946 .29241 Mdot
.946 .2934 Mdot
.946 .29356 Mdot
.946 .2955 Mdot
.946 .29558 Mdot
.946 .29599 Mdot
.946 .2966 Mdot
.946 .29735 Mdot
.946 .2974 Mdot
.946 .29843 Mdot
.946 .29897 Mdot
.946 .29957 Mdot
.946 .30018 Mdot
.946 .30025 Mdot
.946 .30209 Mdot
.946 .30257 Mdot
.946 .30291 Mdot
.946 .30363 Mdot
.946 .30435 Mdot
.946 .30528 Mdot
.946 .30646 Mdot
.946 .30681 Mdot
.946 .30745 Mdot
.946 .30772 Mdot
.946 .30797 Mdot
.946 .30802 Mdot
.946 .30802 Mdot
.946 .30816 Mdot
.946 .30816 Mdot
.946 .30869 Mdot
.946 .30872 Mdot
.946 .31158 Mdot
.946 .31168 Mdot
.946 .31179 Mdot
.946 .31225 Mdot
.946 .3129 Mdot
.946 .31367 Mdot
.946 .31381 Mdot
.946 .3144 Mdot
.946 .31714 Mdot
.946 .31748 Mdot
.946 .31755 Mdot
.946 .31783 Mdot
.946 .31841 Mdot
.946 .31844 Mdot
.946 .31894 Mdot
.946 .31894 Mdot
.946 .31925 Mdot
.946 .31928 Mdot
.946 .31934 Mdot
.946 .31984 Mdot
.946 .32044 Mdot
.946 .32059 Mdot
.946 .3207 Mdot
.946 .32104 Mdot
.946 .32119 Mdot
.946 .3212 Mdot
.946 .32133 Mdot
.946 .32144 Mdot
.946 .32181 Mdot
.946 .32241 Mdot
.946 .32373 Mdot
.946 .32411 Mdot
.946 .32435 Mdot
.946 .32523 Mdot
.946 .32535 Mdot
.946 .32585 Mdot
.946 .32586 Mdot
.946 .32614 Mdot
.946 .32654 Mdot
.946 .32753 Mdot
.946 .32761 Mdot
.946 .3279 Mdot
.946 .32796 Mdot
.946 .32801 Mdot
.946 .32929 Mdot
.946 .33009 Mdot
.946 .33016 Mdot
.946 .33035 Mdot
.946 .33081 Mdot
.946 .33089 Mdot
.946 .33106 Mdot
.946 .33112 Mdot
.946 .33116 Mdot
.946 .33145 Mdot
.946 .33156 Mdot
.946 .33169 Mdot
.946 .33252 Mdot
.946 .33324 Mdot
.946 .33336 Mdot
.946 .33373 Mdot
.946 .33386 Mdot
.946 .33432 Mdot
.946 .33475 Mdot
.946 .33562 Mdot
.946 .33612 Mdot
.946 .33751 Mdot
.946 .33829 Mdot
.946 .33884 Mdot
.946 .3389 Mdot
.946 .33905 Mdot
.946 .33931 Mdot
.946 .33989 Mdot
.946 .34121 Mdot
.946 .34211 Mdot
.946 .34222 Mdot
.946 .34256 Mdot
.946 .34264 Mdot
.946 .34273 Mdot
.946 .34314 Mdot
.946 .3453 Mdot
.946 .34605 Mdot
.946 .34618 Mdot
.946 .34695 Mdot
.946 .34711 Mdot
.946 .34746 Mdot
.946 .34829 Mdot
.946 .34848 Mdot
.946 .34892 Mdot
.946 .34896 Mdot
.946 .34905 Mdot
.946 .34984 Mdot
.946 .35013 Mdot
.946 .35131 Mdot
.946 .35133 Mdot
.946 .35149 Mdot
.946 .35187 Mdot
.946 .3519 Mdot
.946 .35239 Mdot
.946 .35251 Mdot
.946 .35264 Mdot
.946 .35289 Mdot
.946 .35327 Mdot
.946 .35411 Mdot
.946 .35467 Mdot
.946 .35523 Mdot
.946 .35524 Mdot
.946 .35623 Mdot
.946 .35631 Mdot
.946 .3568 Mdot
.946 .35791 Mdot
.946 .35874 Mdot
.946 .3595 Mdot
.946 .36024 Mdot
.946 .36045 Mdot
.946 .36171 Mdot
.946 .36306 Mdot
.946 .36372 Mdot
.946 .36491 Mdot
.946 .36655 Mdot
.946 .36671 Mdot
.946 .36732 Mdot
.946 .3674 Mdot
.946 .36748 Mdot
.946 .36798 Mdot
.946 .36811 Mdot
.946 .36819 Mdot
.946 .36982 Mdot
.946 .36987 Mdot
.946 .37007 Mdot
.946 .37075 Mdot
.946 .37132 Mdot
.946 .37143 Mdot
.946 .3716 Mdot
.946 .37262 Mdot
.946 .37327 Mdot
.946 .37337 Mdot
.946 .37436 Mdot
.946 .37446 Mdot
.946 .37478 Mdot
.946 .37479 Mdot
.946 .37483 Mdot
.946 .37498 Mdot
.946 .37499 Mdot
.946 .37582 Mdot
.946 .37585 Mdot
.946 .37771 Mdot
.946 .37794 Mdot
.946 .37827 Mdot
.946 .37831 Mdot
.946 .37843 Mdot
.946 .37847 Mdot
.946 .37851 Mdot
.946 .37918 Mdot
.946 .37936 Mdot
.946 .3796 Mdot
.946 .37964 Mdot
.946 .37978 Mdot
.946 .38037 Mdot
.946 .38038 Mdot
.946 .38096 Mdot
.946 .38103 Mdot
.946 .38126 Mdot
.946 .38164 Mdot
.946 .38198 Mdot
.946 .38201 Mdot
.946 .38214 Mdot
.946 .38251 Mdot
.946 .38303 Mdot
.946 .38346 Mdot
.946 .38407 Mdot
.946 .38449 Mdot
.946 .38567 Mdot
.946 .38571 Mdot
.946 .38581 Mdot
.946 .3861 Mdot
.946 .38705 Mdot
.946 .38726 Mdot
.946 .38783 Mdot
.946 .38799 Mdot
.946 .38873 Mdot
.946 .38896 Mdot
.946 .38918 Mdot
.946 .39017 Mdot
.946 .39036 Mdot
.946 .3914 Mdot
.946 .39232 Mdot
.946 .39345 Mdot
.946 .39442 Mdot
.946 .39449 Mdot
.946 .39467 Mdot
.946 .39525 Mdot
.946 .39661 Mdot
.946 .39687 Mdot
.946 .39709 Mdot
.946 .39834 Mdot
.946 .39954 Mdot
.946 .39962 Mdot
.946 .40036 Mdot
.946 .40059 Mdot
.946 .40065 Mdot
.946 .40073 Mdot
.946 .40085 Mdot
.946 .40124 Mdot
.946 .40128 Mdot
.946 .40258 Mdot
.946 .40269 Mdot
.946 .40283 Mdot
.946 .4051 Mdot
.946 .40614 Mdot
.946 .40676 Mdot
.946 .40687 Mdot
.946 .40747 Mdot
.946 .40788 Mdot
.946 .40839 Mdot
.946 .40854 Mdot
.946 .41029 Mdot
.946 .41056 Mdot
.946 .41074 Mdot
.946 .41094 Mdot
.946 .41141 Mdot
.946 .41142 Mdot
.946 .4118 Mdot
.946 .41204 Mdot
.946 .4124 Mdot
.946 .41242 Mdot
.946 .4125 Mdot
.946 .41253 Mdot
.946 .41426 Mdot
.946 .41436 Mdot
.946 .41437 Mdot
.946 .41459 Mdot
.946 .41512 Mdot
.946 .41517 Mdot
.946 .41551 Mdot
.946 .4165 Mdot
.946 .41789 Mdot
.946 .41823 Mdot
.946 .41827 Mdot
.946 .41863 Mdot
.946 .41872 Mdot
.946 .41959 Mdot
.946 .42021 Mdot
.946 .42056 Mdot
.946 .42128 Mdot
.946 .42245 Mdot
.946 .42285 Mdot
.946 .42329 Mdot
.946 .42387 Mdot
.946 .4247 Mdot
.946 .425 Mdot
.946 .42607 Mdot
.946 .42646 Mdot
.946 .42827 Mdot
.946 .42881 Mdot
.946 .42899 Mdot
.946 .42908 Mdot
.946 .42949 Mdot
.946 .42955 Mdot
.946 .43109 Mdot
.946 .43131 Mdot
.946 .43211 Mdot
.946 .43312 Mdot
.946 .43326 Mdot
.946 .43333 Mdot
.946 .43365 Mdot
.946 .43407 Mdot
.946 .43506 Mdot
.946 .43576 Mdot
.946 .436 Mdot
.946 .43606 Mdot
.946 .43671 Mdot
.946 .43714 Mdot
.946 .43721 Mdot
.946 .43727 Mdot
.946 .43743 Mdot
.946 .43748 Mdot
.946 .43757 Mdot
.946 .43785 Mdot
.946 .43799 Mdot
.946 .43909 Mdot
.946 .43911 Mdot
.946 .4393 Mdot
.946 .44023 Mdot
.946 .44049 Mdot
.946 .44056 Mdot
.946 .44102 Mdot
.946 .44115 Mdot
.946 .44135 Mdot
.946 .44262 Mdot
.946 .4427 Mdot
.946 .44277 Mdot
.946 .44301 Mdot
.946 .44309 Mdot
.946 .44341 Mdot
.946 .4437 Mdot
.946 .44388 Mdot
.946 .44415 Mdot
.946 .44447 Mdot
.946 .44628 Mdot
.946 .44659 Mdot
.946 .44707 Mdot
.946 .44742 Mdot
.946 .44766 Mdot
.946 .44772 Mdot
.946 .44777 Mdot
.946 .44928 Mdot
.946 .4493 Mdot
.946 .44958 Mdot
.946 .44966 Mdot
.946 .44968 Mdot
.946 .45029 Mdot
.946 .45048 Mdot
.946 .45197 Mdot
.946 .45236 Mdot
.946 .45253 Mdot
.946 .45376 Mdot
.946 .45526 Mdot
.946 .4553 Mdot
.946 .45569 Mdot
.946 .45601 Mdot
.946 .45623 Mdot
.946 .4573 Mdot
.946 .45738 Mdot
.946 .45859 Mdot
.946 .45896 Mdot
.946 .45901 Mdot
.946 .45907 Mdot
.946 .46 Mdot
.946 .46001 Mdot
.946 .46009 Mdot
.946 .46027 Mdot
.946 .46092 Mdot
.946 .46215 Mdot
.946 .4623 Mdot
.946 .46254 Mdot
.946 .4632 Mdot
.946 .4635 Mdot
.946 .46361 Mdot
.946 .46363 Mdot
.946 .46364 Mdot
.946 .46379 Mdot
.946 .4638 Mdot
.946 .46454 Mdot
.946 .46474 Mdot
.946 .46495 Mdot
.946 .46516 Mdot
.946 .46524 Mdot
.946 .46546 Mdot
.946 .46604 Mdot
.946 .46836 Mdot
.946 .46861 Mdot
.946 .46865 Mdot
.946 .46951 Mdot
.946 .47003 Mdot
.946 .4706 Mdot
.946 .47083 Mdot
.946 .47091 Mdot
.946 .47105 Mdot
.946 .47186 Mdot
.946 .47252 Mdot
.946 .47256 Mdot
.946 .47361 Mdot
.946 .47441 Mdot
.946 .47679 Mdot
.946 .4772 Mdot
.946 .47748 Mdot
.946 .47763 Mdot
.946 .4786 Mdot
.946 .47876 Mdot
.946 .48003 Mdot
.946 .48028 Mdot
.946 .48102 Mdot
.946 .4816 Mdot
.946 .48161 Mdot
.946 .4837 Mdot
.946 .4839 Mdot
.946 .48462 Mdot
.946 .48479 Mdot
.946 .48492 Mdot
.946 .48665 Mdot
.946 .48667 Mdot
.946 .48764 Mdot
.946 .48773 Mdot
.946 .48779 Mdot
.946 .48879 Mdot
.946 .49038 Mdot
.946 .4911 Mdot
.946 .49157 Mdot
.946 .49182 Mdot
.946 .49184 Mdot
.946 .49205 Mdot
.946 .49271 Mdot
.946 .49282 Mdot
.946 .49297 Mdot
.946 .49303 Mdot
.946 .49306 Mdot
.946 .49355 Mdot
.946 .49375 Mdot
.946 .49386 Mdot
.946 .49404 Mdot
.946 .49409 Mdot
.946 .49466 Mdot
.946 .49513 Mdot
.946 .49516 Mdot
.946 .49633 Mdot
.946 .4967 Mdot
.946 .49686 Mdot
.946 .49837 Mdot
.946 .49853 Mdot
.946 .49859 Mdot
.946 .49861 Mdot
.946 .49945 Mdot
.946 .49979 Mdot
.946 .50061 Mdot
.946 .50104 Mdot
.946 .50138 Mdot
.946 .5015 Mdot
.946 .50167 Mdot
.946 .50179 Mdot
.946 .50204 Mdot
.946 .50207 Mdot
.946 .50234 Mdot
.946 .5027 Mdot
.946 .50281 Mdot
.946 .50307 Mdot
.946 .5038 Mdot
.946 .50404 Mdot
.946 .50418 Mdot
.946 .50498 Mdot
.946 .50506 Mdot
.946 .50546 Mdot
.946 .50548 Mdot
.946 .50618 Mdot
.946 .50925 Mdot
.946 .50928 Mdot
.946 .50955 Mdot
.946 .51031 Mdot
.946 .51049 Mdot
.946 .51064 Mdot
.946 .51065 Mdot
.946 .51098 Mdot
.946 .51128 Mdot
.946 .51149 Mdot
.946 .51233 Mdot
.946 .51307 Mdot
.946 .51319 Mdot
.946 .51384 Mdot
.946 .51413 Mdot
.946 .51489 Mdot
.946 .51566 Mdot
.946 .5157 Mdot
.946 .51637 Mdot
.946 .5168 Mdot
.946 .51729 Mdot
.946 .51757 Mdot
.946 .51768 Mdot
.946 .51872 Mdot
.946 .51899 Mdot
.946 .51906 Mdot
.946 .5192 Mdot
.946 .51958 Mdot
.946 .5196 Mdot
.946 .51969 Mdot
.946 .51984 Mdot
.946 .52008 Mdot
.946 .52019 Mdot
.946 .52116 Mdot
.946 .52274 Mdot
.946 .52282 Mdot
.946 .5229 Mdot
.946 .52351 Mdot
.946 .52377 Mdot
.946 .5244 Mdot
.946 .52493 Mdot
.946 .5251 Mdot
.946 .52542 Mdot
.946 .52624 Mdot
.946 .5271 Mdot
.946 .52735 Mdot
.946 .52804 Mdot
.946 .52828 Mdot
.946 .52932 Mdot
.946 .52964 Mdot
.946 .5301 Mdot
.946 .5312 Mdot
.946 .53145 Mdot
.946 .53166 Mdot
.946 .53166 Mdot
.946 .53211 Mdot
.946 .53222 Mdot
.946 .53228 Mdot
.946 .53229 Mdot
.946 .53241 Mdot
.946 .53257 Mdot
.946 .53261 Mdot
.946 .53272 Mdot
.946 .53287 Mdot
.946 .53374 Mdot
.946 .53374 Mdot
.946 .5341 Mdot
.946 .53423 Mdot
.946 .53574 Mdot
.946 .53594 Mdot
.946 .53616 Mdot
.946 .53633 Mdot
.946 .53708 Mdot
.946 .53765 Mdot
.946 .53817 Mdot
.946 .53826 Mdot
.946 .53837 Mdot
.946 .53846 Mdot
.946 .53893 Mdot
.946 .53908 Mdot
.946 .54012 Mdot
.946 .54096 Mdot
.946 .54171 Mdot
.946 .54199 Mdot
.946 .54224 Mdot
.946 .54226 Mdot
.946 .54229 Mdot
.946 .5432 Mdot
.946 .54344 Mdot
.946 .54509 Mdot
.946 .54555 Mdot
.946 .54596 Mdot
.946 .54611 Mdot
.946 .54627 Mdot
.946 .54688 Mdot
.946 .54803 Mdot
.946 .54876 Mdot
.946 .54945 Mdot
.946 .54956 Mdot
.946 .54991 Mdot
.946 .5506 Mdot
.946 .5508 Mdot
.946 .55105 Mdot
.946 .55108 Mdot
.946 .55136 Mdot
.946 .55151 Mdot
.946 .55201 Mdot
.946 .55221 Mdot
.946 .55249 Mdot
.946 .55252 Mdot
.946 .55363 Mdot
.946 .55366 Mdot
.946 .55457 Mdot
.946 .55469 Mdot
.946 .55475 Mdot
.946 .55482 Mdot
.946 .55495 Mdot
.946 .5552 Mdot
.946 .55533 Mdot
.946 .55533 Mdot
.946 .55627 Mdot
.946 .55634 Mdot
.946 .55742 Mdot
.946 .55796 Mdot
.946 .5581 Mdot
.946 .55844 Mdot
.946 .55874 Mdot
.946 .55934 Mdot
.946 .55997 Mdot
.946 .56135 Mdot
.946 .56271 Mdot
.946 .56391 Mdot
.946 .56446 Mdot
.946 .56503 Mdot
.946 .56531 Mdot
.946 .56669 Mdot
.946 .56676 Mdot
.946 .56737 Mdot
.946 .56798 Mdot
.946 .56856 Mdot
.946 .56887 Mdot
.946 .56908 Mdot
.946 .56908 Mdot
.946 .56926 Mdot
.946 .56956 Mdot
.946 .56964 Mdot
.946 .56965 Mdot
.946 .56991 Mdot
.946 .56992 Mdot
.946 .57091 Mdot
.946 .57097 Mdot
.948 .07297 Mdot
.948 .07497 Mdot
.948 .0782 Mdot
.948 .07866 Mdot
.948 .07867 Mdot
.948 .07935 Mdot
.948 .07942 Mdot
.948 .08034 Mdot
.948 .08066 Mdot
.948 .08141 Mdot
.948 .08219 Mdot
.948 .08283 Mdot
.948 .08294 Mdot
.948 .08325 Mdot
.948 .08363 Mdot
.948 .08434 Mdot
.948 .08454 Mdot
.948 .08504 Mdot
.948 .08512 Mdot
.948 .08726 Mdot
.948 .08736 Mdot
.948 .0888 Mdot
.948 .08988 Mdot
.948 .0903 Mdot
.948 .09497 Mdot
.948 .09554 Mdot
.948 .09617 Mdot
.948 .09636 Mdot
.948 .09772 Mdot
.948 .09907 Mdot
.948 .09913 Mdot
.948 .1017 Mdot
.948 .10194 Mdot
.948 .10255 Mdot
.948 .10339 Mdot
.948 .10344 Mdot
.948 .10348 Mdot
.948 .10534 Mdot
.948 .10632 Mdot
.948 .10639 Mdot
.948 .10902 Mdot
.948 .10913 Mdot
.948 .11062 Mdot
.948 .11107 Mdot
.948 .11123 Mdot
.948 .11126 Mdot
.948 .11302 Mdot
.948 .11491 Mdot
.948 .11613 Mdot
.948 .11657 Mdot
.948 .11803 Mdot
.948 .11946 Mdot
.948 .11997 Mdot
.948 .12062 Mdot
.948 .1207 Mdot
.948 .12171 Mdot
.948 .12258 Mdot
.948 .12386 Mdot
.948 .12401 Mdot
.948 .12516 Mdot
.948 .12618 Mdot
.948 .12657 Mdot
.948 .12699 Mdot
.948 .12896 Mdot
.948 .12913 Mdot
.948 .12967 Mdot
.948 .12999 Mdot
.948 .13153 Mdot
.948 .13175 Mdot
.948 .13243 Mdot
.948 .13347 Mdot
.948 .13508 Mdot
.948 .13596 Mdot
.948 .13596 Mdot
.948 .13597 Mdot
.948 .13656 Mdot
.948 .13688 Mdot
.948 .13727 Mdot
.948 .13739 Mdot
.948 .13774 Mdot
.948 .13914 Mdot
.948 .13971 Mdot
.948 .13974 Mdot
.948 .14033 Mdot
.948 .14041 Mdot
.948 .14118 Mdot
.948 .1412 Mdot
.948 .14131 Mdot
.948 .14264 Mdot
.948 .14294 Mdot
.948 .14338 Mdot
.948 .14361 Mdot
.948 .14386 Mdot
.948 .14406 Mdot
.948 .14442 Mdot
.948 .14466 Mdot
.948 .14538 Mdot
.948 .14598 Mdot
.948 .14602 Mdot
.948 .14672 Mdot
.948 .14696 Mdot
.948 .1471 Mdot
.948 .1476 Mdot
.948 .1476 Mdot
.948 .14806 Mdot
.948 .1482 Mdot
.948 .14926 Mdot
.948 .14933 Mdot
.948 .1504 Mdot
.948 .15209 Mdot
.948 .15226 Mdot
.948 .15245 Mdot
.948 .15407 Mdot
.948 .15422 Mdot
.948 .15518 Mdot
.948 .15563 Mdot
.948 .1558 Mdot
.948 .15649 Mdot
.948 .1571 Mdot
.948 .15723 Mdot
.948 .15803 Mdot
.948 .15813 Mdot
.948 .15836 Mdot
.948 .15909 Mdot
.948 .15957 Mdot
.948 .15957 Mdot
.948 .16078 Mdot
.948 .16196 Mdot
.948 .16248 Mdot
.948 .16279 Mdot
.948 .163 Mdot
.948 .16395 Mdot
.948 .16581 Mdot
.948 .16607 Mdot
.948 .16688 Mdot
.948 .16697 Mdot
.948 .16706 Mdot
.948 .1678 Mdot
.948 .16796 Mdot
.948 .16819 Mdot
.948 .16851 Mdot
.948 .16859 Mdot
.948 .16915 Mdot
.948 .16934 Mdot
.948 .16945 Mdot
.948 .16952 Mdot
.948 .16999 Mdot
.948 .17139 Mdot
.948 .17166 Mdot
.948 .17187 Mdot
.948 .17209 Mdot
.948 .17285 Mdot
.948 .17374 Mdot
.948 .17414 Mdot
.948 .17456 Mdot
.948 .17465 Mdot
.948 .17477 Mdot
.948 .17478 Mdot
.948 .17521 Mdot
.948 .17561 Mdot
.948 .17583 Mdot
.948 .17592 Mdot
.948 .17713 Mdot
.948 .17964 Mdot
.948 .1801 Mdot
.948 .18126 Mdot
.948 .18221 Mdot
.948 .18244 Mdot
.948 .18284 Mdot
.948 .18294 Mdot
.948 .18302 Mdot
.948 .18344 Mdot
.948 .18352 Mdot
.948 .18366 Mdot
.948 .18509 Mdot
.948 .18634 Mdot
.948 .18655 Mdot
.948 .18839 Mdot
.948 .18852 Mdot
.948 .18995 Mdot
.948 .19206 Mdot
.948 .19244 Mdot
.948 .19352 Mdot
.948 .19373 Mdot
.948 .1941 Mdot
.948 .19453 Mdot
.948 .19474 Mdot
.948 .19581 Mdot
.948 .19583 Mdot
.948 .19622 Mdot
.948 .19656 Mdot
.948 .19687 Mdot
.948 .19698 Mdot
.948 .19712 Mdot
.948 .1974 Mdot
.948 .19772 Mdot
.948 .19776 Mdot
.948 .2011 Mdot
.948 .20215 Mdot
.948 .20409 Mdot
.948 .20469 Mdot
.948 .20504 Mdot
.948 .20682 Mdot
.948 .20699 Mdot
.948 .2078 Mdot
.948 .20783 Mdot
.948 .20852 Mdot
.948 .20922 Mdot
.948 .20924 Mdot
.948 .21061 Mdot
.948 .2107 Mdot
.948 .21085 Mdot
.948 .21119 Mdot
.948 .21154 Mdot
.948 .21163 Mdot
.948 .21331 Mdot
.948 .21393 Mdot
.948 .21427 Mdot
.948 .21433 Mdot
.948 .21478 Mdot
.948 .21524 Mdot
.948 .21552 Mdot
.948 .21566 Mdot
.948 .21576 Mdot
.948 .21586 Mdot
.948 .21624 Mdot
.948 .21694 Mdot
.948 .21758 Mdot
.948 .21824 Mdot
.948 .21923 Mdot
.948 .22123 Mdot
.948 .22158 Mdot
.948 .22165 Mdot
.948 .22194 Mdot
.948 .22347 Mdot
.948 .22363 Mdot
.948 .22379 Mdot
.948 .22412 Mdot
.948 .22447 Mdot
.948 .22537 Mdot
.948 .22606 Mdot
.948 .22666 Mdot
.948 .22676 Mdot
.948 .2268 Mdot
.948 .22755 Mdot
.948 .22757 Mdot
.948 .22758 Mdot
.948 .23024 Mdot
.948 .23097 Mdot
.948 .23116 Mdot
.948 .23132 Mdot
.948 .23164 Mdot
.948 .23191 Mdot
.948 .23202 Mdot
.948 .23257 Mdot
.948 .23267 Mdot
.948 .23327 Mdot
.948 .23359 Mdot
.948 .23423 Mdot
.948 .23439 Mdot
.948 .23444 Mdot
.948 .23514 Mdot
.948 .2362 Mdot
.948 .23642 Mdot
.948 .23661 Mdot
.948 .23782 Mdot
.948 .2379 Mdot
.948 .23804 Mdot
.948 .23836 Mdot
.948 .2386 Mdot
.948 .23894 Mdot
.948 .23947 Mdot
.948 .23987 Mdot
.948 .2427 Mdot
.948 .24293 Mdot
.948 .24459 Mdot
.948 .2446 Mdot
.948 .24462 Mdot
.948 .24574 Mdot
.948 .24633 Mdot
.948 .24662 Mdot
.948 .24677 Mdot
.948 .24693 Mdot
.948 .24707 Mdot
.948 .24731 Mdot
.948 .2476 Mdot
.948 .24797 Mdot
.948 .24837 Mdot
.948 .24843 Mdot
.948 .24924 Mdot
.948 .24955 Mdot
.948 .25062 Mdot
.948 .25116 Mdot
.948 .25123 Mdot
.948 .25148 Mdot
.948 .25169 Mdot
.948 .2517 Mdot
.948 .25177 Mdot
.948 .25189 Mdot
.948 .25238 Mdot
.948 .25288 Mdot
.948 .25304 Mdot
.948 .25307 Mdot
.948 .25382 Mdot
.948 .25397 Mdot
.948 .25448 Mdot
.948 .2545 Mdot
.948 .25452 Mdot
.948 .25473 Mdot
.948 .25476 Mdot
.948 .2548 Mdot
.948 .25572 Mdot
.948 .25632 Mdot
.948 .25726 Mdot
.948 .25762 Mdot
.948 .25782 Mdot
.948 .25867 Mdot
.948 .25909 Mdot
.948 .25936 Mdot
.948 .25957 Mdot
.948 .25976 Mdot
.948 .25996 Mdot
.948 .26008 Mdot
.948 .2601 Mdot
.948 .26064 Mdot
.948 .26086 Mdot
.948 .26109 Mdot
.948 .26137 Mdot
.948 .26246 Mdot
.948 .2636 Mdot
.948 .26366 Mdot
.948 .26477 Mdot
.948 .26499 Mdot
.948 .26546 Mdot
.948 .26572 Mdot
.948 .26667 Mdot
.948 .26667 Mdot
.948 .26692 Mdot
.948 .26753 Mdot
.948 .26781 Mdot
.948 .26833 Mdot
.948 .26982 Mdot
.948 .26992 Mdot
.948 .26995 Mdot
.948 .27022 Mdot
.948 .27035 Mdot
.948 .27046 Mdot
.948 .27113 Mdot
.948 .27122 Mdot
.948 .27132 Mdot
.948 .27136 Mdot
.948 .27196 Mdot
.948 .2732 Mdot
.948 .27374 Mdot
.948 .27517 Mdot
.948 .27549 Mdot
.948 .2755 Mdot
.948 .27586 Mdot
.948 .27644 Mdot
.948 .27654 Mdot
.948 .27713 Mdot
.948 .27892 Mdot
.948 .27894 Mdot
.948 .27922 Mdot
.948 .2807 Mdot
.948 .28103 Mdot
.948 .28112 Mdot
.948 .28135 Mdot
.948 .28141 Mdot
.948 .28189 Mdot
.948 .28216 Mdot
.948 .28222 Mdot
.948 .28268 Mdot
.948 .28283 Mdot
.948 .28286 Mdot
.948 .28307 Mdot
.948 .28318 Mdot
.948 .28329 Mdot
.948 .28352 Mdot
.948 .28468 Mdot
.948 .28492 Mdot
.948 .28524 Mdot
.948 .28644 Mdot
.948 .28663 Mdot
.948 .28707 Mdot
.948 .28845 Mdot
.948 .28909 Mdot
.948 .28935 Mdot
.948 .28936 Mdot
.948 .29002 Mdot
.948 .29021 Mdot
.948 .29069 Mdot
.948 .29165 Mdot
.948 .29284 Mdot
.948 .29313 Mdot
.948 .29332 Mdot
.948 .29338 Mdot
.948 .2939 Mdot
.948 .29465 Mdot
.948 .29476 Mdot
.948 .29487 Mdot
.948 .29547 Mdot
.948 .29587 Mdot
.948 .29611 Mdot
.948 .29714 Mdot
.948 .29767 Mdot
.948 .298 Mdot
.948 .29853 Mdot
.948 .29902 Mdot
.948 .29907 Mdot
.948 .29964 Mdot
.948 .3004 Mdot
.948 .30067 Mdot
.948 .30118 Mdot
.948 .30168 Mdot
.948 .30239 Mdot
.948 .30279 Mdot
.948 .30322 Mdot
.948 .30339 Mdot
.948 .30355 Mdot
.948 .30497 Mdot
.948 .30527 Mdot
.948 .3057 Mdot
.948 .30631 Mdot
.948 .30645 Mdot
.948 .30681 Mdot
.948 .3069 Mdot
.948 .30693 Mdot
.948 .30732 Mdot
.948 .30753 Mdot
.948 .30788 Mdot
.948 .30809 Mdot
.948 .30822 Mdot
.948 .30912 Mdot
.948 .30972 Mdot
.948 .3113 Mdot
.948 .3115 Mdot
.948 .31177 Mdot
.948 .31229 Mdot
.948 .31269 Mdot
.948 .31288 Mdot
.948 .3131 Mdot
.948 .31372 Mdot
.948 .31454 Mdot
.948 .31623 Mdot
.948 .31698 Mdot
.948 .31778 Mdot
.948 .31795 Mdot
.948 .31818 Mdot
.948 .3182 Mdot
.948 .31902 Mdot
.948 .31978 Mdot
.948 .3202 Mdot
.948 .32037 Mdot
.948 .32185 Mdot
.948 .32265 Mdot
.948 .32279 Mdot
.948 .32298 Mdot
.948 .323 Mdot
.948 .32388 Mdot
.948 .32534 Mdot
.948 .32558 Mdot
.948 .32724 Mdot
.948 .32741 Mdot
.948 .3275 Mdot
.948 .32829 Mdot
.948 .32846 Mdot
.948 .32848 Mdot
.948 .32873 Mdot
.948 .32931 Mdot
.948 .3296 Mdot
.948 .33048 Mdot
.948 .33048 Mdot
.948 .33096 Mdot
.948 .33126 Mdot
.948 .33173 Mdot
.948 .33228 Mdot
.948 .33272 Mdot
.948 .33313 Mdot
.948 .33341 Mdot
.948 .33348 Mdot
.948 .33368 Mdot
.948 .33381 Mdot
.948 .33381 Mdot
.948 .33462 Mdot
.948 .33477 Mdot
.948 .33503 Mdot
.948 .33555 Mdot
.948 .33562 Mdot
.948 .33589 Mdot
.948 .3363 Mdot
.948 .3371 Mdot
.948 .33775 Mdot
.948 .33786 Mdot
.948 .33816 Mdot
.948 .33834 Mdot
.948 .34011 Mdot
.948 .34051 Mdot
.948 .34091 Mdot
.948 .34126 Mdot
.948 .34342 Mdot
.948 .34359 Mdot
.948 .34401 Mdot
.948 .34419 Mdot
.948 .34426 Mdot
.948 .34646 Mdot
.948 .34696 Mdot
.948 .34723 Mdot
.948 .34762 Mdot
.948 .34763 Mdot
.948 .34829 Mdot
.948 .3493 Mdot
.948 .34977 Mdot
.948 .35013 Mdot
.948 .35096 Mdot
.948 .35163 Mdot
.948 .35168 Mdot
.948 .35212 Mdot
.948 .3525 Mdot
.948 .35347 Mdot
.948 .35373 Mdot
.948 .35397 Mdot
.948 .35412 Mdot
.948 .35458 Mdot
.948 .35464 Mdot
.948 .35483 Mdot
.948 .35519 Mdot
.948 .35558 Mdot
.948 .35564 Mdot
.948 .35589 Mdot
.948 .35604 Mdot
.948 .35807 Mdot
.948 .35811 Mdot
.948 .35852 Mdot
.948 .35884 Mdot
.948 .35938 Mdot
.948 .35949 Mdot
.948 .36007 Mdot
.948 .36022 Mdot
.948 .36029 Mdot
.948 .36056 Mdot
.948 .36109 Mdot
.948 .36168 Mdot
.948 .36177 Mdot
.948 .36199 Mdot
.948 .36407 Mdot
.948 .36451 Mdot
.948 .36484 Mdot
.948 .36606 Mdot
.948 .36806 Mdot
.948 .3681 Mdot
.948 .36811 Mdot
.948 .3682 Mdot
.948 .3701 Mdot
.948 .37029 Mdot
.948 .37088 Mdot
.948 .37103 Mdot
.948 .37139 Mdot
.948 .3726 Mdot
.948 .37299 Mdot
.948 .37354 Mdot
.948 .37491 Mdot
.948 .37558 Mdot
.948 .37602 Mdot
.948 .37607 Mdot
.948 .37895 Mdot
.948 .37922 Mdot
.948 .37927 Mdot
.948 .37927 Mdot
.948 .37999 Mdot
.948 .38053 Mdot
.948 .3808 Mdot
.948 .38087 Mdot
.948 .38111 Mdot
.948 .3817 Mdot
.948 .38209 Mdot
.948 .38217 Mdot
.948 .38228 Mdot
.948 .38276 Mdot
.948 .38286 Mdot
.948 .38341 Mdot
.948 .38349 Mdot
.948 .38354 Mdot
.948 .38435 Mdot
.948 .38601 Mdot
.948 .38612 Mdot
.948 .38631 Mdot
.948 .38659 Mdot
.948 .38724 Mdot
.948 .38789 Mdot
.948 .38806 Mdot
.948 .38834 Mdot
.948 .38939 Mdot
.948 .38963 Mdot
.948 .3907 Mdot
.948 .39082 Mdot
.948 .39091 Mdot
.948 .39125 Mdot
.948 .39243 Mdot
.948 .39307 Mdot
.948 .39318 Mdot
.948 .39404 Mdot
.948 .39491 Mdot
.948 .39513 Mdot
.948 .39544 Mdot
.948 .39571 Mdot
.948 .3959 Mdot
.948 .39608 Mdot
.948 .39634 Mdot
.948 .3968 Mdot
.948 .39811 Mdot
.948 .39814 Mdot
.948 .39934 Mdot
.948 .39968 Mdot
.948 .4006 Mdot
.948 .40164 Mdot
.948 .40247 Mdot
.948 .4034 Mdot
.948 .40404 Mdot
.948 .40626 Mdot
.948 .40631 Mdot
.948 .40637 Mdot
.948 .40694 Mdot
.948 .40706 Mdot
.948 .40762 Mdot
.948 .40885 Mdot
.948 .40972 Mdot
.948 .41022 Mdot
.948 .41051 Mdot
.948 .41056 Mdot
.948 .41081 Mdot
.948 .41091 Mdot
.948 .41112 Mdot
.948 .41143 Mdot
.948 .41174 Mdot
.948 .41202 Mdot
.948 .4124 Mdot
.948 .41243 Mdot
.948 .41409 Mdot
.948 .41412 Mdot
.948 .41542 Mdot
.948 .41572 Mdot
.948 .41592 Mdot
.948 .41656 Mdot
.948 .41675 Mdot
.948 .41682 Mdot
.948 .41714 Mdot
.948 .41824 Mdot
.948 .41829 Mdot
.948 .41832 Mdot
.948 .41937 Mdot
.948 .42001 Mdot
.948 .42019 Mdot
.948 .42042 Mdot
.948 .42245 Mdot
.948 .42289 Mdot
.948 .42335 Mdot
.948 .42473 Mdot
.948 .4249 Mdot
.948 .4251 Mdot
.948 .42539 Mdot
.948 .42542 Mdot
.948 .42575 Mdot
.948 .42601 Mdot
.948 .42652 Mdot
.948 .42672 Mdot
.948 .42698 Mdot
.948 .42777 Mdot
.948 .42796 Mdot
.948 .42821 Mdot
.948 .42874 Mdot
.948 .42909 Mdot
.948 .42909 Mdot
.948 .4293 Mdot
.948 .42971 Mdot
.948 .43091 Mdot
.948 .43122 Mdot
.948 .43131 Mdot
.948 .43245 Mdot
.948 .43263 Mdot
.948 .43399 Mdot
.948 .43408 Mdot
.948 .43424 Mdot
.948 .43464 Mdot
.948 .43507 Mdot
.948 .43528 Mdot
.948 .43542 Mdot
.948 .43546 Mdot
.948 .43638 Mdot
.948 .43659 Mdot
.948 .43674 Mdot
.948 .43748 Mdot
.948 .43772 Mdot
.948 .43788 Mdot
.948 .43813 Mdot
.948 .4386 Mdot
.948 .43875 Mdot
.948 .43906 Mdot
.948 .43919 Mdot
.948 .4392 Mdot
.948 .43971 Mdot
.948 .43984 Mdot
.948 .44072 Mdot
.948 .44084 Mdot
.948 .44162 Mdot
.948 .44208 Mdot
.948 .44209 Mdot
.948 .44219 Mdot
.948 .44269 Mdot
.948 .44697 Mdot
.948 .44742 Mdot
.948 .44815 Mdot
.948 .44825 Mdot
.948 .44908 Mdot
.948 .45035 Mdot
.948 .45056 Mdot
.948 .45057 Mdot
.948 .45062 Mdot
.948 .45274 Mdot
.948 .45295 Mdot
.948 .45386 Mdot
.948 .454 Mdot
.948 .4544 Mdot
.948 .4547 Mdot
.948 .45473 Mdot
.948 .45499 Mdot
.948 .45526 Mdot
.948 .45572 Mdot
.948 .45626 Mdot
.948 .45697 Mdot
.948 .45704 Mdot
.948 .4577 Mdot
.948 .45773 Mdot
.948 .45783 Mdot
.948 .45799 Mdot
.948 .45912 Mdot
.948 .45938 Mdot
.948 .45947 Mdot
.948 .45997 Mdot
.948 .46199 Mdot
.948 .46302 Mdot
.948 .46308 Mdot
.948 .46314 Mdot
.948 .46325 Mdot
.948 .46326 Mdot
.948 .46334 Mdot
.948 .46362 Mdot
.948 .46402 Mdot
.948 .46405 Mdot
.948 .46417 Mdot
.948 .46439 Mdot
.948 .46533 Mdot
.948 .46627 Mdot
.948 .46658 Mdot
.948 .46664 Mdot
.948 .46713 Mdot
.948 .46806 Mdot
.948 .46835 Mdot
.948 .46932 Mdot
.948 .46934 Mdot
.948 .46939 Mdot
.948 .46944 Mdot
.948 .46979 Mdot
.948 .46985 Mdot
.948 .46992 Mdot
.948 .47007 Mdot
.948 .47091 Mdot
.948 .47166 Mdot
.948 .47279 Mdot
.948 .47459 Mdot
.948 .47485 Mdot
.948 .47525 Mdot
.948 .47526 Mdot
.948 .47543 Mdot
.948 .47564 Mdot
.948 .47657 Mdot
.948 .47725 Mdot
.948 .47757 Mdot
.948 .47805 Mdot
.948 .47807 Mdot
.948 .47821 Mdot
.948 .47849 Mdot
.948 .47857 Mdot
.948 .47896 Mdot
.948 .47933 Mdot
.948 .47959 Mdot
.948 .47969 Mdot
.948 .4798 Mdot
.948 .47994 Mdot
.948 .47997 Mdot
.948 .48082 Mdot
.948 .48098 Mdot
.948 .48141 Mdot
.948 .48144 Mdot
.948 .48185 Mdot
.948 .4822 Mdot
.948 .48228 Mdot
.948 .48237 Mdot
.948 .48443 Mdot
.948 .48614 Mdot
.948 .48642 Mdot
.948 .48659 Mdot
.948 .48672 Mdot
.948 .48689 Mdot
.948 .48701 Mdot
.948 .48775 Mdot
.948 .48842 Mdot
.948 .48879 Mdot
.948 .48882 Mdot
.948 .4889 Mdot
.948 .48924 Mdot
.948 .48977 Mdot
.948 .49007 Mdot
.948 .49012 Mdot
.948 .49052 Mdot
.948 .49062 Mdot
.948 .491 Mdot
.948 .49241 Mdot
.948 .49243 Mdot
.948 .49284 Mdot
.948 .49289 Mdot
.948 .49357 Mdot
.948 .49405 Mdot
.948 .49441 Mdot
.948 .49449 Mdot
.948 .49458 Mdot
.948 .49557 Mdot
.948 .49576 Mdot
.948 .49733 Mdot
.948 .49802 Mdot
.948 .49839 Mdot
.948 .49859 Mdot
.948 .49864 Mdot
.948 .49892 Mdot
.948 .49916 Mdot
.948 .4994 Mdot
.948 .49961 Mdot
.948 .50082 Mdot
.948 .50087 Mdot
.948 .50105 Mdot
.948 .50123 Mdot
.948 .50131 Mdot
.948 .50208 Mdot
.948 .50209 Mdot
.948 .50246 Mdot
.948 .50284 Mdot
.948 .50335 Mdot
.948 .50429 Mdot
.948 .5048 Mdot
.948 .50582 Mdot
.948 .50847 Mdot
.948 .50855 Mdot
.948 .50861 Mdot
.948 .50895 Mdot
.948 .50915 Mdot
.948 .50916 Mdot
.948 .50973 Mdot
.948 .50984 Mdot
.948 .51006 Mdot
.948 .51094 Mdot
.948 .51114 Mdot
.948 .51226 Mdot
.948 .51416 Mdot
.948 .51482 Mdot
.948 .51557 Mdot
.948 .51565 Mdot
.948 .51569 Mdot
.948 .51622 Mdot
.948 .51634 Mdot
.948 .51902 Mdot
.948 .51965 Mdot
.948 .5197 Mdot
.948 .51982 Mdot
.948 .52003 Mdot
.948 .52026 Mdot
.948 .52037 Mdot
.948 .52059 Mdot
.948 .5208 Mdot
.948 .52127 Mdot
.948 .52179 Mdot
.948 .5219 Mdot
.948 .52204 Mdot
.948 .52278 Mdot
.948 .52307 Mdot
.948 .52313 Mdot
.948 .52352 Mdot
.948 .52356 Mdot
.948 .52373 Mdot
.948 .52394 Mdot
.948 .52433 Mdot
.948 .52437 Mdot
.948 .52485 Mdot
.948 .52499 Mdot
.948 .52597 Mdot
.948 .52647 Mdot
.948 .52658 Mdot
.948 .52675 Mdot
.948 .52701 Mdot
.948 .52764 Mdot
.948 .52828 Mdot
.948 .52828 Mdot
.948 .52853 Mdot
.948 .52891 Mdot
.948 .52904 Mdot
.948 .52958 Mdot
.948 .5299 Mdot
.948 .53026 Mdot
.948 .53036 Mdot
.948 .5311 Mdot
.948 .53118 Mdot
.948 .53222 Mdot
.948 .53312 Mdot
.948 .53368 Mdot
.948 .53371 Mdot
.948 .53459 Mdot
.948 .53459 Mdot
.948 .53493 Mdot
.948 .53543 Mdot
.948 .53544 Mdot
.948 .53627 Mdot
.948 .5367 Mdot
.948 .53682 Mdot
.948 .53705 Mdot
.948 .53791 Mdot
.948 .53797 Mdot
.948 .53838 Mdot
.948 .53843 Mdot
.948 .53875 Mdot
.948 .53979 Mdot
.948 .54025 Mdot
.948 .54041 Mdot
.948 .54073 Mdot
.948 .54204 Mdot
.948 .54259 Mdot
.948 .54295 Mdot
.948 .54307 Mdot
.948 .54388 Mdot
.948 .54405 Mdot
.948 .54433 Mdot
.948 .54546 Mdot
.948 .54568 Mdot
.948 .54589 Mdot
.948 .54703 Mdot
.948 .54711 Mdot
.948 .54779 Mdot
.948 .54825 Mdot
.948 .54878 Mdot
.948 .54882 Mdot
.948 .54917 Mdot
.948 .54943 Mdot
.948 .55019 Mdot
.948 .55096 Mdot
.948 .55119 Mdot
.948 .55183 Mdot
.948 .55283 Mdot
.948 .55376 Mdot
.948 .55377 Mdot
.948 .55386 Mdot
.948 .55409 Mdot
.948 .55488 Mdot
.948 .55494 Mdot
.948 .55633 Mdot
.948 .55636 Mdot
.948 .55688 Mdot
.948 .55786 Mdot
.948 .55788 Mdot
.948 .55791 Mdot
.948 .55835 Mdot
.948 .55867 Mdot
.948 .5588 Mdot
.948 .56015 Mdot
.948 .56019 Mdot
.948 .5609 Mdot
.948 .56162 Mdot
.948 .56172 Mdot
.948 .56205 Mdot
.948 .56235 Mdot
.948 .56481 Mdot
.948 .56503 Mdot
.948 .5656 Mdot
.948 .56636 Mdot
.948 .56642 Mdot
.948 .56754 Mdot
.948 .56759 Mdot
.948 .56785 Mdot
.948 .56796 Mdot
.948 .56833 Mdot
.948 .56853 Mdot
.948 .5687 Mdot
.948 .56875 Mdot
.948 .56909 Mdot
.948 .5695 Mdot
.948 .5699 Mdot
.948 .57007 Mdot
.948 .57055 Mdot
.948 .57059 Mdot
.948 .57095 Mdot
.948 .57095 Mdot
.948 .57119 Mdot
.948 .5729 Mdot
.948 .57395 Mdot
.95 .07148 Mdot
.95 .07177 Mdot
.95 .07252 Mdot
.95 .07295 Mdot
.95 .07303 Mdot
.95 .07306 Mdot
.95 .07414 Mdot
.95 .07453 Mdot
.95 .07465 Mdot
.95 .07488 Mdot
.95 .07569 Mdot
.95 .07633 Mdot
.95 .07676 Mdot
.95 .07786 Mdot
.95 .07856 Mdot
.95 .07946 Mdot
.95 .08037 Mdot
.95 .08156 Mdot
.95 .08156 Mdot
.95 .08194 Mdot
.95 .08392 Mdot
.95 .08396 Mdot
.95 .08465 Mdot
.95 .08493 Mdot
.95 .08603 Mdot
.95 .08697 Mdot
.95 .08847 Mdot
.95 .0888 Mdot
.95 .09114 Mdot
.95 .09174 Mdot
.95 .09258 Mdot
.95 .09534 Mdot
.95 .09744 Mdot
.95 .09889 Mdot
.95 .10001 Mdot
.95 .10109 Mdot
.95 .10174 Mdot
.95 .10237 Mdot
.95 .10291 Mdot
.95 .10332 Mdot
.95 .10534 Mdot
.95 .10609 Mdot
.95 .10626 Mdot
.95 .1082 Mdot
.95 .10835 Mdot
.95 .1109 Mdot
.95 .11139 Mdot
.95 .11221 Mdot
.95 .11401 Mdot
.95 .11447 Mdot
.95 .11674 Mdot
.95 .11742 Mdot
.95 .11933 Mdot
.95 .11937 Mdot
.95 .12089 Mdot
.95 .12242 Mdot
.95 .12257 Mdot
.95 .12312 Mdot
.95 .12413 Mdot
.95 .12455 Mdot
.95 .12536 Mdot
.95 .12551 Mdot
.95 .12556 Mdot
.95 .12762 Mdot
.95 .12836 Mdot
.95 .12859 Mdot
.95 .12902 Mdot
.95 .13057 Mdot
.95 .13095 Mdot
.95 .13127 Mdot
.95 .13152 Mdot
.95 .13178 Mdot
.95 .13189 Mdot
.95 .13259 Mdot
.95 .13346 Mdot
.95 .13362 Mdot
.95 .1347 Mdot
.95 .13504 Mdot
.95 .13516 Mdot
.95 .13536 Mdot
.95 .13601 Mdot
.95 .13627 Mdot
.95 .13773 Mdot
.95 .13789 Mdot
.95 .13861 Mdot
.95 .13895 Mdot
.95 .13897 Mdot
.95 .13945 Mdot
.95 .13962 Mdot
.95 .13995 Mdot
.95 .14089 Mdot
.95 .14165 Mdot
.95 .14171 Mdot
.95 .14172 Mdot
.95 .14211 Mdot
.95 .14244 Mdot
.95 .14291 Mdot
.95 .14384 Mdot
.95 .14533 Mdot
.95 .14621 Mdot
.95 .14629 Mdot
.95 .14654 Mdot
.95 .1475 Mdot
.95 .1476 Mdot
.95 .14813 Mdot
.95 .14818 Mdot
.95 .14863 Mdot
.95 .14903 Mdot
.95 .15022 Mdot
.95 .15113 Mdot
.95 .15133 Mdot
.95 .152 Mdot
.95 .15232 Mdot
.95 .15373 Mdot
.95 .15373 Mdot
.95 .15411 Mdot
.95 .15438 Mdot
.95 .15441 Mdot
.95 .15485 Mdot
.95 .15516 Mdot
.95 .1553 Mdot
.95 .15542 Mdot
.95 .15547 Mdot
.95 .15679 Mdot
.95 .15787 Mdot
.95 .15931 Mdot
.95 .15993 Mdot
.95 .16002 Mdot
.95 .16008 Mdot
.95 .16018 Mdot
.95 .16055 Mdot
.95 .16083 Mdot
.95 .16106 Mdot
.95 .16115 Mdot
.95 .16266 Mdot
.95 .16366 Mdot
.95 .16536 Mdot
.95 .1657 Mdot
.95 .16608 Mdot
.95 .16639 Mdot
.95 .1679 Mdot
.95 .16964 Mdot
.95 .17023 Mdot
.95 .17046 Mdot
.95 .17052 Mdot
.95 .17069 Mdot
.95 .17137 Mdot
.95 .17154 Mdot
.95 .17189 Mdot
.95 .17233 Mdot
.95 .17439 Mdot
.95 .17448 Mdot
.95 .17466 Mdot
.95 .17501 Mdot
.95 .17589 Mdot
.95 .17677 Mdot
.95 .1775 Mdot
.95 .17771 Mdot
.95 .17775 Mdot
.95 .17883 Mdot
.95 .17952 Mdot
.95 .18006 Mdot
.95 .18126 Mdot
.95 .18186 Mdot
.95 .18212 Mdot
.95 .18216 Mdot
.95 .18229 Mdot
.95 .18306 Mdot
.95 .1831 Mdot
.95 .18387 Mdot
.95 .18438 Mdot
.95 .18691 Mdot
.95 .18695 Mdot
.95 .1872 Mdot
.95 .18728 Mdot
.95 .18833 Mdot
.95 .18865 Mdot
.95 .18899 Mdot
.95 .18953 Mdot
.95 .18993 Mdot
.95 .19059 Mdot
.95 .19073 Mdot
.95 .19181 Mdot
.95 .19197 Mdot
.95 .19233 Mdot
.95 .19262 Mdot
.95 .19404 Mdot
.95 .19583 Mdot
.95 .19669 Mdot
.95 .19683 Mdot
.95 .19705 Mdot
.95 .19715 Mdot
.95 .19747 Mdot
.95 .19806 Mdot
.95 .1983 Mdot
.95 .1984 Mdot
.95 .19858 Mdot
.95 .19893 Mdot
.95 .19996 Mdot
.95 .19996 Mdot
.95 .2012 Mdot
.95 .20123 Mdot
.95 .20337 Mdot
.95 .20424 Mdot
.95 .20496 Mdot
.95 .20516 Mdot
.95 .20553 Mdot
.95 .20623 Mdot
.95 .20632 Mdot
.95 .20769 Mdot
.95 .20821 Mdot
.95 .20841 Mdot
.95 .20856 Mdot
.95 .20934 Mdot
.95 .20985 Mdot
.95 .21218 Mdot
.95 .21318 Mdot
.95 .21329 Mdot
.95 .21348 Mdot
.95 .21355 Mdot
.95 .21439 Mdot
.95 .2162 Mdot
.95 .21645 Mdot
.95 .21714 Mdot
.95 .21822 Mdot
.95 .21935 Mdot
.95 .21964 Mdot
.95 .22017 Mdot
.95 .22022 Mdot
.95 .22055 Mdot
.95 .22056 Mdot
.95 .22069 Mdot
.95 .22084 Mdot
.95 .22167 Mdot
.95 .22204 Mdot
.95 .2226 Mdot
.95 .2234 Mdot
.95 .22414 Mdot
.95 .2242 Mdot
.95 .22473 Mdot
.95 .2248 Mdot
.95 .22485 Mdot
.95 .22494 Mdot
.95 .22522 Mdot
.95 .22533 Mdot
.95 .2261 Mdot
.95 .22671 Mdot
.95 .2281 Mdot
.95 .22923 Mdot
.95 .2293 Mdot
.95 .23063 Mdot
.95 .23107 Mdot
.95 .23144 Mdot
.95 .23169 Mdot
.95 .2319 Mdot
.95 .23204 Mdot
.95 .23288 Mdot
.95 .23311 Mdot
.95 .23317 Mdot
.95 .2332 Mdot
.95 .23372 Mdot
.95 .23374 Mdot
.95 .23382 Mdot
.95 .23483 Mdot
.95 .23556 Mdot
.95 .23584 Mdot
.95 .23586 Mdot
.95 .23617 Mdot
.95 .23665 Mdot
.95 .23714 Mdot
.95 .23734 Mdot
.95 .23769 Mdot
.95 .23779 Mdot
.95 .23858 Mdot
.95 .23869 Mdot
.95 .23978 Mdot
.95 .24033 Mdot
.95 .24043 Mdot
.95 .24064 Mdot
.95 .24268 Mdot
.95 .24333 Mdot
.95 .24343 Mdot
.95 .24356 Mdot
.95 .24394 Mdot
.95 .24411 Mdot
.95 .24518 Mdot
.95 .24567 Mdot
.95 .24813 Mdot
.95 .24845 Mdot
.95 .24874 Mdot
.95 .24889 Mdot
.95 .24895 Mdot
.95 .25001 Mdot
.95 .25011 Mdot
.95 .25077 Mdot
.95 .25079 Mdot
.95 .25158 Mdot
.95 .25172 Mdot
.95 .25203 Mdot
.95 .25245 Mdot
.95 .25265 Mdot
.95 .25352 Mdot
.95 .25407 Mdot
.95 .25445 Mdot
.95 .25503 Mdot
.95 .25589 Mdot
.95 .25597 Mdot
.95 .25597 Mdot
.95 .25601 Mdot
.95 .25602 Mdot
.95 .25633 Mdot
.95 .25653 Mdot
.95 .25676 Mdot
.95 .25681 Mdot
.95 .25718 Mdot
.95 .25738 Mdot
.95 .25829 Mdot
.95 .25937 Mdot
.95 .25961 Mdot
.95 .26004 Mdot
.95 .26034 Mdot
.95 .26168 Mdot
.95 .26187 Mdot
.95 .2627 Mdot
.95 .26288 Mdot
.95 .26343 Mdot
.95 .26345 Mdot
.95 .26453 Mdot
.95 .26455 Mdot
.95 .26455 Mdot
.95 .2647 Mdot
.95 .26471 Mdot
.95 .26473 Mdot
.95 .26502 Mdot
.95 .26512 Mdot
.95 .26519 Mdot
.95 .26578 Mdot
.95 .26701 Mdot
.95 .26703 Mdot
.95 .26719 Mdot
.95 .26812 Mdot
.95 .2682 Mdot
.95 .2683 Mdot
.95 .26915 Mdot
.95 .26941 Mdot
.95 .26991 Mdot
.95 .27022 Mdot
.95 .27157 Mdot
.95 .27162 Mdot
.95 .27217 Mdot
.95 .27356 Mdot
.95 .27391 Mdot
.95 .27429 Mdot
.95 .27469 Mdot
.95 .27555 Mdot
.95 .27617 Mdot
.95 .27646 Mdot
.95 .2765 Mdot
.95 .27669 Mdot
.95 .27742 Mdot
.95 .27822 Mdot
.95 .27884 Mdot
.95 .27885 Mdot
.95 .27892 Mdot
.95 .27957 Mdot
.95 .28006 Mdot
.95 .28007 Mdot
.95 .28013 Mdot
.95 .28057 Mdot
.95 .28082 Mdot
.95 .28096 Mdot
.95 .28156 Mdot
.95 .28178 Mdot
.95 .28183 Mdot
.95 .28206 Mdot
.95 .28214 Mdot
.95 .2834 Mdot
.95 .28349 Mdot
.95 .28466 Mdot
.95 .28496 Mdot
.95 .28517 Mdot
.95 .28557 Mdot
.95 .28587 Mdot
.95 .28624 Mdot
.95 .28671 Mdot
.95 .28738 Mdot
.95 .28802 Mdot
.95 .28844 Mdot
.95 .28945 Mdot
.95 .28971 Mdot
.95 .29006 Mdot
.95 .29027 Mdot
.95 .29062 Mdot
.95 .2908 Mdot
.95 .29081 Mdot
.95 .2909 Mdot
.95 .2911 Mdot
.95 .2918 Mdot
.95 .29186 Mdot
.95 .29233 Mdot
.95 .29276 Mdot
.95 .29293 Mdot
.95 .29302 Mdot
.95 .29581 Mdot
.95 .29759 Mdot
.95 .29772 Mdot
.95 .29986 Mdot
.95 .30094 Mdot
.95 .3016 Mdot
.95 .3019 Mdot
.95 .30231 Mdot
.95 .30289 Mdot
.95 .30365 Mdot
.95 .30405 Mdot
.95 .30577 Mdot
.95 .30585 Mdot
.95 .30604 Mdot
.95 .30754 Mdot
.95 .30773 Mdot
.95 .30804 Mdot
.95 .30815 Mdot
.95 .30907 Mdot
.95 .30909 Mdot
.95 .3095 Mdot
.95 .30998 Mdot
.95 .31018 Mdot
.95 .31033 Mdot
.95 .31063 Mdot
.95 .31074 Mdot
.95 .31077 Mdot
.95 .31084 Mdot
.95 .31106 Mdot
.95 .31211 Mdot
.95 .31236 Mdot
.95 .31269 Mdot
.95 .31269 Mdot
.95 .31279 Mdot
.95 .31334 Mdot
.95 .31393 Mdot
.95 .31419 Mdot
.95 .3146 Mdot
.95 .31469 Mdot
.95 .31551 Mdot
.95 .3181 Mdot
.95 .31828 Mdot
.95 .3186 Mdot
.95 .31871 Mdot
.95 .31928 Mdot
.95 .31948 Mdot
.95 .32007 Mdot
.95 .32011 Mdot
.95 .32082 Mdot
.95 .32095 Mdot
.95 .32118 Mdot
.95 .32243 Mdot
.95 .32262 Mdot
.95 .32315 Mdot
.95 .32316 Mdot
.95 .32401 Mdot
.95 .3244 Mdot
.95 .32448 Mdot
.95 .32653 Mdot
.95 .32711 Mdot
.95 .3275 Mdot
.95 .32784 Mdot
.95 .32886 Mdot
.95 .32946 Mdot
.95 .33035 Mdot
.95 .33069 Mdot
.95 .33114 Mdot
.95 .33127 Mdot
.95 .33196 Mdot
.95 .33229 Mdot
.95 .33268 Mdot
.95 .33279 Mdot
.95 .33286 Mdot
.95 .33287 Mdot
.95 .33308 Mdot
.95 .33311 Mdot
.95 .33442 Mdot
.95 .33447 Mdot
.95 .33457 Mdot
.95 .33465 Mdot
.95 .33543 Mdot
.95 .3361 Mdot
.95 .33618 Mdot
.95 .33709 Mdot
.95 .33731 Mdot
.95 .33738 Mdot
.95 .3384 Mdot
.95 .34081 Mdot
.95 .34103 Mdot
.95 .34188 Mdot
.95 .34195 Mdot
.95 .34245 Mdot
.95 .3426 Mdot
.95 .34327 Mdot
.95 .34434 Mdot
.95 .34458 Mdot
.95 .34462 Mdot
.95 .34468 Mdot
.95 .34496 Mdot
.95 .34503 Mdot
.95 .3452 Mdot
.95 .34583 Mdot
.95 .34687 Mdot
.95 .34692 Mdot
.95 .34703 Mdot
.95 .34725 Mdot
.95 .34763 Mdot
.95 .34808 Mdot
.95 .34887 Mdot
.95 .34915 Mdot
.95 .35054 Mdot
.95 .35108 Mdot
.95 .35119 Mdot
.95 .3515 Mdot
.95 .3516 Mdot
.95 .35218 Mdot
.95 .35235 Mdot
.95 .35273 Mdot
.95 .3529 Mdot
.95 .35328 Mdot
.95 .3546 Mdot
.95 .35543 Mdot
.95 .35543 Mdot
.95 .35618 Mdot
.95 .35883 Mdot
.95 .35904 Mdot
.95 .36032 Mdot
.95 .36047 Mdot
.95 .36074 Mdot
.95 .361 Mdot
.95 .361 Mdot
.95 .36116 Mdot
.95 .36123 Mdot
.95 .36134 Mdot
.95 .36194 Mdot
.95 .36307 Mdot
.95 .36353 Mdot
.95 .36372 Mdot
.95 .36406 Mdot
.95 .36472 Mdot
.95 .36534 Mdot
.95 .36619 Mdot
.95 .36668 Mdot
.95 .36669 Mdot
.95 .36716 Mdot
.95 .36788 Mdot
.95 .36815 Mdot
.95 .36903 Mdot
.95 .36909 Mdot
.95 .3692 Mdot
.95 .3697 Mdot
.95 .36988 Mdot
.95 .36999 Mdot
.95 .37035 Mdot
.95 .37253 Mdot
.95 .37316 Mdot
.95 .37432 Mdot
.95 .37482 Mdot
.95 .37487 Mdot
.95 .37534 Mdot
.95 .37542 Mdot
.95 .37572 Mdot
.95 .37618 Mdot
.95 .3762 Mdot
.95 .37655 Mdot
.95 .37674 Mdot
.95 .37706 Mdot
.95 .37724 Mdot
.95 .37727 Mdot
.95 .37749 Mdot
.95 .37859 Mdot
.95 .37877 Mdot
.95 .37941 Mdot
.95 .37961 Mdot
.95 .38136 Mdot
.95 .38186 Mdot
.95 .3823 Mdot
.95 .38236 Mdot
.95 .38273 Mdot
.95 .38301 Mdot
.95 .3845 Mdot
.95 .38518 Mdot
.95 .38548 Mdot
.95 .38556 Mdot
.95 .3872 Mdot
.95 .38785 Mdot
.95 .38855 Mdot
.95 .38955 Mdot
.95 .38991 Mdot
.95 .3901 Mdot
.95 .39153 Mdot
.95 .3918 Mdot
.95 .392 Mdot
.95 .39208 Mdot
.95 .39237 Mdot
.95 .39251 Mdot
.95 .39255 Mdot
.95 .39259 Mdot
.95 .39378 Mdot
.95 .39394 Mdot
.95 .39409 Mdot
.95 .39431 Mdot
.95 .39587 Mdot
.95 .3969 Mdot
.95 .39753 Mdot
.95 .398 Mdot
.95 .39815 Mdot
.95 .39932 Mdot
.95 .40039 Mdot
.95 .40101 Mdot
.95 .40137 Mdot
.95 .40169 Mdot
.95 .40287 Mdot
.95 .40353 Mdot
.95 .40407 Mdot
.95 .40489 Mdot
.95 .40509 Mdot
.95 .40517 Mdot
.95 .4058 Mdot
.95 .40582 Mdot
.95 .40607 Mdot
.95 .40635 Mdot
.95 .40711 Mdot
.95 .4074 Mdot
.95 .40792 Mdot
.95 .40829 Mdot
.95 .40863 Mdot
.95 .4095 Mdot
.95 .40969 Mdot
.95 .41121 Mdot
.95 .41144 Mdot
.95 .41263 Mdot
.95 .41273 Mdot
.95 .41374 Mdot
.95 .41387 Mdot
.95 .41397 Mdot
.95 .41414 Mdot
.95 .41442 Mdot
.95 .41468 Mdot
.95 .41483 Mdot
.95 .41488 Mdot
.95 .41512 Mdot
.95 .41541 Mdot
.95 .41635 Mdot
.95 .4175 Mdot
.95 .41769 Mdot
.95 .41775 Mdot
.95 .41784 Mdot
.95 .41811 Mdot
.95 .41866 Mdot
.95 .4188 Mdot
.95 .41918 Mdot
.95 .41969 Mdot
.95 .42014 Mdot
.95 .4223 Mdot
.95 .42242 Mdot
.95 .42242 Mdot
.95 .42278 Mdot
.95 .42345 Mdot
.95 .42496 Mdot
.95 .42536 Mdot
.95 .42579 Mdot
.95 .42649 Mdot
.95 .42669 Mdot
.95 .42698 Mdot
.95 .42737 Mdot
.95 .42764 Mdot
.95 .42793 Mdot
.95 .42922 Mdot
.95 .42966 Mdot
.95 .42978 Mdot
.95 .42983 Mdot
.95 .43083 Mdot
.95 .43086 Mdot
.95 .43101 Mdot
.95 .43104 Mdot
.95 .43119 Mdot
.95 .43175 Mdot
.95 .43293 Mdot
.95 .43305 Mdot
.95 .43432 Mdot
.95 .43486 Mdot
.95 .43489 Mdot
.95 .43548 Mdot
.95 .43588 Mdot
.95 .43639 Mdot
.95 .43641 Mdot
.95 .43712 Mdot
.95 .43723 Mdot
.95 .43733 Mdot
.95 .43771 Mdot
.95 .43807 Mdot
.95 .43838 Mdot
.95 .43855 Mdot
.95 .43902 Mdot
.95 .44005 Mdot
.95 .44026 Mdot
.95 .44234 Mdot
.95 .44234 Mdot
.95 .44272 Mdot
.95 .44338 Mdot
.95 .44357 Mdot
.95 .44394 Mdot
.95 .44397 Mdot
.95 .44427 Mdot
.95 .44637 Mdot
.95 .4468 Mdot
.95 .44684 Mdot
.95 .4472 Mdot
.95 .4478 Mdot
.95 .44785 Mdot
.95 .44816 Mdot
.95 .44882 Mdot
.95 .44886 Mdot
.95 .44909 Mdot
.95 .44928 Mdot
.95 .44953 Mdot
.95 .44974 Mdot
.95 .45024 Mdot
.95 .4503 Mdot
.95 .45046 Mdot
.95 .45056 Mdot
.95 .45135 Mdot
.95 .45145 Mdot
.95 .4524 Mdot
.95 .45261 Mdot
.95 .45353 Mdot
.95 .4546 Mdot
.95 .4558 Mdot
.95 .4582 Mdot
.95 .45881 Mdot
.95 .45937 Mdot
.95 .45965 Mdot
.95 .45976 Mdot
.95 .45994 Mdot
.95 .46061 Mdot
.95 .46084 Mdot
.95 .46117 Mdot
.95 .46177 Mdot
.95 .46197 Mdot
.95 .46212 Mdot
.95 .46233 Mdot
.95 .46245 Mdot
.95 .46322 Mdot
.95 .46327 Mdot
.95 .46412 Mdot
.95 .46462 Mdot
.95 .46475 Mdot
.95 .46502 Mdot
.95 .46562 Mdot
.95 .46599 Mdot
.95 .46641 Mdot
.95 .4668 Mdot
.95 .46689 Mdot
.95 .46692 Mdot
.95 .46785 Mdot
.95 .46845 Mdot
.95 .46946 Mdot
.95 .46949 Mdot
.95 .4702 Mdot
.95 .47063 Mdot
.95 .47131 Mdot
.95 .47188 Mdot
.95 .47254 Mdot
.95 .47289 Mdot
.95 .47294 Mdot
.95 .47309 Mdot
.95 .4731 Mdot
.95 .47318 Mdot
.95 .4732 Mdot
.95 .47376 Mdot
.95 .47378 Mdot
.95 .47416 Mdot
.95 .4746 Mdot
.95 .4747 Mdot
.95 .4754 Mdot
.95 .47579 Mdot
.95 .47591 Mdot
.95 .47706 Mdot
.95 .47726 Mdot
.95 .47741 Mdot
.95 .47751 Mdot
.95 .4777 Mdot
.95 .4777 Mdot
.95 .4782 Mdot
.95 .4787 Mdot
.95 .47899 Mdot
.95 .47955 Mdot
.95 .48001 Mdot
.95 .48084 Mdot
.95 .4814 Mdot
.95 .48143 Mdot
.95 .48183 Mdot
.95 .48394 Mdot
.95 .4843 Mdot
.95 .48588 Mdot
.95 .48622 Mdot
.95 .48686 Mdot
.95 .48727 Mdot
.95 .48732 Mdot
.95 .48829 Mdot
.95 .4883 Mdot
.95 .48936 Mdot
.95 .4894 Mdot
.95 .48941 Mdot
.95 .48969 Mdot
.95 .4897 Mdot
.95 .48973 Mdot
.95 .48986 Mdot
.95 .49029 Mdot
.95 .49048 Mdot
.95 .49061 Mdot
.95 .49174 Mdot
.95 .49237 Mdot
.95 .4931 Mdot
.95 .49342 Mdot
.95 .49408 Mdot
.95 .49411 Mdot
.95 .49414 Mdot
.95 .49442 Mdot
.95 .49445 Mdot
.95 .49556 Mdot
.95 .49576 Mdot
.95 .49619 Mdot
.95 .49634 Mdot
.95 .49634 Mdot
.95 .49652 Mdot
.95 .49654 Mdot
.95 .49757 Mdot
.95 .49814 Mdot
.95 .49863 Mdot
.95 .49959 Mdot
.95 .50017 Mdot
.95 .50022 Mdot
.95 .50075 Mdot
.95 .50224 Mdot
.95 .50273 Mdot
.95 .50284 Mdot
.95 .50311 Mdot
.95 .50383 Mdot
.95 .50388 Mdot
.95 .50425 Mdot
.95 .50445 Mdot
.95 .50455 Mdot
.95 .50651 Mdot
.95 .50653 Mdot
.95 .50718 Mdot
.95 .50772 Mdot
.95 .50791 Mdot
.95 .50805 Mdot
.95 .50818 Mdot
.95 .50866 Mdot
.95 .50871 Mdot
.95 .50883 Mdot
.95 .5089 Mdot
.95 .50936 Mdot
.95 .5103 Mdot
.95 .51139 Mdot
.95 .51147 Mdot
.95 .51204 Mdot
.95 .51211 Mdot
.95 .51246 Mdot
.95 .51267 Mdot
.95 .51296 Mdot
.95 .51385 Mdot
.95 .51389 Mdot
.95 .51403 Mdot
.95 .51538 Mdot
.95 .51565 Mdot
.95 .51605 Mdot
.95 .51655 Mdot
.95 .51657 Mdot
.95 .51671 Mdot
.95 .51794 Mdot
.95 .51887 Mdot
.95 .51889 Mdot
.95 .519 Mdot
.95 .51985 Mdot
.95 .52031 Mdot
.95 .52059 Mdot
.95 .52064 Mdot
.95 .52172 Mdot
.95 .52214 Mdot
.95 .52223 Mdot
.95 .52259 Mdot
.95 .52268 Mdot
.95 .52271 Mdot
.95 .52283 Mdot
.95 .52314 Mdot
.95 .52485 Mdot
.95 .52501 Mdot
.95 .52521 Mdot
.95 .52539 Mdot
.95 .52628 Mdot
.95 .52761 Mdot
.95 .52778 Mdot
.95 .52792 Mdot
.95 .52812 Mdot
.95 .52817 Mdot
.95 .5282 Mdot
.95 .52857 Mdot
.95 .52933 Mdot
.95 .5299 Mdot
.95 .53062 Mdot
.95 .53069 Mdot
.95 .53076 Mdot
.95 .53116 Mdot
.95 .53117 Mdot
.95 .53131 Mdot
.95 .53151 Mdot
.95 .53151 Mdot
.95 .53225 Mdot
.95 .53277 Mdot
.95 .53288 Mdot
.95 .53399 Mdot
.95 .5342 Mdot
.95 .53443 Mdot
.95 .53479 Mdot
.95 .53529 Mdot
.95 .53594 Mdot
.95 .53672 Mdot
.95 .5372 Mdot
.95 .53763 Mdot
.95 .53787 Mdot
.95 .53827 Mdot
.95 .53877 Mdot
.95 .53894 Mdot
.95 .53928 Mdot
.95 .53929 Mdot
.95 .53947 Mdot
.95 .53985 Mdot
.95 .5407 Mdot
.95 .54118 Mdot
.95 .54128 Mdot
.95 .54135 Mdot
.95 .5421 Mdot
.95 .54218 Mdot
.95 .54301 Mdot
.95 .5432 Mdot
.95 .54333 Mdot
.95 .5435 Mdot
.95 .54709 Mdot
.95 .54799 Mdot
.95 .5488 Mdot
.95 .5496 Mdot
.95 .54962 Mdot
.95 .55062 Mdot
.95 .55098 Mdot
.95 .55218 Mdot
.95 .55242 Mdot
.95 .55336 Mdot
.95 .5538 Mdot
.95 .55405 Mdot
.95 .5554 Mdot
.95 .55548 Mdot
.95 .5565 Mdot
.95 .55659 Mdot
.95 .55698 Mdot
.95 .55805 Mdot
.95 .55826 Mdot
.95 .55854 Mdot
.95 .55888 Mdot
.95 .55922 Mdot
.95 .55979 Mdot
.95 .56037 Mdot
.95 .56114 Mdot
.95 .56224 Mdot
.95 .5637 Mdot
.95 .56414 Mdot
.95 .56445 Mdot
.95 .56569 Mdot
.95 .56586 Mdot
.95 .56665 Mdot
.95 .56714 Mdot
.95 .56772 Mdot
.95 .56787 Mdot
.95 .56823 Mdot
.95 .56825 Mdot
.95 .5693 Mdot
.95 .5695 Mdot
.95 .5695 Mdot
.95 .57012 Mdot
.95 .5706 Mdot
.95 .57108 Mdot
.95 .57144 Mdot
.95 .57202 Mdot
.95 .57225 Mdot
.95 .57259 Mdot
.95 .57301 Mdot
.95 .57313 Mdot
.95 .5732 Mdot
.95 .5734 Mdot
.95 .57397 Mdot
.95 .57399 Mdot
.95 .57403 Mdot
.95 .57425 Mdot
.95 .57465 Mdot
.95 .5748 Mdot
.952 .06921 Mdot
.952 .07303 Mdot
.952 .07363 Mdot
.952 .07438 Mdot
.952 .0749 Mdot
.952 .0753 Mdot
.952 .07556 Mdot
.952 .07746 Mdot
.952 .07903 Mdot
.952 .08062 Mdot
.952 .08073 Mdot
.952 .08103 Mdot
.952 .08216 Mdot
.952 .08219 Mdot
.952 .08223 Mdot
.952 .08403 Mdot
.952 .08453 Mdot
.952 .08464 Mdot
.952 .08467 Mdot
.952 .08629 Mdot
.952 .08674 Mdot
.952 .0872 Mdot
.952 .08731 Mdot
.952 .08771 Mdot
.952 .08932 Mdot
.952 .08956 Mdot
.952 .08977 Mdot
.952 .0902 Mdot
.952 .09046 Mdot
.952 .09213 Mdot
.952 .09246 Mdot
.952 .0927 Mdot
.952 .0929 Mdot
.952 .09351 Mdot
.952 .09424 Mdot
.952 .09451 Mdot
.952 .09486 Mdot
.952 .09506 Mdot
.952 .09558 Mdot
.952 .0957 Mdot
.952 .09642 Mdot
.952 .09703 Mdot
.952 .09837 Mdot
.952 .09845 Mdot
.952 .0987 Mdot
.952 .09948 Mdot
.952 .0996 Mdot
.952 .09976 Mdot
.952 .10104 Mdot
.952 .1013 Mdot
.952 .10228 Mdot
.952 .10245 Mdot
.952 .10305 Mdot
.952 .10307 Mdot
.952 .10346 Mdot
.952 .10357 Mdot
.952 .10425 Mdot
.952 .10438 Mdot
.952 .10507 Mdot
.952 .11043 Mdot
.952 .11233 Mdot
.952 .11311 Mdot
.952 .11325 Mdot
.952 .1148 Mdot
.952 .11483 Mdot
.952 .11623 Mdot
.952 .117 Mdot
.952 .11847 Mdot
.952 .12059 Mdot
.952 .12161 Mdot
.952 .12215 Mdot
.952 .12357 Mdot
.952 .12473 Mdot
.952 .12532 Mdot
.952 .12574 Mdot
.952 .12663 Mdot
.952 .1269 Mdot
.952 .12831 Mdot
.952 .12835 Mdot
.952 .12913 Mdot
.952 .12931 Mdot
.952 .12968 Mdot
.952 .12996 Mdot
.952 .13007 Mdot
.952 .13056 Mdot
.952 .13062 Mdot
.952 .13102 Mdot
.952 .13146 Mdot
.952 .13228 Mdot
.952 .13367 Mdot
.952 .13376 Mdot
.952 .13417 Mdot
.952 .13714 Mdot
.952 .13717 Mdot
.952 .13757 Mdot
.952 .13986 Mdot
.952 .1399 Mdot
.952 .14019 Mdot
.952 .1404 Mdot
.952 .14098 Mdot
.952 .14166 Mdot
.952 .14251 Mdot
.952 .14312 Mdot
.952 .14318 Mdot
.952 .14327 Mdot
.952 .14576 Mdot
.952 .14591 Mdot
.952 .14669 Mdot
.952 .14764 Mdot
.952 .14765 Mdot
.952 .14786 Mdot
.952 .14791 Mdot
.952 .14802 Mdot
.952 .15007 Mdot
.952 .15011 Mdot
.952 .15099 Mdot
.952 .15162 Mdot
.952 .15185 Mdot
.952 .15205 Mdot
.952 .15235 Mdot
.952 .15273 Mdot
.952 .15293 Mdot
.952 .1537 Mdot
.952 .15424 Mdot
.952 .15438 Mdot
.952 .15443 Mdot
.952 .15676 Mdot
.952 .15721 Mdot
.952 .15756 Mdot
.952 .15762 Mdot
.952 .15845 Mdot
.952 .15894 Mdot
.952 .15906 Mdot
.952 .16022 Mdot
.952 .16042 Mdot
.952 .16124 Mdot
.952 .16211 Mdot
.952 .16275 Mdot
.952 .1632 Mdot
.952 .16359 Mdot
.952 .16466 Mdot
.952 .16474 Mdot
.952 .16491 Mdot
.952 .16553 Mdot
.952 .16593 Mdot
.952 .16613 Mdot
.952 .16661 Mdot
.952 .16665 Mdot
.952 .16702 Mdot
.952 .16732 Mdot
.952 .16768 Mdot
.952 .16768 Mdot
.952 .16836 Mdot
.952 .16864 Mdot
.952 .16868 Mdot
.952 .16892 Mdot
.952 .16956 Mdot
.952 .17028 Mdot
.952 .17047 Mdot
.952 .17115 Mdot
.952 .17144 Mdot
.952 .17194 Mdot
.952 .17196 Mdot
.952 .1727 Mdot
.952 .17367 Mdot
.952 .17395 Mdot
.952 .17396 Mdot
.952 .174 Mdot
.952 .17415 Mdot
.952 .17463 Mdot
.952 .1747 Mdot
.952 .1748 Mdot
.952 .17492 Mdot
.952 .17597 Mdot
.952 .17611 Mdot
.952 .17633 Mdot
.952 .17665 Mdot
.952 .17732 Mdot
.952 .1774 Mdot
.952 .1776 Mdot
.952 .17868 Mdot
.952 .17908 Mdot
.952 .17957 Mdot
.952 .17963 Mdot
.952 .17996 Mdot
.952 .18114 Mdot
.952 .18144 Mdot
.952 .18177 Mdot
.952 .18291 Mdot
.952 .18294 Mdot
.952 .18368 Mdot
.952 .1839 Mdot
.952 .18399 Mdot
.952 .18409 Mdot
.952 .18426 Mdot
.952 .18461 Mdot
.952 .1849 Mdot
.952 .18519 Mdot
.952 .18539 Mdot
.952 .1854 Mdot
.952 .18543 Mdot
.952 .18644 Mdot
.952 .18676 Mdot
.952 .18679 Mdot
.952 .18698 Mdot
.952 .18772 Mdot
.952 .18799 Mdot
.952 .1883 Mdot
.952 .18913 Mdot
.952 .18951 Mdot
.952 .19006 Mdot
.952 .19111 Mdot
.952 .19146 Mdot
.952 .19306 Mdot
.952 .19329 Mdot
.952 .19345 Mdot
.952 .19369 Mdot
.952 .19473 Mdot
.952 .19527 Mdot
.952 .19651 Mdot
.952 .19695 Mdot
.952 .19735 Mdot
.952 .19736 Mdot
.952 .1974 Mdot
.952 .1983 Mdot
.952 .20044 Mdot
.952 .20057 Mdot
.952 .20115 Mdot
.952 .20206 Mdot
.952 .20233 Mdot
.952 .20318 Mdot
.952 .20348 Mdot
.952 .20353 Mdot
.952 .20369 Mdot
.952 .20395 Mdot
.952 .20527 Mdot
.952 .20533 Mdot
.952 .20556 Mdot
.952 .2058 Mdot
.952 .20591 Mdot
.952 .20799 Mdot
.952 .20846 Mdot
.952 .20928 Mdot
.952 .20946 Mdot
.952 .20955 Mdot
.952 .2104 Mdot
.952 .21085 Mdot
.952 .21189 Mdot
.952 .21226 Mdot
.952 .21274 Mdot
.952 .21459 Mdot
.952 .2163 Mdot
.952 .21682 Mdot
.952 .21791 Mdot
.952 .21807 Mdot
.952 .21825 Mdot
.952 .21866 Mdot
.952 .21924 Mdot
.952 .21927 Mdot
.952 .22047 Mdot
.952 .22052 Mdot
.952 .22198 Mdot
.952 .22418 Mdot
.952 .2243 Mdot
.952 .22525 Mdot
.952 .22531 Mdot
.952 .22542 Mdot
.952 .22583 Mdot
.952 .22611 Mdot
.952 .22709 Mdot
.952 .22781 Mdot
.952 .22788 Mdot
.952 .22831 Mdot
.952 .2289 Mdot
.952 .23025 Mdot
.952 .23101 Mdot
.952 .23108 Mdot
.952 .23136 Mdot
.952 .23183 Mdot
.952 .23241 Mdot
.952 .23256 Mdot
.952 .2329 Mdot
.952 .23294 Mdot
.952 .23317 Mdot
.952 .23347 Mdot
.952 .23361 Mdot
.952 .23403 Mdot
.952 .23414 Mdot
.952 .23435 Mdot
.952 .23464 Mdot
.952 .23528 Mdot
.952 .2354 Mdot
.952 .23545 Mdot
.952 .23615 Mdot
.952 .237 Mdot
.952 .23856 Mdot
.952 .23889 Mdot
.952 .2412 Mdot
.952 .24137 Mdot
.952 .24178 Mdot
.952 .24217 Mdot
.952 .24229 Mdot
.952 .24499 Mdot
.952 .24501 Mdot
.952 .24556 Mdot
.952 .2478 Mdot
.952 .24787 Mdot
.952 .24792 Mdot
.952 .24862 Mdot
.952 .24907 Mdot
.952 .24921 Mdot
.952 .25066 Mdot
.952 .25127 Mdot
.952 .25165 Mdot
.952 .25167 Mdot
.952 .25199 Mdot
.952 .25208 Mdot
.952 .25299 Mdot
.952 .25307 Mdot
.952 .25362 Mdot
.952 .25402 Mdot
.952 .2541 Mdot
.952 .25512 Mdot
.952 .25589 Mdot
.952 .25641 Mdot
.952 .25662 Mdot
.952 .25713 Mdot
.952 .25804 Mdot
.952 .25909 Mdot
.952 .25921 Mdot
.952 .25921 Mdot
.952 .25932 Mdot
.952 .25949 Mdot
.952 .25988 Mdot
.952 .25992 Mdot
.952 .26024 Mdot
.952 .26104 Mdot
.952 .26105 Mdot
.952 .26179 Mdot
.952 .26368 Mdot
.952 .26423 Mdot
.952 .26431 Mdot
.952 .26452 Mdot
.952 .26481 Mdot
.952 .26599 Mdot
.952 .26645 Mdot
.952 .2665 Mdot
.952 .2678 Mdot
.952 .26781 Mdot
.952 .26822 Mdot
.952 .26831 Mdot
.952 .26852 Mdot
.952 .26995 Mdot
.952 .27018 Mdot
.952 .27047 Mdot
.952 .2709 Mdot
.952 .27193 Mdot
.952 .27244 Mdot
.952 .2725 Mdot
.952 .27314 Mdot
.952 .27393 Mdot
.952 .27419 Mdot
.952 .27419 Mdot
.952 .2752 Mdot
.952 .27537 Mdot
.952 .27581 Mdot
.952 .2762 Mdot
.952 .27635 Mdot
.952 .27677 Mdot
.952 .27749 Mdot
.952 .27749 Mdot
.952 .2778 Mdot
.952 .27785 Mdot
.952 .27788 Mdot
.952 .27899 Mdot
.952 .27908 Mdot
.952 .27934 Mdot
.952 .28038 Mdot
.952 .28041 Mdot
.952 .28044 Mdot
.952 .28064 Mdot
.952 .28072 Mdot
.952 .2812 Mdot
.952 .28211 Mdot
.952 .28267 Mdot
.952 .28517 Mdot
.952 .28603 Mdot
.952 .28608 Mdot
.952 .28669 Mdot
.952 .28681 Mdot
.952 .2879 Mdot
.952 .28838 Mdot
.952 .28842 Mdot
.952 .28932 Mdot
.952 .28955 Mdot
.952 .29004 Mdot
.952 .29176 Mdot
.952 .29214 Mdot
.952 .29237 Mdot
.952 .2926 Mdot
.952 .29278 Mdot
.952 .29301 Mdot
.952 .29322 Mdot
.952 .2937 Mdot
.952 .29422 Mdot
.952 .29536 Mdot
.952 .29657 Mdot
.952 .29695 Mdot
.952 .29743 Mdot
.952 .29817 Mdot
.952 .30009 Mdot
.952 .3002 Mdot
.952 .30037 Mdot
.952 .30069 Mdot
.952 .30116 Mdot
.952 .30186 Mdot
.952 .30223 Mdot
.952 .30226 Mdot
.952 .30256 Mdot
.952 .30263 Mdot
.952 .303 Mdot
.952 .30312 Mdot
.952 .30321 Mdot
.952 .30367 Mdot
.952 .30375 Mdot
.952 .30392 Mdot
.952 .30399 Mdot
.952 .30457 Mdot
.952 .3047 Mdot
.952 .30527 Mdot
.952 .30545 Mdot
.952 .30596 Mdot
.952 .30597 Mdot
.952 .30636 Mdot
.952 .30726 Mdot
.952 .30779 Mdot
.952 .30786 Mdot
.952 .30797 Mdot
.952 .30832 Mdot
.952 .30954 Mdot
.952 .31091 Mdot
.952 .31128 Mdot
.952 .31256 Mdot
.952 .313 Mdot
.952 .31312 Mdot
.952 .31345 Mdot
.952 .31408 Mdot
.952 .31411 Mdot
.952 .31457 Mdot
.952 .31485 Mdot
.952 .31496 Mdot
.952 .31553 Mdot
.952 .31634 Mdot
.952 .31656 Mdot
.952 .31693 Mdot
.952 .31698 Mdot
.952 .31736 Mdot
.952 .3179 Mdot
.952 .31792 Mdot
.952 .31799 Mdot
.952 .31821 Mdot
.952 .31828 Mdot
.952 .31864 Mdot
.952 .31898 Mdot
.952 .3192 Mdot
.952 .31933 Mdot
.952 .31952 Mdot
.952 .31956 Mdot
.952 .31975 Mdot
.952 .32175 Mdot
.952 .322 Mdot
.952 .32243 Mdot
.952 .32304 Mdot
.952 .32431 Mdot
.952 .32446 Mdot
.952 .32485 Mdot
.952 .32533 Mdot
.952 .32654 Mdot
.952 .3269 Mdot
.952 .32766 Mdot
.952 .32859 Mdot
.952 .32871 Mdot
.952 .32934 Mdot
.952 .33159 Mdot
.952 .33216 Mdot
.952 .33217 Mdot
.952 .33279 Mdot
.952 .33335 Mdot
.952 .33464 Mdot
.952 .33496 Mdot
.952 .33502 Mdot
.952 .33524 Mdot
.952 .33618 Mdot
.952 .33625 Mdot
.952 .33642 Mdot
.952 .33654 Mdot
.952 .33684 Mdot
.952 .33702 Mdot
.952 .33721 Mdot
.952 .33754 Mdot
.952 .33779 Mdot
.952 .33797 Mdot
.952 .3382 Mdot
.952 .3384 Mdot
.952 .33875 Mdot
.952 .33931 Mdot
.952 .33968 Mdot
.952 .3397 Mdot
.952 .33975 Mdot
.952 .34073 Mdot
.952 .34169 Mdot
.952 .34177 Mdot
.952 .34219 Mdot
.952 .34229 Mdot
.952 .34234 Mdot
.952 .34255 Mdot
.952 .34271 Mdot
.952 .34294 Mdot
.952 .34348 Mdot
.952 .34408 Mdot
.952 .34413 Mdot
.952 .34448 Mdot
.952 .34463 Mdot
.952 .34497 Mdot
.952 .34522 Mdot
.952 .34605 Mdot
.952 .34681 Mdot
.952 .34691 Mdot
.952 .34702 Mdot
.952 .34753 Mdot
.952 .34756 Mdot
.952 .34827 Mdot
.952 .34857 Mdot
.952 .3488 Mdot
.952 .34996 Mdot
.952 .35057 Mdot
.952 .35092 Mdot
.952 .35124 Mdot
.952 .35264 Mdot
.952 .35306 Mdot
.952 .35362 Mdot
.952 .3539 Mdot
.952 .35428 Mdot
.952 .35471 Mdot
.952 .35502 Mdot
.952 .35549 Mdot
.952 .35666 Mdot
.952 .35746 Mdot
.952 .3585 Mdot
.952 .36027 Mdot
.952 .36086 Mdot
.952 .36155 Mdot
.952 .36169 Mdot
.952 .36223 Mdot
.952 .36245 Mdot
.952 .36246 Mdot
.952 .36255 Mdot
.952 .36277 Mdot
.952 .36367 Mdot
.952 .36381 Mdot
.952 .36426 Mdot
.952 .36523 Mdot
.952 .36549 Mdot
.952 .36611 Mdot
.952 .36668 Mdot
.952 .36699 Mdot
.952 .36739 Mdot
.952 .36811 Mdot
.952 .36833 Mdot
.952 .36858 Mdot
.952 .36968 Mdot
.952 .37141 Mdot
.952 .37165 Mdot
.952 .37192 Mdot
.952 .37268 Mdot
.952 .37354 Mdot
.952 .37413 Mdot
.952 .37414 Mdot
.952 .37422 Mdot
.952 .37453 Mdot
.952 .37455 Mdot
.952 .37478 Mdot
.952 .37502 Mdot
.952 .37527 Mdot
.952 .37572 Mdot
.952 .37754 Mdot
.952 .37764 Mdot
.952 .37809 Mdot
.952 .3782 Mdot
.952 .37854 Mdot
.952 .37866 Mdot
.952 .37875 Mdot
.952 .37891 Mdot
.952 .38272 Mdot
.952 .38307 Mdot
.952 .3835 Mdot
.952 .38352 Mdot
.952 .3836 Mdot
.952 .38516 Mdot
.952 .38551 Mdot
.952 .38568 Mdot
.952 .38664 Mdot
.952 .3873 Mdot
.952 .38815 Mdot
.952 .39014 Mdot
.952 .39068 Mdot
.952 .39083 Mdot
.952 .39112 Mdot
.952 .39175 Mdot
.952 .39191 Mdot
.952 .392 Mdot
.952 .39211 Mdot
.952 .39428 Mdot
.952 .3944 Mdot
.952 .39529 Mdot
.952 .39643 Mdot
.952 .39655 Mdot
.952 .39656 Mdot
.952 .39853 Mdot
.952 .39865 Mdot
.952 .3989 Mdot
.952 .39953 Mdot
.952 .39956 Mdot
.952 .40015 Mdot
.952 .4008 Mdot
.952 .40098 Mdot
.952 .40137 Mdot
.952 .4016 Mdot
.952 .40181 Mdot
.952 .4019 Mdot
.952 .40224 Mdot
.952 .40255 Mdot
.952 .4029 Mdot
.952 .40303 Mdot
.952 .40413 Mdot
.952 .40413 Mdot
.952 .4042 Mdot
.952 .40526 Mdot
.952 .40533 Mdot
.952 .40647 Mdot
.952 .40652 Mdot
.952 .40657 Mdot
.952 .40699 Mdot
.952 .40721 Mdot
.952 .40934 Mdot
.952 .41098 Mdot
.952 .41099 Mdot
.952 .41121 Mdot
.952 .4134 Mdot
.952 .41353 Mdot
.952 .41377 Mdot
.952 .41508 Mdot
.952 .41531 Mdot
.952 .41557 Mdot
.952 .41569 Mdot
.952 .4159 Mdot
.952 .41667 Mdot
.952 .41721 Mdot
.952 .41907 Mdot
.952 .41945 Mdot
.952 .41966 Mdot
.952 .41982 Mdot
.952 .42012 Mdot
.952 .42045 Mdot
.952 .42059 Mdot
.952 .42133 Mdot
.952 .4214 Mdot
.952 .42187 Mdot
.952 .42216 Mdot
.952 .42252 Mdot
.952 .42319 Mdot
.952 .42508 Mdot
.952 .42653 Mdot
.952 .42668 Mdot
.952 .42698 Mdot
.952 .4272 Mdot
.952 .4281 Mdot
.952 .4286 Mdot
.952 .42921 Mdot
.952 .42949 Mdot
.952 .42986 Mdot
.952 .43015 Mdot
.952 .43021 Mdot
.952 .43066 Mdot
.952 .43122 Mdot
.952 .43148 Mdot
.952 .43169 Mdot
.952 .43201 Mdot
.952 .43229 Mdot
.952 .4325 Mdot
.952 .43268 Mdot
.952 .43291 Mdot
.952 .43345 Mdot
.952 .43467 Mdot
.952 .4349 Mdot
.952 .435 Mdot
.952 .43565 Mdot
.952 .4358 Mdot
.952 .43584 Mdot
.952 .43633 Mdot
.952 .43665 Mdot
.952 .43733 Mdot
.952 .43795 Mdot
.952 .44091 Mdot
.952 .44154 Mdot
.952 .44457 Mdot
.952 .44488 Mdot
.952 .44506 Mdot
.952 .44528 Mdot
.952 .44592 Mdot
.952 .44595 Mdot
.952 .44615 Mdot
.952 .44626 Mdot
.952 .44699 Mdot
.952 .44705 Mdot
.952 .44719 Mdot
.952 .44778 Mdot
.952 .44801 Mdot
.952 .45066 Mdot
.952 .4515 Mdot
.952 .45198 Mdot
.952 .45244 Mdot
.952 .45288 Mdot
.952 .45291 Mdot
.952 .45315 Mdot
.952 .4532 Mdot
.952 .4535 Mdot
.952 .45365 Mdot
.952 .45367 Mdot
.952 .45424 Mdot
.952 .4548 Mdot
.952 .45644 Mdot
.952 .45788 Mdot
.952 .4584 Mdot
.952 .45852 Mdot
.952 .45864 Mdot
.952 .45873 Mdot
.952 .45885 Mdot
.952 .46008 Mdot
.952 .46092 Mdot
.952 .4612 Mdot
.952 .46215 Mdot
.952 .46395 Mdot
.952 .46424 Mdot
.952 .46472 Mdot
.952 .46512 Mdot
.952 .46513 Mdot
.952 .46583 Mdot
.952 .46588 Mdot
.952 .46648 Mdot
.952 .4665 Mdot
.952 .46667 Mdot
.952 .46726 Mdot
.952 .46787 Mdot
.952 .4684 Mdot
.952 .46854 Mdot
.952 .46895 Mdot
.952 .46959 Mdot
.952 .47013 Mdot
.952 .47035 Mdot
.952 .47051 Mdot
.952 .47063 Mdot
.952 .47244 Mdot
.952 .47247 Mdot
.952 .47333 Mdot
.952 .47359 Mdot
.952 .47392 Mdot
.952 .47491 Mdot
.952 .4753 Mdot
.952 .4753 Mdot
.952 .47572 Mdot
.952 .47589 Mdot
.952 .47591 Mdot
.952 .47626 Mdot
.952 .47633 Mdot
.952 .47736 Mdot
.952 .47763 Mdot
.952 .47801 Mdot
.952 .47895 Mdot
.952 .48001 Mdot
.952 .48006 Mdot
.952 .48023 Mdot
.952 .48024 Mdot
.952 .48044 Mdot
.952 .48076 Mdot
.952 .48152 Mdot
.952 .48159 Mdot
.952 .4822 Mdot
.952 .48344 Mdot
.952 .48372 Mdot
.952 .48374 Mdot
.952 .48515 Mdot
.952 .48542 Mdot
.952 .48694 Mdot
.952 .48875 Mdot
.952 .48917 Mdot
.952 .48979 Mdot
.952 .48994 Mdot
.952 .49007 Mdot
.952 .49034 Mdot
.952 .49065 Mdot
.952 .4909 Mdot
.952 .49148 Mdot
.952 .49219 Mdot
.952 .49272 Mdot
.952 .49314 Mdot
.952 .4938 Mdot
.952 .49401 Mdot
.952 .4941 Mdot
.952 .4946 Mdot
.952 .49659 Mdot
.952 .49661 Mdot
.952 .49726 Mdot
.952 .49738 Mdot
.952 .49756 Mdot
.952 .49787 Mdot
.952 .49796 Mdot
.952 .49853 Mdot
.952 .4997 Mdot
.952 .50067 Mdot
.952 .50112 Mdot
.952 .50167 Mdot
.952 .5019 Mdot
.952 .50235 Mdot
.952 .50249 Mdot
.952 .50292 Mdot
.952 .50426 Mdot
.952 .50432 Mdot
.952 .50444 Mdot
.952 .50529 Mdot
.952 .50542 Mdot
.952 .50551 Mdot
.952 .50553 Mdot
.952 .5057 Mdot
.952 .50676 Mdot
.952 .50713 Mdot
.952 .50826 Mdot
.952 .50873 Mdot
.952 .50875 Mdot
.952 .50876 Mdot
.952 .5092 Mdot
.952 .50985 Mdot
.952 .51013 Mdot
.952 .51068 Mdot
.952 .51081 Mdot
.952 .51089 Mdot
.952 .51101 Mdot
.952 .51185 Mdot
.952 .51203 Mdot
.952 .51259 Mdot
.952 .51287 Mdot
.952 .51307 Mdot
.952 .51351 Mdot
.952 .51367 Mdot
.952 .51381 Mdot
.952 .5142 Mdot
.952 .5143 Mdot
.952 .51448 Mdot
.952 .51503 Mdot
.952 .51504 Mdot
.952 .51529 Mdot
.952 .51545 Mdot
.952 .51563 Mdot
.952 .51572 Mdot
.952 .51577 Mdot
.952 .51727 Mdot
.952 .51789 Mdot
.952 .51806 Mdot
.952 .51856 Mdot
.952 .51913 Mdot
.952 .51924 Mdot
.952 .51928 Mdot
.952 .51998 Mdot
.952 .52054 Mdot
.952 .5206 Mdot
.952 .52065 Mdot
.952 .52104 Mdot
.952 .52105 Mdot
.952 .52119 Mdot
.952 .5217 Mdot
.952 .52209 Mdot
.952 .5221 Mdot
.952 .52252 Mdot
.952 .52287 Mdot
.952 .52335 Mdot
.952 .52384 Mdot
.952 .52398 Mdot
.952 .52434 Mdot
.952 .52469 Mdot
.952 .5249 Mdot
.952 .52526 Mdot
.952 .52547 Mdot
.952 .52579 Mdot
.952 .52593 Mdot
.952 .52772 Mdot
.952 .52815 Mdot
.952 .52826 Mdot
.952 .52886 Mdot
.952 .52966 Mdot
.952 .5313 Mdot
.952 .53132 Mdot
.952 .5314 Mdot
.952 .53239 Mdot
.952 .53255 Mdot
.952 .53278 Mdot
.952 .53357 Mdot
.952 .53359 Mdot
.952 .53467 Mdot
.952 .53486 Mdot
.952 .53577 Mdot
.952 .53585 Mdot
.952 .53756 Mdot
.952 .53801 Mdot
.952 .53893 Mdot
.952 .53895 Mdot
.952 .54016 Mdot
.952 .54038 Mdot
.952 .54216 Mdot
.952 .5422 Mdot
.952 .54293 Mdot
.952 .54336 Mdot
.952 .54359 Mdot
.952 .5438 Mdot
.952 .54415 Mdot
.952 .5443 Mdot
.952 .54459 Mdot
.952 .54499 Mdot
.952 .5459 Mdot
.952 .54659 Mdot
.952 .5469 Mdot
.952 .54751 Mdot
.952 .54825 Mdot
.952 .54853 Mdot
.952 .54907 Mdot
.952 .55096 Mdot
.952 .55136 Mdot
.952 .5521 Mdot
.952 .55211 Mdot
.952 .55293 Mdot
.952 .553 Mdot
.952 .55341 Mdot
.952 .55441 Mdot
.952 .55722 Mdot
.952 .55759 Mdot
.952 .55765 Mdot
.952 .55801 Mdot
.952 .55807 Mdot
.952 .55827 Mdot
.952 .55828 Mdot
.952 .5586 Mdot
.952 .55869 Mdot
.952 .5592 Mdot
.952 .55934 Mdot
.952 .56001 Mdot
.952 .5601 Mdot
.952 .56016 Mdot
.952 .56057 Mdot
.952 .5607 Mdot
.952 .56074 Mdot
.952 .56145 Mdot
.952 .56177 Mdot
.952 .56214 Mdot
.952 .56221 Mdot
.952 .56248 Mdot
.952 .56258 Mdot
.952 .56277 Mdot
.952 .56291 Mdot
.952 .56329 Mdot
.952 .56361 Mdot
.952 .56372 Mdot
.952 .56384 Mdot
.952 .56402 Mdot
.952 .56489 Mdot
.952 .56503 Mdot
.952 .56526 Mdot
.952 .56537 Mdot
.952 .5655 Mdot
.952 .56634 Mdot
.952 .56655 Mdot
.952 .56661 Mdot
.952 .56685 Mdot
.952 .56709 Mdot
.952 .56794 Mdot
.952 .56795 Mdot
.952 .56801 Mdot
.952 .56827 Mdot
.952 .56922 Mdot
.952 .56924 Mdot
.952 .56926 Mdot
.952 .56985 Mdot
.952 .57001 Mdot
.952 .57007 Mdot
.952 .5709 Mdot
.952 .57173 Mdot
.952 .57272 Mdot
.952 .57286 Mdot
.952 .57307 Mdot
.952 .57334 Mdot
.952 .57373 Mdot
.952 .57405 Mdot
.952 .57606 Mdot
.954 .06694 Mdot
.954 .06949 Mdot
.954 .06964 Mdot
.954 .06969 Mdot
.954 .07039 Mdot
.954 .0712 Mdot
.954 .0712 Mdot
.954 .07379 Mdot
.954 .07384 Mdot
.954 .07505 Mdot
.954 .07507 Mdot
.954 .07712 Mdot
.954 .07766 Mdot
.954 .07951 Mdot
.954 .07958 Mdot
.954 .07978 Mdot
.954 .08109 Mdot
.954 .08133 Mdot
.954 .08156 Mdot
.954 .08376 Mdot
.954 .08497 Mdot
.954 .08505 Mdot
.954 .08526 Mdot
.954 .08621 Mdot
.954 .08731 Mdot
.954 .08992 Mdot
.954 .09337 Mdot
.954 .09337 Mdot
.954 .09434 Mdot
.954 .09462 Mdot
.954 .0949 Mdot
.954 .0951 Mdot
.954 .09539 Mdot
.954 .0955 Mdot
.954 .09571 Mdot
.954 .09655 Mdot
.954 .09751 Mdot
.954 .09792 Mdot
.954 .09801 Mdot
.954 .09832 Mdot
.954 .09878 Mdot
.954 .09947 Mdot
.954 .10024 Mdot
.954 .10025 Mdot
.954 .10053 Mdot
.954 .10065 Mdot
.954 .10132 Mdot
.954 .10569 Mdot
.954 .10571 Mdot
.954 .10587 Mdot
.954 .10612 Mdot
.954 .10671 Mdot
.954 .10717 Mdot
.954 .10764 Mdot
.954 .108 Mdot
.954 .10861 Mdot
.954 .11046 Mdot
.954 .11168 Mdot
.954 .11437 Mdot
.954 .11494 Mdot
.954 .11594 Mdot
.954 .11701 Mdot
.954 .11922 Mdot
.954 .11951 Mdot
.954 .1196 Mdot
.954 .12043 Mdot
.954 .12093 Mdot
.954 .12145 Mdot
.954 .12164 Mdot
.954 .12248 Mdot
.954 .12249 Mdot
.954 .12249 Mdot
.954 .12251 Mdot
.954 .12548 Mdot
.954 .1261 Mdot
.954 .12626 Mdot
.954 .12743 Mdot
.954 .12753 Mdot
.954 .12848 Mdot
.954 .1289 Mdot
.954 .12901 Mdot
.954 .12984 Mdot
.954 .12988 Mdot
.954 .12992 Mdot
.954 .12999 Mdot
.954 .13067 Mdot
.954 .13145 Mdot
.954 .13162 Mdot
.954 .13173 Mdot
.954 .13217 Mdot
.954 .13317 Mdot
.954 .1332 Mdot
.954 .13379 Mdot
.954 .13449 Mdot
.954 .13482 Mdot
.954 .13505 Mdot
.954 .13586 Mdot
.954 .13677 Mdot
.954 .13743 Mdot
.954 .1376 Mdot
.954 .13835 Mdot
.954 .13847 Mdot
.954 .13856 Mdot
.954 .13886 Mdot
.954 .13959 Mdot
.954 .14035 Mdot
.954 .14136 Mdot
.954 .14157 Mdot
.954 .14159 Mdot
.954 .14183 Mdot
.954 .14225 Mdot
.954 .14361 Mdot
.954 .14483 Mdot
.954 .14556 Mdot
.954 .14618 Mdot
.954 .14646 Mdot
.954 .14844 Mdot
.954 .14876 Mdot
.954 .14879 Mdot
.954 .14892 Mdot
.954 .14932 Mdot
.954 .14965 Mdot
.954 .14979 Mdot
.954 .15113 Mdot
.954 .15137 Mdot
.954 .15152 Mdot
.954 .15306 Mdot
.954 .15322 Mdot
.954 .15533 Mdot
.954 .15752 Mdot
.954 .15821 Mdot
.954 .15851 Mdot
.954 .15993 Mdot
.954 .16325 Mdot
.954 .16361 Mdot
.954 .16365 Mdot
.954 .16368 Mdot
.954 .16478 Mdot
.954 .16479 Mdot
.954 .16665 Mdot
.954 .16718 Mdot
.954 .16771 Mdot
.954 .16808 Mdot
.954 .16809 Mdot
.954 .16864 Mdot
.954 .16876 Mdot
.954 .16886 Mdot
.954 .16925 Mdot
.954 .16977 Mdot
.954 .17038 Mdot
.954 .17085 Mdot
.954 .1718 Mdot
.954 .17198 Mdot
.954 .17269 Mdot
.954 .17348 Mdot
.954 .17364 Mdot
.954 .17407 Mdot
.954 .17423 Mdot
.954 .17511 Mdot
.954 .17565 Mdot
.954 .17644 Mdot
.954 .17726 Mdot
.954 .1779 Mdot
.954 .17792 Mdot
.954 .17824 Mdot
.954 .17832 Mdot
.954 .17845 Mdot
.954 .17846 Mdot
.954 .17867 Mdot
.954 .17877 Mdot
.954 .1793 Mdot
.954 .17944 Mdot
.954 .17995 Mdot
.954 .18156 Mdot
.954 .18178 Mdot
.954 .18277 Mdot
.954 .18588 Mdot
.954 .18829 Mdot
.954 .18834 Mdot
.954 .18864 Mdot
.954 .18912 Mdot
.954 .19012 Mdot
.954 .19023 Mdot
.954 .19077 Mdot
.954 .19103 Mdot
.954 .19112 Mdot
.954 .19112 Mdot
.954 .19201 Mdot
.954 .19224 Mdot
.954 .19269 Mdot
.954 .19282 Mdot
.954 .19386 Mdot
.954 .19422 Mdot
.954 .19634 Mdot
.954 .1974 Mdot
.954 .19827 Mdot
.954 .1986 Mdot
.954 .19973 Mdot
.954 .20016 Mdot
.954 .20031 Mdot
.954 .20073 Mdot
.954 .20212 Mdot
.954 .20298 Mdot
.954 .2031 Mdot
.954 .20322 Mdot
.954 .20404 Mdot
.954 .20486 Mdot
.954 .20539 Mdot
.954 .20594 Mdot
.954 .20714 Mdot
.954 .20784 Mdot
.954 .20816 Mdot
.954 .20905 Mdot
.954 .2093 Mdot
.954 .20989 Mdot
.954 .21097 Mdot
.954 .21097 Mdot
.954 .21121 Mdot
.954 .2113 Mdot
.954 .21148 Mdot
.954 .21151 Mdot
.954 .21152 Mdot
.954 .21177 Mdot
.954 .21373 Mdot
.954 .21411 Mdot
.954 .21465 Mdot
.954 .21467 Mdot
.954 .21484 Mdot
.954 .21552 Mdot
.954 .21552 Mdot
.954 .21643 Mdot
.954 .21673 Mdot
.954 .21728 Mdot
.954 .21738 Mdot
.954 .21795 Mdot
.954 .21796 Mdot
.954 .21836 Mdot
.954 .21872 Mdot
.954 .21933 Mdot
.954 .21967 Mdot
.954 .22021 Mdot
.954 .22032 Mdot
.954 .22034 Mdot
.954 .22035 Mdot
.954 .2204 Mdot
.954 .22298 Mdot
.954 .22349 Mdot
.954 .22369 Mdot
.954 .22387 Mdot
.954 .22411 Mdot
.954 .22526 Mdot
.954 .2257 Mdot
.954 .22606 Mdot
.954 .22719 Mdot
.954 .22723 Mdot
.954 .22755 Mdot
.954 .22887 Mdot
.954 .22976 Mdot
.954 .22977 Mdot
.954 .22996 Mdot
.954 .23178 Mdot
.954 .23257 Mdot
.954 .23279 Mdot
.954 .23438 Mdot
.954 .23442 Mdot
.954 .23444 Mdot
.954 .23446 Mdot
.954 .23453 Mdot
.954 .23466 Mdot
.954 .23595 Mdot
.954 .23662 Mdot
.954 .23698 Mdot
.954 .23745 Mdot
.954 .23776 Mdot
.954 .23786 Mdot
.954 .23798 Mdot
.954 .23882 Mdot
.954 .23948 Mdot
.954 .24034 Mdot
.954 .24035 Mdot
.954 .24049 Mdot
.954 .24073 Mdot
.954 .24079 Mdot
.954 .24175 Mdot
.954 .2419 Mdot
.954 .24267 Mdot
.954 .24325 Mdot
.954 .24387 Mdot
.954 .24431 Mdot
.954 .24492 Mdot
.954 .24503 Mdot
.954 .24585 Mdot
.954 .24734 Mdot
.954 .2476 Mdot
.954 .24806 Mdot
.954 .24826 Mdot
.954 .24886 Mdot
.954 .24918 Mdot
.954 .2493 Mdot
.954 .25022 Mdot
.954 .25061 Mdot
.954 .25073 Mdot
.954 .25084 Mdot
.954 .25101 Mdot
.954 .25159 Mdot
.954 .25227 Mdot
.954 .25298 Mdot
.954 .25423 Mdot
.954 .25442 Mdot
.954 .25449 Mdot
.954 .25474 Mdot
.954 .25635 Mdot
.954 .25668 Mdot
.954 .25675 Mdot
.954 .25679 Mdot
.954 .25724 Mdot
.954 .25745 Mdot
.954 .25806 Mdot
.954 .25909 Mdot
.954 .25923 Mdot
.954 .25948 Mdot
.954 .26065 Mdot
.954 .26069 Mdot
.954 .26155 Mdot
.954 .26297 Mdot
.954 .26437 Mdot
.954 .26556 Mdot
.954 .26608 Mdot
.954 .26647 Mdot
.954 .26652 Mdot
.954 .26657 Mdot
.954 .26747 Mdot
.954 .26762 Mdot
.954 .26771 Mdot
.954 .26843 Mdot
.954 .26876 Mdot
.954 .269 Mdot
.954 .26986 Mdot
.954 .26986 Mdot
.954 .26987 Mdot
.954 .27001 Mdot
.954 .27047 Mdot
.954 .27054 Mdot
.954 .27078 Mdot
.954 .27154 Mdot
.954 .27217 Mdot
.954 .27244 Mdot
.954 .27298 Mdot
.954 .27403 Mdot
.954 .27461 Mdot
.954 .275 Mdot
.954 .27546 Mdot
.954 .27549 Mdot
.954 .27556 Mdot
.954 .27574 Mdot
.954 .27776 Mdot
.954 .27803 Mdot
.954 .27867 Mdot
.954 .27898 Mdot
.954 .28015 Mdot
.954 .28072 Mdot
.954 .28077 Mdot
.954 .28116 Mdot
.954 .28161 Mdot
.954 .28179 Mdot
.954 .28301 Mdot
.954 .28302 Mdot
.954 .28469 Mdot
.954 .28638 Mdot
.954 .28682 Mdot
.954 .28719 Mdot
.954 .28798 Mdot
.954 .28851 Mdot
.954 .28907 Mdot
.954 .28962 Mdot
.954 .29017 Mdot
.954 .29087 Mdot
.954 .29178 Mdot
.954 .29256 Mdot
.954 .29349 Mdot
.954 .29431 Mdot
.954 .29432 Mdot
.954 .2946 Mdot
.954 .29813 Mdot
.954 .2983 Mdot
.954 .29881 Mdot
.954 .29888 Mdot
.954 .29892 Mdot
.954 .29893 Mdot
.954 .30013 Mdot
.954 .30035 Mdot
.954 .30104 Mdot
.954 .30106 Mdot
.954 .30118 Mdot
.954 .30173 Mdot
.954 .30189 Mdot
.954 .30197 Mdot
.954 .30232 Mdot
.954 .30428 Mdot
.954 .30454 Mdot
.954 .3046 Mdot
.954 .30562 Mdot
.954 .30612 Mdot
.954 .30663 Mdot
.954 .30734 Mdot
.954 .30735 Mdot
.954 .30769 Mdot
.954 .3084 Mdot
.954 .3084 Mdot
.954 .30863 Mdot
.954 .30882 Mdot
.954 .30957 Mdot
.954 .31052 Mdot
.954 .31056 Mdot
.954 .31171 Mdot
.954 .31262 Mdot
.954 .31329 Mdot
.954 .31335 Mdot
.954 .31371 Mdot
.954 .31383 Mdot
.954 .31444 Mdot
.954 .31477 Mdot
.954 .31541 Mdot
.954 .31613 Mdot
.954 .31708 Mdot
.954 .31735 Mdot
.954 .31755 Mdot
.954 .31763 Mdot
.954 .31772 Mdot
.954 .31795 Mdot
.954 .31844 Mdot
.954 .31856 Mdot
.954 .31876 Mdot
.954 .31897 Mdot
.954 .31897 Mdot
.954 .31908 Mdot
.954 .32074 Mdot
.954 .32087 Mdot
.954 .321 Mdot
.954 .32177 Mdot
.954 .32211 Mdot
.954 .323 Mdot
.954 .32328 Mdot
.954 .32357 Mdot
.954 .32451 Mdot
.954 .32484 Mdot
.954 .32607 Mdot
.954 .32611 Mdot
.954 .32672 Mdot
.954 .32687 Mdot
.954 .32712 Mdot
.954 .32714 Mdot
.954 .32732 Mdot
.954 .32754 Mdot
.954 .32758 Mdot
.954 .32774 Mdot
.954 .32801 Mdot
.954 .32802 Mdot
.954 .32837 Mdot
.954 .32875 Mdot
.954 .329 Mdot
.954 .32918 Mdot
.954 .32949 Mdot
.954 .32998 Mdot
.954 .33032 Mdot
.954 .33121 Mdot
.954 .33159 Mdot
.954 .3323 Mdot
.954 .33254 Mdot
.954 .33305 Mdot
.954 .33347 Mdot
.954 .3341 Mdot
.954 .33497 Mdot
.954 .33536 Mdot
.954 .33628 Mdot
.954 .33639 Mdot
.954 .33807 Mdot
.954 .33968 Mdot
.954 .34012 Mdot
.954 .34039 Mdot
.954 .34045 Mdot
.954 .34054 Mdot
.954 .34068 Mdot
.954 .3413 Mdot
.954 .34249 Mdot
.954 .34424 Mdot
.954 .34589 Mdot
.954 .34598 Mdot
.954 .34646 Mdot
.954 .34657 Mdot
.954 .34719 Mdot
.954 .34725 Mdot
.954 .34748 Mdot
.954 .34833 Mdot
.954 .34938 Mdot
.954 .34945 Mdot
.954 .34947 Mdot
.954 .3496 Mdot
.954 .35014 Mdot
.954 .35063 Mdot
.954 .35112 Mdot
.954 .3513 Mdot
.954 .3513 Mdot
.954 .35268 Mdot
.954 .35299 Mdot
.954 .35343 Mdot
.954 .3543 Mdot
.954 .35454 Mdot
.954 .35582 Mdot
.954 .35583 Mdot
.954 .35653 Mdot
.954 .35677 Mdot
.954 .35721 Mdot
.954 .35745 Mdot
.954 .35745 Mdot
.954 .35749 Mdot
.954 .35809 Mdot
.954 .35937 Mdot
.954 .35957 Mdot
.954 .35962 Mdot
.954 .36073 Mdot
.954 .36126 Mdot
.954 .3614 Mdot
.954 .36328 Mdot
.954 .36463 Mdot
.954 .36464 Mdot
.954 .36494 Mdot
.954 .36526 Mdot
.954 .36532 Mdot
.954 .36556 Mdot
.954 .36556 Mdot
.954 .3656 Mdot
.954 .3667 Mdot
.954 .36686 Mdot
.954 .36711 Mdot
.954 .36773 Mdot
.954 .36854 Mdot
.954 .36884 Mdot
.954 .36963 Mdot
.954 .37099 Mdot
.954 .37227 Mdot
.954 .37228 Mdot
.954 .37236 Mdot
.954 .37337 Mdot
.954 .37387 Mdot
.954 .37393 Mdot
.954 .37416 Mdot
.954 .37431 Mdot
.954 .37438 Mdot
.954 .37501 Mdot
.954 .37595 Mdot
.954 .3775 Mdot
.954 .3776 Mdot
.954 .37807 Mdot
.954 .37853 Mdot
.954 .37871 Mdot
.954 .37894 Mdot
.954 .37957 Mdot
.954 .37961 Mdot
.954 .38016 Mdot
.954 .38031 Mdot
.954 .38134 Mdot
.954 .38153 Mdot
.954 .38185 Mdot
.954 .38217 Mdot
.954 .38251 Mdot
.954 .38271 Mdot
.954 .3832 Mdot
.954 .3838 Mdot
.954 .38383 Mdot
.954 .38429 Mdot
.954 .38551 Mdot
.954 .38599 Mdot
.954 .3868 Mdot
.954 .38711 Mdot
.954 .38742 Mdot
.954 .38743 Mdot
.954 .38831 Mdot
.954 .38917 Mdot
.954 .38918 Mdot
.954 .38962 Mdot
.954 .38979 Mdot
.954 .39015 Mdot
.954 .3902 Mdot
.954 .39022 Mdot
.954 .39071 Mdot
.954 .39159 Mdot
.954 .39159 Mdot
.954 .39176 Mdot
.954 .39178 Mdot
.954 .39186 Mdot
.954 .39227 Mdot
.954 .39371 Mdot
.954 .39399 Mdot
.954 .39425 Mdot
.954 .39444 Mdot
.954 .39515 Mdot
.954 .39546 Mdot
.954 .39586 Mdot
.954 .39618 Mdot
.954 .39623 Mdot
.954 .3965 Mdot
.954 .39656 Mdot
.954 .39687 Mdot
.954 .39699 Mdot
.954 .39768 Mdot
.954 .39785 Mdot
.954 .39785 Mdot
.954 .3981 Mdot
.954 .399 Mdot
.954 .39958 Mdot
.954 .39966 Mdot
.954 .40017 Mdot
.954 .40035 Mdot
.954 .40045 Mdot
.954 .40048 Mdot
.954 .40121 Mdot
.954 .4014 Mdot
.954 .40249 Mdot
.954 .40251 Mdot
.954 .40256 Mdot
.954 .40293 Mdot
.954 .40327 Mdot
.954 .40396 Mdot
.954 .40432 Mdot
.954 .40439 Mdot
.954 .40458 Mdot
.954 .40492 Mdot
.954 .40513 Mdot
.954 .40576 Mdot
.954 .4059 Mdot
.954 .40604 Mdot
.954 .4068 Mdot
.954 .40701 Mdot
.954 .40705 Mdot
.954 .40706 Mdot
.954 .40715 Mdot
.954 .40715 Mdot
.954 .40887 Mdot
.954 .40934 Mdot
.954 .40934 Mdot
.954 .40966 Mdot
.954 .41098 Mdot
.954 .41122 Mdot
.954 .41181 Mdot
.954 .41191 Mdot
.954 .41209 Mdot
.954 .41242 Mdot
.954 .41252 Mdot
.954 .41306 Mdot
.954 .41315 Mdot
.954 .41344 Mdot
.954 .41379 Mdot
.954 .41391 Mdot
.954 .41424 Mdot
.954 .41449 Mdot
.954 .41584 Mdot
.954 .41621 Mdot
.954 .41644 Mdot
.954 .4167 Mdot
.954 .41724 Mdot
.954 .41728 Mdot
.954 .41795 Mdot
.954 .41999 Mdot
.954 .42011 Mdot
.954 .4202 Mdot
.954 .42078 Mdot
.954 .4208 Mdot
.954 .42092 Mdot
.954 .42096 Mdot
.954 .42128 Mdot
.954 .42129 Mdot
.954 .42297 Mdot
.954 .42333 Mdot
.954 .42391 Mdot
.954 .42394 Mdot
.954 .42404 Mdot
.954 .42471 Mdot
.954 .42503 Mdot
.954 .42505 Mdot
.954 .42505 Mdot
.954 .4254 Mdot
.954 .42589 Mdot
.954 .4259 Mdot
.954 .42755 Mdot
.954 .42888 Mdot
.954 .42923 Mdot
.954 .42924 Mdot
.954 .42983 Mdot
.954 .43039 Mdot
.954 .43043 Mdot
.954 .43081 Mdot
.954 .43197 Mdot
.954 .43289 Mdot
.954 .43383 Mdot
.954 .43391 Mdot
.954 .43396 Mdot
.954 .43399 Mdot
.954 .43413 Mdot
.954 .43436 Mdot
.954 .43521 Mdot
.954 .43608 Mdot
.954 .43615 Mdot
.954 .43683 Mdot
.954 .43729 Mdot
.954 .4381 Mdot
.954 .43823 Mdot
.954 .4386 Mdot
.954 .4388 Mdot
.954 .43927 Mdot
.954 .4397 Mdot
.954 .43986 Mdot
.954 .44029 Mdot
.954 .44047 Mdot
.954 .44048 Mdot
.954 .4407 Mdot
.954 .44084 Mdot
.954 .44231 Mdot
.954 .4428 Mdot
.954 .4431 Mdot
.954 .44357 Mdot
.954 .44415 Mdot
.954 .44422 Mdot
.954 .44522 Mdot
.954 .44522 Mdot
.954 .44543 Mdot
.954 .44549 Mdot
.954 .44587 Mdot
.954 .44596 Mdot
.954 .44607 Mdot
.954 .44621 Mdot
.954 .44708 Mdot
.954 .44791 Mdot
.954 .44797 Mdot
.954 .44816 Mdot
.954 .44819 Mdot
.954 .44964 Mdot
.954 .45075 Mdot
.954 .45113 Mdot
.954 .45195 Mdot
.954 .45278 Mdot
.954 .45291 Mdot
.954 .45394 Mdot
.954 .45413 Mdot
.954 .45416 Mdot
.954 .45425 Mdot
.954 .45454 Mdot
.954 .45498 Mdot
.954 .45509 Mdot
.954 .45572 Mdot
.954 .45605 Mdot
.954 .45799 Mdot
.954 .45813 Mdot
.954 .45814 Mdot
.954 .45857 Mdot
.954 .45906 Mdot
.954 .45994 Mdot
.954 .46031 Mdot
.954 .4606 Mdot
.954 .46146 Mdot
.954 .46207 Mdot
.954 .4623 Mdot
.954 .46318 Mdot
.954 .46406 Mdot
.954 .4647 Mdot
.954 .4648 Mdot
.954 .46503 Mdot
.954 .46524 Mdot
.954 .46526 Mdot
.954 .46556 Mdot
.954 .46667 Mdot
.954 .46682 Mdot
.954 .46797 Mdot
.954 .468 Mdot
.954 .46846 Mdot
.954 .46877 Mdot
.954 .46932 Mdot
.954 .47088 Mdot
.954 .47095 Mdot
.954 .47095 Mdot
.954 .4714 Mdot
.954 .47153 Mdot
.954 .47171 Mdot
.954 .47208 Mdot
.954 .47213 Mdot
.954 .47221 Mdot
.954 .47268 Mdot
.954 .47271 Mdot
.954 .47273 Mdot
.954 .47531 Mdot
.954 .47576 Mdot
.954 .47639 Mdot
.954 .47653 Mdot
.954 .4766 Mdot
.954 .47746 Mdot
.954 .47786 Mdot
.954 .47888 Mdot
.954 .47901 Mdot
.954 .47915 Mdot
.954 .48017 Mdot
.954 .48098 Mdot
.954 .48125 Mdot
.954 .48173 Mdot
.954 .48228 Mdot
.954 .48238 Mdot
.954 .48276 Mdot
.954 .48397 Mdot
.954 .48403 Mdot
.954 .48521 Mdot
.954 .48568 Mdot
.954 .48635 Mdot
.954 .48642 Mdot
.954 .48642 Mdot
.954 .48688 Mdot
.954 .48773 Mdot
.954 .48819 Mdot
.954 .48838 Mdot
.954 .48951 Mdot
.954 .48953 Mdot
.954 .49197 Mdot
.954 .49244 Mdot
.954 .49332 Mdot
.954 .4941 Mdot
.954 .49433 Mdot
.954 .49493 Mdot
.954 .49506 Mdot
.954 .49515 Mdot
.954 .49526 Mdot
.954 .49552 Mdot
.954 .49698 Mdot
.954 .49726 Mdot
.954 .49744 Mdot
.954 .49815 Mdot
.954 .49816 Mdot
.954 .49851 Mdot
.954 .4988 Mdot
.954 .49943 Mdot
.954 .49943 Mdot
.954 .49989 Mdot
.954 .50037 Mdot
.954 .5014 Mdot
.954 .50153 Mdot
.954 .50154 Mdot
.954 .50155 Mdot
.954 .50165 Mdot
.954 .5017 Mdot
.954 .50182 Mdot
.954 .50182 Mdot
.954 .50269 Mdot
.954 .50282 Mdot
.954 .50329 Mdot
.954 .50383 Mdot
.954 .50474 Mdot
.954 .50545 Mdot
.954 .50588 Mdot
.954 .50594 Mdot
.954 .506 Mdot
.954 .50646 Mdot
.954 .50719 Mdot
.954 .5074 Mdot
.954 .50748 Mdot
.954 .5083 Mdot
.954 .50847 Mdot
.954 .50948 Mdot
.954 .5106 Mdot
.954 .51133 Mdot
.954 .51164 Mdot
.954 .51222 Mdot
.954 .51227 Mdot
.954 .5124 Mdot
.954 .51275 Mdot
.954 .51497 Mdot
.954 .5166 Mdot
.954 .51712 Mdot
.954 .51723 Mdot
.954 .51835 Mdot
.954 .51842 Mdot
.954 .51869 Mdot
.954 .51886 Mdot
.954 .51893 Mdot
.954 .51897 Mdot
.954 .51949 Mdot
.954 .52033 Mdot
.954 .52116 Mdot
.954 .52226 Mdot
.954 .52235 Mdot
.954 .52309 Mdot
.954 .52341 Mdot
.954 .52394 Mdot
.954 .5243 Mdot
.954 .52661 Mdot
.954 .52662 Mdot
.954 .52664 Mdot
.954 .52683 Mdot
.954 .52857 Mdot
.954 .52932 Mdot
.954 .52983 Mdot
.954 .53098 Mdot
.954 .53217 Mdot
.954 .53298 Mdot
.954 .53305 Mdot
.954 .53388 Mdot
.954 .53396 Mdot
.954 .53441 Mdot
.954 .53459 Mdot
.954 .53577 Mdot
.954 .5361 Mdot
.954 .53649 Mdot
.954 .53712 Mdot
.954 .53818 Mdot
.954 .53819 Mdot
.954 .53883 Mdot
.954 .53923 Mdot
.954 .53977 Mdot
.954 .54027 Mdot
.954 .54036 Mdot
.954 .54071 Mdot
.954 .54119 Mdot
.954 .54161 Mdot
.954 .5419 Mdot
.954 .54258 Mdot
.954 .54259 Mdot
.954 .54312 Mdot
.954 .54335 Mdot
.954 .54341 Mdot
.954 .54349 Mdot
.954 .54391 Mdot
.954 .54426 Mdot
.954 .5443 Mdot
.954 .54477 Mdot
.954 .54483 Mdot
.954 .54505 Mdot
.954 .54622 Mdot
.954 .5463 Mdot
.954 .54662 Mdot
.954 .54818 Mdot
.954 .5482 Mdot
.954 .54864 Mdot
.954 .54874 Mdot
.954 .54927 Mdot
.954 .55106 Mdot
.954 .55163 Mdot
.954 .55215 Mdot
.954 .55386 Mdot
.954 .5545 Mdot
.954 .55547 Mdot
.954 .55579 Mdot
.954 .55598 Mdot
.954 .55622 Mdot
.954 .55646 Mdot
.954 .55677 Mdot
.954 .5569 Mdot
.954 .55699 Mdot
.954 .557 Mdot
.954 .55929 Mdot
.954 .55964 Mdot
.954 .5597 Mdot
.954 .55985 Mdot
.954 .55985 Mdot
.954 .56025 Mdot
.954 .56062 Mdot
.954 .56086 Mdot
.954 .56102 Mdot
.954 .56107 Mdot
.954 .56128 Mdot
.954 .56179 Mdot
.954 .56223 Mdot
.954 .56234 Mdot
.954 .5624 Mdot
.954 .56255 Mdot
.954 .56265 Mdot
.954 .5628 Mdot
.954 .56294 Mdot
.954 .56345 Mdot
.954 .56346 Mdot
.954 .56526 Mdot
.954 .56663 Mdot
.954 .56721 Mdot
.954 .5677 Mdot
.954 .56781 Mdot
.954 .56786 Mdot
.954 .56849 Mdot
.954 .56964 Mdot
.954 .56976 Mdot
.954 .56989 Mdot
.954 .57058 Mdot
.954 .57068 Mdot
.954 .57072 Mdot
.954 .57169 Mdot
.954 .57197 Mdot
.954 .57304 Mdot
.954 .57305 Mdot
.954 .57369 Mdot
.954 .57372 Mdot
.954 .57507 Mdot
.954 .57507 Mdot
.954 .5755 Mdot
.954 .57587 Mdot
.954 .57589 Mdot
.954 .57597 Mdot
.954 .5773 Mdot
.956 .06481 Mdot
.956 .06664 Mdot
.956 .06804 Mdot
.956 .06901 Mdot
.956 .06903 Mdot
.956 .06934 Mdot
.956 .06947 Mdot
.956 .0726 Mdot
.956 .07313 Mdot
.956 .07376 Mdot
.956 .07426 Mdot
.956 .0745 Mdot
.956 .07591 Mdot
.956 .07847 Mdot
.956 .07871 Mdot
.956 .07888 Mdot
.956 .07898 Mdot
.956 .08057 Mdot
.956 .08066 Mdot
.956 .08066 Mdot
.956 .08106 Mdot
.956 .0839 Mdot
.956 .08397 Mdot
.956 .08455 Mdot
.956 .08482 Mdot
.956 .08531 Mdot
.956 .08546 Mdot
.956 .08548 Mdot
.956 .086 Mdot
.956 .0867 Mdot
.956 .08696 Mdot
.956 .08723 Mdot
.956 .08766 Mdot
.956 .08936 Mdot
.956 .0906 Mdot
.956 .09106 Mdot
.956 .09213 Mdot
.956 .09394 Mdot
.956 .09558 Mdot
.956 .0965 Mdot
.956 .09663 Mdot
.956 .09907 Mdot
.956 .09947 Mdot
.956 .0996 Mdot
.956 .10078 Mdot
.956 .10183 Mdot
.956 .10329 Mdot
.956 .10348 Mdot
.956 .10417 Mdot
.956 .10606 Mdot
.956 .10626 Mdot
.956 .10785 Mdot
.956 .10798 Mdot
.956 .10799 Mdot
.956 .10816 Mdot
.956 .1105 Mdot
.956 .11207 Mdot
.956 .11332 Mdot
.956 .114 Mdot
.956 .1141 Mdot
.956 .11668 Mdot
.956 .11852 Mdot
.956 .11856 Mdot
.956 .11864 Mdot
.956 .11916 Mdot
.956 .11941 Mdot
.956 .11965 Mdot
.956 .1204 Mdot
.956 .12105 Mdot
.956 .12145 Mdot
.956 .12164 Mdot
.956 .12212 Mdot
.956 .1224 Mdot
.956 .12241 Mdot
.956 .12418 Mdot
.956 .12519 Mdot
.956 .12539 Mdot
.956 .1264 Mdot
.956 .1276 Mdot
.956 .12826 Mdot
.956 .12838 Mdot
.956 .12857 Mdot
.956 .12859 Mdot
.956 .12903 Mdot
.956 .1305 Mdot
.956 .13053 Mdot
.956 .13075 Mdot
.956 .13173 Mdot
.956 .13281 Mdot
.956 .13298 Mdot
.956 .133 Mdot
.956 .13313 Mdot
.956 .13355 Mdot
.956 .13371 Mdot
.956 .13371 Mdot
.956 .13404 Mdot
.956 .13515 Mdot
.956 .13553 Mdot
.956 .13613 Mdot
.956 .13635 Mdot
.956 .13661 Mdot
.956 .13707 Mdot
.956 .13718 Mdot
.956 .13739 Mdot
.956 .13759 Mdot
.956 .13762 Mdot
.956 .13914 Mdot
.956 .14042 Mdot
.956 .14063 Mdot
.956 .14081 Mdot
.956 .14081 Mdot
.956 .14156 Mdot
.956 .1435 Mdot
.956 .14415 Mdot
.956 .14472 Mdot
.956 .14519 Mdot
.956 .14564 Mdot
.956 .14592 Mdot
.956 .147 Mdot
.956 .1471 Mdot
.956 .14712 Mdot
.956 .14823 Mdot
.956 .14832 Mdot
.956 .14861 Mdot
.956 .14876 Mdot
.956 .14969 Mdot
.956 .14998 Mdot
.956 .15001 Mdot
.956 .15025 Mdot
.956 .15032 Mdot
.956 .15102 Mdot
.956 .15108 Mdot
.956 .15166 Mdot
.956 .15235 Mdot
.956 .15252 Mdot
.956 .15285 Mdot
.956 .15336 Mdot
.956 .15373 Mdot
.956 .15419 Mdot
.956 .15743 Mdot
.956 .15869 Mdot
.956 .15909 Mdot
.956 .15915 Mdot
.956 .15953 Mdot
.956 .1598 Mdot
.956 .16069 Mdot
.956 .16073 Mdot
.956 .16273 Mdot
.956 .16597 Mdot
.956 .16619 Mdot
.956 .16692 Mdot
.956 .16765 Mdot
.956 .16781 Mdot
.956 .16828 Mdot
.956 .16932 Mdot
.956 .16973 Mdot
.956 .17105 Mdot
.956 .17109 Mdot
.956 .17133 Mdot
.956 .17188 Mdot
.956 .17223 Mdot
.956 .17323 Mdot
.956 .17361 Mdot
.956 .17404 Mdot
.956 .17524 Mdot
.956 .176 Mdot
.956 .17676 Mdot
.956 .17701 Mdot
.956 .17716 Mdot
.956 .1773 Mdot
.956 .17879 Mdot
.956 .17926 Mdot
.956 .17948 Mdot
.956 .17969 Mdot
.956 .18066 Mdot
.956 .18128 Mdot
.956 .18149 Mdot
.956 .18377 Mdot
.956 .18407 Mdot
.956 .18443 Mdot
.956 .18515 Mdot
.956 .1855 Mdot
.956 .18575 Mdot
.956 .1869 Mdot
.956 .18862 Mdot
.956 .18935 Mdot
.956 .18937 Mdot
.956 .18953 Mdot
.956 .18956 Mdot
.956 .18975 Mdot
.956 .19 Mdot
.956 .19279 Mdot
.956 .19303 Mdot
.956 .19305 Mdot
.956 .19332 Mdot
.956 .19338 Mdot
.956 .19487 Mdot
.956 .19534 Mdot
.956 .19705 Mdot
.956 .19724 Mdot
.956 .19785 Mdot
.956 .19835 Mdot
.956 .19905 Mdot
.956 .1993 Mdot
.956 .19983 Mdot
.956 .20038 Mdot
.956 .20086 Mdot
.956 .20112 Mdot
.956 .20131 Mdot
.956 .20132 Mdot
.956 .2015 Mdot
.956 .20325 Mdot
.956 .20455 Mdot
.956 .20473 Mdot
.956 .20514 Mdot
.956 .2058 Mdot
.956 .2066 Mdot
.956 .20678 Mdot
.956 .20681 Mdot
.956 .20682 Mdot
.956 .20787 Mdot
.956 .20807 Mdot
.956 .2083 Mdot
.956 .20882 Mdot
.956 .20946 Mdot
.956 .20946 Mdot
.956 .20967 Mdot
.956 .21112 Mdot
.956 .21116 Mdot
.956 .21319 Mdot
.956 .21327 Mdot
.956 .21343 Mdot
.956 .2144 Mdot
.956 .21488 Mdot
.956 .21536 Mdot
.956 .21678 Mdot
.956 .21723 Mdot
.956 .21738 Mdot
.956 .21802 Mdot
.956 .2181 Mdot
.956 .21867 Mdot
.956 .21871 Mdot
.956 .2188 Mdot
.956 .21887 Mdot
.956 .21915 Mdot
.956 .21948 Mdot
.956 .22007 Mdot
.956 .22062 Mdot
.956 .22064 Mdot
.956 .22291 Mdot
.956 .22306 Mdot
.956 .22394 Mdot
.956 .22402 Mdot
.956 .22512 Mdot
.956 .22563 Mdot
.956 .22595 Mdot
.956 .22632 Mdot
.956 .22758 Mdot
.956 .22826 Mdot
.956 .22826 Mdot
.956 .23055 Mdot
.956 .23071 Mdot
.956 .23072 Mdot
.956 .23103 Mdot
.956 .23181 Mdot
.956 .23205 Mdot
.956 .23235 Mdot
.956 .2324 Mdot
.956 .23245 Mdot
.956 .2325 Mdot
.956 .23328 Mdot
.956 .23365 Mdot
.956 .23402 Mdot
.956 .23438 Mdot
.956 .23481 Mdot
.956 .23609 Mdot
.956 .23615 Mdot
.956 .23657 Mdot
.956 .23661 Mdot
.956 .23803 Mdot
.956 .23844 Mdot
.956 .23945 Mdot
.956 .23966 Mdot
.956 .23996 Mdot
.956 .2405 Mdot
.956 .24062 Mdot
.956 .24084 Mdot
.956 .24087 Mdot
.956 .241 Mdot
.956 .24101 Mdot
.956 .24105 Mdot
.956 .24112 Mdot
.956 .24193 Mdot
.956 .24223 Mdot
.956 .24223 Mdot
.956 .24255 Mdot
.956 .24286 Mdot
.956 .2438 Mdot
.956 .24383 Mdot
.956 .24426 Mdot
.956 .24492 Mdot
.956 .24499 Mdot
.956 .24518 Mdot
.956 .24531 Mdot
.956 .2457 Mdot
.956 .24687 Mdot
.956 .24727 Mdot
.956 .24777 Mdot
.956 .24851 Mdot
.956 .24867 Mdot
.956 .24887 Mdot
.956 .24927 Mdot
.956 .24964 Mdot
.956 .2497 Mdot
.956 .25261 Mdot
.956 .25506 Mdot
.956 .25547 Mdot
.956 .25572 Mdot
.956 .2558 Mdot
.956 .2558 Mdot
.956 .25581 Mdot
.956 .25612 Mdot
.956 .25724 Mdot
.956 .2602 Mdot
.956 .26048 Mdot
.956 .26061 Mdot
.956 .26095 Mdot
.956 .26136 Mdot
.956 .26137 Mdot
.956 .26137 Mdot
.956 .26166 Mdot
.956 .2618 Mdot
.956 .26219 Mdot
.956 .26257 Mdot
.956 .26328 Mdot
.956 .2641 Mdot
.956 .26419 Mdot
.956 .26486 Mdot
.956 .26505 Mdot
.956 .26558 Mdot
.956 .26604 Mdot
.956 .26743 Mdot
.956 .26764 Mdot
.956 .26783 Mdot
.956 .26788 Mdot
.956 .26955 Mdot
.956 .27 Mdot
.956 .27018 Mdot
.956 .27072 Mdot
.956 .271 Mdot
.956 .27278 Mdot
.956 .27304 Mdot
.956 .27334 Mdot
.956 .2734 Mdot
.956 .27386 Mdot
.956 .27399 Mdot
.956 .27442 Mdot
.956 .27533 Mdot
.956 .27545 Mdot
.956 .2755 Mdot
.956 .27617 Mdot
.956 .27656 Mdot
.956 .27788 Mdot
.956 .2782 Mdot
.956 .27884 Mdot
.956 .27981 Mdot
.956 .27991 Mdot
.956 .28051 Mdot
.956 .28139 Mdot
.956 .28164 Mdot
.956 .28366 Mdot
.956 .28376 Mdot
.956 .28389 Mdot
.956 .28525 Mdot
.956 .28665 Mdot
.956 .28673 Mdot
.956 .28706 Mdot
.956 .28746 Mdot
.956 .28758 Mdot
.956 .28805 Mdot
.956 .28889 Mdot
.956 .29 Mdot
.956 .29023 Mdot
.956 .29033 Mdot
.956 .29072 Mdot
.956 .29077 Mdot
.956 .29088 Mdot
.956 .29092 Mdot
.956 .29153 Mdot
.956 .29159 Mdot
.956 .29212 Mdot
.956 .29256 Mdot
.956 .29381 Mdot
.956 .29389 Mdot
.956 .29403 Mdot
.956 .29609 Mdot
.956 .29664 Mdot
.956 .29771 Mdot
.956 .29776 Mdot
.956 .29829 Mdot
.956 .2988 Mdot
.956 .29904 Mdot
.956 .29973 Mdot
.956 .3002 Mdot
.956 .3009 Mdot
.956 .30115 Mdot
.956 .30286 Mdot
.956 .30358 Mdot
.956 .30377 Mdot
.956 .30392 Mdot
.956 .30433 Mdot
.956 .30513 Mdot
.956 .30523 Mdot
.956 .30572 Mdot
.956 .30712 Mdot
.956 .30744 Mdot
.956 .30833 Mdot
.956 .30869 Mdot
.956 .30982 Mdot
.956 .31032 Mdot
.956 .31097 Mdot
.956 .31098 Mdot
.956 .3111 Mdot
.956 .3121 Mdot
.956 .31241 Mdot
.956 .31247 Mdot
.956 .31286 Mdot
.956 .31356 Mdot
.956 .31363 Mdot
.956 .3137 Mdot
.956 .31413 Mdot
.956 .31416 Mdot
.956 .31504 Mdot
.956 .31522 Mdot
.956 .3153 Mdot
.956 .31543 Mdot
.956 .31547 Mdot
.956 .31588 Mdot
.956 .31596 Mdot
.956 .31607 Mdot
.956 .31688 Mdot
.956 .317 Mdot
.956 .3173 Mdot
.956 .31779 Mdot
.956 .31853 Mdot
.956 .3193 Mdot
.956 .31934 Mdot
.956 .3204 Mdot
.956 .32116 Mdot
.956 .3216 Mdot
.956 .32163 Mdot
.956 .32309 Mdot
.956 .32455 Mdot
.956 .32482 Mdot
.956 .32503 Mdot
.956 .32521 Mdot
.956 .32532 Mdot
.956 .32558 Mdot
.956 .32606 Mdot
.956 .32634 Mdot
.956 .32718 Mdot
.956 .32721 Mdot
.956 .32779 Mdot
.956 .32842 Mdot
.956 .32847 Mdot
.956 .32867 Mdot
.956 .32876 Mdot
.956 .32933 Mdot
.956 .32962 Mdot
.956 .32974 Mdot
.956 .33015 Mdot
.956 .33152 Mdot
.956 .33168 Mdot
.956 .33201 Mdot
.956 .3332 Mdot
.956 .33321 Mdot
.956 .33342 Mdot
.956 .33358 Mdot
.956 .33382 Mdot
.956 .33561 Mdot
.956 .33606 Mdot
.956 .33749 Mdot
.956 .33795 Mdot
.956 .33813 Mdot
.956 .33852 Mdot
.956 .33911 Mdot
.956 .33921 Mdot
.956 .3397 Mdot
.956 .34003 Mdot
.956 .34059 Mdot
.956 .341 Mdot
.956 .34125 Mdot
.956 .34174 Mdot
.956 .34236 Mdot
.956 .34274 Mdot
.956 .34369 Mdot
.956 .34394 Mdot
.956 .34654 Mdot
.956 .34676 Mdot
.956 .34691 Mdot
.956 .34711 Mdot
.956 .34716 Mdot
.956 .34717 Mdot
.956 .34721 Mdot
.956 .34821 Mdot
.956 .34861 Mdot
.956 .34866 Mdot
.956 .34867 Mdot
.956 .34896 Mdot
.956 .34901 Mdot
.956 .34907 Mdot
.956 .34939 Mdot
.956 .34986 Mdot
.956 .35191 Mdot
.956 .35192 Mdot
.956 .35213 Mdot
.956 .35307 Mdot
.956 .35311 Mdot
.956 .35367 Mdot
.956 .3552 Mdot
.956 .35565 Mdot
.956 .35569 Mdot
.956 .35601 Mdot
.956 .35621 Mdot
.956 .35632 Mdot
.956 .35765 Mdot
.956 .35791 Mdot
.956 .35879 Mdot
.956 .35909 Mdot
.956 .35916 Mdot
.956 .36007 Mdot
.956 .36205 Mdot
.956 .36207 Mdot
.956 .36335 Mdot
.956 .36338 Mdot
.956 .36371 Mdot
.956 .36454 Mdot
.956 .36487 Mdot
.956 .36525 Mdot
.956 .36583 Mdot
.956 .36716 Mdot
.956 .36746 Mdot
.956 .36764 Mdot
.956 .36866 Mdot
.956 .36914 Mdot
.956 .36972 Mdot
.956 .3705 Mdot
.956 .37062 Mdot
.956 .37112 Mdot
.956 .37148 Mdot
.956 .37151 Mdot
.956 .37167 Mdot
.956 .37184 Mdot
.956 .37309 Mdot
.956 .37324 Mdot
.956 .37354 Mdot
.956 .37383 Mdot
.956 .3739 Mdot
.956 .37494 Mdot
.956 .37519 Mdot
.956 .37755 Mdot
.956 .37757 Mdot
.956 .37768 Mdot
.956 .37787 Mdot
.956 .37802 Mdot
.956 .37881 Mdot
.956 .38007 Mdot
.956 .38105 Mdot
.956 .38129 Mdot
.956 .38159 Mdot
.956 .3816 Mdot
.956 .38176 Mdot
.956 .38195 Mdot
.956 .382 Mdot
.956 .38202 Mdot
.956 .38226 Mdot
.956 .38341 Mdot
.956 .3839 Mdot
.956 .38402 Mdot
.956 .38441 Mdot
.956 .38486 Mdot
.956 .38511 Mdot
.956 .38585 Mdot
.956 .38706 Mdot
.956 .38706 Mdot
.956 .38747 Mdot
.956 .38836 Mdot
.956 .38842 Mdot
.956 .38948 Mdot
.956 .38993 Mdot
.956 .39 Mdot
.956 .39024 Mdot
.956 .39032 Mdot
.956 .39149 Mdot
.956 .39201 Mdot
.956 .39261 Mdot
.956 .39415 Mdot
.956 .39419 Mdot
.956 .39435 Mdot
.956 .39437 Mdot
.956 .39466 Mdot
.956 .39537 Mdot
.956 .39639 Mdot
.956 .39652 Mdot
.956 .39666 Mdot
.956 .39697 Mdot
.956 .39711 Mdot
.956 .39744 Mdot
.956 .39833 Mdot
.956 .39834 Mdot
.956 .39863 Mdot
.956 .39919 Mdot
.956 .39949 Mdot
.956 .39997 Mdot
.956 .40105 Mdot
.956 .40114 Mdot
.956 .4015 Mdot
.956 .40182 Mdot
.956 .40192 Mdot
.956 .40222 Mdot
.956 .40238 Mdot
.956 .40257 Mdot
.956 .40318 Mdot
.956 .40344 Mdot
.956 .4036 Mdot
.956 .40388 Mdot
.956 .40404 Mdot
.956 .40468 Mdot
.956 .40475 Mdot
.956 .40492 Mdot
.956 .40506 Mdot
.956 .40559 Mdot
.956 .40611 Mdot
.956 .40623 Mdot
.956 .40703 Mdot
.956 .40735 Mdot
.956 .40762 Mdot
.956 .4084 Mdot
.956 .40844 Mdot
.956 .40867 Mdot
.956 .40923 Mdot
.956 .40926 Mdot
.956 .41096 Mdot
.956 .41159 Mdot
.956 .41185 Mdot
.956 .41245 Mdot
.956 .41271 Mdot
.956 .41279 Mdot
.956 .41296 Mdot
.956 .41308 Mdot
.956 .41475 Mdot
.956 .4149 Mdot
.956 .41491 Mdot
.956 .41628 Mdot
.956 .41682 Mdot
.956 .41686 Mdot
.956 .41701 Mdot
.956 .41717 Mdot
.956 .41724 Mdot
.956 .41798 Mdot
.956 .4186 Mdot
.956 .41931 Mdot
.956 .42019 Mdot
.956 .42134 Mdot
.956 .42171 Mdot
.956 .42232 Mdot
.956 .42301 Mdot
.956 .42302 Mdot
.956 .42457 Mdot
.956 .42472 Mdot
.956 .42518 Mdot
.956 .42532 Mdot
.956 .42618 Mdot
.956 .4274 Mdot
.956 .42769 Mdot
.956 .42771 Mdot
.956 .4282 Mdot
.956 .42831 Mdot
.956 .42832 Mdot
.956 .4298 Mdot
.956 .43002 Mdot
.956 .43026 Mdot
.956 .4308 Mdot
.956 .4308 Mdot
.956 .43083 Mdot
.956 .43094 Mdot
.956 .43102 Mdot
.956 .43113 Mdot
.956 .43262 Mdot
.956 .43312 Mdot
.956 .43331 Mdot
.956 .43403 Mdot
.956 .43453 Mdot
.956 .43471 Mdot
.956 .43501 Mdot
.956 .43553 Mdot
.956 .43586 Mdot
.956 .43661 Mdot
.956 .43684 Mdot
.956 .43778 Mdot
.956 .43799 Mdot
.956 .4381 Mdot
.956 .4389 Mdot
.956 .43898 Mdot
.956 .43998 Mdot
.956 .44043 Mdot
.956 .44048 Mdot
.956 .44058 Mdot
.956 .44093 Mdot
.956 .44124 Mdot
.956 .44126 Mdot
.956 .44169 Mdot
.956 .44184 Mdot
.956 .44229 Mdot
.956 .44249 Mdot
.956 .44417 Mdot
.956 .4444 Mdot
.956 .4448 Mdot
.956 .44537 Mdot
.956 .44642 Mdot
.956 .44658 Mdot
.956 .44664 Mdot
.956 .44706 Mdot
.956 .44713 Mdot
.956 .44738 Mdot
.956 .4474 Mdot
.956 .44747 Mdot
.956 .4476 Mdot
.956 .44808 Mdot
.956 .44838 Mdot
.956 .44874 Mdot
.956 .44895 Mdot
.956 .44898 Mdot
.956 .44914 Mdot
.956 .44973 Mdot
.956 .44973 Mdot
.956 .45033 Mdot
.956 .45093 Mdot
.956 .45273 Mdot
.956 .45279 Mdot
.956 .4535 Mdot
.956 .4536 Mdot
.956 .45398 Mdot
.956 .45487 Mdot
.956 .455 Mdot
.956 .45537 Mdot
.956 .45561 Mdot
.956 .45597 Mdot
.956 .4561 Mdot
.956 .45637 Mdot
.956 .45664 Mdot
.956 .45723 Mdot
.956 .45752 Mdot
.956 .45859 Mdot
.956 .45936 Mdot
.956 .4599 Mdot
.956 .46022 Mdot
.956 .46032 Mdot
.956 .46053 Mdot
.956 .46058 Mdot
.956 .46128 Mdot
.956 .46172 Mdot
.956 .46203 Mdot
.956 .46224 Mdot
.956 .46241 Mdot
.956 .46245 Mdot
.956 .46319 Mdot
.956 .4639 Mdot
.956 .46396 Mdot
.956 .46402 Mdot
.956 .46507 Mdot
.956 .46598 Mdot
.956 .46793 Mdot
.956 .46828 Mdot
.956 .46885 Mdot
.956 .46957 Mdot
.956 .4714 Mdot
.956 .47251 Mdot
.956 .47323 Mdot
.956 .47385 Mdot
.956 .47425 Mdot
.956 .47504 Mdot
.956 .47545 Mdot
.956 .47552 Mdot
.956 .47567 Mdot
.956 .47567 Mdot
.956 .47568 Mdot
.956 .47607 Mdot
.956 .47614 Mdot
.956 .47629 Mdot
.956 .47842 Mdot
.956 .47859 Mdot
.956 .47863 Mdot
.956 .4824 Mdot
.956 .48407 Mdot
.956 .48414 Mdot
.956 .48428 Mdot
.956 .48463 Mdot
.956 .48485 Mdot
.956 .48486 Mdot
.956 .48552 Mdot
.956 .4863 Mdot
.956 .48632 Mdot
.956 .48633 Mdot
.956 .48653 Mdot
.956 .48687 Mdot
.956 .48703 Mdot
.956 .48714 Mdot
.956 .48788 Mdot
.956 .48862 Mdot
.956 .48957 Mdot
.956 .48979 Mdot
.956 .48998 Mdot
.956 .49017 Mdot
.956 .49077 Mdot
.956 .49085 Mdot
.956 .49154 Mdot
.956 .49171 Mdot
.956 .49171 Mdot
.956 .49299 Mdot
.956 .49335 Mdot
.956 .49437 Mdot
.956 .49463 Mdot
.956 .49525 Mdot
.956 .49571 Mdot
.956 .49579 Mdot
.956 .49758 Mdot
.956 .4979 Mdot
.956 .49799 Mdot
.956 .49801 Mdot
.956 .4983 Mdot
.956 .49868 Mdot
.956 .49876 Mdot
.956 .50193 Mdot
.956 .50196 Mdot
.956 .50283 Mdot
.956 .50283 Mdot
.956 .50316 Mdot
.956 .50343 Mdot
.956 .50355 Mdot
.956 .50366 Mdot
.956 .5042 Mdot
.956 .50421 Mdot
.956 .50422 Mdot
.956 .50432 Mdot
.956 .50474 Mdot
.956 .50508 Mdot
.956 .50699 Mdot
.956 .50708 Mdot
.956 .50709 Mdot
.956 .50719 Mdot
.956 .50757 Mdot
.956 .50786 Mdot
.956 .50814 Mdot
.956 .50827 Mdot
.956 .50863 Mdot
.956 .50921 Mdot
.956 .50931 Mdot
.956 .51021 Mdot
.956 .51046 Mdot
.956 .51127 Mdot
.956 .513 Mdot
.956 .51323 Mdot
.956 .51325 Mdot
.956 .51334 Mdot
.956 .51373 Mdot
.956 .51462 Mdot
.956 .51536 Mdot
.956 .51554 Mdot
.956 .51626 Mdot
.956 .51745 Mdot
.956 .51788 Mdot
.956 .51839 Mdot
.956 .51851 Mdot
.956 .51887 Mdot
.956 .51964 Mdot
.956 .51972 Mdot
.956 .52072 Mdot
.956 .52135 Mdot
.956 .52157 Mdot
.956 .52177 Mdot
.956 .5223 Mdot
.956 .52248 Mdot
.956 .52291 Mdot
.956 .5236 Mdot
.956 .52436 Mdot
.956 .52461 Mdot
.956 .52469 Mdot
.956 .52508 Mdot
.956 .52557 Mdot
.956 .52831 Mdot
.956 .52894 Mdot
.956 .52913 Mdot
.956 .52917 Mdot
.956 .52938 Mdot
.956 .53197 Mdot
.956 .5326 Mdot
.956 .53305 Mdot
.956 .53336 Mdot
.956 .53375 Mdot
.956 .53379 Mdot
.956 .53465 Mdot
.956 .5348 Mdot
.956 .53544 Mdot
.956 .53606 Mdot
.956 .5362 Mdot
.956 .53644 Mdot
.956 .53668 Mdot
.956 .53698 Mdot
.956 .53732 Mdot
.956 .53893 Mdot
.956 .5396 Mdot
.956 .5404 Mdot
.956 .54063 Mdot
.956 .54106 Mdot
.956 .54117 Mdot
.956 .54149 Mdot
.956 .54169 Mdot
.956 .54227 Mdot
.956 .54244 Mdot
.956 .54244 Mdot
.956 .54253 Mdot
.956 .54275 Mdot
.956 .54281 Mdot
.956 .54282 Mdot
.956 .54291 Mdot
.956 .54399 Mdot
.956 .54411 Mdot
.956 .54412 Mdot
.956 .54512 Mdot
.956 .54523 Mdot
.956 .54529 Mdot
.956 .5469 Mdot
.956 .54742 Mdot
.956 .54835 Mdot
.956 .54835 Mdot
.956 .54851 Mdot
.956 .54876 Mdot
.956 .54885 Mdot
.956 .54907 Mdot
.956 .54941 Mdot
.956 .54979 Mdot
.956 .55032 Mdot
.956 .5527 Mdot
.956 .55311 Mdot
.956 .55376 Mdot
.956 .55581 Mdot
.956 .5559 Mdot
.956 .5559 Mdot
.956 .55597 Mdot
.956 .5568 Mdot
.956 .5569 Mdot
.956 .55789 Mdot
.956 .55825 Mdot
.956 .55835 Mdot
.956 .55911 Mdot
.956 .55967 Mdot
.956 .56028 Mdot
.956 .56035 Mdot
.956 .56056 Mdot
.956 .56184 Mdot
.956 .5619 Mdot
.956 .56239 Mdot
.956 .56324 Mdot
.956 .56419 Mdot
.956 .56475 Mdot
.956 .56499 Mdot
.956 .56564 Mdot
.956 .56653 Mdot
.956 .56675 Mdot
.956 .56689 Mdot
.956 .56703 Mdot
.956 .56739 Mdot
.956 .56767 Mdot
.956 .56768 Mdot
.956 .56776 Mdot
.956 .56801 Mdot
.956 .56815 Mdot
.956 .56846 Mdot
.956 .56849 Mdot
.956 .56998 Mdot
.956 .57019 Mdot
.956 .57019 Mdot
.956 .57023 Mdot
.956 .57107 Mdot
.956 .57112 Mdot
.956 .57121 Mdot
.956 .57134 Mdot
.956 .57267 Mdot
.956 .57341 Mdot
.956 .57353 Mdot
.956 .5738 Mdot
.956 .57413 Mdot
.956 .5744 Mdot
.956 .57604 Mdot
.956 .57611 Mdot
.956 .57627 Mdot
.956 .57628 Mdot
.956 .57679 Mdot
.956 .57752 Mdot
.956 .57848 Mdot
.958 .06285 Mdot
.958 .06296 Mdot
.958 .06369 Mdot
.958 .06407 Mdot
.958 .06415 Mdot
.958 .06421 Mdot
.958 .0646 Mdot
.958 .06462 Mdot
.958 .06759 Mdot
.958 .06803 Mdot
.958 .06903 Mdot
.958 .06942 Mdot
.958 .07085 Mdot
.958 .07147 Mdot
.958 .07188 Mdot
.958 .07282 Mdot
.958 .07399 Mdot
.958 .07501 Mdot
.958 .07651 Mdot
.958 .07665 Mdot
.958 .07737 Mdot
.958 .08059 Mdot
.958 .08167 Mdot
.958 .08182 Mdot
.958 .08228 Mdot
.958 .0825 Mdot
.958 .08393 Mdot
.958 .08408 Mdot
.958 .0846 Mdot
.958 .08572 Mdot
.958 .08579 Mdot
.958 .08815 Mdot
.958 .08928 Mdot
.958 .09193 Mdot
.958 .09428 Mdot
.958 .09453 Mdot
.958 .09496 Mdot
.958 .09502 Mdot
.958 .09558 Mdot
.958 .09576 Mdot
.958 .09602 Mdot
.958 .09682 Mdot
.958 .09758 Mdot
.958 .09876 Mdot
.958 .09887 Mdot
.958 .10115 Mdot
.958 .10288 Mdot
.958 .10348 Mdot
.958 .10453 Mdot
.958 .10454 Mdot
.958 .10552 Mdot
.958 .10612 Mdot
.958 .10695 Mdot
.958 .10715 Mdot
.958 .10855 Mdot
.958 .10927 Mdot
.958 .10944 Mdot
.958 .10955 Mdot
.958 .11029 Mdot
.958 .11033 Mdot
.958 .11044 Mdot
.958 .11197 Mdot
.958 .11223 Mdot
.958 .11342 Mdot
.958 .11367 Mdot
.958 .11496 Mdot
.958 .11603 Mdot
.958 .11687 Mdot
.958 .11878 Mdot
.958 .11953 Mdot
.958 .11955 Mdot
.958 .11986 Mdot
.958 .12124 Mdot
.958 .12146 Mdot
.958 .12188 Mdot
.958 .12228 Mdot
.958 .12269 Mdot
.958 .12345 Mdot
.958 .12424 Mdot
.958 .12484 Mdot
.958 .12604 Mdot
.958 .12661 Mdot
.958 .1271 Mdot
.958 .12772 Mdot
.958 .12784 Mdot
.958 .12829 Mdot
.958 .129 Mdot
.958 .13023 Mdot
.958 .13311 Mdot
.958 .13339 Mdot
.958 .13453 Mdot
.958 .13475 Mdot
.958 .13774 Mdot
.958 .13979 Mdot
.958 .14019 Mdot
.958 .14094 Mdot
.958 .14301 Mdot
.958 .14328 Mdot
.958 .14328 Mdot
.958 .14414 Mdot
.958 .14416 Mdot
.958 .1446 Mdot
.958 .14593 Mdot
.958 .14616 Mdot
.958 .14733 Mdot
.958 .14763 Mdot
.958 .14766 Mdot
.958 .14861 Mdot
.958 .14903 Mdot
.958 .14919 Mdot
.958 .15016 Mdot
.958 .15076 Mdot
.958 .1509 Mdot
.958 .15157 Mdot
.958 .15167 Mdot
.958 .15218 Mdot
.958 .15247 Mdot
.958 .15342 Mdot
.958 .15349 Mdot
.958 .15418 Mdot
.958 .15421 Mdot
.958 .15539 Mdot
.958 .15542 Mdot
.958 .15542 Mdot
.958 .15559 Mdot
.958 .15569 Mdot
.958 .15677 Mdot
.958 .15758 Mdot
.958 .15934 Mdot
.958 .16265 Mdot
.958 .16364 Mdot
.958 .1639 Mdot
.958 .16411 Mdot
.958 .16549 Mdot
.958 .16606 Mdot
.958 .16662 Mdot
.958 .16716 Mdot
.958 .16744 Mdot
.958 .16764 Mdot
.958 .16839 Mdot
.958 .16841 Mdot
.958 .16846 Mdot
.958 .16858 Mdot
.958 .16896 Mdot
.958 .16901 Mdot
.958 .16944 Mdot
.958 .16964 Mdot
.958 .16999 Mdot
.958 .17049 Mdot
.958 .17178 Mdot
.958 .17202 Mdot
.958 .17203 Mdot
.958 .17236 Mdot
.958 .17334 Mdot
.958 .17342 Mdot
.958 .17348 Mdot
.958 .17389 Mdot
.958 .17483 Mdot
.958 .17492 Mdot
.958 .17553 Mdot
.958 .17575 Mdot
.958 .17596 Mdot
.958 .17617 Mdot
.958 .17687 Mdot
.958 .17799 Mdot
.958 .17817 Mdot
.958 .18032 Mdot
.958 .18118 Mdot
.958 .18175 Mdot
.958 .18248 Mdot
.958 .18364 Mdot
.958 .18377 Mdot
.958 .1847 Mdot
.958 .18479 Mdot
.958 .18596 Mdot
.958 .18679 Mdot
.958 .18682 Mdot
.958 .18722 Mdot
.958 .18821 Mdot
.958 .18871 Mdot
.958 .18965 Mdot
.958 .18984 Mdot
.958 .18984 Mdot
.958 .19023 Mdot
.958 .1905 Mdot
.958 .19143 Mdot
.958 .19181 Mdot
.958 .19242 Mdot
.958 .19266 Mdot
.958 .1945 Mdot
.958 .19589 Mdot
.958 .19621 Mdot
.958 .1963 Mdot
.958 .19643 Mdot
.958 .1972 Mdot
.958 .19784 Mdot
.958 .19791 Mdot
.958 .19812 Mdot
.958 .19925 Mdot
.958 .19962 Mdot
.958 .20024 Mdot
.958 .20033 Mdot
.958 .20039 Mdot
.958 .20106 Mdot
.958 .20155 Mdot
.958 .20235 Mdot
.958 .20311 Mdot
.958 .20331 Mdot
.958 .20383 Mdot
.958 .20432 Mdot
.958 .20679 Mdot
.958 .20717 Mdot
.958 .2079 Mdot
.958 .208 Mdot
.958 .20817 Mdot
.958 .20883 Mdot
.958 .20976 Mdot
.958 .20999 Mdot
.958 .21021 Mdot
.958 .21029 Mdot
.958 .21045 Mdot
.958 .21092 Mdot
.958 .21109 Mdot
.958 .21109 Mdot
.958 .21119 Mdot
.958 .21233 Mdot
.958 .21383 Mdot
.958 .21411 Mdot
.958 .21454 Mdot
.958 .21498 Mdot
.958 .21517 Mdot
.958 .21549 Mdot
.958 .21554 Mdot
.958 .21557 Mdot
.958 .21574 Mdot
.958 .21587 Mdot
.958 .21588 Mdot
.958 .21618 Mdot
.958 .21767 Mdot
.958 .21882 Mdot
.958 .21923 Mdot
.958 .22005 Mdot
.958 .22056 Mdot
.958 .22059 Mdot
.958 .2208 Mdot
.958 .22112 Mdot
.958 .22159 Mdot
.958 .22165 Mdot
.958 .22215 Mdot
.958 .22227 Mdot
.958 .2229 Mdot
.958 .22305 Mdot
.958 .22456 Mdot
.958 .22495 Mdot
.958 .22507 Mdot
.958 .22522 Mdot
.958 .22572 Mdot
.958 .22619 Mdot
.958 .22639 Mdot
.958 .22692 Mdot
.958 .22712 Mdot
.958 .22801 Mdot
.958 .22815 Mdot
.958 .22849 Mdot
.958 .2291 Mdot
.958 .22924 Mdot
.958 .23004 Mdot
.958 .2309 Mdot
.958 .23094 Mdot
.958 .23124 Mdot
.958 .23146 Mdot
.958 .23152 Mdot
.958 .23226 Mdot
.958 .23232 Mdot
.958 .23368 Mdot
.958 .2341 Mdot
.958 .23457 Mdot
.958 .23475 Mdot
.958 .23526 Mdot
.958 .23605 Mdot
.958 .23788 Mdot
.958 .23971 Mdot
.958 .24077 Mdot
.958 .24079 Mdot
.958 .24156 Mdot
.958 .2421 Mdot
.958 .24271 Mdot
.958 .24373 Mdot
.958 .24389 Mdot
.958 .24429 Mdot
.958 .24448 Mdot
.958 .24471 Mdot
.958 .24529 Mdot
.958 .24803 Mdot
.958 .24895 Mdot
.958 .24897 Mdot
.958 .25042 Mdot
.958 .25146 Mdot
.958 .25253 Mdot
.958 .25268 Mdot
.958 .25311 Mdot
.958 .25363 Mdot
.958 .25411 Mdot
.958 .2542 Mdot
.958 .25436 Mdot
.958 .2545 Mdot
.958 .25462 Mdot
.958 .25512 Mdot
.958 .25586 Mdot
.958 .25641 Mdot
.958 .25652 Mdot
.958 .25655 Mdot
.958 .25728 Mdot
.958 .25739 Mdot
.958 .25742 Mdot
.958 .25781 Mdot
.958 .25982 Mdot
.958 .26024 Mdot
.958 .26052 Mdot
.958 .26105 Mdot
.958 .26105 Mdot
.958 .26255 Mdot
.958 .26269 Mdot
.958 .26274 Mdot
.958 .26287 Mdot
.958 .26357 Mdot
.958 .26374 Mdot
.958 .2644 Mdot
.958 .26482 Mdot
.958 .26533 Mdot
.958 .26592 Mdot
.958 .26612 Mdot
.958 .26626 Mdot
.958 .2664 Mdot
.958 .26656 Mdot
.958 .26734 Mdot
.958 .26783 Mdot
.958 .26803 Mdot
.958 .2688 Mdot
.958 .26911 Mdot
.958 .26935 Mdot
.958 .26938 Mdot
.958 .26943 Mdot
.958 .26993 Mdot
.958 .27126 Mdot
.958 .27152 Mdot
.958 .27205 Mdot
.958 .27207 Mdot
.958 .27236 Mdot
.958 .27422 Mdot
.958 .27537 Mdot
.958 .27564 Mdot
.958 .27598 Mdot
.958 .27633 Mdot
.958 .27693 Mdot
.958 .27713 Mdot
.958 .27728 Mdot
.958 .2781 Mdot
.958 .27865 Mdot
.958 .27901 Mdot
.958 .27942 Mdot
.958 .27978 Mdot
.958 .27984 Mdot
.958 .28048 Mdot
.958 .28061 Mdot
.958 .28076 Mdot
.958 .28193 Mdot
.958 .28199 Mdot
.958 .28423 Mdot
.958 .28425 Mdot
.958 .2843 Mdot
.958 .28431 Mdot
.958 .28463 Mdot
.958 .28483 Mdot
.958 .28484 Mdot
.958 .28511 Mdot
.958 .28518 Mdot
.958 .28532 Mdot
.958 .28535 Mdot
.958 .28604 Mdot
.958 .28689 Mdot
.958 .28845 Mdot
.958 .28856 Mdot
.958 .28999 Mdot
.958 .29181 Mdot
.958 .29202 Mdot
.958 .29215 Mdot
.958 .29322 Mdot
.958 .29344 Mdot
.958 .29361 Mdot
.958 .29407 Mdot
.958 .29567 Mdot
.958 .29816 Mdot
.958 .29861 Mdot
.958 .29908 Mdot
.958 .30006 Mdot
.958 .30055 Mdot
.958 .30077 Mdot
.958 .30089 Mdot
.958 .30096 Mdot
.958 .3016 Mdot
.958 .30232 Mdot
.958 .30359 Mdot
.958 .30378 Mdot
.958 .30435 Mdot
.958 .30439 Mdot
.958 .30468 Mdot
.958 .30576 Mdot
.958 .3058 Mdot
.958 .3068 Mdot
.958 .30734 Mdot
.958 .30773 Mdot
.958 .30811 Mdot
.958 .30916 Mdot
.958 .30919 Mdot
.958 .30929 Mdot
.958 .30949 Mdot
.958 .30952 Mdot
.958 .31025 Mdot
.958 .31035 Mdot
.958 .31036 Mdot
.958 .31117 Mdot
.958 .31156 Mdot
.958 .31222 Mdot
.958 .31234 Mdot
.958 .31291 Mdot
.958 .31319 Mdot
.958 .31383 Mdot
.958 .31517 Mdot
.958 .31523 Mdot
.958 .31566 Mdot
.958 .31611 Mdot
.958 .31613 Mdot
.958 .31677 Mdot
.958 .31864 Mdot
.958 .31879 Mdot
.958 .31891 Mdot
.958 .31913 Mdot
.958 .31966 Mdot
.958 .31969 Mdot
.958 .32094 Mdot
.958 .32123 Mdot
.958 .3215 Mdot
.958 .32166 Mdot
.958 .32284 Mdot
.958 .32326 Mdot
.958 .32333 Mdot
.958 .32365 Mdot
.958 .32407 Mdot
.958 .32541 Mdot
.958 .32584 Mdot
.958 .32676 Mdot
.958 .32755 Mdot
.958 .3279 Mdot
.958 .33028 Mdot
.958 .33179 Mdot
.958 .33202 Mdot
.958 .33257 Mdot
.958 .33298 Mdot
.958 .33339 Mdot
.958 .33366 Mdot
.958 .33475 Mdot
.958 .33546 Mdot
.958 .33616 Mdot
.958 .33733 Mdot
.958 .33783 Mdot
.958 .33799 Mdot
.958 .33814 Mdot
.958 .33837 Mdot
.958 .33863 Mdot
.958 .3388 Mdot
.958 .33971 Mdot
.958 .34 Mdot
.958 .34012 Mdot
.958 .3404 Mdot
.958 .34057 Mdot
.958 .34094 Mdot
.958 .34124 Mdot
.958 .34282 Mdot
.958 .34442 Mdot
.958 .34447 Mdot
.958 .34465 Mdot
.958 .34524 Mdot
.958 .34623 Mdot
.958 .34647 Mdot
.958 .34713 Mdot
.958 .3473 Mdot
.958 .34808 Mdot
.958 .34919 Mdot
.958 .34939 Mdot
.958 .34941 Mdot
.958 .34989 Mdot
.958 .35021 Mdot
.958 .35026 Mdot
.958 .35026 Mdot
.958 .351 Mdot
.958 .3512 Mdot
.958 .35132 Mdot
.958 .35146 Mdot
.958 .35152 Mdot
.958 .35156 Mdot
.958 .35284 Mdot
.958 .3533 Mdot
.958 .35403 Mdot
.958 .35411 Mdot
.958 .35437 Mdot
.958 .35442 Mdot
.958 .35462 Mdot
.958 .35486 Mdot
.958 .3549 Mdot
.958 .3552 Mdot
.958 .35566 Mdot
.958 .35602 Mdot
.958 .35755 Mdot
.958 .35805 Mdot
.958 .35919 Mdot
.958 .35935 Mdot
.958 .36032 Mdot
.958 .36057 Mdot
.958 .36058 Mdot
.958 .36125 Mdot
.958 .36155 Mdot
.958 .3617 Mdot
.958 .36184 Mdot
.958 .36208 Mdot
.958 .36245 Mdot
.958 .3626 Mdot
.958 .36263 Mdot
.958 .36288 Mdot
.958 .36365 Mdot
.958 .36436 Mdot
.958 .3646 Mdot
.958 .36532 Mdot
.958 .36558 Mdot
.958 .36571 Mdot
.958 .36606 Mdot
.958 .36613 Mdot
.958 .36803 Mdot
.958 .36829 Mdot
.958 .36876 Mdot
.958 .36887 Mdot
.958 .36899 Mdot
.958 .36924 Mdot
.958 .37018 Mdot
.958 .37035 Mdot
.958 .37048 Mdot
.958 .37049 Mdot
.958 .37067 Mdot
.958 .37175 Mdot
.958 .3723 Mdot
.958 .37234 Mdot
.958 .37263 Mdot
.958 .37269 Mdot
.958 .37274 Mdot
.958 .37286 Mdot
.958 .3733 Mdot
.958 .37423 Mdot
.958 .37472 Mdot
.958 .37567 Mdot
.958 .37606 Mdot
.958 .37706 Mdot
.958 .37799 Mdot
.958 .37824 Mdot
.958 .37983 Mdot
.958 .38018 Mdot
.958 .38026 Mdot
.958 .38083 Mdot
.958 .38177 Mdot
.958 .38272 Mdot
.958 .38313 Mdot
.958 .38346 Mdot
.958 .38357 Mdot
.958 .38478 Mdot
.958 .38487 Mdot
.958 .38504 Mdot
.958 .38537 Mdot
.958 .38541 Mdot
.958 .38563 Mdot
.958 .38664 Mdot
.958 .38736 Mdot
.958 .38793 Mdot
.958 .38842 Mdot
.958 .38852 Mdot
.958 .38887 Mdot
.958 .38921 Mdot
.958 .38929 Mdot
.958 .3893 Mdot
.958 .38942 Mdot
.958 .38943 Mdot
.958 .38974 Mdot
.958 .39064 Mdot
.958 .39098 Mdot
.958 .39098 Mdot
.958 .39116 Mdot
.958 .39128 Mdot
.958 .39153 Mdot
.958 .39181 Mdot
.958 .39207 Mdot
.958 .39324 Mdot
.958 .39334 Mdot
.958 .39373 Mdot
.958 .39418 Mdot
.958 .39426 Mdot
.958 .39429 Mdot
.958 .39579 Mdot
.958 .39622 Mdot
.958 .39632 Mdot
.958 .39675 Mdot
.958 .39757 Mdot
.958 .39843 Mdot
.958 .39878 Mdot
.958 .39941 Mdot
.958 .39949 Mdot
.958 .39956 Mdot
.958 .39987 Mdot
.958 .40001 Mdot
.958 .40013 Mdot
.958 .40015 Mdot
.958 .40071 Mdot
.958 .40359 Mdot
.958 .40551 Mdot
.958 .40579 Mdot
.958 .40657 Mdot
.958 .40659 Mdot
.958 .40663 Mdot
.958 .40686 Mdot
.958 .40712 Mdot
.958 .40773 Mdot
.958 .40786 Mdot
.958 .40801 Mdot
.958 .40814 Mdot
.958 .40911 Mdot
.958 .40917 Mdot
.958 .40922 Mdot
.958 .40958 Mdot
.958 .40989 Mdot
.958 .41019 Mdot
.958 .41109 Mdot
.958 .41121 Mdot
.958 .41153 Mdot
.958 .41216 Mdot
.958 .41239 Mdot
.958 .41311 Mdot
.958 .41359 Mdot
.958 .41389 Mdot
.958 .41393 Mdot
.958 .41412 Mdot
.958 .41494 Mdot
.958 .41679 Mdot
.958 .41753 Mdot
.958 .41775 Mdot
.958 .41782 Mdot
.958 .41788 Mdot
.958 .41803 Mdot
.958 .41805 Mdot
.958 .4189 Mdot
.958 .41899 Mdot
.958 .41965 Mdot
.958 .41984 Mdot
.958 .41989 Mdot
.958 .42028 Mdot
.958 .4213 Mdot
.958 .42169 Mdot
.958 .42207 Mdot
.958 .42256 Mdot
.958 .42311 Mdot
.958 .42338 Mdot
.958 .42358 Mdot
.958 .42366 Mdot
.958 .42381 Mdot
.958 .42417 Mdot
.958 .42417 Mdot
.958 .4243 Mdot
.958 .4248 Mdot
.958 .42548 Mdot
.958 .42574 Mdot
.958 .42654 Mdot
.958 .42713 Mdot
.958 .42715 Mdot
.958 .42727 Mdot
.958 .42738 Mdot
.958 .42741 Mdot
.958 .42754 Mdot
.958 .4282 Mdot
.958 .42887 Mdot
.958 .42893 Mdot
.958 .429 Mdot
.958 .42906 Mdot
.958 .42958 Mdot
.958 .42999 Mdot
.958 .43 Mdot
.958 .43011 Mdot
.958 .43109 Mdot
.958 .43153 Mdot
.958 .43165 Mdot
.958 .43248 Mdot
.958 .43426 Mdot
.958 .43442 Mdot
.958 .43484 Mdot
.958 .43491 Mdot
.958 .43506 Mdot
.958 .43553 Mdot
.958 .43587 Mdot
.958 .43595 Mdot
.958 .43604 Mdot
.958 .4363 Mdot
.958 .43727 Mdot
.958 .43835 Mdot
.958 .43857 Mdot
.958 .43878 Mdot
.958 .43919 Mdot
.958 .43998 Mdot
.958 .44181 Mdot
.958 .44229 Mdot
.958 .44361 Mdot
.958 .4447 Mdot
.958 .44485 Mdot
.958 .44552 Mdot
.958 .4458 Mdot
.958 .44783 Mdot
.958 .44787 Mdot
.958 .44856 Mdot
.958 .44904 Mdot
.958 .44934 Mdot
.958 .45038 Mdot
.958 .45083 Mdot
.958 .45155 Mdot
.958 .45276 Mdot
.958 .45349 Mdot
.958 .45351 Mdot
.958 .45381 Mdot
.958 .45457 Mdot
.958 .45495 Mdot
.958 .45532 Mdot
.958 .45538 Mdot
.958 .45626 Mdot
.958 .45651 Mdot
.958 .45804 Mdot
.958 .45888 Mdot
.958 .45912 Mdot
.958 .45921 Mdot
.958 .45932 Mdot
.958 .45988 Mdot
.958 .45995 Mdot
.958 .46101 Mdot
.958 .46175 Mdot
.958 .46307 Mdot
.958 .46343 Mdot
.958 .46344 Mdot
.958 .46352 Mdot
.958 .46356 Mdot
.958 .46369 Mdot
.958 .46401 Mdot
.958 .46582 Mdot
.958 .4663 Mdot
.958 .46634 Mdot
.958 .46652 Mdot
.958 .46674 Mdot
.958 .46764 Mdot
.958 .46814 Mdot
.958 .46832 Mdot
.958 .47037 Mdot
.958 .47065 Mdot
.958 .47147 Mdot
.958 .47178 Mdot
.958 .4719 Mdot
.958 .47247 Mdot
.958 .47257 Mdot
.958 .47283 Mdot
.958 .47332 Mdot
.958 .47339 Mdot
.958 .47357 Mdot
.958 .47388 Mdot
.958 .47414 Mdot
.958 .47436 Mdot
.958 .47471 Mdot
.958 .47516 Mdot
.958 .47533 Mdot
.958 .47653 Mdot
.958 .47675 Mdot
.958 .4778 Mdot
.958 .47801 Mdot
.958 .47802 Mdot
.958 .47808 Mdot
.958 .47847 Mdot
.958 .47853 Mdot
.958 .47882 Mdot
.958 .47947 Mdot
.958 .47953 Mdot
.958 .47969 Mdot
.958 .47973 Mdot
.958 .47998 Mdot
.958 .48026 Mdot
.958 .48048 Mdot
.958 .48056 Mdot
.958 .48112 Mdot
.958 .48241 Mdot
.958 .48242 Mdot
.958 .4829 Mdot
.958 .48433 Mdot
.958 .48476 Mdot
.958 .48507 Mdot
.958 .48515 Mdot
.958 .48568 Mdot
.958 .48669 Mdot
.958 .4867 Mdot
.958 .48725 Mdot
.958 .4882 Mdot
.958 .48957 Mdot
.958 .48984 Mdot
.958 .48993 Mdot
.958 .49018 Mdot
.958 .49114 Mdot
.958 .49152 Mdot
.958 .49183 Mdot
.958 .49185 Mdot
.958 .49271 Mdot
.958 .49311 Mdot
.958 .49328 Mdot
.958 .49336 Mdot
.958 .49382 Mdot
.958 .49392 Mdot
.958 .4942 Mdot
.958 .49431 Mdot
.958 .49481 Mdot
.958 .49489 Mdot
.958 .49495 Mdot
.958 .49602 Mdot
.958 .49635 Mdot
.958 .49641 Mdot
.958 .49667 Mdot
.958 .49695 Mdot
.958 .49723 Mdot
.958 .49724 Mdot
.958 .49875 Mdot
.958 .49968 Mdot
.958 .49969 Mdot
.958 .49976 Mdot
.958 .49989 Mdot
.958 .50006 Mdot
.958 .50015 Mdot
.958 .50039 Mdot
.958 .50075 Mdot
.958 .50154 Mdot
.958 .50213 Mdot
.958 .50218 Mdot
.958 .50218 Mdot
.958 .50227 Mdot
.958 .5026 Mdot
.958 .50264 Mdot
.958 .50276 Mdot
.958 .50288 Mdot
.958 .50371 Mdot
.958 .5038 Mdot
.958 .50385 Mdot
.958 .50423 Mdot
.958 .50625 Mdot
.958 .50635 Mdot
.958 .50675 Mdot
.958 .50777 Mdot
.958 .5078 Mdot
.958 .50785 Mdot
.958 .50817 Mdot
.958 .50836 Mdot
.958 .50943 Mdot
.958 .5099 Mdot
.958 .5118 Mdot
.958 .51193 Mdot
.958 .51293 Mdot
.958 .51307 Mdot
.958 .51328 Mdot
.958 .51337 Mdot
.958 .51413 Mdot
.958 .51464 Mdot
.958 .5153 Mdot
.958 .51596 Mdot
.958 .51644 Mdot
.958 .51712 Mdot
.958 .5175 Mdot
.958 .5178 Mdot
.958 .51937 Mdot
.958 .51946 Mdot
.958 .52005 Mdot
.958 .52041 Mdot
.958 .52074 Mdot
.958 .52107 Mdot
.958 .52111 Mdot
.958 .5216 Mdot
.958 .52185 Mdot
.958 .52189 Mdot
.958 .5224 Mdot
.958 .52258 Mdot
.958 .5227 Mdot
.958 .52392 Mdot
.958 .52415 Mdot
.958 .52417 Mdot
.958 .52446 Mdot
.958 .52447 Mdot
.958 .52497 Mdot
.958 .5254 Mdot
.958 .52569 Mdot
.958 .52599 Mdot
.958 .52671 Mdot
.958 .52682 Mdot
.958 .52695 Mdot
.958 .5292 Mdot
.958 .53054 Mdot
.958 .5311 Mdot
.958 .53115 Mdot
.958 .53124 Mdot
.958 .53125 Mdot
.958 .53187 Mdot
.958 .53189 Mdot
.958 .53225 Mdot
.958 .53228 Mdot
.958 .53278 Mdot
.958 .53293 Mdot
.958 .5332 Mdot
.958 .53325 Mdot
.958 .53399 Mdot
.958 .53449 Mdot
.958 .53457 Mdot
.958 .53529 Mdot
.958 .53608 Mdot
.958 .53619 Mdot
.958 .53713 Mdot
.958 .53758 Mdot
.958 .53919 Mdot
.958 .5394 Mdot
.958 .54047 Mdot
.958 .54214 Mdot
.958 .54503 Mdot
.958 .54564 Mdot
.958 .5457 Mdot
.958 .54602 Mdot
.958 .54628 Mdot
.958 .5472 Mdot
.958 .54832 Mdot
.958 .54874 Mdot
.958 .54897 Mdot
.958 .54908 Mdot
.958 .5498 Mdot
.958 .54996 Mdot
.958 .55236 Mdot
.958 .55303 Mdot
.958 .55316 Mdot
.958 .55378 Mdot
.958 .55392 Mdot
.958 .55472 Mdot
.958 .55697 Mdot
.958 .55728 Mdot
.958 .5578 Mdot
.958 .5578 Mdot
.958 .55835 Mdot
.958 .55866 Mdot
.958 .55957 Mdot
.958 .56076 Mdot
.958 .56081 Mdot
.958 .56143 Mdot
.958 .56183 Mdot
.958 .56224 Mdot
.958 .56238 Mdot
.958 .56247 Mdot
.958 .56277 Mdot
.958 .5628 Mdot
.958 .56302 Mdot
.958 .56315 Mdot
.958 .56438 Mdot
.958 .56576 Mdot
.958 .56635 Mdot
.958 .56758 Mdot
.958 .56762 Mdot
.958 .5682 Mdot
.958 .56847 Mdot
.958 .56855 Mdot
.958 .5693 Mdot
.958 .56942 Mdot
.958 .56966 Mdot
.958 .56973 Mdot
.958 .5703 Mdot
.958 .57198 Mdot
.958 .57235 Mdot
.958 .57243 Mdot
.958 .57321 Mdot
.958 .57374 Mdot
.958 .57435 Mdot
.958 .57484 Mdot
.958 .57506 Mdot
.958 .57538 Mdot
.958 .57613 Mdot
.958 .57633 Mdot
.958 .57685 Mdot
.958 .57708 Mdot
.958 .57863 Mdot
.958 .57864 Mdot
.958 .57884 Mdot
.958 .57887 Mdot
.958 .57892 Mdot
.958 .57912 Mdot
.958 .5795 Mdot
.958 .57955 Mdot
.96 .06338 Mdot
.96 .06368 Mdot
.96 .06372 Mdot
.96 .0652 Mdot
.96 .06644 Mdot
.96 .06655 Mdot
.96 .06688 Mdot
.96 .0675 Mdot
.96 .06798 Mdot
.96 .06845 Mdot
.96 .06846 Mdot
.96 .06886 Mdot
.96 .06958 Mdot
.96 .07265 Mdot
.96 .0738 Mdot
.96 .07419 Mdot
.96 .0744 Mdot
.96 .07487 Mdot
.96 .07643 Mdot
.96 .07654 Mdot
.96 .07725 Mdot
.96 .07729 Mdot
.96 .07742 Mdot
.96 .07807 Mdot
.96 .07959 Mdot
.96 .08145 Mdot
.96 .08171 Mdot
.96 .0826 Mdot
.96 .0848 Mdot
.96 .08499 Mdot
.96 .08535 Mdot
.96 .08632 Mdot
.96 .08686 Mdot
.96 .08704 Mdot
.96 .08736 Mdot
.96 .08753 Mdot
.96 .08754 Mdot
.96 .08962 Mdot
.96 .09003 Mdot
.96 .09121 Mdot
.96 .09152 Mdot
.96 .09209 Mdot
.96 .09271 Mdot
.96 .09314 Mdot
.96 .09353 Mdot
.96 .09435 Mdot
.96 .096 Mdot
.96 .09639 Mdot
.96 .09672 Mdot
.96 .09887 Mdot
.96 .09887 Mdot
.96 .09924 Mdot
.96 .09947 Mdot
.96 .09954 Mdot
.96 .09991 Mdot
.96 .10285 Mdot
.96 .10331 Mdot
.96 .1037 Mdot
.96 .10464 Mdot
.96 .10614 Mdot
.96 .10637 Mdot
.96 .10679 Mdot
.96 .10717 Mdot
.96 .10791 Mdot
.96 .10808 Mdot
.96 .10814 Mdot
.96 .10827 Mdot
.96 .10873 Mdot
.96 .10881 Mdot
.96 .11165 Mdot
.96 .11217 Mdot
.96 .11275 Mdot
.96 .11282 Mdot
.96 .11403 Mdot
.96 .11424 Mdot
.96 .11487 Mdot
.96 .11495 Mdot
.96 .11606 Mdot
.96 .11617 Mdot
.96 .11629 Mdot
.96 .11657 Mdot
.96 .11698 Mdot
.96 .11752 Mdot
.96 .11757 Mdot
.96 .11788 Mdot
.96 .11791 Mdot
.96 .11824 Mdot
.96 .11848 Mdot
.96 .11867 Mdot
.96 .12006 Mdot
.96 .12125 Mdot
.96 .122 Mdot
.96 .12203 Mdot
.96 .12301 Mdot
.96 .12392 Mdot
.96 .12418 Mdot
.96 .12437 Mdot
.96 .12493 Mdot
.96 .12539 Mdot
.96 .12594 Mdot
.96 .12664 Mdot
.96 .12816 Mdot
.96 .1289 Mdot
.96 .12918 Mdot
.96 .12931 Mdot
.96 .12949 Mdot
.96 .12953 Mdot
.96 .13022 Mdot
.96 .13023 Mdot
.96 .13037 Mdot
.96 .13066 Mdot
.96 .13167 Mdot
.96 .13251 Mdot
.96 .13275 Mdot
.96 .1332 Mdot
.96 .13341 Mdot
.96 .13374 Mdot
.96 .13421 Mdot
.96 .13457 Mdot
.96 .1346 Mdot
.96 .13479 Mdot
.96 .13485 Mdot
.96 .1351 Mdot
.96 .13545 Mdot
.96 .13628 Mdot
.96 .13635 Mdot
.96 .13713 Mdot
.96 .13928 Mdot
.96 .13996 Mdot
.96 .14051 Mdot
.96 .14115 Mdot
.96 .14181 Mdot
.96 .14285 Mdot
.96 .14302 Mdot
.96 .14334 Mdot
.96 .1435 Mdot
.96 .14365 Mdot
.96 .14493 Mdot
.96 .14505 Mdot
.96 .14554 Mdot
.96 .14835 Mdot
.96 .14928 Mdot
.96 .14965 Mdot
.96 .14997 Mdot
.96 .15034 Mdot
.96 .15181 Mdot
.96 .15218 Mdot
.96 .15219 Mdot
.96 .15255 Mdot
.96 .15317 Mdot
.96 .15324 Mdot
.96 .15355 Mdot
.96 .15358 Mdot
.96 .15419 Mdot
.96 .15452 Mdot
.96 .15453 Mdot
.96 .15538 Mdot
.96 .15564 Mdot
.96 .15689 Mdot
.96 .15781 Mdot
.96 .15794 Mdot
.96 .15823 Mdot
.96 .15854 Mdot
.96 .15929 Mdot
.96 .15932 Mdot
.96 .16023 Mdot
.96 .16159 Mdot
.96 .16169 Mdot
.96 .16218 Mdot
.96 .16327 Mdot
.96 .16446 Mdot
.96 .16456 Mdot
.96 .16477 Mdot
.96 .16529 Mdot
.96 .16532 Mdot
.96 .16591 Mdot
.96 .16603 Mdot
.96 .16657 Mdot
.96 .167 Mdot
.96 .16738 Mdot
.96 .16744 Mdot
.96 .16762 Mdot
.96 .16887 Mdot
.96 .16947 Mdot
.96 .1703 Mdot
.96 .17079 Mdot
.96 .17154 Mdot
.96 .17188 Mdot
.96 .17217 Mdot
.96 .17276 Mdot
.96 .17288 Mdot
.96 .1744 Mdot
.96 .17447 Mdot
.96 .17496 Mdot
.96 .17611 Mdot
.96 .17628 Mdot
.96 .1763 Mdot
.96 .17658 Mdot
.96 .17661 Mdot
.96 .177 Mdot
.96 .17711 Mdot
.96 .17744 Mdot
.96 .17759 Mdot
.96 .17829 Mdot
.96 .17912 Mdot
.96 .18186 Mdot
.96 .18238 Mdot
.96 .18393 Mdot
.96 .18482 Mdot
.96 .18556 Mdot
.96 .18717 Mdot
.96 .18736 Mdot
.96 .18753 Mdot
.96 .18822 Mdot
.96 .19009 Mdot
.96 .19026 Mdot
.96 .1907 Mdot
.96 .1915 Mdot
.96 .19222 Mdot
.96 .19238 Mdot
.96 .19319 Mdot
.96 .19365 Mdot
.96 .19365 Mdot
.96 .19398 Mdot
.96 .1941 Mdot
.96 .19434 Mdot
.96 .1946 Mdot
.96 .19503 Mdot
.96 .19523 Mdot
.96 .19538 Mdot
.96 .19576 Mdot
.96 .19727 Mdot
.96 .20067 Mdot
.96 .20084 Mdot
.96 .20161 Mdot
.96 .20178 Mdot
.96 .20182 Mdot
.96 .20293 Mdot
.96 .20308 Mdot
.96 .20426 Mdot
.96 .20488 Mdot
.96 .20539 Mdot
.96 .20579 Mdot
.96 .20701 Mdot
.96 .20716 Mdot
.96 .20795 Mdot
.96 .2093 Mdot
.96 .20951 Mdot
.96 .20974 Mdot
.96 .21028 Mdot
.96 .21106 Mdot
.96 .2121 Mdot
.96 .2122 Mdot
.96 .21279 Mdot
.96 .21285 Mdot
.96 .21348 Mdot
.96 .21354 Mdot
.96 .21392 Mdot
.96 .21395 Mdot
.96 .21431 Mdot
.96 .21508 Mdot
.96 .21698 Mdot
.96 .2182 Mdot
.96 .21926 Mdot
.96 .21961 Mdot
.96 .2207 Mdot
.96 .22077 Mdot
.96 .22093 Mdot
.96 .22147 Mdot
.96 .2219 Mdot
.96 .222 Mdot
.96 .22263 Mdot
.96 .22307 Mdot
.96 .22388 Mdot
.96 .22422 Mdot
.96 .22438 Mdot
.96 .22489 Mdot
.96 .22498 Mdot
.96 .22525 Mdot
.96 .22578 Mdot
.96 .22591 Mdot
.96 .22634 Mdot
.96 .22722 Mdot
.96 .22792 Mdot
.96 .22827 Mdot
.96 .22896 Mdot
.96 .22961 Mdot
.96 .23013 Mdot
.96 .23253 Mdot
.96 .23351 Mdot
.96 .23396 Mdot
.96 .23449 Mdot
.96 .23474 Mdot
.96 .23484 Mdot
.96 .23509 Mdot
.96 .23516 Mdot
.96 .23581 Mdot
.96 .23595 Mdot
.96 .23648 Mdot
.96 .23651 Mdot
.96 .23677 Mdot
.96 .2368 Mdot
.96 .23707 Mdot
.96 .23733 Mdot
.96 .23906 Mdot
.96 .23911 Mdot
.96 .23927 Mdot
.96 .23929 Mdot
.96 .23976 Mdot
.96 .24053 Mdot
.96 .24088 Mdot
.96 .24135 Mdot
.96 .24135 Mdot
.96 .24142 Mdot
.96 .24149 Mdot
.96 .24222 Mdot
.96 .24224 Mdot
.96 .24262 Mdot
.96 .24325 Mdot
.96 .24379 Mdot
.96 .24399 Mdot
.96 .24415 Mdot
.96 .24449 Mdot
.96 .24483 Mdot
.96 .2449 Mdot
.96 .24525 Mdot
.96 .24538 Mdot
.96 .24581 Mdot
.96 .24585 Mdot
.96 .2462 Mdot
.96 .24653 Mdot
.96 .24789 Mdot
.96 .24811 Mdot
.96 .24826 Mdot
.96 .24882 Mdot
.96 .24976 Mdot
.96 .25027 Mdot
.96 .25055 Mdot
.96 .25097 Mdot
.96 .25132 Mdot
.96 .25258 Mdot
.96 .25388 Mdot
.96 .25389 Mdot
.96 .25397 Mdot
.96 .25405 Mdot
.96 .25519 Mdot
.96 .25623 Mdot
.96 .25711 Mdot
.96 .25746 Mdot
.96 .25873 Mdot
.96 .25966 Mdot
.96 .26047 Mdot
.96 .26073 Mdot
.96 .26094 Mdot
.96 .26107 Mdot
.96 .26167 Mdot
.96 .26197 Mdot
.96 .26227 Mdot
.96 .2647 Mdot
.96 .26473 Mdot
.96 .26495 Mdot
.96 .26515 Mdot
.96 .26547 Mdot
.96 .26576 Mdot
.96 .26578 Mdot
.96 .2659 Mdot
.96 .27057 Mdot
.96 .27129 Mdot
.96 .27247 Mdot
.96 .27307 Mdot
.96 .27379 Mdot
.96 .27441 Mdot
.96 .27511 Mdot
.96 .27521 Mdot
.96 .27651 Mdot
.96 .27739 Mdot
.96 .27794 Mdot
.96 .27808 Mdot
.96 .27821 Mdot
.96 .27865 Mdot
.96 .27867 Mdot
.96 .27908 Mdot
.96 .27935 Mdot
.96 .28001 Mdot
.96 .28056 Mdot
.96 .28068 Mdot
.96 .28097 Mdot
.96 .28113 Mdot
.96 .28128 Mdot
.96 .28134 Mdot
.96 .28251 Mdot
.96 .28314 Mdot
.96 .28317 Mdot
.96 .28383 Mdot
.96 .28443 Mdot
.96 .2848 Mdot
.96 .2853 Mdot
.96 .2865 Mdot
.96 .28705 Mdot
.96 .28718 Mdot
.96 .28769 Mdot
.96 .28786 Mdot
.96 .28878 Mdot
.96 .28947 Mdot
.96 .2897 Mdot
.96 .28997 Mdot
.96 .29026 Mdot
.96 .29085 Mdot
.96 .29094 Mdot
.96 .29209 Mdot
.96 .29229 Mdot
.96 .29236 Mdot
.96 .29288 Mdot
.96 .29409 Mdot
.96 .2941 Mdot
.96 .29537 Mdot
.96 .29539 Mdot
.96 .29555 Mdot
.96 .29666 Mdot
.96 .29671 Mdot
.96 .29691 Mdot
.96 .29691 Mdot
.96 .29712 Mdot
.96 .29759 Mdot
.96 .29785 Mdot
.96 .29888 Mdot
.96 .299 Mdot
.96 .29906 Mdot
.96 .29916 Mdot
.96 .29994 Mdot
.96 .30038 Mdot
.96 .30071 Mdot
.96 .30115 Mdot
.96 .30167 Mdot
.96 .30223 Mdot
.96 .30224 Mdot
.96 .30242 Mdot
.96 .30283 Mdot
.96 .30298 Mdot
.96 .30381 Mdot
.96 .30388 Mdot
.96 .3048 Mdot
.96 .30498 Mdot
.96 .30501 Mdot
.96 .30525 Mdot
.96 .3058 Mdot
.96 .30585 Mdot
.96 .30627 Mdot
.96 .3071 Mdot
.96 .3073 Mdot
.96 .30784 Mdot
.96 .30796 Mdot
.96 .30829 Mdot
.96 .3087 Mdot
.96 .30879 Mdot
.96 .3107 Mdot
.96 .31147 Mdot
.96 .31172 Mdot
.96 .31185 Mdot
.96 .31198 Mdot
.96 .31199 Mdot
.96 .31343 Mdot
.96 .31372 Mdot
.96 .31418 Mdot
.96 .31437 Mdot
.96 .31501 Mdot
.96 .31582 Mdot
.96 .31647 Mdot
.96 .31683 Mdot
.96 .31703 Mdot
.96 .31711 Mdot
.96 .31784 Mdot
.96 .31816 Mdot
.96 .31839 Mdot
.96 .31856 Mdot
.96 .31878 Mdot
.96 .31956 Mdot
.96 .31965 Mdot
.96 .32023 Mdot
.96 .32042 Mdot
.96 .32131 Mdot
.96 .32144 Mdot
.96 .32221 Mdot
.96 .32238 Mdot
.96 .32278 Mdot
.96 .32459 Mdot
.96 .32493 Mdot
.96 .32496 Mdot
.96 .32504 Mdot
.96 .32549 Mdot
.96 .32555 Mdot
.96 .3263 Mdot
.96 .32651 Mdot
.96 .32678 Mdot
.96 .32715 Mdot
.96 .32743 Mdot
.96 .32777 Mdot
.96 .32855 Mdot
.96 .32874 Mdot
.96 .32878 Mdot
.96 .32886 Mdot
.96 .32936 Mdot
.96 .32982 Mdot
.96 .32992 Mdot
.96 .33016 Mdot
.96 .33038 Mdot
.96 .33138 Mdot
.96 .33188 Mdot
.96 .33238 Mdot
.96 .33273 Mdot
.96 .33366 Mdot
.96 .3347 Mdot
.96 .3348 Mdot
.96 .33507 Mdot
.96 .33563 Mdot
.96 .33597 Mdot
.96 .33634 Mdot
.96 .33662 Mdot
.96 .33728 Mdot
.96 .3386 Mdot
.96 .33882 Mdot
.96 .33922 Mdot
.96 .33961 Mdot
.96 .34028 Mdot
.96 .34087 Mdot
.96 .34132 Mdot
.96 .34275 Mdot
.96 .34447 Mdot
.96 .34582 Mdot
.96 .34594 Mdot
.96 .3462 Mdot
.96 .34652 Mdot
.96 .34785 Mdot
.96 .34815 Mdot
.96 .34899 Mdot
.96 .34982 Mdot
.96 .35134 Mdot
.96 .35144 Mdot
.96 .35176 Mdot
.96 .35261 Mdot
.96 .35299 Mdot
.96 .35334 Mdot
.96 .35414 Mdot
.96 .35524 Mdot
.96 .35552 Mdot
.96 .35584 Mdot
.96 .35676 Mdot
.96 .35738 Mdot
.96 .35765 Mdot
.96 .35826 Mdot
.96 .35828 Mdot
.96 .35888 Mdot
.96 .3589 Mdot
.96 .35913 Mdot
.96 .3596 Mdot
.96 .36009 Mdot
.96 .3602 Mdot
.96 .36091 Mdot
.96 .3613 Mdot
.96 .36138 Mdot
.96 .36149 Mdot
.96 .36159 Mdot
.96 .36231 Mdot
.96 .36233 Mdot
.96 .36385 Mdot
.96 .36407 Mdot
.96 .36522 Mdot
.96 .36733 Mdot
.96 .36866 Mdot
.96 .36888 Mdot
.96 .36937 Mdot
.96 .36968 Mdot
.96 .37041 Mdot
.96 .37132 Mdot
.96 .37175 Mdot
.96 .37207 Mdot
.96 .37234 Mdot
.96 .37265 Mdot
.96 .37354 Mdot
.96 .37389 Mdot
.96 .37396 Mdot
.96 .37452 Mdot
.96 .37454 Mdot
.96 .37499 Mdot
.96 .37511 Mdot
.96 .3761 Mdot
.96 .37637 Mdot
.96 .37638 Mdot
.96 .37864 Mdot
.96 .37936 Mdot
.96 .37944 Mdot
.96 .37983 Mdot
.96 .37989 Mdot
.96 .38082 Mdot
.96 .38097 Mdot
.96 .38159 Mdot
.96 .38254 Mdot
.96 .38276 Mdot
.96 .38297 Mdot
.96 .38331 Mdot
.96 .38367 Mdot
.96 .38392 Mdot
.96 .38421 Mdot
.96 .38526 Mdot
.96 .38532 Mdot
.96 .38572 Mdot
.96 .38726 Mdot
.96 .38786 Mdot
.96 .38808 Mdot
.96 .38831 Mdot
.96 .38872 Mdot
.96 .38917 Mdot
.96 .39019 Mdot
.96 .39077 Mdot
.96 .39144 Mdot
.96 .3917 Mdot
.96 .39211 Mdot
.96 .39342 Mdot
.96 .39369 Mdot
.96 .39389 Mdot
.96 .39501 Mdot
.96 .39514 Mdot
.96 .39634 Mdot
.96 .39647 Mdot
.96 .39718 Mdot
.96 .39724 Mdot
.96 .3973 Mdot
.96 .39794 Mdot
.96 .39942 Mdot
.96 .3996 Mdot
.96 .40181 Mdot
.96 .40306 Mdot
.96 .40422 Mdot
.96 .40541 Mdot
.96 .40744 Mdot
.96 .40812 Mdot
.96 .40846 Mdot
.96 .40882 Mdot
.96 .41022 Mdot
.96 .41033 Mdot
.96 .41065 Mdot
.96 .41165 Mdot
.96 .41168 Mdot
.96 .41251 Mdot
.96 .4127 Mdot
.96 .41288 Mdot
.96 .41299 Mdot
.96 .4131 Mdot
.96 .41392 Mdot
.96 .41448 Mdot
.96 .41472 Mdot
.96 .41476 Mdot
.96 .41631 Mdot
.96 .41697 Mdot
.96 .41704 Mdot
.96 .41727 Mdot
.96 .41728 Mdot
.96 .41825 Mdot
.96 .41842 Mdot
.96 .41895 Mdot
.96 .41942 Mdot
.96 .4198 Mdot
.96 .41996 Mdot
.96 .42022 Mdot
.96 .42033 Mdot
.96 .42103 Mdot
.96 .42272 Mdot
.96 .42284 Mdot
.96 .42364 Mdot
.96 .42406 Mdot
.96 .42412 Mdot
.96 .42474 Mdot
.96 .42542 Mdot
.96 .42607 Mdot
.96 .42653 Mdot
.96 .42732 Mdot
.96 .42831 Mdot
.96 .42849 Mdot
.96 .42935 Mdot
.96 .43014 Mdot
.96 .43058 Mdot
.96 .43101 Mdot
.96 .43216 Mdot
.96 .43293 Mdot
.96 .4348 Mdot
.96 .43511 Mdot
.96 .43566 Mdot
.96 .43587 Mdot
.96 .43599 Mdot
.96 .43668 Mdot
.96 .43717 Mdot
.96 .43736 Mdot
.96 .43783 Mdot
.96 .43797 Mdot
.96 .43802 Mdot
.96 .43856 Mdot
.96 .43905 Mdot
.96 .43923 Mdot
.96 .43949 Mdot
.96 .43975 Mdot
.96 .44038 Mdot
.96 .44051 Mdot
.96 .44056 Mdot
.96 .4408 Mdot
.96 .44106 Mdot
.96 .44112 Mdot
.96 .44122 Mdot
.96 .44163 Mdot
.96 .44214 Mdot
.96 .44305 Mdot
.96 .44423 Mdot
.96 .44453 Mdot
.96 .44546 Mdot
.96 .44555 Mdot
.96 .44586 Mdot
.96 .4459 Mdot
.96 .44631 Mdot
.96 .44642 Mdot
.96 .4468 Mdot
.96 .44718 Mdot
.96 .44733 Mdot
.96 .44828 Mdot
.96 .44871 Mdot
.96 .44894 Mdot
.96 .44985 Mdot
.96 .44985 Mdot
.96 .44999 Mdot
.96 .45012 Mdot
.96 .45152 Mdot
.96 .45156 Mdot
.96 .45229 Mdot
.96 .45304 Mdot
.96 .45307 Mdot
.96 .4535 Mdot
.96 .45359 Mdot
.96 .45454 Mdot
.96 .45493 Mdot
.96 .45522 Mdot
.96 .45549 Mdot
.96 .45572 Mdot
.96 .45589 Mdot
.96 .45653 Mdot
.96 .45658 Mdot
.96 .45661 Mdot
.96 .45668 Mdot
.96 .45734 Mdot
.96 .45759 Mdot
.96 .4577 Mdot
.96 .45783 Mdot
.96 .45841 Mdot
.96 .45849 Mdot
.96 .4585 Mdot
.96 .45917 Mdot
.96 .4598 Mdot
.96 .46021 Mdot
.96 .46081 Mdot
.96 .46132 Mdot
.96 .46194 Mdot
.96 .46241 Mdot
.96 .46277 Mdot
.96 .46283 Mdot
.96 .46312 Mdot
.96 .4642 Mdot
.96 .46451 Mdot
.96 .46592 Mdot
.96 .466 Mdot
.96 .46651 Mdot
.96 .46699 Mdot
.96 .46744 Mdot
.96 .46751 Mdot
.96 .46787 Mdot
.96 .46833 Mdot
.96 .469 Mdot
.96 .47043 Mdot
.96 .47142 Mdot
.96 .47391 Mdot
.96 .47393 Mdot
.96 .47408 Mdot
.96 .47424 Mdot
.96 .47448 Mdot
.96 .47644 Mdot
.96 .47668 Mdot
.96 .4771 Mdot
.96 .47843 Mdot
.96 .48002 Mdot
.96 .48007 Mdot
.96 .48011 Mdot
.96 .48079 Mdot
.96 .48144 Mdot
.96 .48163 Mdot
.96 .48185 Mdot
.96 .48199 Mdot
.96 .48275 Mdot
.96 .48323 Mdot
.96 .48411 Mdot
.96 .48432 Mdot
.96 .485 Mdot
.96 .48526 Mdot
.96 .48537 Mdot
.96 .48618 Mdot
.96 .48657 Mdot
.96 .4866 Mdot
.96 .48664 Mdot
.96 .48707 Mdot
.96 .48747 Mdot
.96 .48771 Mdot
.96 .48781 Mdot
.96 .48783 Mdot
.96 .48887 Mdot
.96 .48901 Mdot
.96 .48945 Mdot
.96 .48952 Mdot
.96 .49003 Mdot
.96 .49072 Mdot
.96 .49248 Mdot
.96 .49309 Mdot
.96 .49363 Mdot
.96 .49468 Mdot
.96 .49475 Mdot
.96 .49517 Mdot
.96 .49556 Mdot
.96 .49574 Mdot
.96 .49616 Mdot
.96 .49672 Mdot
.96 .49677 Mdot
.96 .49699 Mdot
.96 .49727 Mdot
.96 .49796 Mdot
.96 .49869 Mdot
.96 .50032 Mdot
.96 .50093 Mdot
.96 .50112 Mdot
.96 .50404 Mdot
.96 .50563 Mdot
.96 .50596 Mdot
.96 .50725 Mdot
.96 .50734 Mdot
.96 .50783 Mdot
.96 .5096 Mdot
.96 .51038 Mdot
.96 .51077 Mdot
.96 .51099 Mdot
.96 .51148 Mdot
.96 .51172 Mdot
.96 .51214 Mdot
.96 .51333 Mdot
.96 .51431 Mdot
.96 .51467 Mdot
.96 .51486 Mdot
.96 .51735 Mdot
.96 .51762 Mdot
.96 .51905 Mdot
.96 .5201 Mdot
.96 .52036 Mdot
.96 .52038 Mdot
.96 .52062 Mdot
.96 .52122 Mdot
.96 .52147 Mdot
.96 .52151 Mdot
.96 .5223 Mdot
.96 .52236 Mdot
.96 .52282 Mdot
.96 .52365 Mdot
.96 .52407 Mdot
.96 .52439 Mdot
.96 .52513 Mdot
.96 .52516 Mdot
.96 .52536 Mdot
.96 .52559 Mdot
.96 .52593 Mdot
.96 .52624 Mdot
.96 .52652 Mdot
.96 .52663 Mdot
.96 .52813 Mdot
.96 .52889 Mdot
.96 .52938 Mdot
.96 .52993 Mdot
.96 .53008 Mdot
.96 .53015 Mdot
.96 .53063 Mdot
.96 .53128 Mdot
.96 .53141 Mdot
.96 .53237 Mdot
.96 .53256 Mdot
.96 .53289 Mdot
.96 .53308 Mdot
.96 .53327 Mdot
.96 .53423 Mdot
.96 .53508 Mdot
.96 .53654 Mdot
.96 .53686 Mdot
.96 .53752 Mdot
.96 .5376 Mdot
.96 .53785 Mdot
.96 .53848 Mdot
.96 .53883 Mdot
.96 .53916 Mdot
.96 .53944 Mdot
.96 .54092 Mdot
.96 .54137 Mdot
.96 .54179 Mdot
.96 .54224 Mdot
.96 .54226 Mdot
.96 .54244 Mdot
.96 .54268 Mdot
.96 .5432 Mdot
.96 .54333 Mdot
.96 .54376 Mdot
.96 .54429 Mdot
.96 .54444 Mdot
.96 .54451 Mdot
.96 .54488 Mdot
.96 .5449 Mdot
.96 .54506 Mdot
.96 .54638 Mdot
.96 .54703 Mdot
.96 .54727 Mdot
.96 .54757 Mdot
.96 .54766 Mdot
.96 .5478 Mdot
.96 .54828 Mdot
.96 .54878 Mdot
.96 .5488 Mdot
.96 .54919 Mdot
.96 .55063 Mdot
.96 .55076 Mdot
.96 .55111 Mdot
.96 .55113 Mdot
.96 .55163 Mdot
.96 .55177 Mdot
.96 .55184 Mdot
.96 .55247 Mdot
.96 .55358 Mdot
.96 .55362 Mdot
.96 .55392 Mdot
.96 .55595 Mdot
.96 .55605 Mdot
.96 .55614 Mdot
.96 .55653 Mdot
.96 .55672 Mdot
.96 .55694 Mdot
.96 .55706 Mdot
.96 .55784 Mdot
.96 .55833 Mdot
.96 .55853 Mdot
.96 .55877 Mdot
.96 .56031 Mdot
.96 .5605 Mdot
.96 .56054 Mdot
.96 .56065 Mdot
.96 .56084 Mdot
.96 .56085 Mdot
.96 .56197 Mdot
.96 .56214 Mdot
.96 .56234 Mdot
.96 .5632 Mdot
.96 .56363 Mdot
.96 .56383 Mdot
.96 .56406 Mdot
.96 .56438 Mdot
.96 .56468 Mdot
.96 .56484 Mdot
.96 .56545 Mdot
.96 .56566 Mdot
.96 .56675 Mdot
.96 .56675 Mdot
.96 .56684 Mdot
.96 .56701 Mdot
.96 .5671 Mdot
.96 .56738 Mdot
.96 .56789 Mdot
.96 .56807 Mdot
.96 .56818 Mdot
.96 .56932 Mdot
.96 .56979 Mdot
.96 .56992 Mdot
.96 .57089 Mdot
.96 .57168 Mdot
.96 .57202 Mdot
.96 .57209 Mdot
.96 .57211 Mdot
.96 .57248 Mdot
.96 .57254 Mdot
.96 .57335 Mdot
.96 .57359 Mdot
.96 .5737 Mdot
.96 .5739 Mdot
.96 .57451 Mdot
.96 .5761 Mdot
.96 .57648 Mdot
.96 .57668 Mdot
.96 .57669 Mdot
.96 .57694 Mdot
.96 .57719 Mdot
.96 .57751 Mdot
.96 .57768 Mdot
.96 .57774 Mdot
.96 .57838 Mdot
.96 .57915 Mdot
.96 .57917 Mdot
.96 .57933 Mdot
.962 .05871 Mdot
.962 .05937 Mdot
.962 .05945 Mdot
.962 .05957 Mdot
.962 .05969 Mdot
.962 .05993 Mdot
.962 .06191 Mdot
.962 .0648 Mdot
.962 .06489 Mdot
.962 .06785 Mdot
.962 .06792 Mdot
.962 .06995 Mdot
.962 .07003 Mdot
.962 .07038 Mdot
.962 .07189 Mdot
.962 .07902 Mdot
.962 .07972 Mdot
.962 .07987 Mdot
.962 .08205 Mdot
.962 .08701 Mdot
.962 .08731 Mdot
.962 .0885 Mdot
.962 .0898 Mdot
.962 .0906 Mdot
.962 .09066 Mdot
.962 .09279 Mdot
.962 .09338 Mdot
.962 .09679 Mdot
.962 .09747 Mdot
.962 .09889 Mdot
.962 .09936 Mdot
.962 .09995 Mdot
.962 .10031 Mdot
.962 .10063 Mdot
.962 .10079 Mdot
.962 .10102 Mdot
.962 .10124 Mdot
.962 .10171 Mdot
.962 .10551 Mdot
.962 .10589 Mdot
.962 .10595 Mdot
.962 .10683 Mdot
.962 .10765 Mdot
.962 .10781 Mdot
.962 .10898 Mdot
.962 .10909 Mdot
.962 .11001 Mdot
.962 .11108 Mdot
.962 .11126 Mdot
.962 .112 Mdot
.962 .11274 Mdot
.962 .11275 Mdot
.962 .11413 Mdot
.962 .1146 Mdot
.962 .11473 Mdot
.962 .11695 Mdot
.962 .11707 Mdot
.962 .11752 Mdot
.962 .11879 Mdot
.962 .11942 Mdot
.962 .11972 Mdot
.962 .12054 Mdot
.962 .12078 Mdot
.962 .12085 Mdot
.962 .12099 Mdot
.962 .12114 Mdot
.962 .12128 Mdot
.962 .12181 Mdot
.962 .12199 Mdot
.962 .12334 Mdot
.962 .12473 Mdot
.962 .12578 Mdot
.962 .12584 Mdot
.962 .1261 Mdot
.962 .12681 Mdot
.962 .12912 Mdot
.962 .12943 Mdot
.962 .13006 Mdot
.962 .13085 Mdot
.962 .13392 Mdot
.962 .13498 Mdot
.962 .1351 Mdot
.962 .13778 Mdot
.962 .13844 Mdot
.962 .13867 Mdot
.962 .13867 Mdot
.962 .13875 Mdot
.962 .13895 Mdot
.962 .13979 Mdot
.962 .14008 Mdot
.962 .14137 Mdot
.962 .14139 Mdot
.962 .14315 Mdot
.962 .14327 Mdot
.962 .14388 Mdot
.962 .14411 Mdot
.962 .14426 Mdot
.962 .14539 Mdot
.962 .14621 Mdot
.962 .14644 Mdot
.962 .14723 Mdot
.962 .14807 Mdot
.962 .14851 Mdot
.962 .15019 Mdot
.962 .15023 Mdot
.962 .15134 Mdot
.962 .15158 Mdot
.962 .1538 Mdot
.962 .15438 Mdot
.962 .15506 Mdot
.962 .15563 Mdot
.962 .15668 Mdot
.962 .15668 Mdot
.962 .15681 Mdot
.962 .15802 Mdot
.962 .15919 Mdot
.962 .1592 Mdot
.962 .16013 Mdot
.962 .16032 Mdot
.962 .16071 Mdot
.962 .16084 Mdot
.962 .16494 Mdot
.962 .16606 Mdot
.962 .16633 Mdot
.962 .16781 Mdot
.962 .16901 Mdot
.962 .16979 Mdot
.962 .17263 Mdot
.962 .17294 Mdot
.962 .17394 Mdot
.962 .17505 Mdot
.962 .17602 Mdot
.962 .17668 Mdot
.962 .17672 Mdot
.962 .17694 Mdot
.962 .17757 Mdot
.962 .17828 Mdot
.962 .17871 Mdot
.962 .17886 Mdot
.962 .17939 Mdot
.962 .18001 Mdot
.962 .18032 Mdot
.962 .18058 Mdot
.962 .18076 Mdot
.962 .18119 Mdot
.962 .18191 Mdot
.962 .1821 Mdot
.962 .18326 Mdot
.962 .18375 Mdot
.962 .18419 Mdot
.962 .18462 Mdot
.962 .18475 Mdot
.962 .18494 Mdot
.962 .18526 Mdot
.962 .18545 Mdot
.962 .18609 Mdot
.962 .18615 Mdot
.962 .18648 Mdot
.962 .18687 Mdot
.962 .18821 Mdot
.962 .18841 Mdot
.962 .18923 Mdot
.962 .18935 Mdot
.962 .18941 Mdot
.962 .18956 Mdot
.962 .19015 Mdot
.962 .19025 Mdot
.962 .19039 Mdot
.962 .19195 Mdot
.962 .19205 Mdot
.962 .1925 Mdot
.962 .19334 Mdot
.962 .19351 Mdot
.962 .19382 Mdot
.962 .19609 Mdot
.962 .19628 Mdot
.962 .19688 Mdot
.962 .19806 Mdot
.962 .1984 Mdot
.962 .20003 Mdot
.962 .20013 Mdot
.962 .20046 Mdot
.962 .20065 Mdot
.962 .20157 Mdot
.962 .20184 Mdot
.962 .20189 Mdot
.962 .20247 Mdot
.962 .20301 Mdot
.962 .20332 Mdot
.962 .20334 Mdot
.962 .20597 Mdot
.962 .20598 Mdot
.962 .20656 Mdot
.962 .2069 Mdot
.962 .20715 Mdot
.962 .20881 Mdot
.962 .20968 Mdot
.962 .20969 Mdot
.962 .21 Mdot
.962 .21008 Mdot
.962 .21115 Mdot
.962 .21142 Mdot
.962 .21161 Mdot
.962 .21165 Mdot
.962 .21238 Mdot
.962 .21251 Mdot
.962 .21287 Mdot
.962 .21326 Mdot
.962 .21433 Mdot
.962 .21492 Mdot
.962 .21496 Mdot
.962 .21497 Mdot
.962 .21517 Mdot
.962 .21534 Mdot
.962 .21596 Mdot
.962 .21598 Mdot
.962 .2161 Mdot
.962 .21617 Mdot
.962 .21675 Mdot
.962 .21712 Mdot
.962 .21802 Mdot
.962 .21831 Mdot
.962 .21878 Mdot
.962 .21891 Mdot
.962 .21913 Mdot
.962 .21919 Mdot
.962 .21935 Mdot
.962 .21947 Mdot
.962 .21975 Mdot
.962 .22076 Mdot
.962 .22077 Mdot
.962 .22112 Mdot
.962 .22258 Mdot
.962 .22336 Mdot
.962 .22352 Mdot
.962 .2237 Mdot
.962 .22371 Mdot
.962 .22386 Mdot
.962 .22581 Mdot
.962 .22638 Mdot
.962 .22716 Mdot
.962 .22819 Mdot
.962 .22824 Mdot
.962 .2284 Mdot
.962 .22846 Mdot
.962 .22852 Mdot
.962 .22892 Mdot
.962 .22901 Mdot
.962 .22964 Mdot
.962 .22988 Mdot
.962 .23038 Mdot
.962 .23111 Mdot
.962 .23115 Mdot
.962 .23199 Mdot
.962 .23215 Mdot
.962 .23247 Mdot
.962 .23283 Mdot
.962 .23418 Mdot
.962 .2342 Mdot
.962 .23484 Mdot
.962 .23508 Mdot
.962 .23543 Mdot
.962 .23663 Mdot
.962 .23709 Mdot
.962 .23731 Mdot
.962 .23793 Mdot
.962 .23809 Mdot
.962 .23816 Mdot
.962 .23882 Mdot
.962 .23933 Mdot
.962 .23953 Mdot
.962 .24154 Mdot
.962 .24181 Mdot
.962 .24239 Mdot
.962 .24406 Mdot
.962 .2453 Mdot
.962 .24561 Mdot
.962 .24611 Mdot
.962 .24634 Mdot
.962 .24758 Mdot
.962 .24776 Mdot
.962 .25049 Mdot
.962 .25081 Mdot
.962 .25097 Mdot
.962 .25126 Mdot
.962 .25149 Mdot
.962 .25277 Mdot
.962 .25298 Mdot
.962 .25314 Mdot
.962 .2532 Mdot
.962 .2532 Mdot
.962 .25335 Mdot
.962 .25375 Mdot
.962 .25411 Mdot
.962 .25474 Mdot
.962 .25536 Mdot
.962 .2559 Mdot
.962 .25591 Mdot
.962 .25651 Mdot
.962 .25694 Mdot
.962 .25698 Mdot
.962 .25753 Mdot
.962 .25766 Mdot
.962 .25839 Mdot
.962 .25844 Mdot
.962 .25897 Mdot
.962 .25906 Mdot
.962 .26128 Mdot
.962 .26182 Mdot
.962 .26206 Mdot
.962 .26243 Mdot
.962 .26322 Mdot
.962 .26329 Mdot
.962 .26361 Mdot
.962 .26367 Mdot
.962 .26396 Mdot
.962 .26432 Mdot
.962 .26494 Mdot
.962 .26569 Mdot
.962 .26613 Mdot
.962 .26643 Mdot
.962 .26698 Mdot
.962 .26698 Mdot
.962 .2672 Mdot
.962 .26725 Mdot
.962 .26771 Mdot
.962 .26782 Mdot
.962 .26816 Mdot
.962 .26859 Mdot
.962 .26868 Mdot
.962 .26952 Mdot
.962 .26968 Mdot
.962 .27129 Mdot
.962 .27173 Mdot
.962 .27214 Mdot
.962 .27332 Mdot
.962 .27412 Mdot
.962 .27417 Mdot
.962 .27443 Mdot
.962 .27504 Mdot
.962 .27523 Mdot
.962 .27536 Mdot
.962 .27541 Mdot
.962 .27545 Mdot
.962 .27557 Mdot
.962 .27582 Mdot
.962 .27701 Mdot
.962 .27758 Mdot
.962 .27804 Mdot
.962 .27967 Mdot
.962 .28232 Mdot
.962 .28328 Mdot
.962 .28344 Mdot
.962 .28474 Mdot
.962 .28576 Mdot
.962 .28583 Mdot
.962 .28639 Mdot
.962 .28646 Mdot
.962 .28713 Mdot
.962 .28779 Mdot
.962 .28786 Mdot
.962 .28786 Mdot
.962 .2881 Mdot
.962 .28883 Mdot
.962 .29019 Mdot
.962 .29036 Mdot
.962 .29044 Mdot
.962 .29201 Mdot
.962 .29237 Mdot
.962 .29268 Mdot
.962 .2927 Mdot
.962 .29323 Mdot
.962 .29449 Mdot
.962 .29487 Mdot
.962 .29487 Mdot
.962 .29507 Mdot
.962 .29561 Mdot
.962 .29586 Mdot
.962 .29624 Mdot
.962 .2967 Mdot
.962 .29823 Mdot
.962 .29861 Mdot
.962 .29899 Mdot
.962 .30083 Mdot
.962 .30174 Mdot
.962 .30316 Mdot
.962 .30375 Mdot
.962 .30379 Mdot
.962 .30398 Mdot
.962 .3059 Mdot
.962 .30641 Mdot
.962 .30643 Mdot
.962 .30698 Mdot
.962 .30699 Mdot
.962 .30779 Mdot
.962 .3086 Mdot
.962 .30913 Mdot
.962 .3092 Mdot
.962 .30926 Mdot
.962 .30929 Mdot
.962 .30993 Mdot
.962 .31016 Mdot
.962 .31158 Mdot
.962 .31308 Mdot
.962 .31757 Mdot
.962 .31798 Mdot
.962 .31833 Mdot
.962 .31854 Mdot
.962 .31914 Mdot
.962 .31929 Mdot
.962 .32022 Mdot
.962 .32107 Mdot
.962 .32268 Mdot
.962 .32293 Mdot
.962 .32319 Mdot
.962 .32351 Mdot
.962 .32503 Mdot
.962 .32506 Mdot
.962 .32582 Mdot
.962 .32633 Mdot
.962 .32641 Mdot
.962 .32663 Mdot
.962 .32683 Mdot
.962 .32805 Mdot
.962 .32806 Mdot
.962 .32813 Mdot
.962 .32833 Mdot
.962 .32942 Mdot
.962 .33025 Mdot
.962 .33053 Mdot
.962 .33155 Mdot
.962 .33226 Mdot
.962 .33274 Mdot
.962 .33277 Mdot
.962 .33334 Mdot
.962 .33384 Mdot
.962 .33407 Mdot
.962 .33419 Mdot
.962 .33464 Mdot
.962 .33495 Mdot
.962 .33502 Mdot
.962 .3364 Mdot
.962 .33643 Mdot
.962 .33676 Mdot
.962 .33733 Mdot
.962 .33738 Mdot
.962 .339 Mdot
.962 .3394 Mdot
.962 .33994 Mdot
.962 .34079 Mdot
.962 .34162 Mdot
.962 .34187 Mdot
.962 .34223 Mdot
.962 .3424 Mdot
.962 .34285 Mdot
.962 .34321 Mdot
.962 .34371 Mdot
.962 .34412 Mdot
.962 .34434 Mdot
.962 .34444 Mdot
.962 .34455 Mdot
.962 .34491 Mdot
.962 .34519 Mdot
.962 .3455 Mdot
.962 .34595 Mdot
.962 .3463 Mdot
.962 .34827 Mdot
.962 .34852 Mdot
.962 .34859 Mdot
.962 .34877 Mdot
.962 .34891 Mdot
.962 .35048 Mdot
.962 .35071 Mdot
.962 .35082 Mdot
.962 .35111 Mdot
.962 .35144 Mdot
.962 .35197 Mdot
.962 .35213 Mdot
.962 .35224 Mdot
.962 .35245 Mdot
.962 .35272 Mdot
.962 .35332 Mdot
.962 .3542 Mdot
.962 .35441 Mdot
.962 .3545 Mdot
.962 .35454 Mdot
.962 .35571 Mdot
.962 .35591 Mdot
.962 .35651 Mdot
.962 .35674 Mdot
.962 .35678 Mdot
.962 .35687 Mdot
.962 .35734 Mdot
.962 .35818 Mdot
.962 .35834 Mdot
.962 .35839 Mdot
.962 .35858 Mdot
.962 .35872 Mdot
.962 .35878 Mdot
.962 .35932 Mdot
.962 .35939 Mdot
.962 .35955 Mdot
.962 .36182 Mdot
.962 .36194 Mdot
.962 .36272 Mdot
.962 .3632 Mdot
.962 .36336 Mdot
.962 .36364 Mdot
.962 .36367 Mdot
.962 .36405 Mdot
.962 .36496 Mdot
.962 .36519 Mdot
.962 .36547 Mdot
.962 .36584 Mdot
.962 .36626 Mdot
.962 .36665 Mdot
.962 .36688 Mdot
.962 .36747 Mdot
.962 .36812 Mdot
.962 .3682 Mdot
.962 .36837 Mdot
.962 .36847 Mdot
.962 .36851 Mdot
.962 .36962 Mdot
.962 .3706 Mdot
.962 .37127 Mdot
.962 .37144 Mdot
.962 .37145 Mdot
.962 .37209 Mdot
.962 .37246 Mdot
.962 .37251 Mdot
.962 .37295 Mdot
.962 .37372 Mdot
.962 .37422 Mdot
.962 .37463 Mdot
.962 .37474 Mdot
.962 .37484 Mdot
.962 .37558 Mdot
.962 .37597 Mdot
.962 .37613 Mdot
.962 .37619 Mdot
.962 .37684 Mdot
.962 .377 Mdot
.962 .37722 Mdot
.962 .37743 Mdot
.962 .3776 Mdot
.962 .37762 Mdot
.962 .37779 Mdot
.962 .37997 Mdot
.962 .38032 Mdot
.962 .38187 Mdot
.962 .38269 Mdot
.962 .38271 Mdot
.962 .38383 Mdot
.962 .38447 Mdot
.962 .38495 Mdot
.962 .38576 Mdot
.962 .38703 Mdot
.962 .38709 Mdot
.962 .38762 Mdot
.962 .38815 Mdot
.962 .38915 Mdot
.962 .38919 Mdot
.962 .38981 Mdot
.962 .38984 Mdot
.962 .38985 Mdot
.962 .39044 Mdot
.962 .3906 Mdot
.962 .39083 Mdot
.962 .39181 Mdot
.962 .39185 Mdot
.962 .39205 Mdot
.962 .39218 Mdot
.962 .3923 Mdot
.962 .39266 Mdot
.962 .3928 Mdot
.962 .3929 Mdot
.962 .39312 Mdot
.962 .39318 Mdot
.962 .39354 Mdot
.962 .39361 Mdot
.962 .39362 Mdot
.962 .39392 Mdot
.962 .39418 Mdot
.962 .39441 Mdot
.962 .3947 Mdot
.962 .39482 Mdot
.962 .39503 Mdot
.962 .39527 Mdot
.962 .39597 Mdot
.962 .39613 Mdot
.962 .39671 Mdot
.962 .39723 Mdot
.962 .39878 Mdot
.962 .39919 Mdot
.962 .39921 Mdot
.962 .39937 Mdot
.962 .39991 Mdot
.962 .39998 Mdot
.962 .40001 Mdot
.962 .40018 Mdot
.962 .4004 Mdot
.962 .40055 Mdot
.962 .40069 Mdot
.962 .40073 Mdot
.962 .40191 Mdot
.962 .40191 Mdot
.962 .40196 Mdot
.962 .40217 Mdot
.962 .40231 Mdot
.962 .40343 Mdot
.962 .40407 Mdot
.962 .40414 Mdot
.962 .40433 Mdot
.962 .40475 Mdot
.962 .40484 Mdot
.962 .40484 Mdot
.962 .40587 Mdot
.962 .40644 Mdot
.962 .40712 Mdot
.962 .40718 Mdot
.962 .40733 Mdot
.962 .40745 Mdot
.962 .40759 Mdot
.962 .40775 Mdot
.962 .408 Mdot
.962 .40812 Mdot
.962 .40817 Mdot
.962 .40843 Mdot
.962 .40849 Mdot
.962 .40856 Mdot
.962 .40866 Mdot
.962 .40868 Mdot
.962 .40919 Mdot
.962 .40972 Mdot
.962 .41004 Mdot
.962 .41006 Mdot
.962 .41086 Mdot
.962 .41114 Mdot
.962 .41117 Mdot
.962 .41183 Mdot
.962 .41385 Mdot
.962 .41465 Mdot
.962 .41484 Mdot
.962 .41597 Mdot
.962 .41615 Mdot
.962 .41627 Mdot
.962 .41646 Mdot
.962 .4168 Mdot
.962 .41683 Mdot
.962 .41712 Mdot
.962 .41761 Mdot
.962 .41808 Mdot
.962 .41848 Mdot
.962 .41872 Mdot
.962 .41927 Mdot
.962 .41971 Mdot
.962 .42022 Mdot
.962 .42079 Mdot
.962 .42081 Mdot
.962 .42087 Mdot
.962 .42095 Mdot
.962 .42164 Mdot
.962 .42176 Mdot
.962 .42196 Mdot
.962 .42218 Mdot
.962 .42237 Mdot
.962 .42264 Mdot
.962 .42333 Mdot
.962 .42347 Mdot
.962 .42355 Mdot
.962 .4238 Mdot
.962 .42421 Mdot
.962 .42427 Mdot
.962 .42545 Mdot
.962 .42553 Mdot
.962 .42585 Mdot
.962 .42595 Mdot
.962 .42608 Mdot
.962 .42616 Mdot
.962 .4266 Mdot
.962 .42684 Mdot
.962 .42691 Mdot
.962 .42703 Mdot
.962 .42805 Mdot
.962 .42807 Mdot
.962 .42812 Mdot
.962 .42823 Mdot
.962 .42869 Mdot
.962 .42931 Mdot
.962 .42939 Mdot
.962 .42966 Mdot
.962 .43105 Mdot
.962 .43114 Mdot
.962 .43131 Mdot
.962 .43234 Mdot
.962 .43275 Mdot
.962 .43306 Mdot
.962 .43335 Mdot
.962 .43347 Mdot
.962 .43368 Mdot
.962 .43436 Mdot
.962 .43592 Mdot
.962 .43697 Mdot
.962 .437 Mdot
.962 .43747 Mdot
.962 .43823 Mdot
.962 .4384 Mdot
.962 .43869 Mdot
.962 .43937 Mdot
.962 .43963 Mdot
.962 .44168 Mdot
.962 .44178 Mdot
.962 .44181 Mdot
.962 .44256 Mdot
.962 .44298 Mdot
.962 .44339 Mdot
.962 .44418 Mdot
.962 .44448 Mdot
.962 .44462 Mdot
.962 .44589 Mdot
.962 .44637 Mdot
.962 .44687 Mdot
.962 .44706 Mdot
.962 .44727 Mdot
.962 .45112 Mdot
.962 .45124 Mdot
.962 .45157 Mdot
.962 .45162 Mdot
.962 .45165 Mdot
.962 .45193 Mdot
.962 .45235 Mdot
.962 .45277 Mdot
.962 .45277 Mdot
.962 .45307 Mdot
.962 .45433 Mdot
.962 .45443 Mdot
.962 .45476 Mdot
.962 .4555 Mdot
.962 .45597 Mdot
.962 .45692 Mdot
.962 .45712 Mdot
.962 .45732 Mdot
.962 .45811 Mdot
.962 .45835 Mdot
.962 .45896 Mdot
.962 .45907 Mdot
.962 .45992 Mdot
.962 .46037 Mdot
.962 .46056 Mdot
.962 .46141 Mdot
.962 .4615 Mdot
.962 .46221 Mdot
.962 .46275 Mdot
.962 .46309 Mdot
.962 .46344 Mdot
.962 .46347 Mdot
.962 .4638 Mdot
.962 .46509 Mdot
.962 .46697 Mdot
.962 .46835 Mdot
.962 .46897 Mdot
.962 .4691 Mdot
.962 .46918 Mdot
.962 .46928 Mdot
.962 .46938 Mdot
.962 .46969 Mdot
.962 .46982 Mdot
.962 .46985 Mdot
.962 .47027 Mdot
.962 .47109 Mdot
.962 .47224 Mdot
.962 .47268 Mdot
.962 .47272 Mdot
.962 .47313 Mdot
.962 .47342 Mdot
.962 .47345 Mdot
.962 .47356 Mdot
.962 .47356 Mdot
.962 .47385 Mdot
.962 .47423 Mdot
.962 .47462 Mdot
.962 .47494 Mdot
.962 .47532 Mdot
.962 .47548 Mdot
.962 .47593 Mdot
.962 .47653 Mdot
.962 .47768 Mdot
.962 .47772 Mdot
.962 .47841 Mdot
.962 .47848 Mdot
.962 .47876 Mdot
.962 .47878 Mdot
.962 .47901 Mdot
.962 .47932 Mdot
.962 .47992 Mdot
.962 .48025 Mdot
.962 .48075 Mdot
.962 .48084 Mdot
.962 .48173 Mdot
.962 .48188 Mdot
.962 .48197 Mdot
.962 .48213 Mdot
.962 .48355 Mdot
.962 .48365 Mdot
.962 .48467 Mdot
.962 .48483 Mdot
.962 .48634 Mdot
.962 .48664 Mdot
.962 .48679 Mdot
.962 .48783 Mdot
.962 .48793 Mdot
.962 .4882 Mdot
.962 .48858 Mdot
.962 .48866 Mdot
.962 .48899 Mdot
.962 .4891 Mdot
.962 .49014 Mdot
.962 .4906 Mdot
.962 .49061 Mdot
.962 .49131 Mdot
.962 .4915 Mdot
.962 .49167 Mdot
.962 .49175 Mdot
.962 .49218 Mdot
.962 .49285 Mdot
.962 .49297 Mdot
.962 .49335 Mdot
.962 .49359 Mdot
.962 .4937 Mdot
.962 .49372 Mdot
.962 .49426 Mdot
.962 .49496 Mdot
.962 .49597 Mdot
.962 .49605 Mdot
.962 .49615 Mdot
.962 .49623 Mdot
.962 .49664 Mdot
.962 .49759 Mdot
.962 .49832 Mdot
.962 .49843 Mdot
.962 .49901 Mdot
.962 .49948 Mdot
.962 .50001 Mdot
.962 .50007 Mdot
.962 .50008 Mdot
.962 .5004 Mdot
.962 .50049 Mdot
.962 .50059 Mdot
.962 .50062 Mdot
.962 .50093 Mdot
.962 .50148 Mdot
.962 .50169 Mdot
.962 .50194 Mdot
.962 .50234 Mdot
.962 .50258 Mdot
.962 .50314 Mdot
.962 .50318 Mdot
.962 .50334 Mdot
.962 .50334 Mdot
.962 .5038 Mdot
.962 .50497 Mdot
.962 .50527 Mdot
.962 .50681 Mdot
.962 .50709 Mdot
.962 .50742 Mdot
.962 .50756 Mdot
.962 .50804 Mdot
.962 .50836 Mdot
.962 .50921 Mdot
.962 .51 Mdot
.962 .51184 Mdot
.962 .51227 Mdot
.962 .51251 Mdot
.962 .51337 Mdot
.962 .5138 Mdot
.962 .51391 Mdot
.962 .51397 Mdot
.962 .5144 Mdot
.962 .5145 Mdot
.962 .5152 Mdot
.962 .5154 Mdot
.962 .51558 Mdot
.962 .5156 Mdot
.962 .51594 Mdot
.962 .51603 Mdot
.962 .5162 Mdot
.962 .5163 Mdot
.962 .51637 Mdot
.962 .51659 Mdot
.962 .51682 Mdot
.962 .51707 Mdot
.962 .51778 Mdot
.962 .51847 Mdot
.962 .51936 Mdot
.962 .51966 Mdot
.962 .52036 Mdot
.962 .52048 Mdot
.962 .52084 Mdot
.962 .52135 Mdot
.962 .52244 Mdot
.962 .52408 Mdot
.962 .52448 Mdot
.962 .52511 Mdot
.962 .52587 Mdot
.962 .529 Mdot
.962 .5291 Mdot
.962 .52958 Mdot
.962 .53019 Mdot
.962 .53082 Mdot
.962 .53089 Mdot
.962 .53144 Mdot
.962 .53173 Mdot
.962 .53354 Mdot
.962 .53367 Mdot
.962 .53424 Mdot
.962 .53427 Mdot
.962 .53514 Mdot
.962 .53537 Mdot
.962 .5358 Mdot
.962 .53621 Mdot
.962 .53633 Mdot
.962 .53676 Mdot
.962 .53743 Mdot
.962 .53755 Mdot
.962 .53786 Mdot
.962 .53792 Mdot
.962 .53884 Mdot
.962 .53885 Mdot
.962 .5401 Mdot
.962 .54021 Mdot
.962 .54025 Mdot
.962 .54025 Mdot
.962 .54072 Mdot
.962 .54211 Mdot
.962 .54217 Mdot
.962 .54272 Mdot
.962 .54432 Mdot
.962 .54473 Mdot
.962 .54505 Mdot
.962 .54521 Mdot
.962 .54642 Mdot
.962 .54679 Mdot
.962 .54692 Mdot
.962 .54695 Mdot
.962 .54822 Mdot
.962 .54892 Mdot
.962 .54929 Mdot
.962 .54952 Mdot
.962 .54955 Mdot
.962 .54968 Mdot
.962 .5501 Mdot
.962 .55026 Mdot
.962 .55058 Mdot
.962 .55125 Mdot
.962 .55269 Mdot
.962 .55276 Mdot
.962 .55301 Mdot
.962 .55372 Mdot
.962 .55373 Mdot
.962 .55411 Mdot
.962 .55515 Mdot
.962 .55563 Mdot
.962 .55568 Mdot
.962 .55629 Mdot
.962 .55638 Mdot
.962 .5568 Mdot
.962 .55726 Mdot
.962 .55729 Mdot
.962 .56019 Mdot
.962 .56038 Mdot
.962 .56093 Mdot
.962 .56166 Mdot
.962 .56202 Mdot
.962 .56379 Mdot
.962 .5641 Mdot
.962 .5652 Mdot
.962 .56524 Mdot
.962 .56565 Mdot
.962 .56633 Mdot
.962 .56695 Mdot
.962 .5671 Mdot
.962 .56968 Mdot
.962 .57081 Mdot
.962 .57089 Mdot
.962 .57125 Mdot
.962 .57496 Mdot
.962 .57575 Mdot
.962 .57593 Mdot
.962 .57597 Mdot
.962 .57703 Mdot
.962 .57706 Mdot
.962 .5786 Mdot
.962 .57864 Mdot
.962 .58015 Mdot
.962 .58118 Mdot
.962 .5813 Mdot
.962 .58136 Mdot
.962 .58143 Mdot
.962 .58147 Mdot
.962 .58181 Mdot
.964 .05813 Mdot
.964 .05937 Mdot
.964 .05962 Mdot
.964 .06042 Mdot
.964 .06073 Mdot
.964 .0615 Mdot
.964 .06169 Mdot
.964 .06358 Mdot
.964 .0652 Mdot
.964 .06612 Mdot
.964 .06643 Mdot
.964 .06679 Mdot
.964 .06813 Mdot
.964 .06835 Mdot
.964 .06947 Mdot
.964 .07014 Mdot
.964 .07113 Mdot
.964 .07174 Mdot
.964 .07241 Mdot
.964 .07325 Mdot
.964 .0739 Mdot
.964 .07444 Mdot
.964 .0762 Mdot
.964 .07743 Mdot
.964 .07801 Mdot
.964 .07868 Mdot
.964 .07937 Mdot
.964 .08084 Mdot
.964 .08134 Mdot
.964 .0823 Mdot
.964 .08389 Mdot
.964 .08637 Mdot
.964 .08675 Mdot
.964 .08756 Mdot
.964 .08778 Mdot
.964 .09182 Mdot
.964 .09378 Mdot
.964 .09389 Mdot
.964 .09444 Mdot
.964 .09611 Mdot
.964 .09756 Mdot
.964 .09843 Mdot
.964 .09902 Mdot
.964 .10082 Mdot
.964 .1013 Mdot
.964 .10283 Mdot
.964 .10316 Mdot
.964 .10344 Mdot
.964 .10382 Mdot
.964 .10385 Mdot
.964 .10397 Mdot
.964 .10429 Mdot
.964 .10491 Mdot
.964 .10497 Mdot
.964 .10528 Mdot
.964 .10539 Mdot
.964 .10552 Mdot
.964 .10632 Mdot
.964 .10846 Mdot
.964 .10893 Mdot
.964 .10922 Mdot
.964 .10945 Mdot
.964 .10957 Mdot
.964 .11071 Mdot
.964 .11097 Mdot
.964 .11206 Mdot
.964 .11383 Mdot
.964 .11442 Mdot
.964 .11469 Mdot
.964 .11471 Mdot
.964 .11511 Mdot
.964 .11584 Mdot
.964 .11586 Mdot
.964 .11678 Mdot
.964 .11729 Mdot
.964 .11733 Mdot
.964 .1176 Mdot
.964 .11769 Mdot
.964 .11812 Mdot
.964 .11854 Mdot
.964 .11855 Mdot
.964 .11891 Mdot
.964 .11978 Mdot
.964 .11984 Mdot
.964 .12028 Mdot
.964 .12158 Mdot
.964 .12219 Mdot
.964 .12235 Mdot
.964 .12349 Mdot
.964 .12406 Mdot
.964 .12465 Mdot
.964 .12595 Mdot
.964 .12636 Mdot
.964 .12748 Mdot
.964 .12757 Mdot
.964 .12882 Mdot
.964 .12986 Mdot
.964 .12989 Mdot
.964 .13024 Mdot
.964 .13045 Mdot
.964 .13197 Mdot
.964 .13269 Mdot
.964 .13321 Mdot
.964 .13327 Mdot
.964 .13496 Mdot
.964 .13562 Mdot
.964 .13675 Mdot
.964 .137 Mdot
.964 .13705 Mdot
.964 .13803 Mdot
.964 .1393 Mdot
.964 .13937 Mdot
.964 .14219 Mdot
.964 .14255 Mdot
.964 .14291 Mdot
.964 .14316 Mdot
.964 .14502 Mdot
.964 .14507 Mdot
.964 .14532 Mdot
.964 .14537 Mdot
.964 .1456 Mdot
.964 .14746 Mdot
.964 .14809 Mdot
.964 .14885 Mdot
.964 .14996 Mdot
.964 .15006 Mdot
.964 .15219 Mdot
.964 .15287 Mdot
.964 .15337 Mdot
.964 .15359 Mdot
.964 .15516 Mdot
.964 .15554 Mdot
.964 .15559 Mdot
.964 .15636 Mdot
.964 .15689 Mdot
.964 .15697 Mdot
.964 .15843 Mdot
.964 .15911 Mdot
.964 .16207 Mdot
.964 .16338 Mdot
.964 .1645 Mdot
.964 .16509 Mdot
.964 .16517 Mdot
.964 .16625 Mdot
.964 .16638 Mdot
.964 .16687 Mdot
.964 .1669 Mdot
.964 .16705 Mdot
.964 .16716 Mdot
.964 .16737 Mdot
.964 .16842 Mdot
.964 .17005 Mdot
.964 .17017 Mdot
.964 .17083 Mdot
.964 .1713 Mdot
.964 .17165 Mdot
.964 .17356 Mdot
.964 .17444 Mdot
.964 .17478 Mdot
.964 .17508 Mdot
.964 .17595 Mdot
.964 .17611 Mdot
.964 .17666 Mdot
.964 .17726 Mdot
.964 .18022 Mdot
.964 .18072 Mdot
.964 .18087 Mdot
.964 .18118 Mdot
.964 .18165 Mdot
.964 .18185 Mdot
.964 .18215 Mdot
.964 .1829 Mdot
.964 .18298 Mdot
.964 .18323 Mdot
.964 .18326 Mdot
.964 .1846 Mdot
.964 .18509 Mdot
.964 .18523 Mdot
.964 .18577 Mdot
.964 .1865 Mdot
.964 .18658 Mdot
.964 .18658 Mdot
.964 .18679 Mdot
.964 .18737 Mdot
.964 .18742 Mdot
.964 .18861 Mdot
.964 .18873 Mdot
.964 .18933 Mdot
.964 .18954 Mdot
.964 .18978 Mdot
.964 .19033 Mdot
.964 .19038 Mdot
.964 .19084 Mdot
.964 .19084 Mdot
.964 .1909 Mdot
.964 .19132 Mdot
.964 .19182 Mdot
.964 .19185 Mdot
.964 .19241 Mdot
.964 .19517 Mdot
.964 .19546 Mdot
.964 .19632 Mdot
.964 .19637 Mdot
.964 .1965 Mdot
.964 .19689 Mdot
.964 .19691 Mdot
.964 .19707 Mdot
.964 .19737 Mdot
.964 .1976 Mdot
.964 .19979 Mdot
.964 .2003 Mdot
.964 .20036 Mdot
.964 .20083 Mdot
.964 .20085 Mdot
.964 .20239 Mdot
.964 .20374 Mdot
.964 .20538 Mdot
.964 .20545 Mdot
.964 .20581 Mdot
.964 .2063 Mdot
.964 .20694 Mdot
.964 .20746 Mdot
.964 .2075 Mdot
.964 .20827 Mdot
.964 .20917 Mdot
.964 .2092 Mdot
.964 .20968 Mdot
.964 .20972 Mdot
.964 .21003 Mdot
.964 .21004 Mdot
.964 .21055 Mdot
.964 .21151 Mdot
.964 .21206 Mdot
.964 .21248 Mdot
.964 .21256 Mdot
.964 .21301 Mdot
.964 .21308 Mdot
.964 .21325 Mdot
.964 .21381 Mdot
.964 .21407 Mdot
.964 .21416 Mdot
.964 .21488 Mdot
.964 .21491 Mdot
.964 .21561 Mdot
.964 .21579 Mdot
.964 .2158 Mdot
.964 .21614 Mdot
.964 .21647 Mdot
.964 .21728 Mdot
.964 .2174 Mdot
.964 .21774 Mdot
.964 .21786 Mdot
.964 .21796 Mdot
.964 .2181 Mdot
.964 .21825 Mdot
.964 .21828 Mdot
.964 .22074 Mdot
.964 .22139 Mdot
.964 .22143 Mdot
.964 .2218 Mdot
.964 .22193 Mdot
.964 .22205 Mdot
.964 .22223 Mdot
.964 .22272 Mdot
.964 .22276 Mdot
.964 .2229 Mdot
.964 .22404 Mdot
.964 .22443 Mdot
.964 .22487 Mdot
.964 .22554 Mdot
.964 .22668 Mdot
.964 .22841 Mdot
.964 .22868 Mdot
.964 .22917 Mdot
.964 .22925 Mdot
.964 .22997 Mdot
.964 .23052 Mdot
.964 .23088 Mdot
.964 .23161 Mdot
.964 .23212 Mdot
.964 .23229 Mdot
.964 .23265 Mdot
.964 .23302 Mdot
.964 .23343 Mdot
.964 .23452 Mdot
.964 .23471 Mdot
.964 .23598 Mdot
.964 .23653 Mdot
.964 .23671 Mdot
.964 .23678 Mdot
.964 .23745 Mdot
.964 .23775 Mdot
.964 .23779 Mdot
.964 .23786 Mdot
.964 .23855 Mdot
.964 .23874 Mdot
.964 .23903 Mdot
.964 .24078 Mdot
.964 .24216 Mdot
.964 .24307 Mdot
.964 .24318 Mdot
.964 .24328 Mdot
.964 .24496 Mdot
.964 .24591 Mdot
.964 .24655 Mdot
.964 .24783 Mdot
.964 .24936 Mdot
.964 .25 Mdot
.964 .25049 Mdot
.964 .25057 Mdot
.964 .25247 Mdot
.964 .25247 Mdot
.964 .25253 Mdot
.964 .25345 Mdot
.964 .25453 Mdot
.964 .25492 Mdot
.964 .25506 Mdot
.964 .25852 Mdot
.964 .25877 Mdot
.964 .25928 Mdot
.964 .2605 Mdot
.964 .2607 Mdot
.964 .26071 Mdot
.964 .26104 Mdot
.964 .26119 Mdot
.964 .26187 Mdot
.964 .26198 Mdot
.964 .26236 Mdot
.964 .26474 Mdot
.964 .26475 Mdot
.964 .26494 Mdot
.964 .26595 Mdot
.964 .26604 Mdot
.964 .26606 Mdot
.964 .26652 Mdot
.964 .26662 Mdot
.964 .26706 Mdot
.964 .26817 Mdot
.964 .26817 Mdot
.964 .26839 Mdot
.964 .2684 Mdot
.964 .26986 Mdot
.964 .27064 Mdot
.964 .27186 Mdot
.964 .27216 Mdot
.964 .27333 Mdot
.964 .27427 Mdot
.964 .27448 Mdot
.964 .27544 Mdot
.964 .27547 Mdot
.964 .27567 Mdot
.964 .27575 Mdot
.964 .27757 Mdot
.964 .27798 Mdot
.964 .27977 Mdot
.964 .27995 Mdot
.964 .28107 Mdot
.964 .28205 Mdot
.964 .28246 Mdot
.964 .28341 Mdot
.964 .2855 Mdot
.964 .28556 Mdot
.964 .28564 Mdot
.964 .28623 Mdot
.964 .28632 Mdot
.964 .2878 Mdot
.964 .28883 Mdot
.964 .28898 Mdot
.964 .28917 Mdot
.964 .28958 Mdot
.964 .28963 Mdot
.964 .29038 Mdot
.964 .2918 Mdot
.964 .29278 Mdot
.964 .29278 Mdot
.964 .29303 Mdot
.964 .29311 Mdot
.964 .29312 Mdot
.964 .29489 Mdot
.964 .29632 Mdot
.964 .29674 Mdot
.964 .29803 Mdot
.964 .29881 Mdot
.964 .30133 Mdot
.964 .30253 Mdot
.964 .30292 Mdot
.964 .30332 Mdot
.964 .30351 Mdot
.964 .30384 Mdot
.964 .30417 Mdot
.964 .30465 Mdot
.964 .30479 Mdot
.964 .3058 Mdot
.964 .30598 Mdot
.964 .3067 Mdot
.964 .30688 Mdot
.964 .30713 Mdot
.964 .30808 Mdot
.964 .30813 Mdot
.964 .30842 Mdot
.964 .30863 Mdot
.964 .30903 Mdot
.964 .31069 Mdot
.964 .31106 Mdot
.964 .31183 Mdot
.964 .31259 Mdot
.964 .31305 Mdot
.964 .31311 Mdot
.964 .31386 Mdot
.964 .31402 Mdot
.964 .3142 Mdot
.964 .31443 Mdot
.964 .31571 Mdot
.964 .3166 Mdot
.964 .31729 Mdot
.964 .31796 Mdot
.964 .31828 Mdot
.964 .31834 Mdot
.964 .31942 Mdot
.964 .31995 Mdot
.964 .31998 Mdot
.964 .32013 Mdot
.964 .32097 Mdot
.964 .32247 Mdot
.964 .32266 Mdot
.964 .32269 Mdot
.964 .32296 Mdot
.964 .32311 Mdot
.964 .32332 Mdot
.964 .3239 Mdot
.964 .3241 Mdot
.964 .32417 Mdot
.964 .3242 Mdot
.964 .32458 Mdot
.964 .32557 Mdot
.964 .32558 Mdot
.964 .32588 Mdot
.964 .32589 Mdot
.964 .32614 Mdot
.964 .32671 Mdot
.964 .32695 Mdot
.964 .32696 Mdot
.964 .32764 Mdot
.964 .3281 Mdot
.964 .32872 Mdot
.964 .32967 Mdot
.964 .33103 Mdot
.964 .33158 Mdot
.964 .3322 Mdot
.964 .33382 Mdot
.964 .33439 Mdot
.964 .33477 Mdot
.964 .33506 Mdot
.964 .33509 Mdot
.964 .33566 Mdot
.964 .33657 Mdot
.964 .33679 Mdot
.964 .33695 Mdot
.964 .33753 Mdot
.964 .33898 Mdot
.964 .33914 Mdot
.964 .33916 Mdot
.964 .33948 Mdot
.964 .33961 Mdot
.964 .33966 Mdot
.964 .34047 Mdot
.964 .3405 Mdot
.964 .34068 Mdot
.964 .3408 Mdot
.964 .34174 Mdot
.964 .34206 Mdot
.964 .34225 Mdot
.964 .34321 Mdot
.964 .34338 Mdot
.964 .34346 Mdot
.964 .34401 Mdot
.964 .34402 Mdot
.964 .34452 Mdot
.964 .34592 Mdot
.964 .34594 Mdot
.964 .34606 Mdot
.964 .34608 Mdot
.964 .34632 Mdot
.964 .34633 Mdot
.964 .34648 Mdot
.964 .34759 Mdot
.964 .34769 Mdot
.964 .34774 Mdot
.964 .34862 Mdot
.964 .34875 Mdot
.964 .34997 Mdot
.964 .34999 Mdot
.964 .35022 Mdot
.964 .35136 Mdot
.964 .35177 Mdot
.964 .35202 Mdot
.964 .35224 Mdot
.964 .35278 Mdot
.964 .35296 Mdot
.964 .3533 Mdot
.964 .3534 Mdot
.964 .35428 Mdot
.964 .35429 Mdot
.964 .35439 Mdot
.964 .35469 Mdot
.964 .35499 Mdot
.964 .35522 Mdot
.964 .35617 Mdot
.964 .35624 Mdot
.964 .3564 Mdot
.964 .35674 Mdot
.964 .35683 Mdot
.964 .35731 Mdot
.964 .35781 Mdot
.964 .35895 Mdot
.964 .35903 Mdot
.964 .3618 Mdot
.964 .36264 Mdot
.964 .36266 Mdot
.964 .36291 Mdot
.964 .3632 Mdot
.964 .36427 Mdot
.964 .36486 Mdot
.964 .36495 Mdot
.964 .3652 Mdot
.964 .36595 Mdot
.964 .366 Mdot
.964 .3663 Mdot
.964 .36686 Mdot
.964 .36732 Mdot
.964 .36794 Mdot
.964 .36851 Mdot
.964 .36856 Mdot
.964 .3695 Mdot
.964 .37097 Mdot
.964 .37154 Mdot
.964 .37251 Mdot
.964 .37262 Mdot
.964 .37264 Mdot
.964 .37349 Mdot
.964 .37355 Mdot
.964 .37357 Mdot
.964 .37405 Mdot
.964 .37455 Mdot
.964 .3749 Mdot
.964 .37646 Mdot
.964 .37655 Mdot
.964 .37699 Mdot
.964 .37704 Mdot
.964 .37831 Mdot
.964 .37882 Mdot
.964 .37894 Mdot
.964 .37895 Mdot
.964 .37916 Mdot
.964 .3792 Mdot
.964 .38026 Mdot
.964 .38035 Mdot
.964 .3808 Mdot
.964 .3808 Mdot
.964 .38147 Mdot
.964 .38191 Mdot
.964 .38193 Mdot
.964 .38204 Mdot
.964 .38231 Mdot
.964 .38239 Mdot
.964 .38246 Mdot
.964 .38315 Mdot
.964 .38378 Mdot
.964 .38392 Mdot
.964 .38409 Mdot
.964 .38532 Mdot
.964 .38605 Mdot
.964 .38632 Mdot
.964 .38632 Mdot
.964 .38641 Mdot
.964 .38666 Mdot
.964 .38727 Mdot
.964 .38789 Mdot
.964 .38789 Mdot
.964 .38827 Mdot
.964 .38854 Mdot
.964 .38963 Mdot
.964 .38967 Mdot
.964 .3906 Mdot
.964 .39069 Mdot
.964 .39129 Mdot
.964 .39131 Mdot
.964 .39205 Mdot
.964 .39228 Mdot
.964 .39235 Mdot
.964 .39371 Mdot
.964 .39387 Mdot
.964 .39413 Mdot
.964 .3952 Mdot
.964 .39548 Mdot
.964 .39558 Mdot
.964 .396 Mdot
.964 .39614 Mdot
.964 .39615 Mdot
.964 .39666 Mdot
.964 .39673 Mdot
.964 .39702 Mdot
.964 .39704 Mdot
.964 .39717 Mdot
.964 .39747 Mdot
.964 .3975 Mdot
.964 .39858 Mdot
.964 .39874 Mdot
.964 .39891 Mdot
.964 .39907 Mdot
.964 .39917 Mdot
.964 .39925 Mdot
.964 .39955 Mdot
.964 .40019 Mdot
.964 .40027 Mdot
.964 .40064 Mdot
.964 .40068 Mdot
.964 .40145 Mdot
.964 .40204 Mdot
.964 .40221 Mdot
.964 .40238 Mdot
.964 .4024 Mdot
.964 .40272 Mdot
.964 .40306 Mdot
.964 .40343 Mdot
.964 .4037 Mdot
.964 .40409 Mdot
.964 .4047 Mdot
.964 .40474 Mdot
.964 .40508 Mdot
.964 .40527 Mdot
.964 .40541 Mdot
.964 .40549 Mdot
.964 .40615 Mdot
.964 .40638 Mdot
.964 .40653 Mdot
.964 .40657 Mdot
.964 .40684 Mdot
.964 .40714 Mdot
.964 .40718 Mdot
.964 .40802 Mdot
.964 .40811 Mdot
.964 .40881 Mdot
.964 .40896 Mdot
.964 .41078 Mdot
.964 .41092 Mdot
.964 .41112 Mdot
.964 .41144 Mdot
.964 .41176 Mdot
.964 .41194 Mdot
.964 .41208 Mdot
.964 .41318 Mdot
.964 .41326 Mdot
.964 .41397 Mdot
.964 .41416 Mdot
.964 .41421 Mdot
.964 .41422 Mdot
.964 .41445 Mdot
.964 .4148 Mdot
.964 .4148 Mdot
.964 .41504 Mdot
.964 .41508 Mdot
.964 .41563 Mdot
.964 .41576 Mdot
.964 .41577 Mdot
.964 .41583 Mdot
.964 .41609 Mdot
.964 .41675 Mdot
.964 .41678 Mdot
.964 .41705 Mdot
.964 .41786 Mdot
.964 .41804 Mdot
.964 .4183 Mdot
.964 .41859 Mdot
.964 .41904 Mdot
.964 .4199 Mdot
.964 .42066 Mdot
.964 .42115 Mdot
.964 .42118 Mdot
.964 .42147 Mdot
.964 .42337 Mdot
.964 .42408 Mdot
.964 .42421 Mdot
.964 .42465 Mdot
.964 .42609 Mdot
.964 .42613 Mdot
.964 .42672 Mdot
.964 .42723 Mdot
.964 .42728 Mdot
.964 .42746 Mdot
.964 .42818 Mdot
.964 .42834 Mdot
.964 .42924 Mdot
.964 .42933 Mdot
.964 .42972 Mdot
.964 .43079 Mdot
.964 .43142 Mdot
.964 .43149 Mdot
.964 .43195 Mdot
.964 .43268 Mdot
.964 .43268 Mdot
.964 .43288 Mdot
.964 .43388 Mdot
.964 .43388 Mdot
.964 .43421 Mdot
.964 .4349 Mdot
.964 .43506 Mdot
.964 .43554 Mdot
.964 .43561 Mdot
.964 .4357 Mdot
.964 .43572 Mdot
.964 .43623 Mdot
.964 .4364 Mdot
.964 .43763 Mdot
.964 .43851 Mdot
.964 .43887 Mdot
.964 .44001 Mdot
.964 .44033 Mdot
.964 .44061 Mdot
.964 .44132 Mdot
.964 .44181 Mdot
.964 .44237 Mdot
.964 .44272 Mdot
.964 .44285 Mdot
.964 .44315 Mdot
.964 .44328 Mdot
.964 .44344 Mdot
.964 .44396 Mdot
.964 .44416 Mdot
.964 .44417 Mdot
.964 .44421 Mdot
.964 .44472 Mdot
.964 .4448 Mdot
.964 .44494 Mdot
.964 .44505 Mdot
.964 .44627 Mdot
.964 .44634 Mdot
.964 .44636 Mdot
.964 .44663 Mdot
.964 .4472 Mdot
.964 .44723 Mdot
.964 .44739 Mdot
.964 .44944 Mdot
.964 .44952 Mdot
.964 .44991 Mdot
.964 .44994 Mdot
.964 .45018 Mdot
.964 .45057 Mdot
.964 .45116 Mdot
.964 .45323 Mdot
.964 .45361 Mdot
.964 .4537 Mdot
.964 .45455 Mdot
.964 .45472 Mdot
.964 .45499 Mdot
.964 .45519 Mdot
.964 .4554 Mdot
.964 .45773 Mdot
.964 .4584 Mdot
.964 .45862 Mdot
.964 .45936 Mdot
.964 .46028 Mdot
.964 .46032 Mdot
.964 .46045 Mdot
.964 .46045 Mdot
.964 .4617 Mdot
.964 .46209 Mdot
.964 .46212 Mdot
.964 .46233 Mdot
.964 .46415 Mdot
.964 .4642 Mdot
.964 .46531 Mdot
.964 .46711 Mdot
.964 .46813 Mdot
.964 .46834 Mdot
.964 .46929 Mdot
.964 .46944 Mdot
.964 .46995 Mdot
.964 .47006 Mdot
.964 .47115 Mdot
.964 .47234 Mdot
.964 .4731 Mdot
.964 .4731 Mdot
.964 .47322 Mdot
.964 .47322 Mdot
.964 .47431 Mdot
.964 .4749 Mdot
.964 .47499 Mdot
.964 .475 Mdot
.964 .47643 Mdot
.964 .47692 Mdot
.964 .47709 Mdot
.964 .47709 Mdot
.964 .47783 Mdot
.964 .47809 Mdot
.964 .47822 Mdot
.964 .48029 Mdot
.964 .48085 Mdot
.964 .48133 Mdot
.964 .48136 Mdot
.964 .48297 Mdot
.964 .48476 Mdot
.964 .48526 Mdot
.964 .48624 Mdot
.964 .48833 Mdot
.964 .48848 Mdot
.964 .48858 Mdot
.964 .48898 Mdot
.964 .489 Mdot
.964 .48963 Mdot
.964 .48991 Mdot
.964 .49067 Mdot
.964 .49124 Mdot
.964 .49145 Mdot
.964 .49164 Mdot
.964 .49218 Mdot
.964 .49256 Mdot
.964 .49275 Mdot
.964 .4934 Mdot
.964 .4937 Mdot
.964 .49384 Mdot
.964 .49567 Mdot
.964 .49611 Mdot
.964 .4967 Mdot
.964 .49677 Mdot
.964 .49679 Mdot
.964 .49714 Mdot
.964 .49727 Mdot
.964 .49746 Mdot
.964 .49748 Mdot
.964 .4991 Mdot
.964 .49919 Mdot
.964 .49926 Mdot
.964 .49931 Mdot
.964 .49937 Mdot
.964 .50003 Mdot
.964 .5002 Mdot
.964 .50038 Mdot
.964 .50039 Mdot
.964 .50123 Mdot
.964 .50141 Mdot
.964 .50183 Mdot
.964 .50232 Mdot
.964 .5031 Mdot
.964 .50337 Mdot
.964 .50337 Mdot
.964 .50381 Mdot
.964 .50382 Mdot
.964 .50531 Mdot
.964 .50575 Mdot
.964 .50579 Mdot
.964 .50664 Mdot
.964 .50814 Mdot
.964 .50814 Mdot
.964 .50839 Mdot
.964 .51009 Mdot
.964 .51019 Mdot
.964 .51039 Mdot
.964 .51048 Mdot
.964 .51108 Mdot
.964 .51251 Mdot
.964 .5128 Mdot
.964 .51282 Mdot
.964 .5133 Mdot
.964 .51332 Mdot
.964 .51333 Mdot
.964 .51357 Mdot
.964 .51359 Mdot
.964 .51513 Mdot
.964 .51553 Mdot
.964 .51631 Mdot
.964 .51726 Mdot
.964 .51727 Mdot
.964 .5174 Mdot
.964 .51744 Mdot
.964 .51783 Mdot
.964 .51799 Mdot
.964 .51834 Mdot
.964 .5185 Mdot
.964 .51883 Mdot
.964 .52068 Mdot
.964 .52105 Mdot
.964 .5215 Mdot
.964 .52166 Mdot
.964 .52229 Mdot
.964 .52346 Mdot
.964 .5237 Mdot
.964 .52405 Mdot
.964 .52411 Mdot
.964 .52567 Mdot
.964 .52574 Mdot
.964 .52576 Mdot
.964 .52601 Mdot
.964 .52608 Mdot
.964 .52664 Mdot
.964 .52668 Mdot
.964 .52699 Mdot
.964 .52825 Mdot
.964 .52978 Mdot
.964 .53014 Mdot
.964 .5309 Mdot
.964 .53093 Mdot
.964 .53121 Mdot
.964 .53164 Mdot
.964 .53276 Mdot
.964 .53337 Mdot
.964 .53448 Mdot
.964 .53453 Mdot
.964 .5351 Mdot
.964 .53583 Mdot
.964 .53679 Mdot
.964 .53691 Mdot
.964 .53694 Mdot
.964 .53707 Mdot
.964 .53819 Mdot
.964 .53837 Mdot
.964 .54006 Mdot
.964 .54123 Mdot
.964 .54125 Mdot
.964 .54231 Mdot
.964 .54322 Mdot
.964 .54349 Mdot
.964 .54386 Mdot
.964 .54465 Mdot
.964 .54476 Mdot
.964 .54494 Mdot
.964 .54619 Mdot
.964 .54677 Mdot
.964 .54796 Mdot
.964 .54885 Mdot
.964 .54893 Mdot
.964 .55015 Mdot
.964 .55018 Mdot
.964 .55063 Mdot
.964 .55082 Mdot
.964 .55083 Mdot
.964 .55131 Mdot
.964 .55145 Mdot
.964 .55148 Mdot
.964 .55174 Mdot
.964 .55222 Mdot
.964 .55223 Mdot
.964 .55281 Mdot
.964 .55283 Mdot
.964 .55475 Mdot
.964 .55489 Mdot
.964 .55548 Mdot
.964 .55554 Mdot
.964 .55566 Mdot
.964 .55605 Mdot
.964 .55717 Mdot
.964 .55758 Mdot
.964 .55765 Mdot
.964 .55786 Mdot
.964 .55822 Mdot
.964 .55838 Mdot
.964 .55844 Mdot
.964 .55846 Mdot
.964 .55881 Mdot
.964 .56095 Mdot
.964 .56171 Mdot
.964 .56246 Mdot
.964 .56333 Mdot
.964 .56361 Mdot
.964 .56367 Mdot
.964 .56468 Mdot
.964 .56678 Mdot
.964 .56689 Mdot
.964 .56732 Mdot
.964 .56751 Mdot
.964 .5688 Mdot
.964 .56962 Mdot
.964 .57012 Mdot
.964 .57038 Mdot
.964 .57114 Mdot
.964 .5715 Mdot
.964 .57185 Mdot
.964 .57215 Mdot
.964 .57278 Mdot
.964 .5737 Mdot
.964 .57398 Mdot
.964 .57432 Mdot
.964 .57475 Mdot
.964 .5751 Mdot
.964 .57542 Mdot
.964 .57593 Mdot
.964 .57628 Mdot
.964 .57686 Mdot
.964 .57697 Mdot
.964 .57767 Mdot
.964 .57786 Mdot
.964 .57801 Mdot
.964 .57849 Mdot
.964 .57933 Mdot
.964 .58031 Mdot
.964 .58041 Mdot
.964 .58081 Mdot
.964 .58097 Mdot
.964 .58138 Mdot
.964 .58151 Mdot
.964 .58216 Mdot
.966 .05511 Mdot
.966 .05749 Mdot
.966 .05782 Mdot
.966 .05968 Mdot
.966 .06019 Mdot
.966 .06114 Mdot
.966 .06127 Mdot
.966 .06191 Mdot
.966 .062 Mdot
.966 .06328 Mdot
.966 .06351 Mdot
.966 .06387 Mdot
.966 .06573 Mdot
.966 .06629 Mdot
.966 .06715 Mdot
.966 .06741 Mdot
.966 .06781 Mdot
.966 .06923 Mdot
.966 .06976 Mdot
.966 .07012 Mdot
.966 .07202 Mdot
.966 .07401 Mdot
.966 .07567 Mdot
.966 .07582 Mdot
.966 .07693 Mdot
.966 .07739 Mdot
.966 .07786 Mdot
.966 .07972 Mdot
.966 .08116 Mdot
.966 .08204 Mdot
.966 .08383 Mdot
.966 .08417 Mdot
.966 .08482 Mdot
.966 .085 Mdot
.966 .0872 Mdot
.966 .08767 Mdot
.966 .08768 Mdot
.966 .08788 Mdot
.966 .08851 Mdot
.966 .08964 Mdot
.966 .08987 Mdot
.966 .09005 Mdot
.966 .09215 Mdot
.966 .09276 Mdot
.966 .09423 Mdot
.966 .09436 Mdot
.966 .09736 Mdot
.966 .09799 Mdot
.966 .09811 Mdot
.966 .10158 Mdot
.966 .10184 Mdot
.966 .10233 Mdot
.966 .10257 Mdot
.966 .10275 Mdot
.966 .10393 Mdot
.966 .1044 Mdot
.966 .10465 Mdot
.966 .10491 Mdot
.966 .1055 Mdot
.966 .1059 Mdot
.966 .10607 Mdot
.966 .10742 Mdot
.966 .10854 Mdot
.966 .10899 Mdot
.966 .10899 Mdot
.966 .10968 Mdot
.966 .1099 Mdot
.966 .11013 Mdot
.966 .11064 Mdot
.966 .11187 Mdot
.966 .11267 Mdot
.966 .11307 Mdot
.966 .1132 Mdot
.966 .11329 Mdot
.966 .11335 Mdot
.966 .1143 Mdot
.966 .11437 Mdot
.966 .11466 Mdot
.966 .11471 Mdot
.966 .11554 Mdot
.966 .11602 Mdot
.966 .11652 Mdot
.966 .11694 Mdot
.966 .11729 Mdot
.966 .11757 Mdot
.966 .11867 Mdot
.966 .12004 Mdot
.966 .12044 Mdot
.966 .12082 Mdot
.966 .12106 Mdot
.966 .12115 Mdot
.966 .12175 Mdot
.966 .12175 Mdot
.966 .12317 Mdot
.966 .12511 Mdot
.966 .12544 Mdot
.966 .12574 Mdot
.966 .12636 Mdot
.966 .12798 Mdot
.966 .12928 Mdot
.966 .1307 Mdot
.966 .13118 Mdot
.966 .13172 Mdot
.966 .13203 Mdot
.966 .13248 Mdot
.966 .13277 Mdot
.966 .13314 Mdot
.966 .13491 Mdot
.966 .13517 Mdot
.966 .13529 Mdot
.966 .13581 Mdot
.966 .13615 Mdot
.966 .13644 Mdot
.966 .13652 Mdot
.966 .13671 Mdot
.966 .13675 Mdot
.966 .13796 Mdot
.966 .13807 Mdot
.966 .1403 Mdot
.966 .14108 Mdot
.966 .1424 Mdot
.966 .14242 Mdot
.966 .14309 Mdot
.966 .14446 Mdot
.966 .14464 Mdot
.966 .14478 Mdot
.966 .14552 Mdot
.966 .14561 Mdot
.966 .14825 Mdot
.966 .14861 Mdot
.966 .1489 Mdot
.966 .15017 Mdot
.966 .15051 Mdot
.966 .1512 Mdot
.966 .15172 Mdot
.966 .1519 Mdot
.966 .15283 Mdot
.966 .15475 Mdot
.966 .15506 Mdot
.966 .15525 Mdot
.966 .15566 Mdot
.966 .15568 Mdot
.966 .15585 Mdot
.966 .15607 Mdot
.966 .1565 Mdot
.966 .15729 Mdot
.966 .15737 Mdot
.966 .15746 Mdot
.966 .15793 Mdot
.966 .15806 Mdot
.966 .15851 Mdot
.966 .15879 Mdot
.966 .15947 Mdot
.966 .15957 Mdot
.966 .15992 Mdot
.966 .16026 Mdot
.966 .16238 Mdot
.966 .16254 Mdot
.966 .16265 Mdot
.966 .16272 Mdot
.966 .16432 Mdot
.966 .1655 Mdot
.966 .16595 Mdot
.966 .16623 Mdot
.966 .16633 Mdot
.966 .16654 Mdot
.966 .16762 Mdot
.966 .16833 Mdot
.966 .16858 Mdot
.966 .16876 Mdot
.966 .16879 Mdot
.966 .16958 Mdot
.966 .16966 Mdot
.966 .17025 Mdot
.966 .17177 Mdot
.966 .17217 Mdot
.966 .17276 Mdot
.966 .17307 Mdot
.966 .17423 Mdot
.966 .17439 Mdot
.966 .17525 Mdot
.966 .17549 Mdot
.966 .17561 Mdot
.966 .17583 Mdot
.966 .17644 Mdot
.966 .17668 Mdot
.966 .17773 Mdot
.966 .17811 Mdot
.966 .17825 Mdot
.966 .17886 Mdot
.966 .1789 Mdot
.966 .18059 Mdot
.966 .18095 Mdot
.966 .18255 Mdot
.966 .18303 Mdot
.966 .18305 Mdot
.966 .18394 Mdot
.966 .18398 Mdot
.966 .18445 Mdot
.966 .18468 Mdot
.966 .18479 Mdot
.966 .18502 Mdot
.966 .18655 Mdot
.966 .18685 Mdot
.966 .18697 Mdot
.966 .18708 Mdot
.966 .18744 Mdot
.966 .18799 Mdot
.966 .18847 Mdot
.966 .18891 Mdot
.966 .18897 Mdot
.966 .19011 Mdot
.966 .19089 Mdot
.966 .19121 Mdot
.966 .19152 Mdot
.966 .19162 Mdot
.966 .19377 Mdot
.966 .19381 Mdot
.966 .19465 Mdot
.966 .19538 Mdot
.966 .19599 Mdot
.966 .19685 Mdot
.966 .19686 Mdot
.966 .19798 Mdot
.966 .19819 Mdot
.966 .19861 Mdot
.966 .19864 Mdot
.966 .19906 Mdot
.966 .1991 Mdot
.966 .20004 Mdot
.966 .20157 Mdot
.966 .20195 Mdot
.966 .20241 Mdot
.966 .20396 Mdot
.966 .20472 Mdot
.966 .20474 Mdot
.966 .20499 Mdot
.966 .20515 Mdot
.966 .20529 Mdot
.966 .20544 Mdot
.966 .20658 Mdot
.966 .20711 Mdot
.966 .20724 Mdot
.966 .20732 Mdot
.966 .2078 Mdot
.966 .2079 Mdot
.966 .20864 Mdot
.966 .20901 Mdot
.966 .20951 Mdot
.966 .21043 Mdot
.966 .21057 Mdot
.966 .21123 Mdot
.966 .21141 Mdot
.966 .21221 Mdot
.966 .21222 Mdot
.966 .21289 Mdot
.966 .21342 Mdot
.966 .21436 Mdot
.966 .21483 Mdot
.966 .21556 Mdot
.966 .21655 Mdot
.966 .2169 Mdot
.966 .21712 Mdot
.966 .21722 Mdot
.966 .21726 Mdot
.966 .21758 Mdot
.966 .21759 Mdot
.966 .21821 Mdot
.966 .21832 Mdot
.966 .21891 Mdot
.966 .21898 Mdot
.966 .21972 Mdot
.966 .22017 Mdot
.966 .22034 Mdot
.966 .22057 Mdot
.966 .22151 Mdot
.966 .22151 Mdot
.966 .2229 Mdot
.966 .22426 Mdot
.966 .22476 Mdot
.966 .22523 Mdot
.966 .22656 Mdot
.966 .22746 Mdot
.966 .228 Mdot
.966 .22813 Mdot
.966 .22863 Mdot
.966 .22876 Mdot
.966 .22922 Mdot
.966 .23042 Mdot
.966 .2306 Mdot
.966 .23349 Mdot
.966 .23354 Mdot
.966 .23359 Mdot
.966 .23375 Mdot
.966 .23533 Mdot
.966 .23605 Mdot
.966 .2388 Mdot
.966 .23972 Mdot
.966 .24013 Mdot
.966 .24076 Mdot
.966 .24136 Mdot
.966 .24161 Mdot
.966 .24208 Mdot
.966 .24225 Mdot
.966 .24277 Mdot
.966 .2428 Mdot
.966 .24323 Mdot
.966 .24351 Mdot
.966 .24366 Mdot
.966 .24398 Mdot
.966 .24479 Mdot
.966 .24544 Mdot
.966 .24692 Mdot
.966 .24743 Mdot
.966 .24766 Mdot
.966 .2484 Mdot
.966 .24867 Mdot
.966 .24889 Mdot
.966 .24933 Mdot
.966 .24989 Mdot
.966 .25001 Mdot
.966 .25005 Mdot
.966 .25042 Mdot
.966 .25049 Mdot
.966 .25147 Mdot
.966 .25245 Mdot
.966 .25283 Mdot
.966 .25304 Mdot
.966 .25459 Mdot
.966 .25526 Mdot
.966 .25533 Mdot
.966 .25549 Mdot
.966 .25581 Mdot
.966 .25639 Mdot
.966 .25665 Mdot
.966 .25734 Mdot
.966 .25886 Mdot
.966 .25917 Mdot
.966 .25929 Mdot
.966 .25969 Mdot
.966 .2614 Mdot
.966 .26144 Mdot
.966 .26274 Mdot
.966 .26493 Mdot
.966 .26537 Mdot
.966 .26573 Mdot
.966 .26573 Mdot
.966 .26585 Mdot
.966 .26591 Mdot
.966 .266 Mdot
.966 .26647 Mdot
.966 .26716 Mdot
.966 .26743 Mdot
.966 .26761 Mdot
.966 .2708 Mdot
.966 .27271 Mdot
.966 .27341 Mdot
.966 .27393 Mdot
.966 .27396 Mdot
.966 .27404 Mdot
.966 .27445 Mdot
.966 .27474 Mdot
.966 .27554 Mdot
.966 .2761 Mdot
.966 .27627 Mdot
.966 .27641 Mdot
.966 .27669 Mdot
.966 .277 Mdot
.966 .27707 Mdot
.966 .27841 Mdot
.966 .27857 Mdot
.966 .2788 Mdot
.966 .27881 Mdot
.966 .27911 Mdot
.966 .2794 Mdot
.966 .28045 Mdot
.966 .28048 Mdot
.966 .28127 Mdot
.966 .28156 Mdot
.966 .28171 Mdot
.966 .28184 Mdot
.966 .28209 Mdot
.966 .28227 Mdot
.966 .28248 Mdot
.966 .28501 Mdot
.966 .28504 Mdot
.966 .28527 Mdot
.966 .28587 Mdot
.966 .28587 Mdot
.966 .28622 Mdot
.966 .28703 Mdot
.966 .28706 Mdot
.966 .28738 Mdot
.966 .28745 Mdot
.966 .28778 Mdot
.966 .28781 Mdot
.966 .28865 Mdot
.966 .28888 Mdot
.966 .29017 Mdot
.966 .29033 Mdot
.966 .2905 Mdot
.966 .2914 Mdot
.966 .29165 Mdot
.966 .29252 Mdot
.966 .29307 Mdot
.966 .29329 Mdot
.966 .2933 Mdot
.966 .29438 Mdot
.966 .29458 Mdot
.966 .29524 Mdot
.966 .29576 Mdot
.966 .29592 Mdot
.966 .29878 Mdot
.966 .2999 Mdot
.966 .29994 Mdot
.966 .30001 Mdot
.966 .30031 Mdot
.966 .30053 Mdot
.966 .30053 Mdot
.966 .30066 Mdot
.966 .30156 Mdot
.966 .30266 Mdot
.966 .30316 Mdot
.966 .30329 Mdot
.966 .30341 Mdot
.966 .30371 Mdot
.966 .30375 Mdot
.966 .30524 Mdot
.966 .30585 Mdot
.966 .30596 Mdot
.966 .30603 Mdot
.966 .30641 Mdot
.966 .30691 Mdot
.966 .30743 Mdot
.966 .30761 Mdot
.966 .30764 Mdot
.966 .30803 Mdot
.966 .30853 Mdot
.966 .31014 Mdot
.966 .31078 Mdot
.966 .3115 Mdot
.966 .31198 Mdot
.966 .31233 Mdot
.966 .31239 Mdot
.966 .31313 Mdot
.966 .31392 Mdot
.966 .31406 Mdot
.966 .31467 Mdot
.966 .3152 Mdot
.966 .31712 Mdot
.966 .31735 Mdot
.966 .31792 Mdot
.966 .3181 Mdot
.966 .31814 Mdot
.966 .31892 Mdot
.966 .32006 Mdot
.966 .32065 Mdot
.966 .32166 Mdot
.966 .32266 Mdot
.966 .32279 Mdot
.966 .3229 Mdot
.966 .32322 Mdot
.966 .32457 Mdot
.966 .32488 Mdot
.966 .32534 Mdot
.966 .32556 Mdot
.966 .32566 Mdot
.966 .3257 Mdot
.966 .32574 Mdot
.966 .32599 Mdot
.966 .3267 Mdot
.966 .32717 Mdot
.966 .32764 Mdot
.966 .32783 Mdot
.966 .32837 Mdot
.966 .32966 Mdot
.966 .33039 Mdot
.966 .33066 Mdot
.966 .33104 Mdot
.966 .33185 Mdot
.966 .33193 Mdot
.966 .33407 Mdot
.966 .33519 Mdot
.966 .33588 Mdot
.966 .33602 Mdot
.966 .33607 Mdot
.966 .33632 Mdot
.966 .33696 Mdot
.966 .33753 Mdot
.966 .33772 Mdot
.966 .33791 Mdot
.966 .33888 Mdot
.966 .33897 Mdot
.966 .33983 Mdot
.966 .33991 Mdot
.966 .33993 Mdot
.966 .3408 Mdot
.966 .34139 Mdot
.966 .3415 Mdot
.966 .34166 Mdot
.966 .34174 Mdot
.966 .34205 Mdot
.966 .34264 Mdot
.966 .34309 Mdot
.966 .3433 Mdot
.966 .34375 Mdot
.966 .34441 Mdot
.966 .34485 Mdot
.966 .34559 Mdot
.966 .34671 Mdot
.966 .34728 Mdot
.966 .34752 Mdot
.966 .34772 Mdot
.966 .34841 Mdot
.966 .34871 Mdot
.966 .34937 Mdot
.966 .34948 Mdot
.966 .35022 Mdot
.966 .35041 Mdot
.966 .35072 Mdot
.966 .35092 Mdot
.966 .35127 Mdot
.966 .35137 Mdot
.966 .3528 Mdot
.966 .35357 Mdot
.966 .35358 Mdot
.966 .35386 Mdot
.966 .35509 Mdot
.966 .35559 Mdot
.966 .35571 Mdot
.966 .35607 Mdot
.966 .35631 Mdot
.966 .35649 Mdot
.966 .35715 Mdot
.966 .35793 Mdot
.966 .35842 Mdot
.966 .36041 Mdot
.966 .36065 Mdot
.966 .36073 Mdot
.966 .36095 Mdot
.966 .36113 Mdot
.966 .36192 Mdot
.966 .36235 Mdot
.966 .36376 Mdot
.966 .36378 Mdot
.966 .36382 Mdot
.966 .36484 Mdot
.966 .36494 Mdot
.966 .3666 Mdot
.966 .36661 Mdot
.966 .36676 Mdot
.966 .36876 Mdot
.966 .36879 Mdot
.966 .36919 Mdot
.966 .36958 Mdot
.966 .37 Mdot
.966 .37007 Mdot
.966 .37015 Mdot
.966 .37051 Mdot
.966 .37084 Mdot
.966 .37088 Mdot
.966 .37095 Mdot
.966 .37105 Mdot
.966 .37173 Mdot
.966 .37238 Mdot
.966 .37276 Mdot
.966 .37395 Mdot
.966 .37572 Mdot
.966 .37646 Mdot
.966 .37666 Mdot
.966 .37674 Mdot
.966 .37734 Mdot
.966 .37746 Mdot
.966 .38033 Mdot
.966 .38039 Mdot
.966 .38055 Mdot
.966 .38155 Mdot
.966 .38181 Mdot
.966 .38185 Mdot
.966 .38233 Mdot
.966 .38262 Mdot
.966 .38263 Mdot
.966 .38264 Mdot
.966 .3829 Mdot
.966 .3832 Mdot
.966 .38487 Mdot
.966 .38539 Mdot
.966 .38541 Mdot
.966 .38547 Mdot
.966 .38616 Mdot
.966 .38642 Mdot
.966 .38668 Mdot
.966 .38683 Mdot
.966 .38686 Mdot
.966 .38701 Mdot
.966 .38764 Mdot
.966 .38776 Mdot
.966 .38796 Mdot
.966 .38933 Mdot
.966 .38938 Mdot
.966 .38989 Mdot
.966 .3901 Mdot
.966 .39106 Mdot
.966 .39207 Mdot
.966 .39212 Mdot
.966 .39233 Mdot
.966 .39284 Mdot
.966 .39311 Mdot
.966 .39363 Mdot
.966 .39439 Mdot
.966 .39454 Mdot
.966 .39472 Mdot
.966 .39478 Mdot
.966 .39496 Mdot
.966 .39556 Mdot
.966 .39628 Mdot
.966 .3963 Mdot
.966 .39728 Mdot
.966 .39732 Mdot
.966 .39759 Mdot
.966 .39848 Mdot
.966 .39862 Mdot
.966 .39864 Mdot
.966 .39902 Mdot
.966 .39983 Mdot
.966 .40042 Mdot
.966 .40083 Mdot
.966 .40114 Mdot
.966 .40134 Mdot
.966 .40276 Mdot
.966 .40467 Mdot
.966 .40483 Mdot
.966 .40534 Mdot
.966 .40576 Mdot
.966 .40596 Mdot
.966 .40604 Mdot
.966 .40664 Mdot
.966 .40666 Mdot
.966 .40756 Mdot
.966 .40786 Mdot
.966 .40796 Mdot
.966 .40808 Mdot
.966 .40855 Mdot
.966 .40922 Mdot
.966 .40933 Mdot
.966 .40936 Mdot
.966 .41049 Mdot
.966 .41078 Mdot
.966 .41165 Mdot
.966 .41198 Mdot
.966 .41206 Mdot
.966 .41242 Mdot
.966 .41277 Mdot
.966 .41282 Mdot
.966 .41308 Mdot
.966 .41425 Mdot
.966 .41425 Mdot
.966 .41481 Mdot
.966 .41532 Mdot
.966 .4154 Mdot
.966 .41692 Mdot
.966 .4173 Mdot
.966 .41734 Mdot
.966 .41874 Mdot
.966 .41955 Mdot
.966 .41988 Mdot
.966 .42024 Mdot
.966 .42035 Mdot
.966 .42052 Mdot
.966 .42071 Mdot
.966 .421 Mdot
.966 .42142 Mdot
.966 .42246 Mdot
.966 .42345 Mdot
.966 .42398 Mdot
.966 .424 Mdot
.966 .42497 Mdot
.966 .42538 Mdot
.966 .42547 Mdot
.966 .42575 Mdot
.966 .42678 Mdot
.966 .42703 Mdot
.966 .42743 Mdot
.966 .42799 Mdot
.966 .42824 Mdot
.966 .42914 Mdot
.966 .42929 Mdot
.966 .42969 Mdot
.966 .43066 Mdot
.966 .43076 Mdot
.966 .43102 Mdot
.966 .43146 Mdot
.966 .4318 Mdot
.966 .43342 Mdot
.966 .4338 Mdot
.966 .43403 Mdot
.966 .43525 Mdot
.966 .43554 Mdot
.966 .43559 Mdot
.966 .43589 Mdot
.966 .4364 Mdot
.966 .43689 Mdot
.966 .43739 Mdot
.966 .43749 Mdot
.966 .43759 Mdot
.966 .43788 Mdot
.966 .43822 Mdot
.966 .43835 Mdot
.966 .43837 Mdot
.966 .43938 Mdot
.966 .44095 Mdot
.966 .44233 Mdot
.966 .44261 Mdot
.966 .44319 Mdot
.966 .44369 Mdot
.966 .44371 Mdot
.966 .44373 Mdot
.966 .4443 Mdot
.966 .44522 Mdot
.966 .44529 Mdot
.966 .44581 Mdot
.966 .44765 Mdot
.966 .44774 Mdot
.966 .44803 Mdot
.966 .44816 Mdot
.966 .44942 Mdot
.966 .45022 Mdot
.966 .45144 Mdot
.966 .4526 Mdot
.966 .45308 Mdot
.966 .4537 Mdot
.966 .45393 Mdot
.966 .45398 Mdot
.966 .4543 Mdot
.966 .4551 Mdot
.966 .45525 Mdot
.966 .45531 Mdot
.966 .45538 Mdot
.966 .45564 Mdot
.966 .45621 Mdot
.966 .45674 Mdot
.966 .45704 Mdot
.966 .45707 Mdot
.966 .45765 Mdot
.966 .45921 Mdot
.966 .46048 Mdot
.966 .46049 Mdot
.966 .46277 Mdot
.966 .46334 Mdot
.966 .46351 Mdot
.966 .46433 Mdot
.966 .46476 Mdot
.966 .46477 Mdot
.966 .46608 Mdot
.966 .46619 Mdot
.966 .46628 Mdot
.966 .46642 Mdot
.966 .46648 Mdot
.966 .46671 Mdot
.966 .46712 Mdot
.966 .46714 Mdot
.966 .46783 Mdot
.966 .46798 Mdot
.966 .46799 Mdot
.966 .46811 Mdot
.966 .46892 Mdot
.966 .46908 Mdot
.966 .4693 Mdot
.966 .46938 Mdot
.966 .46967 Mdot
.966 .47009 Mdot
.966 .47024 Mdot
.966 .47045 Mdot
.966 .47051 Mdot
.966 .47213 Mdot
.966 .47401 Mdot
.966 .47437 Mdot
.966 .47466 Mdot
.966 .47469 Mdot
.966 .47475 Mdot
.966 .47517 Mdot
.966 .47788 Mdot
.966 .47809 Mdot
.966 .47815 Mdot
.966 .47945 Mdot
.966 .47959 Mdot
.966 .47988 Mdot
.966 .48006 Mdot
.966 .48013 Mdot
.966 .48017 Mdot
.966 .48052 Mdot
.966 .48163 Mdot
.966 .48213 Mdot
.966 .48289 Mdot
.966 .48347 Mdot
.966 .48372 Mdot
.966 .48525 Mdot
.966 .48559 Mdot
.966 .48601 Mdot
.966 .48617 Mdot
.966 .4864 Mdot
.966 .48664 Mdot
.966 .48699 Mdot
.966 .48724 Mdot
.966 .488 Mdot
.966 .49049 Mdot
.966 .49131 Mdot
.966 .49139 Mdot
.966 .49144 Mdot
.966 .49294 Mdot
.966 .49389 Mdot
.966 .49421 Mdot
.966 .49456 Mdot
.966 .49503 Mdot
.966 .49572 Mdot
.966 .49596 Mdot
.966 .49692 Mdot
.966 .49813 Mdot
.966 .49899 Mdot
.966 .49929 Mdot
.966 .49967 Mdot
.966 .49968 Mdot
.966 .49984 Mdot
.966 .49986 Mdot
.966 .49991 Mdot
.966 .50002 Mdot
.966 .50021 Mdot
.966 .5011 Mdot
.966 .50134 Mdot
.966 .50245 Mdot
.966 .50296 Mdot
.966 .5033 Mdot
.966 .50411 Mdot
.966 .5043 Mdot
.966 .50498 Mdot
.966 .50537 Mdot
.966 .50596 Mdot
.966 .50633 Mdot
.966 .50776 Mdot
.966 .50796 Mdot
.966 .50924 Mdot
.966 .50948 Mdot
.966 .50982 Mdot
.966 .51117 Mdot
.966 .51154 Mdot
.966 .512 Mdot
.966 .51311 Mdot
.966 .51316 Mdot
.966 .51451 Mdot
.966 .51528 Mdot
.966 .51552 Mdot
.966 .51558 Mdot
.966 .51573 Mdot
.966 .51653 Mdot
.966 .5167 Mdot
.966 .51709 Mdot
.966 .51756 Mdot
.966 .51864 Mdot
.966 .51882 Mdot
.966 .51969 Mdot
.966 .51972 Mdot
.966 .52003 Mdot
.966 .52011 Mdot
.966 .5203 Mdot
.966 .52084 Mdot
.966 .52097 Mdot
.966 .52146 Mdot
.966 .52158 Mdot
.966 .52211 Mdot
.966 .52272 Mdot
.966 .52287 Mdot
.966 .52318 Mdot
.966 .52339 Mdot
.966 .52418 Mdot
.966 .52448 Mdot
.966 .52452 Mdot
.966 .52493 Mdot
.966 .52495 Mdot
.966 .52553 Mdot
.966 .5261 Mdot
.966 .5262 Mdot
.966 .52626 Mdot
.966 .5264 Mdot
.966 .52807 Mdot
.966 .52811 Mdot
.966 .52817 Mdot
.966 .52825 Mdot
.966 .5297 Mdot
.966 .53011 Mdot
.966 .53025 Mdot
.966 .53048 Mdot
.966 .53055 Mdot
.966 .53079 Mdot
.966 .53084 Mdot
.966 .53129 Mdot
.966 .53163 Mdot
.966 .53194 Mdot
.966 .53203 Mdot
.966 .53319 Mdot
.966 .53367 Mdot
.966 .53377 Mdot
.966 .53403 Mdot
.966 .53537 Mdot
.966 .53693 Mdot
.966 .53697 Mdot
.966 .53743 Mdot
.966 .53752 Mdot
.966 .53858 Mdot
.966 .53859 Mdot
.966 .53927 Mdot
.966 .54083 Mdot
.966 .54088 Mdot
.966 .54151 Mdot
.966 .54163 Mdot
.966 .54167 Mdot
.966 .54182 Mdot
.966 .54227 Mdot
.966 .54233 Mdot
.966 .54338 Mdot
.966 .54396 Mdot
.966 .54412 Mdot
.966 .5444 Mdot
.966 .54464 Mdot
.966 .54605 Mdot
.966 .54689 Mdot
.966 .54721 Mdot
.966 .54754 Mdot
.966 .54854 Mdot
.966 .54928 Mdot
.966 .54959 Mdot
.966 .54976 Mdot
.966 .54995 Mdot
.966 .55087 Mdot
.966 .55144 Mdot
.966 .55177 Mdot
.966 .55249 Mdot
.966 .55292 Mdot
.966 .55295 Mdot
.966 .55313 Mdot
.966 .55362 Mdot
.966 .5537 Mdot
.966 .55377 Mdot
.966 .55398 Mdot
.966 .55439 Mdot
.966 .55503 Mdot
.966 .55529 Mdot
.966 .55541 Mdot
.966 .55588 Mdot
.966 .5567 Mdot
.966 .55769 Mdot
.966 .55799 Mdot
.966 .5585 Mdot
.966 .55911 Mdot
.966 .55933 Mdot
.966 .55958 Mdot
.966 .56151 Mdot
.966 .56346 Mdot
.966 .56352 Mdot
.966 .5646 Mdot
.966 .56568 Mdot
.966 .56578 Mdot
.966 .5659 Mdot
.966 .56648 Mdot
.966 .56681 Mdot
.966 .56691 Mdot
.966 .56692 Mdot
.966 .56716 Mdot
.966 .5683 Mdot
.966 .56839 Mdot
.966 .56873 Mdot
.966 .5689 Mdot
.966 .56983 Mdot
.966 .57029 Mdot
.966 .57103 Mdot
.966 .57199 Mdot
.966 .57224 Mdot
.966 .57248 Mdot
.966 .57305 Mdot
.966 .57313 Mdot
.966 .57399 Mdot
.966 .57501 Mdot
.966 .576 Mdot
.966 .57619 Mdot
.966 .57646 Mdot
.966 .5772 Mdot
.966 .5774 Mdot
.966 .57754 Mdot
.966 .57798 Mdot
.966 .57827 Mdot
.966 .57924 Mdot
.966 .57942 Mdot
.966 .57954 Mdot
.966 .5802 Mdot
.966 .58025 Mdot
.966 .58058 Mdot
.966 .58065 Mdot
.966 .58114 Mdot
.966 .5814 Mdot
.966 .58237 Mdot
.966 .58254 Mdot
.966 .58377 Mdot
.968 .05226 Mdot
.968 .05233 Mdot
.968 .05288 Mdot
.968 .05366 Mdot
.968 .05401 Mdot
.968 .05411 Mdot
.968 .05422 Mdot
.968 .05541 Mdot
.968 .05623 Mdot
.968 .05727 Mdot
.968 .05884 Mdot
.968 .05949 Mdot
.968 .06069 Mdot
.968 .06172 Mdot
.968 .06267 Mdot
.968 .06387 Mdot
.968 .06528 Mdot
.968 .06561 Mdot
.968 .06789 Mdot
.968 .06938 Mdot
.968 .06969 Mdot
.968 .07027 Mdot
.968 .07095 Mdot
.968 .07186 Mdot
.968 .07359 Mdot
.968 .07457 Mdot
.968 .07468 Mdot
.968 .07478 Mdot
.968 .07603 Mdot
.968 .07837 Mdot
.968 .07955 Mdot
.968 .07956 Mdot
.968 .07986 Mdot
.968 .08031 Mdot
.968 .08142 Mdot
.968 .0817 Mdot
.968 .08177 Mdot
.968 .08178 Mdot
.968 .08244 Mdot
.968 .08302 Mdot
.968 .08303 Mdot
.968 .08515 Mdot
.968 .08516 Mdot
.968 .08556 Mdot
.968 .08558 Mdot
.968 .0874 Mdot
.968 .08743 Mdot
.968 .08754 Mdot
.968 .08815 Mdot
.968 .0886 Mdot
.968 .08945 Mdot
.968 .09011 Mdot
.968 .09026 Mdot
.968 .09026 Mdot
.968 .09032 Mdot
.968 .09079 Mdot
.968 .09098 Mdot
.968 .0912 Mdot
.968 .09288 Mdot
.968 .09349 Mdot
.968 .09363 Mdot
.968 .09471 Mdot
.968 .09488 Mdot
.968 .09508 Mdot
.968 .09556 Mdot
.968 .09559 Mdot
.968 .0971 Mdot
.968 .09768 Mdot
.968 .09773 Mdot
.968 .09957 Mdot
.968 .10014 Mdot
.968 .1014 Mdot
.968 .10306 Mdot
.968 .10372 Mdot
.968 .10386 Mdot
.968 .10463 Mdot
.968 .10571 Mdot
.968 .10696 Mdot
.968 .10746 Mdot
.968 .10756 Mdot
.968 .10876 Mdot
.968 .10949 Mdot
.968 .10987 Mdot
.968 .11109 Mdot
.968 .11184 Mdot
.968 .11262 Mdot
.968 .11309 Mdot
.968 .11325 Mdot
.968 .11445 Mdot
.968 .1154 Mdot
.968 .11675 Mdot
.968 .11767 Mdot
.968 .11769 Mdot
.968 .11844 Mdot
.968 .11877 Mdot
.968 .11897 Mdot
.968 .12054 Mdot
.968 .12114 Mdot
.968 .12224 Mdot
.968 .12228 Mdot
.968 .12328 Mdot
.968 .12359 Mdot
.968 .12465 Mdot
.968 .12525 Mdot
.968 .12536 Mdot
.968 .12592 Mdot
.968 .12612 Mdot
.968 .12618 Mdot
.968 .12673 Mdot
.968 .1268 Mdot
.968 .12711 Mdot
.968 .12738 Mdot
.968 .12869 Mdot
.968 .12886 Mdot
.968 .13043 Mdot
.968 .1306 Mdot
.968 .1308 Mdot
.968 .131 Mdot
.968 .1328 Mdot
.968 .13317 Mdot
.968 .13343 Mdot
.968 .13374 Mdot
.968 .13379 Mdot
.968 .13453 Mdot
.968 .13459 Mdot
.968 .135 Mdot
.968 .13535 Mdot
.968 .13574 Mdot
.968 .1361 Mdot
.968 .13769 Mdot
.968 .13796 Mdot
.968 .14023 Mdot
.968 .14026 Mdot
.968 .14083 Mdot
.968 .14171 Mdot
.968 .14248 Mdot
.968 .14385 Mdot
.968 .14435 Mdot
.968 .14439 Mdot
.968 .14453 Mdot
.968 .14455 Mdot
.968 .14462 Mdot
.968 .14572 Mdot
.968 .14574 Mdot
.968 .14583 Mdot
.968 .14604 Mdot
.968 .14695 Mdot
.968 .14698 Mdot
.968 .14744 Mdot
.968 .14819 Mdot
.968 .15065 Mdot
.968 .15107 Mdot
.968 .1511 Mdot
.968 .15186 Mdot
.968 .15191 Mdot
.968 .15339 Mdot
.968 .15406 Mdot
.968 .15544 Mdot
.968 .15549 Mdot
.968 .15571 Mdot
.968 .15679 Mdot
.968 .15689 Mdot
.968 .15775 Mdot
.968 .15806 Mdot
.968 .15934 Mdot
.968 .15941 Mdot
.968 .15983 Mdot
.968 .16068 Mdot
.968 .16097 Mdot
.968 .16098 Mdot
.968 .16107 Mdot
.968 .16109 Mdot
.968 .16135 Mdot
.968 .16171 Mdot
.968 .162 Mdot
.968 .16235 Mdot
.968 .16236 Mdot
.968 .16279 Mdot
.968 .16289 Mdot
.968 .16335 Mdot
.968 .16401 Mdot
.968 .16437 Mdot
.968 .16604 Mdot
.968 .16722 Mdot
.968 .16723 Mdot
.968 .16741 Mdot
.968 .16746 Mdot
.968 .16749 Mdot
.968 .16962 Mdot
.968 .16992 Mdot
.968 .17031 Mdot
.968 .1705 Mdot
.968 .17124 Mdot
.968 .17129 Mdot
.968 .17146 Mdot
.968 .17374 Mdot
.968 .17422 Mdot
.968 .17533 Mdot
.968 .17543 Mdot
.968 .1772 Mdot
.968 .17799 Mdot
.968 .17832 Mdot
.968 .17899 Mdot
.968 .17965 Mdot
.968 .1801 Mdot
.968 .18014 Mdot
.968 .18253 Mdot
.968 .18267 Mdot
.968 .18576 Mdot
.968 .18582 Mdot
.968 .18677 Mdot
.968 .18703 Mdot
.968 .18725 Mdot
.968 .18731 Mdot
.968 .18833 Mdot
.968 .18879 Mdot
.968 .18985 Mdot
.968 .18997 Mdot
.968 .19058 Mdot
.968 .19088 Mdot
.968 .19331 Mdot
.968 .19382 Mdot
.968 .19411 Mdot
.968 .19427 Mdot
.968 .19445 Mdot
.968 .19503 Mdot
.968 .19601 Mdot
.968 .19602 Mdot
.968 .19648 Mdot
.968 .19676 Mdot
.968 .19679 Mdot
.968 .19712 Mdot
.968 .19736 Mdot
.968 .1976 Mdot
.968 .19804 Mdot
.968 .19819 Mdot
.968 .19894 Mdot
.968 .20129 Mdot
.968 .20208 Mdot
.968 .20276 Mdot
.968 .20292 Mdot
.968 .203 Mdot
.968 .20394 Mdot
.968 .20425 Mdot
.968 .20481 Mdot
.968 .20517 Mdot
.968 .20545 Mdot
.968 .20549 Mdot
.968 .20549 Mdot
.968 .20613 Mdot
.968 .20626 Mdot
.968 .2078 Mdot
.968 .20879 Mdot
.968 .20964 Mdot
.968 .21191 Mdot
.968 .21225 Mdot
.968 .21285 Mdot
.968 .21403 Mdot
.968 .21407 Mdot
.968 .21423 Mdot
.968 .21473 Mdot
.968 .21494 Mdot
.968 .21553 Mdot
.968 .21593 Mdot
.968 .21617 Mdot
.968 .21624 Mdot
.968 .21649 Mdot
.968 .21656 Mdot
.968 .2169 Mdot
.968 .21735 Mdot
.968 .21739 Mdot
.968 .21746 Mdot
.968 .2196 Mdot
.968 .21985 Mdot
.968 .22021 Mdot
.968 .22029 Mdot
.968 .2204 Mdot
.968 .22076 Mdot
.968 .22079 Mdot
.968 .22181 Mdot
.968 .22289 Mdot
.968 .22295 Mdot
.968 .22393 Mdot
.968 .22491 Mdot
.968 .225 Mdot
.968 .22551 Mdot
.968 .22755 Mdot
.968 .22787 Mdot
.968 .22871 Mdot
.968 .22892 Mdot
.968 .22982 Mdot
.968 .23001 Mdot
.968 .23039 Mdot
.968 .23051 Mdot
.968 .23157 Mdot
.968 .2317 Mdot
.968 .23219 Mdot
.968 .23232 Mdot
.968 .2328 Mdot
.968 .23284 Mdot
.968 .23305 Mdot
.968 .23537 Mdot
.968 .23537 Mdot
.968 .23569 Mdot
.968 .2366 Mdot
.968 .23797 Mdot
.968 .23797 Mdot
.968 .23873 Mdot
.968 .23907 Mdot
.968 .23946 Mdot
.968 .23975 Mdot
.968 .23985 Mdot
.968 .24 Mdot
.968 .24156 Mdot
.968 .24177 Mdot
.968 .24241 Mdot
.968 .24316 Mdot
.968 .24332 Mdot
.968 .24405 Mdot
.968 .24454 Mdot
.968 .24515 Mdot
.968 .24524 Mdot
.968 .24531 Mdot
.968 .24555 Mdot
.968 .24587 Mdot
.968 .24608 Mdot
.968 .24668 Mdot
.968 .24678 Mdot
.968 .24737 Mdot
.968 .24759 Mdot
.968 .24826 Mdot
.968 .24856 Mdot
.968 .24901 Mdot
.968 .24971 Mdot
.968 .24989 Mdot
.968 .25279 Mdot
.968 .25332 Mdot
.968 .25404 Mdot
.968 .25772 Mdot
.968 .25777 Mdot
.968 .2585 Mdot
.968 .25887 Mdot
.968 .25988 Mdot
.968 .26058 Mdot
.968 .26119 Mdot
.968 .26126 Mdot
.968 .26206 Mdot
.968 .26258 Mdot
.968 .26457 Mdot
.968 .26462 Mdot
.968 .26472 Mdot
.968 .26537 Mdot
.968 .26568 Mdot
.968 .26576 Mdot
.968 .26603 Mdot
.968 .26608 Mdot
.968 .26622 Mdot
.968 .26659 Mdot
.968 .26683 Mdot
.968 .26834 Mdot
.968 .26838 Mdot
.968 .26855 Mdot
.968 .26896 Mdot
.968 .26924 Mdot
.968 .27072 Mdot
.968 .27078 Mdot
.968 .27095 Mdot
.968 .27166 Mdot
.968 .27253 Mdot
.968 .27272 Mdot
.968 .27313 Mdot
.968 .2738 Mdot
.968 .27544 Mdot
.968 .27589 Mdot
.968 .2761 Mdot
.968 .27702 Mdot
.968 .27789 Mdot
.968 .2787 Mdot
.968 .27871 Mdot
.968 .27876 Mdot
.968 .28023 Mdot
.968 .28033 Mdot
.968 .2804 Mdot
.968 .28154 Mdot
.968 .28245 Mdot
.968 .28318 Mdot
.968 .28404 Mdot
.968 .2845 Mdot
.968 .28486 Mdot
.968 .28706 Mdot
.968 .28716 Mdot
.968 .28726 Mdot
.968 .28747 Mdot
.968 .28748 Mdot
.968 .28768 Mdot
.968 .28769 Mdot
.968 .28971 Mdot
.968 .28978 Mdot
.968 .28996 Mdot
.968 .29048 Mdot
.968 .29163 Mdot
.968 .29168 Mdot
.968 .29223 Mdot
.968 .29259 Mdot
.968 .29284 Mdot
.968 .2932 Mdot
.968 .2947 Mdot
.968 .29484 Mdot
.968 .29546 Mdot
.968 .29566 Mdot
.968 .2973 Mdot
.968 .29731 Mdot
.968 .29787 Mdot
.968 .29788 Mdot
.968 .29806 Mdot
.968 .2981 Mdot
.968 .29859 Mdot
.968 .29929 Mdot
.968 .29951 Mdot
.968 .29986 Mdot
.968 .30005 Mdot
.968 .30054 Mdot
.968 .30055 Mdot
.968 .30065 Mdot
.968 .30122 Mdot
.968 .30138 Mdot
.968 .30156 Mdot
.968 .30158 Mdot
.968 .30195 Mdot
.968 .30215 Mdot
.968 .30246 Mdot
.968 .30348 Mdot
.968 .30374 Mdot
.968 .30444 Mdot
.968 .30526 Mdot
.968 .30587 Mdot
.968 .30665 Mdot
.968 .30768 Mdot
.968 .30859 Mdot
.968 .30894 Mdot
.968 .30996 Mdot
.968 .30998 Mdot
.968 .31013 Mdot
.968 .31034 Mdot
.968 .31043 Mdot
.968 .31049 Mdot
.968 .31102 Mdot
.968 .3113 Mdot
.968 .31189 Mdot
.968 .31221 Mdot
.968 .31248 Mdot
.968 .31306 Mdot
.968 .31344 Mdot
.968 .31453 Mdot
.968 .31461 Mdot
.968 .31477 Mdot
.968 .31519 Mdot
.968 .31594 Mdot
.968 .31597 Mdot
.968 .31631 Mdot
.968 .31725 Mdot
.968 .31732 Mdot
.968 .31774 Mdot
.968 .31784 Mdot
.968 .31817 Mdot
.968 .31874 Mdot
.968 .3201 Mdot
.968 .32012 Mdot
.968 .321 Mdot
.968 .32258 Mdot
.968 .32352 Mdot
.968 .32504 Mdot
.968 .32523 Mdot
.968 .32566 Mdot
.968 .32586 Mdot
.968 .32742 Mdot
.968 .32762 Mdot
.968 .32863 Mdot
.968 .32928 Mdot
.968 .32967 Mdot
.968 .32983 Mdot
.968 .32985 Mdot
.968 .32993 Mdot
.968 .33 Mdot
.968 .3304 Mdot
.968 .33082 Mdot
.968 .33145 Mdot
.968 .33155 Mdot
.968 .33204 Mdot
.968 .33275 Mdot
.968 .33403 Mdot
.968 .3346 Mdot
.968 .3349 Mdot
.968 .33498 Mdot
.968 .33556 Mdot
.968 .33712 Mdot
.968 .33819 Mdot
.968 .33853 Mdot
.968 .33866 Mdot
.968 .33933 Mdot
.968 .33948 Mdot
.968 .3396 Mdot
.968 .33978 Mdot
.968 .33987 Mdot
.968 .34127 Mdot
.968 .34176 Mdot
.968 .34359 Mdot
.968 .34408 Mdot
.968 .34476 Mdot
.968 .34585 Mdot
.968 .34598 Mdot
.968 .3467 Mdot
.968 .34781 Mdot
.968 .34805 Mdot
.968 .34832 Mdot
.968 .34832 Mdot
.968 .34851 Mdot
.968 .34874 Mdot
.968 .34886 Mdot
.968 .34994 Mdot
.968 .35018 Mdot
.968 .35066 Mdot
.968 .35083 Mdot
.968 .35172 Mdot
.968 .35378 Mdot
.968 .35389 Mdot
.968 .35401 Mdot
.968 .35404 Mdot
.968 .35479 Mdot
.968 .35493 Mdot
.968 .3552 Mdot
.968 .35576 Mdot
.968 .35605 Mdot
.968 .35797 Mdot
.968 .35914 Mdot
.968 .35951 Mdot
.968 .35998 Mdot
.968 .36005 Mdot
.968 .36047 Mdot
.968 .36069 Mdot
.968 .36147 Mdot
.968 .36153 Mdot
.968 .36202 Mdot
.968 .36234 Mdot
.968 .36269 Mdot
.968 .3638 Mdot
.968 .36499 Mdot
.968 .36571 Mdot
.968 .36572 Mdot
.968 .36662 Mdot
.968 .36682 Mdot
.968 .36714 Mdot
.968 .36721 Mdot
.968 .36785 Mdot
.968 .36831 Mdot
.968 .36873 Mdot
.968 .36878 Mdot
.968 .36907 Mdot
.968 .36963 Mdot
.968 .36993 Mdot
.968 .37138 Mdot
.968 .37272 Mdot
.968 .37278 Mdot
.968 .37593 Mdot
.968 .37639 Mdot
.968 .37648 Mdot
.968 .37658 Mdot
.968 .37663 Mdot
.968 .37746 Mdot
.968 .37835 Mdot
.968 .37844 Mdot
.968 .37876 Mdot
.968 .379 Mdot
.968 .37907 Mdot
.968 .37923 Mdot
.968 .37932 Mdot
.968 .38 Mdot
.968 .38068 Mdot
.968 .38106 Mdot
.968 .38166 Mdot
.968 .38274 Mdot
.968 .38338 Mdot
.968 .38343 Mdot
.968 .38397 Mdot
.968 .38405 Mdot
.968 .38406 Mdot
.968 .38417 Mdot
.968 .38448 Mdot
.968 .38461 Mdot
.968 .38529 Mdot
.968 .38555 Mdot
.968 .38596 Mdot
.968 .38625 Mdot
.968 .38637 Mdot
.968 .38667 Mdot
.968 .388 Mdot
.968 .38852 Mdot
.968 .38895 Mdot
.968 .38945 Mdot
.968 .39044 Mdot
.968 .39071 Mdot
.968 .39101 Mdot
.968 .39194 Mdot
.968 .39206 Mdot
.968 .39208 Mdot
.968 .39225 Mdot
.968 .3934 Mdot
.968 .39548 Mdot
.968 .39646 Mdot
.968 .39649 Mdot
.968 .39696 Mdot
.968 .39699 Mdot
.968 .39714 Mdot
.968 .39722 Mdot
.968 .3974 Mdot
.968 .3983 Mdot
.968 .39852 Mdot
.968 .39907 Mdot
.968 .39992 Mdot
.968 .40026 Mdot
.968 .40034 Mdot
.968 .40059 Mdot
.968 .40062 Mdot
.968 .40067 Mdot
.968 .40098 Mdot
.968 .40153 Mdot
.968 .4018 Mdot
.968 .40194 Mdot
.968 .40234 Mdot
.968 .40272 Mdot
.968 .40281 Mdot
.968 .40349 Mdot
.968 .40422 Mdot
.968 .40426 Mdot
.968 .40474 Mdot
.968 .40488 Mdot
.968 .40535 Mdot
.968 .40549 Mdot
.968 .40553 Mdot
.968 .40571 Mdot
.968 .40615 Mdot
.968 .40643 Mdot
.968 .40701 Mdot
.968 .4071 Mdot
.968 .40722 Mdot
.968 .40724 Mdot
.968 .40749 Mdot
.968 .408 Mdot
.968 .40908 Mdot
.968 .40967 Mdot
.968 .40977 Mdot
.968 .40983 Mdot
.968 .41031 Mdot
.968 .41046 Mdot
.968 .41112 Mdot
.968 .41137 Mdot
.968 .41187 Mdot
.968 .41255 Mdot
.968 .4127 Mdot
.968 .41277 Mdot
.968 .41292 Mdot
.968 .41362 Mdot
.968 .41368 Mdot
.968 .41384 Mdot
.968 .41425 Mdot
.968 .41565 Mdot
.968 .416 Mdot
.968 .41635 Mdot
.968 .41651 Mdot
.968 .4168 Mdot
.968 .41685 Mdot
.968 .41774 Mdot
.968 .41776 Mdot
.968 .41782 Mdot
.968 .41786 Mdot
.968 .41973 Mdot
.968 .41976 Mdot
.968 .42164 Mdot
.968 .42182 Mdot
.968 .4228 Mdot
.968 .42375 Mdot
.968 .42597 Mdot
.968 .4263 Mdot
.968 .42634 Mdot
.968 .42658 Mdot
.968 .42677 Mdot
.968 .42738 Mdot
.968 .42837 Mdot
.968 .42895 Mdot
.968 .42902 Mdot
.968 .42941 Mdot
.968 .42948 Mdot
.968 .43115 Mdot
.968 .4314 Mdot
.968 .43153 Mdot
.968 .43226 Mdot
.968 .43236 Mdot
.968 .4325 Mdot
.968 .4332 Mdot
.968 .4342 Mdot
.968 .43455 Mdot
.968 .4348 Mdot
.968 .43575 Mdot
.968 .436 Mdot
.968 .43677 Mdot
.968 .43693 Mdot
.968 .437 Mdot
.968 .43735 Mdot
.968 .43742 Mdot
.968 .43759 Mdot
.968 .43814 Mdot
.968 .43895 Mdot
.968 .43945 Mdot
.968 .44077 Mdot
.968 .44102 Mdot
.968 .44162 Mdot
.968 .44182 Mdot
.968 .44186 Mdot
.968 .4419 Mdot
.968 .44191 Mdot
.968 .442 Mdot
.968 .44253 Mdot
.968 .44305 Mdot
.968 .44316 Mdot
.968 .44429 Mdot
.968 .44439 Mdot
.968 .44647 Mdot
.968 .44693 Mdot
.968 .44694 Mdot
.968 .44764 Mdot
.968 .44837 Mdot
.968 .44841 Mdot
.968 .44907 Mdot
.968 .44969 Mdot
.968 .44981 Mdot
.968 .45038 Mdot
.968 .45057 Mdot
.968 .45087 Mdot
.968 .45101 Mdot
.968 .45118 Mdot
.968 .45148 Mdot
.968 .45163 Mdot
.968 .45209 Mdot
.968 .4527 Mdot
.968 .45288 Mdot
.968 .45388 Mdot
.968 .45429 Mdot
.968 .4546 Mdot
.968 .45552 Mdot
.968 .45621 Mdot
.968 .45631 Mdot
.968 .45651 Mdot
.968 .45669 Mdot
.968 .45698 Mdot
.968 .4573 Mdot
.968 .45757 Mdot
.968 .45871 Mdot
.968 .45967 Mdot
.968 .46083 Mdot
.968 .46102 Mdot
.968 .46115 Mdot
.968 .46162 Mdot
.968 .46224 Mdot
.968 .46264 Mdot
.968 .46368 Mdot
.968 .46379 Mdot
.968 .46379 Mdot
.968 .464 Mdot
.968 .46514 Mdot
.968 .46556 Mdot
.968 .46638 Mdot
.968 .46685 Mdot
.968 .46744 Mdot
.968 .46832 Mdot
.968 .46919 Mdot
.968 .46967 Mdot
.968 .46978 Mdot
.968 .47 Mdot
.968 .47085 Mdot
.968 .47141 Mdot
.968 .47151 Mdot
.968 .47232 Mdot
.968 .47321 Mdot
.968 .47445 Mdot
.968 .47458 Mdot
.968 .47521 Mdot
.968 .47559 Mdot
.968 .47562 Mdot
.968 .47665 Mdot
.968 .47733 Mdot
.968 .47736 Mdot
.968 .47804 Mdot
.968 .47876 Mdot
.968 .48106 Mdot
.968 .48321 Mdot
.968 .48389 Mdot
.968 .4845 Mdot
.968 .48517 Mdot
.968 .48528 Mdot
.968 .48544 Mdot
.968 .48557 Mdot
.968 .48668 Mdot
.968 .48707 Mdot
.968 .4874 Mdot
.968 .48751 Mdot
.968 .48831 Mdot
.968 .48844 Mdot
.968 .48936 Mdot
.968 .48936 Mdot
.968 .49007 Mdot
.968 .4907 Mdot
.968 .4919 Mdot
.968 .49203 Mdot
.968 .49235 Mdot
.968 .49357 Mdot
.968 .49458 Mdot
.968 .49606 Mdot
.968 .49661 Mdot
.968 .49771 Mdot
.968 .49823 Mdot
.968 .49844 Mdot
.968 .49849 Mdot
.968 .49853 Mdot
.968 .49872 Mdot
.968 .49995 Mdot
.968 .49999 Mdot
.968 .50001 Mdot
.968 .50024 Mdot
.968 .50046 Mdot
.968 .50058 Mdot
.968 .50075 Mdot
.968 .50126 Mdot
.968 .50137 Mdot
.968 .50162 Mdot
.968 .50234 Mdot
.968 .50282 Mdot
.968 .50443 Mdot
.968 .50574 Mdot
.968 .50581 Mdot
.968 .50613 Mdot
.968 .50616 Mdot
.968 .50649 Mdot
.968 .50694 Mdot
.968 .50742 Mdot
.968 .50747 Mdot
.968 .5079 Mdot
.968 .50999 Mdot
.968 .51021 Mdot
.968 .51034 Mdot
.968 .51046 Mdot
.968 .51065 Mdot
.968 .51079 Mdot
.968 .51103 Mdot
.968 .51103 Mdot
.968 .51154 Mdot
.968 .51202 Mdot
.968 .51216 Mdot
.968 .51384 Mdot
.968 .51415 Mdot
.968 .51422 Mdot
.968 .515 Mdot
.968 .51556 Mdot
.968 .51581 Mdot
.968 .5163 Mdot
.968 .51793 Mdot
.968 .51923 Mdot
.968 .51948 Mdot
.968 .52017 Mdot
.968 .52034 Mdot
.968 .52075 Mdot
.968 .52254 Mdot
.968 .52371 Mdot
.968 .52421 Mdot
.968 .52466 Mdot
.968 .52578 Mdot
.968 .52581 Mdot
.968 .52591 Mdot
.968 .52738 Mdot
.968 .52757 Mdot
.968 .52791 Mdot
.968 .52814 Mdot
.968 .52842 Mdot
.968 .52875 Mdot
.968 .52894 Mdot
.968 .52908 Mdot
.968 .52972 Mdot
.968 .52998 Mdot
.968 .53064 Mdot
.968 .53129 Mdot
.968 .5327 Mdot
.968 .53305 Mdot
.968 .53446 Mdot
.968 .53573 Mdot
.968 .53612 Mdot
.968 .53684 Mdot
.968 .537 Mdot
.968 .53701 Mdot
.968 .53758 Mdot
.968 .53772 Mdot
.968 .53869 Mdot
.968 .54116 Mdot
.968 .54198 Mdot
.968 .54217 Mdot
.968 .54237 Mdot
.968 .54255 Mdot
.968 .54276 Mdot
.968 .54279 Mdot
.968 .54317 Mdot
.968 .5432 Mdot
.968 .54349 Mdot
.968 .54369 Mdot
.968 .54491 Mdot
.968 .54572 Mdot
.968 .54648 Mdot
.968 .54662 Mdot
.968 .54679 Mdot
.968 .54682 Mdot
.968 .5471 Mdot
.968 .54714 Mdot
.968 .54724 Mdot
.968 .54758 Mdot
.968 .54789 Mdot
.968 .5486 Mdot
.968 .54914 Mdot
.968 .55082 Mdot
.968 .55093 Mdot
.968 .5511 Mdot
.968 .55149 Mdot
.968 .55198 Mdot
.968 .55267 Mdot
.968 .55316 Mdot
.968 .55387 Mdot
.968 .55451 Mdot
.968 .5549 Mdot
.968 .55573 Mdot
.968 .5561 Mdot
.968 .55677 Mdot
.968 .55703 Mdot
.968 .55823 Mdot
.968 .55863 Mdot
.968 .55904 Mdot
.968 .56085 Mdot
.968 .5618 Mdot
.968 .56183 Mdot
.968 .5629 Mdot
.968 .56292 Mdot
.968 .56327 Mdot
.968 .56336 Mdot
.968 .56392 Mdot
.968 .5643 Mdot
.968 .56562 Mdot
.968 .56565 Mdot
.968 .56566 Mdot
.968 .56607 Mdot
.968 .56675 Mdot
.968 .56712 Mdot
.968 .56807 Mdot
.968 .56809 Mdot
.968 .56829 Mdot
.968 .5683 Mdot
.968 .56939 Mdot
.968 .5694 Mdot
.968 .5697 Mdot
.968 .57004 Mdot
.968 .57004 Mdot
.968 .57008 Mdot
.968 .57022 Mdot
.968 .5708 Mdot
.968 .57103 Mdot
.968 .57118 Mdot
.968 .57119 Mdot
.968 .5718 Mdot
.968 .573 Mdot
.968 .57365 Mdot
.968 .57371 Mdot
.968 .57376 Mdot
.968 .57427 Mdot
.968 .57516 Mdot
.968 .57563 Mdot
.968 .57598 Mdot
.968 .57628 Mdot
.968 .57644 Mdot
.968 .57721 Mdot
.968 .57839 Mdot
.968 .57856 Mdot
.968 .57929 Mdot
.968 .57991 Mdot
.968 .5804 Mdot
.968 .58093 Mdot
.968 .58155 Mdot
.968 .58189 Mdot
.968 .5827 Mdot
.968 .58324 Mdot
.968 .58366 Mdot
.968 .58427 Mdot
.968 .58433 Mdot
.968 .58438 Mdot
.968 .58456 Mdot
.968 .58497 Mdot
.968 .58525 Mdot
.968 .58528 Mdot
.97 .05 Mdot
.97 .05111 Mdot
.97 .05125 Mdot
.97 .05161 Mdot
.97 .05474 Mdot
.97 .05504 Mdot
.97 .05793 Mdot
.97 .05914 Mdot
.97 .05931 Mdot
.97 .05936 Mdot
.97 .06115 Mdot
.97 .06214 Mdot
.97 .06214 Mdot
.97 .06379 Mdot
.97 .06458 Mdot
.97 .0647 Mdot
.97 .06541 Mdot
.97 .06567 Mdot
.97 .06739 Mdot
.97 .06799 Mdot
.97 .06934 Mdot
.97 .0707 Mdot
.97 .07078 Mdot
.97 .071 Mdot
.97 .07147 Mdot
.97 .07152 Mdot
.97 .07161 Mdot
.97 .0722 Mdot
.97 .07232 Mdot
.97 .0729 Mdot
.97 .07294 Mdot
.97 .07379 Mdot
.97 .07711 Mdot
.97 .07717 Mdot
.97 .07815 Mdot
.97 .07845 Mdot
.97 .08045 Mdot
.97 .08303 Mdot
.97 .08306 Mdot
.97 .08316 Mdot
.97 .08348 Mdot
.97 .08353 Mdot
.97 .08361 Mdot
.97 .08531 Mdot
.97 .08558 Mdot
.97 .08624 Mdot
.97 .08628 Mdot
.97 .0863 Mdot
.97 .09047 Mdot
.97 .09141 Mdot
.97 .09151 Mdot
.97 .09237 Mdot
.97 .09237 Mdot
.97 .09295 Mdot
.97 .09325 Mdot
.97 .09395 Mdot
.97 .09484 Mdot
.97 .09531 Mdot
.97 .09572 Mdot
.97 .09701 Mdot
.97 .09717 Mdot
.97 .09855 Mdot
.97 .09855 Mdot
.97 .09927 Mdot
.97 .10031 Mdot
.97 .10042 Mdot
.97 .10091 Mdot
.97 .10092 Mdot
.97 .10123 Mdot
.97 .10132 Mdot
.97 .10298 Mdot
.97 .10383 Mdot
.97 .10453 Mdot
.97 .1048 Mdot
.97 .10485 Mdot
.97 .10671 Mdot
.97 .10672 Mdot
.97 .10674 Mdot
.97 .10681 Mdot
.97 .10824 Mdot
.97 .10973 Mdot
.97 .10993 Mdot
.97 .11118 Mdot
.97 .11125 Mdot
.97 .11145 Mdot
.97 .11168 Mdot
.97 .11204 Mdot
.97 .11294 Mdot
.97 .11306 Mdot
.97 .11357 Mdot
.97 .11367 Mdot
.97 .1169 Mdot
.97 .11806 Mdot
.97 .1207 Mdot
.97 .12257 Mdot
.97 .12333 Mdot
.97 .12348 Mdot
.97 .1239 Mdot
.97 .12482 Mdot
.97 .12492 Mdot
.97 .12509 Mdot
.97 .12599 Mdot
.97 .12623 Mdot
.97 .12631 Mdot
.97 .12632 Mdot
.97 .12646 Mdot
.97 .12657 Mdot
.97 .1267 Mdot
.97 .1276 Mdot
.97 .12767 Mdot
.97 .12816 Mdot
.97 .12892 Mdot
.97 .12911 Mdot
.97 .12932 Mdot
.97 .12983 Mdot
.97 .13191 Mdot
.97 .13261 Mdot
.97 .13281 Mdot
.97 .13543 Mdot
.97 .13575 Mdot
.97 .13586 Mdot
.97 .13587 Mdot
.97 .1366 Mdot
.97 .13778 Mdot
.97 .13835 Mdot
.97 .14083 Mdot
.97 .14223 Mdot
.97 .14243 Mdot
.97 .14319 Mdot
.97 .14327 Mdot
.97 .14444 Mdot
.97 .14449 Mdot
.97 .1446 Mdot
.97 .14469 Mdot
.97 .14485 Mdot
.97 .14532 Mdot
.97 .14558 Mdot
.97 .14607 Mdot
.97 .14647 Mdot
.97 .14725 Mdot
.97 .14731 Mdot
.97 .14751 Mdot
.97 .14762 Mdot
.97 .14793 Mdot
.97 .14804 Mdot
.97 .14813 Mdot
.97 .14821 Mdot
.97 .14838 Mdot
.97 .15066 Mdot
.97 .15075 Mdot
.97 .151 Mdot
.97 .15129 Mdot
.97 .15167 Mdot
.97 .1522 Mdot
.97 .1528 Mdot
.97 .15322 Mdot
.97 .15348 Mdot
.97 .15355 Mdot
.97 .15358 Mdot
.97 .15367 Mdot
.97 .15542 Mdot
.97 .15802 Mdot
.97 .15846 Mdot
.97 .15913 Mdot
.97 .15926 Mdot
.97 .15973 Mdot
.97 .15975 Mdot
.97 .15999 Mdot
.97 .16043 Mdot
.97 .16167 Mdot
.97 .16203 Mdot
.97 .1635 Mdot
.97 .16369 Mdot
.97 .16417 Mdot
.97 .16426 Mdot
.97 .16498 Mdot
.97 .16536 Mdot
.97 .16536 Mdot
.97 .16555 Mdot
.97 .16599 Mdot
.97 .16649 Mdot
.97 .16664 Mdot
.97 .16707 Mdot
.97 .16842 Mdot
.97 .16889 Mdot
.97 .16901 Mdot
.97 .16984 Mdot
.97 .17003 Mdot
.97 .17016 Mdot
.97 .17107 Mdot
.97 .17187 Mdot
.97 .17282 Mdot
.97 .17365 Mdot
.97 .17437 Mdot
.97 .17468 Mdot
.97 .17562 Mdot
.97 .17735 Mdot
.97 .17735 Mdot
.97 .17773 Mdot
.97 .1786 Mdot
.97 .17876 Mdot
.97 .17966 Mdot
.97 .17985 Mdot
.97 .18068 Mdot
.97 .18077 Mdot
.97 .18098 Mdot
.97 .1811 Mdot
.97 .18169 Mdot
.97 .18193 Mdot
.97 .18196 Mdot
.97 .18202 Mdot
.97 .18255 Mdot
.97 .18272 Mdot
.97 .18331 Mdot
.97 .18334 Mdot
.97 .18451 Mdot
.97 .18493 Mdot
.97 .18516 Mdot
.97 .18538 Mdot
.97 .18581 Mdot
.97 .18595 Mdot
.97 .18659 Mdot
.97 .18761 Mdot
.97 .18809 Mdot
.97 .18874 Mdot
.97 .18883 Mdot
.97 .18895 Mdot
.97 .1891 Mdot
.97 .18949 Mdot
.97 .18957 Mdot
.97 .18968 Mdot
.97 .19114 Mdot
.97 .19158 Mdot
.97 .19205 Mdot
.97 .19319 Mdot
.97 .1932 Mdot
.97 .19325 Mdot
.97 .19338 Mdot
.97 .19343 Mdot
.97 .19376 Mdot
.97 .19616 Mdot
.97 .1966 Mdot
.97 .19726 Mdot
.97 .19892 Mdot
.97 .19904 Mdot
.97 .19942 Mdot
.97 .19964 Mdot
.97 .2002 Mdot
.97 .20092 Mdot
.97 .20121 Mdot
.97 .20186 Mdot
.97 .20199 Mdot
.97 .20237 Mdot
.97 .20283 Mdot
.97 .20352 Mdot
.97 .20372 Mdot
.97 .20476 Mdot
.97 .20527 Mdot
.97 .20551 Mdot
.97 .20562 Mdot
.97 .20649 Mdot
.97 .20668 Mdot
.97 .20908 Mdot
.97 .20949 Mdot
.97 .21014 Mdot
.97 .21026 Mdot
.97 .21035 Mdot
.97 .21089 Mdot
.97 .21099 Mdot
.97 .21167 Mdot
.97 .21174 Mdot
.97 .21206 Mdot
.97 .2121 Mdot
.97 .21296 Mdot
.97 .21338 Mdot
.97 .21453 Mdot
.97 .21495 Mdot
.97 .21521 Mdot
.97 .21557 Mdot
.97 .21634 Mdot
.97 .21801 Mdot
.97 .22032 Mdot
.97 .22058 Mdot
.97 .22066 Mdot
.97 .22118 Mdot
.97 .2212 Mdot
.97 .22232 Mdot
.97 .22285 Mdot
.97 .22395 Mdot
.97 .22409 Mdot
.97 .22543 Mdot
.97 .22571 Mdot
.97 .22654 Mdot
.97 .22676 Mdot
.97 .22703 Mdot
.97 .22817 Mdot
.97 .22833 Mdot
.97 .22851 Mdot
.97 .22884 Mdot
.97 .22981 Mdot
.97 .23025 Mdot
.97 .23058 Mdot
.97 .23082 Mdot
.97 .23105 Mdot
.97 .23121 Mdot
.97 .23122 Mdot
.97 .23151 Mdot
.97 .2317 Mdot
.97 .23197 Mdot
.97 .23348 Mdot
.97 .23368 Mdot
.97 .23371 Mdot
.97 .23385 Mdot
.97 .2348 Mdot
.97 .23626 Mdot
.97 .23637 Mdot
.97 .23663 Mdot
.97 .23678 Mdot
.97 .23704 Mdot
.97 .23804 Mdot
.97 .23846 Mdot
.97 .23901 Mdot
.97 .24002 Mdot
.97 .24198 Mdot
.97 .24199 Mdot
.97 .24203 Mdot
.97 .24208 Mdot
.97 .24242 Mdot
.97 .24284 Mdot
.97 .24337 Mdot
.97 .24343 Mdot
.97 .24374 Mdot
.97 .24383 Mdot
.97 .24483 Mdot
.97 .24603 Mdot
.97 .24615 Mdot
.97 .2489 Mdot
.97 .24924 Mdot
.97 .24953 Mdot
.97 .24974 Mdot
.97 .24976 Mdot
.97 .25116 Mdot
.97 .25346 Mdot
.97 .25457 Mdot
.97 .25651 Mdot
.97 .25768 Mdot
.97 .25896 Mdot
.97 .25937 Mdot
.97 .25993 Mdot
.97 .26069 Mdot
.97 .26167 Mdot
.97 .2621 Mdot
.97 .26248 Mdot
.97 .26319 Mdot
.97 .26366 Mdot
.97 .26396 Mdot
.97 .26396 Mdot
.97 .26412 Mdot
.97 .26573 Mdot
.97 .26639 Mdot
.97 .26647 Mdot
.97 .2667 Mdot
.97 .26684 Mdot
.97 .26686 Mdot
.97 .26718 Mdot
.97 .26809 Mdot
.97 .2686 Mdot
.97 .26934 Mdot
.97 .26954 Mdot
.97 .27032 Mdot
.97 .2717 Mdot
.97 .27182 Mdot
.97 .27194 Mdot
.97 .27233 Mdot
.97 .27256 Mdot
.97 .27315 Mdot
.97 .27336 Mdot
.97 .27353 Mdot
.97 .2737 Mdot
.97 .27402 Mdot
.97 .27461 Mdot
.97 .27472 Mdot
.97 .27551 Mdot
.97 .27659 Mdot
.97 .27785 Mdot
.97 .27845 Mdot
.97 .27863 Mdot
.97 .27911 Mdot
.97 .27968 Mdot
.97 .28041 Mdot
.97 .28045 Mdot
.97 .28063 Mdot
.97 .28143 Mdot
.97 .28261 Mdot
.97 .28267 Mdot
.97 .2834 Mdot
.97 .28342 Mdot
.97 .28381 Mdot
.97 .28392 Mdot
.97 .28405 Mdot
.97 .28412 Mdot
.97 .28429 Mdot
.97 .28466 Mdot
.97 .28749 Mdot
.97 .28768 Mdot
.97 .28823 Mdot
.97 .28868 Mdot
.97 .2891 Mdot
.97 .29272 Mdot
.97 .29317 Mdot
.97 .29319 Mdot
.97 .29357 Mdot
.97 .29487 Mdot
.97 .29514 Mdot
.97 .29605 Mdot
.97 .29608 Mdot
.97 .29655 Mdot
.97 .29695 Mdot
.97 .2973 Mdot
.97 .29741 Mdot
.97 .29819 Mdot
.97 .29842 Mdot
.97 .29844 Mdot
.97 .29869 Mdot
.97 .29981 Mdot
.97 .30051 Mdot
.97 .30055 Mdot
.97 .30066 Mdot
.97 .30189 Mdot
.97 .30224 Mdot
.97 .30335 Mdot
.97 .30355 Mdot
.97 .3037 Mdot
.97 .30373 Mdot
.97 .30387 Mdot
.97 .30392 Mdot
.97 .30394 Mdot
.97 .30467 Mdot
.97 .30482 Mdot
.97 .30528 Mdot
.97 .30578 Mdot
.97 .30622 Mdot
.97 .30622 Mdot
.97 .30696 Mdot
.97 .30697 Mdot
.97 .30734 Mdot
.97 .30818 Mdot
.97 .30902 Mdot
.97 .30915 Mdot
.97 .30944 Mdot
.97 .31028 Mdot
.97 .31129 Mdot
.97 .31238 Mdot
.97 .31291 Mdot
.97 .31382 Mdot
.97 .31385 Mdot
.97 .31404 Mdot
.97 .31509 Mdot
.97 .31565 Mdot
.97 .31588 Mdot
.97 .31603 Mdot
.97 .31627 Mdot
.97 .31717 Mdot
.97 .31743 Mdot
.97 .31804 Mdot
.97 .31872 Mdot
.97 .31886 Mdot
.97 .31959 Mdot
.97 .32144 Mdot
.97 .32163 Mdot
.97 .32186 Mdot
.97 .32248 Mdot
.97 .32304 Mdot
.97 .32348 Mdot
.97 .32403 Mdot
.97 .32444 Mdot
.97 .32503 Mdot
.97 .32504 Mdot
.97 .32542 Mdot
.97 .32643 Mdot
.97 .32687 Mdot
.97 .32923 Mdot
.97 .33014 Mdot
.97 .33022 Mdot
.97 .33023 Mdot
.97 .33033 Mdot
.97 .33092 Mdot
.97 .33097 Mdot
.97 .33195 Mdot
.97 .33265 Mdot
.97 .33276 Mdot
.97 .33296 Mdot
.97 .33408 Mdot
.97 .33451 Mdot
.97 .33471 Mdot
.97 .33504 Mdot
.97 .33505 Mdot
.97 .33508 Mdot
.97 .33515 Mdot
.97 .33589 Mdot
.97 .33669 Mdot
.97 .33686 Mdot
.97 .33726 Mdot
.97 .33738 Mdot
.97 .33749 Mdot
.97 .33865 Mdot
.97 .3391 Mdot
.97 .33911 Mdot
.97 .33917 Mdot
.97 .33929 Mdot
.97 .34031 Mdot
.97 .3405 Mdot
.97 .34065 Mdot
.97 .34157 Mdot
.97 .34179 Mdot
.97 .34184 Mdot
.97 .34258 Mdot
.97 .34333 Mdot
.97 .34412 Mdot
.97 .3444 Mdot
.97 .34445 Mdot
.97 .34494 Mdot
.97 .34503 Mdot
.97 .34537 Mdot
.97 .3458 Mdot
.97 .34592 Mdot
.97 .34664 Mdot
.97 .34681 Mdot
.97 .34691 Mdot
.97 .34806 Mdot
.97 .34815 Mdot
.97 .3489 Mdot
.97 .34952 Mdot
.97 .34971 Mdot
.97 .35013 Mdot
.97 .35107 Mdot
.97 .35232 Mdot
.97 .3525 Mdot
.97 .35273 Mdot
.97 .3529 Mdot
.97 .35302 Mdot
.97 .35336 Mdot
.97 .35378 Mdot
.97 .35394 Mdot
.97 .35415 Mdot
.97 .35459 Mdot
.97 .35529 Mdot
.97 .35588 Mdot
.97 .35699 Mdot
.97 .35784 Mdot
.97 .35799 Mdot
.97 .35875 Mdot
.97 .35958 Mdot
.97 .36017 Mdot
.97 .36096 Mdot
.97 .36096 Mdot
.97 .36097 Mdot
.97 .36108 Mdot
.97 .36119 Mdot
.97 .36133 Mdot
.97 .36143 Mdot
.97 .36203 Mdot
.97 .36206 Mdot
.97 .36513 Mdot
.97 .36547 Mdot
.97 .36573 Mdot
.97 .36619 Mdot
.97 .36659 Mdot
.97 .36672 Mdot
.97 .3668 Mdot
.97 .36727 Mdot
.97 .36756 Mdot
.97 .36886 Mdot
.97 .37118 Mdot
.97 .37123 Mdot
.97 .37177 Mdot
.97 .37196 Mdot
.97 .37207 Mdot
.97 .3723 Mdot
.97 .37305 Mdot
.97 .37348 Mdot
.97 .37456 Mdot
.97 .37589 Mdot
.97 .37595 Mdot
.97 .37652 Mdot
.97 .37688 Mdot
.97 .37742 Mdot
.97 .37778 Mdot
.97 .37791 Mdot
.97 .37803 Mdot
.97 .37877 Mdot
.97 .37966 Mdot
.97 .37973 Mdot
.97 .38006 Mdot
.97 .38059 Mdot
.97 .38101 Mdot
.97 .38138 Mdot
.97 .38212 Mdot
.97 .38218 Mdot
.97 .3834 Mdot
.97 .38414 Mdot
.97 .38438 Mdot
.97 .38443 Mdot
.97 .38486 Mdot
.97 .38508 Mdot
.97 .38543 Mdot
.97 .38569 Mdot
.97 .38631 Mdot
.97 .38676 Mdot
.97 .38713 Mdot
.97 .38937 Mdot
.97 .38953 Mdot
.97 .39043 Mdot
.97 .39178 Mdot
.97 .3922 Mdot
.97 .39257 Mdot
.97 .39377 Mdot
.97 .39384 Mdot
.97 .39407 Mdot
.97 .39412 Mdot
.97 .39425 Mdot
.97 .39529 Mdot
.97 .3955 Mdot
.97 .3968 Mdot
.97 .39695 Mdot
.97 .39756 Mdot
.97 .39765 Mdot
.97 .39779 Mdot
.97 .39914 Mdot
.97 .39931 Mdot
.97 .40012 Mdot
.97 .4004 Mdot
.97 .40087 Mdot
.97 .40129 Mdot
.97 .40236 Mdot
.97 .40272 Mdot
.97 .40318 Mdot
.97 .40329 Mdot
.97 .40367 Mdot
.97 .40438 Mdot
.97 .40468 Mdot
.97 .40541 Mdot
.97 .40563 Mdot
.97 .40587 Mdot
.97 .40652 Mdot
.97 .40722 Mdot
.97 .40911 Mdot
.97 .40929 Mdot
.97 .4101 Mdot
.97 .41101 Mdot
.97 .41147 Mdot
.97 .41156 Mdot
.97 .41314 Mdot
.97 .41345 Mdot
.97 .41359 Mdot
.97 .4141 Mdot
.97 .41425 Mdot
.97 .41526 Mdot
.97 .41529 Mdot
.97 .41608 Mdot
.97 .41636 Mdot
.97 .41653 Mdot
.97 .41746 Mdot
.97 .41772 Mdot
.97 .418 Mdot
.97 .4185 Mdot
.97 .42053 Mdot
.97 .42063 Mdot
.97 .42091 Mdot
.97 .42093 Mdot
.97 .42295 Mdot
.97 .42319 Mdot
.97 .4233 Mdot
.97 .42351 Mdot
.97 .42374 Mdot
.97 .42388 Mdot
.97 .42405 Mdot
.97 .42565 Mdot
.97 .42608 Mdot
.97 .4262 Mdot
.97 .42661 Mdot
.97 .42691 Mdot
.97 .42773 Mdot
.97 .42882 Mdot
.97 .42912 Mdot
.97 .42948 Mdot
.97 .43012 Mdot
.97 .43035 Mdot
.97 .432 Mdot
.97 .4321 Mdot
.97 .43242 Mdot
.97 .43285 Mdot
.97 .43349 Mdot
.97 .43395 Mdot
.97 .43441 Mdot
.97 .43471 Mdot
.97 .43474 Mdot
.97 .43529 Mdot
.97 .43567 Mdot
.97 .4362 Mdot
.97 .43675 Mdot
.97 .43747 Mdot
.97 .43836 Mdot
.97 .43913 Mdot
.97 .4395 Mdot
.97 .43955 Mdot
.97 .43956 Mdot
.97 .43984 Mdot
.97 .44006 Mdot
.97 .44074 Mdot
.97 .44115 Mdot
.97 .44169 Mdot
.97 .44199 Mdot
.97 .44209 Mdot
.97 .44256 Mdot
.97 .444 Mdot
.97 .44452 Mdot
.97 .44472 Mdot
.97 .44524 Mdot
.97 .44552 Mdot
.97 .44604 Mdot
.97 .44635 Mdot
.97 .44648 Mdot
.97 .4479 Mdot
.97 .44797 Mdot
.97 .44864 Mdot
.97 .44877 Mdot
.97 .44944 Mdot
.97 .44985 Mdot
.97 .45048 Mdot
.97 .45112 Mdot
.97 .45124 Mdot
.97 .45181 Mdot
.97 .45298 Mdot
.97 .45442 Mdot
.97 .45464 Mdot
.97 .4549 Mdot
.97 .45559 Mdot
.97 .4556 Mdot
.97 .45563 Mdot
.97 .45572 Mdot
.97 .4558 Mdot
.97 .45647 Mdot
.97 .45665 Mdot
.97 .45728 Mdot
.97 .45734 Mdot
.97 .4583 Mdot
.97 .45843 Mdot
.97 .45844 Mdot
.97 .45856 Mdot
.97 .45902 Mdot
.97 .45919 Mdot
.97 .46114 Mdot
.97 .46114 Mdot
.97 .46324 Mdot
.97 .46346 Mdot
.97 .46369 Mdot
.97 .46407 Mdot
.97 .46553 Mdot
.97 .46597 Mdot
.97 .46618 Mdot
.97 .46655 Mdot
.97 .46761 Mdot
.97 .4677 Mdot
.97 .46904 Mdot
.97 .46969 Mdot
.97 .47025 Mdot
.97 .47065 Mdot
.97 .47071 Mdot
.97 .47221 Mdot
.97 .47343 Mdot
.97 .47472 Mdot
.97 .47529 Mdot
.97 .4762 Mdot
.97 .47636 Mdot
.97 .4766 Mdot
.97 .47738 Mdot
.97 .47789 Mdot
.97 .47828 Mdot
.97 .47878 Mdot
.97 .47944 Mdot
.97 .48004 Mdot
.97 .48379 Mdot
.97 .48538 Mdot
.97 .48544 Mdot
.97 .48606 Mdot
.97 .48663 Mdot
.97 .48682 Mdot
.97 .48709 Mdot
.97 .4873 Mdot
.97 .4875 Mdot
.97 .48753 Mdot
.97 .48753 Mdot
.97 .48854 Mdot
.97 .48906 Mdot
.97 .48935 Mdot
.97 .49021 Mdot
.97 .49042 Mdot
.97 .49181 Mdot
.97 .49191 Mdot
.97 .49328 Mdot
.97 .49358 Mdot
.97 .4938 Mdot
.97 .49465 Mdot
.97 .49524 Mdot
.97 .49538 Mdot
.97 .49675 Mdot
.97 .49739 Mdot
.97 .49767 Mdot
.97 .49824 Mdot
.97 .49825 Mdot
.97 .49852 Mdot
.97 .49856 Mdot
.97 .49989 Mdot
.97 .50075 Mdot
.97 .50114 Mdot
.97 .50146 Mdot
.97 .50168 Mdot
.97 .50227 Mdot
.97 .50293 Mdot
.97 .50296 Mdot
.97 .50312 Mdot
.97 .50316 Mdot
.97 .5035 Mdot
.97 .50356 Mdot
.97 .50383 Mdot
.97 .50388 Mdot
.97 .50394 Mdot
.97 .50428 Mdot
.97 .50449 Mdot
.97 .50627 Mdot
.97 .50672 Mdot
.97 .50725 Mdot
.97 .50855 Mdot
.97 .5087 Mdot
.97 .50907 Mdot
.97 .50935 Mdot
.97 .50973 Mdot
.97 .51058 Mdot
.97 .51092 Mdot
.97 .51239 Mdot
.97 .51256 Mdot
.97 .51327 Mdot
.97 .51351 Mdot
.97 .51374 Mdot
.97 .51449 Mdot
.97 .51479 Mdot
.97 .51493 Mdot
.97 .51497 Mdot
.97 .51531 Mdot
.97 .51608 Mdot
.97 .51648 Mdot
.97 .51671 Mdot
.97 .51682 Mdot
.97 .51694 Mdot
.97 .51715 Mdot
.97 .51776 Mdot
.97 .51777 Mdot
.97 .51844 Mdot
.97 .51861 Mdot
.97 .51891 Mdot
.97 .51913 Mdot
.97 .51955 Mdot
.97 .51965 Mdot
.97 .5202 Mdot
.97 .52065 Mdot
.97 .52174 Mdot
.97 .52275 Mdot
.97 .52318 Mdot
.97 .52462 Mdot
.97 .52472 Mdot
.97 .52515 Mdot
.97 .5252 Mdot
.97 .52637 Mdot
.97 .5267 Mdot
.97 .52693 Mdot
.97 .52722 Mdot
.97 .52759 Mdot
.97 .52764 Mdot
.97 .52874 Mdot
.97 .52957 Mdot
.97 .52979 Mdot
.97 .52992 Mdot
.97 .52993 Mdot
.97 .53017 Mdot
.97 .53024 Mdot
.97 .53058 Mdot
.97 .53081 Mdot
.97 .53215 Mdot
.97 .53305 Mdot
.97 .53328 Mdot
.97 .5335 Mdot
.97 .53428 Mdot
.97 .53443 Mdot
.97 .53456 Mdot
.97 .5346 Mdot
.97 .53596 Mdot
.97 .53601 Mdot
.97 .53617 Mdot
.97 .53676 Mdot
.97 .53697 Mdot
.97 .53722 Mdot
.97 .53735 Mdot
.97 .5376 Mdot
.97 .53768 Mdot
.97 .53773 Mdot
.97 .53779 Mdot
.97 .53781 Mdot
.97 .53841 Mdot
.97 .53845 Mdot
.97 .53885 Mdot
.97 .53967 Mdot
.97 .54185 Mdot
.97 .54223 Mdot
.97 .54245 Mdot
.97 .5438 Mdot
.97 .54391 Mdot
.97 .54427 Mdot
.97 .54534 Mdot
.97 .54571 Mdot
.97 .54581 Mdot
.97 .5462 Mdot
.97 .54695 Mdot
.97 .54702 Mdot
.97 .54715 Mdot
.97 .54716 Mdot
.97 .54732 Mdot
.97 .54908 Mdot
.97 .55367 Mdot
.97 .55405 Mdot
.97 .55451 Mdot
.97 .55492 Mdot
.97 .55495 Mdot
.97 .5557 Mdot
.97 .55647 Mdot
.97 .55721 Mdot
.97 .55724 Mdot
.97 .55822 Mdot
.97 .55838 Mdot
.97 .55874 Mdot
.97 .55918 Mdot
.97 .56024 Mdot
.97 .5605 Mdot
.97 .56056 Mdot
.97 .56109 Mdot
.97 .56147 Mdot
.97 .56218 Mdot
.97 .56226 Mdot
.97 .56292 Mdot
.97 .56313 Mdot
.97 .56338 Mdot
.97 .56384 Mdot
.97 .5642 Mdot
.97 .56465 Mdot
.97 .56509 Mdot
.97 .56515 Mdot
.97 .56563 Mdot
.97 .56779 Mdot
.97 .56781 Mdot
.97 .56916 Mdot
.97 .56921 Mdot
.97 .56923 Mdot
.97 .56945 Mdot
.97 .56946 Mdot
.97 .5708 Mdot
.97 .57183 Mdot
.97 .57198 Mdot
.97 .57249 Mdot
.97 .57252 Mdot
.97 .57423 Mdot
.97 .57467 Mdot
.97 .57468 Mdot
.97 .57499 Mdot
.97 .57505 Mdot
.97 .57535 Mdot
.97 .5754 Mdot
.97 .57542 Mdot
.97 .57567 Mdot
.97 .57578 Mdot
.97 .57582 Mdot
.97 .57652 Mdot
.97 .57722 Mdot
.97 .57753 Mdot
.97 .57841 Mdot
.97 .57855 Mdot
.97 .57891 Mdot
.97 .57898 Mdot
.97 .57938 Mdot
.97 .58023 Mdot
.97 .58023 Mdot
.97 .58074 Mdot
.97 .58167 Mdot
.97 .58169 Mdot
.97 .58178 Mdot
.97 .5824 Mdot
.97 .58389 Mdot
.97 .58405 Mdot
.97 .58566 Mdot
.97 .58585 Mdot
.97 .58592 Mdot
.97 .58649 Mdot
.972 .04777 Mdot
.972 .04778 Mdot
.972 .04833 Mdot
.972 .04925 Mdot
.972 .04998 Mdot
.972 .05403 Mdot
.972 .0542 Mdot
.972 .05451 Mdot
.972 .05459 Mdot
.972 .05635 Mdot
.972 .05671 Mdot
.972 .05701 Mdot
.972 .05802 Mdot
.972 .05871 Mdot
.972 .05912 Mdot
.972 .05969 Mdot
.972 .06061 Mdot
.972 .06277 Mdot
.972 .06284 Mdot
.972 .06422 Mdot
.972 .06524 Mdot
.972 .06678 Mdot
.972 .06862 Mdot
.972 .06879 Mdot
.972 .07008 Mdot
.972 .07123 Mdot
.972 .07155 Mdot
.972 .07157 Mdot
.972 .07229 Mdot
.972 .07384 Mdot
.972 .07418 Mdot
.972 .07516 Mdot
.972 .07538 Mdot
.972 .07564 Mdot
.972 .07685 Mdot
.972 .0777 Mdot
.972 .07897 Mdot
.972 .07899 Mdot
.972 .08006 Mdot
.972 .08185 Mdot
.972 .08219 Mdot
.972 .08327 Mdot
.972 .08513 Mdot
.972 .08544 Mdot
.972 .08775 Mdot
.972 .08793 Mdot
.972 .08799 Mdot
.972 .08828 Mdot
.972 .08895 Mdot
.972 .08927 Mdot
.972 .08954 Mdot
.972 .09104 Mdot
.972 .09114 Mdot
.972 .09148 Mdot
.972 .09208 Mdot
.972 .09223 Mdot
.972 .09294 Mdot
.972 .09565 Mdot
.972 .09628 Mdot
.972 .09636 Mdot
.972 .09679 Mdot
.972 .09693 Mdot
.972 .097 Mdot
.972 .097 Mdot
.972 .0981 Mdot
.972 .09889 Mdot
.972 .09966 Mdot
.972 .09987 Mdot
.972 .10025 Mdot
.972 .10103 Mdot
.972 .10122 Mdot
.972 .10134 Mdot
.972 .10167 Mdot
.972 .10177 Mdot
.972 .10192 Mdot
.972 .10198 Mdot
.972 .10215 Mdot
.972 .10219 Mdot
.972 .10394 Mdot
.972 .10429 Mdot
.972 .10469 Mdot
.972 .1062 Mdot
.972 .10723 Mdot
.972 .10726 Mdot
.972 .10813 Mdot
.972 .10828 Mdot
.972 .1088 Mdot
.972 .10885 Mdot
.972 .10925 Mdot
.972 .1102 Mdot
.972 .11094 Mdot
.972 .11095 Mdot
.972 .11232 Mdot
.972 .11264 Mdot
.972 .11293 Mdot
.972 .11428 Mdot
.972 .11512 Mdot
.972 .11578 Mdot
.972 .11593 Mdot
.972 .11594 Mdot
.972 .11697 Mdot
.972 .11834 Mdot
.972 .11836 Mdot
.972 .11854 Mdot
.972 .11951 Mdot
.972 .11983 Mdot
.972 .11995 Mdot
.972 .12144 Mdot
.972 .12219 Mdot
.972 .12231 Mdot
.972 .12234 Mdot
.972 .12301 Mdot
.972 .12351 Mdot
.972 .12457 Mdot
.972 .12519 Mdot
.972 .12525 Mdot
.972 .12603 Mdot
.972 .12663 Mdot
.972 .12756 Mdot
.972 .12796 Mdot
.972 .12965 Mdot
.972 .13031 Mdot
.972 .13216 Mdot
.972 .13221 Mdot
.972 .13265 Mdot
.972 .13316 Mdot
.972 .1332 Mdot
.972 .13331 Mdot
.972 .13336 Mdot
.972 .13411 Mdot
.972 .13424 Mdot
.972 .13426 Mdot
.972 .1355 Mdot
.972 .13559 Mdot
.972 .13716 Mdot
.972 .13824 Mdot
.972 .13884 Mdot
.972 .13962 Mdot
.972 .13967 Mdot
.972 .14013 Mdot
.972 .14124 Mdot
.972 .14126 Mdot
.972 .14141 Mdot
.972 .14174 Mdot
.972 .14199 Mdot
.972 .1421 Mdot
.972 .14522 Mdot
.972 .14529 Mdot
.972 .14572 Mdot
.972 .14588 Mdot
.972 .14639 Mdot
.972 .14687 Mdot
.972 .14789 Mdot
.972 .14798 Mdot
.972 .14819 Mdot
.972 .14842 Mdot
.972 .1497 Mdot
.972 .15094 Mdot
.972 .1515 Mdot
.972 .15159 Mdot
.972 .15204 Mdot
.972 .15205 Mdot
.972 .15221 Mdot
.972 .15263 Mdot
.972 .1527 Mdot
.972 .1536 Mdot
.972 .15375 Mdot
.972 .15602 Mdot
.972 .15667 Mdot
.972 .15669 Mdot
.972 .15672 Mdot
.972 .15705 Mdot
.972 .15716 Mdot
.972 .15773 Mdot
.972 .15899 Mdot
.972 .15903 Mdot
.972 .15963 Mdot
.972 .15965 Mdot
.972 .16018 Mdot
.972 .16081 Mdot
.972 .16088 Mdot
.972 .16164 Mdot
.972 .16253 Mdot
.972 .16309 Mdot
.972 .16329 Mdot
.972 .16395 Mdot
.972 .16428 Mdot
.972 .16484 Mdot
.972 .16493 Mdot
.972 .16511 Mdot
.972 .16516 Mdot
.972 .1654 Mdot
.972 .16541 Mdot
.972 .16632 Mdot
.972 .16678 Mdot
.972 .16746 Mdot
.972 .16833 Mdot
.972 .16917 Mdot
.972 .16992 Mdot
.972 .17018 Mdot
.972 .17167 Mdot
.972 .17205 Mdot
.972 .17219 Mdot
.972 .17328 Mdot
.972 .17343 Mdot
.972 .17399 Mdot
.972 .17428 Mdot
.972 .17454 Mdot
.972 .17468 Mdot
.972 .17468 Mdot
.972 .17495 Mdot
.972 .17541 Mdot
.972 .17564 Mdot
.972 .17682 Mdot
.972 .17744 Mdot
.972 .17833 Mdot
.972 .17835 Mdot
.972 .17836 Mdot
.972 .17898 Mdot
.972 .1793 Mdot
.972 .17941 Mdot
.972 .17986 Mdot
.972 .18007 Mdot
.972 .18025 Mdot
.972 .18078 Mdot
.972 .18078 Mdot
.972 .18099 Mdot
.972 .18101 Mdot
.972 .18141 Mdot
.972 .18252 Mdot
.972 .18253 Mdot
.972 .18256 Mdot
.972 .18287 Mdot
.972 .18299 Mdot
.972 .18311 Mdot
.972 .18324 Mdot
.972 .18345 Mdot
.972 .18376 Mdot
.972 .18396 Mdot
.972 .18423 Mdot
.972 .18435 Mdot
.972 .18469 Mdot
.972 .18477 Mdot
.972 .18803 Mdot
.972 .18816 Mdot
.972 .18884 Mdot
.972 .18963 Mdot
.972 .19027 Mdot
.972 .19068 Mdot
.972 .19085 Mdot
.972 .19256 Mdot
.972 .19422 Mdot
.972 .19457 Mdot
.972 .19463 Mdot
.972 .19632 Mdot
.972 .1966 Mdot
.972 .1975 Mdot
.972 .19762 Mdot
.972 .19772 Mdot
.972 .19796 Mdot
.972 .19849 Mdot
.972 .19894 Mdot
.972 .19912 Mdot
.972 .19912 Mdot
.972 .20033 Mdot
.972 .20177 Mdot
.972 .20179 Mdot
.972 .20235 Mdot
.972 .20281 Mdot
.972 .20332 Mdot
.972 .20447 Mdot
.972 .20509 Mdot
.972 .20531 Mdot
.972 .20564 Mdot
.972 .2063 Mdot
.972 .20826 Mdot
.972 .2099 Mdot
.972 .21102 Mdot
.972 .21118 Mdot
.972 .21128 Mdot
.972 .2113 Mdot
.972 .21147 Mdot
.972 .21149 Mdot
.972 .21351 Mdot
.972 .21411 Mdot
.972 .21486 Mdot
.972 .21616 Mdot
.972 .21617 Mdot
.972 .21621 Mdot
.972 .21654 Mdot
.972 .21712 Mdot
.972 .21845 Mdot
.972 .21906 Mdot
.972 .21928 Mdot
.972 .22176 Mdot
.972 .22218 Mdot
.972 .22364 Mdot
.972 .22388 Mdot
.972 .22395 Mdot
.972 .22425 Mdot
.972 .22478 Mdot
.972 .22524 Mdot
.972 .22572 Mdot
.972 .22604 Mdot
.972 .22621 Mdot
.972 .22646 Mdot
.972 .22657 Mdot
.972 .22697 Mdot
.972 .22828 Mdot
.972 .22837 Mdot
.972 .22949 Mdot
.972 .22959 Mdot
.972 .23086 Mdot
.972 .23112 Mdot
.972 .23191 Mdot
.972 .2321 Mdot
.972 .23229 Mdot
.972 .23408 Mdot
.972 .23485 Mdot
.972 .23486 Mdot
.972 .2357 Mdot
.972 .2358 Mdot
.972 .23609 Mdot
.972 .23628 Mdot
.972 .23816 Mdot
.972 .23861 Mdot
.972 .23943 Mdot
.972 .2402 Mdot
.972 .24064 Mdot
.972 .24203 Mdot
.972 .24214 Mdot
.972 .2423 Mdot
.972 .24302 Mdot
.972 .24313 Mdot
.972 .2436 Mdot
.972 .24395 Mdot
.972 .24399 Mdot
.972 .24497 Mdot
.972 .24505 Mdot
.972 .24526 Mdot
.972 .24536 Mdot
.972 .24582 Mdot
.972 .24635 Mdot
.972 .24681 Mdot
.972 .24706 Mdot
.972 .24711 Mdot
.972 .24812 Mdot
.972 .24952 Mdot
.972 .24967 Mdot
.972 .2497 Mdot
.972 .2508 Mdot
.972 .25272 Mdot
.972 .25275 Mdot
.972 .25337 Mdot
.972 .25381 Mdot
.972 .25411 Mdot
.972 .25485 Mdot
.972 .25602 Mdot
.972 .2569 Mdot
.972 .25754 Mdot
.972 .25763 Mdot
.972 .25804 Mdot
.972 .25853 Mdot
.972 .25957 Mdot
.972 .25969 Mdot
.972 .25972 Mdot
.972 .26067 Mdot
.972 .26072 Mdot
.972 .261 Mdot
.972 .26166 Mdot
.972 .26203 Mdot
.972 .26214 Mdot
.972 .26216 Mdot
.972 .26236 Mdot
.972 .26618 Mdot
.972 .26625 Mdot
.972 .26829 Mdot
.972 .26842 Mdot
.972 .26854 Mdot
.972 .2694 Mdot
.972 .2694 Mdot
.972 .2697 Mdot
.972 .2707 Mdot
.972 .27163 Mdot
.972 .27355 Mdot
.972 .2736 Mdot
.972 .27367 Mdot
.972 .27378 Mdot
.972 .27379 Mdot
.972 .27419 Mdot
.972 .27425 Mdot
.972 .27464 Mdot
.972 .27489 Mdot
.972 .27579 Mdot
.972 .27652 Mdot
.972 .27713 Mdot
.972 .27808 Mdot
.972 .27832 Mdot
.972 .27908 Mdot
.972 .27952 Mdot
.972 .27954 Mdot
.972 .28063 Mdot
.972 .2808 Mdot
.972 .28168 Mdot
.972 .2817 Mdot
.972 .282 Mdot
.972 .28215 Mdot
.972 .28248 Mdot
.972 .28281 Mdot
.972 .28296 Mdot
.972 .28335 Mdot
.972 .28353 Mdot
.972 .28449 Mdot
.972 .28471 Mdot
.972 .28501 Mdot
.972 .28551 Mdot
.972 .28621 Mdot
.972 .28681 Mdot
.972 .28684 Mdot
.972 .28823 Mdot
.972 .28941 Mdot
.972 .28995 Mdot
.972 .29035 Mdot
.972 .29068 Mdot
.972 .29072 Mdot
.972 .29077 Mdot
.972 .29077 Mdot
.972 .29113 Mdot
.972 .29141 Mdot
.972 .29145 Mdot
.972 .29163 Mdot
.972 .29273 Mdot
.972 .2951 Mdot
.972 .29516 Mdot
.972 .29518 Mdot
.972 .29527 Mdot
.972 .2953 Mdot
.972 .29566 Mdot
.972 .29572 Mdot
.972 .29642 Mdot
.972 .29648 Mdot
.972 .29661 Mdot
.972 .29749 Mdot
.972 .298 Mdot
.972 .29839 Mdot
.972 .29847 Mdot
.972 .29873 Mdot
.972 .2988 Mdot
.972 .29887 Mdot
.972 .29948 Mdot
.972 .30034 Mdot
.972 .30153 Mdot
.972 .30207 Mdot
.972 .30214 Mdot
.972 .30255 Mdot
.972 .30315 Mdot
.972 .30316 Mdot
.972 .30324 Mdot
.972 .30354 Mdot
.972 .30389 Mdot
.972 .30483 Mdot
.972 .30509 Mdot
.972 .30548 Mdot
.972 .30629 Mdot
.972 .30644 Mdot
.972 .30655 Mdot
.972 .30674 Mdot
.972 .30708 Mdot
.972 .30718 Mdot
.972 .30764 Mdot
.972 .30766 Mdot
.972 .30779 Mdot
.972 .3093 Mdot
.972 .30944 Mdot
.972 .30945 Mdot
.972 .31034 Mdot
.972 .31053 Mdot
.972 .31165 Mdot
.972 .31239 Mdot
.972 .31334 Mdot
.972 .31393 Mdot
.972 .31498 Mdot
.972 .31546 Mdot
.972 .31643 Mdot
.972 .31693 Mdot
.972 .31719 Mdot
.972 .31764 Mdot
.972 .31983 Mdot
.972 .32057 Mdot
.972 .32084 Mdot
.972 .32297 Mdot
.972 .32326 Mdot
.972 .32427 Mdot
.972 .32435 Mdot
.972 .3249 Mdot
.972 .32501 Mdot
.972 .32541 Mdot
.972 .32568 Mdot
.972 .32569 Mdot
.972 .3261 Mdot
.972 .32611 Mdot
.972 .32621 Mdot
.972 .32646 Mdot
.972 .32703 Mdot
.972 .32711 Mdot
.972 .32754 Mdot
.972 .32964 Mdot
.972 .32967 Mdot
.972 .32986 Mdot
.972 .33066 Mdot
.972 .33106 Mdot
.972 .33228 Mdot
.972 .33259 Mdot
.972 .33279 Mdot
.972 .33283 Mdot
.972 .33283 Mdot
.972 .33404 Mdot
.972 .33468 Mdot
.972 .33472 Mdot
.972 .33488 Mdot
.972 .33575 Mdot
.972 .33617 Mdot
.972 .33652 Mdot
.972 .33754 Mdot
.972 .33754 Mdot
.972 .33795 Mdot
.972 .33799 Mdot
.972 .33878 Mdot
.972 .33938 Mdot
.972 .33954 Mdot
.972 .34008 Mdot
.972 .34078 Mdot
.972 .34092 Mdot
.972 .34095 Mdot
.972 .34101 Mdot
.972 .34162 Mdot
.972 .34185 Mdot
.972 .34207 Mdot
.972 .34234 Mdot
.972 .34273 Mdot
.972 .34335 Mdot
.972 .34372 Mdot
.972 .34378 Mdot
.972 .34426 Mdot
.972 .34449 Mdot
.972 .34467 Mdot
.972 .34478 Mdot
.972 .34495 Mdot
.972 .34514 Mdot
.972 .34531 Mdot
.972 .34706 Mdot
.972 .34765 Mdot
.972 .34781 Mdot
.972 .34957 Mdot
.972 .34995 Mdot
.972 .35163 Mdot
.972 .35189 Mdot
.972 .35321 Mdot
.972 .35396 Mdot
.972 .35416 Mdot
.972 .3545 Mdot
.972 .35476 Mdot
.972 .35599 Mdot
.972 .35664 Mdot
.972 .35678 Mdot
.972 .35712 Mdot
.972 .35945 Mdot
.972 .35978 Mdot
.972 .36044 Mdot
.972 .36098 Mdot
.972 .36138 Mdot
.972 .36235 Mdot
.972 .36296 Mdot
.972 .36367 Mdot
.972 .36418 Mdot
.972 .36435 Mdot
.972 .36447 Mdot
.972 .36599 Mdot
.972 .36603 Mdot
.972 .36774 Mdot
.972 .36776 Mdot
.972 .3683 Mdot
.972 .36975 Mdot
.972 .37005 Mdot
.972 .37028 Mdot
.972 .37048 Mdot
.972 .37089 Mdot
.972 .37095 Mdot
.972 .37115 Mdot
.972 .37196 Mdot
.972 .37205 Mdot
.972 .37285 Mdot
.972 .3732 Mdot
.972 .37321 Mdot
.972 .37425 Mdot
.972 .37539 Mdot
.972 .37554 Mdot
.972 .37555 Mdot
.972 .37616 Mdot
.972 .37628 Mdot
.972 .37655 Mdot
.972 .37752 Mdot
.972 .37755 Mdot
.972 .37772 Mdot
.972 .37804 Mdot
.972 .37835 Mdot
.972 .37839 Mdot
.972 .37915 Mdot
.972 .37947 Mdot
.972 .38038 Mdot
.972 .38136 Mdot
.972 .38359 Mdot
.972 .38384 Mdot
.972 .3848 Mdot
.972 .38523 Mdot
.972 .38588 Mdot
.972 .38715 Mdot
.972 .38851 Mdot
.972 .38858 Mdot
.972 .38914 Mdot
.972 .3893 Mdot
.972 .38934 Mdot
.972 .39097 Mdot
.972 .39168 Mdot
.972 .39251 Mdot
.972 .39416 Mdot
.972 .39633 Mdot
.972 .39664 Mdot
.972 .39668 Mdot
.972 .39684 Mdot
.972 .39687 Mdot
.972 .39694 Mdot
.972 .3972 Mdot
.972 .39725 Mdot
.972 .39734 Mdot
.972 .39887 Mdot
.972 .40013 Mdot
.972 .40028 Mdot
.972 .40032 Mdot
.972 .40117 Mdot
.972 .40234 Mdot
.972 .40245 Mdot
.972 .4038 Mdot
.972 .40523 Mdot
.972 .40632 Mdot
.972 .40634 Mdot
.972 .40642 Mdot
.972 .40707 Mdot
.972 .40786 Mdot
.972 .40806 Mdot
.972 .4082 Mdot
.972 .41034 Mdot
.972 .41077 Mdot
.972 .41197 Mdot
.972 .41199 Mdot
.972 .41207 Mdot
.972 .41236 Mdot
.972 .4124 Mdot
.972 .4148 Mdot
.972 .41721 Mdot
.972 .41778 Mdot
.972 .41795 Mdot
.972 .41804 Mdot
.972 .41805 Mdot
.972 .41855 Mdot
.972 .41869 Mdot
.972 .41875 Mdot
.972 .41907 Mdot
.972 .41914 Mdot
.972 .41973 Mdot
.972 .42086 Mdot
.972 .42133 Mdot
.972 .42146 Mdot
.972 .42205 Mdot
.972 .42308 Mdot
.972 .42396 Mdot
.972 .42398 Mdot
.972 .42491 Mdot
.972 .42554 Mdot
.972 .42585 Mdot
.972 .42635 Mdot
.972 .42656 Mdot
.972 .42718 Mdot
.972 .42734 Mdot
.972 .42879 Mdot
.972 .42989 Mdot
.972 .43007 Mdot
.972 .43017 Mdot
.972 .43223 Mdot
.972 .43243 Mdot
.972 .43333 Mdot
.972 .43341 Mdot
.972 .43372 Mdot
.972 .4348 Mdot
.972 .43489 Mdot
.972 .43495 Mdot
.972 .43541 Mdot
.972 .43695 Mdot
.972 .43731 Mdot
.972 .43758 Mdot
.972 .43767 Mdot
.972 .44006 Mdot
.972 .44116 Mdot
.972 .44132 Mdot
.972 .44216 Mdot
.972 .44266 Mdot
.972 .44268 Mdot
.972 .44402 Mdot
.972 .44431 Mdot
.972 .4445 Mdot
.972 .4445 Mdot
.972 .44506 Mdot
.972 .44544 Mdot
.972 .44885 Mdot
.972 .44908 Mdot
.972 .44997 Mdot
.972 .45076 Mdot
.972 .45155 Mdot
.972 .45251 Mdot
.972 .45307 Mdot
.972 .45314 Mdot
.972 .45392 Mdot
.972 .45461 Mdot
.972 .45469 Mdot
.972 .45531 Mdot
.972 .45593 Mdot
.972 .45626 Mdot
.972 .45631 Mdot
.972 .45662 Mdot
.972 .45683 Mdot
.972 .45714 Mdot
.972 .45819 Mdot
.972 .45854 Mdot
.972 .45872 Mdot
.972 .45875 Mdot
.972 .45896 Mdot
.972 .45967 Mdot
.972 .46013 Mdot
.972 .46016 Mdot
.972 .46034 Mdot
.972 .46042 Mdot
.972 .46045 Mdot
.972 .46232 Mdot
.972 .46249 Mdot
.972 .46268 Mdot
.972 .46289 Mdot
.972 .46309 Mdot
.972 .46398 Mdot
.972 .4647 Mdot
.972 .46471 Mdot
.972 .46502 Mdot
.972 .46538 Mdot
.972 .46591 Mdot
.972 .4664 Mdot
.972 .46649 Mdot
.972 .46694 Mdot
.972 .46711 Mdot
.972 .46846 Mdot
.972 .46869 Mdot
.972 .46908 Mdot
.972 .4692 Mdot
.972 .47 Mdot
.972 .47038 Mdot
.972 .47084 Mdot
.972 .47117 Mdot
.972 .47141 Mdot
.972 .47147 Mdot
.972 .47153 Mdot
.972 .47367 Mdot
.972 .47424 Mdot
.972 .47529 Mdot
.972 .47533 Mdot
.972 .47739 Mdot
.972 .47746 Mdot
.972 .47865 Mdot
.972 .47866 Mdot
.972 .47873 Mdot
.972 .47951 Mdot
.972 .4801 Mdot
.972 .48153 Mdot
.972 .48169 Mdot
.972 .48191 Mdot
.972 .48225 Mdot
.972 .48323 Mdot
.972 .48381 Mdot
.972 .48461 Mdot
.972 .48552 Mdot
.972 .4858 Mdot
.972 .48676 Mdot
.972 .48694 Mdot
.972 .48761 Mdot
.972 .48769 Mdot
.972 .48775 Mdot
.972 .48846 Mdot
.972 .48869 Mdot
.972 .4895 Mdot
.972 .4907 Mdot
.972 .4908 Mdot
.972 .49095 Mdot
.972 .491 Mdot
.972 .49143 Mdot
.972 .49285 Mdot
.972 .49295 Mdot
.972 .49349 Mdot
.972 .49477 Mdot
.972 .49549 Mdot
.972 .4957 Mdot
.972 .49575 Mdot
.972 .49597 Mdot
.972 .49613 Mdot
.972 .49662 Mdot
.972 .49689 Mdot
.972 .49817 Mdot
.972 .50056 Mdot
.972 .50105 Mdot
.972 .50172 Mdot
.972 .50211 Mdot
.972 .50355 Mdot
.972 .50356 Mdot
.972 .5037 Mdot
.972 .50613 Mdot
.972 .50664 Mdot
.972 .50766 Mdot
.972 .50792 Mdot
.972 .50816 Mdot
.972 .50982 Mdot
.972 .50982 Mdot
.972 .50991 Mdot
.972 .51041 Mdot
.972 .51065 Mdot
.972 .51234 Mdot
.972 .51407 Mdot
.972 .51416 Mdot
.972 .51437 Mdot
.972 .51553 Mdot
.972 .51788 Mdot
.972 .51799 Mdot
.972 .51812 Mdot
.972 .51834 Mdot
.972 .51835 Mdot
.972 .51893 Mdot
.972 .51914 Mdot
.972 .51925 Mdot
.972 .51926 Mdot
.972 .51962 Mdot
.972 .51996 Mdot
.972 .52001 Mdot
.972 .52018 Mdot
.972 .5205 Mdot
.972 .52051 Mdot
.972 .52097 Mdot
.972 .5219 Mdot
.972 .52201 Mdot
.972 .52225 Mdot
.972 .52275 Mdot
.972 .52367 Mdot
.972 .52394 Mdot
.972 .52471 Mdot
.972 .52484 Mdot
.972 .52523 Mdot
.972 .52566 Mdot
.972 .52611 Mdot
.972 .52669 Mdot
.972 .52717 Mdot
.972 .52729 Mdot
.972 .52741 Mdot
.972 .52745 Mdot
.972 .52774 Mdot
.972 .52864 Mdot
.972 .5291 Mdot
.972 .52949 Mdot
.972 .52953 Mdot
.972 .53014 Mdot
.972 .53046 Mdot
.972 .53163 Mdot
.972 .53165 Mdot
.972 .53199 Mdot
.972 .53316 Mdot
.972 .53323 Mdot
.972 .5337 Mdot
.972 .53374 Mdot
.972 .53403 Mdot
.972 .53404 Mdot
.972 .53431 Mdot
.972 .5346 Mdot
.972 .53524 Mdot
.972 .5359 Mdot
.972 .53602 Mdot
.972 .53617 Mdot
.972 .53669 Mdot
.972 .53694 Mdot
.972 .53729 Mdot
.972 .53751 Mdot
.972 .53915 Mdot
.972 .53921 Mdot
.972 .53951 Mdot
.972 .53958 Mdot
.972 .5396 Mdot
.972 .54016 Mdot
.972 .54083 Mdot
.972 .54114 Mdot
.972 .5425 Mdot
.972 .54318 Mdot
.972 .5432 Mdot
.972 .54326 Mdot
.972 .54365 Mdot
.972 .54367 Mdot
.972 .54373 Mdot
.972 .54427 Mdot
.972 .54643 Mdot
.972 .54663 Mdot
.972 .54741 Mdot
.972 .54872 Mdot
.972 .54897 Mdot
.972 .54933 Mdot
.972 .54939 Mdot
.972 .54978 Mdot
.972 .55055 Mdot
.972 .55119 Mdot
.972 .55127 Mdot
.972 .55136 Mdot
.972 .55137 Mdot
.972 .55208 Mdot
.972 .55262 Mdot
.972 .55269 Mdot
.972 .55303 Mdot
.972 .55346 Mdot
.972 .5543 Mdot
.972 .55447 Mdot
.972 .55518 Mdot
.972 .55556 Mdot
.972 .55605 Mdot
.972 .55625 Mdot
.972 .55628 Mdot
.972 .55707 Mdot
.972 .55709 Mdot
.972 .55762 Mdot
.972 .55839 Mdot
.972 .5586 Mdot
.972 .55968 Mdot
.972 .55979 Mdot
.972 .55982 Mdot
.972 .55989 Mdot
.972 .55995 Mdot
.972 .56012 Mdot
.972 .56018 Mdot
.972 .56088 Mdot
.972 .56098 Mdot
.972 .56178 Mdot
.972 .56235 Mdot
.972 .56235 Mdot
.972 .56246 Mdot
.972 .56272 Mdot
.972 .56444 Mdot
.972 .56542 Mdot
.972 .56619 Mdot
.972 .56633 Mdot
.972 .56649 Mdot
.972 .56684 Mdot
.972 .56699 Mdot
.972 .56701 Mdot
.972 .56711 Mdot
.972 .5683 Mdot
.972 .56846 Mdot
.972 .56997 Mdot
.972 .57228 Mdot
.972 .57272 Mdot
.972 .57334 Mdot
.972 .57347 Mdot
.972 .57359 Mdot
.972 .57409 Mdot
.972 .57426 Mdot
.972 .57506 Mdot
.972 .57543 Mdot
.972 .57544 Mdot
.972 .57561 Mdot
.972 .5762 Mdot
.972 .57686 Mdot
.972 .57695 Mdot
.972 .57789 Mdot
.972 .57869 Mdot
.972 .57921 Mdot
.972 .57992 Mdot
.972 .57996 Mdot
.972 .58107 Mdot
.972 .58154 Mdot
.972 .58184 Mdot
.972 .58205 Mdot
.972 .5824 Mdot
.972 .58292 Mdot
.972 .58307 Mdot
.972 .58326 Mdot
.972 .58417 Mdot
.972 .58421 Mdot
.972 .58436 Mdot
.972 .58445 Mdot
.972 .58654 Mdot
.972 .58691 Mdot
.972 .58739 Mdot
.972 .58767 Mdot
.972 .58768 Mdot
.974 .0457 Mdot
.974 .04783 Mdot
.974 .04812 Mdot
.974 .04861 Mdot
.974 .05014 Mdot
.974 .05024 Mdot
.974 .05047 Mdot
.974 .05133 Mdot
.974 .05365 Mdot
.974 .05486 Mdot
.974 .05543 Mdot
.974 .05701 Mdot
.974 .06005 Mdot
.974 .06261 Mdot
.974 .06496 Mdot
.974 .06501 Mdot
.974 .06545 Mdot
.974 .06731 Mdot
.974 .06969 Mdot
.974 .07051 Mdot
.974 .07181 Mdot
.974 .07201 Mdot
.974 .07508 Mdot
.974 .07573 Mdot
.974 .07574 Mdot
.974 .07599 Mdot
.974 .07685 Mdot
.974 .07699 Mdot
.974 .07731 Mdot
.974 .07786 Mdot
.974 .07836 Mdot
.974 .07922 Mdot
.974 .07978 Mdot
.974 .08073 Mdot
.974 .08074 Mdot
.974 .08118 Mdot
.974 .08193 Mdot
.974 .08213 Mdot
.974 .08308 Mdot
.974 .08337 Mdot
.974 .08372 Mdot
.974 .08392 Mdot
.974 .0842 Mdot
.974 .08437 Mdot
.974 .08463 Mdot
.974 .08594 Mdot
.974 .08604 Mdot
.974 .08632 Mdot
.974 .08766 Mdot
.974 .08803 Mdot
.974 .08984 Mdot
.974 .09011 Mdot
.974 .09018 Mdot
.974 .0902 Mdot
.974 .09055 Mdot
.974 .09056 Mdot
.974 .09206 Mdot
.974 .09237 Mdot
.974 .09292 Mdot
.974 .09352 Mdot
.974 .09403 Mdot
.974 .09419 Mdot
.974 .09496 Mdot
.974 .09703 Mdot
.974 .09711 Mdot
.974 .09772 Mdot
.974 .09778 Mdot
.974 .09946 Mdot
.974 .10118 Mdot
.974 .10224 Mdot
.974 .10261 Mdot
.974 .103 Mdot
.974 .10303 Mdot
.974 .10363 Mdot
.974 .10535 Mdot
.974 .10579 Mdot
.974 .10635 Mdot
.974 .10802 Mdot
.974 .1082 Mdot
.974 .10824 Mdot
.974 .1101 Mdot
.974 .11019 Mdot
.974 .11049 Mdot
.974 .11053 Mdot
.974 .11076 Mdot
.974 .1108 Mdot
.974 .11165 Mdot
.974 .11226 Mdot
.974 .1125 Mdot
.974 .11259 Mdot
.974 .11268 Mdot
.974 .11351 Mdot
.974 .11354 Mdot
.974 .11451 Mdot
.974 .11584 Mdot
.974 .11717 Mdot
.974 .11745 Mdot
.974 .11837 Mdot
.974 .12044 Mdot
.974 .12047 Mdot
.974 .12114 Mdot
.974 .12118 Mdot
.974 .12133 Mdot
.974 .1218 Mdot
.974 .1234 Mdot
.974 .12573 Mdot
.974 .12593 Mdot
.974 .12632 Mdot
.974 .1323 Mdot
.974 .13262 Mdot
.974 .13282 Mdot
.974 .13298 Mdot
.974 .13357 Mdot
.974 .1336 Mdot
.974 .13408 Mdot
.974 .13439 Mdot
.974 .13519 Mdot
.974 .13575 Mdot
.974 .13603 Mdot
.974 .13666 Mdot
.974 .13685 Mdot
.974 .13688 Mdot
.974 .13764 Mdot
.974 .13773 Mdot
.974 .13825 Mdot
.974 .13832 Mdot
.974 .1387 Mdot
.974 .13926 Mdot
.974 .14037 Mdot
.974 .14114 Mdot
.974 .14146 Mdot
.974 .14311 Mdot
.974 .1433 Mdot
.974 .14333 Mdot
.974 .14412 Mdot
.974 .14419 Mdot
.974 .14513 Mdot
.974 .14556 Mdot
.974 .14564 Mdot
.974 .14603 Mdot
.974 .14771 Mdot
.974 .1479 Mdot
.974 .14846 Mdot
.974 .14913 Mdot
.974 .14953 Mdot
.974 .15007 Mdot
.974 .1504 Mdot
.974 .15057 Mdot
.974 .15066 Mdot
.974 .15067 Mdot
.974 .15091 Mdot
.974 .15131 Mdot
.974 .15179 Mdot
.974 .15308 Mdot
.974 .15346 Mdot
.974 .15366 Mdot
.974 .15419 Mdot
.974 .15421 Mdot
.974 .15424 Mdot
.974 .15578 Mdot
.974 .15629 Mdot
.974 .15682 Mdot
.974 .15719 Mdot
.974 .15719 Mdot
.974 .15727 Mdot
.974 .15753 Mdot
.974 .15816 Mdot
.974 .15895 Mdot
.974 .15905 Mdot
.974 .15952 Mdot
.974 .15968 Mdot
.974 .15998 Mdot
.974 .16027 Mdot
.974 .16094 Mdot
.974 .16107 Mdot
.974 .16157 Mdot
.974 .16172 Mdot
.974 .16176 Mdot
.974 .16243 Mdot
.974 .16246 Mdot
.974 .16332 Mdot
.974 .16338 Mdot
.974 .16538 Mdot
.974 .16599 Mdot
.974 .16662 Mdot
.974 .16705 Mdot
.974 .16737 Mdot
.974 .16823 Mdot
.974 .16922 Mdot
.974 .16954 Mdot
.974 .17035 Mdot
.974 .17036 Mdot
.974 .17103 Mdot
.974 .17156 Mdot
.974 .17231 Mdot
.974 .17506 Mdot
.974 .17521 Mdot
.974 .17533 Mdot
.974 .1764 Mdot
.974 .17652 Mdot
.974 .17881 Mdot
.974 .17947 Mdot
.974 .1798 Mdot
.974 .18049 Mdot
.974 .18082 Mdot
.974 .18137 Mdot
.974 .18169 Mdot
.974 .18179 Mdot
.974 .1822 Mdot
.974 .18316 Mdot
.974 .18465 Mdot
.974 .18522 Mdot
.974 .18558 Mdot
.974 .18594 Mdot
.974 .1867 Mdot
.974 .18675 Mdot
.974 .18776 Mdot
.974 .18792 Mdot
.974 .18798 Mdot
.974 .18829 Mdot
.974 .18929 Mdot
.974 .1896 Mdot
.974 .18984 Mdot
.974 .19095 Mdot
.974 .19127 Mdot
.974 .19127 Mdot
.974 .19201 Mdot
.974 .19213 Mdot
.974 .19321 Mdot
.974 .19325 Mdot
.974 .19429 Mdot
.974 .19502 Mdot
.974 .19614 Mdot
.974 .19645 Mdot
.974 .19647 Mdot
.974 .19653 Mdot
.974 .19675 Mdot
.974 .19683 Mdot
.974 .19689 Mdot
.974 .1969 Mdot
.974 .19802 Mdot
.974 .19823 Mdot
.974 .1998 Mdot
.974 .19992 Mdot
.974 .20038 Mdot
.974 .20052 Mdot
.974 .2007 Mdot
.974 .20128 Mdot
.974 .20136 Mdot
.974 .20164 Mdot
.974 .2018 Mdot
.974 .20181 Mdot
.974 .20186 Mdot
.974 .20189 Mdot
.974 .20342 Mdot
.974 .20354 Mdot
.974 .20377 Mdot
.974 .20419 Mdot
.974 .20435 Mdot
.974 .20473 Mdot
.974 .20521 Mdot
.974 .20538 Mdot
.974 .20555 Mdot
.974 .20559 Mdot
.974 .20583 Mdot
.974 .20602 Mdot
.974 .20685 Mdot
.974 .20716 Mdot
.974 .20723 Mdot
.974 .20742 Mdot
.974 .20828 Mdot
.974 .20908 Mdot
.974 .20912 Mdot
.974 .2117 Mdot
.974 .21325 Mdot
.974 .21343 Mdot
.974 .21429 Mdot
.974 .21485 Mdot
.974 .21487 Mdot
.974 .21509 Mdot
.974 .21568 Mdot
.974 .21663 Mdot
.974 .2191 Mdot
.974 .21977 Mdot
.974 .22058 Mdot
.974 .22067 Mdot
.974 .22072 Mdot
.974 .22203 Mdot
.974 .22211 Mdot
.974 .2224 Mdot
.974 .22331 Mdot
.974 .2235 Mdot
.974 .22643 Mdot
.974 .22704 Mdot
.974 .228 Mdot
.974 .22878 Mdot
.974 .22891 Mdot
.974 .22893 Mdot
.974 .22939 Mdot
.974 .22977 Mdot
.974 .23031 Mdot
.974 .23032 Mdot
.974 .23051 Mdot
.974 .23097 Mdot
.974 .23136 Mdot
.974 .23211 Mdot
.974 .23514 Mdot
.974 .23542 Mdot
.974 .23581 Mdot
.974 .23669 Mdot
.974 .2376 Mdot
.974 .24059 Mdot
.974 .24202 Mdot
.974 .24313 Mdot
.974 .24333 Mdot
.974 .24377 Mdot
.974 .24405 Mdot
.974 .24438 Mdot
.974 .24469 Mdot
.974 .24478 Mdot
.974 .24496 Mdot
.974 .2451 Mdot
.974 .24624 Mdot
.974 .2463 Mdot
.974 .24725 Mdot
.974 .24745 Mdot
.974 .24785 Mdot
.974 .24939 Mdot
.974 .25023 Mdot
.974 .25049 Mdot
.974 .25075 Mdot
.974 .25092 Mdot
.974 .25103 Mdot
.974 .25195 Mdot
.974 .25226 Mdot
.974 .25264 Mdot
.974 .25264 Mdot
.974 .25269 Mdot
.974 .25355 Mdot
.974 .25416 Mdot
.974 .25435 Mdot
.974 .25463 Mdot
.974 .25505 Mdot
.974 .25533 Mdot
.974 .25537 Mdot
.974 .25551 Mdot
.974 .25624 Mdot
.974 .25732 Mdot
.974 .25767 Mdot
.974 .25805 Mdot
.974 .25948 Mdot
.974 .2609 Mdot
.974 .261 Mdot
.974 .26112 Mdot
.974 .26112 Mdot
.974 .26162 Mdot
.974 .26255 Mdot
.974 .26371 Mdot
.974 .26482 Mdot
.974 .2652 Mdot
.974 .26525 Mdot
.974 .26635 Mdot
.974 .26679 Mdot
.974 .26694 Mdot
.974 .26721 Mdot
.974 .26764 Mdot
.974 .26827 Mdot
.974 .26864 Mdot
.974 .26876 Mdot
.974 .2688 Mdot
.974 .26921 Mdot
.974 .26926 Mdot
.974 .2696 Mdot
.974 .26976 Mdot
.974 .27025 Mdot
.974 .27052 Mdot
.974 .27085 Mdot
.974 .27142 Mdot
.974 .27191 Mdot
.974 .27197 Mdot
.974 .27343 Mdot
.974 .2738 Mdot
.974 .27415 Mdot
.974 .27524 Mdot
.974 .27656 Mdot
.974 .27734 Mdot
.974 .27839 Mdot
.974 .27904 Mdot
.974 .27929 Mdot
.974 .27937 Mdot
.974 .27953 Mdot
.974 .27956 Mdot
.974 .27977 Mdot
.974 .28003 Mdot
.974 .28026 Mdot
.974 .2808 Mdot
.974 .28082 Mdot
.974 .28157 Mdot
.974 .28175 Mdot
.974 .28177 Mdot
.974 .28252 Mdot
.974 .28425 Mdot
.974 .285 Mdot
.974 .28518 Mdot
.974 .28538 Mdot
.974 .28538 Mdot
.974 .2864 Mdot
.974 .28645 Mdot
.974 .2865 Mdot
.974 .28832 Mdot
.974 .28951 Mdot
.974 .2897 Mdot
.974 .29026 Mdot
.974 .2905 Mdot
.974 .29092 Mdot
.974 .29127 Mdot
.974 .29154 Mdot
.974 .29225 Mdot
.974 .29226 Mdot
.974 .29241 Mdot
.974 .29244 Mdot
.974 .29293 Mdot
.974 .29342 Mdot
.974 .29369 Mdot
.974 .29414 Mdot
.974 .29431 Mdot
.974 .29451 Mdot
.974 .29478 Mdot
.974 .29524 Mdot
.974 .29568 Mdot
.974 .2957 Mdot
.974 .29588 Mdot
.974 .29642 Mdot
.974 .2968 Mdot
.974 .29711 Mdot
.974 .29719 Mdot
.974 .29768 Mdot
.974 .2977 Mdot
.974 .29825 Mdot
.974 .2987 Mdot
.974 .29955 Mdot
.974 .29981 Mdot
.974 .29986 Mdot
.974 .30005 Mdot
.974 .3008 Mdot
.974 .30093 Mdot
.974 .30107 Mdot
.974 .30116 Mdot
.974 .30142 Mdot
.974 .30247 Mdot
.974 .30253 Mdot
.974 .3042 Mdot
.974 .30432 Mdot
.974 .30433 Mdot
.974 .30495 Mdot
.974 .30642 Mdot
.974 .30684 Mdot
.974 .30699 Mdot
.974 .30815 Mdot
.974 .30821 Mdot
.974 .30824 Mdot
.974 .30864 Mdot
.974 .30884 Mdot
.974 .30941 Mdot
.974 .31062 Mdot
.974 .31147 Mdot
.974 .31208 Mdot
.974 .31377 Mdot
.974 .31568 Mdot
.974 .31631 Mdot
.974 .31653 Mdot
.974 .3179 Mdot
.974 .3179 Mdot
.974 .3182 Mdot
.974 .31922 Mdot
.974 .31991 Mdot
.974 .32013 Mdot
.974 .32025 Mdot
.974 .32059 Mdot
.974 .32105 Mdot
.974 .32162 Mdot
.974 .32171 Mdot
.974 .32181 Mdot
.974 .32277 Mdot
.974 .32499 Mdot
.974 .32582 Mdot
.974 .32646 Mdot
.974 .32706 Mdot
.974 .32707 Mdot
.974 .32737 Mdot
.974 .32753 Mdot
.974 .32759 Mdot
.974 .32968 Mdot
.974 .32987 Mdot
.974 .32992 Mdot
.974 .33336 Mdot
.974 .33357 Mdot
.974 .33438 Mdot
.974 .33464 Mdot
.974 .33566 Mdot
.974 .33592 Mdot
.974 .33619 Mdot
.974 .3363 Mdot
.974 .33765 Mdot
.974 .33795 Mdot
.974 .33829 Mdot
.974 .339 Mdot
.974 .33937 Mdot
.974 .33939 Mdot
.974 .33998 Mdot
.974 .34018 Mdot
.974 .34098 Mdot
.974 .34185 Mdot
.974 .34284 Mdot
.974 .34315 Mdot
.974 .34335 Mdot
.974 .34507 Mdot
.974 .34551 Mdot
.974 .34574 Mdot
.974 .34582 Mdot
.974 .34585 Mdot
.974 .3466 Mdot
.974 .34685 Mdot
.974 .34756 Mdot
.974 .34783 Mdot
.974 .34791 Mdot
.974 .34827 Mdot
.974 .34835 Mdot
.974 .34934 Mdot
.974 .34971 Mdot
.974 .34973 Mdot
.974 .34983 Mdot
.974 .35108 Mdot
.974 .35114 Mdot
.974 .35155 Mdot
.974 .35164 Mdot
.974 .3518 Mdot
.974 .35212 Mdot
.974 .35224 Mdot
.974 .35283 Mdot
.974 .35463 Mdot
.974 .35478 Mdot
.974 .35538 Mdot
.974 .35586 Mdot
.974 .35607 Mdot
.974 .35803 Mdot
.974 .35823 Mdot
.974 .35864 Mdot
.974 .35864 Mdot
.974 .35869 Mdot
.974 .35998 Mdot
.974 .36009 Mdot
.974 .36032 Mdot
.974 .36056 Mdot
.974 .36202 Mdot
.974 .36226 Mdot
.974 .36243 Mdot
.974 .3625 Mdot
.974 .36452 Mdot
.974 .36516 Mdot
.974 .36595 Mdot
.974 .36813 Mdot
.974 .36874 Mdot
.974 .36878 Mdot
.974 .36889 Mdot
.974 .36932 Mdot
.974 .36947 Mdot
.974 .3696 Mdot
.974 .36962 Mdot
.974 .37167 Mdot
.974 .3718 Mdot
.974 .3722 Mdot
.974 .3724 Mdot
.974 .37527 Mdot
.974 .3755 Mdot
.974 .37555 Mdot
.974 .37575 Mdot
.974 .37587 Mdot
.974 .3764 Mdot
.974 .37666 Mdot
.974 .37696 Mdot
.974 .37702 Mdot
.974 .37725 Mdot
.974 .37814 Mdot
.974 .37831 Mdot
.974 .3787 Mdot
.974 .37884 Mdot
.974 .37915 Mdot
.974 .37917 Mdot
.974 .37928 Mdot
.974 .37933 Mdot
.974 .38136 Mdot
.974 .38225 Mdot
.974 .38231 Mdot
.974 .38243 Mdot
.974 .38255 Mdot
.974 .38275 Mdot
.974 .383 Mdot
.974 .38381 Mdot
.974 .38413 Mdot
.974 .38487 Mdot
.974 .38579 Mdot
.974 .38585 Mdot
.974 .38613 Mdot
.974 .38647 Mdot
.974 .38654 Mdot
.974 .387 Mdot
.974 .38738 Mdot
.974 .38837 Mdot
.974 .38899 Mdot
.974 .38928 Mdot
.974 .38961 Mdot
.974 .38974 Mdot
.974 .3901 Mdot
.974 .39059 Mdot
.974 .39178 Mdot
.974 .39247 Mdot
.974 .39281 Mdot
.974 .39334 Mdot
.974 .39341 Mdot
.974 .39417 Mdot
.974 .39691 Mdot
.974 .39696 Mdot
.974 .39774 Mdot
.974 .39844 Mdot
.974 .40053 Mdot
.974 .40087 Mdot
.974 .40137 Mdot
.974 .40146 Mdot
.974 .40182 Mdot
.974 .40254 Mdot
.974 .40255 Mdot
.974 .40349 Mdot
.974 .40358 Mdot
.974 .40402 Mdot
.974 .40403 Mdot
.974 .40441 Mdot
.974 .40442 Mdot
.974 .40452 Mdot
.974 .40457 Mdot
.974 .40463 Mdot
.974 .40463 Mdot
.974 .40483 Mdot
.974 .40483 Mdot
.974 .40505 Mdot
.974 .40558 Mdot
.974 .40559 Mdot
.974 .40619 Mdot
.974 .40644 Mdot
.974 .40662 Mdot
.974 .40805 Mdot
.974 .40845 Mdot
.974 .40848 Mdot
.974 .40988 Mdot
.974 .41058 Mdot
.974 .41076 Mdot
.974 .41173 Mdot
.974 .41239 Mdot
.974 .41286 Mdot
.974 .41416 Mdot
.974 .41575 Mdot
.974 .41591 Mdot
.974 .416 Mdot
.974 .41646 Mdot
.974 .41783 Mdot
.974 .41857 Mdot
.974 .41872 Mdot
.974 .41928 Mdot
.974 .41934 Mdot
.974 .41944 Mdot
.974 .42106 Mdot
.974 .42144 Mdot
.974 .42478 Mdot
.974 .42627 Mdot
.974 .42639 Mdot
.974 .42714 Mdot
.974 .42744 Mdot
.974 .4281 Mdot
.974 .42833 Mdot
.974 .42944 Mdot
.974 .43019 Mdot
.974 .43172 Mdot
.974 .43176 Mdot
.974 .43197 Mdot
.974 .43201 Mdot
.974 .43271 Mdot
.974 .4329 Mdot
.974 .43341 Mdot
.974 .43363 Mdot
.974 .43368 Mdot
.974 .4343 Mdot
.974 .43469 Mdot
.974 .4347 Mdot
.974 .43487 Mdot
.974 .43509 Mdot
.974 .43597 Mdot
.974 .43607 Mdot
.974 .43674 Mdot
.974 .43801 Mdot
.974 .43821 Mdot
.974 .43875 Mdot
.974 .43965 Mdot
.974 .43979 Mdot
.974 .44044 Mdot
.974 .44099 Mdot
.974 .4411 Mdot
.974 .44289 Mdot
.974 .4441 Mdot
.974 .44434 Mdot
.974 .44465 Mdot
.974 .44497 Mdot
.974 .4454 Mdot
.974 .44654 Mdot
.974 .44703 Mdot
.974 .44713 Mdot
.974 .44742 Mdot
.974 .44766 Mdot
.974 .44789 Mdot
.974 .448 Mdot
.974 .44889 Mdot
.974 .44974 Mdot
.974 .45369 Mdot
.974 .45379 Mdot
.974 .454 Mdot
.974 .45405 Mdot
.974 .45464 Mdot
.974 .45472 Mdot
.974 .45493 Mdot
.974 .45569 Mdot
.974 .456 Mdot
.974 .4575 Mdot
.974 .45775 Mdot
.974 .4582 Mdot
.974 .4583 Mdot
.974 .45889 Mdot
.974 .45941 Mdot
.974 .45967 Mdot
.974 .46006 Mdot
.974 .46044 Mdot
.974 .46067 Mdot
.974 .46091 Mdot
.974 .46105 Mdot
.974 .46115 Mdot
.974 .46147 Mdot
.974 .4616 Mdot
.974 .46211 Mdot
.974 .46271 Mdot
.974 .46289 Mdot
.974 .46323 Mdot
.974 .46351 Mdot
.974 .46423 Mdot
.974 .46573 Mdot
.974 .46584 Mdot
.974 .4672 Mdot
.974 .46759 Mdot
.974 .46769 Mdot
.974 .46808 Mdot
.974 .46836 Mdot
.974 .46861 Mdot
.974 .46886 Mdot
.974 .47187 Mdot
.974 .47262 Mdot
.974 .47265 Mdot
.974 .4729 Mdot
.974 .47319 Mdot
.974 .4735 Mdot
.974 .47401 Mdot
.974 .47403 Mdot
.974 .47425 Mdot
.974 .47432 Mdot
.974 .47452 Mdot
.974 .47484 Mdot
.974 .47506 Mdot
.974 .4755 Mdot
.974 .47686 Mdot
.974 .47745 Mdot
.974 .47818 Mdot
.974 .47819 Mdot
.974 .4783 Mdot
.974 .47976 Mdot
.974 .47996 Mdot
.974 .48116 Mdot
.974 .4813 Mdot
.974 .48152 Mdot
.974 .48207 Mdot
.974 .48254 Mdot
.974 .48289 Mdot
.974 .48342 Mdot
.974 .48351 Mdot
.974 .48378 Mdot
.974 .48521 Mdot
.974 .48648 Mdot
.974 .48662 Mdot
.974 .48695 Mdot
.974 .48732 Mdot
.974 .48742 Mdot
.974 .48799 Mdot
.974 .48873 Mdot
.974 .49026 Mdot
.974 .49073 Mdot
.974 .49118 Mdot
.974 .49138 Mdot
.974 .49153 Mdot
.974 .4939 Mdot
.974 .494 Mdot
.974 .494 Mdot
.974 .49428 Mdot
.974 .49448 Mdot
.974 .49471 Mdot
.974 .49472 Mdot
.974 .49479 Mdot
.974 .49519 Mdot
.974 .49568 Mdot
.974 .4975 Mdot
.974 .499 Mdot
.974 .49941 Mdot
.974 .49976 Mdot
.974 .50151 Mdot
.974 .50181 Mdot
.974 .50193 Mdot
.974 .50267 Mdot
.974 .50276 Mdot
.974 .5049 Mdot
.974 .50531 Mdot
.974 .50575 Mdot
.974 .50605 Mdot
.974 .50647 Mdot
.974 .50657 Mdot
.974 .50669 Mdot
.974 .50733 Mdot
.974 .50741 Mdot
.974 .50763 Mdot
.974 .50781 Mdot
.974 .50861 Mdot
.974 .50864 Mdot
.974 .50872 Mdot
.974 .50937 Mdot
.974 .5096 Mdot
.974 .50966 Mdot
.974 .51047 Mdot
.974 .51058 Mdot
.974 .51115 Mdot
.974 .51123 Mdot
.974 .51134 Mdot
.974 .51138 Mdot
.974 .51154 Mdot
.974 .51212 Mdot
.974 .5125 Mdot
.974 .51303 Mdot
.974 .51366 Mdot
.974 .51405 Mdot
.974 .51421 Mdot
.974 .51478 Mdot
.974 .5149 Mdot
.974 .51506 Mdot
.974 .51558 Mdot
.974 .51573 Mdot
.974 .51585 Mdot
.974 .51696 Mdot
.974 .51744 Mdot
.974 .5187 Mdot
.974 .51891 Mdot
.974 .51896 Mdot
.974 .51912 Mdot
.974 .51941 Mdot
.974 .51958 Mdot
.974 .5201 Mdot
.974 .52044 Mdot
.974 .52223 Mdot
.974 .52378 Mdot
.974 .52416 Mdot
.974 .52478 Mdot
.974 .52478 Mdot
.974 .52631 Mdot
.974 .5267 Mdot
.974 .52836 Mdot
.974 .52839 Mdot
.974 .52962 Mdot
.974 .52996 Mdot
.974 .53011 Mdot
.974 .53026 Mdot
.974 .53034 Mdot
.974 .53058 Mdot
.974 .53064 Mdot
.974 .53104 Mdot
.974 .5315 Mdot
.974 .53154 Mdot
.974 .53154 Mdot
.974 .532 Mdot
.974 .53226 Mdot
.974 .53306 Mdot
.974 .53308 Mdot
.974 .53365 Mdot
.974 .53431 Mdot
.974 .53456 Mdot
.974 .53488 Mdot
.974 .53489 Mdot
.974 .53493 Mdot
.974 .5364 Mdot
.974 .53751 Mdot
.974 .53773 Mdot
.974 .53825 Mdot
.974 .53877 Mdot
.974 .53978 Mdot
.974 .54074 Mdot
.974 .54122 Mdot
.974 .54126 Mdot
.974 .54158 Mdot
.974 .54196 Mdot
.974 .54198 Mdot
.974 .54283 Mdot
.974 .54324 Mdot
.974 .54396 Mdot
.974 .54405 Mdot
.974 .54415 Mdot
.974 .54769 Mdot
.974 .54995 Mdot
.974 .55002 Mdot
.974 .55004 Mdot
.974 .55039 Mdot
.974 .5504 Mdot
.974 .55147 Mdot
.974 .55194 Mdot
.974 .55277 Mdot
.974 .55345 Mdot
.974 .55396 Mdot
.974 .55448 Mdot
.974 .5546 Mdot
.974 .55492 Mdot
.974 .55535 Mdot
.974 .55537 Mdot
.974 .55549 Mdot
.974 .55551 Mdot
.974 .55567 Mdot
.974 .55571 Mdot
.974 .55667 Mdot
.974 .55669 Mdot
.974 .55764 Mdot
.974 .55792 Mdot
.974 .55815 Mdot
.974 .55903 Mdot
.974 .55936 Mdot
.974 .55956 Mdot
.974 .55975 Mdot
.974 .56029 Mdot
.974 .56117 Mdot
.974 .56204 Mdot
.974 .56207 Mdot
.974 .56242 Mdot
.974 .56348 Mdot
.974 .56388 Mdot
.974 .56422 Mdot
.974 .56481 Mdot
.974 .56497 Mdot
.974 .56575 Mdot
.974 .56593 Mdot
.974 .56594 Mdot
.974 .56598 Mdot
.974 .56611 Mdot
.974 .56704 Mdot
.974 .56723 Mdot
.974 .56792 Mdot
.974 .56811 Mdot
.974 .56879 Mdot
.974 .56901 Mdot
.974 .56943 Mdot
.974 .56958 Mdot
.974 .57007 Mdot
.974 .57018 Mdot
.974 .57056 Mdot
.974 .57079 Mdot
.974 .572 Mdot
.974 .57226 Mdot
.974 .57254 Mdot
.974 .57271 Mdot
.974 .57278 Mdot
.974 .57322 Mdot
.974 .57335 Mdot
.974 .57336 Mdot
.974 .57527 Mdot
.974 .57537 Mdot
.974 .57604 Mdot
.974 .57646 Mdot
.974 .57768 Mdot
.974 .57863 Mdot
.974 .57886 Mdot
.974 .57888 Mdot
.974 .58009 Mdot
.974 .58141 Mdot
.974 .58297 Mdot
.974 .58378 Mdot
.974 .58407 Mdot
.974 .58469 Mdot
.974 .58588 Mdot
.974 .58632 Mdot
.974 .58644 Mdot
.974 .58649 Mdot
.974 .58728 Mdot
.974 .58753 Mdot
.974 .58768 Mdot
.974 .58877 Mdot
.976 .04355 Mdot
.976 .04521 Mdot
.976 .04567 Mdot
.976 .04619 Mdot
.976 .04675 Mdot
.976 .05105 Mdot
.976 .05154 Mdot
.976 .05281 Mdot
.976 .05506 Mdot
.976 .05858 Mdot
.976 .06047 Mdot
.976 .06117 Mdot
.976 .06144 Mdot
.976 .0617 Mdot
.976 .06219 Mdot
.976 .06558 Mdot
.976 .06588 Mdot
.976 .06759 Mdot
.976 .06771 Mdot
.976 .06791 Mdot
.976 .06856 Mdot
.976 .07077 Mdot
.976 .07099 Mdot
.976 .07296 Mdot
.976 .07329 Mdot
.976 .07342 Mdot
.976 .07349 Mdot
.976 .07366 Mdot
.976 .07418 Mdot
.976 .07423 Mdot
.976 .07448 Mdot
.976 .07514 Mdot
.976 .07616 Mdot
.976 .07627 Mdot
.976 .0766 Mdot
.976 .07674 Mdot
.976 .07711 Mdot
.976 .07725 Mdot
.976 .07751 Mdot
.976 .07816 Mdot
.976 .07859 Mdot
.976 .07885 Mdot
.976 .08008 Mdot
.976 .08305 Mdot
.976 .08428 Mdot
.976 .08436 Mdot
.976 .08563 Mdot
.976 .08564 Mdot
.976 .08657 Mdot
.976 .0866 Mdot
.976 .08764 Mdot
.976 .08792 Mdot
.976 .08809 Mdot
.976 .08909 Mdot
.976 .08994 Mdot
.976 .0924 Mdot
.976 .09346 Mdot
.976 .09426 Mdot
.976 .09428 Mdot
.976 .09434 Mdot
.976 .09453 Mdot
.976 .09717 Mdot
.976 .09839 Mdot
.976 .10035 Mdot
.976 .10099 Mdot
.976 .10285 Mdot
.976 .10347 Mdot
.976 .10393 Mdot
.976 .10403 Mdot
.976 .10487 Mdot
.976 .1054 Mdot
.976 .10593 Mdot
.976 .10642 Mdot
.976 .10651 Mdot
.976 .10739 Mdot
.976 .1075 Mdot
.976 .10753 Mdot
.976 .10811 Mdot
.976 .10827 Mdot
.976 .10993 Mdot
.976 .11009 Mdot
.976 .11149 Mdot
.976 .11188 Mdot
.976 .11283 Mdot
.976 .11348 Mdot
.976 .11401 Mdot
.976 .11431 Mdot
.976 .11459 Mdot
.976 .11484 Mdot
.976 .11555 Mdot
.976 .11625 Mdot
.976 .11715 Mdot
.976 .11731 Mdot
.976 .11794 Mdot
.976 .11816 Mdot
.976 .11856 Mdot
.976 .11983 Mdot
.976 .12013 Mdot
.976 .12083 Mdot
.976 .12108 Mdot
.976 .12129 Mdot
.976 .1214 Mdot
.976 .12186 Mdot
.976 .12265 Mdot
.976 .12304 Mdot
.976 .12414 Mdot
.976 .12433 Mdot
.976 .12457 Mdot
.976 .12505 Mdot
.976 .12671 Mdot
.976 .12756 Mdot
.976 .12775 Mdot
.976 .12806 Mdot
.976 .12841 Mdot
.976 .12869 Mdot
.976 .12879 Mdot
.976 .12906 Mdot
.976 .12932 Mdot
.976 .12944 Mdot
.976 .12977 Mdot
.976 .13078 Mdot
.976 .13089 Mdot
.976 .13137 Mdot
.976 .1315 Mdot
.976 .13243 Mdot
.976 .13253 Mdot
.976 .13267 Mdot
.976 .13315 Mdot
.976 .13465 Mdot
.976 .13475 Mdot
.976 .13488 Mdot
.976 .13552 Mdot
.976 .13578 Mdot
.976 .13651 Mdot
.976 .13653 Mdot
.976 .13671 Mdot
.976 .13678 Mdot
.976 .13704 Mdot
.976 .1373 Mdot
.976 .13856 Mdot
.976 .1394 Mdot
.976 .13941 Mdot
.976 .13992 Mdot
.976 .14009 Mdot
.976 .14015 Mdot
.976 .14231 Mdot
.976 .14357 Mdot
.976 .14438 Mdot
.976 .14462 Mdot
.976 .14746 Mdot
.976 .1481 Mdot
.976 .14942 Mdot
.976 .15042 Mdot
.976 .1505 Mdot
.976 .15067 Mdot
.976 .15077 Mdot
.976 .15099 Mdot
.976 .1517 Mdot
.976 .15278 Mdot
.976 .15315 Mdot
.976 .15317 Mdot
.976 .15422 Mdot
.976 .15438 Mdot
.976 .15498 Mdot
.976 .15504 Mdot
.976 .15514 Mdot
.976 .15636 Mdot
.976 .15648 Mdot
.976 .15699 Mdot
.976 .15707 Mdot
.976 .15755 Mdot
.976 .15762 Mdot
.976 .15795 Mdot
.976 .15846 Mdot
.976 .15989 Mdot
.976 .16155 Mdot
.976 .16162 Mdot
.976 .16443 Mdot
.976 .16635 Mdot
.976 .16836 Mdot
.976 .16843 Mdot
.976 .1685 Mdot
.976 .16999 Mdot
.976 .17002 Mdot
.976 .17015 Mdot
.976 .17046 Mdot
.976 .17051 Mdot
.976 .17091 Mdot
.976 .17256 Mdot
.976 .17424 Mdot
.976 .1754 Mdot
.976 .17567 Mdot
.976 .17717 Mdot
.976 .17736 Mdot
.976 .17804 Mdot
.976 .17897 Mdot
.976 .17898 Mdot
.976 .17944 Mdot
.976 .18023 Mdot
.976 .18187 Mdot
.976 .18312 Mdot
.976 .18334 Mdot
.976 .18372 Mdot
.976 .18675 Mdot
.976 .18796 Mdot
.976 .18812 Mdot
.976 .18879 Mdot
.976 .18886 Mdot
.976 .18906 Mdot
.976 .19066 Mdot
.976 .1907 Mdot
.976 .19174 Mdot
.976 .19213 Mdot
.976 .19277 Mdot
.976 .19298 Mdot
.976 .19308 Mdot
.976 .19369 Mdot
.976 .19373 Mdot
.976 .19391 Mdot
.976 .19562 Mdot
.976 .19583 Mdot
.976 .19589 Mdot
.976 .19702 Mdot
.976 .19733 Mdot
.976 .19796 Mdot
.976 .19913 Mdot
.976 .19994 Mdot
.976 .2001 Mdot
.976 .20057 Mdot
.976 .2007 Mdot
.976 .20089 Mdot
.976 .20182 Mdot
.976 .20188 Mdot
.976 .20362 Mdot
.976 .20438 Mdot
.976 .20483 Mdot
.976 .20539 Mdot
.976 .20623 Mdot
.976 .20694 Mdot
.976 .20751 Mdot
.976 .20796 Mdot
.976 .20801 Mdot
.976 .20815 Mdot
.976 .20854 Mdot
.976 .20912 Mdot
.976 .20926 Mdot
.976 .20933 Mdot
.976 .20968 Mdot
.976 .21015 Mdot
.976 .21081 Mdot
.976 .21103 Mdot
.976 .21155 Mdot
.976 .21291 Mdot
.976 .21307 Mdot
.976 .21362 Mdot
.976 .21467 Mdot
.976 .21497 Mdot
.976 .21514 Mdot
.976 .2162 Mdot
.976 .21663 Mdot
.976 .21683 Mdot
.976 .21727 Mdot
.976 .21742 Mdot
.976 .21762 Mdot
.976 .21914 Mdot
.976 .21958 Mdot
.976 .21989 Mdot
.976 .22048 Mdot
.976 .22185 Mdot
.976 .22234 Mdot
.976 .22275 Mdot
.976 .22296 Mdot
.976 .22308 Mdot
.976 .22384 Mdot
.976 .22386 Mdot
.976 .2254 Mdot
.976 .22597 Mdot
.976 .22617 Mdot
.976 .22703 Mdot
.976 .22733 Mdot
.976 .2283 Mdot
.976 .22868 Mdot
.976 .22915 Mdot
.976 .22932 Mdot
.976 .22982 Mdot
.976 .23009 Mdot
.976 .23012 Mdot
.976 .23071 Mdot
.976 .23332 Mdot
.976 .23339 Mdot
.976 .23384 Mdot
.976 .23413 Mdot
.976 .23499 Mdot
.976 .23505 Mdot
.976 .23511 Mdot
.976 .23537 Mdot
.976 .23567 Mdot
.976 .23596 Mdot
.976 .23596 Mdot
.976 .23641 Mdot
.976 .23664 Mdot
.976 .2372 Mdot
.976 .23739 Mdot
.976 .23773 Mdot
.976 .23791 Mdot
.976 .23793 Mdot
.976 .23842 Mdot
.976 .23866 Mdot
.976 .2389 Mdot
.976 .23893 Mdot
.976 .23923 Mdot
.976 .2393 Mdot
.976 .24128 Mdot
.976 .24149 Mdot
.976 .24242 Mdot
.976 .24267 Mdot
.976 .24268 Mdot
.976 .2443 Mdot
.976 .24449 Mdot
.976 .24469 Mdot
.976 .24489 Mdot
.976 .24496 Mdot
.976 .24497 Mdot
.976 .24498 Mdot
.976 .24518 Mdot
.976 .2459 Mdot
.976 .24724 Mdot
.976 .24753 Mdot
.976 .24883 Mdot
.976 .24903 Mdot
.976 .24927 Mdot
.976 .24957 Mdot
.976 .24985 Mdot
.976 .25033 Mdot
.976 .25044 Mdot
.976 .25052 Mdot
.976 .25103 Mdot
.976 .25115 Mdot
.976 .25241 Mdot
.976 .25245 Mdot
.976 .25247 Mdot
.976 .25251 Mdot
.976 .25285 Mdot
.976 .25299 Mdot
.976 .25348 Mdot
.976 .254 Mdot
.976 .25456 Mdot
.976 .25457 Mdot
.976 .25509 Mdot
.976 .25647 Mdot
.976 .25652 Mdot
.976 .25654 Mdot
.976 .2581 Mdot
.976 .25811 Mdot
.976 .25842 Mdot
.976 .25896 Mdot
.976 .25911 Mdot
.976 .25944 Mdot
.976 .25956 Mdot
.976 .26026 Mdot
.976 .26042 Mdot
.976 .2605 Mdot
.976 .26063 Mdot
.976 .26379 Mdot
.976 .2639 Mdot
.976 .26543 Mdot
.976 .26549 Mdot
.976 .26587 Mdot
.976 .26589 Mdot
.976 .26622 Mdot
.976 .26623 Mdot
.976 .26783 Mdot
.976 .26785 Mdot
.976 .26814 Mdot
.976 .2683 Mdot
.976 .26855 Mdot
.976 .26998 Mdot
.976 .27016 Mdot
.976 .27039 Mdot
.976 .27144 Mdot
.976 .2726 Mdot
.976 .27351 Mdot
.976 .27384 Mdot
.976 .27427 Mdot
.976 .27431 Mdot
.976 .27508 Mdot
.976 .27663 Mdot
.976 .27766 Mdot
.976 .27922 Mdot
.976 .27946 Mdot
.976 .27961 Mdot
.976 .27974 Mdot
.976 .27978 Mdot
.976 .2801 Mdot
.976 .2803 Mdot
.976 .28034 Mdot
.976 .28071 Mdot
.976 .28124 Mdot
.976 .28133 Mdot
.976 .28211 Mdot
.976 .28292 Mdot
.976 .28423 Mdot
.976 .28485 Mdot
.976 .28493 Mdot
.976 .28498 Mdot
.976 .28545 Mdot
.976 .28606 Mdot
.976 .28704 Mdot
.976 .28733 Mdot
.976 .28818 Mdot
.976 .28852 Mdot
.976 .28862 Mdot
.976 .28883 Mdot
.976 .28895 Mdot
.976 .28898 Mdot
.976 .28903 Mdot
.976 .28928 Mdot
.976 .29003 Mdot
.976 .29007 Mdot
.976 .29067 Mdot
.976 .29081 Mdot
.976 .2912 Mdot
.976 .29145 Mdot
.976 .29155 Mdot
.976 .29196 Mdot
.976 .29244 Mdot
.976 .29259 Mdot
.976 .29354 Mdot
.976 .29366 Mdot
.976 .29431 Mdot
.976 .29531 Mdot
.976 .29605 Mdot
.976 .29721 Mdot
.976 .29769 Mdot
.976 .29774 Mdot
.976 .29809 Mdot
.976 .29834 Mdot
.976 .29869 Mdot
.976 .29902 Mdot
.976 .30071 Mdot
.976 .30134 Mdot
.976 .30148 Mdot
.976 .30166 Mdot
.976 .30224 Mdot
.976 .30299 Mdot
.976 .30304 Mdot
.976 .30307 Mdot
.976 .30469 Mdot
.976 .30695 Mdot
.976 .31001 Mdot
.976 .31044 Mdot
.976 .31057 Mdot
.976 .3107 Mdot
.976 .31085 Mdot
.976 .31198 Mdot
.976 .31211 Mdot
.976 .31303 Mdot
.976 .31396 Mdot
.976 .31445 Mdot
.976 .31464 Mdot
.976 .31477 Mdot
.976 .3149 Mdot
.976 .31579 Mdot
.976 .31587 Mdot
.976 .31658 Mdot
.976 .31782 Mdot
.976 .31785 Mdot
.976 .31787 Mdot
.976 .31813 Mdot
.976 .3186 Mdot
.976 .31872 Mdot
.976 .31882 Mdot
.976 .31892 Mdot
.976 .31909 Mdot
.976 .31921 Mdot
.976 .31928 Mdot
.976 .3196 Mdot
.976 .32072 Mdot
.976 .32158 Mdot
.976 .32283 Mdot
.976 .32332 Mdot
.976 .32332 Mdot
.976 .32339 Mdot
.976 .3244 Mdot
.976 .32557 Mdot
.976 .3261 Mdot
.976 .32653 Mdot
.976 .32679 Mdot
.976 .327 Mdot
.976 .32747 Mdot
.976 .32836 Mdot
.976 .32891 Mdot
.976 .32909 Mdot
.976 .33029 Mdot
.976 .3314 Mdot
.976 .33183 Mdot
.976 .33211 Mdot
.976 .33219 Mdot
.976 .33238 Mdot
.976 .33309 Mdot
.976 .33336 Mdot
.976 .33353 Mdot
.976 .33535 Mdot
.976 .33536 Mdot
.976 .33626 Mdot
.976 .33654 Mdot
.976 .3378 Mdot
.976 .33839 Mdot
.976 .341 Mdot
.976 .3428 Mdot
.976 .34332 Mdot
.976 .34343 Mdot
.976 .34387 Mdot
.976 .34461 Mdot
.976 .34555 Mdot
.976 .34567 Mdot
.976 .3467 Mdot
.976 .34813 Mdot
.976 .34862 Mdot
.976 .34925 Mdot
.976 .35054 Mdot
.976 .35105 Mdot
.976 .35234 Mdot
.976 .35248 Mdot
.976 .35289 Mdot
.976 .35321 Mdot
.976 .3545 Mdot
.976 .35465 Mdot
.976 .35504 Mdot
.976 .35569 Mdot
.976 .35609 Mdot
.976 .35621 Mdot
.976 .35713 Mdot
.976 .35733 Mdot
.976 .35789 Mdot
.976 .35816 Mdot
.976 .35824 Mdot
.976 .36003 Mdot
.976 .36027 Mdot
.976 .36051 Mdot
.976 .36063 Mdot
.976 .36103 Mdot
.976 .36137 Mdot
.976 .36227 Mdot
.976 .3627 Mdot
.976 .36287 Mdot
.976 .36347 Mdot
.976 .36354 Mdot
.976 .36408 Mdot
.976 .36415 Mdot
.976 .36428 Mdot
.976 .36449 Mdot
.976 .36539 Mdot
.976 .36553 Mdot
.976 .3659 Mdot
.976 .36784 Mdot
.976 .36826 Mdot
.976 .36836 Mdot
.976 .36845 Mdot
.976 .36944 Mdot
.976 .36948 Mdot
.976 .37057 Mdot
.976 .37118 Mdot
.976 .37192 Mdot
.976 .372 Mdot
.976 .37239 Mdot
.976 .37242 Mdot
.976 .37283 Mdot
.976 .37334 Mdot
.976 .37366 Mdot
.976 .3747 Mdot
.976 .37487 Mdot
.976 .37521 Mdot
.976 .37628 Mdot
.976 .37658 Mdot
.976 .37688 Mdot
.976 .37706 Mdot
.976 .3775 Mdot
.976 .37775 Mdot
.976 .3781 Mdot
.976 .37812 Mdot
.976 .37854 Mdot
.976 .37994 Mdot
.976 .38006 Mdot
.976 .38111 Mdot
.976 .38228 Mdot
.976 .38233 Mdot
.976 .38236 Mdot
.976 .38237 Mdot
.976 .38345 Mdot
.976 .38453 Mdot
.976 .38495 Mdot
.976 .38574 Mdot
.976 .38581 Mdot
.976 .3869 Mdot
.976 .38739 Mdot
.976 .38855 Mdot
.976 .38995 Mdot
.976 .39105 Mdot
.976 .39193 Mdot
.976 .39204 Mdot
.976 .39231 Mdot
.976 .39251 Mdot
.976 .39307 Mdot
.976 .39319 Mdot
.976 .39397 Mdot
.976 .39418 Mdot
.976 .39448 Mdot
.976 .39451 Mdot
.976 .39461 Mdot
.976 .39528 Mdot
.976 .39619 Mdot
.976 .39621 Mdot
.976 .39656 Mdot
.976 .39696 Mdot
.976 .39749 Mdot
.976 .39781 Mdot
.976 .39793 Mdot
.976 .3986 Mdot
.976 .39892 Mdot
.976 .39893 Mdot
.976 .39893 Mdot
.976 .40159 Mdot
.976 .40266 Mdot
.976 .40299 Mdot
.976 .40328 Mdot
.976 .40328 Mdot
.976 .40442 Mdot
.976 .40503 Mdot
.976 .40562 Mdot
.976 .40562 Mdot
.976 .40594 Mdot
.976 .40785 Mdot
.976 .40785 Mdot
.976 .40801 Mdot
.976 .40842 Mdot
.976 .40885 Mdot
.976 .40906 Mdot
.976 .40925 Mdot
.976 .41011 Mdot
.976 .41039 Mdot
.976 .41078 Mdot
.976 .41114 Mdot
.976 .41376 Mdot
.976 .4146 Mdot
.976 .41523 Mdot
.976 .41633 Mdot
.976 .41634 Mdot
.976 .41635 Mdot
.976 .41638 Mdot
.976 .41698 Mdot
.976 .41829 Mdot
.976 .41852 Mdot
.976 .41905 Mdot
.976 .41914 Mdot
.976 .42 Mdot
.976 .42017 Mdot
.976 .42079 Mdot
.976 .42096 Mdot
.976 .42122 Mdot
.976 .42144 Mdot
.976 .42164 Mdot
.976 .42168 Mdot
.976 .42293 Mdot
.976 .42296 Mdot
.976 .42346 Mdot
.976 .42477 Mdot
.976 .42496 Mdot
.976 .42503 Mdot
.976 .4256 Mdot
.976 .42597 Mdot
.976 .42601 Mdot
.976 .42709 Mdot
.976 .42747 Mdot
.976 .42753 Mdot
.976 .42778 Mdot
.976 .42887 Mdot
.976 .42916 Mdot
.976 .42926 Mdot
.976 .42973 Mdot
.976 .42979 Mdot
.976 .43 Mdot
.976 .43164 Mdot
.976 .43172 Mdot
.976 .43237 Mdot
.976 .4333 Mdot
.976 .43362 Mdot
.976 .43387 Mdot
.976 .4346 Mdot
.976 .43513 Mdot
.976 .43519 Mdot
.976 .43634 Mdot
.976 .4366 Mdot
.976 .43886 Mdot
.976 .43981 Mdot
.976 .44144 Mdot
.976 .44158 Mdot
.976 .44194 Mdot
.976 .44208 Mdot
.976 .44244 Mdot
.976 .44301 Mdot
.976 .44362 Mdot
.976 .44445 Mdot
.976 .4447 Mdot
.976 .4448 Mdot
.976 .44493 Mdot
.976 .44543 Mdot
.976 .44603 Mdot
.976 .44655 Mdot
.976 .44658 Mdot
.976 .44658 Mdot
.976 .44747 Mdot
.976 .44791 Mdot
.976 .44865 Mdot
.976 .44869 Mdot
.976 .44875 Mdot
.976 .44883 Mdot
.976 .449 Mdot
.976 .44938 Mdot
.976 .45004 Mdot
.976 .4504 Mdot
.976 .45044 Mdot
.976 .45112 Mdot
.976 .45138 Mdot
.976 .45185 Mdot
.976 .45232 Mdot
.976 .45239 Mdot
.976 .45297 Mdot
.976 .45311 Mdot
.976 .45318 Mdot
.976 .4534 Mdot
.976 .45613 Mdot
.976 .45695 Mdot
.976 .45697 Mdot
.976 .457 Mdot
.976 .45738 Mdot
.976 .45768 Mdot
.976 .45816 Mdot
.976 .45903 Mdot
.976 .4592 Mdot
.976 .45938 Mdot
.976 .45969 Mdot
.976 .45971 Mdot
.976 .45996 Mdot
.976 .46055 Mdot
.976 .46265 Mdot
.976 .46286 Mdot
.976 .46323 Mdot
.976 .46331 Mdot
.976 .46362 Mdot
.976 .46364 Mdot
.976 .46402 Mdot
.976 .46415 Mdot
.976 .46417 Mdot
.976 .46419 Mdot
.976 .46458 Mdot
.976 .46567 Mdot
.976 .46598 Mdot
.976 .46629 Mdot
.976 .46728 Mdot
.976 .46809 Mdot
.976 .46814 Mdot
.976 .4686 Mdot
.976 .46891 Mdot
.976 .46905 Mdot
.976 .46917 Mdot
.976 .4705 Mdot
.976 .47169 Mdot
.976 .47171 Mdot
.976 .4721 Mdot
.976 .47257 Mdot
.976 .47316 Mdot
.976 .4737 Mdot
.976 .47381 Mdot
.976 .47391 Mdot
.976 .47464 Mdot
.976 .47485 Mdot
.976 .475 Mdot
.976 .47583 Mdot
.976 .476 Mdot
.976 .47601 Mdot
.976 .47621 Mdot
.976 .47624 Mdot
.976 .47702 Mdot
.976 .4787 Mdot
.976 .47877 Mdot
.976 .47881 Mdot
.976 .47888 Mdot
.976 .47955 Mdot
.976 .47983 Mdot
.976 .48079 Mdot
.976 .4808 Mdot
.976 .48154 Mdot
.976 .4818 Mdot
.976 .48181 Mdot
.976 .48289 Mdot
.976 .48291 Mdot
.976 .48355 Mdot
.976 .48392 Mdot
.976 .48397 Mdot
.976 .48422 Mdot
.976 .48436 Mdot
.976 .48541 Mdot
.976 .48556 Mdot
.976 .48661 Mdot
.976 .48672 Mdot
.976 .48673 Mdot
.976 .48676 Mdot
.976 .48707 Mdot
.976 .48789 Mdot
.976 .48966 Mdot
.976 .48981 Mdot
.976 .48983 Mdot
.976 .49032 Mdot
.976 .49043 Mdot
.976 .4911 Mdot
.976 .49134 Mdot
.976 .49148 Mdot
.976 .49177 Mdot
.976 .4918 Mdot
.976 .49227 Mdot
.976 .49242 Mdot
.976 .49265 Mdot
.976 .49402 Mdot
.976 .49433 Mdot
.976 .49448 Mdot
.976 .49474 Mdot
.976 .49576 Mdot
.976 .49591 Mdot
.976 .49645 Mdot
.976 .49754 Mdot
.976 .49793 Mdot
.976 .49973 Mdot
.976 .49995 Mdot
.976 .50073 Mdot
.976 .50091 Mdot
.976 .50113 Mdot
.976 .502 Mdot
.976 .50278 Mdot
.976 .50306 Mdot
.976 .5041 Mdot
.976 .50422 Mdot
.976 .50498 Mdot
.976 .50501 Mdot
.976 .50558 Mdot
.976 .50565 Mdot
.976 .50568 Mdot
.976 .5062 Mdot
.976 .507 Mdot
.976 .50728 Mdot
.976 .5088 Mdot
.976 .50883 Mdot
.976 .5094 Mdot
.976 .50971 Mdot
.976 .50979 Mdot
.976 .5102 Mdot
.976 .5108 Mdot
.976 .51299 Mdot
.976 .5133 Mdot
.976 .51335 Mdot
.976 .51379 Mdot
.976 .51454 Mdot
.976 .5155 Mdot
.976 .51584 Mdot
.976 .5181 Mdot
.976 .51829 Mdot
.976 .51989 Mdot
.976 .52029 Mdot
.976 .52053 Mdot
.976 .52053 Mdot
.976 .52136 Mdot
.976 .52145 Mdot
.976 .52236 Mdot
.976 .52295 Mdot
.976 .52381 Mdot
.976 .52466 Mdot
.976 .52489 Mdot
.976 .52589 Mdot
.976 .52596 Mdot
.976 .52798 Mdot
.976 .52942 Mdot
.976 .53104 Mdot
.976 .5315 Mdot
.976 .53179 Mdot
.976 .53205 Mdot
.976 .53212 Mdot
.976 .53274 Mdot
.976 .53313 Mdot
.976 .53321 Mdot
.976 .53395 Mdot
.976 .5345 Mdot
.976 .53498 Mdot
.976 .53516 Mdot
.976 .53567 Mdot
.976 .53667 Mdot
.976 .53813 Mdot
.976 .53825 Mdot
.976 .53867 Mdot
.976 .54042 Mdot
.976 .54045 Mdot
.976 .5408 Mdot
.976 .54201 Mdot
.976 .54218 Mdot
.976 .54227 Mdot
.976 .54318 Mdot
.976 .544 Mdot
.976 .54432 Mdot
.976 .54437 Mdot
.976 .54485 Mdot
.976 .54624 Mdot
.976 .54629 Mdot
.976 .54661 Mdot
.976 .54677 Mdot
.976 .54687 Mdot
.976 .54731 Mdot
.976 .54815 Mdot
.976 .54852 Mdot
.976 .54918 Mdot
.976 .54938 Mdot
.976 .54979 Mdot
.976 .55002 Mdot
.976 .55008 Mdot
.976 .55019 Mdot
.976 .55031 Mdot
.976 .55067 Mdot
.976 .55212 Mdot
.976 .5522 Mdot
.976 .55266 Mdot
.976 .55302 Mdot
.976 .55339 Mdot
.976 .55366 Mdot
.976 .55408 Mdot
.976 .55442 Mdot
.976 .5549 Mdot
.976 .5551 Mdot
.976 .55582 Mdot
.976 .5559 Mdot
.976 .55675 Mdot
.976 .55683 Mdot
.976 .55713 Mdot
.976 .55714 Mdot
.976 .55765 Mdot
.976 .55849 Mdot
.976 .55897 Mdot
.976 .55921 Mdot
.976 .55953 Mdot
.976 .56048 Mdot
.976 .56181 Mdot
.976 .56243 Mdot
.976 .56379 Mdot
.976 .56388 Mdot
.976 .56392 Mdot
.976 .56393 Mdot
.976 .56488 Mdot
.976 .56614 Mdot
.976 .56709 Mdot
.976 .56717 Mdot
.976 .56732 Mdot
.976 .56786 Mdot
.976 .56835 Mdot
.976 .569 Mdot
.976 .56904 Mdot
.976 .56967 Mdot
.976 .57119 Mdot
.976 .57182 Mdot
.976 .57195 Mdot
.976 .57217 Mdot
.976 .57251 Mdot
.976 .57271 Mdot
.976 .5729 Mdot
.976 .57297 Mdot
.976 .57314 Mdot
.976 .57406 Mdot
.976 .57422 Mdot
.976 .57448 Mdot
.976 .57457 Mdot
.976 .5746 Mdot
.976 .57467 Mdot
.976 .57484 Mdot
.976 .57596 Mdot
.976 .57709 Mdot
.976 .57742 Mdot
.976 .57753 Mdot
.976 .57759 Mdot
.976 .57847 Mdot
.976 .57862 Mdot
.976 .58036 Mdot
.976 .58061 Mdot
.976 .58074 Mdot
.976 .58088 Mdot
.976 .58124 Mdot
.976 .5822 Mdot
.976 .58401 Mdot
.976 .58516 Mdot
.976 .58581 Mdot
.976 .58606 Mdot
.976 .58827 Mdot
.976 .58855 Mdot
.976 .58882 Mdot
.976 .58906 Mdot
.976 .58991 Mdot
.978 .04148 Mdot
.978 .04151 Mdot
.978 .04166 Mdot
.978 .04242 Mdot
.978 .04276 Mdot
.978 .04384 Mdot
.978 .04662 Mdot
.978 .04752 Mdot
.978 .04781 Mdot
.978 .04803 Mdot
.978 .04815 Mdot
.978 .05548 Mdot
.978 .0555 Mdot
.978 .05563 Mdot
.978 .05672 Mdot
.978 .05828 Mdot
.978 .05864 Mdot
.978 .06006 Mdot
.978 .06188 Mdot
.978 .0632 Mdot
.978 .06396 Mdot
.978 .06397 Mdot
.978 .0641 Mdot
.978 .06511 Mdot
.978 .06583 Mdot
.978 .06607 Mdot
.978 .06631 Mdot
.978 .06699 Mdot
.978 .06708 Mdot
.978 .06713 Mdot
.978 .06742 Mdot
.978 .06839 Mdot
.978 .06891 Mdot
.978 .06956 Mdot
.978 .06962 Mdot
.978 .06964 Mdot
.978 .07105 Mdot
.978 .0711 Mdot
.978 .07169 Mdot
.978 .07335 Mdot
.978 .07563 Mdot
.978 .07646 Mdot
.978 .07712 Mdot
.978 .0784 Mdot
.978 .07852 Mdot
.978 .07862 Mdot
.978 .07889 Mdot
.978 .07922 Mdot
.978 .07928 Mdot
.978 .07944 Mdot
.978 .07987 Mdot
.978 .08011 Mdot
.978 .08126 Mdot
.978 .0821 Mdot
.978 .08223 Mdot
.978 .08289 Mdot
.978 .08304 Mdot
.978 .08429 Mdot
.978 .08491 Mdot
.978 .08598 Mdot
.978 .08611 Mdot
.978 .08732 Mdot
.978 .0885 Mdot
.978 .08868 Mdot
.978 .09055 Mdot
.978 .09068 Mdot
.978 .09127 Mdot
.978 .09287 Mdot
.978 .09306 Mdot
.978 .09445 Mdot
.978 .09449 Mdot
.978 .09475 Mdot
.978 .09628 Mdot
.978 .09689 Mdot
.978 .09857 Mdot
.978 .09992 Mdot
.978 .10063 Mdot
.978 .10098 Mdot
.978 .10183 Mdot
.978 .10277 Mdot
.978 .10341 Mdot
.978 .10408 Mdot
.978 .10436 Mdot
.978 .10541 Mdot
.978 .10553 Mdot
.978 .10596 Mdot
.978 .10646 Mdot
.978 .10697 Mdot
.978 .10955 Mdot
.978 .1098 Mdot
.978 .1101 Mdot
.978 .11037 Mdot
.978 .11062 Mdot
.978 .11103 Mdot
.978 .11105 Mdot
.978 .11132 Mdot
.978 .11329 Mdot
.978 .11431 Mdot
.978 .11469 Mdot
.978 .11475 Mdot
.978 .11492 Mdot
.978 .11516 Mdot
.978 .11564 Mdot
.978 .11678 Mdot
.978 .11697 Mdot
.978 .11713 Mdot
.978 .11719 Mdot
.978 .11724 Mdot
.978 .11781 Mdot
.978 .11791 Mdot
.978 .11898 Mdot
.978 .1197 Mdot
.978 .1198 Mdot
.978 .12073 Mdot
.978 .12176 Mdot
.978 .122 Mdot
.978 .1221 Mdot
.978 .12214 Mdot
.978 .12342 Mdot
.978 .12357 Mdot
.978 .12458 Mdot
.978 .12491 Mdot
.978 .125 Mdot
.978 .12551 Mdot
.978 .12615 Mdot
.978 .12626 Mdot
.978 .12689 Mdot
.978 .12941 Mdot
.978 .13287 Mdot
.978 .13355 Mdot
.978 .13386 Mdot
.978 .13387 Mdot
.978 .13548 Mdot
.978 .13586 Mdot
.978 .13654 Mdot
.978 .13678 Mdot
.978 .13806 Mdot
.978 .13858 Mdot
.978 .1389 Mdot
.978 .13918 Mdot
.978 .13929 Mdot
.978 .13952 Mdot
.978 .13971 Mdot
.978 .14024 Mdot
.978 .14088 Mdot
.978 .14101 Mdot
.978 .14124 Mdot
.978 .14132 Mdot
.978 .14216 Mdot
.978 .14263 Mdot
.978 .14484 Mdot
.978 .14488 Mdot
.978 .14581 Mdot
.978 .14652 Mdot
.978 .14678 Mdot
.978 .14807 Mdot
.978 .14835 Mdot
.978 .1503 Mdot
.978 .1508 Mdot
.978 .1514 Mdot
.978 .15201 Mdot
.978 .15299 Mdot
.978 .15401 Mdot
.978 .15411 Mdot
.978 .15424 Mdot
.978 .15437 Mdot
.978 .15613 Mdot
.978 .15617 Mdot
.978 .15672 Mdot
.978 .15697 Mdot
.978 .15877 Mdot
.978 .15903 Mdot
.978 .15939 Mdot
.978 .15991 Mdot
.978 .16039 Mdot
.978 .16138 Mdot
.978 .16305 Mdot
.978 .1633 Mdot
.978 .16445 Mdot
.978 .16502 Mdot
.978 .16532 Mdot
.978 .16583 Mdot
.978 .16658 Mdot
.978 .16758 Mdot
.978 .16795 Mdot
.978 .16861 Mdot
.978 .16896 Mdot
.978 .16903 Mdot
.978 .16912 Mdot
.978 .17067 Mdot
.978 .17075 Mdot
.978 .17076 Mdot
.978 .17126 Mdot
.978 .17143 Mdot
.978 .17199 Mdot
.978 .17226 Mdot
.978 .17334 Mdot
.978 .1739 Mdot
.978 .17425 Mdot
.978 .17427 Mdot
.978 .17544 Mdot
.978 .17873 Mdot
.978 .17876 Mdot
.978 .1804 Mdot
.978 .18103 Mdot
.978 .18138 Mdot
.978 .18232 Mdot
.978 .18276 Mdot
.978 .18345 Mdot
.978 .18493 Mdot
.978 .1851 Mdot
.978 .18535 Mdot
.978 .186 Mdot
.978 .18664 Mdot
.978 .18694 Mdot
.978 .18762 Mdot
.978 .18819 Mdot
.978 .18845 Mdot
.978 .18951 Mdot
.978 .19006 Mdot
.978 .1919 Mdot
.978 .19212 Mdot
.978 .19235 Mdot
.978 .1932 Mdot
.978 .19335 Mdot
.978 .19417 Mdot
.978 .19461 Mdot
.978 .19491 Mdot
.978 .19517 Mdot
.978 .1969 Mdot
.978 .19705 Mdot
.978 .19813 Mdot
.978 .19894 Mdot
.978 .19976 Mdot
.978 .20021 Mdot
.978 .20039 Mdot
.978 .20071 Mdot
.978 .20128 Mdot
.978 .20181 Mdot
.978 .20209 Mdot
.978 .20231 Mdot
.978 .20311 Mdot
.978 .20316 Mdot
.978 .20367 Mdot
.978 .20549 Mdot
.978 .20753 Mdot
.978 .20893 Mdot
.978 .20953 Mdot
.978 .20976 Mdot
.978 .20998 Mdot
.978 .21026 Mdot
.978 .21038 Mdot
.978 .21071 Mdot
.978 .21118 Mdot
.978 .2114 Mdot
.978 .21145 Mdot
.978 .21145 Mdot
.978 .21166 Mdot
.978 .21212 Mdot
.978 .21402 Mdot
.978 .21435 Mdot
.978 .21472 Mdot
.978 .21492 Mdot
.978 .21504 Mdot
.978 .21516 Mdot
.978 .21526 Mdot
.978 .21591 Mdot
.978 .21637 Mdot
.978 .21656 Mdot
.978 .21699 Mdot
.978 .21745 Mdot
.978 .21865 Mdot
.978 .21957 Mdot
.978 .22006 Mdot
.978 .22026 Mdot
.978 .22029 Mdot
.978 .22126 Mdot
.978 .22182 Mdot
.978 .22207 Mdot
.978 .2222 Mdot
.978 .22268 Mdot
.978 .22352 Mdot
.978 .22371 Mdot
.978 .2241 Mdot
.978 .22429 Mdot
.978 .22449 Mdot
.978 .22456 Mdot
.978 .22476 Mdot
.978 .22484 Mdot
.978 .22602 Mdot
.978 .22645 Mdot
.978 .22722 Mdot
.978 .22735 Mdot
.978 .22763 Mdot
.978 .22832 Mdot
.978 .22934 Mdot
.978 .2296 Mdot
.978 .2302 Mdot
.978 .23026 Mdot
.978 .23042 Mdot
.978 .23143 Mdot
.978 .23269 Mdot
.978 .23289 Mdot
.978 .2333 Mdot
.978 .23354 Mdot
.978 .23412 Mdot
.978 .2347 Mdot
.978 .23501 Mdot
.978 .23642 Mdot
.978 .23721 Mdot
.978 .23746 Mdot
.978 .23879 Mdot
.978 .23905 Mdot
.978 .23914 Mdot
.978 .23933 Mdot
.978 .24086 Mdot
.978 .24166 Mdot
.978 .24172 Mdot
.978 .24481 Mdot
.978 .24562 Mdot
.978 .24582 Mdot
.978 .24596 Mdot
.978 .24716 Mdot
.978 .24722 Mdot
.978 .24742 Mdot
.978 .24777 Mdot
.978 .24779 Mdot
.978 .24837 Mdot
.978 .2487 Mdot
.978 .24994 Mdot
.978 .25077 Mdot
.978 .25093 Mdot
.978 .25132 Mdot
.978 .25135 Mdot
.978 .25167 Mdot
.978 .25193 Mdot
.978 .25196 Mdot
.978 .253 Mdot
.978 .25348 Mdot
.978 .25432 Mdot
.978 .25449 Mdot
.978 .25485 Mdot
.978 .25517 Mdot
.978 .25589 Mdot
.978 .25598 Mdot
.978 .257 Mdot
.978 .25701 Mdot
.978 .25762 Mdot
.978 .25777 Mdot
.978 .25818 Mdot
.978 .25838 Mdot
.978 .25875 Mdot
.978 .25883 Mdot
.978 .2592 Mdot
.978 .26001 Mdot
.978 .26024 Mdot
.978 .26099 Mdot
.978 .2611 Mdot
.978 .2615 Mdot
.978 .26155 Mdot
.978 .26175 Mdot
.978 .26197 Mdot
.978 .2621 Mdot
.978 .2622 Mdot
.978 .26235 Mdot
.978 .26334 Mdot
.978 .26346 Mdot
.978 .264 Mdot
.978 .26491 Mdot
.978 .26492 Mdot
.978 .26557 Mdot
.978 .26736 Mdot
.978 .26867 Mdot
.978 .26871 Mdot
.978 .26923 Mdot
.978 .26931 Mdot
.978 .27002 Mdot
.978 .27114 Mdot
.978 .27156 Mdot
.978 .27252 Mdot
.978 .27303 Mdot
.978 .27345 Mdot
.978 .27473 Mdot
.978 .27487 Mdot
.978 .27522 Mdot
.978 .27555 Mdot
.978 .27602 Mdot
.978 .27611 Mdot
.978 .27697 Mdot
.978 .27705 Mdot
.978 .27826 Mdot
.978 .27838 Mdot
.978 .27915 Mdot
.978 .27936 Mdot
.978 .27992 Mdot
.978 .28089 Mdot
.978 .28207 Mdot
.978 .28232 Mdot
.978 .28326 Mdot
.978 .28396 Mdot
.978 .28409 Mdot
.978 .28449 Mdot
.978 .28519 Mdot
.978 .28527 Mdot
.978 .28718 Mdot
.978 .28737 Mdot
.978 .28762 Mdot
.978 .28788 Mdot
.978 .28835 Mdot
.978 .28887 Mdot
.978 .28908 Mdot
.978 .28936 Mdot
.978 .28955 Mdot
.978 .29019 Mdot
.978 .29126 Mdot
.978 .29133 Mdot
.978 .2914 Mdot
.978 .29248 Mdot
.978 .2929 Mdot
.978 .29298 Mdot
.978 .29501 Mdot
.978 .29632 Mdot
.978 .29648 Mdot
.978 .297 Mdot
.978 .29771 Mdot
.978 .29872 Mdot
.978 .29965 Mdot
.978 .29969 Mdot
.978 .30019 Mdot
.978 .30041 Mdot
.978 .30101 Mdot
.978 .3016 Mdot
.978 .3023 Mdot
.978 .30316 Mdot
.978 .30342 Mdot
.978 .30346 Mdot
.978 .30485 Mdot
.978 .30535 Mdot
.978 .30759 Mdot
.978 .30768 Mdot
.978 .30872 Mdot
.978 .30929 Mdot
.978 .30934 Mdot
.978 .31007 Mdot
.978 .3103 Mdot
.978 .31039 Mdot
.978 .3114 Mdot
.978 .31164 Mdot
.978 .31177 Mdot
.978 .31372 Mdot
.978 .31372 Mdot
.978 .31376 Mdot
.978 .31445 Mdot
.978 .31491 Mdot
.978 .31539 Mdot
.978 .31573 Mdot
.978 .31593 Mdot
.978 .31642 Mdot
.978 .31648 Mdot
.978 .31655 Mdot
.978 .31672 Mdot
.978 .31741 Mdot
.978 .31742 Mdot
.978 .31779 Mdot
.978 .31976 Mdot
.978 .31992 Mdot
.978 .31994 Mdot
.978 .32045 Mdot
.978 .32071 Mdot
.978 .32092 Mdot
.978 .32125 Mdot
.978 .32141 Mdot
.978 .32172 Mdot
.978 .32204 Mdot
.978 .32235 Mdot
.978 .32288 Mdot
.978 .32349 Mdot
.978 .32354 Mdot
.978 .32498 Mdot
.978 .32561 Mdot
.978 .32583 Mdot
.978 .32607 Mdot
.978 .32677 Mdot
.978 .3268 Mdot
.978 .32704 Mdot
.978 .32791 Mdot
.978 .32909 Mdot
.978 .32925 Mdot
.978 .32974 Mdot
.978 .33147 Mdot
.978 .33238 Mdot
.978 .33394 Mdot
.978 .33472 Mdot
.978 .33552 Mdot
.978 .33559 Mdot
.978 .33879 Mdot
.978 .3392 Mdot
.978 .33953 Mdot
.978 .34002 Mdot
.978 .34071 Mdot
.978 .3414 Mdot
.978 .34256 Mdot
.978 .34276 Mdot
.978 .34339 Mdot
.978 .34342 Mdot
.978 .34402 Mdot
.978 .34424 Mdot
.978 .34476 Mdot
.978 .34653 Mdot
.978 .34755 Mdot
.978 .34766 Mdot
.978 .348 Mdot
.978 .34847 Mdot
.978 .34975 Mdot
.978 .351 Mdot
.978 .35121 Mdot
.978 .35143 Mdot
.978 .35159 Mdot
.978 .35292 Mdot
.978 .35404 Mdot
.978 .3541 Mdot
.978 .35448 Mdot
.978 .35454 Mdot
.978 .35515 Mdot
.978 .35565 Mdot
.978 .3566 Mdot
.978 .35679 Mdot
.978 .35769 Mdot
.978 .3586 Mdot
.978 .35889 Mdot
.978 .36026 Mdot
.978 .36128 Mdot
.978 .36172 Mdot
.978 .36217 Mdot
.978 .3632 Mdot
.978 .36383 Mdot
.978 .36388 Mdot
.978 .36413 Mdot
.978 .36476 Mdot
.978 .36491 Mdot
.978 .36506 Mdot
.978 .36569 Mdot
.978 .36573 Mdot
.978 .36583 Mdot
.978 .3661 Mdot
.978 .36659 Mdot
.978 .36685 Mdot
.978 .36717 Mdot
.978 .36758 Mdot
.978 .36769 Mdot
.978 .3691 Mdot
.978 .36944 Mdot
.978 .36979 Mdot
.978 .37019 Mdot
.978 .37106 Mdot
.978 .37115 Mdot
.978 .37136 Mdot
.978 .37194 Mdot
.978 .37301 Mdot
.978 .37347 Mdot
.978 .37472 Mdot
.978 .37477 Mdot
.978 .37485 Mdot
.978 .37489 Mdot
.978 .37506 Mdot
.978 .37534 Mdot
.978 .37577 Mdot
.978 .37632 Mdot
.978 .37667 Mdot
.978 .37754 Mdot
.978 .37789 Mdot
.978 .37823 Mdot
.978 .37845 Mdot
.978 .37852 Mdot
.978 .37964 Mdot
.978 .38067 Mdot
.978 .38121 Mdot
.978 .38122 Mdot
.978 .38152 Mdot
.978 .38165 Mdot
.978 .38179 Mdot
.978 .38218 Mdot
.978 .38228 Mdot
.978 .38304 Mdot
.978 .38322 Mdot
.978 .3833 Mdot
.978 .38339 Mdot
.978 .38377 Mdot
.978 .38378 Mdot
.978 .38432 Mdot
.978 .38492 Mdot
.978 .3854 Mdot
.978 .38787 Mdot
.978 .38845 Mdot
.978 .3888 Mdot
.978 .39101 Mdot
.978 .39187 Mdot
.978 .39247 Mdot
.978 .39302 Mdot
.978 .39415 Mdot
.978 .39432 Mdot
.978 .39459 Mdot
.978 .3948 Mdot
.978 .39578 Mdot
.978 .39597 Mdot
.978 .39622 Mdot
.978 .39643 Mdot
.978 .39666 Mdot
.978 .39716 Mdot
.978 .39717 Mdot
.978 .3972 Mdot
.978 .39743 Mdot
.978 .39807 Mdot
.978 .39886 Mdot
.978 .39894 Mdot
.978 .39901 Mdot
.978 .39942 Mdot
.978 .39952 Mdot
.978 .39952 Mdot
.978 .39995 Mdot
.978 .40084 Mdot
.978 .40142 Mdot
.978 .4018 Mdot
.978 .40223 Mdot
.978 .40228 Mdot
.978 .40271 Mdot
.978 .40302 Mdot
.978 .40347 Mdot
.978 .40436 Mdot
.978 .40455 Mdot
.978 .4049 Mdot
.978 .40519 Mdot
.978 .40547 Mdot
.978 .40593 Mdot
.978 .40616 Mdot
.978 .40632 Mdot
.978 .40654 Mdot
.978 .40656 Mdot
.978 .40678 Mdot
.978 .40698 Mdot
.978 .40825 Mdot
.978 .40829 Mdot
.978 .40915 Mdot
.978 .40916 Mdot
.978 .40953 Mdot
.978 .40976 Mdot
.978 .41036 Mdot
.978 .4106 Mdot
.978 .41069 Mdot
.978 .41127 Mdot
.978 .41155 Mdot
.978 .4123 Mdot
.978 .41343 Mdot
.978 .41361 Mdot
.978 .41517 Mdot
.978 .41541 Mdot
.978 .41599 Mdot
.978 .416 Mdot
.978 .4162 Mdot
.978 .41637 Mdot
.978 .41676 Mdot
.978 .41681 Mdot
.978 .41701 Mdot
.978 .41715 Mdot
.978 .4173 Mdot
.978 .41872 Mdot
.978 .41883 Mdot
.978 .41981 Mdot
.978 .42009 Mdot
.978 .42031 Mdot
.978 .42054 Mdot
.978 .42056 Mdot
.978 .4206 Mdot
.978 .42063 Mdot
.978 .4215 Mdot
.978 .42205 Mdot
.978 .42245 Mdot
.978 .42294 Mdot
.978 .42315 Mdot
.978 .42333 Mdot
.978 .4235 Mdot
.978 .42428 Mdot
.978 .42465 Mdot
.978 .42503 Mdot
.978 .42517 Mdot
.978 .42524 Mdot
.978 .42556 Mdot
.978 .42564 Mdot
.978 .42572 Mdot
.978 .42617 Mdot
.978 .42651 Mdot
.978 .42802 Mdot
.978 .42872 Mdot
.978 .42887 Mdot
.978 .42979 Mdot
.978 .43038 Mdot
.978 .43063 Mdot
.978 .43097 Mdot
.978 .43117 Mdot
.978 .43253 Mdot
.978 .43264 Mdot
.978 .43452 Mdot
.978 .43504 Mdot
.978 .43621 Mdot
.978 .43632 Mdot
.978 .43664 Mdot
.978 .43697 Mdot
.978 .43766 Mdot
.978 .43862 Mdot
.978 .43878 Mdot
.978 .44107 Mdot
.978 .44147 Mdot
.978 .44227 Mdot
.978 .44274 Mdot
.978 .44362 Mdot
.978 .44387 Mdot
.978 .44456 Mdot
.978 .445 Mdot
.978 .44562 Mdot
.978 .44573 Mdot
.978 .44679 Mdot
.978 .44682 Mdot
.978 .44756 Mdot
.978 .44772 Mdot
.978 .44788 Mdot
.978 .44824 Mdot
.978 .44837 Mdot
.978 .44973 Mdot
.978 .44992 Mdot
.978 .44993 Mdot
.978 .4504 Mdot
.978 .45068 Mdot
.978 .45096 Mdot
.978 .4512 Mdot
.978 .45179 Mdot
.978 .45181 Mdot
.978 .45288 Mdot
.978 .453 Mdot
.978 .45351 Mdot
.978 .45368 Mdot
.978 .45405 Mdot
.978 .4549 Mdot
.978 .45706 Mdot
.978 .45708 Mdot
.978 .45721 Mdot
.978 .45765 Mdot
.978 .45831 Mdot
.978 .45862 Mdot
.978 .45873 Mdot
.978 .45899 Mdot
.978 .46071 Mdot
.978 .46138 Mdot
.978 .46246 Mdot
.978 .46329 Mdot
.978 .46384 Mdot
.978 .46417 Mdot
.978 .46427 Mdot
.978 .46441 Mdot
.978 .46452 Mdot
.978 .46478 Mdot
.978 .46636 Mdot
.978 .46676 Mdot
.978 .46696 Mdot
.978 .46703 Mdot
.978 .46786 Mdot
.978 .46938 Mdot
.978 .46949 Mdot
.978 .46988 Mdot
.978 .46994 Mdot
.978 .47056 Mdot
.978 .4706 Mdot
.978 .47109 Mdot
.978 .47149 Mdot
.978 .47167 Mdot
.978 .47175 Mdot
.978 .4724 Mdot
.978 .47337 Mdot
.978 .47415 Mdot
.978 .47482 Mdot
.978 .47484 Mdot
.978 .47551 Mdot
.978 .47643 Mdot
.978 .47676 Mdot
.978 .47751 Mdot
.978 .47757 Mdot
.978 .4782 Mdot
.978 .47827 Mdot
.978 .47848 Mdot
.978 .47871 Mdot
.978 .47877 Mdot
.978 .47927 Mdot
.978 .47991 Mdot
.978 .48042 Mdot
.978 .4808 Mdot
.978 .48138 Mdot
.978 .48174 Mdot
.978 .48191 Mdot
.978 .48209 Mdot
.978 .48218 Mdot
.978 .48339 Mdot
.978 .4834 Mdot
.978 .4837 Mdot
.978 .48372 Mdot
.978 .484 Mdot
.978 .48442 Mdot
.978 .48505 Mdot
.978 .48522 Mdot
.978 .48571 Mdot
.978 .48581 Mdot
.978 .48645 Mdot
.978 .48663 Mdot
.978 .48704 Mdot
.978 .48862 Mdot
.978 .48865 Mdot
.978 .48906 Mdot
.978 .48985 Mdot
.978 .48994 Mdot
.978 .49012 Mdot
.978 .4908 Mdot
.978 .49093 Mdot
.978 .49133 Mdot
.978 .49205 Mdot
.978 .49221 Mdot
.978 .4928 Mdot
.978 .49293 Mdot
.978 .49451 Mdot
.978 .49495 Mdot
.978 .49547 Mdot
.978 .49603 Mdot
.978 .49643 Mdot
.978 .49665 Mdot
.978 .49743 Mdot
.978 .49753 Mdot
.978 .49783 Mdot
.978 .49792 Mdot
.978 .49835 Mdot
.978 .4986 Mdot
.978 .4988 Mdot
.978 .49908 Mdot
.978 .49958 Mdot
.978 .49995 Mdot
.978 .50103 Mdot
.978 .50127 Mdot
.978 .50182 Mdot
.978 .50232 Mdot
.978 .50278 Mdot
.978 .50399 Mdot
.978 .5041 Mdot
.978 .5041 Mdot
.978 .50413 Mdot
.978 .50485 Mdot
.978 .50496 Mdot
.978 .50539 Mdot
.978 .50714 Mdot
.978 .50889 Mdot
.978 .50975 Mdot
.978 .51007 Mdot
.978 .51049 Mdot
.978 .51091 Mdot
.978 .51146 Mdot
.978 .51154 Mdot
.978 .51255 Mdot
.978 .51271 Mdot
.978 .51335 Mdot
.978 .51409 Mdot
.978 .51586 Mdot
.978 .51628 Mdot
.978 .51678 Mdot
.978 .51711 Mdot
.978 .51744 Mdot
.978 .51765 Mdot
.978 .51899 Mdot
.978 .51965 Mdot
.978 .51997 Mdot
.978 .52081 Mdot
.978 .52311 Mdot
.978 .5233 Mdot
.978 .52358 Mdot
.978 .52413 Mdot
.978 .52427 Mdot
.978 .52456 Mdot
.978 .52491 Mdot
.978 .52574 Mdot
.978 .52579 Mdot
.978 .52582 Mdot
.978 .526 Mdot
.978 .52704 Mdot
.978 .52742 Mdot
.978 .52768 Mdot
.978 .52783 Mdot
.978 .52969 Mdot
.978 .5302 Mdot
.978 .53045 Mdot
.978 .53103 Mdot
.978 .53195 Mdot
.978 .53236 Mdot
.978 .53238 Mdot
.978 .53335 Mdot
.978 .53346 Mdot
.978 .53398 Mdot
.978 .5348 Mdot
.978 .53536 Mdot
.978 .53766 Mdot
.978 .53815 Mdot
.978 .53999 Mdot
.978 .54104 Mdot
.978 .54119 Mdot
.978 .54135 Mdot
.978 .54162 Mdot
.978 .5424 Mdot
.978 .54274 Mdot
.978 .54376 Mdot
.978 .54392 Mdot
.978 .54427 Mdot
.978 .54733 Mdot
.978 .54765 Mdot
.978 .54803 Mdot
.978 .54851 Mdot
.978 .54903 Mdot
.978 .5491 Mdot
.978 .54995 Mdot
.978 .55095 Mdot
.978 .55137 Mdot
.978 .55192 Mdot
.978 .55229 Mdot
.978 .5525 Mdot
.978 .55345 Mdot
.978 .55354 Mdot
.978 .55376 Mdot
.978 .55565 Mdot
.978 .55578 Mdot
.978 .55591 Mdot
.978 .55606 Mdot
.978 .55777 Mdot
.978 .55803 Mdot
.978 .55825 Mdot
.978 .55831 Mdot
.978 .55885 Mdot
.978 .55899 Mdot
.978 .55966 Mdot
.978 .56014 Mdot
.978 .56057 Mdot
.978 .56181 Mdot
.978 .56298 Mdot
.978 .56463 Mdot
.978 .56472 Mdot
.978 .56554 Mdot
.978 .56584 Mdot
.978 .56591 Mdot
.978 .56686 Mdot
.978 .56696 Mdot
.978 .56756 Mdot
.978 .56818 Mdot
.978 .56824 Mdot
.978 .56879 Mdot
.978 .56911 Mdot
.978 .56975 Mdot
.978 .57016 Mdot
.978 .57023 Mdot
.978 .57066 Mdot
.978 .57167 Mdot
.978 .5717 Mdot
.978 .57201 Mdot
.978 .57206 Mdot
.978 .57212 Mdot
.978 .57311 Mdot
.978 .57353 Mdot
.978 .5747 Mdot
.978 .57585 Mdot
.978 .57588 Mdot
.978 .5766 Mdot
.978 .57661 Mdot
.978 .57724 Mdot
.978 .57795 Mdot
.978 .5783 Mdot
.978 .57842 Mdot
.978 .57855 Mdot
.978 .57891 Mdot
.978 .57943 Mdot
.978 .5795 Mdot
.978 .5795 Mdot
.978 .57989 Mdot
.978 .58056 Mdot
.978 .5815 Mdot
.978 .58222 Mdot
.978 .58241 Mdot
.978 .5832 Mdot
.978 .58376 Mdot
.978 .58383 Mdot
.978 .58384 Mdot
.978 .58759 Mdot
.978 .58765 Mdot
.978 .58776 Mdot
.978 .5879 Mdot
.978 .58837 Mdot
.978 .58979 Mdot
.978 .59034 Mdot
.978 .59051 Mdot
.978 .5909 Mdot
.978 .59098 Mdot
.978 .59099 Mdot
.98 .03896 Mdot
.98 .03924 Mdot
.98 .04078 Mdot
.98 .04143 Mdot
.98 .04145 Mdot
.98 .04213 Mdot
.98 .04285 Mdot
.98 .04426 Mdot
.98 .04585 Mdot
.98 .04755 Mdot
.98 .04923 Mdot
.98 .04972 Mdot
.98 .05044 Mdot
.98 .05068 Mdot
.98 .05095 Mdot
.98 .05157 Mdot
.98 .05294 Mdot
.98 .05402 Mdot
.98 .05429 Mdot
.98 .05434 Mdot
.98 .05446 Mdot
.98 .05449 Mdot
.98 .0552 Mdot
.98 .05541 Mdot
.98 .05649 Mdot
.98 .05716 Mdot
.98 .05752 Mdot
.98 .05987 Mdot
.98 .06016 Mdot
.98 .06223 Mdot
.98 .06278 Mdot
.98 .06294 Mdot
.98 .06352 Mdot
.98 .0636 Mdot
.98 .06369 Mdot
.98 .06479 Mdot
.98 .06535 Mdot
.98 .06535 Mdot
.98 .06581 Mdot
.98 .06707 Mdot
.98 .06711 Mdot
.98 .06845 Mdot
.98 .0686 Mdot
.98 .06869 Mdot
.98 .06986 Mdot
.98 .06996 Mdot
.98 .07161 Mdot
.98 .0724 Mdot
.98 .07262 Mdot
.98 .07373 Mdot
.98 .07453 Mdot
.98 .07551 Mdot
.98 .07573 Mdot
.98 .07576 Mdot
.98 .07629 Mdot
.98 .0765 Mdot
.98 .07871 Mdot
.98 .07908 Mdot
.98 .08086 Mdot
.98 .08116 Mdot
.98 .08164 Mdot
.98 .08233 Mdot
.98 .08236 Mdot
.98 .08332 Mdot
.98 .08353 Mdot
.98 .08366 Mdot
.98 .08456 Mdot
.98 .0847 Mdot
.98 .08474 Mdot
.98 .0852 Mdot
.98 .08531 Mdot
.98 .08573 Mdot
.98 .08674 Mdot
.98 .08696 Mdot
.98 .08779 Mdot
.98 .08964 Mdot
.98 .09065 Mdot
.98 .09126 Mdot
.98 .09158 Mdot
.98 .09175 Mdot
.98 .09194 Mdot
.98 .09227 Mdot
.98 .09237 Mdot
.98 .0926 Mdot
.98 .09262 Mdot
.98 .09263 Mdot
.98 .09263 Mdot
.98 .09268 Mdot
.98 .09407 Mdot
.98 .09442 Mdot
.98 .09444 Mdot
.98 .09447 Mdot
.98 .09508 Mdot
.98 .09512 Mdot
.98 .09555 Mdot
.98 .09595 Mdot
.98 .0966 Mdot
.98 .09765 Mdot
.98 .09791 Mdot
.98 .09796 Mdot
.98 .09861 Mdot
.98 .09935 Mdot
.98 .10321 Mdot
.98 .1035 Mdot
.98 .10379 Mdot
.98 .10437 Mdot
.98 .10491 Mdot
.98 .10495 Mdot
.98 .1058 Mdot
.98 .10747 Mdot
.98 .10752 Mdot
.98 .10784 Mdot
.98 .10807 Mdot
.98 .10892 Mdot
.98 .10923 Mdot
.98 .11038 Mdot
.98 .11053 Mdot
.98 .11064 Mdot
.98 .11071 Mdot
.98 .11286 Mdot
.98 .11305 Mdot
.98 .11396 Mdot
.98 .11397 Mdot
.98 .11443 Mdot
.98 .11486 Mdot
.98 .11568 Mdot
.98 .11591 Mdot
.98 .11705 Mdot
.98 .11733 Mdot
.98 .1174 Mdot
.98 .12004 Mdot
.98 .12012 Mdot
.98 .12032 Mdot
.98 .1205 Mdot
.98 .12139 Mdot
.98 .12281 Mdot
.98 .12294 Mdot
.98 .12299 Mdot
.98 .12344 Mdot
.98 .12496 Mdot
.98 .12531 Mdot
.98 .12586 Mdot
.98 .12622 Mdot
.98 .12713 Mdot
.98 .12749 Mdot
.98 .12777 Mdot
.98 .12822 Mdot
.98 .12864 Mdot
.98 .12866 Mdot
.98 .12916 Mdot
.98 .13038 Mdot
.98 .1308 Mdot
.98 .13176 Mdot
.98 .13181 Mdot
.98 .13196 Mdot
.98 .13242 Mdot
.98 .13319 Mdot
.98 .13364 Mdot
.98 .13388 Mdot
.98 .13431 Mdot
.98 .13436 Mdot
.98 .13438 Mdot
.98 .13508 Mdot
.98 .13539 Mdot
.98 .13582 Mdot
.98 .13583 Mdot
.98 .1376 Mdot
.98 .13822 Mdot
.98 .13873 Mdot
.98 .13879 Mdot
.98 .14015 Mdot
.98 .14028 Mdot
.98 .14087 Mdot
.98 .14214 Mdot
.98 .14276 Mdot
.98 .14306 Mdot
.98 .14436 Mdot
.98 .14494 Mdot
.98 .1459 Mdot
.98 .14724 Mdot
.98 .14729 Mdot
.98 .14791 Mdot
.98 .14918 Mdot
.98 .14958 Mdot
.98 .14984 Mdot
.98 .15161 Mdot
.98 .15188 Mdot
.98 .15197 Mdot
.98 .15274 Mdot
.98 .15287 Mdot
.98 .15309 Mdot
.98 .1536 Mdot
.98 .15365 Mdot
.98 .15391 Mdot
.98 .15555 Mdot
.98 .15589 Mdot
.98 .15596 Mdot
.98 .15597 Mdot
.98 .15631 Mdot
.98 .1575 Mdot
.98 .15794 Mdot
.98 .15794 Mdot
.98 .15858 Mdot
.98 .16156 Mdot
.98 .16265 Mdot
.98 .16354 Mdot
.98 .16465 Mdot
.98 .16474 Mdot
.98 .16536 Mdot
.98 .16569 Mdot
.98 .16607 Mdot
.98 .16628 Mdot
.98 .16673 Mdot
.98 .16692 Mdot
.98 .16736 Mdot
.98 .1674 Mdot
.98 .16742 Mdot
.98 .16743 Mdot
.98 .16752 Mdot
.98 .16783 Mdot
.98 .16818 Mdot
.98 .16887 Mdot
.98 .1697 Mdot
.98 .17025 Mdot
.98 .17093 Mdot
.98 .17097 Mdot
.98 .17103 Mdot
.98 .17223 Mdot
.98 .17231 Mdot
.98 .17235 Mdot
.98 .17282 Mdot
.98 .17316 Mdot
.98 .1732 Mdot
.98 .17394 Mdot
.98 .17405 Mdot
.98 .17413 Mdot
.98 .1752 Mdot
.98 .17574 Mdot
.98 .17707 Mdot
.98 .17727 Mdot
.98 .17778 Mdot
.98 .17788 Mdot
.98 .17915 Mdot
.98 .1806 Mdot
.98 .18111 Mdot
.98 .18308 Mdot
.98 .18332 Mdot
.98 .18528 Mdot
.98 .18815 Mdot
.98 .18817 Mdot
.98 .18874 Mdot
.98 .18895 Mdot
.98 .18929 Mdot
.98 .18971 Mdot
.98 .19019 Mdot
.98 .19044 Mdot
.98 .19049 Mdot
.98 .1915 Mdot
.98 .19158 Mdot
.98 .19325 Mdot
.98 .19387 Mdot
.98 .19484 Mdot
.98 .19651 Mdot
.98 .19661 Mdot
.98 .19683 Mdot
.98 .19724 Mdot
.98 .19768 Mdot
.98 .19836 Mdot
.98 .19936 Mdot
.98 .19974 Mdot
.98 .19997 Mdot
.98 .20091 Mdot
.98 .20166 Mdot
.98 .20184 Mdot
.98 .20221 Mdot
.98 .20221 Mdot
.98 .20252 Mdot
.98 .20273 Mdot
.98 .20286 Mdot
.98 .20319 Mdot
.98 .20442 Mdot
.98 .20466 Mdot
.98 .20692 Mdot
.98 .20708 Mdot
.98 .20745 Mdot
.98 .20923 Mdot
.98 .20925 Mdot
.98 .21017 Mdot
.98 .21052 Mdot
.98 .21055 Mdot
.98 .21067 Mdot
.98 .211 Mdot
.98 .2116 Mdot
.98 .21261 Mdot
.98 .21305 Mdot
.98 .21497 Mdot
.98 .215 Mdot
.98 .21505 Mdot
.98 .2153 Mdot
.98 .21584 Mdot
.98 .21598 Mdot
.98 .21624 Mdot
.98 .21654 Mdot
.98 .21824 Mdot
.98 .21914 Mdot
.98 .21954 Mdot
.98 .22022 Mdot
.98 .22046 Mdot
.98 .22114 Mdot
.98 .22117 Mdot
.98 .22132 Mdot
.98 .22171 Mdot
.98 .22206 Mdot
.98 .22229 Mdot
.98 .2238 Mdot
.98 .22434 Mdot
.98 .22522 Mdot
.98 .22556 Mdot
.98 .22588 Mdot
.98 .22656 Mdot
.98 .22657 Mdot
.98 .22684 Mdot
.98 .22693 Mdot
.98 .22779 Mdot
.98 .22782 Mdot
.98 .22816 Mdot
.98 .23047 Mdot
.98 .23079 Mdot
.98 .23147 Mdot
.98 .23186 Mdot
.98 .23234 Mdot
.98 .23257 Mdot
.98 .23327 Mdot
.98 .23505 Mdot
.98 .2351 Mdot
.98 .23576 Mdot
.98 .23576 Mdot
.98 .23631 Mdot
.98 .23633 Mdot
.98 .23685 Mdot
.98 .23718 Mdot
.98 .23723 Mdot
.98 .238 Mdot
.98 .23804 Mdot
.98 .23903 Mdot
.98 .24012 Mdot
.98 .24111 Mdot
.98 .24142 Mdot
.98 .24224 Mdot
.98 .24412 Mdot
.98 .24422 Mdot
.98 .24451 Mdot
.98 .24542 Mdot
.98 .24577 Mdot
.98 .24693 Mdot
.98 .24752 Mdot
.98 .24781 Mdot
.98 .24827 Mdot
.98 .24864 Mdot
.98 .24892 Mdot
.98 .24912 Mdot
.98 .24922 Mdot
.98 .24925 Mdot
.98 .24981 Mdot
.98 .25063 Mdot
.98 .25124 Mdot
.98 .25208 Mdot
.98 .25211 Mdot
.98 .25321 Mdot
.98 .25329 Mdot
.98 .25361 Mdot
.98 .25452 Mdot
.98 .25482 Mdot
.98 .25557 Mdot
.98 .25678 Mdot
.98 .25779 Mdot
.98 .25789 Mdot
.98 .25907 Mdot
.98 .25919 Mdot
.98 .26057 Mdot
.98 .26083 Mdot
.98 .26092 Mdot
.98 .26115 Mdot
.98 .26197 Mdot
.98 .2624 Mdot
.98 .26274 Mdot
.98 .26447 Mdot
.98 .26475 Mdot
.98 .26568 Mdot
.98 .26627 Mdot
.98 .26665 Mdot
.98 .26705 Mdot
.98 .26791 Mdot
.98 .26883 Mdot
.98 .26996 Mdot
.98 .27004 Mdot
.98 .27016 Mdot
.98 .27057 Mdot
.98 .27132 Mdot
.98 .27183 Mdot
.98 .2724 Mdot
.98 .27345 Mdot
.98 .2738 Mdot
.98 .27424 Mdot
.98 .27446 Mdot
.98 .27456 Mdot
.98 .27559 Mdot
.98 .27577 Mdot
.98 .27586 Mdot
.98 .27669 Mdot
.98 .27827 Mdot
.98 .27895 Mdot
.98 .27895 Mdot
.98 .27906 Mdot
.98 .27956 Mdot
.98 .27979 Mdot
.98 .28231 Mdot
.98 .28303 Mdot
.98 .28342 Mdot
.98 .28343 Mdot
.98 .28357 Mdot
.98 .28373 Mdot
.98 .28476 Mdot
.98 .28524 Mdot
.98 .2855 Mdot
.98 .28593 Mdot
.98 .28678 Mdot
.98 .28693 Mdot
.98 .28702 Mdot
.98 .28741 Mdot
.98 .28754 Mdot
.98 .28828 Mdot
.98 .28937 Mdot
.98 .28976 Mdot
.98 .29075 Mdot
.98 .29142 Mdot
.98 .29156 Mdot
.98 .29157 Mdot
.98 .29201 Mdot
.98 .29224 Mdot
.98 .29369 Mdot
.98 .29457 Mdot
.98 .29467 Mdot
.98 .29496 Mdot
.98 .29544 Mdot
.98 .29544 Mdot
.98 .29669 Mdot
.98 .29697 Mdot
.98 .29734 Mdot
.98 .29777 Mdot
.98 .2978 Mdot
.98 .29954 Mdot
.98 .29989 Mdot
.98 .30015 Mdot
.98 .30036 Mdot
.98 .30134 Mdot
.98 .30254 Mdot
.98 .30268 Mdot
.98 .30396 Mdot
.98 .30467 Mdot
.98 .30484 Mdot
.98 .30512 Mdot
.98 .30642 Mdot
.98 .30661 Mdot
.98 .30839 Mdot
.98 .30858 Mdot
.98 .30876 Mdot
.98 .30933 Mdot
.98 .30999 Mdot
.98 .31046 Mdot
.98 .31063 Mdot
.98 .31137 Mdot
.98 .31178 Mdot
.98 .31222 Mdot
.98 .31266 Mdot
.98 .31304 Mdot
.98 .31311 Mdot
.98 .31327 Mdot
.98 .31363 Mdot
.98 .31391 Mdot
.98 .31398 Mdot
.98 .31399 Mdot
.98 .31402 Mdot
.98 .31403 Mdot
.98 .31422 Mdot
.98 .31482 Mdot
.98 .31551 Mdot
.98 .31623 Mdot
.98 .31638 Mdot
.98 .3164 Mdot
.98 .31643 Mdot
.98 .31686 Mdot
.98 .3177 Mdot
.98 .31773 Mdot
.98 .31849 Mdot
.98 .31869 Mdot
.98 .31957 Mdot
.98 .3197 Mdot
.98 .31976 Mdot
.98 .32034 Mdot
.98 .3209 Mdot
.98 .32097 Mdot
.98 .3211 Mdot
.98 .32128 Mdot
.98 .32186 Mdot
.98 .32189 Mdot
.98 .32344 Mdot
.98 .3236 Mdot
.98 .32368 Mdot
.98 .32378 Mdot
.98 .32396 Mdot
.98 .32442 Mdot
.98 .3246 Mdot
.98 .32461 Mdot
.98 .32527 Mdot
.98 .32535 Mdot
.98 .32679 Mdot
.98 .32701 Mdot
.98 .32717 Mdot
.98 .32927 Mdot
.98 .32996 Mdot
.98 .33032 Mdot
.98 .33144 Mdot
.98 .33294 Mdot
.98 .33303 Mdot
.98 .33333 Mdot
.98 .33334 Mdot
.98 .33414 Mdot
.98 .33432 Mdot
.98 .33452 Mdot
.98 .33483 Mdot
.98 .33501 Mdot
.98 .3352 Mdot
.98 .33685 Mdot
.98 .33701 Mdot
.98 .33835 Mdot
.98 .33984 Mdot
.98 .34084 Mdot
.98 .34096 Mdot
.98 .34219 Mdot
.98 .34313 Mdot
.98 .34471 Mdot
.98 .34517 Mdot
.98 .3475 Mdot
.98 .34903 Mdot
.98 .35031 Mdot
.98 .35108 Mdot
.98 .35184 Mdot
.98 .35214 Mdot
.98 .35239 Mdot
.98 .35248 Mdot
.98 .35306 Mdot
.98 .35465 Mdot
.98 .35469 Mdot
.98 .3558 Mdot
.98 .35581 Mdot
.98 .35582 Mdot
.98 .35614 Mdot
.98 .35621 Mdot
.98 .35689 Mdot
.98 .35717 Mdot
.98 .35723 Mdot
.98 .35771 Mdot
.98 .35864 Mdot
.98 .35914 Mdot
.98 .35924 Mdot
.98 .35984 Mdot
.98 .36104 Mdot
.98 .36122 Mdot
.98 .36136 Mdot
.98 .36235 Mdot
.98 .36428 Mdot
.98 .36464 Mdot
.98 .36576 Mdot
.98 .36586 Mdot
.98 .36777 Mdot
.98 .36783 Mdot
.98 .36824 Mdot
.98 .36926 Mdot
.98 .36936 Mdot
.98 .37103 Mdot
.98 .37123 Mdot
.98 .37165 Mdot
.98 .37246 Mdot
.98 .37268 Mdot
.98 .37333 Mdot
.98 .37362 Mdot
.98 .3745 Mdot
.98 .37466 Mdot
.98 .37586 Mdot
.98 .37629 Mdot
.98 .37655 Mdot
.98 .37663 Mdot
.98 .37725 Mdot
.98 .37736 Mdot
.98 .37737 Mdot
.98 .37782 Mdot
.98 .37791 Mdot
.98 .37803 Mdot
.98 .37864 Mdot
.98 .37897 Mdot
.98 .3792 Mdot
.98 .37966 Mdot
.98 .38012 Mdot
.98 .38066 Mdot
.98 .38112 Mdot
.98 .38149 Mdot
.98 .38158 Mdot
.98 .3822 Mdot
.98 .38221 Mdot
.98 .38255 Mdot
.98 .3828 Mdot
.98 .38323 Mdot
.98 .38348 Mdot
.98 .38413 Mdot
.98 .38417 Mdot
.98 .38574 Mdot
.98 .38654 Mdot
.98 .38662 Mdot
.98 .387 Mdot
.98 .3871 Mdot
.98 .38917 Mdot
.98 .3903 Mdot
.98 .39104 Mdot
.98 .39143 Mdot
.98 .39151 Mdot
.98 .39175 Mdot
.98 .39247 Mdot
.98 .39467 Mdot
.98 .3957 Mdot
.98 .39597 Mdot
.98 .39599 Mdot
.98 .39686 Mdot
.98 .3978 Mdot
.98 .39787 Mdot
.98 .39805 Mdot
.98 .39841 Mdot
.98 .39849 Mdot
.98 .39855 Mdot
.98 .3988 Mdot
.98 .39943 Mdot
.98 .40049 Mdot
.98 .40061 Mdot
.98 .40145 Mdot
.98 .40164 Mdot
.98 .40176 Mdot
.98 .40258 Mdot
.98 .40346 Mdot
.98 .40721 Mdot
.98 .40727 Mdot
.98 .40737 Mdot
.98 .40786 Mdot
.98 .40892 Mdot
.98 .4091 Mdot
.98 .40919 Mdot
.98 .40971 Mdot
.98 .4103 Mdot
.98 .41082 Mdot
.98 .41243 Mdot
.98 .41268 Mdot
.98 .41305 Mdot
.98 .41363 Mdot
.98 .41468 Mdot
.98 .41493 Mdot
.98 .41538 Mdot
.98 .41618 Mdot
.98 .41701 Mdot
.98 .4175 Mdot
.98 .41797 Mdot
.98 .41825 Mdot
.98 .41872 Mdot
.98 .41883 Mdot
.98 .419 Mdot
.98 .41931 Mdot
.98 .41937 Mdot
.98 .41965 Mdot
.98 .41971 Mdot
.98 .42007 Mdot
.98 .4202 Mdot
.98 .42042 Mdot
.98 .42112 Mdot
.98 .42156 Mdot
.98 .42204 Mdot
.98 .42374 Mdot
.98 .42379 Mdot
.98 .42431 Mdot
.98 .42452 Mdot
.98 .42557 Mdot
.98 .42633 Mdot
.98 .42731 Mdot
.98 .42798 Mdot
.98 .42859 Mdot
.98 .42992 Mdot
.98 .42996 Mdot
.98 .43048 Mdot
.98 .43064 Mdot
.98 .43065 Mdot
.98 .43205 Mdot
.98 .43235 Mdot
.98 .4324 Mdot
.98 .43252 Mdot
.98 .43268 Mdot
.98 .43306 Mdot
.98 .43345 Mdot
.98 .43489 Mdot
.98 .43712 Mdot
.98 .4376 Mdot
.98 .43823 Mdot
.98 .43956 Mdot
.98 .44033 Mdot
.98 .44116 Mdot
.98 .44126 Mdot
.98 .44136 Mdot
.98 .4417 Mdot
.98 .44212 Mdot
.98 .44227 Mdot
.98 .44308 Mdot
.98 .44384 Mdot
.98 .44657 Mdot
.98 .44666 Mdot
.98 .4469 Mdot
.98 .44699 Mdot
.98 .44795 Mdot
.98 .44797 Mdot
.98 .44827 Mdot
.98 .44875 Mdot
.98 .44904 Mdot
.98 .44907 Mdot
.98 .44959 Mdot
.98 .45008 Mdot
.98 .45009 Mdot
.98 .45074 Mdot
.98 .45076 Mdot
.98 .45077 Mdot
.98 .45084 Mdot
.98 .45199 Mdot
.98 .45217 Mdot
.98 .45235 Mdot
.98 .45244 Mdot
.98 .45289 Mdot
.98 .45379 Mdot
.98 .45436 Mdot
.98 .45484 Mdot
.98 .45575 Mdot
.98 .45651 Mdot
.98 .45665 Mdot
.98 .4571 Mdot
.98 .45776 Mdot
.98 .45844 Mdot
.98 .45894 Mdot
.98 .45905 Mdot
.98 .45918 Mdot
.98 .45936 Mdot
.98 .46024 Mdot
.98 .46026 Mdot
.98 .46048 Mdot
.98 .46067 Mdot
.98 .46169 Mdot
.98 .46184 Mdot
.98 .46235 Mdot
.98 .4632 Mdot
.98 .46435 Mdot
.98 .46455 Mdot
.98 .4651 Mdot
.98 .46555 Mdot
.98 .46587 Mdot
.98 .4669 Mdot
.98 .46758 Mdot
.98 .46758 Mdot
.98 .46815 Mdot
.98 .46944 Mdot
.98 .46986 Mdot
.98 .46987 Mdot
.98 .47102 Mdot
.98 .47144 Mdot
.98 .47158 Mdot
.98 .47227 Mdot
.98 .47249 Mdot
.98 .47267 Mdot
.98 .4732 Mdot
.98 .47376 Mdot
.98 .47414 Mdot
.98 .47435 Mdot
.98 .47441 Mdot
.98 .4755 Mdot
.98 .47593 Mdot
.98 .47614 Mdot
.98 .47711 Mdot
.98 .47814 Mdot
.98 .47831 Mdot
.98 .47895 Mdot
.98 .47906 Mdot
.98 .47995 Mdot
.98 .48001 Mdot
.98 .48217 Mdot
.98 .48233 Mdot
.98 .48279 Mdot
.98 .48295 Mdot
.98 .48299 Mdot
.98 .48473 Mdot
.98 .48518 Mdot
.98 .48533 Mdot
.98 .4859 Mdot
.98 .48679 Mdot
.98 .48917 Mdot
.98 .48968 Mdot
.98 .49115 Mdot
.98 .49135 Mdot
.98 .49161 Mdot
.98 .4919 Mdot
.98 .49224 Mdot
.98 .49364 Mdot
.98 .49389 Mdot
.98 .4946 Mdot
.98 .49578 Mdot
.98 .49596 Mdot
.98 .4966 Mdot
.98 .49694 Mdot
.98 .4971 Mdot
.98 .49728 Mdot
.98 .49773 Mdot
.98 .49877 Mdot
.98 .49934 Mdot
.98 .49971 Mdot
.98 .49983 Mdot
.98 .50017 Mdot
.98 .50038 Mdot
.98 .50084 Mdot
.98 .5017 Mdot
.98 .50186 Mdot
.98 .50247 Mdot
.98 .50249 Mdot
.98 .50251 Mdot
.98 .50423 Mdot
.98 .5047 Mdot
.98 .50476 Mdot
.98 .50478 Mdot
.98 .50662 Mdot
.98 .50777 Mdot
.98 .50789 Mdot
.98 .50852 Mdot
.98 .50902 Mdot
.98 .5092 Mdot
.98 .5093 Mdot
.98 .50968 Mdot
.98 .51028 Mdot
.98 .51098 Mdot
.98 .51176 Mdot
.98 .51278 Mdot
.98 .51327 Mdot
.98 .515 Mdot
.98 .51515 Mdot
.98 .51539 Mdot
.98 .51578 Mdot
.98 .51619 Mdot
.98 .51765 Mdot
.98 .51866 Mdot
.98 .51878 Mdot
.98 .51978 Mdot
.98 .52184 Mdot
.98 .52252 Mdot
.98 .52334 Mdot
.98 .52338 Mdot
.98 .52382 Mdot
.98 .52401 Mdot
.98 .52425 Mdot
.98 .52603 Mdot
.98 .52638 Mdot
.98 .52656 Mdot
.98 .52735 Mdot
.98 .52818 Mdot
.98 .5292 Mdot
.98 .53128 Mdot
.98 .5316 Mdot
.98 .53183 Mdot
.98 .53261 Mdot
.98 .53261 Mdot
.98 .53282 Mdot
.98 .53379 Mdot
.98 .53382 Mdot
.98 .53426 Mdot
.98 .53672 Mdot
.98 .5392 Mdot
.98 .53935 Mdot
.98 .53967 Mdot
.98 .54061 Mdot
.98 .54138 Mdot
.98 .5414 Mdot
.98 .54167 Mdot
.98 .54198 Mdot
.98 .54288 Mdot
.98 .54327 Mdot
.98 .54363 Mdot
.98 .544 Mdot
.98 .54423 Mdot
.98 .54462 Mdot
.98 .54494 Mdot
.98 .54496 Mdot
.98 .54545 Mdot
.98 .54629 Mdot
.98 .54654 Mdot
.98 .54655 Mdot
.98 .54714 Mdot
.98 .54732 Mdot
.98 .54797 Mdot
.98 .54825 Mdot
.98 .54843 Mdot
.98 .54921 Mdot
.98 .54946 Mdot
.98 .55025 Mdot
.98 .5509 Mdot
.98 .55246 Mdot
.98 .55305 Mdot
.98 .55317 Mdot
.98 .5538 Mdot
.98 .55451 Mdot
.98 .55573 Mdot
.98 .55705 Mdot
.98 .55733 Mdot
.98 .55736 Mdot
.98 .5582 Mdot
.98 .55864 Mdot
.98 .55866 Mdot
.98 .55893 Mdot
.98 .55938 Mdot
.98 .5615 Mdot
.98 .5622 Mdot
.98 .56236 Mdot
.98 .56323 Mdot
.98 .56343 Mdot
.98 .56365 Mdot
.98 .56368 Mdot
.98 .564 Mdot
.98 .56401 Mdot
.98 .56493 Mdot
.98 .56493 Mdot
.98 .56494 Mdot
.98 .56528 Mdot
.98 .56546 Mdot
.98 .56563 Mdot
.98 .56594 Mdot
.98 .56739 Mdot
.98 .56793 Mdot
.98 .56866 Mdot
.98 .56897 Mdot
.98 .56904 Mdot
.98 .5695 Mdot
.98 .56957 Mdot
.98 .57018 Mdot
.98 .57053 Mdot
.98 .57078 Mdot
.98 .57093 Mdot
.98 .57203 Mdot
.98 .57297 Mdot
.98 .57315 Mdot
.98 .57326 Mdot
.98 .57353 Mdot
.98 .57366 Mdot
.98 .57416 Mdot
.98 .57457 Mdot
.98 .57525 Mdot
.98 .57565 Mdot
.98 .57649 Mdot
.98 .57714 Mdot
.98 .57719 Mdot
.98 .57884 Mdot
.98 .57884 Mdot
.98 .57913 Mdot
.98 .57969 Mdot
.98 .57974 Mdot
.98 .57978 Mdot
.98 .58007 Mdot
.98 .58149 Mdot
.98 .58164 Mdot
.98 .58284 Mdot
.98 .58302 Mdot
.98 .58336 Mdot
.98 .58392 Mdot
.98 .58402 Mdot
.98 .58438 Mdot
.98 .5844 Mdot
.98 .58446 Mdot
.98 .58449 Mdot
.98 .58463 Mdot
.98 .58518 Mdot
.98 .58587 Mdot
.98 .58619 Mdot
.98 .58633 Mdot
.98 .58645 Mdot
.98 .58682 Mdot
.98 .58707 Mdot
.98 .58792 Mdot
.98 .58879 Mdot
.98 .5896 Mdot
.98 .59032 Mdot
.98 .59069 Mdot
.98 .59104 Mdot
.98 .59105 Mdot
.98 .59138 Mdot
.98 .59217 Mdot
.98 .59231 Mdot
.982 .03632 Mdot
.982 .03711 Mdot
.982 .03834 Mdot
.982 .03836 Mdot
.982 .03844 Mdot
.982 .03918 Mdot
.982 .03947 Mdot
.982 .04098 Mdot
.982 .04167 Mdot
.982 .04283 Mdot
.982 .04307 Mdot
.982 .04307 Mdot
.982 .04543 Mdot
.982 .04586 Mdot
.982 .04711 Mdot
.982 .04786 Mdot
.982 .04889 Mdot
.982 .05033 Mdot
.982 .05185 Mdot
.982 .05246 Mdot
.982 .05705 Mdot
.982 .05715 Mdot
.982 .05871 Mdot
.982 .05897 Mdot
.982 .06111 Mdot
.982 .06112 Mdot
.982 .06115 Mdot
.982 .06119 Mdot
.982 .06131 Mdot
.982 .06277 Mdot
.982 .06333 Mdot
.982 .06422 Mdot
.982 .06456 Mdot
.982 .06547 Mdot
.982 .0663 Mdot
.982 .06647 Mdot
.982 .06671 Mdot
.982 .06683 Mdot
.982 .06714 Mdot
.982 .06718 Mdot
.982 .06766 Mdot
.982 .06871 Mdot
.982 .0693 Mdot
.982 .06994 Mdot
.982 .06995 Mdot
.982 .0704 Mdot
.982 .0704 Mdot
.982 .07052 Mdot
.982 .07182 Mdot
.982 .07266 Mdot
.982 .07502 Mdot
.982 .07504 Mdot
.982 .07588 Mdot
.982 .07627 Mdot
.982 .07695 Mdot
.982 .07834 Mdot
.982 .07927 Mdot
.982 .07961 Mdot
.982 .07981 Mdot
.982 .08183 Mdot
.982 .08208 Mdot
.982 .0822 Mdot
.982 .0828 Mdot
.982 .08336 Mdot
.982 .08357 Mdot
.982 .08466 Mdot
.982 .08508 Mdot
.982 .08765 Mdot
.982 .08823 Mdot
.982 .0887 Mdot
.982 .08884 Mdot
.982 .08926 Mdot
.982 .08955 Mdot
.982 .09005 Mdot
.982 .09093 Mdot
.982 .09168 Mdot
.982 .09208 Mdot
.982 .09276 Mdot
.982 .09631 Mdot
.982 .09692 Mdot
.982 .09787 Mdot
.982 .09805 Mdot
.982 .09813 Mdot
.982 .09891 Mdot
.982 .09946 Mdot
.982 .09995 Mdot
.982 .10111 Mdot
.982 .10155 Mdot
.982 .10163 Mdot
.982 .10215 Mdot
.982 .10239 Mdot
.982 .10241 Mdot
.982 .10351 Mdot
.982 .10365 Mdot
.982 .10514 Mdot
.982 .10583 Mdot
.982 .10585 Mdot
.982 .10591 Mdot
.982 .10598 Mdot
.982 .10622 Mdot
.982 .10631 Mdot
.982 .10742 Mdot
.982 .1081 Mdot
.982 .10854 Mdot
.982 .10909 Mdot
.982 .10924 Mdot
.982 .11019 Mdot
.982 .1103 Mdot
.982 .1108 Mdot
.982 .11133 Mdot
.982 .11176 Mdot
.982 .11194 Mdot
.982 .11234 Mdot
.982 .11262 Mdot
.982 .1144 Mdot
.982 .11505 Mdot
.982 .11604 Mdot
.982 .11636 Mdot
.982 .11684 Mdot
.982 .11707 Mdot
.982 .11767 Mdot
.982 .11775 Mdot
.982 .1187 Mdot
.982 .12064 Mdot
.982 .12076 Mdot
.982 .12079 Mdot
.982 .12172 Mdot
.982 .12193 Mdot
.982 .12212 Mdot
.982 .12231 Mdot
.982 .12318 Mdot
.982 .12319 Mdot
.982 .12407 Mdot
.982 .12409 Mdot
.982 .12431 Mdot
.982 .12652 Mdot
.982 .12686 Mdot
.982 .12852 Mdot
.982 .12882 Mdot
.982 .13105 Mdot
.982 .13272 Mdot
.982 .13276 Mdot
.982 .13315 Mdot
.982 .1332 Mdot
.982 .13401 Mdot
.982 .13484 Mdot
.982 .13496 Mdot
.982 .13561 Mdot
.982 .13571 Mdot
.982 .13695 Mdot
.982 .13763 Mdot
.982 .13838 Mdot
.982 .13858 Mdot
.982 .13878 Mdot
.982 .13968 Mdot
.982 .14149 Mdot
.982 .14216 Mdot
.982 .14255 Mdot
.982 .14351 Mdot
.982 .1446 Mdot
.982 .14653 Mdot
.982 .14701 Mdot
.982 .14725 Mdot
.982 .14764 Mdot
.982 .14766 Mdot
.982 .14779 Mdot
.982 .14844 Mdot
.982 .14893 Mdot
.982 .14953 Mdot
.982 .14995 Mdot
.982 .15052 Mdot
.982 .15134 Mdot
.982 .15208 Mdot
.982 .15209 Mdot
.982 .15231 Mdot
.982 .1529 Mdot
.982 .15346 Mdot
.982 .15665 Mdot
.982 .15689 Mdot
.982 .15782 Mdot
.982 .15796 Mdot
.982 .15857 Mdot
.982 .1586 Mdot
.982 .1591 Mdot
.982 .15954 Mdot
.982 .16001 Mdot
.982 .1603 Mdot
.982 .16037 Mdot
.982 .16113 Mdot
.982 .16153 Mdot
.982 .1617 Mdot
.982 .16268 Mdot
.982 .16392 Mdot
.982 .1644 Mdot
.982 .16443 Mdot
.982 .16501 Mdot
.982 .16527 Mdot
.982 .16529 Mdot
.982 .16562 Mdot
.982 .16587 Mdot
.982 .1659 Mdot
.982 .16621 Mdot
.982 .16627 Mdot
.982 .16643 Mdot
.982 .16667 Mdot
.982 .168 Mdot
.982 .16904 Mdot
.982 .16936 Mdot
.982 .17106 Mdot
.982 .17114 Mdot
.982 .17144 Mdot
.982 .17237 Mdot
.982 .17246 Mdot
.982 .17409 Mdot
.982 .17454 Mdot
.982 .17484 Mdot
.982 .17497 Mdot
.982 .17616 Mdot
.982 .17803 Mdot
.982 .17838 Mdot
.982 .17853 Mdot
.982 .17972 Mdot
.982 .18008 Mdot
.982 .18092 Mdot
.982 .18115 Mdot
.982 .18203 Mdot
.982 .18211 Mdot
.982 .18319 Mdot
.982 .18325 Mdot
.982 .18394 Mdot
.982 .1844 Mdot
.982 .18526 Mdot
.982 .18542 Mdot
.982 .18643 Mdot
.982 .1869 Mdot
.982 .18695 Mdot
.982 .18911 Mdot
.982 .18938 Mdot
.982 .18943 Mdot
.982 .18974 Mdot
.982 .18998 Mdot
.982 .19096 Mdot
.982 .19228 Mdot
.982 .19231 Mdot
.982 .19366 Mdot
.982 .19371 Mdot
.982 .19383 Mdot
.982 .19397 Mdot
.982 .19444 Mdot
.982 .19461 Mdot
.982 .19481 Mdot
.982 .19503 Mdot
.982 .19678 Mdot
.982 .1974 Mdot
.982 .19757 Mdot
.982 .19767 Mdot
.982 .19813 Mdot
.982 .19837 Mdot
.982 .19864 Mdot
.982 .19899 Mdot
.982 .20007 Mdot
.982 .20036 Mdot
.982 .20217 Mdot
.982 .20223 Mdot
.982 .20244 Mdot
.982 .20251 Mdot
.982 .20342 Mdot
.982 .20446 Mdot
.982 .20493 Mdot
.982 .2053 Mdot
.982 .20566 Mdot
.982 .20646 Mdot
.982 .20699 Mdot
.982 .20789 Mdot
.982 .20801 Mdot
.982 .21049 Mdot
.982 .21058 Mdot
.982 .21176 Mdot
.982 .21263 Mdot
.982 .21278 Mdot
.982 .21298 Mdot
.982 .21371 Mdot
.982 .21434 Mdot
.982 .21441 Mdot
.982 .21522 Mdot
.982 .21529 Mdot
.982 .21575 Mdot
.982 .21692 Mdot
.982 .21708 Mdot
.982 .21716 Mdot
.982 .21782 Mdot
.982 .21892 Mdot
.982 .21894 Mdot
.982 .2191 Mdot
.982 .22097 Mdot
.982 .22137 Mdot
.982 .22222 Mdot
.982 .22276 Mdot
.982 .22298 Mdot
.982 .22298 Mdot
.982 .22304 Mdot
.982 .22368 Mdot
.982 .22431 Mdot
.982 .22487 Mdot
.982 .22515 Mdot
.982 .22528 Mdot
.982 .22549 Mdot
.982 .22565 Mdot
.982 .22603 Mdot
.982 .22643 Mdot
.982 .22673 Mdot
.982 .22774 Mdot
.982 .22775 Mdot
.982 .22871 Mdot
.982 .2295 Mdot
.982 .22952 Mdot
.982 .22997 Mdot
.982 .23 Mdot
.982 .2311 Mdot
.982 .23291 Mdot
.982 .23354 Mdot
.982 .23416 Mdot
.982 .2342 Mdot
.982 .2343 Mdot
.982 .23491 Mdot
.982 .23497 Mdot
.982 .23506 Mdot
.982 .23619 Mdot
.982 .23655 Mdot
.982 .23668 Mdot
.982 .23764 Mdot
.982 .23822 Mdot
.982 .23882 Mdot
.982 .23972 Mdot
.982 .24035 Mdot
.982 .24226 Mdot
.982 .24292 Mdot
.982 .24312 Mdot
.982 .2432 Mdot
.982 .24379 Mdot
.982 .24442 Mdot
.982 .2449 Mdot
.982 .24648 Mdot
.982 .24655 Mdot
.982 .24733 Mdot
.982 .24737 Mdot
.982 .24741 Mdot
.982 .24782 Mdot
.982 .2486 Mdot
.982 .24901 Mdot
.982 .25065 Mdot
.982 .25088 Mdot
.982 .25146 Mdot
.982 .25215 Mdot
.982 .25235 Mdot
.982 .2527 Mdot
.982 .25341 Mdot
.982 .25373 Mdot
.982 .25467 Mdot
.982 .25479 Mdot
.982 .25543 Mdot
.982 .25555 Mdot
.982 .25572 Mdot
.982 .25611 Mdot
.982 .25677 Mdot
.982 .25756 Mdot
.982 .25759 Mdot
.982 .25798 Mdot
.982 .25802 Mdot
.982 .25837 Mdot
.982 .25929 Mdot
.982 .26014 Mdot
.982 .26022 Mdot
.982 .26055 Mdot
.982 .26131 Mdot
.982 .26212 Mdot
.982 .26245 Mdot
.982 .26333 Mdot
.982 .2637 Mdot
.982 .26376 Mdot
.982 .26502 Mdot
.982 .26579 Mdot
.982 .26749 Mdot
.982 .26767 Mdot
.982 .26836 Mdot
.982 .26841 Mdot
.982 .26967 Mdot
.982 .26981 Mdot
.982 .27123 Mdot
.982 .27173 Mdot
.982 .27359 Mdot
.982 .27423 Mdot
.982 .27455 Mdot
.982 .27501 Mdot
.982 .27577 Mdot
.982 .27581 Mdot
.982 .27583 Mdot
.982 .27598 Mdot
.982 .27607 Mdot
.982 .27614 Mdot
.982 .27704 Mdot
.982 .27734 Mdot
.982 .27756 Mdot
.982 .278 Mdot
.982 .27831 Mdot
.982 .27913 Mdot
.982 .27943 Mdot
.982 .27949 Mdot
.982 .27968 Mdot
.982 .28031 Mdot
.982 .28143 Mdot
.982 .28171 Mdot
.982 .28299 Mdot
.982 .28304 Mdot
.982 .28374 Mdot
.982 .2845 Mdot
.982 .28451 Mdot
.982 .28494 Mdot
.982 .28552 Mdot
.982 .28612 Mdot
.982 .28721 Mdot
.982 .28726 Mdot
.982 .28736 Mdot
.982 .28909 Mdot
.982 .28979 Mdot
.982 .29107 Mdot
.982 .29136 Mdot
.982 .29208 Mdot
.982 .29237 Mdot
.982 .29237 Mdot
.982 .29313 Mdot
.982 .29348 Mdot
.982 .29379 Mdot
.982 .29395 Mdot
.982 .29515 Mdot
.982 .2957 Mdot
.982 .29578 Mdot
.982 .29605 Mdot
.982 .29725 Mdot
.982 .29731 Mdot
.982 .29828 Mdot
.982 .29837 Mdot
.982 .29915 Mdot
.982 .30008 Mdot
.982 .30064 Mdot
.982 .30079 Mdot
.982 .30195 Mdot
.982 .30227 Mdot
.982 .30306 Mdot
.982 .30307 Mdot
.982 .30339 Mdot
.982 .30413 Mdot
.982 .30532 Mdot
.982 .30548 Mdot
.982 .30775 Mdot
.982 .30869 Mdot
.982 .30876 Mdot
.982 .30897 Mdot
.982 .30989 Mdot
.982 .3101 Mdot
.982 .31041 Mdot
.982 .31044 Mdot
.982 .3111 Mdot
.982 .31128 Mdot
.982 .31158 Mdot
.982 .31164 Mdot
.982 .31225 Mdot
.982 .31236 Mdot
.982 .31269 Mdot
.982 .31288 Mdot
.982 .31315 Mdot
.982 .31352 Mdot
.982 .31576 Mdot
.982 .31721 Mdot
.982 .31771 Mdot
.982 .31777 Mdot
.982 .3178 Mdot
.982 .31788 Mdot
.982 .31789 Mdot
.982 .31829 Mdot
.982 .31844 Mdot
.982 .31909 Mdot
.982 .31992 Mdot
.982 .32042 Mdot
.982 .32175 Mdot
.982 .32178 Mdot
.982 .32194 Mdot
.982 .32253 Mdot
.982 .32347 Mdot
.982 .32382 Mdot
.982 .32405 Mdot
.982 .32435 Mdot
.982 .32452 Mdot
.982 .32612 Mdot
.982 .32639 Mdot
.982 .3268 Mdot
.982 .32696 Mdot
.982 .32735 Mdot
.982 .32773 Mdot
.982 .3285 Mdot
.982 .32861 Mdot
.982 .32879 Mdot
.982 .32907 Mdot
.982 .3292 Mdot
.982 .32934 Mdot
.982 .32945 Mdot
.982 .33175 Mdot
.982 .33179 Mdot
.982 .33522 Mdot
.982 .33546 Mdot
.982 .33615 Mdot
.982 .33645 Mdot
.982 .33875 Mdot
.982 .33876 Mdot
.982 .33879 Mdot
.982 .3395 Mdot
.982 .34115 Mdot
.982 .34158 Mdot
.982 .34159 Mdot
.982 .34297 Mdot
.982 .3431 Mdot
.982 .34333 Mdot
.982 .34348 Mdot
.982 .3443 Mdot
.982 .34482 Mdot
.982 .34492 Mdot
.982 .34518 Mdot
.982 .34561 Mdot
.982 .34572 Mdot
.982 .34707 Mdot
.982 .34738 Mdot
.982 .34797 Mdot
.982 .34798 Mdot
.982 .34966 Mdot
.982 .34998 Mdot
.982 .35032 Mdot
.982 .35165 Mdot
.982 .35169 Mdot
.982 .35197 Mdot
.982 .35289 Mdot
.982 .35298 Mdot
.982 .3544 Mdot
.982 .35507 Mdot
.982 .3556 Mdot
.982 .35627 Mdot
.982 .35677 Mdot
.982 .35723 Mdot
.982 .35776 Mdot
.982 .35786 Mdot
.982 .35828 Mdot
.982 .35846 Mdot
.982 .35863 Mdot
.982 .35893 Mdot
.982 .35977 Mdot
.982 .36039 Mdot
.982 .36086 Mdot
.982 .36118 Mdot
.982 .36119 Mdot
.982 .36171 Mdot
.982 .36208 Mdot
.982 .36278 Mdot
.982 .36345 Mdot
.982 .3635 Mdot
.982 .36492 Mdot
.982 .36617 Mdot
.982 .36625 Mdot
.982 .3665 Mdot
.982 .36677 Mdot
.982 .36737 Mdot
.982 .3677 Mdot
.982 .36802 Mdot
.982 .36822 Mdot
.982 .36843 Mdot
.982 .36885 Mdot
.982 .36982 Mdot
.982 .37005 Mdot
.982 .37006 Mdot
.982 .37092 Mdot
.982 .3723 Mdot
.982 .37243 Mdot
.982 .37255 Mdot
.982 .37298 Mdot
.982 .37351 Mdot
.982 .37384 Mdot
.982 .37403 Mdot
.982 .37495 Mdot
.982 .37542 Mdot
.982 .37593 Mdot
.982 .37601 Mdot
.982 .37627 Mdot
.982 .37664 Mdot
.982 .37699 Mdot
.982 .37783 Mdot
.982 .37875 Mdot
.982 .37932 Mdot
.982 .38087 Mdot
.982 .38159 Mdot
.982 .38286 Mdot
.982 .38288 Mdot
.982 .38289 Mdot
.982 .38299 Mdot
.982 .38341 Mdot
.982 .38354 Mdot
.982 .38389 Mdot
.982 .38502 Mdot
.982 .38534 Mdot
.982 .38564 Mdot
.982 .38571 Mdot
.982 .38579 Mdot
.982 .38738 Mdot
.982 .3883 Mdot
.982 .38903 Mdot
.982 .38973 Mdot
.982 .38996 Mdot
.982 .39053 Mdot
.982 .3913 Mdot
.982 .39235 Mdot
.982 .39253 Mdot
.982 .39284 Mdot
.982 .39345 Mdot
.982 .39411 Mdot
.982 .39434 Mdot
.982 .39593 Mdot
.982 .39703 Mdot
.982 .39706 Mdot
.982 .39795 Mdot
.982 .39821 Mdot
.982 .39921 Mdot
.982 .3994 Mdot
.982 .39973 Mdot
.982 .39974 Mdot
.982 .4 Mdot
.982 .40049 Mdot
.982 .40172 Mdot
.982 .40312 Mdot
.982 .4034 Mdot
.982 .40341 Mdot
.982 .40371 Mdot
.982 .4041 Mdot
.982 .4043 Mdot
.982 .40529 Mdot
.982 .40555 Mdot
.982 .40581 Mdot
.982 .40631 Mdot
.982 .40677 Mdot
.982 .40692 Mdot
.982 .40826 Mdot
.982 .40851 Mdot
.982 .40864 Mdot
.982 .40864 Mdot
.982 .40942 Mdot
.982 .40955 Mdot
.982 .41 Mdot
.982 .41002 Mdot
.982 .41057 Mdot
.982 .41184 Mdot
.982 .41215 Mdot
.982 .41231 Mdot
.982 .41332 Mdot
.982 .41361 Mdot
.982 .41574 Mdot
.982 .41578 Mdot
.982 .41582 Mdot
.982 .41613 Mdot
.982 .41671 Mdot
.982 .41722 Mdot
.982 .41723 Mdot
.982 .41788 Mdot
.982 .41825 Mdot
.982 .41979 Mdot
.982 .42022 Mdot
.982 .42059 Mdot
.982 .42072 Mdot
.982 .42226 Mdot
.982 .42248 Mdot
.982 .42254 Mdot
.982 .42331 Mdot
.982 .42375 Mdot
.982 .42376 Mdot
.982 .42387 Mdot
.982 .42469 Mdot
.982 .42512 Mdot
.982 .42636 Mdot
.982 .42745 Mdot
.982 .42781 Mdot
.982 .428 Mdot
.982 .42827 Mdot
.982 .42827 Mdot
.982 .42867 Mdot
.982 .42899 Mdot
.982 .42957 Mdot
.982 .42975 Mdot
.982 .43051 Mdot
.982 .43077 Mdot
.982 .43111 Mdot
.982 .43138 Mdot
.982 .43172 Mdot
.982 .4331 Mdot
.982 .43312 Mdot
.982 .4338 Mdot
.982 .435 Mdot
.982 .4353 Mdot
.982 .43641 Mdot
.982 .43655 Mdot
.982 .4366 Mdot
.982 .43687 Mdot
.982 .43747 Mdot
.982 .43754 Mdot
.982 .43824 Mdot
.982 .43969 Mdot
.982 .43969 Mdot
.982 .44149 Mdot
.982 .44325 Mdot
.982 .44448 Mdot
.982 .44462 Mdot
.982 .44476 Mdot
.982 .44491 Mdot
.982 .4455 Mdot
.982 .4457 Mdot
.982 .44577 Mdot
.982 .44599 Mdot
.982 .44612 Mdot
.982 .44718 Mdot
.982 .44729 Mdot
.982 .44747 Mdot
.982 .44834 Mdot
.982 .44902 Mdot
.982 .44928 Mdot
.982 .4497 Mdot
.982 .45011 Mdot
.982 .45031 Mdot
.982 .45032 Mdot
.982 .45037 Mdot
.982 .45041 Mdot
.982 .45066 Mdot
.982 .45254 Mdot
.982 .45286 Mdot
.982 .45368 Mdot
.982 .45428 Mdot
.982 .45485 Mdot
.982 .45663 Mdot
.982 .45732 Mdot
.982 .45786 Mdot
.982 .45843 Mdot
.982 .46025 Mdot
.982 .46161 Mdot
.982 .46189 Mdot
.982 .46258 Mdot
.982 .46292 Mdot
.982 .4633 Mdot
.982 .46331 Mdot
.982 .46345 Mdot
.982 .46382 Mdot
.982 .46397 Mdot
.982 .46462 Mdot
.982 .46497 Mdot
.982 .46585 Mdot
.982 .46591 Mdot
.982 .46679 Mdot
.982 .4677 Mdot
.982 .46808 Mdot
.982 .46873 Mdot
.982 .46976 Mdot
.982 .46989 Mdot
.982 .47004 Mdot
.982 .47062 Mdot
.982 .47085 Mdot
.982 .47111 Mdot
.982 .47157 Mdot
.982 .47165 Mdot
.982 .47174 Mdot
.982 .47254 Mdot
.982 .47382 Mdot
.982 .47407 Mdot
.982 .47487 Mdot
.982 .4755 Mdot
.982 .47553 Mdot
.982 .47597 Mdot
.982 .47787 Mdot
.982 .47809 Mdot
.982 .47854 Mdot
.982 .47871 Mdot
.982 .47912 Mdot
.982 .47951 Mdot
.982 .47968 Mdot
.982 .48015 Mdot
.982 .4808 Mdot
.982 .48103 Mdot
.982 .48143 Mdot
.982 .48197 Mdot
.982 .48211 Mdot
.982 .4825 Mdot
.982 .48298 Mdot
.982 .48314 Mdot
.982 .4835 Mdot
.982 .48414 Mdot
.982 .48559 Mdot
.982 .48599 Mdot
.982 .48622 Mdot
.982 .48748 Mdot
.982 .48772 Mdot
.982 .48804 Mdot
.982 .48838 Mdot
.982 .48848 Mdot
.982 .48882 Mdot
.982 .48979 Mdot
.982 .49011 Mdot
.982 .49117 Mdot
.982 .49166 Mdot
.982 .49173 Mdot
.982 .49191 Mdot
.982 .49249 Mdot
.982 .49256 Mdot
.982 .49293 Mdot
.982 .49295 Mdot
.982 .49326 Mdot
.982 .49358 Mdot
.982 .4945 Mdot
.982 .49506 Mdot
.982 .49572 Mdot
.982 .49673 Mdot
.982 .49688 Mdot
.982 .49736 Mdot
.982 .49753 Mdot
.982 .49796 Mdot
.982 .49828 Mdot
.982 .49864 Mdot
.982 .49902 Mdot
.982 .49946 Mdot
.982 .49966 Mdot
.982 .50061 Mdot
.982 .5007 Mdot
.982 .50126 Mdot
.982 .5016 Mdot
.982 .50259 Mdot
.982 .503 Mdot
.982 .50373 Mdot
.982 .50383 Mdot
.982 .50391 Mdot
.982 .50495 Mdot
.982 .50626 Mdot
.982 .50632 Mdot
.982 .50783 Mdot
.982 .50906 Mdot
.982 .50923 Mdot
.982 .51103 Mdot
.982 .51117 Mdot
.982 .51153 Mdot
.982 .51158 Mdot
.982 .51166 Mdot
.982 .51287 Mdot
.982 .51298 Mdot
.982 .51427 Mdot
.982 .51494 Mdot
.982 .51544 Mdot
.982 .51556 Mdot
.982 .51572 Mdot
.982 .51852 Mdot
.982 .51886 Mdot
.982 .51889 Mdot
.982 .51949 Mdot
.982 .52005 Mdot
.982 .52066 Mdot
.982 .52315 Mdot
.982 .5233 Mdot
.982 .52353 Mdot
.982 .52436 Mdot
.982 .52441 Mdot
.982 .52488 Mdot
.982 .52503 Mdot
.982 .52507 Mdot
.982 .52594 Mdot
.982 .5261 Mdot
.982 .52743 Mdot
.982 .52751 Mdot
.982 .52754 Mdot
.982 .5277 Mdot
.982 .52784 Mdot
.982 .52801 Mdot
.982 .52802 Mdot
.982 .52815 Mdot
.982 .52845 Mdot
.982 .52871 Mdot
.982 .52993 Mdot
.982 .53051 Mdot
.982 .53094 Mdot
.982 .53142 Mdot
.982 .53143 Mdot
.982 .53181 Mdot
.982 .53229 Mdot
.982 .53241 Mdot
.982 .53403 Mdot
.982 .53462 Mdot
.982 .53473 Mdot
.982 .53511 Mdot
.982 .53553 Mdot
.982 .53634 Mdot
.982 .53692 Mdot
.982 .53698 Mdot
.982 .537 Mdot
.982 .53855 Mdot
.982 .5391 Mdot
.982 .54151 Mdot
.982 .54161 Mdot
.982 .54171 Mdot
.982 .5421 Mdot
.982 .54307 Mdot
.982 .54345 Mdot
.982 .54394 Mdot
.982 .54457 Mdot
.982 .54459 Mdot
.982 .54544 Mdot
.982 .54658 Mdot
.982 .54775 Mdot
.982 .54989 Mdot
.982 .54999 Mdot
.982 .5502 Mdot
.982 .55067 Mdot
.982 .55074 Mdot
.982 .55359 Mdot
.982 .55497 Mdot
.982 .55527 Mdot
.982 .55549 Mdot
.982 .55576 Mdot
.982 .55601 Mdot
.982 .55655 Mdot
.982 .5569 Mdot
.982 .55713 Mdot
.982 .55748 Mdot
.982 .55804 Mdot
.982 .55864 Mdot
.982 .5594 Mdot
.982 .55947 Mdot
.982 .56003 Mdot
.982 .56004 Mdot
.982 .56016 Mdot
.982 .56046 Mdot
.982 .56128 Mdot
.982 .56153 Mdot
.982 .56181 Mdot
.982 .56221 Mdot
.982 .56282 Mdot
.982 .56313 Mdot
.982 .56494 Mdot
.982 .56528 Mdot
.982 .56549 Mdot
.982 .56587 Mdot
.982 .56632 Mdot
.982 .56657 Mdot
.982 .56672 Mdot
.982 .56701 Mdot
.982 .56725 Mdot
.982 .56885 Mdot
.982 .56962 Mdot
.982 .56973 Mdot
.982 .57001 Mdot
.982 .57032 Mdot
.982 .57038 Mdot
.982 .57164 Mdot
.982 .57181 Mdot
.982 .57299 Mdot
.982 .57334 Mdot
.982 .57397 Mdot
.982 .57518 Mdot
.982 .5756 Mdot
.982 .57626 Mdot
.982 .57656 Mdot
.982 .57688 Mdot
.982 .57719 Mdot
.982 .57797 Mdot
.982 .57799 Mdot
.982 .57814 Mdot
.982 .5782 Mdot
.982 .57833 Mdot
.982 .57884 Mdot
.982 .5793 Mdot
.982 .57947 Mdot
.982 .58102 Mdot
.982 .58105 Mdot
.982 .58214 Mdot
.982 .58312 Mdot
.982 .58546 Mdot
.982 .58577 Mdot
.982 .58655 Mdot
.982 .58728 Mdot
.982 .5878 Mdot
.982 .58818 Mdot
.982 .58882 Mdot
.982 .58904 Mdot
.982 .59024 Mdot
.982 .59024 Mdot
.982 .59036 Mdot
.982 .59095 Mdot
.982 .5913 Mdot
.982 .59208 Mdot
.982 .59222 Mdot
.982 .5926 Mdot
.982 .59264 Mdot
.982 .59265 Mdot
.982 .59327 Mdot
.982 .59368 Mdot
.984 .03355 Mdot
.984 .03405 Mdot
.984 .03596 Mdot
.984 .03677 Mdot
.984 .03705 Mdot
.984 .03879 Mdot
.984 .03899 Mdot
.984 .03917 Mdot
.984 .04025 Mdot
.984 .04033 Mdot
.984 .04055 Mdot
.984 .04065 Mdot
.984 .04081 Mdot
.984 .04262 Mdot
.984 .04363 Mdot
.984 .04431 Mdot
.984 .04488 Mdot
.984 .04602 Mdot
.984 .04734 Mdot
.984 .04757 Mdot
.984 .04768 Mdot
.984 .049 Mdot
.984 .04911 Mdot
.984 .05178 Mdot
.984 .05222 Mdot
.984 .05255 Mdot
.984 .05272 Mdot
.984 .05276 Mdot
.984 .05341 Mdot
.984 .05379 Mdot
.984 .05457 Mdot
.984 .0546 Mdot
.984 .05564 Mdot
.984 .05601 Mdot
.984 .05652 Mdot
.984 .05795 Mdot
.984 .05805 Mdot
.984 .05811 Mdot
.984 .05867 Mdot
.984 .0588 Mdot
.984 .05956 Mdot
.984 .05997 Mdot
.984 .06106 Mdot
.984 .0621 Mdot
.984 .06215 Mdot
.984 .06222 Mdot
.984 .06249 Mdot
.984 .06283 Mdot
.984 .06284 Mdot
.984 .06287 Mdot
.984 .06292 Mdot
.984 .06409 Mdot
.984 .06497 Mdot
.984 .06512 Mdot
.984 .06529 Mdot
.984 .06544 Mdot
.984 .06555 Mdot
.984 .06576 Mdot
.984 .06607 Mdot
.984 .06644 Mdot
.984 .06722 Mdot
.984 .06778 Mdot
.984 .06827 Mdot
.984 .06847 Mdot
.984 .06855 Mdot
.984 .06963 Mdot
.984 .07032 Mdot
.984 .07096 Mdot
.984 .07161 Mdot
.984 .07295 Mdot
.984 .07408 Mdot
.984 .07465 Mdot
.984 .07527 Mdot
.984 .07633 Mdot
.984 .07674 Mdot
.984 .0771 Mdot
.984 .07892 Mdot
.984 .07937 Mdot
.984 .07959 Mdot
.984 .08146 Mdot
.984 .08152 Mdot
.984 .08189 Mdot
.984 .08213 Mdot
.984 .08219 Mdot
.984 .0824 Mdot
.984 .08271 Mdot
.984 .0867 Mdot
.984 .08717 Mdot
.984 .08767 Mdot
.984 .08853 Mdot
.984 .0889 Mdot
.984 .08918 Mdot
.984 .08936 Mdot
.984 .08951 Mdot
.984 .08958 Mdot
.984 .09063 Mdot
.984 .09086 Mdot
.984 .09161 Mdot
.984 .09193 Mdot
.984 .0923 Mdot
.984 .09314 Mdot
.984 .09321 Mdot
.984 .09526 Mdot
.984 .09591 Mdot
.984 .09598 Mdot
.984 .09692 Mdot
.984 .09699 Mdot
.984 .0972 Mdot
.984 .09822 Mdot
.984 .09897 Mdot
.984 .09937 Mdot
.984 .09971 Mdot
.984 .09975 Mdot
.984 .0998 Mdot
.984 .09999 Mdot
.984 .10012 Mdot
.984 .10122 Mdot
.984 .10147 Mdot
.984 .10195 Mdot
.984 .10198 Mdot
.984 .10298 Mdot
.984 .10378 Mdot
.984 .10494 Mdot
.984 .10542 Mdot
.984 .10592 Mdot
.984 .10748 Mdot
.984 .10796 Mdot
.984 .10806 Mdot
.984 .1082 Mdot
.984 .10873 Mdot
.984 .1088 Mdot
.984 .1094 Mdot
.984 .1094 Mdot
.984 .10943 Mdot
.984 .10948 Mdot
.984 .10952 Mdot
.984 .10958 Mdot
.984 .1098 Mdot
.984 .10983 Mdot
.984 .10994 Mdot
.984 .11131 Mdot
.984 .11189 Mdot
.984 .11361 Mdot
.984 .11391 Mdot
.984 .11426 Mdot
.984 .11455 Mdot
.984 .11476 Mdot
.984 .11517 Mdot
.984 .11521 Mdot
.984 .11579 Mdot
.984 .11652 Mdot
.984 .11804 Mdot
.984 .11915 Mdot
.984 .12 Mdot
.984 .12011 Mdot
.984 .1205 Mdot
.984 .12067 Mdot
.984 .12116 Mdot
.984 .12279 Mdot
.984 .12387 Mdot
.984 .12415 Mdot
.984 .12466 Mdot
.984 .12504 Mdot
.984 .1254 Mdot
.984 .12669 Mdot
.984 .12809 Mdot
.984 .12809 Mdot
.984 .1286 Mdot
.984 .12882 Mdot
.984 .12932 Mdot
.984 .13017 Mdot
.984 .13059 Mdot
.984 .13155 Mdot
.984 .13267 Mdot
.984 .13388 Mdot
.984 .13399 Mdot
.984 .13597 Mdot
.984 .13679 Mdot
.984 .13679 Mdot
.984 .13749 Mdot
.984 .13801 Mdot
.984 .13821 Mdot
.984 .13925 Mdot
.984 .1395 Mdot
.984 .14034 Mdot
.984 .14108 Mdot
.984 .14161 Mdot
.984 .14194 Mdot
.984 .14195 Mdot
.984 .14238 Mdot
.984 .14319 Mdot
.984 .14347 Mdot
.984 .14371 Mdot
.984 .14517 Mdot
.984 .14537 Mdot
.984 .14607 Mdot
.984 .14619 Mdot
.984 .14692 Mdot
.984 .14739 Mdot
.984 .1475 Mdot
.984 .14793 Mdot
.984 .14852 Mdot
.984 .14993 Mdot
.984 .15012 Mdot
.984 .15039 Mdot
.984 .15262 Mdot
.984 .1546 Mdot
.984 .15487 Mdot
.984 .15588 Mdot
.984 .15639 Mdot
.984 .15686 Mdot
.984 .15691 Mdot
.984 .15731 Mdot
.984 .15828 Mdot
.984 .15886 Mdot
.984 .15999 Mdot
.984 .16041 Mdot
.984 .16072 Mdot
.984 .16072 Mdot
.984 .16116 Mdot
.984 .16126 Mdot
.984 .16137 Mdot
.984 .16162 Mdot
.984 .16167 Mdot
.984 .16181 Mdot
.984 .16191 Mdot
.984 .16205 Mdot
.984 .16272 Mdot
.984 .16369 Mdot
.984 .16411 Mdot
.984 .16451 Mdot
.984 .16457 Mdot
.984 .16495 Mdot
.984 .16538 Mdot
.984 .16583 Mdot
.984 .16605 Mdot
.984 .16645 Mdot
.984 .16666 Mdot
.984 .16709 Mdot
.984 .16739 Mdot
.984 .1681 Mdot
.984 .16906 Mdot
.984 .16919 Mdot
.984 .16955 Mdot
.984 .17003 Mdot
.984 .17098 Mdot
.984 .17196 Mdot
.984 .17322 Mdot
.984 .17361 Mdot
.984 .17451 Mdot
.984 .17459 Mdot
.984 .17464 Mdot
.984 .17649 Mdot
.984 .17664 Mdot
.984 .17704 Mdot
.984 .17818 Mdot
.984 .17906 Mdot
.984 .17993 Mdot
.984 .18052 Mdot
.984 .18132 Mdot
.984 .18145 Mdot
.984 .18199 Mdot
.984 .18207 Mdot
.984 .18216 Mdot
.984 .18254 Mdot
.984 .18267 Mdot
.984 .1828 Mdot
.984 .18361 Mdot
.984 .18495 Mdot
.984 .18497 Mdot
.984 .18545 Mdot
.984 .1864 Mdot
.984 .18645 Mdot
.984 .18838 Mdot
.984 .18842 Mdot
.984 .18849 Mdot
.984 .18964 Mdot
.984 .18999 Mdot
.984 .19217 Mdot
.984 .19227 Mdot
.984 .19257 Mdot
.984 .19322 Mdot
.984 .1942 Mdot
.984 .19437 Mdot
.984 .19653 Mdot
.984 .19683 Mdot
.984 .19707 Mdot
.984 .19727 Mdot
.984 .19822 Mdot
.984 .19842 Mdot
.984 .19867 Mdot
.984 .1987 Mdot
.984 .19945 Mdot
.984 .19974 Mdot
.984 .19978 Mdot
.984 .19987 Mdot
.984 .19993 Mdot
.984 .20105 Mdot
.984 .20106 Mdot
.984 .20111 Mdot
.984 .20122 Mdot
.984 .2013 Mdot
.984 .2014 Mdot
.984 .20185 Mdot
.984 .20191 Mdot
.984 .20212 Mdot
.984 .20268 Mdot
.984 .20482 Mdot
.984 .20593 Mdot
.984 .20596 Mdot
.984 .20601 Mdot
.984 .20647 Mdot
.984 .20723 Mdot
.984 .20855 Mdot
.984 .20935 Mdot
.984 .20967 Mdot
.984 .20993 Mdot
.984 .21061 Mdot
.984 .21081 Mdot
.984 .21119 Mdot
.984 .2116 Mdot
.984 .21241 Mdot
.984 .21249 Mdot
.984 .21262 Mdot
.984 .21362 Mdot
.984 .21454 Mdot
.984 .2148 Mdot
.984 .21506 Mdot
.984 .21537 Mdot
.984 .21806 Mdot
.984 .21824 Mdot
.984 .22025 Mdot
.984 .22114 Mdot
.984 .22192 Mdot
.984 .22213 Mdot
.984 .2229 Mdot
.984 .22323 Mdot
.984 .22409 Mdot
.984 .2242 Mdot
.984 .22465 Mdot
.984 .22488 Mdot
.984 .22508 Mdot
.984 .2265 Mdot
.984 .22657 Mdot
.984 .22678 Mdot
.984 .22741 Mdot
.984 .22952 Mdot
.984 .22955 Mdot
.984 .22996 Mdot
.984 .23009 Mdot
.984 .23009 Mdot
.984 .23109 Mdot
.984 .23184 Mdot
.984 .23196 Mdot
.984 .23198 Mdot
.984 .23255 Mdot
.984 .23451 Mdot
.984 .23507 Mdot
.984 .23511 Mdot
.984 .23598 Mdot
.984 .23784 Mdot
.984 .23785 Mdot
.984 .23856 Mdot
.984 .23883 Mdot
.984 .23928 Mdot
.984 .23998 Mdot
.984 .24026 Mdot
.984 .24192 Mdot
.984 .24276 Mdot
.984 .24343 Mdot
.984 .24419 Mdot
.984 .24465 Mdot
.984 .24531 Mdot
.984 .24532 Mdot
.984 .24643 Mdot
.984 .24685 Mdot
.984 .2469 Mdot
.984 .24923 Mdot
.984 .24944 Mdot
.984 .25144 Mdot
.984 .25157 Mdot
.984 .25334 Mdot
.984 .25495 Mdot
.984 .25495 Mdot
.984 .25633 Mdot
.984 .25736 Mdot
.984 .25774 Mdot
.984 .2584 Mdot
.984 .25888 Mdot
.984 .25892 Mdot
.984 .25979 Mdot
.984 .25981 Mdot
.984 .26018 Mdot
.984 .26023 Mdot
.984 .26029 Mdot
.984 .26194 Mdot
.984 .26339 Mdot
.984 .26444 Mdot
.984 .26479 Mdot
.984 .2651 Mdot
.984 .26512 Mdot
.984 .26596 Mdot
.984 .26667 Mdot
.984 .26747 Mdot
.984 .26755 Mdot
.984 .26811 Mdot
.984 .26857 Mdot
.984 .27144 Mdot
.984 .27183 Mdot
.984 .27321 Mdot
.984 .27347 Mdot
.984 .27489 Mdot
.984 .27582 Mdot
.984 .27603 Mdot
.984 .27628 Mdot
.984 .27651 Mdot
.984 .27663 Mdot
.984 .27668 Mdot
.984 .27688 Mdot
.984 .27804 Mdot
.984 .27831 Mdot
.984 .27889 Mdot
.984 .27946 Mdot
.984 .28076 Mdot
.984 .28081 Mdot
.984 .28119 Mdot
.984 .28173 Mdot
.984 .28227 Mdot
.984 .28234 Mdot
.984 .28261 Mdot
.984 .28266 Mdot
.984 .2837 Mdot
.984 .28522 Mdot
.984 .28611 Mdot
.984 .28701 Mdot
.984 .28854 Mdot
.984 .28955 Mdot
.984 .28993 Mdot
.984 .29001 Mdot
.984 .29054 Mdot
.984 .29107 Mdot
.984 .2912 Mdot
.984 .29196 Mdot
.984 .29254 Mdot
.984 .29255 Mdot
.984 .29293 Mdot
.984 .2932 Mdot
.984 .29327 Mdot
.984 .29353 Mdot
.984 .29446 Mdot
.984 .29456 Mdot
.984 .29534 Mdot
.984 .29579 Mdot
.984 .29694 Mdot
.984 .29726 Mdot
.984 .29839 Mdot
.984 .29886 Mdot
.984 .30061 Mdot
.984 .30079 Mdot
.984 .30114 Mdot
.984 .30139 Mdot
.984 .30143 Mdot
.984 .30205 Mdot
.984 .30206 Mdot
.984 .30207 Mdot
.984 .30223 Mdot
.984 .30253 Mdot
.984 .30291 Mdot
.984 .30311 Mdot
.984 .3033 Mdot
.984 .30333 Mdot
.984 .30383 Mdot
.984 .30393 Mdot
.984 .30419 Mdot
.984 .3044 Mdot
.984 .3045 Mdot
.984 .30468 Mdot
.984 .30598 Mdot
.984 .30601 Mdot
.984 .3067 Mdot
.984 .30775 Mdot
.984 .3079 Mdot
.984 .30873 Mdot
.984 .3088 Mdot
.984 .3095 Mdot
.984 .30963 Mdot
.984 .31039 Mdot
.984 .31112 Mdot
.984 .31117 Mdot
.984 .31121 Mdot
.984 .31151 Mdot
.984 .31157 Mdot
.984 .3116 Mdot
.984 .31211 Mdot
.984 .31236 Mdot
.984 .31254 Mdot
.984 .31298 Mdot
.984 .31332 Mdot
.984 .31375 Mdot
.984 .31378 Mdot
.984 .31458 Mdot
.984 .31467 Mdot
.984 .31519 Mdot
.984 .31658 Mdot
.984 .31715 Mdot
.984 .31765 Mdot
.984 .31846 Mdot
.984 .31873 Mdot
.984 .3188 Mdot
.984 .31926 Mdot
.984 .31942 Mdot
.984 .32038 Mdot
.984 .32092 Mdot
.984 .32215 Mdot
.984 .32224 Mdot
.984 .32231 Mdot
.984 .32349 Mdot
.984 .32417 Mdot
.984 .3245 Mdot
.984 .32665 Mdot
.984 .32676 Mdot
.984 .32742 Mdot
.984 .32919 Mdot
.984 .32935 Mdot
.984 .32945 Mdot
.984 .32949 Mdot
.984 .33208 Mdot
.984 .33308 Mdot
.984 .33339 Mdot
.984 .33417 Mdot
.984 .3343 Mdot
.984 .33436 Mdot
.984 .33471 Mdot
.984 .33482 Mdot
.984 .33642 Mdot
.984 .33734 Mdot
.984 .33775 Mdot
.984 .33807 Mdot
.984 .33814 Mdot
.984 .33981 Mdot
.984 .33986 Mdot
.984 .34102 Mdot
.984 .3416 Mdot
.984 .34161 Mdot
.984 .34212 Mdot
.984 .3426 Mdot
.984 .34284 Mdot
.984 .34369 Mdot
.984 .3438 Mdot
.984 .34392 Mdot
.984 .34408 Mdot
.984 .34424 Mdot
.984 .34488 Mdot
.984 .345 Mdot
.984 .34525 Mdot
.984 .3455 Mdot
.984 .34711 Mdot
.984 .34826 Mdot
.984 .34851 Mdot
.984 .34886 Mdot
.984 .34974 Mdot
.984 .34977 Mdot
.984 .35006 Mdot
.984 .35072 Mdot
.984 .35198 Mdot
.984 .3524 Mdot
.984 .3526 Mdot
.984 .35268 Mdot
.984 .35441 Mdot
.984 .35524 Mdot
.984 .35553 Mdot
.984 .35649 Mdot
.984 .35656 Mdot
.984 .35671 Mdot
.984 .3582 Mdot
.984 .35896 Mdot
.984 .35966 Mdot
.984 .361 Mdot
.984 .36181 Mdot
.984 .3627 Mdot
.984 .36395 Mdot
.984 .36415 Mdot
.984 .36443 Mdot
.984 .36473 Mdot
.984 .36485 Mdot
.984 .36602 Mdot
.984 .36794 Mdot
.984 .36818 Mdot
.984 .36828 Mdot
.984 .36829 Mdot
.984 .36947 Mdot
.984 .37243 Mdot
.984 .37252 Mdot
.984 .37311 Mdot
.984 .37326 Mdot
.984 .37359 Mdot
.984 .37398 Mdot
.984 .374 Mdot
.984 .37435 Mdot
.984 .3756 Mdot
.984 .37586 Mdot
.984 .37625 Mdot
.984 .37629 Mdot
.984 .37648 Mdot
.984 .37673 Mdot
.984 .3768 Mdot
.984 .37682 Mdot
.984 .37777 Mdot
.984 .37826 Mdot
.984 .37876 Mdot
.984 .37885 Mdot
.984 .37892 Mdot
.984 .37909 Mdot
.984 .37921 Mdot
.984 .37972 Mdot
.984 .38029 Mdot
.984 .38143 Mdot
.984 .38144 Mdot
.984 .38153 Mdot
.984 .38175 Mdot
.984 .38191 Mdot
.984 .38212 Mdot
.984 .38235 Mdot
.984 .38299 Mdot
.984 .38312 Mdot
.984 .38353 Mdot
.984 .38396 Mdot
.984 .38462 Mdot
.984 .38547 Mdot
.984 .38617 Mdot
.984 .38752 Mdot
.984 .3882 Mdot
.984 .38839 Mdot
.984 .38884 Mdot
.984 .39015 Mdot
.984 .39102 Mdot
.984 .39108 Mdot
.984 .39117 Mdot
.984 .39149 Mdot
.984 .39209 Mdot
.984 .39359 Mdot
.984 .39619 Mdot
.984 .39767 Mdot
.984 .39776 Mdot
.984 .39808 Mdot
.984 .39831 Mdot
.984 .39839 Mdot
.984 .39864 Mdot
.984 .3989 Mdot
.984 .39929 Mdot
.984 .39982 Mdot
.984 .40024 Mdot
.984 .40063 Mdot
.984 .40081 Mdot
.984 .40138 Mdot
.984 .40183 Mdot
.984 .40218 Mdot
.984 .40378 Mdot
.984 .40388 Mdot
.984 .40394 Mdot
.984 .4042 Mdot
.984 .40538 Mdot
.984 .40617 Mdot
.984 .40693 Mdot
.984 .40797 Mdot
.984 .40849 Mdot
.984 .40899 Mdot
.984 .40926 Mdot
.984 .40959 Mdot
.984 .40976 Mdot
.984 .40988 Mdot
.984 .41009 Mdot
.984 .41323 Mdot
.984 .41391 Mdot
.984 .4148 Mdot
.984 .4149 Mdot
.984 .41524 Mdot
.984 .41593 Mdot
.984 .41629 Mdot
.984 .41705 Mdot
.984 .41787 Mdot
.984 .41892 Mdot
.984 .41921 Mdot
.984 .41969 Mdot
.984 .4202 Mdot
.984 .42068 Mdot
.984 .42085 Mdot
.984 .42095 Mdot
.984 .4213 Mdot
.984 .42194 Mdot
.984 .42211 Mdot
.984 .42249 Mdot
.984 .42291 Mdot
.984 .42442 Mdot
.984 .42502 Mdot
.984 .42507 Mdot
.984 .42676 Mdot
.984 .42698 Mdot
.984 .42786 Mdot
.984 .42831 Mdot
.984 .42872 Mdot
.984 .43014 Mdot
.984 .4315 Mdot
.984 .43165 Mdot
.984 .43207 Mdot
.984 .43309 Mdot
.984 .4333 Mdot
.984 .43428 Mdot
.984 .43489 Mdot
.984 .43507 Mdot
.984 .43519 Mdot
.984 .43691 Mdot
.984 .43746 Mdot
.984 .43752 Mdot
.984 .43832 Mdot
.984 .43857 Mdot
.984 .43858 Mdot
.984 .43949 Mdot
.984 .44037 Mdot
.984 .44053 Mdot
.984 .44074 Mdot
.984 .44202 Mdot
.984 .44208 Mdot
.984 .44226 Mdot
.984 .44229 Mdot
.984 .44341 Mdot
.984 .44473 Mdot
.984 .44612 Mdot
.984 .44727 Mdot
.984 .44778 Mdot
.984 .44838 Mdot
.984 .44846 Mdot
.984 .44909 Mdot
.984 .44993 Mdot
.984 .45016 Mdot
.984 .45075 Mdot
.984 .451 Mdot
.984 .45226 Mdot
.984 .45271 Mdot
.984 .45312 Mdot
.984 .45343 Mdot
.984 .45382 Mdot
.984 .45384 Mdot
.984 .45387 Mdot
.984 .45404 Mdot
.984 .45407 Mdot
.984 .45524 Mdot
.984 .45578 Mdot
.984 .45631 Mdot
.984 .45666 Mdot
.984 .45743 Mdot
.984 .45804 Mdot
.984 .45843 Mdot
.984 .45858 Mdot
.984 .45866 Mdot
.984 .45901 Mdot
.984 .45914 Mdot
.984 .45931 Mdot
.984 .4603 Mdot
.984 .46127 Mdot
.984 .46186 Mdot
.984 .46314 Mdot
.984 .46317 Mdot
.984 .46331 Mdot
.984 .4635 Mdot
.984 .4638 Mdot
.984 .46419 Mdot
.984 .46425 Mdot
.984 .46483 Mdot
.984 .46502 Mdot
.984 .46554 Mdot
.984 .46632 Mdot
.984 .46723 Mdot
.984 .468 Mdot
.984 .46853 Mdot
.984 .46855 Mdot
.984 .46869 Mdot
.984 .46872 Mdot
.984 .46949 Mdot
.984 .47015 Mdot
.984 .47044 Mdot
.984 .47074 Mdot
.984 .47156 Mdot
.984 .47159 Mdot
.984 .47165 Mdot
.984 .47177 Mdot
.984 .47624 Mdot
.984 .47665 Mdot
.984 .47761 Mdot
.984 .47992 Mdot
.984 .47995 Mdot
.984 .48014 Mdot
.984 .48059 Mdot
.984 .48061 Mdot
.984 .48085 Mdot
.984 .48432 Mdot
.984 .48439 Mdot
.984 .4867 Mdot
.984 .48693 Mdot
.984 .4875 Mdot
.984 .48751 Mdot
.984 .48752 Mdot
.984 .48808 Mdot
.984 .48846 Mdot
.984 .49021 Mdot
.984 .49093 Mdot
.984 .49225 Mdot
.984 .49269 Mdot
.984 .49299 Mdot
.984 .49428 Mdot
.984 .49429 Mdot
.984 .49524 Mdot
.984 .49531 Mdot
.984 .49551 Mdot
.984 .49692 Mdot
.984 .49703 Mdot
.984 .49707 Mdot
.984 .49778 Mdot
.984 .49789 Mdot
.984 .49801 Mdot
.984 .49829 Mdot
.984 .49979 Mdot
.984 .50126 Mdot
.984 .50272 Mdot
.984 .50301 Mdot
.984 .50314 Mdot
.984 .50412 Mdot
.984 .50504 Mdot
.984 .50561 Mdot
.984 .50618 Mdot
.984 .50685 Mdot
.984 .50724 Mdot
.984 .50748 Mdot
.984 .50752 Mdot
.984 .50917 Mdot
.984 .51057 Mdot
.984 .51064 Mdot
.984 .51081 Mdot
.984 .51121 Mdot
.984 .51202 Mdot
.984 .51214 Mdot
.984 .51229 Mdot
.984 .51339 Mdot
.984 .51431 Mdot
.984 .51451 Mdot
.984 .5158 Mdot
.984 .51638 Mdot
.984 .51643 Mdot
.984 .51817 Mdot
.984 .51886 Mdot
.984 .51934 Mdot
.984 .51996 Mdot
.984 .52073 Mdot
.984 .52162 Mdot
.984 .52344 Mdot
.984 .52394 Mdot
.984 .52478 Mdot
.984 .52527 Mdot
.984 .52576 Mdot
.984 .526 Mdot
.984 .52674 Mdot
.984 .52725 Mdot
.984 .52758 Mdot
.984 .52789 Mdot
.984 .52812 Mdot
.984 .52834 Mdot
.984 .52856 Mdot
.984 .52898 Mdot
.984 .52947 Mdot
.984 .52994 Mdot
.984 .53 Mdot
.984 .53016 Mdot
.984 .53027 Mdot
.984 .53049 Mdot
.984 .53065 Mdot
.984 .53144 Mdot
.984 .53242 Mdot
.984 .53245 Mdot
.984 .53295 Mdot
.984 .53346 Mdot
.984 .5336 Mdot
.984 .53461 Mdot
.984 .53574 Mdot
.984 .53588 Mdot
.984 .53597 Mdot
.984 .53829 Mdot
.984 .53839 Mdot
.984 .53913 Mdot
.984 .53925 Mdot
.984 .5394 Mdot
.984 .54003 Mdot
.984 .5402 Mdot
.984 .54084 Mdot
.984 .54127 Mdot
.984 .5414 Mdot
.984 .54193 Mdot
.984 .54203 Mdot
.984 .54265 Mdot
.984 .54407 Mdot
.984 .5458 Mdot
.984 .54601 Mdot
.984 .5467 Mdot
.984 .54681 Mdot
.984 .54707 Mdot
.984 .54707 Mdot
.984 .54862 Mdot
.984 .54881 Mdot
.984 .54921 Mdot
.984 .55059 Mdot
.984 .55118 Mdot
.984 .55361 Mdot
.984 .55559 Mdot
.984 .55629 Mdot
.984 .55634 Mdot
.984 .55636 Mdot
.984 .5565 Mdot
.984 .55656 Mdot
.984 .55687 Mdot
.984 .55754 Mdot
.984 .55859 Mdot
.984 .55883 Mdot
.984 .56034 Mdot
.984 .56035 Mdot
.984 .56147 Mdot
.984 .56149 Mdot
.984 .56166 Mdot
.984 .56187 Mdot
.984 .56224 Mdot
.984 .56277 Mdot
.984 .56291 Mdot
.984 .56342 Mdot
.984 .56526 Mdot
.984 .56544 Mdot
.984 .5661 Mdot
.984 .56675 Mdot
.984 .56698 Mdot
.984 .56786 Mdot
.984 .5681 Mdot
.984 .57013 Mdot
.984 .57042 Mdot
.984 .57054 Mdot
.984 .57073 Mdot
.984 .57076 Mdot
.984 .57298 Mdot
.984 .57316 Mdot
.984 .57391 Mdot
.984 .57422 Mdot
.984 .5761 Mdot
.984 .57642 Mdot
.984 .57732 Mdot
.984 .57736 Mdot
.984 .57747 Mdot
.984 .57771 Mdot
.984 .578 Mdot
.984 .57839 Mdot
.984 .5789 Mdot
.984 .57898 Mdot
.984 .57959 Mdot
.984 .58018 Mdot
.984 .58021 Mdot
.984 .58023 Mdot
.984 .58054 Mdot
.984 .58058 Mdot
.984 .58113 Mdot
.984 .58168 Mdot
.984 .58189 Mdot
.984 .58228 Mdot
.984 .58266 Mdot
.984 .58271 Mdot
.984 .5837 Mdot
.984 .58388 Mdot
.984 .58441 Mdot
.984 .58443 Mdot
.984 .58482 Mdot
.984 .58502 Mdot
.984 .58537 Mdot
.984 .58545 Mdot
.984 .58562 Mdot
.984 .5872 Mdot
.984 .58726 Mdot
.984 .58793 Mdot
.984 .58798 Mdot
.984 .5881 Mdot
.984 .58877 Mdot
.984 .58935 Mdot
.984 .58964 Mdot
.984 .58999 Mdot
.984 .5905 Mdot
.984 .59142 Mdot
.984 .5915 Mdot
.984 .59155 Mdot
.984 .59166 Mdot
.984 .5917 Mdot
.984 .59225 Mdot
.984 .59234 Mdot
.984 .59244 Mdot
.984 .59333 Mdot
.984 .59347 Mdot
.984 .59388 Mdot
.984 .59486 Mdot
.984 .59511 Mdot
.986 .03238 Mdot
.986 .03244 Mdot
.986 .03284 Mdot
.986 .0329 Mdot
.986 .03434 Mdot
.986 .03701 Mdot
.986 .03778 Mdot
.986 .03938 Mdot
.986 .03947 Mdot
.986 .03974 Mdot
.986 .04083 Mdot
.986 .04234 Mdot
.986 .04289 Mdot
.986 .04351 Mdot
.986 .04483 Mdot
.986 .0451 Mdot
.986 .04584 Mdot
.986 .0459 Mdot
.986 .04711 Mdot
.986 .04764 Mdot
.986 .048 Mdot
.986 .04872 Mdot
.986 .04892 Mdot
.986 .04955 Mdot
.986 .04966 Mdot
.986 .05046 Mdot
.986 .05058 Mdot
.986 .05149 Mdot
.986 .05341 Mdot
.986 .05375 Mdot
.986 .05513 Mdot
.986 .05609 Mdot
.986 .05869 Mdot
.986 .05918 Mdot
.986 .06014 Mdot
.986 .06021 Mdot
.986 .06039 Mdot
.986 .06239 Mdot
.986 .0629 Mdot
.986 .06335 Mdot
.986 .06352 Mdot
.986 .0636 Mdot
.986 .06366 Mdot
.986 .06407 Mdot
.986 .06621 Mdot
.986 .06721 Mdot
.986 .06865 Mdot
.986 .06909 Mdot
.986 .06919 Mdot
.986 .06919 Mdot
.986 .06935 Mdot
.986 .07028 Mdot
.986 .07079 Mdot
.986 .07149 Mdot
.986 .07379 Mdot
.986 .0741 Mdot
.986 .07464 Mdot
.986 .07552 Mdot
.986 .07587 Mdot
.986 .07595 Mdot
.986 .0761 Mdot
.986 .07621 Mdot
.986 .07634 Mdot
.986 .0786 Mdot
.986 .07892 Mdot
.986 .0795 Mdot
.986 .07965 Mdot
.986 .07969 Mdot
.986 .07979 Mdot
.986 .08035 Mdot
.986 .08056 Mdot
.986 .08166 Mdot
.986 .08177 Mdot
.986 .08217 Mdot
.986 .08278 Mdot
.986 .0834 Mdot
.986 .08362 Mdot
.986 .08437 Mdot
.986 .0852 Mdot
.986 .08544 Mdot
.986 .08607 Mdot
.986 .08715 Mdot
.986 .08757 Mdot
.986 .08891 Mdot
.986 .08907 Mdot
.986 .08966 Mdot
.986 .08974 Mdot
.986 .09017 Mdot
.986 .09102 Mdot
.986 .09169 Mdot
.986 .09441 Mdot
.986 .09628 Mdot
.986 .09631 Mdot
.986 .09786 Mdot
.986 .099 Mdot
.986 .10142 Mdot
.986 .1023 Mdot
.986 .1024 Mdot
.986 .1043 Mdot
.986 .10443 Mdot
.986 .10478 Mdot
.986 .10504 Mdot
.986 .1085 Mdot
.986 .10872 Mdot
.986 .10902 Mdot
.986 .1093 Mdot
.986 .10973 Mdot
.986 .10984 Mdot
.986 .11061 Mdot
.986 .11062 Mdot
.986 .11097 Mdot
.986 .11111 Mdot
.986 .11123 Mdot
.986 .11205 Mdot
.986 .11214 Mdot
.986 .1125 Mdot
.986 .11512 Mdot
.986 .1152 Mdot
.986 .11539 Mdot
.986 .11626 Mdot
.986 .11742 Mdot
.986 .11783 Mdot
.986 .11823 Mdot
.986 .12108 Mdot
.986 .12174 Mdot
.986 .12193 Mdot
.986 .12213 Mdot
.986 .12214 Mdot
.986 .12245 Mdot
.986 .12306 Mdot
.986 .12429 Mdot
.986 .12471 Mdot
.986 .12529 Mdot
.986 .12597 Mdot
.986 .12617 Mdot
.986 .12668 Mdot
.986 .1279 Mdot
.986 .12801 Mdot
.986 .1289 Mdot
.986 .13121 Mdot
.986 .13181 Mdot
.986 .13196 Mdot
.986 .13289 Mdot
.986 .13462 Mdot
.986 .13531 Mdot
.986 .13547 Mdot
.986 .13576 Mdot
.986 .13597 Mdot
.986 .13603 Mdot
.986 .13625 Mdot
.986 .13703 Mdot
.986 .13751 Mdot
.986 .13772 Mdot
.986 .13936 Mdot
.986 .13981 Mdot
.986 .14035 Mdot
.986 .14069 Mdot
.986 .1413 Mdot
.986 .14133 Mdot
.986 .14223 Mdot
.986 .14247 Mdot
.986 .14277 Mdot
.986 .14285 Mdot
.986 .14303 Mdot
.986 .14415 Mdot
.986 .14455 Mdot
.986 .14477 Mdot
.986 .14596 Mdot
.986 .14628 Mdot
.986 .14673 Mdot
.986 .14678 Mdot
.986 .14695 Mdot
.986 .14773 Mdot
.986 .14803 Mdot
.986 .14885 Mdot
.986 .14893 Mdot
.986 .14946 Mdot
.986 .15011 Mdot
.986 .15017 Mdot
.986 .15038 Mdot
.986 .1506 Mdot
.986 .15113 Mdot
.986 .15208 Mdot
.986 .1533 Mdot
.986 .15367 Mdot
.986 .15372 Mdot
.986 .15419 Mdot
.986 .155 Mdot
.986 .15543 Mdot
.986 .15579 Mdot
.986 .15665 Mdot
.986 .15712 Mdot
.986 .15755 Mdot
.986 .15805 Mdot
.986 .15839 Mdot
.986 .15844 Mdot
.986 .16103 Mdot
.986 .16133 Mdot
.986 .16246 Mdot
.986 .1625 Mdot
.986 .16267 Mdot
.986 .16352 Mdot
.986 .16405 Mdot
.986 .16518 Mdot
.986 .16539 Mdot
.986 .16578 Mdot
.986 .16624 Mdot
.986 .16652 Mdot
.986 .16921 Mdot
.986 .16927 Mdot
.986 .1701 Mdot
.986 .17162 Mdot
.986 .17168 Mdot
.986 .17187 Mdot
.986 .17557 Mdot
.986 .17562 Mdot
.986 .1763 Mdot
.986 .17707 Mdot
.986 .17819 Mdot
.986 .17868 Mdot
.986 .1788 Mdot
.986 .18075 Mdot
.986 .18092 Mdot
.986 .18244 Mdot
.986 .18264 Mdot
.986 .18516 Mdot
.986 .18519 Mdot
.986 .1855 Mdot
.986 .1857 Mdot
.986 .18656 Mdot
.986 .18693 Mdot
.986 .18744 Mdot
.986 .18762 Mdot
.986 .18789 Mdot
.986 .18923 Mdot
.986 .19098 Mdot
.986 .19121 Mdot
.986 .19137 Mdot
.986 .19163 Mdot
.986 .19232 Mdot
.986 .19284 Mdot
.986 .19359 Mdot
.986 .19408 Mdot
.986 .19476 Mdot
.986 .19515 Mdot
.986 .19534 Mdot
.986 .19547 Mdot
.986 .19611 Mdot
.986 .1984 Mdot
.986 .19931 Mdot
.986 .19966 Mdot
.986 .2001 Mdot
.986 .20024 Mdot
.986 .20069 Mdot
.986 .20124 Mdot
.986 .20169 Mdot
.986 .20208 Mdot
.986 .2023 Mdot
.986 .20383 Mdot
.986 .20383 Mdot
.986 .2042 Mdot
.986 .20451 Mdot
.986 .20452 Mdot
.986 .20457 Mdot
.986 .20467 Mdot
.986 .20476 Mdot
.986 .2048 Mdot
.986 .20505 Mdot
.986 .20629 Mdot
.986 .20647 Mdot
.986 .20665 Mdot
.986 .20684 Mdot
.986 .20713 Mdot
.986 .20741 Mdot
.986 .20755 Mdot
.986 .20844 Mdot
.986 .20948 Mdot
.986 .20984 Mdot
.986 .21006 Mdot
.986 .21014 Mdot
.986 .21027 Mdot
.986 .21049 Mdot
.986 .21063 Mdot
.986 .21188 Mdot
.986 .21204 Mdot
.986 .21271 Mdot
.986 .21287 Mdot
.986 .21326 Mdot
.986 .21464 Mdot
.986 .21495 Mdot
.986 .21577 Mdot
.986 .21631 Mdot
.986 .21656 Mdot
.986 .21725 Mdot
.986 .21806 Mdot
.986 .21877 Mdot
.986 .21884 Mdot
.986 .22218 Mdot
.986 .22225 Mdot
.986 .22366 Mdot
.986 .22447 Mdot
.986 .22448 Mdot
.986 .22468 Mdot
.986 .22471 Mdot
.986 .22576 Mdot
.986 .22615 Mdot
.986 .22654 Mdot
.986 .22655 Mdot
.986 .22658 Mdot
.986 .22716 Mdot
.986 .22837 Mdot
.986 .22972 Mdot
.986 .2308 Mdot
.986 .23162 Mdot
.986 .23247 Mdot
.986 .23277 Mdot
.986 .23282 Mdot
.986 .23287 Mdot
.986 .23412 Mdot
.986 .2345 Mdot
.986 .2348 Mdot
.986 .23551 Mdot
.986 .23564 Mdot
.986 .23588 Mdot
.986 .2361 Mdot
.986 .23644 Mdot
.986 .23705 Mdot
.986 .23738 Mdot
.986 .23791 Mdot
.986 .23813 Mdot
.986 .23825 Mdot
.986 .23859 Mdot
.986 .23989 Mdot
.986 .24014 Mdot
.986 .24057 Mdot
.986 .24124 Mdot
.986 .2436 Mdot
.986 .24444 Mdot
.986 .24563 Mdot
.986 .24591 Mdot
.986 .24592 Mdot
.986 .24612 Mdot
.986 .24776 Mdot
.986 .2478 Mdot
.986 .24823 Mdot
.986 .24832 Mdot
.986 .24962 Mdot
.986 .24983 Mdot
.986 .24987 Mdot
.986 .25028 Mdot
.986 .25084 Mdot
.986 .25117 Mdot
.986 .25209 Mdot
.986 .25253 Mdot
.986 .25284 Mdot
.986 .25331 Mdot
.986 .25342 Mdot
.986 .25384 Mdot
.986 .25395 Mdot
.986 .25438 Mdot
.986 .25503 Mdot
.986 .25563 Mdot
.986 .25592 Mdot
.986 .2564 Mdot
.986 .25687 Mdot
.986 .25729 Mdot
.986 .2586 Mdot
.986 .2594 Mdot
.986 .25989 Mdot
.986 .26015 Mdot
.986 .26052 Mdot
.986 .26141 Mdot
.986 .26205 Mdot
.986 .26247 Mdot
.986 .26314 Mdot
.986 .26354 Mdot
.986 .26365 Mdot
.986 .2638 Mdot
.986 .26433 Mdot
.986 .26441 Mdot
.986 .26458 Mdot
.986 .26462 Mdot
.986 .26618 Mdot
.986 .26665 Mdot
.986 .26724 Mdot
.986 .2674 Mdot
.986 .26759 Mdot
.986 .26776 Mdot
.986 .26901 Mdot
.986 .26935 Mdot
.986 .2696 Mdot
.986 .2697 Mdot
.986 .26997 Mdot
.986 .27005 Mdot
.986 .27005 Mdot
.986 .2707 Mdot
.986 .27075 Mdot
.986 .27119 Mdot
.986 .27169 Mdot
.986 .27185 Mdot
.986 .27354 Mdot
.986 .27416 Mdot
.986 .27492 Mdot
.986 .27504 Mdot
.986 .27514 Mdot
.986 .27548 Mdot
.986 .27703 Mdot
.986 .27761 Mdot
.986 .27825 Mdot
.986 .279 Mdot
.986 .27907 Mdot
.986 .27923 Mdot
.986 .27939 Mdot
.986 .28013 Mdot
.986 .28044 Mdot
.986 .28172 Mdot
.986 .28183 Mdot
.986 .28225 Mdot
.986 .28269 Mdot
.986 .28373 Mdot
.986 .28475 Mdot
.986 .2856 Mdot
.986 .288 Mdot
.986 .28804 Mdot
.986 .28874 Mdot
.986 .28883 Mdot
.986 .28956 Mdot
.986 .28977 Mdot
.986 .29136 Mdot
.986 .29221 Mdot
.986 .2925 Mdot
.986 .29291 Mdot
.986 .29459 Mdot
.986 .29461 Mdot
.986 .29554 Mdot
.986 .29638 Mdot
.986 .29723 Mdot
.986 .29737 Mdot
.986 .29804 Mdot
.986 .29814 Mdot
.986 .29947 Mdot
.986 .29984 Mdot
.986 .3015 Mdot
.986 .30214 Mdot
.986 .30245 Mdot
.986 .30324 Mdot
.986 .30385 Mdot
.986 .30443 Mdot
.986 .30542 Mdot
.986 .30555 Mdot
.986 .30607 Mdot
.986 .30614 Mdot
.986 .30648 Mdot
.986 .30664 Mdot
.986 .30752 Mdot
.986 .30815 Mdot
.986 .30884 Mdot
.986 .30921 Mdot
.986 .30933 Mdot
.986 .31005 Mdot
.986 .31017 Mdot
.986 .31144 Mdot
.986 .31185 Mdot
.986 .31194 Mdot
.986 .31222 Mdot
.986 .31261 Mdot
.986 .31351 Mdot
.986 .31353 Mdot
.986 .31407 Mdot
.986 .31425 Mdot
.986 .3143 Mdot
.986 .3159 Mdot
.986 .31719 Mdot
.986 .31777 Mdot
.986 .31808 Mdot
.986 .31809 Mdot
.986 .31901 Mdot
.986 .31938 Mdot
.986 .31949 Mdot
.986 .31952 Mdot
.986 .3207 Mdot
.986 .32114 Mdot
.986 .32123 Mdot
.986 .32222 Mdot
.986 .32224 Mdot
.986 .32244 Mdot
.986 .32272 Mdot
.986 .32342 Mdot
.986 .32413 Mdot
.986 .32424 Mdot
.986 .32459 Mdot
.986 .32463 Mdot
.986 .32491 Mdot
.986 .32874 Mdot
.986 .32976 Mdot
.986 .32997 Mdot
.986 .33017 Mdot
.986 .33133 Mdot
.986 .33192 Mdot
.986 .33202 Mdot
.986 .33303 Mdot
.986 .33337 Mdot
.986 .33412 Mdot
.986 .33417 Mdot
.986 .33461 Mdot
.986 .33487 Mdot
.986 .33696 Mdot
.986 .33709 Mdot
.986 .33782 Mdot
.986 .33806 Mdot
.986 .3383 Mdot
.986 .33934 Mdot
.986 .33947 Mdot
.986 .33979 Mdot
.986 .34059 Mdot
.986 .34124 Mdot
.986 .34158 Mdot
.986 .34201 Mdot
.986 .34213 Mdot
.986 .34247 Mdot
.986 .3435 Mdot
.986 .34525 Mdot
.986 .34547 Mdot
.986 .34587 Mdot
.986 .34706 Mdot
.986 .34726 Mdot
.986 .35084 Mdot
.986 .35089 Mdot
.986 .35151 Mdot
.986 .35191 Mdot
.986 .35195 Mdot
.986 .35298 Mdot
.986 .35359 Mdot
.986 .35423 Mdot
.986 .35431 Mdot
.986 .35433 Mdot
.986 .35435 Mdot
.986 .35438 Mdot
.986 .35532 Mdot
.986 .35569 Mdot
.986 .35576 Mdot
.986 .35579 Mdot
.986 .35589 Mdot
.986 .35621 Mdot
.986 .35721 Mdot
.986 .35741 Mdot
.986 .35886 Mdot
.986 .35945 Mdot
.986 .35951 Mdot
.986 .3615 Mdot
.986 .36159 Mdot
.986 .36161 Mdot
.986 .36232 Mdot
.986 .36238 Mdot
.986 .36244 Mdot
.986 .36268 Mdot
.986 .36277 Mdot
.986 .36308 Mdot
.986 .36359 Mdot
.986 .36496 Mdot
.986 .36558 Mdot
.986 .36591 Mdot
.986 .36598 Mdot
.986 .36623 Mdot
.986 .36746 Mdot
.986 .36766 Mdot
.986 .36843 Mdot
.986 .36949 Mdot
.986 .36976 Mdot
.986 .37053 Mdot
.986 .3709 Mdot
.986 .37099 Mdot
.986 .37105 Mdot
.986 .37117 Mdot
.986 .37134 Mdot
.986 .37242 Mdot
.986 .37618 Mdot
.986 .37694 Mdot
.986 .37748 Mdot
.986 .37873 Mdot
.986 .37942 Mdot
.986 .38001 Mdot
.986 .38026 Mdot
.986 .3803 Mdot
.986 .38058 Mdot
.986 .38145 Mdot
.986 .38194 Mdot
.986 .38253 Mdot
.986 .38255 Mdot
.986 .38344 Mdot
.986 .38352 Mdot
.986 .38419 Mdot
.986 .38433 Mdot
.986 .38458 Mdot
.986 .38464 Mdot
.986 .38471 Mdot
.986 .38519 Mdot
.986 .38626 Mdot
.986 .38736 Mdot
.986 .38764 Mdot
.986 .38766 Mdot
.986 .38837 Mdot
.986 .38899 Mdot
.986 .38902 Mdot
.986 .3891 Mdot
.986 .38931 Mdot
.986 .38947 Mdot
.986 .38956 Mdot
.986 .39006 Mdot
.986 .39051 Mdot
.986 .39097 Mdot
.986 .39249 Mdot
.986 .39285 Mdot
.986 .39321 Mdot
.986 .39322 Mdot
.986 .39358 Mdot
.986 .39416 Mdot
.986 .39417 Mdot
.986 .39471 Mdot
.986 .39499 Mdot
.986 .39582 Mdot
.986 .3959 Mdot
.986 .39627 Mdot
.986 .39674 Mdot
.986 .39712 Mdot
.986 .39846 Mdot
.986 .39879 Mdot
.986 .39944 Mdot
.986 .39951 Mdot
.986 .39994 Mdot
.986 .40009 Mdot
.986 .40035 Mdot
.986 .40065 Mdot
.986 .40078 Mdot
.986 .40105 Mdot
.986 .40226 Mdot
.986 .40351 Mdot
.986 .40353 Mdot
.986 .40384 Mdot
.986 .40419 Mdot
.986 .40517 Mdot
.986 .40549 Mdot
.986 .40566 Mdot
.986 .40604 Mdot
.986 .40624 Mdot
.986 .40643 Mdot
.986 .40718 Mdot
.986 .40752 Mdot
.986 .40815 Mdot
.986 .40897 Mdot
.986 .40958 Mdot
.986 .41008 Mdot
.986 .41076 Mdot
.986 .41119 Mdot
.986 .41138 Mdot
.986 .41142 Mdot
.986 .41226 Mdot
.986 .41274 Mdot
.986 .41388 Mdot
.986 .41411 Mdot
.986 .41571 Mdot
.986 .41627 Mdot
.986 .41681 Mdot
.986 .41705 Mdot
.986 .41712 Mdot
.986 .41725 Mdot
.986 .41766 Mdot
.986 .41816 Mdot
.986 .41846 Mdot
.986 .41931 Mdot
.986 .41944 Mdot
.986 .42072 Mdot
.986 .42138 Mdot
.986 .42384 Mdot
.986 .42398 Mdot
.986 .42401 Mdot
.986 .42477 Mdot
.986 .4257 Mdot
.986 .42643 Mdot
.986 .42658 Mdot
.986 .42676 Mdot
.986 .42822 Mdot
.986 .42835 Mdot
.986 .42838 Mdot
.986 .42877 Mdot
.986 .42878 Mdot
.986 .42882 Mdot
.986 .42983 Mdot
.986 .42986 Mdot
.986 .4309 Mdot
.986 .431 Mdot
.986 .43167 Mdot
.986 .43172 Mdot
.986 .43173 Mdot
.986 .43244 Mdot
.986 .43245 Mdot
.986 .43246 Mdot
.986 .43251 Mdot
.986 .43315 Mdot
.986 .43366 Mdot
.986 .43605 Mdot
.986 .43615 Mdot
.986 .43706 Mdot
.986 .43795 Mdot
.986 .43871 Mdot
.986 .43892 Mdot
.986 .4391 Mdot
.986 .43943 Mdot
.986 .43983 Mdot
.986 .44 Mdot
.986 .44006 Mdot
.986 .44083 Mdot
.986 .44127 Mdot
.986 .44246 Mdot
.986 .44268 Mdot
.986 .44271 Mdot
.986 .44326 Mdot
.986 .44412 Mdot
.986 .44471 Mdot
.986 .44481 Mdot
.986 .44492 Mdot
.986 .44544 Mdot
.986 .44738 Mdot
.986 .44754 Mdot
.986 .44813 Mdot
.986 .44849 Mdot
.986 .44863 Mdot
.986 .44873 Mdot
.986 .44874 Mdot
.986 .44924 Mdot
.986 .44951 Mdot
.986 .45011 Mdot
.986 .45037 Mdot
.986 .45083 Mdot
.986 .45084 Mdot
.986 .451 Mdot
.986 .45129 Mdot
.986 .45195 Mdot
.986 .45276 Mdot
.986 .45278 Mdot
.986 .45315 Mdot
.986 .45381 Mdot
.986 .45395 Mdot
.986 .45485 Mdot
.986 .45491 Mdot
.986 .45528 Mdot
.986 .45553 Mdot
.986 .4562 Mdot
.986 .45664 Mdot
.986 .45719 Mdot
.986 .45726 Mdot
.986 .45776 Mdot
.986 .45877 Mdot
.986 .45892 Mdot
.986 .45925 Mdot
.986 .46009 Mdot
.986 .46028 Mdot
.986 .46142 Mdot
.986 .46275 Mdot
.986 .46381 Mdot
.986 .4653 Mdot
.986 .46607 Mdot
.986 .46774 Mdot
.986 .47008 Mdot
.986 .47062 Mdot
.986 .47066 Mdot
.986 .47104 Mdot
.986 .47273 Mdot
.986 .47429 Mdot
.986 .47437 Mdot
.986 .47487 Mdot
.986 .4752 Mdot
.986 .4752 Mdot
.986 .47538 Mdot
.986 .47543 Mdot
.986 .47555 Mdot
.986 .47573 Mdot
.986 .47645 Mdot
.986 .47795 Mdot
.986 .47797 Mdot
.986 .47837 Mdot
.986 .47844 Mdot
.986 .4785 Mdot
.986 .47926 Mdot
.986 .48035 Mdot
.986 .4806 Mdot
.986 .48101 Mdot
.986 .48212 Mdot
.986 .48251 Mdot
.986 .48282 Mdot
.986 .48369 Mdot
.986 .48431 Mdot
.986 .48494 Mdot
.986 .48522 Mdot
.986 .48543 Mdot
.986 .48545 Mdot
.986 .48556 Mdot
.986 .48622 Mdot
.986 .48626 Mdot
.986 .48648 Mdot
.986 .48733 Mdot
.986 .48744 Mdot
.986 .48861 Mdot
.986 .48981 Mdot
.986 .49015 Mdot
.986 .49037 Mdot
.986 .49115 Mdot
.986 .49132 Mdot
.986 .49176 Mdot
.986 .49193 Mdot
.986 .49224 Mdot
.986 .49241 Mdot
.986 .49253 Mdot
.986 .49265 Mdot
.986 .49307 Mdot
.986 .49405 Mdot
.986 .49408 Mdot
.986 .49426 Mdot
.986 .49565 Mdot
.986 .49724 Mdot
.986 .49819 Mdot
.986 .4982 Mdot
.986 .4983 Mdot
.986 .49872 Mdot
.986 .49944 Mdot
.986 .49947 Mdot
.986 .5012 Mdot
.986 .50232 Mdot
.986 .50245 Mdot
.986 .50272 Mdot
.986 .5033 Mdot
.986 .50461 Mdot
.986 .50469 Mdot
.986 .50533 Mdot
.986 .5054 Mdot
.986 .50551 Mdot
.986 .50558 Mdot
.986 .50562 Mdot
.986 .50573 Mdot
.986 .50591 Mdot
.986 .50644 Mdot
.986 .50696 Mdot
.986 .5071 Mdot
.986 .50744 Mdot
.986 .50753 Mdot
.986 .50831 Mdot
.986 .50835 Mdot
.986 .5084 Mdot
.986 .50843 Mdot
.986 .50859 Mdot
.986 .50986 Mdot
.986 .5106 Mdot
.986 .51107 Mdot
.986 .51153 Mdot
.986 .51269 Mdot
.986 .51302 Mdot
.986 .51309 Mdot
.986 .51318 Mdot
.986 .51338 Mdot
.986 .51372 Mdot
.986 .51397 Mdot
.986 .51518 Mdot
.986 .51529 Mdot
.986 .51618 Mdot
.986 .51686 Mdot
.986 .51735 Mdot
.986 .51754 Mdot
.986 .51807 Mdot
.986 .51823 Mdot
.986 .51824 Mdot
.986 .51952 Mdot
.986 .51963 Mdot
.986 .52048 Mdot
.986 .52147 Mdot
.986 .52178 Mdot
.986 .52235 Mdot
.986 .52274 Mdot
.986 .52508 Mdot
.986 .52511 Mdot
.986 .52588 Mdot
.986 .52631 Mdot
.986 .52633 Mdot
.986 .52784 Mdot
.986 .52807 Mdot
.986 .52827 Mdot
.986 .52895 Mdot
.986 .52976 Mdot
.986 .5318 Mdot
.986 .53199 Mdot
.986 .53246 Mdot
.986 .5327 Mdot
.986 .53314 Mdot
.986 .53354 Mdot
.986 .53421 Mdot
.986 .5344 Mdot
.986 .5355 Mdot
.986 .53588 Mdot
.986 .53602 Mdot
.986 .53635 Mdot
.986 .53666 Mdot
.986 .53707 Mdot
.986 .53771 Mdot
.986 .53796 Mdot
.986 .53812 Mdot
.986 .53873 Mdot
.986 .54001 Mdot
.986 .54049 Mdot
.986 .54097 Mdot
.986 .54124 Mdot
.986 .54147 Mdot
.986 .5423 Mdot
.986 .54241 Mdot
.986 .54265 Mdot
.986 .54316 Mdot
.986 .54522 Mdot
.986 .54677 Mdot
.986 .54723 Mdot
.986 .54728 Mdot
.986 .54816 Mdot
.986 .54826 Mdot
.986 .5489 Mdot
.986 .54974 Mdot
.986 .55041 Mdot
.986 .55239 Mdot
.986 .5526 Mdot
.986 .55362 Mdot
.986 .55372 Mdot
.986 .55376 Mdot
.986 .55509 Mdot
.986 .55527 Mdot
.986 .55605 Mdot
.986 .55644 Mdot
.986 .55671 Mdot
.986 .55685 Mdot
.986 .55712 Mdot
.986 .55887 Mdot
.986 .56026 Mdot
.986 .56194 Mdot
.986 .56251 Mdot
.986 .56331 Mdot
.986 .56641 Mdot
.986 .56663 Mdot
.986 .56668 Mdot
.986 .56697 Mdot
.986 .56705 Mdot
.986 .56773 Mdot
.986 .56795 Mdot
.986 .56849 Mdot
.986 .56935 Mdot
.986 .57016 Mdot
.986 .57073 Mdot
.986 .57129 Mdot
.986 .57168 Mdot
.986 .57173 Mdot
.986 .57183 Mdot
.986 .57212 Mdot
.986 .57343 Mdot
.986 .57363 Mdot
.986 .57367 Mdot
.986 .57384 Mdot
.986 .57472 Mdot
.986 .57624 Mdot
.986 .57697 Mdot
.986 .57706 Mdot
.986 .57711 Mdot
.986 .57733 Mdot
.986 .57806 Mdot
.986 .57986 Mdot
.986 .57989 Mdot
.986 .58025 Mdot
.986 .5805 Mdot
.986 .58152 Mdot
.986 .58164 Mdot
.986 .58213 Mdot
.986 .5837 Mdot
.986 .58418 Mdot
.986 .58488 Mdot
.986 .58603 Mdot
.986 .58733 Mdot
.986 .58743 Mdot
.986 .5878 Mdot
.986 .58798 Mdot
.986 .58825 Mdot
.986 .58887 Mdot
.986 .58889 Mdot
.986 .58927 Mdot
.986 .58941 Mdot
.986 .59008 Mdot
.986 .59039 Mdot
.986 .59067 Mdot
.986 .59144 Mdot
.986 .59199 Mdot
.986 .59213 Mdot
.986 .59217 Mdot
.986 .59298 Mdot
.986 .59337 Mdot
.986 .59473 Mdot
.986 .59545 Mdot
.986 .59549 Mdot
.986 .59569 Mdot
.986 .59572 Mdot
.988 .02882 Mdot
.988 .02911 Mdot
.988 .03022 Mdot
.988 .0305 Mdot
.988 .03138 Mdot
.988 .03232 Mdot
.988 .03372 Mdot
.988 .03424 Mdot
.988 .0356 Mdot
.988 .03852 Mdot
.988 .03902 Mdot
.988 .03915 Mdot
.988 .0426 Mdot
.988 .04316 Mdot
.988 .04478 Mdot
.988 .04534 Mdot
.988 .04535 Mdot
.988 .04591 Mdot
.988 .04694 Mdot
.988 .04765 Mdot
.988 .04772 Mdot
.988 .04845 Mdot
.988 .04907 Mdot
.988 .04918 Mdot
.988 .0495 Mdot
.988 .05035 Mdot
.988 .05227 Mdot
.988 .05304 Mdot
.988 .05329 Mdot
.988 .05376 Mdot
.988 .0552 Mdot
.988 .05599 Mdot
.988 .05685 Mdot
.988 .05907 Mdot
.988 .06176 Mdot
.988 .06267 Mdot
.988 .06274 Mdot
.988 .0629 Mdot
.988 .06299 Mdot
.988 .06562 Mdot
.988 .06653 Mdot
.988 .06931 Mdot
.988 .06957 Mdot
.988 .06981 Mdot
.988 .07091 Mdot
.988 .0723 Mdot
.988 .07326 Mdot
.988 .07359 Mdot
.988 .07413 Mdot
.988 .07423 Mdot
.988 .07438 Mdot
.988 .07467 Mdot
.988 .07523 Mdot
.988 .07526 Mdot
.988 .0756 Mdot
.988 .07636 Mdot
.988 .07758 Mdot
.988 .07787 Mdot
.988 .07833 Mdot
.988 .07839 Mdot
.988 .0798 Mdot
.988 .07983 Mdot
.988 .07992 Mdot
.988 .08013 Mdot
.988 .08062 Mdot
.988 .08125 Mdot
.988 .08137 Mdot
.988 .08139 Mdot
.988 .08157 Mdot
.988 .0817 Mdot
.988 .08192 Mdot
.988 .08243 Mdot
.988 .0826 Mdot
.988 .08282 Mdot
.988 .08303 Mdot
.988 .08332 Mdot
.988 .08345 Mdot
.988 .08368 Mdot
.988 .08436 Mdot
.988 .08513 Mdot
.988 .08567 Mdot
.988 .08679 Mdot
.988 .08681 Mdot
.988 .08686 Mdot
.988 .08862 Mdot
.988 .08892 Mdot
.988 .08893 Mdot
.988 .08921 Mdot
.988 .09044 Mdot
.988 .09072 Mdot
.988 .09095 Mdot
.988 .09186 Mdot
.988 .09251 Mdot
.988 .09407 Mdot
.988 .09471 Mdot
.988 .09509 Mdot
.988 .09601 Mdot
.988 .09627 Mdot
.988 .09654 Mdot
.988 .09663 Mdot
.988 .09798 Mdot
.988 .09869 Mdot
.988 .09875 Mdot
.988 .10132 Mdot
.988 .1023 Mdot
.988 .10233 Mdot
.988 .10236 Mdot
.988 .10287 Mdot
.988 .1069 Mdot
.988 .10745 Mdot
.988 .10755 Mdot
.988 .10762 Mdot
.988 .10768 Mdot
.988 .1078 Mdot
.988 .10947 Mdot
.988 .10962 Mdot
.988 .10967 Mdot
.988 .10993 Mdot
.988 .11011 Mdot
.988 .11283 Mdot
.988 .11298 Mdot
.988 .11364 Mdot
.988 .11529 Mdot
.988 .11626 Mdot
.988 .1171 Mdot
.988 .11867 Mdot
.988 .1191 Mdot
.988 .12031 Mdot
.988 .12095 Mdot
.988 .12141 Mdot
.988 .1226 Mdot
.988 .1231 Mdot
.988 .12326 Mdot
.988 .12357 Mdot
.988 .1244 Mdot
.988 .12452 Mdot
.988 .12559 Mdot
.988 .12576 Mdot
.988 .12577 Mdot
.988 .12593 Mdot
.988 .12851 Mdot
.988 .12871 Mdot
.988 .12893 Mdot
.988 .12913 Mdot
.988 .12981 Mdot
.988 .1302 Mdot
.988 .1304 Mdot
.988 .13105 Mdot
.988 .13211 Mdot
.988 .13232 Mdot
.988 .13258 Mdot
.988 .13261 Mdot
.988 .13319 Mdot
.988 .13322 Mdot
.988 .1334 Mdot
.988 .1343 Mdot
.988 .13434 Mdot
.988 .13461 Mdot
.988 .13502 Mdot
.988 .13541 Mdot
.988 .13653 Mdot
.988 .13746 Mdot
.988 .13894 Mdot
.988 .13903 Mdot
.988 .1395 Mdot
.988 .14015 Mdot
.988 .14041 Mdot
.988 .14053 Mdot
.988 .14071 Mdot
.988 .14205 Mdot
.988 .14224 Mdot
.988 .14263 Mdot
.988 .1428 Mdot
.988 .14332 Mdot
.988 .14339 Mdot
.988 .14357 Mdot
.988 .14359 Mdot
.988 .14398 Mdot
.988 .14415 Mdot
.988 .14453 Mdot
.988 .14494 Mdot
.988 .14553 Mdot
.988 .14618 Mdot
.988 .14637 Mdot
.988 .14643 Mdot
.988 .14646 Mdot
.988 .14683 Mdot
.988 .14708 Mdot
.988 .1475 Mdot
.988 .14782 Mdot
.988 .14814 Mdot
.988 .14822 Mdot
.988 .14852 Mdot
.988 .14886 Mdot
.988 .14928 Mdot
.988 .14931 Mdot
.988 .1497 Mdot
.988 .15027 Mdot
.988 .15043 Mdot
.988 .15053 Mdot
.988 .15098 Mdot
.988 .15104 Mdot
.988 .15234 Mdot
.988 .15309 Mdot
.988 .1535 Mdot
.988 .15386 Mdot
.988 .15493 Mdot
.988 .15539 Mdot
.988 .15596 Mdot
.988 .15661 Mdot
.988 .15714 Mdot
.988 .15717 Mdot
.988 .15719 Mdot
.988 .15727 Mdot
.988 .15808 Mdot
.988 .1587 Mdot
.988 .15921 Mdot
.988 .16075 Mdot
.988 .16119 Mdot
.988 .16134 Mdot
.988 .16136 Mdot
.988 .16191 Mdot
.988 .16335 Mdot
.988 .16353 Mdot
.988 .16394 Mdot
.988 .16398 Mdot
.988 .16423 Mdot
.988 .16434 Mdot
.988 .16471 Mdot
.988 .16489 Mdot
.988 .16527 Mdot
.988 .16535 Mdot
.988 .16615 Mdot
.988 .16636 Mdot
.988 .16646 Mdot
.988 .16715 Mdot
.988 .16843 Mdot
.988 .16977 Mdot
.988 .17066 Mdot
.988 .17121 Mdot
.988 .17153 Mdot
.988 .17153 Mdot
.988 .17279 Mdot
.988 .17354 Mdot
.988 .17535 Mdot
.988 .17571 Mdot
.988 .17587 Mdot
.988 .1764 Mdot
.988 .17658 Mdot
.988 .1766 Mdot
.988 .17851 Mdot
.988 .17876 Mdot
.988 .17889 Mdot
.988 .17925 Mdot
.988 .17949 Mdot
.988 .18042 Mdot
.988 .18058 Mdot
.988 .18065 Mdot
.988 .18077 Mdot
.988 .18184 Mdot
.988 .18317 Mdot
.988 .18585 Mdot
.988 .18612 Mdot
.988 .18634 Mdot
.988 .18769 Mdot
.988 .18779 Mdot
.988 .18784 Mdot
.988 .18791 Mdot
.988 .18827 Mdot
.988 .1886 Mdot
.988 .1889 Mdot
.988 .19003 Mdot
.988 .19049 Mdot
.988 .19226 Mdot
.988 .19356 Mdot
.988 .19658 Mdot
.988 .19687 Mdot
.988 .19728 Mdot
.988 .1978 Mdot
.988 .19795 Mdot
.988 .19801 Mdot
.988 .19816 Mdot
.988 .1983 Mdot
.988 .19842 Mdot
.988 .19865 Mdot
.988 .19872 Mdot
.988 .19941 Mdot
.988 .20007 Mdot
.988 .20107 Mdot
.988 .20194 Mdot
.988 .20224 Mdot
.988 .20235 Mdot
.988 .20286 Mdot
.988 .20321 Mdot
.988 .20403 Mdot
.988 .20426 Mdot
.988 .20837 Mdot
.988 .2086 Mdot
.988 .20888 Mdot
.988 .20973 Mdot
.988 .21019 Mdot
.988 .21069 Mdot
.988 .2112 Mdot
.988 .21154 Mdot
.988 .21225 Mdot
.988 .21226 Mdot
.988 .21266 Mdot
.988 .21267 Mdot
.988 .21317 Mdot
.988 .21346 Mdot
.988 .21437 Mdot
.988 .21537 Mdot
.988 .21597 Mdot
.988 .21703 Mdot
.988 .21767 Mdot
.988 .21854 Mdot
.988 .22012 Mdot
.988 .22086 Mdot
.988 .22098 Mdot
.988 .2213 Mdot
.988 .22202 Mdot
.988 .22323 Mdot
.988 .22338 Mdot
.988 .22463 Mdot
.988 .22497 Mdot
.988 .22555 Mdot
.988 .22724 Mdot
.988 .22789 Mdot
.988 .22842 Mdot
.988 .22889 Mdot
.988 .2292 Mdot
.988 .22957 Mdot
.988 .22982 Mdot
.988 .2311 Mdot
.988 .23145 Mdot
.988 .23168 Mdot
.988 .23254 Mdot
.988 .23314 Mdot
.988 .23344 Mdot
.988 .2338 Mdot
.988 .23415 Mdot
.988 .23417 Mdot
.988 .23448 Mdot
.988 .23525 Mdot
.988 .23947 Mdot
.988 .23958 Mdot
.988 .23996 Mdot
.988 .2404 Mdot
.988 .24059 Mdot
.988 .24068 Mdot
.988 .24081 Mdot
.988 .24215 Mdot
.988 .24291 Mdot
.988 .2433 Mdot
.988 .24459 Mdot
.988 .24669 Mdot
.988 .24677 Mdot
.988 .2471 Mdot
.988 .24756 Mdot
.988 .24762 Mdot
.988 .24768 Mdot
.988 .24882 Mdot
.988 .24888 Mdot
.988 .24923 Mdot
.988 .24925 Mdot
.988 .24977 Mdot
.988 .25061 Mdot
.988 .25101 Mdot
.988 .2511 Mdot
.988 .25164 Mdot
.988 .25229 Mdot
.988 .25243 Mdot
.988 .25287 Mdot
.988 .25321 Mdot
.988 .25541 Mdot
.988 .25543 Mdot
.988 .2568 Mdot
.988 .25726 Mdot
.988 .25749 Mdot
.988 .25786 Mdot
.988 .25943 Mdot
.988 .26019 Mdot
.988 .26037 Mdot
.988 .2613 Mdot
.988 .26258 Mdot
.988 .26268 Mdot
.988 .26309 Mdot
.988 .26333 Mdot
.988 .26368 Mdot
.988 .26473 Mdot
.988 .26479 Mdot
.988 .26615 Mdot
.988 .26634 Mdot
.988 .26639 Mdot
.988 .2667 Mdot
.988 .26748 Mdot
.988 .26781 Mdot
.988 .26826 Mdot
.988 .26838 Mdot
.988 .26883 Mdot
.988 .26898 Mdot
.988 .26932 Mdot
.988 .26938 Mdot
.988 .27014 Mdot
.988 .27048 Mdot
.988 .2708 Mdot
.988 .27084 Mdot
.988 .27108 Mdot
.988 .27123 Mdot
.988 .27133 Mdot
.988 .27205 Mdot
.988 .27312 Mdot
.988 .2732 Mdot
.988 .27357 Mdot
.988 .27442 Mdot
.988 .27449 Mdot
.988 .27472 Mdot
.988 .27486 Mdot
.988 .27499 Mdot
.988 .27505 Mdot
.988 .27521 Mdot
.988 .27577 Mdot
.988 .27627 Mdot
.988 .27711 Mdot
.988 .27773 Mdot
.988 .27837 Mdot
.988 .27852 Mdot
.988 .27911 Mdot
.988 .27919 Mdot
.988 .27978 Mdot
.988 .28013 Mdot
.988 .28062 Mdot
.988 .28067 Mdot
.988 .28144 Mdot
.988 .28237 Mdot
.988 .28257 Mdot
.988 .28288 Mdot
.988 .28293 Mdot
.988 .28309 Mdot
.988 .2837 Mdot
.988 .28398 Mdot
.988 .28403 Mdot
.988 .28409 Mdot
.988 .28548 Mdot
.988 .28595 Mdot
.988 .28666 Mdot
.988 .28794 Mdot
.988 .28815 Mdot
.988 .28896 Mdot
.988 .28948 Mdot
.988 .2895 Mdot
.988 .28953 Mdot
.988 .28967 Mdot
.988 .2907 Mdot
.988 .2911 Mdot
.988 .29177 Mdot
.988 .2923 Mdot
.988 .29246 Mdot
.988 .29269 Mdot
.988 .29336 Mdot
.988 .29381 Mdot
.988 .29427 Mdot
.988 .29511 Mdot
.988 .29607 Mdot
.988 .29616 Mdot
.988 .2962 Mdot
.988 .29624 Mdot
.988 .2964 Mdot
.988 .2966 Mdot
.988 .29718 Mdot
.988 .29769 Mdot
.988 .298 Mdot
.988 .2982 Mdot
.988 .29853 Mdot
.988 .29923 Mdot
.988 .2993 Mdot
.988 .30024 Mdot
.988 .301 Mdot
.988 .30192 Mdot
.988 .30249 Mdot
.988 .30291 Mdot
.988 .30328 Mdot
.988 .30415 Mdot
.988 .30445 Mdot
.988 .30448 Mdot
.988 .30558 Mdot
.988 .30705 Mdot
.988 .30841 Mdot
.988 .30877 Mdot
.988 .30931 Mdot
.988 .30959 Mdot
.988 .30967 Mdot
.988 .31016 Mdot
.988 .31038 Mdot
.988 .31111 Mdot
.988 .31146 Mdot
.988 .31221 Mdot
.988 .31237 Mdot
.988 .31396 Mdot
.988 .31437 Mdot
.988 .31457 Mdot
.988 .31475 Mdot
.988 .31593 Mdot
.988 .31845 Mdot
.988 .31938 Mdot
.988 .32111 Mdot
.988 .32136 Mdot
.988 .32147 Mdot
.988 .32229 Mdot
.988 .3224 Mdot
.988 .32287 Mdot
.988 .32327 Mdot
.988 .32346 Mdot
.988 .32361 Mdot
.988 .32368 Mdot
.988 .32378 Mdot
.988 .32395 Mdot
.988 .32457 Mdot
.988 .32458 Mdot
.988 .32459 Mdot
.988 .32504 Mdot
.988 .32519 Mdot
.988 .32644 Mdot
.988 .32707 Mdot
.988 .32764 Mdot
.988 .32855 Mdot
.988 .32855 Mdot
.988 .32995 Mdot
.988 .33128 Mdot
.988 .33212 Mdot
.988 .33285 Mdot
.988 .33316 Mdot
.988 .33332 Mdot
.988 .3342 Mdot
.988 .33423 Mdot
.988 .33451 Mdot
.988 .33456 Mdot
.988 .3346 Mdot
.988 .33559 Mdot
.988 .33755 Mdot
.988 .33824 Mdot
.988 .33838 Mdot
.988 .33887 Mdot
.988 .33892 Mdot
.988 .33912 Mdot
.988 .33936 Mdot
.988 .33983 Mdot
.988 .34031 Mdot
.988 .34058 Mdot
.988 .34155 Mdot
.988 .34214 Mdot
.988 .34246 Mdot
.988 .3426 Mdot
.988 .34283 Mdot
.988 .34299 Mdot
.988 .34423 Mdot
.988 .34433 Mdot
.988 .34495 Mdot
.988 .34605 Mdot
.988 .34757 Mdot
.988 .34813 Mdot
.988 .35065 Mdot
.988 .35287 Mdot
.988 .35342 Mdot
.988 .35359 Mdot
.988 .35384 Mdot
.988 .35644 Mdot
.988 .35652 Mdot
.988 .3567 Mdot
.988 .35681 Mdot
.988 .35694 Mdot
.988 .35725 Mdot
.988 .35766 Mdot
.988 .35831 Mdot
.988 .35891 Mdot
.988 .35952 Mdot
.988 .36054 Mdot
.988 .36085 Mdot
.988 .36114 Mdot
.988 .36205 Mdot
.988 .36368 Mdot
.988 .36554 Mdot
.988 .36575 Mdot
.988 .36631 Mdot
.988 .36811 Mdot
.988 .36961 Mdot
.988 .37105 Mdot
.988 .37108 Mdot
.988 .3717 Mdot
.988 .37241 Mdot
.988 .37283 Mdot
.988 .37385 Mdot
.988 .37409 Mdot
.988 .37466 Mdot
.988 .375 Mdot
.988 .37509 Mdot
.988 .37546 Mdot
.988 .37558 Mdot
.988 .37649 Mdot
.988 .3765 Mdot
.988 .3768 Mdot
.988 .3769 Mdot
.988 .37721 Mdot
.988 .37748 Mdot
.988 .37771 Mdot
.988 .37817 Mdot
.988 .37831 Mdot
.988 .37846 Mdot
.988 .37967 Mdot
.988 .38098 Mdot
.988 .38156 Mdot
.988 .38296 Mdot
.988 .38465 Mdot
.988 .38468 Mdot
.988 .38489 Mdot
.988 .38514 Mdot
.988 .38519 Mdot
.988 .38527 Mdot
.988 .38548 Mdot
.988 .38563 Mdot
.988 .38649 Mdot
.988 .38719 Mdot
.988 .38802 Mdot
.988 .38879 Mdot
.988 .38897 Mdot
.988 .38926 Mdot
.988 .39053 Mdot
.988 .3929 Mdot
.988 .39363 Mdot
.988 .39468 Mdot
.988 .39549 Mdot
.988 .39701 Mdot
.988 .39738 Mdot
.988 .39754 Mdot
.988 .39772 Mdot
.988 .39783 Mdot
.988 .39839 Mdot
.988 .39877 Mdot
.988 .40007 Mdot
.988 .40092 Mdot
.988 .40098 Mdot
.988 .40099 Mdot
.988 .40111 Mdot
.988 .40196 Mdot
.988 .40297 Mdot
.988 .40316 Mdot
.988 .40363 Mdot
.988 .40416 Mdot
.988 .40421 Mdot
.988 .40447 Mdot
.988 .40504 Mdot
.988 .40507 Mdot
.988 .4056 Mdot
.988 .40585 Mdot
.988 .40587 Mdot
.988 .40686 Mdot
.988 .40743 Mdot
.988 .40757 Mdot
.988 .40759 Mdot
.988 .4081 Mdot
.988 .40913 Mdot
.988 .40919 Mdot
.988 .40923 Mdot
.988 .41032 Mdot
.988 .41085 Mdot
.988 .41094 Mdot
.988 .41121 Mdot
.988 .41198 Mdot
.988 .41239 Mdot
.988 .41292 Mdot
.988 .41329 Mdot
.988 .41449 Mdot
.988 .41528 Mdot
.988 .41576 Mdot
.988 .41697 Mdot
.988 .41719 Mdot
.988 .41722 Mdot
.988 .41734 Mdot
.988 .41747 Mdot
.988 .41903 Mdot
.988 .4206 Mdot
.988 .42159 Mdot
.988 .42205 Mdot
.988 .4223 Mdot
.988 .42235 Mdot
.988 .42293 Mdot
.988 .42345 Mdot
.988 .42366 Mdot
.988 .42402 Mdot
.988 .42433 Mdot
.988 .42435 Mdot
.988 .42507 Mdot
.988 .42674 Mdot
.988 .42703 Mdot
.988 .42808 Mdot
.988 .42951 Mdot
.988 .42966 Mdot
.988 .43018 Mdot
.988 .43133 Mdot
.988 .43174 Mdot
.988 .43318 Mdot
.988 .43467 Mdot
.988 .43595 Mdot
.988 .437 Mdot
.988 .43787 Mdot
.988 .43792 Mdot
.988 .43855 Mdot
.988 .43927 Mdot
.988 .43976 Mdot
.988 .44038 Mdot
.988 .44095 Mdot
.988 .4413 Mdot
.988 .44229 Mdot
.988 .44284 Mdot
.988 .44298 Mdot
.988 .44344 Mdot
.988 .44447 Mdot
.988 .44514 Mdot
.988 .44586 Mdot
.988 .44632 Mdot
.988 .44692 Mdot
.988 .44755 Mdot
.988 .44763 Mdot
.988 .44786 Mdot
.988 .44827 Mdot
.988 .44832 Mdot
.988 .44836 Mdot
.988 .44843 Mdot
.988 .44853 Mdot
.988 .44896 Mdot
.988 .44902 Mdot
.988 .44944 Mdot
.988 .4495 Mdot
.988 .45049 Mdot
.988 .45284 Mdot
.988 .45559 Mdot
.988 .45673 Mdot
.988 .45883 Mdot
.988 .45904 Mdot
.988 .45933 Mdot
.988 .4598 Mdot
.988 .46066 Mdot
.988 .46105 Mdot
.988 .46121 Mdot
.988 .46147 Mdot
.988 .46173 Mdot
.988 .46202 Mdot
.988 .46229 Mdot
.988 .4632 Mdot
.988 .46367 Mdot
.988 .46412 Mdot
.988 .4642 Mdot
.988 .46481 Mdot
.988 .46501 Mdot
.988 .4656 Mdot
.988 .46562 Mdot
.988 .46562 Mdot
.988 .4664 Mdot
.988 .46741 Mdot
.988 .46765 Mdot
.988 .46839 Mdot
.988 .46855 Mdot
.988 .46894 Mdot
.988 .46923 Mdot
.988 .47036 Mdot
.988 .47083 Mdot
.988 .47285 Mdot
.988 .4731 Mdot
.988 .47325 Mdot
.988 .47368 Mdot
.988 .47391 Mdot
.988 .47481 Mdot
.988 .47494 Mdot
.988 .47506 Mdot
.988 .47508 Mdot
.988 .47631 Mdot
.988 .47637 Mdot
.988 .47731 Mdot
.988 .47743 Mdot
.988 .47812 Mdot
.988 .47815 Mdot
.988 .47919 Mdot
.988 .48083 Mdot
.988 .48163 Mdot
.988 .48182 Mdot
.988 .48217 Mdot
.988 .48287 Mdot
.988 .48416 Mdot
.988 .48445 Mdot
.988 .4853 Mdot
.988 .48572 Mdot
.988 .48599 Mdot
.988 .48684 Mdot
.988 .48724 Mdot
.988 .49033 Mdot
.988 .49037 Mdot
.988 .49094 Mdot
.988 .49307 Mdot
.988 .49399 Mdot
.988 .49414 Mdot
.988 .49444 Mdot
.988 .49517 Mdot
.988 .49594 Mdot
.988 .49653 Mdot
.988 .49712 Mdot
.988 .49827 Mdot
.988 .49915 Mdot
.988 .49977 Mdot
.988 .50013 Mdot
.988 .50035 Mdot
.988 .50153 Mdot
.988 .50197 Mdot
.988 .50283 Mdot
.988 .50364 Mdot
.988 .50424 Mdot
.988 .5045 Mdot
.988 .5045 Mdot
.988 .5047 Mdot
.988 .50471 Mdot
.988 .50507 Mdot
.988 .50524 Mdot
.988 .5055 Mdot
.988 .50599 Mdot
.988 .50667 Mdot
.988 .50875 Mdot
.988 .50887 Mdot
.988 .51037 Mdot
.988 .51087 Mdot
.988 .51121 Mdot
.988 .51156 Mdot
.988 .51192 Mdot
.988 .51202 Mdot
.988 .51229 Mdot
.988 .51264 Mdot
.988 .51417 Mdot
.988 .51483 Mdot
.988 .51572 Mdot
.988 .51595 Mdot
.988 .51668 Mdot
.988 .51685 Mdot
.988 .51714 Mdot
.988 .51782 Mdot
.988 .51793 Mdot
.988 .51943 Mdot
.988 .5201 Mdot
.988 .52074 Mdot
.988 .52082 Mdot
.988 .52129 Mdot
.988 .52159 Mdot
.988 .52166 Mdot
.988 .52178 Mdot
.988 .52275 Mdot
.988 .5232 Mdot
.988 .52532 Mdot
.988 .52548 Mdot
.988 .52576 Mdot
.988 .52621 Mdot
.988 .52788 Mdot
.988 .52793 Mdot
.988 .52804 Mdot
.988 .52849 Mdot
.988 .52877 Mdot
.988 .52901 Mdot
.988 .52914 Mdot
.988 .52916 Mdot
.988 .52937 Mdot
.988 .52946 Mdot
.988 .53055 Mdot
.988 .53155 Mdot
.988 .53181 Mdot
.988 .53213 Mdot
.988 .53258 Mdot
.988 .53287 Mdot
.988 .5332 Mdot
.988 .53348 Mdot
.988 .53444 Mdot
.988 .53465 Mdot
.988 .53569 Mdot
.988 .536 Mdot
.988 .53657 Mdot
.988 .53711 Mdot
.988 .53715 Mdot
.988 .53732 Mdot
.988 .53805 Mdot
.988 .53848 Mdot
.988 .53898 Mdot
.988 .53917 Mdot
.988 .53946 Mdot
.988 .53986 Mdot
.988 .53994 Mdot
.988 .54014 Mdot
.988 .54024 Mdot
.988 .54092 Mdot
.988 .5412 Mdot
.988 .54176 Mdot
.988 .54256 Mdot
.988 .5436 Mdot
.988 .544 Mdot
.988 .54462 Mdot
.988 .54471 Mdot
.988 .54503 Mdot
.988 .54624 Mdot
.988 .54643 Mdot
.988 .54677 Mdot
.988 .54688 Mdot
.988 .54699 Mdot
.988 .54839 Mdot
.988 .54847 Mdot
.988 .54857 Mdot
.988 .54911 Mdot
.988 .54917 Mdot
.988 .54974 Mdot
.988 .55068 Mdot
.988 .55092 Mdot
.988 .55124 Mdot
.988 .55185 Mdot
.988 .55207 Mdot
.988 .55329 Mdot
.988 .55461 Mdot
.988 .55495 Mdot
.988 .55502 Mdot
.988 .55662 Mdot
.988 .55757 Mdot
.988 .55766 Mdot
.988 .5577 Mdot
.988 .55775 Mdot
.988 .55802 Mdot
.988 .56007 Mdot
.988 .56034 Mdot
.988 .56035 Mdot
.988 .56085 Mdot
.988 .56215 Mdot
.988 .56218 Mdot
.988 .56322 Mdot
.988 .56327 Mdot
.988 .56354 Mdot
.988 .564 Mdot
.988 .56452 Mdot
.988 .56531 Mdot
.988 .56622 Mdot
.988 .56698 Mdot
.988 .56712 Mdot
.988 .56728 Mdot
.988 .56817 Mdot
.988 .56819 Mdot
.988 .5682 Mdot
.988 .56877 Mdot
.988 .56943 Mdot
.988 .56978 Mdot
.988 .56996 Mdot
.988 .57011 Mdot
.988 .57041 Mdot
.988 .57067 Mdot
.988 .57078 Mdot
.988 .57084 Mdot
.988 .57094 Mdot
.988 .57101 Mdot
.988 .57133 Mdot
.988 .57157 Mdot
.988 .57172 Mdot
.988 .57249 Mdot
.988 .57272 Mdot
.988 .57286 Mdot
.988 .57387 Mdot
.988 .57434 Mdot
.988 .57448 Mdot
.988 .57456 Mdot
.988 .57488 Mdot
.988 .57505 Mdot
.988 .57553 Mdot
.988 .57692 Mdot
.988 .57705 Mdot
.988 .57846 Mdot
.988 .57892 Mdot
.988 .58029 Mdot
.988 .58041 Mdot
.988 .58223 Mdot
.988 .58335 Mdot
.988 .58419 Mdot
.988 .58492 Mdot
.988 .58528 Mdot
.988 .58664 Mdot
.988 .58724 Mdot
.988 .58729 Mdot
.988 .58761 Mdot
.988 .58798 Mdot
.988 .58837 Mdot
.988 .58918 Mdot
.988 .58946 Mdot
.988 .59231 Mdot
.988 .59238 Mdot
.988 .59263 Mdot
.988 .59411 Mdot
.988 .5948 Mdot
.988 .59506 Mdot
.988 .59577 Mdot
.988 .59624 Mdot
.988 .59669 Mdot
.988 .59683 Mdot
.988 .59739 Mdot
.988 .59754 Mdot
.99 .0274 Mdot
.99 .02832 Mdot
.99 .02902 Mdot
.99 .03257 Mdot
.99 .0331 Mdot
.99 .03346 Mdot
.99 .03419 Mdot
.99 .03564 Mdot
.99 .03612 Mdot
.99 .03755 Mdot
.99 .03968 Mdot
.99 .03983 Mdot
.99 .04028 Mdot
.99 .04117 Mdot
.99 .04166 Mdot
.99 .04217 Mdot
.99 .04304 Mdot
.99 .04328 Mdot
.99 .04438 Mdot
.99 .04464 Mdot
.99 .04569 Mdot
.99 .0464 Mdot
.99 .04707 Mdot
.99 .04889 Mdot
.99 .04987 Mdot
.99 .05008 Mdot
.99 .05109 Mdot
.99 .05112 Mdot
.99 .05137 Mdot
.99 .05149 Mdot
.99 .05183 Mdot
.99 .05327 Mdot
.99 .05331 Mdot
.99 .05353 Mdot
.99 .05414 Mdot
.99 .05598 Mdot
.99 .05614 Mdot
.99 .0566 Mdot
.99 .05709 Mdot
.99 .05776 Mdot
.99 .05876 Mdot
.99 .05901 Mdot
.99 .05993 Mdot
.99 .06009 Mdot
.99 .06093 Mdot
.99 .06224 Mdot
.99 .06261 Mdot
.99 .06372 Mdot
.99 .06385 Mdot
.99 .06414 Mdot
.99 .06444 Mdot
.99 .06478 Mdot
.99 .06534 Mdot
.99 .06709 Mdot
.99 .06724 Mdot
.99 .06806 Mdot
.99 .06826 Mdot
.99 .06909 Mdot
.99 .06929 Mdot
.99 .06967 Mdot
.99 .07002 Mdot
.99 .0708 Mdot
.99 .07128 Mdot
.99 .07169 Mdot
.99 .0731 Mdot
.99 .07345 Mdot
.99 .07363 Mdot
.99 .07381 Mdot
.99 .07392 Mdot
.99 .07396 Mdot
.99 .07477 Mdot
.99 .07487 Mdot
.99 .07551 Mdot
.99 .07591 Mdot
.99 .07605 Mdot
.99 .07614 Mdot
.99 .07619 Mdot
.99 .07662 Mdot
.99 .07744 Mdot
.99 .07806 Mdot
.99 .07877 Mdot
.99 .07903 Mdot
.99 .0792 Mdot
.99 .07935 Mdot
.99 .0821 Mdot
.99 .08238 Mdot
.99 .08432 Mdot
.99 .08473 Mdot
.99 .08674 Mdot
.99 .0868 Mdot
.99 .08688 Mdot
.99 .0873 Mdot
.99 .08753 Mdot
.99 .08821 Mdot
.99 .08945 Mdot
.99 .08956 Mdot
.99 .09082 Mdot
.99 .09106 Mdot
.99 .09113 Mdot
.99 .09156 Mdot
.99 .09246 Mdot
.99 .09277 Mdot
.99 .09594 Mdot
.99 .09628 Mdot
.99 .09642 Mdot
.99 .09665 Mdot
.99 .09674 Mdot
.99 .09748 Mdot
.99 .09765 Mdot
.99 .09769 Mdot
.99 .09862 Mdot
.99 .09994 Mdot
.99 .10114 Mdot
.99 .10186 Mdot
.99 .10193 Mdot
.99 .10208 Mdot
.99 .10242 Mdot
.99 .10424 Mdot
.99 .10455 Mdot
.99 .10535 Mdot
.99 .1062 Mdot
.99 .10622 Mdot
.99 .10674 Mdot
.99 .10707 Mdot
.99 .10881 Mdot
.99 .10889 Mdot
.99 .10956 Mdot
.99 .11004 Mdot
.99 .11095 Mdot
.99 .1113 Mdot
.99 .11174 Mdot
.99 .112 Mdot
.99 .11258 Mdot
.99 .1129 Mdot
.99 .11312 Mdot
.99 .11317 Mdot
.99 .11384 Mdot
.99 .11496 Mdot
.99 .1172 Mdot
.99 .11812 Mdot
.99 .11831 Mdot
.99 .11842 Mdot
.99 .11872 Mdot
.99 .12033 Mdot
.99 .12074 Mdot
.99 .12087 Mdot
.99 .12102 Mdot
.99 .12237 Mdot
.99 .12277 Mdot
.99 .12299 Mdot
.99 .12353 Mdot
.99 .12357 Mdot
.99 .12398 Mdot
.99 .12422 Mdot
.99 .12436 Mdot
.99 .12491 Mdot
.99 .12503 Mdot
.99 .12564 Mdot
.99 .12566 Mdot
.99 .12577 Mdot
.99 .12609 Mdot
.99 .12671 Mdot
.99 .12698 Mdot
.99 .12752 Mdot
.99 .12927 Mdot
.99 .13031 Mdot
.99 .13063 Mdot
.99 .13075 Mdot
.99 .13102 Mdot
.99 .13137 Mdot
.99 .1315 Mdot
.99 .13162 Mdot
.99 .13172 Mdot
.99 .13193 Mdot
.99 .13203 Mdot
.99 .13216 Mdot
.99 .13231 Mdot
.99 .13362 Mdot
.99 .13383 Mdot
.99 .13403 Mdot
.99 .13434 Mdot
.99 .13509 Mdot
.99 .13587 Mdot
.99 .13615 Mdot
.99 .13631 Mdot
.99 .13634 Mdot
.99 .13643 Mdot
.99 .13672 Mdot
.99 .13728 Mdot
.99 .13814 Mdot
.99 .13892 Mdot
.99 .14014 Mdot
.99 .14155 Mdot
.99 .14204 Mdot
.99 .14205 Mdot
.99 .1424 Mdot
.99 .14265 Mdot
.99 .1427 Mdot
.99 .14285 Mdot
.99 .1447 Mdot
.99 .14521 Mdot
.99 .14663 Mdot
.99 .14719 Mdot
.99 .14775 Mdot
.99 .14813 Mdot
.99 .14869 Mdot
.99 .15007 Mdot
.99 .15016 Mdot
.99 .15125 Mdot
.99 .15252 Mdot
.99 .1533 Mdot
.99 .15335 Mdot
.99 .15451 Mdot
.99 .15454 Mdot
.99 .15692 Mdot
.99 .15729 Mdot
.99 .15732 Mdot
.99 .15737 Mdot
.99 .15745 Mdot
.99 .15761 Mdot
.99 .1583 Mdot
.99 .15843 Mdot
.99 .15887 Mdot
.99 .15889 Mdot
.99 .15903 Mdot
.99 .15949 Mdot
.99 .16023 Mdot
.99 .1608 Mdot
.99 .16103 Mdot
.99 .16269 Mdot
.99 .1629 Mdot
.99 .16357 Mdot
.99 .16394 Mdot
.99 .16541 Mdot
.99 .16587 Mdot
.99 .16601 Mdot
.99 .16688 Mdot
.99 .16787 Mdot
.99 .16831 Mdot
.99 .16864 Mdot
.99 .16927 Mdot
.99 .16993 Mdot
.99 .1705 Mdot
.99 .17087 Mdot
.99 .1727 Mdot
.99 .17332 Mdot
.99 .17342 Mdot
.99 .17387 Mdot
.99 .17554 Mdot
.99 .17621 Mdot
.99 .17648 Mdot
.99 .17695 Mdot
.99 .17712 Mdot
.99 .17734 Mdot
.99 .17859 Mdot
.99 .17894 Mdot
.99 .179 Mdot
.99 .17978 Mdot
.99 .18078 Mdot
.99 .18084 Mdot
.99 .18198 Mdot
.99 .18346 Mdot
.99 .18583 Mdot
.99 .18727 Mdot
.99 .1874 Mdot
.99 .1877 Mdot
.99 .18824 Mdot
.99 .18837 Mdot
.99 .1894 Mdot
.99 .18973 Mdot
.99 .19017 Mdot
.99 .1917 Mdot
.99 .19198 Mdot
.99 .19259 Mdot
.99 .19417 Mdot
.99 .19442 Mdot
.99 .19453 Mdot
.99 .19538 Mdot
.99 .19586 Mdot
.99 .19589 Mdot
.99 .19692 Mdot
.99 .19757 Mdot
.99 .1982 Mdot
.99 .19827 Mdot
.99 .19863 Mdot
.99 .20102 Mdot
.99 .20118 Mdot
.99 .20189 Mdot
.99 .20193 Mdot
.99 .2025 Mdot
.99 .20297 Mdot
.99 .20345 Mdot
.99 .2038 Mdot
.99 .20527 Mdot
.99 .20596 Mdot
.99 .20682 Mdot
.99 .2072 Mdot
.99 .20734 Mdot
.99 .20849 Mdot
.99 .20912 Mdot
.99 .20927 Mdot
.99 .20939 Mdot
.99 .20956 Mdot
.99 .20966 Mdot
.99 .20975 Mdot
.99 .2104 Mdot
.99 .21099 Mdot
.99 .21274 Mdot
.99 .21319 Mdot
.99 .21435 Mdot
.99 .21695 Mdot
.99 .21763 Mdot
.99 .21793 Mdot
.99 .21874 Mdot
.99 .21904 Mdot
.99 .2193 Mdot
.99 .21946 Mdot
.99 .21983 Mdot
.99 .22005 Mdot
.99 .22064 Mdot
.99 .22075 Mdot
.99 .22172 Mdot
.99 .22294 Mdot
.99 .22384 Mdot
.99 .22465 Mdot
.99 .22479 Mdot
.99 .2249 Mdot
.99 .2252 Mdot
.99 .22594 Mdot
.99 .22787 Mdot
.99 .22803 Mdot
.99 .22823 Mdot
.99 .22851 Mdot
.99 .22867 Mdot
.99 .2291 Mdot
.99 .22954 Mdot
.99 .23016 Mdot
.99 .23026 Mdot
.99 .23106 Mdot
.99 .23147 Mdot
.99 .23153 Mdot
.99 .23181 Mdot
.99 .23191 Mdot
.99 .23291 Mdot
.99 .23314 Mdot
.99 .23417 Mdot
.99 .23435 Mdot
.99 .23439 Mdot
.99 .2346 Mdot
.99 .23524 Mdot
.99 .23539 Mdot
.99 .23581 Mdot
.99 .23647 Mdot
.99 .237 Mdot
.99 .23803 Mdot
.99 .23807 Mdot
.99 .23873 Mdot
.99 .23896 Mdot
.99 .23968 Mdot
.99 .24022 Mdot
.99 .24154 Mdot
.99 .24236 Mdot
.99 .24358 Mdot
.99 .24359 Mdot
.99 .24378 Mdot
.99 .24384 Mdot
.99 .24398 Mdot
.99 .24422 Mdot
.99 .24446 Mdot
.99 .245 Mdot
.99 .24569 Mdot
.99 .24593 Mdot
.99 .24595 Mdot
.99 .24618 Mdot
.99 .24638 Mdot
.99 .24681 Mdot
.99 .24699 Mdot
.99 .24725 Mdot
.99 .24756 Mdot
.99 .24843 Mdot
.99 .2492 Mdot
.99 .25014 Mdot
.99 .25057 Mdot
.99 .25065 Mdot
.99 .25095 Mdot
.99 .25156 Mdot
.99 .25306 Mdot
.99 .2543 Mdot
.99 .25461 Mdot
.99 .25515 Mdot
.99 .25548 Mdot
.99 .25553 Mdot
.99 .25571 Mdot
.99 .25628 Mdot
.99 .2567 Mdot
.99 .25739 Mdot
.99 .25788 Mdot
.99 .25821 Mdot
.99 .25909 Mdot
.99 .25987 Mdot
.99 .26063 Mdot
.99 .26293 Mdot
.99 .26305 Mdot
.99 .26358 Mdot
.99 .26492 Mdot
.99 .26576 Mdot
.99 .26586 Mdot
.99 .26659 Mdot
.99 .26681 Mdot
.99 .26684 Mdot
.99 .26753 Mdot
.99 .26792 Mdot
.99 .26803 Mdot
.99 .26812 Mdot
.99 .26841 Mdot
.99 .27001 Mdot
.99 .27119 Mdot
.99 .27208 Mdot
.99 .27222 Mdot
.99 .27238 Mdot
.99 .27294 Mdot
.99 .27309 Mdot
.99 .27461 Mdot
.99 .27541 Mdot
.99 .27591 Mdot
.99 .27605 Mdot
.99 .27629 Mdot
.99 .27631 Mdot
.99 .2764 Mdot
.99 .27702 Mdot
.99 .27733 Mdot
.99 .27813 Mdot
.99 .27888 Mdot
.99 .27903 Mdot
.99 .27999 Mdot
.99 .28004 Mdot
.99 .28216 Mdot
.99 .28272 Mdot
.99 .28286 Mdot
.99 .28289 Mdot
.99 .28308 Mdot
.99 .28404 Mdot
.99 .28427 Mdot
.99 .28454 Mdot
.99 .28457 Mdot
.99 .28481 Mdot
.99 .28506 Mdot
.99 .28556 Mdot
.99 .2856 Mdot
.99 .28757 Mdot
.99 .28836 Mdot
.99 .28912 Mdot
.99 .2892 Mdot
.99 .28934 Mdot
.99 .29039 Mdot
.99 .29151 Mdot
.99 .29156 Mdot
.99 .29359 Mdot
.99 .29361 Mdot
.99 .29427 Mdot
.99 .29479 Mdot
.99 .29627 Mdot
.99 .297 Mdot
.99 .29701 Mdot
.99 .29707 Mdot
.99 .29717 Mdot
.99 .29733 Mdot
.99 .29758 Mdot
.99 .29765 Mdot
.99 .29814 Mdot
.99 .29876 Mdot
.99 .29902 Mdot
.99 .29928 Mdot
.99 .30014 Mdot
.99 .30018 Mdot
.99 .30046 Mdot
.99 .30089 Mdot
.99 .30138 Mdot
.99 .30262 Mdot
.99 .30278 Mdot
.99 .30283 Mdot
.99 .30371 Mdot
.99 .30396 Mdot
.99 .30442 Mdot
.99 .3046 Mdot
.99 .30504 Mdot
.99 .30615 Mdot
.99 .30685 Mdot
.99 .30722 Mdot
.99 .30734 Mdot
.99 .30771 Mdot
.99 .30812 Mdot
.99 .30903 Mdot
.99 .30944 Mdot
.99 .31019 Mdot
.99 .31141 Mdot
.99 .3115 Mdot
.99 .31308 Mdot
.99 .31346 Mdot
.99 .31372 Mdot
.99 .314 Mdot
.99 .31428 Mdot
.99 .31462 Mdot
.99 .316 Mdot
.99 .31607 Mdot
.99 .3161 Mdot
.99 .31724 Mdot
.99 .3174 Mdot
.99 .3177 Mdot
.99 .31795 Mdot
.99 .31829 Mdot
.99 .31884 Mdot
.99 .31949 Mdot
.99 .32073 Mdot
.99 .32082 Mdot
.99 .32161 Mdot
.99 .32179 Mdot
.99 .32203 Mdot
.99 .32251 Mdot
.99 .32287 Mdot
.99 .32317 Mdot
.99 .3232 Mdot
.99 .3239 Mdot
.99 .32613 Mdot
.99 .32655 Mdot
.99 .32743 Mdot
.99 .32752 Mdot
.99 .32762 Mdot
.99 .32876 Mdot
.99 .32895 Mdot
.99 .32983 Mdot
.99 .33074 Mdot
.99 .33126 Mdot
.99 .33135 Mdot
.99 .33176 Mdot
.99 .33286 Mdot
.99 .33309 Mdot
.99 .33314 Mdot
.99 .33448 Mdot
.99 .33468 Mdot
.99 .33501 Mdot
.99 .33502 Mdot
.99 .33594 Mdot
.99 .33628 Mdot
.99 .33671 Mdot
.99 .33715 Mdot
.99 .33773 Mdot
.99 .33784 Mdot
.99 .3382 Mdot
.99 .33919 Mdot
.99 .33987 Mdot
.99 .34 Mdot
.99 .34065 Mdot
.99 .34124 Mdot
.99 .34154 Mdot
.99 .34238 Mdot
.99 .34353 Mdot
.99 .34365 Mdot
.99 .34404 Mdot
.99 .34469 Mdot
.99 .34578 Mdot
.99 .3459 Mdot
.99 .34655 Mdot
.99 .3472 Mdot
.99 .34882 Mdot
.99 .34908 Mdot
.99 .35352 Mdot
.99 .35446 Mdot
.99 .35474 Mdot
.99 .35495 Mdot
.99 .35637 Mdot
.99 .35663 Mdot
.99 .35723 Mdot
.99 .35764 Mdot
.99 .3583 Mdot
.99 .35855 Mdot
.99 .35884 Mdot
.99 .3589 Mdot
.99 .35927 Mdot
.99 .35983 Mdot
.99 .3606 Mdot
.99 .36113 Mdot
.99 .36125 Mdot
.99 .36212 Mdot
.99 .36301 Mdot
.99 .3641 Mdot
.99 .36515 Mdot
.99 .36516 Mdot
.99 .36569 Mdot
.99 .36653 Mdot
.99 .3669 Mdot
.99 .37003 Mdot
.99 .37054 Mdot
.99 .37075 Mdot
.99 .3713 Mdot
.99 .37244 Mdot
.99 .37338 Mdot
.99 .37344 Mdot
.99 .37414 Mdot
.99 .37511 Mdot
.99 .37547 Mdot
.99 .37554 Mdot
.99 .37652 Mdot
.99 .37677 Mdot
.99 .37785 Mdot
.99 .37802 Mdot
.99 .37816 Mdot
.99 .37872 Mdot
.99 .37887 Mdot
.99 .37901 Mdot
.99 .38015 Mdot
.99 .38019 Mdot
.99 .38077 Mdot
.99 .38106 Mdot
.99 .38123 Mdot
.99 .38179 Mdot
.99 .38242 Mdot
.99 .38299 Mdot
.99 .38321 Mdot
.99 .38359 Mdot
.99 .38388 Mdot
.99 .38392 Mdot
.99 .38532 Mdot
.99 .3854 Mdot
.99 .38615 Mdot
.99 .38653 Mdot
.99 .38733 Mdot
.99 .38746 Mdot
.99 .38842 Mdot
.99 .38896 Mdot
.99 .38911 Mdot
.99 .39001 Mdot
.99 .392 Mdot
.99 .39338 Mdot
.99 .3935 Mdot
.99 .39451 Mdot
.99 .39508 Mdot
.99 .39584 Mdot
.99 .39611 Mdot
.99 .3984 Mdot
.99 .399 Mdot
.99 .39964 Mdot
.99 .39994 Mdot
.99 .40016 Mdot
.99 .40021 Mdot
.99 .40051 Mdot
.99 .40071 Mdot
.99 .40088 Mdot
.99 .40218 Mdot
.99 .40334 Mdot
.99 .40359 Mdot
.99 .40474 Mdot
.99 .40591 Mdot
.99 .4065 Mdot
.99 .40681 Mdot
.99 .4071 Mdot
.99 .4077 Mdot
.99 .40827 Mdot
.99 .40998 Mdot
.99 .41059 Mdot
.99 .41286 Mdot
.99 .41337 Mdot
.99 .41514 Mdot
.99 .41566 Mdot
.99 .41649 Mdot
.99 .41708 Mdot
.99 .41823 Mdot
.99 .41857 Mdot
.99 .41868 Mdot
.99 .41897 Mdot
.99 .41929 Mdot
.99 .41957 Mdot
.99 .41966 Mdot
.99 .4198 Mdot
.99 .42009 Mdot
.99 .42011 Mdot
.99 .42069 Mdot
.99 .42084 Mdot
.99 .42128 Mdot
.99 .42195 Mdot
.99 .42244 Mdot
.99 .42266 Mdot
.99 .42315 Mdot
.99 .42458 Mdot
.99 .42699 Mdot
.99 .42768 Mdot
.99 .42822 Mdot
.99 .42877 Mdot
.99 .42972 Mdot
.99 .43038 Mdot
.99 .43066 Mdot
.99 .43085 Mdot
.99 .43088 Mdot
.99 .43148 Mdot
.99 .43284 Mdot
.99 .43295 Mdot
.99 .43309 Mdot
.99 .43581 Mdot
.99 .43676 Mdot
.99 .43709 Mdot
.99 .43747 Mdot
.99 .43803 Mdot
.99 .43835 Mdot
.99 .43919 Mdot
.99 .43976 Mdot
.99 .44006 Mdot
.99 .4413 Mdot
.99 .44149 Mdot
.99 .44154 Mdot
.99 .44183 Mdot
.99 .44291 Mdot
.99 .44308 Mdot
.99 .44388 Mdot
.99 .444 Mdot
.99 .44455 Mdot
.99 .44476 Mdot
.99 .4448 Mdot
.99 .44507 Mdot
.99 .44665 Mdot
.99 .44674 Mdot
.99 .44719 Mdot
.99 .4474 Mdot
.99 .44888 Mdot
.99 .44904 Mdot
.99 .44923 Mdot
.99 .44959 Mdot
.99 .44968 Mdot
.99 .45008 Mdot
.99 .45136 Mdot
.99 .45166 Mdot
.99 .45181 Mdot
.99 .45189 Mdot
.99 .45246 Mdot
.99 .45248 Mdot
.99 .45321 Mdot
.99 .45366 Mdot
.99 .45379 Mdot
.99 .45479 Mdot
.99 .45483 Mdot
.99 .45604 Mdot
.99 .45689 Mdot
.99 .45695 Mdot
.99 .45713 Mdot
.99 .45749 Mdot
.99 .45805 Mdot
.99 .45827 Mdot
.99 .45872 Mdot
.99 .45919 Mdot
.99 .45927 Mdot
.99 .46015 Mdot
.99 .46122 Mdot
.99 .46153 Mdot
.99 .46182 Mdot
.99 .46211 Mdot
.99 .46323 Mdot
.99 .46349 Mdot
.99 .46382 Mdot
.99 .46383 Mdot
.99 .46545 Mdot
.99 .46598 Mdot
.99 .46647 Mdot
.99 .46787 Mdot
.99 .46789 Mdot
.99 .46827 Mdot
.99 .46839 Mdot
.99 .4684 Mdot
.99 .46854 Mdot
.99 .46865 Mdot
.99 .46914 Mdot
.99 .46925 Mdot
.99 .4696 Mdot
.99 .47067 Mdot
.99 .47119 Mdot
.99 .47205 Mdot
.99 .47251 Mdot
.99 .47256 Mdot
.99 .47257 Mdot
.99 .47269 Mdot
.99 .47301 Mdot
.99 .47342 Mdot
.99 .47426 Mdot
.99 .47454 Mdot
.99 .47463 Mdot
.99 .47514 Mdot
.99 .47574 Mdot
.99 .4768 Mdot
.99 .47747 Mdot
.99 .47789 Mdot
.99 .47831 Mdot
.99 .47899 Mdot
.99 .47932 Mdot
.99 .48086 Mdot
.99 .4817 Mdot
.99 .48187 Mdot
.99 .48246 Mdot
.99 .48368 Mdot
.99 .48552 Mdot
.99 .48625 Mdot
.99 .48664 Mdot
.99 .4879 Mdot
.99 .48889 Mdot
.99 .48896 Mdot
.99 .48899 Mdot
.99 .48909 Mdot
.99 .48971 Mdot
.99 .49078 Mdot
.99 .49106 Mdot
.99 .49142 Mdot
.99 .49154 Mdot
.99 .49189 Mdot
.99 .49301 Mdot
.99 .49322 Mdot
.99 .49384 Mdot
.99 .49498 Mdot
.99 .49521 Mdot
.99 .49618 Mdot
.99 .4967 Mdot
.99 .49684 Mdot
.99 .49694 Mdot
.99 .498 Mdot
.99 .49858 Mdot
.99 .49952 Mdot
.99 .50013 Mdot
.99 .50062 Mdot
.99 .50135 Mdot
.99 .50148 Mdot
.99 .50164 Mdot
.99 .50204 Mdot
.99 .50254 Mdot
.99 .50385 Mdot
.99 .50466 Mdot
.99 .50585 Mdot
.99 .50618 Mdot
.99 .50636 Mdot
.99 .50642 Mdot
.99 .50746 Mdot
.99 .50918 Mdot
.99 .5096 Mdot
.99 .51012 Mdot
.99 .51015 Mdot
.99 .51179 Mdot
.99 .51197 Mdot
.99 .51201 Mdot
.99 .51343 Mdot
.99 .51386 Mdot
.99 .51392 Mdot
.99 .51529 Mdot
.99 .51606 Mdot
.99 .51628 Mdot
.99 .51645 Mdot
.99 .51704 Mdot
.99 .5202 Mdot
.99 .52081 Mdot
.99 .52131 Mdot
.99 .52254 Mdot
.99 .5243 Mdot
.99 .52452 Mdot
.99 .52457 Mdot
.99 .52489 Mdot
.99 .52581 Mdot
.99 .526 Mdot
.99 .52629 Mdot
.99 .5271 Mdot
.99 .52733 Mdot
.99 .52931 Mdot
.99 .5295 Mdot
.99 .53078 Mdot
.99 .5309 Mdot
.99 .53156 Mdot
.99 .53179 Mdot
.99 .53187 Mdot
.99 .53216 Mdot
.99 .53263 Mdot
.99 .53267 Mdot
.99 .53286 Mdot
.99 .53406 Mdot
.99 .53407 Mdot
.99 .53468 Mdot
.99 .53572 Mdot
.99 .53627 Mdot
.99 .53632 Mdot
.99 .53749 Mdot
.99 .53777 Mdot
.99 .53805 Mdot
.99 .53877 Mdot
.99 .53903 Mdot
.99 .53997 Mdot
.99 .54006 Mdot
.99 .54037 Mdot
.99 .54234 Mdot
.99 .54306 Mdot
.99 .54327 Mdot
.99 .54426 Mdot
.99 .54442 Mdot
.99 .54529 Mdot
.99 .54536 Mdot
.99 .54564 Mdot
.99 .54569 Mdot
.99 .54608 Mdot
.99 .54614 Mdot
.99 .54682 Mdot
.99 .54798 Mdot
.99 .54843 Mdot
.99 .54864 Mdot
.99 .54865 Mdot
.99 .54896 Mdot
.99 .54902 Mdot
.99 .5493 Mdot
.99 .54949 Mdot
.99 .5497 Mdot
.99 .54999 Mdot
.99 .55099 Mdot
.99 .55106 Mdot
.99 .55236 Mdot
.99 .55245 Mdot
.99 .55292 Mdot
.99 .55498 Mdot
.99 .55509 Mdot
.99 .5559 Mdot
.99 .55607 Mdot
.99 .55654 Mdot
.99 .55711 Mdot
.99 .55804 Mdot
.99 .5582 Mdot
.99 .55847 Mdot
.99 .5589 Mdot
.99 .56055 Mdot
.99 .56066 Mdot
.99 .56103 Mdot
.99 .56277 Mdot
.99 .56288 Mdot
.99 .5633 Mdot
.99 .56348 Mdot
.99 .56366 Mdot
.99 .56542 Mdot
.99 .56624 Mdot
.99 .56688 Mdot
.99 .56693 Mdot
.99 .56823 Mdot
.99 .57065 Mdot
.99 .57203 Mdot
.99 .57211 Mdot
.99 .5722 Mdot
.99 .57269 Mdot
.99 .57342 Mdot
.99 .57363 Mdot
.99 .57365 Mdot
.99 .57377 Mdot
.99 .57397 Mdot
.99 .57429 Mdot
.99 .57435 Mdot
.99 .57478 Mdot
.99 .57483 Mdot
.99 .57492 Mdot
.99 .57519 Mdot
.99 .5759 Mdot
.99 .57675 Mdot
.99 .57692 Mdot
.99 .57711 Mdot
.99 .57763 Mdot
.99 .57815 Mdot
.99 .57939 Mdot
.99 .57986 Mdot
.99 .57993 Mdot
.99 .58049 Mdot
.99 .58068 Mdot
.99 .58134 Mdot
.99 .58176 Mdot
.99 .58231 Mdot
.99 .58243 Mdot
.99 .58294 Mdot
.99 .58352 Mdot
.99 .58384 Mdot
.99 .58477 Mdot
.99 .58508 Mdot
.99 .58519 Mdot
.99 .5861 Mdot
.99 .58616 Mdot
.99 .58631 Mdot
.99 .58692 Mdot
.99 .58742 Mdot
.99 .58834 Mdot
.99 .58868 Mdot
.99 .58903 Mdot
.99 .58956 Mdot
.99 .58969 Mdot
.99 .59025 Mdot
.99 .59081 Mdot
.99 .59132 Mdot
.99 .59176 Mdot
.99 .59207 Mdot
.99 .59314 Mdot
.99 .59387 Mdot
.99 .59411 Mdot
.99 .59484 Mdot
.99 .59521 Mdot
.99 .59539 Mdot
.99 .59566 Mdot
.99 .59745 Mdot
.99 .59781 Mdot
.99 .59827 Mdot
.992 .02456 Mdot
.992 .02616 Mdot
.992 .02704 Mdot
.992 .02732 Mdot
.992 .02755 Mdot
.992 .02862 Mdot
.992 .02876 Mdot
.992 .02951 Mdot
.992 .02977 Mdot
.992 .03161 Mdot
.992 .03416 Mdot
.992 .03425 Mdot
.992 .03474 Mdot
.992 .03741 Mdot
.992 .03746 Mdot
.992 .03774 Mdot
.992 .03917 Mdot
.992 .03972 Mdot
.992 .04017 Mdot
.992 .04022 Mdot
.992 .04142 Mdot
.992 .04228 Mdot
.992 .04231 Mdot
.992 .04258 Mdot
.992 .04272 Mdot
.992 .04316 Mdot
.992 .04375 Mdot
.992 .04406 Mdot
.992 .04459 Mdot
.992 .04604 Mdot
.992 .04713 Mdot
.992 .04824 Mdot
.992 .04849 Mdot
.992 .04872 Mdot
.992 .04928 Mdot
.992 .04998 Mdot
.992 .05074 Mdot
.992 .05089 Mdot
.992 .05126 Mdot
.992 .05238 Mdot
.992 .05329 Mdot
.992 .05348 Mdot
.992 .0543 Mdot
.992 .05445 Mdot
.992 .05466 Mdot
.992 .05552 Mdot
.992 .05594 Mdot
.992 .0572 Mdot
.992 .05835 Mdot
.992 .05975 Mdot
.992 .05985 Mdot
.992 .06039 Mdot
.992 .0618 Mdot
.992 .06316 Mdot
.992 .06323 Mdot
.992 .06433 Mdot
.992 .06522 Mdot
.992 .06532 Mdot
.992 .0674 Mdot
.992 .0677 Mdot
.992 .06798 Mdot
.992 .06878 Mdot
.992 .0694 Mdot
.992 .06947 Mdot
.992 .07 Mdot
.992 .07028 Mdot
.992 .07078 Mdot
.992 .07114 Mdot
.992 .07127 Mdot
.992 .07195 Mdot
.992 .07233 Mdot
.992 .07243 Mdot
.992 .07288 Mdot
.992 .07294 Mdot
.992 .07305 Mdot
.992 .07399 Mdot
.992 .07529 Mdot
.992 .07537 Mdot
.992 .07659 Mdot
.992 .07686 Mdot
.992 .07784 Mdot
.992 .07902 Mdot
.992 .07996 Mdot
.992 .08124 Mdot
.992 .08144 Mdot
.992 .08146 Mdot
.992 .08172 Mdot
.992 .08206 Mdot
.992 .08218 Mdot
.992 .08246 Mdot
.992 .08329 Mdot
.992 .08435 Mdot
.992 .08468 Mdot
.992 .08471 Mdot
.992 .08618 Mdot
.992 .08649 Mdot
.992 .08722 Mdot
.992 .08845 Mdot
.992 .089 Mdot
.992 .08943 Mdot
.992 .08945 Mdot
.992 .09092 Mdot
.992 .09114 Mdot
.992 .09123 Mdot
.992 .09125 Mdot
.992 .09148 Mdot
.992 .09163 Mdot
.992 .09326 Mdot
.992 .09342 Mdot
.992 .09354 Mdot
.992 .09384 Mdot
.992 .09397 Mdot
.992 .09568 Mdot
.992 .0965 Mdot
.992 .09753 Mdot
.992 .09858 Mdot
.992 .09901 Mdot
.992 .09922 Mdot
.992 .09949 Mdot
.992 .10076 Mdot
.992 .10123 Mdot
.992 .10128 Mdot
.992 .10147 Mdot
.992 .1028 Mdot
.992 .10399 Mdot
.992 .10406 Mdot
.992 .10426 Mdot
.992 .10465 Mdot
.992 .10491 Mdot
.992 .10533 Mdot
.992 .10629 Mdot
.992 .10812 Mdot
.992 .10916 Mdot
.992 .10999 Mdot
.992 .11082 Mdot
.992 .11096 Mdot
.992 .11137 Mdot
.992 .11316 Mdot
.992 .11492 Mdot
.992 .11512 Mdot
.992 .11614 Mdot
.992 .11737 Mdot
.992 .11744 Mdot
.992 .118 Mdot
.992 .11923 Mdot
.992 .11984 Mdot
.992 .12006 Mdot
.992 .12039 Mdot
.992 .12198 Mdot
.992 .12277 Mdot
.992 .12321 Mdot
.992 .12323 Mdot
.992 .12334 Mdot
.992 .1244 Mdot
.992 .12496 Mdot
.992 .12555 Mdot
.992 .12595 Mdot
.992 .12667 Mdot
.992 .12667 Mdot
.992 .12692 Mdot
.992 .12823 Mdot
.992 .12828 Mdot
.992 .12849 Mdot
.992 .12892 Mdot
.992 .12901 Mdot
.992 .12921 Mdot
.992 .13012 Mdot
.992 .13021 Mdot
.992 .13023 Mdot
.992 .13046 Mdot
.992 .13103 Mdot
.992 .13168 Mdot
.992 .13231 Mdot
.992 .13358 Mdot
.992 .13403 Mdot
.992 .1346 Mdot
.992 .1348 Mdot
.992 .13489 Mdot
.992 .13505 Mdot
.992 .13511 Mdot
.992 .13556 Mdot
.992 .13583 Mdot
.992 .13748 Mdot
.992 .138 Mdot
.992 .13924 Mdot
.992 .13982 Mdot
.992 .13995 Mdot
.992 .14026 Mdot
.992 .14082 Mdot
.992 .14182 Mdot
.992 .14192 Mdot
.992 .1423 Mdot
.992 .14393 Mdot
.992 .14416 Mdot
.992 .14514 Mdot
.992 .14599 Mdot
.992 .14608 Mdot
.992 .14669 Mdot
.992 .14696 Mdot
.992 .1471 Mdot
.992 .14713 Mdot
.992 .14766 Mdot
.992 .14832 Mdot
.992 .14857 Mdot
.992 .14865 Mdot
.992 .14912 Mdot
.992 .15076 Mdot
.992 .15111 Mdot
.992 .15137 Mdot
.992 .15239 Mdot
.992 .15287 Mdot
.992 .15305 Mdot
.992 .15332 Mdot
.992 .15352 Mdot
.992 .15358 Mdot
.992 .15374 Mdot
.992 .15452 Mdot
.992 .15605 Mdot
.992 .15651 Mdot
.992 .15712 Mdot
.992 .15715 Mdot
.992 .15726 Mdot
.992 .15857 Mdot
.992 .15932 Mdot
.992 .15952 Mdot
.992 .15998 Mdot
.992 .16101 Mdot
.992 .16106 Mdot
.992 .1621 Mdot
.992 .16243 Mdot
.992 .16267 Mdot
.992 .16295 Mdot
.992 .16298 Mdot
.992 .16333 Mdot
.992 .16409 Mdot
.992 .16591 Mdot
.992 .16635 Mdot
.992 .16652 Mdot
.992 .16655 Mdot
.992 .16662 Mdot
.992 .16702 Mdot
.992 .16731 Mdot
.992 .16902 Mdot
.992 .16938 Mdot
.992 .16944 Mdot
.992 .17055 Mdot
.992 .17082 Mdot
.992 .17087 Mdot
.992 .17111 Mdot
.992 .17171 Mdot
.992 .17195 Mdot
.992 .17199 Mdot
.992 .17233 Mdot
.992 .17302 Mdot
.992 .17331 Mdot
.992 .17429 Mdot
.992 .17535 Mdot
.992 .17609 Mdot
.992 .17653 Mdot
.992 .17699 Mdot
.992 .17757 Mdot
.992 .17902 Mdot
.992 .18074 Mdot
.992 .18094 Mdot
.992 .18111 Mdot
.992 .18195 Mdot
.992 .18201 Mdot
.992 .18238 Mdot
.992 .18292 Mdot
.992 .18362 Mdot
.992 .18542 Mdot
.992 .18635 Mdot
.992 .18647 Mdot
.992 .18685 Mdot
.992 .1888 Mdot
.992 .18915 Mdot
.992 .18948 Mdot
.992 .19079 Mdot
.992 .1909 Mdot
.992 .19182 Mdot
.992 .19183 Mdot
.992 .19197 Mdot
.992 .19214 Mdot
.992 .19236 Mdot
.992 .19254 Mdot
.992 .19271 Mdot
.992 .19297 Mdot
.992 .19314 Mdot
.992 .19365 Mdot
.992 .1945 Mdot
.992 .19607 Mdot
.992 .19639 Mdot
.992 .19944 Mdot
.992 .20004 Mdot
.992 .2004 Mdot
.992 .20168 Mdot
.992 .20209 Mdot
.992 .20336 Mdot
.992 .20375 Mdot
.992 .20426 Mdot
.992 .20474 Mdot
.992 .20539 Mdot
.992 .20567 Mdot
.992 .20648 Mdot
.992 .20667 Mdot
.992 .20714 Mdot
.992 .20722 Mdot
.992 .20816 Mdot
.992 .20849 Mdot
.992 .20976 Mdot
.992 .21002 Mdot
.992 .21026 Mdot
.992 .21274 Mdot
.992 .21353 Mdot
.992 .21393 Mdot
.992 .21593 Mdot
.992 .21791 Mdot
.992 .21816 Mdot
.992 .21839 Mdot
.992 .21853 Mdot
.992 .21963 Mdot
.992 .22083 Mdot
.992 .22175 Mdot
.992 .22175 Mdot
.992 .22208 Mdot
.992 .22237 Mdot
.992 .2225 Mdot
.992 .22328 Mdot
.992 .22372 Mdot
.992 .22438 Mdot
.992 .22438 Mdot
.992 .22523 Mdot
.992 .22648 Mdot
.992 .22752 Mdot
.992 .22776 Mdot
.992 .2281 Mdot
.992 .2291 Mdot
.992 .22997 Mdot
.992 .23 Mdot
.992 .23007 Mdot
.992 .23019 Mdot
.992 .23023 Mdot
.992 .23194 Mdot
.992 .23198 Mdot
.992 .23233 Mdot
.992 .23343 Mdot
.992 .23383 Mdot
.992 .23461 Mdot
.992 .23541 Mdot
.992 .23602 Mdot
.992 .23683 Mdot
.992 .23684 Mdot
.992 .23733 Mdot
.992 .23802 Mdot
.992 .23881 Mdot
.992 .23889 Mdot
.992 .23917 Mdot
.992 .23935 Mdot
.992 .23993 Mdot
.992 .24002 Mdot
.992 .24044 Mdot
.992 .24129 Mdot
.992 .24146 Mdot
.992 .24149 Mdot
.992 .24188 Mdot
.992 .24368 Mdot
.992 .24386 Mdot
.992 .2439 Mdot
.992 .24435 Mdot
.992 .24467 Mdot
.992 .245 Mdot
.992 .24546 Mdot
.992 .24548 Mdot
.992 .24573 Mdot
.992 .24608 Mdot
.992 .24612 Mdot
.992 .24668 Mdot
.992 .24677 Mdot
.992 .24704 Mdot
.992 .24725 Mdot
.992 .24726 Mdot
.992 .24743 Mdot
.992 .2479 Mdot
.992 .24802 Mdot
.992 .2486 Mdot
.992 .24892 Mdot
.992 .24983 Mdot
.992 .2503 Mdot
.992 .25055 Mdot
.992 .25081 Mdot
.992 .25144 Mdot
.992 .25171 Mdot
.992 .25234 Mdot
.992 .25258 Mdot
.992 .25283 Mdot
.992 .25295 Mdot
.992 .253 Mdot
.992 .25314 Mdot
.992 .25339 Mdot
.992 .25346 Mdot
.992 .25357 Mdot
.992 .25447 Mdot
.992 .25501 Mdot
.992 .25505 Mdot
.992 .25585 Mdot
.992 .25641 Mdot
.992 .25689 Mdot
.992 .25737 Mdot
.992 .25787 Mdot
.992 .25828 Mdot
.992 .25932 Mdot
.992 .25971 Mdot
.992 .26039 Mdot
.992 .26177 Mdot
.992 .2624 Mdot
.992 .26252 Mdot
.992 .26293 Mdot
.992 .26319 Mdot
.992 .26331 Mdot
.992 .2638 Mdot
.992 .26458 Mdot
.992 .2649 Mdot
.992 .26686 Mdot
.992 .2669 Mdot
.992 .267 Mdot
.992 .26708 Mdot
.992 .26732 Mdot
.992 .26785 Mdot
.992 .26917 Mdot
.992 .26985 Mdot
.992 .2699 Mdot
.992 .2707 Mdot
.992 .27108 Mdot
.992 .27154 Mdot
.992 .27179 Mdot
.992 .27212 Mdot
.992 .27348 Mdot
.992 .27432 Mdot
.992 .27449 Mdot
.992 .27517 Mdot
.992 .27534 Mdot
.992 .27586 Mdot
.992 .27589 Mdot
.992 .27656 Mdot
.992 .27676 Mdot
.992 .27686 Mdot
.992 .27693 Mdot
.992 .2771 Mdot
.992 .27736 Mdot
.992 .27743 Mdot
.992 .27848 Mdot
.992 .27872 Mdot
.992 .27925 Mdot
.992 .27978 Mdot
.992 .28004 Mdot
.992 .28029 Mdot
.992 .28044 Mdot
.992 .28131 Mdot
.992 .28138 Mdot
.992 .28176 Mdot
.992 .28306 Mdot
.992 .28324 Mdot
.992 .28392 Mdot
.992 .28462 Mdot
.992 .28531 Mdot
.992 .28584 Mdot
.992 .286 Mdot
.992 .28787 Mdot
.992 .28881 Mdot
.992 .28916 Mdot
.992 .2897 Mdot
.992 .2901 Mdot
.992 .29022 Mdot
.992 .29054 Mdot
.992 .29104 Mdot
.992 .29208 Mdot
.992 .29257 Mdot
.992 .29266 Mdot
.992 .29334 Mdot
.992 .29512 Mdot
.992 .29604 Mdot
.992 .29669 Mdot
.992 .29725 Mdot
.992 .2973 Mdot
.992 .29753 Mdot
.992 .29834 Mdot
.992 .29869 Mdot
.992 .30011 Mdot
.992 .30099 Mdot
.992 .3016 Mdot
.992 .30171 Mdot
.992 .30202 Mdot
.992 .30279 Mdot
.992 .30292 Mdot
.992 .30312 Mdot
.992 .30496 Mdot
.992 .30507 Mdot
.992 .30559 Mdot
.992 .30623 Mdot
.992 .30714 Mdot
.992 .30778 Mdot
.992 .30825 Mdot
.992 .30882 Mdot
.992 .30887 Mdot
.992 .30894 Mdot
.992 .30957 Mdot
.992 .31022 Mdot
.992 .31085 Mdot
.992 .31089 Mdot
.992 .31108 Mdot
.992 .31241 Mdot
.992 .3131 Mdot
.992 .3141 Mdot
.992 .31454 Mdot
.992 .31469 Mdot
.992 .31527 Mdot
.992 .31555 Mdot
.992 .3159 Mdot
.992 .31596 Mdot
.992 .3161 Mdot
.992 .31651 Mdot
.992 .31689 Mdot
.992 .31747 Mdot
.992 .31811 Mdot
.992 .31962 Mdot
.992 .32085 Mdot
.992 .32156 Mdot
.992 .32169 Mdot
.992 .32198 Mdot
.992 .32273 Mdot
.992 .32304 Mdot
.992 .32389 Mdot
.992 .32427 Mdot
.992 .32443 Mdot
.992 .32453 Mdot
.992 .32501 Mdot
.992 .3251 Mdot
.992 .32619 Mdot
.992 .3263 Mdot
.992 .32668 Mdot
.992 .32676 Mdot
.992 .32742 Mdot
.992 .32862 Mdot
.992 .32879 Mdot
.992 .32936 Mdot
.992 .33 Mdot
.992 .33017 Mdot
.992 .33131 Mdot
.992 .33187 Mdot
.992 .33308 Mdot
.992 .33342 Mdot
.992 .33488 Mdot
.992 .33576 Mdot
.992 .33622 Mdot
.992 .33666 Mdot
.992 .33687 Mdot
.992 .33703 Mdot
.992 .33752 Mdot
.992 .33778 Mdot
.992 .33782 Mdot
.992 .3379 Mdot
.992 .33921 Mdot
.992 .33963 Mdot
.992 .34045 Mdot
.992 .34069 Mdot
.992 .34134 Mdot
.992 .34322 Mdot
.992 .34411 Mdot
.992 .3445 Mdot
.992 .34484 Mdot
.992 .34527 Mdot
.992 .34652 Mdot
.992 .34661 Mdot
.992 .34662 Mdot
.992 .34698 Mdot
.992 .34736 Mdot
.992 .34753 Mdot
.992 .34843 Mdot
.992 .34982 Mdot
.992 .35163 Mdot
.992 .35205 Mdot
.992 .3526 Mdot
.992 .35339 Mdot
.992 .35425 Mdot
.992 .35524 Mdot
.992 .35547 Mdot
.992 .35622 Mdot
.992 .35655 Mdot
.992 .35991 Mdot
.992 .35992 Mdot
.992 .36011 Mdot
.992 .36058 Mdot
.992 .3608 Mdot
.992 .36144 Mdot
.992 .36206 Mdot
.992 .36251 Mdot
.992 .36405 Mdot
.992 .36425 Mdot
.992 .36427 Mdot
.992 .36574 Mdot
.992 .3661 Mdot
.992 .36611 Mdot
.992 .36634 Mdot
.992 .36639 Mdot
.992 .36674 Mdot
.992 .36717 Mdot
.992 .3673 Mdot
.992 .36752 Mdot
.992 .36781 Mdot
.992 .36785 Mdot
.992 .36838 Mdot
.992 .36872 Mdot
.992 .36896 Mdot
.992 .36973 Mdot
.992 .37024 Mdot
.992 .37027 Mdot
.992 .37141 Mdot
.992 .37367 Mdot
.992 .37389 Mdot
.992 .37452 Mdot
.992 .37516 Mdot
.992 .37624 Mdot
.992 .38122 Mdot
.992 .38239 Mdot
.992 .38295 Mdot
.992 .38312 Mdot
.992 .38349 Mdot
.992 .38367 Mdot
.992 .38439 Mdot
.992 .38538 Mdot
.992 .38565 Mdot
.992 .38617 Mdot
.992 .38647 Mdot
.992 .38789 Mdot
.992 .3882 Mdot
.992 .389 Mdot
.992 .38976 Mdot
.992 .38986 Mdot
.992 .39007 Mdot
.992 .39077 Mdot
.992 .39173 Mdot
.992 .39302 Mdot
.992 .39316 Mdot
.992 .39358 Mdot
.992 .39518 Mdot
.992 .39556 Mdot
.992 .39649 Mdot
.992 .39665 Mdot
.992 .39851 Mdot
.992 .39916 Mdot
.992 .40105 Mdot
.992 .40169 Mdot
.992 .40212 Mdot
.992 .4022 Mdot
.992 .40262 Mdot
.992 .40268 Mdot
.992 .40574 Mdot
.992 .40759 Mdot
.992 .40916 Mdot
.992 .40941 Mdot
.992 .40995 Mdot
.992 .41393 Mdot
.992 .41549 Mdot
.992 .41559 Mdot
.992 .41643 Mdot
.992 .41659 Mdot
.992 .41745 Mdot
.992 .41785 Mdot
.992 .41835 Mdot
.992 .41871 Mdot
.992 .4188 Mdot
.992 .41908 Mdot
.992 .42246 Mdot
.992 .42364 Mdot
.992 .42375 Mdot
.992 .42547 Mdot
.992 .42548 Mdot
.992 .42613 Mdot
.992 .42671 Mdot
.992 .42696 Mdot
.992 .42745 Mdot
.992 .42775 Mdot
.992 .4285 Mdot
.992 .42938 Mdot
.992 .42961 Mdot
.992 .43035 Mdot
.992 .43069 Mdot
.992 .43069 Mdot
.992 .43238 Mdot
.992 .43354 Mdot
.992 .43437 Mdot
.992 .43465 Mdot
.992 .43486 Mdot
.992 .43693 Mdot
.992 .43721 Mdot
.992 .43739 Mdot
.992 .43807 Mdot
.992 .4391 Mdot
.992 .44005 Mdot
.992 .4405 Mdot
.992 .44091 Mdot
.992 .44112 Mdot
.992 .44178 Mdot
.992 .44185 Mdot
.992 .44198 Mdot
.992 .44222 Mdot
.992 .4423 Mdot
.992 .44263 Mdot
.992 .44421 Mdot
.992 .44482 Mdot
.992 .44568 Mdot
.992 .44577 Mdot
.992 .44646 Mdot
.992 .44763 Mdot
.992 .44823 Mdot
.992 .44865 Mdot
.992 .44927 Mdot
.992 .44943 Mdot
.992 .44981 Mdot
.992 .45099 Mdot
.992 .45176 Mdot
.992 .45256 Mdot
.992 .45319 Mdot
.992 .45355 Mdot
.992 .45378 Mdot
.992 .45428 Mdot
.992 .45463 Mdot
.992 .4554 Mdot
.992 .45542 Mdot
.992 .45573 Mdot
.992 .45638 Mdot
.992 .45775 Mdot
.992 .45807 Mdot
.992 .45931 Mdot
.992 .45948 Mdot
.992 .46002 Mdot
.992 .46039 Mdot
.992 .46154 Mdot
.992 .46172 Mdot
.992 .46255 Mdot
.992 .46424 Mdot
.992 .46459 Mdot
.992 .46463 Mdot
.992 .4654 Mdot
.992 .46794 Mdot
.992 .46899 Mdot
.992 .46933 Mdot
.992 .46942 Mdot
.992 .47008 Mdot
.992 .47031 Mdot
.992 .47095 Mdot
.992 .47134 Mdot
.992 .47161 Mdot
.992 .47251 Mdot
.992 .47255 Mdot
.992 .4726 Mdot
.992 .47304 Mdot
.992 .47305 Mdot
.992 .47374 Mdot
.992 .47383 Mdot
.992 .47494 Mdot
.992 .47511 Mdot
.992 .47565 Mdot
.992 .47606 Mdot
.992 .47608 Mdot
.992 .47643 Mdot
.992 .47736 Mdot
.992 .47752 Mdot
.992 .47759 Mdot
.992 .47874 Mdot
.992 .47938 Mdot
.992 .47977 Mdot
.992 .47984 Mdot
.992 .48085 Mdot
.992 .48119 Mdot
.992 .48212 Mdot
.992 .48237 Mdot
.992 .48261 Mdot
.992 .48286 Mdot
.992 .48314 Mdot
.992 .48354 Mdot
.992 .48438 Mdot
.992 .48458 Mdot
.992 .48466 Mdot
.992 .48491 Mdot
.992 .48523 Mdot
.992 .48568 Mdot
.992 .48593 Mdot
.992 .48617 Mdot
.992 .48663 Mdot
.992 .48679 Mdot
.992 .48714 Mdot
.992 .48738 Mdot
.992 .48747 Mdot
.992 .48747 Mdot
.992 .48758 Mdot
.992 .48776 Mdot
.992 .48804 Mdot
.992 .48806 Mdot
.992 .48824 Mdot
.992 .48838 Mdot
.992 .4886 Mdot
.992 .48877 Mdot
.992 .49039 Mdot
.992 .49146 Mdot
.992 .49155 Mdot
.992 .49169 Mdot
.992 .49173 Mdot
.992 .49213 Mdot
.992 .49313 Mdot
.992 .49424 Mdot
.992 .49517 Mdot
.992 .49519 Mdot
.992 .49607 Mdot
.992 .49613 Mdot
.992 .49713 Mdot
.992 .4973 Mdot
.992 .49794 Mdot
.992 .49857 Mdot
.992 .499 Mdot
.992 .49995 Mdot
.992 .50001 Mdot
.992 .50032 Mdot
.992 .50033 Mdot
.992 .50079 Mdot
.992 .50214 Mdot
.992 .50487 Mdot
.992 .50612 Mdot
.992 .50637 Mdot
.992 .50701 Mdot
.992 .50718 Mdot
.992 .50765 Mdot
.992 .50769 Mdot
.992 .50792 Mdot
.992 .5089 Mdot
.992 .50914 Mdot
.992 .50959 Mdot
.992 .51044 Mdot
.992 .51108 Mdot
.992 .51157 Mdot
.992 .51327 Mdot
.992 .51483 Mdot
.992 .51496 Mdot
.992 .51505 Mdot
.992 .51525 Mdot
.992 .51541 Mdot
.992 .51587 Mdot
.992 .51593 Mdot
.992 .51676 Mdot
.992 .51693 Mdot
.992 .51955 Mdot
.992 .52036 Mdot
.992 .5209 Mdot
.992 .521 Mdot
.992 .52259 Mdot
.992 .52312 Mdot
.992 .52334 Mdot
.992 .52425 Mdot
.992 .52474 Mdot
.992 .52489 Mdot
.992 .52524 Mdot
.992 .5254 Mdot
.992 .526 Mdot
.992 .52669 Mdot
.992 .52672 Mdot
.992 .5269 Mdot
.992 .52811 Mdot
.992 .52939 Mdot
.992 .52977 Mdot
.992 .53011 Mdot
.992 .53022 Mdot
.992 .53091 Mdot
.992 .53146 Mdot
.992 .53169 Mdot
.992 .53179 Mdot
.992 .53283 Mdot
.992 .53289 Mdot
.992 .53344 Mdot
.992 .53421 Mdot
.992 .53461 Mdot
.992 .53482 Mdot
.992 .53495 Mdot
.992 .53528 Mdot
.992 .5358 Mdot
.992 .53593 Mdot
.992 .53717 Mdot
.992 .53802 Mdot
.992 .53847 Mdot
.992 .53851 Mdot
.992 .53894 Mdot
.992 .53955 Mdot
.992 .54056 Mdot
.992 .54061 Mdot
.992 .54112 Mdot
.992 .5414 Mdot
.992 .54162 Mdot
.992 .54191 Mdot
.992 .54363 Mdot
.992 .54377 Mdot
.992 .544 Mdot
.992 .54415 Mdot
.992 .54425 Mdot
.992 .54454 Mdot
.992 .54476 Mdot
.992 .54573 Mdot
.992 .54605 Mdot
.992 .54646 Mdot
.992 .54712 Mdot
.992 .54733 Mdot
.992 .54746 Mdot
.992 .54825 Mdot
.992 .54881 Mdot
.992 .54998 Mdot
.992 .55021 Mdot
.992 .55158 Mdot
.992 .55262 Mdot
.992 .5529 Mdot
.992 .55293 Mdot
.992 .55356 Mdot
.992 .55596 Mdot
.992 .55665 Mdot
.992 .55707 Mdot
.992 .55852 Mdot
.992 .55922 Mdot
.992 .55935 Mdot
.992 .55968 Mdot
.992 .56028 Mdot
.992 .56095 Mdot
.992 .56107 Mdot
.992 .56131 Mdot
.992 .56195 Mdot
.992 .56208 Mdot
.992 .56241 Mdot
.992 .56294 Mdot
.992 .56479 Mdot
.992 .56501 Mdot
.992 .56599 Mdot
.992 .56611 Mdot
.992 .56616 Mdot
.992 .56627 Mdot
.992 .56702 Mdot
.992 .56723 Mdot
.992 .56751 Mdot
.992 .5694 Mdot
.992 .56958 Mdot
.992 .57053 Mdot
.992 .57074 Mdot
.992 .57104 Mdot
.992 .57105 Mdot
.992 .57179 Mdot
.992 .57286 Mdot
.992 .57349 Mdot
.992 .57411 Mdot
.992 .57415 Mdot
.992 .57527 Mdot
.992 .57536 Mdot
.992 .57559 Mdot
.992 .57583 Mdot
.992 .57617 Mdot
.992 .57642 Mdot
.992 .57743 Mdot
.992 .57783 Mdot
.992 .57813 Mdot
.992 .58026 Mdot
.992 .58095 Mdot
.992 .58269 Mdot
.992 .58326 Mdot
.992 .5839 Mdot
.992 .58411 Mdot
.992 .58454 Mdot
.992 .58472 Mdot
.992 .58569 Mdot
.992 .58626 Mdot
.992 .58644 Mdot
.992 .58652 Mdot
.992 .5869 Mdot
.992 .58726 Mdot
.992 .58754 Mdot
.992 .58765 Mdot
.992 .58834 Mdot
.992 .58889 Mdot
.992 .59004 Mdot
.992 .59034 Mdot
.992 .59056 Mdot
.992 .59079 Mdot
.992 .59122 Mdot
.992 .59182 Mdot
.992 .59307 Mdot
.992 .59321 Mdot
.992 .59458 Mdot
.992 .59488 Mdot
.992 .59616 Mdot
.992 .59709 Mdot
.992 .59722 Mdot
.992 .5976 Mdot
.992 .59767 Mdot
.992 .59821 Mdot
.992 .59832 Mdot
.992 .59847 Mdot
.992 .59891 Mdot
.992 .59971 Mdot
.994 .02308 Mdot
.994 .02899 Mdot
.994 .02993 Mdot
.994 .03084 Mdot
.994 .03134 Mdot
.994 .03206 Mdot
.994 .03211 Mdot
.994 .03219 Mdot
.994 .03377 Mdot
.994 .03534 Mdot
.994 .03546 Mdot
.994 .03595 Mdot
.994 .03891 Mdot
.994 .04022 Mdot
.994 .04308 Mdot
.994 .04369 Mdot
.994 .04496 Mdot
.994 .04514 Mdot
.994 .04676 Mdot
.994 .0468 Mdot
.994 .04776 Mdot
.994 .04874 Mdot
.994 .04919 Mdot
.994 .0493 Mdot
.994 .04946 Mdot
.994 .05027 Mdot
.994 .05259 Mdot
.994 .05376 Mdot
.994 .05504 Mdot
.994 .05573 Mdot
.994 .05596 Mdot
.994 .05656 Mdot
.994 .05691 Mdot
.994 .05693 Mdot
.994 .05994 Mdot
.994 .06024 Mdot
.994 .06182 Mdot
.994 .06282 Mdot
.994 .06373 Mdot
.994 .06416 Mdot
.994 .06417 Mdot
.994 .06542 Mdot
.994 .06658 Mdot
.994 .06819 Mdot
.994 .06837 Mdot
.994 .06956 Mdot
.994 .07111 Mdot
.994 .07195 Mdot
.994 .07231 Mdot
.994 .0734 Mdot
.994 .07452 Mdot
.994 .07484 Mdot
.994 .07521 Mdot
.994 .07525 Mdot
.994 .07539 Mdot
.994 .07654 Mdot
.994 .07842 Mdot
.994 .0785 Mdot
.994 .07874 Mdot
.994 .07907 Mdot
.994 .07914 Mdot
.994 .08042 Mdot
.994 .08233 Mdot
.994 .08236 Mdot
.994 .08325 Mdot
.994 .08344 Mdot
.994 .08344 Mdot
.994 .08347 Mdot
.994 .08379 Mdot
.994 .08489 Mdot
.994 .08526 Mdot
.994 .0854 Mdot
.994 .08568 Mdot
.994 .08667 Mdot
.994 .09002 Mdot
.994 .0914 Mdot
.994 .09234 Mdot
.994 .0934 Mdot
.994 .09439 Mdot
.994 .09489 Mdot
.994 .09544 Mdot
.994 .09625 Mdot
.994 .09653 Mdot
.994 .09671 Mdot
.994 .09787 Mdot
.994 .0979 Mdot
.994 .09859 Mdot
.994 .09864 Mdot
.994 .09882 Mdot
.994 .10048 Mdot
.994 .1011 Mdot
.994 .10204 Mdot
.994 .10205 Mdot
.994 .10463 Mdot
.994 .10514 Mdot
.994 .10522 Mdot
.994 .10575 Mdot
.994 .10635 Mdot
.994 .10749 Mdot
.994 .10836 Mdot
.994 .10871 Mdot
.994 .1103 Mdot
.994 .11034 Mdot
.994 .1108 Mdot
.994 .1111 Mdot
.994 .11216 Mdot
.994 .1129 Mdot
.994 .11301 Mdot
.994 .11303 Mdot
.994 .1135 Mdot
.994 .1137 Mdot
.994 .11405 Mdot
.994 .11417 Mdot
.994 .11494 Mdot
.994 .11511 Mdot
.994 .11523 Mdot
.994 .11552 Mdot
.994 .11561 Mdot
.994 .11626 Mdot
.994 .11685 Mdot
.994 .1171 Mdot
.994 .11782 Mdot
.994 .11825 Mdot
.994 .11881 Mdot
.994 .12033 Mdot
.994 .12103 Mdot
.994 .12137 Mdot
.994 .12332 Mdot
.994 .12374 Mdot
.994 .12683 Mdot
.994 .12781 Mdot
.994 .12849 Mdot
.994 .12921 Mdot
.994 .12932 Mdot
.994 .1294 Mdot
.994 .13035 Mdot
.994 .1304 Mdot
.994 .13103 Mdot
.994 .13138 Mdot
.994 .13139 Mdot
.994 .13143 Mdot
.994 .1336 Mdot
.994 .1338 Mdot
.994 .13388 Mdot
.994 .13424 Mdot
.994 .13439 Mdot
.994 .13498 Mdot
.994 .13507 Mdot
.994 .13534 Mdot
.994 .13564 Mdot
.994 .13615 Mdot
.994 .13665 Mdot
.994 .13762 Mdot
.994 .13848 Mdot
.994 .14083 Mdot
.994 .14137 Mdot
.994 .14152 Mdot
.994 .14199 Mdot
.994 .14266 Mdot
.994 .14279 Mdot
.994 .14283 Mdot
.994 .1429 Mdot
.994 .14438 Mdot
.994 .14533 Mdot
.994 .14641 Mdot
.994 .14655 Mdot
.994 .14769 Mdot
.994 .14794 Mdot
.994 .14882 Mdot
.994 .14914 Mdot
.994 .14914 Mdot
.994 .14919 Mdot
.994 .15081 Mdot
.994 .15096 Mdot
.994 .15133 Mdot
.994 .15135 Mdot
.994 .15139 Mdot
.994 .15176 Mdot
.994 .15203 Mdot
.994 .15248 Mdot
.994 .15288 Mdot
.994 .15329 Mdot
.994 .15341 Mdot
.994 .15423 Mdot
.994 .15483 Mdot
.994 .15496 Mdot
.994 .15524 Mdot
.994 .15525 Mdot
.994 .15579 Mdot
.994 .15671 Mdot
.994 .1577 Mdot
.994 .15775 Mdot
.994 .15824 Mdot
.994 .1603 Mdot
.994 .16135 Mdot
.994 .16178 Mdot
.994 .16218 Mdot
.994 .16326 Mdot
.994 .16414 Mdot
.994 .16441 Mdot
.994 .1649 Mdot
.994 .16607 Mdot
.994 .16673 Mdot
.994 .16717 Mdot
.994 .1688 Mdot
.994 .16903 Mdot
.994 .16967 Mdot
.994 .17113 Mdot
.994 .17261 Mdot
.994 .17312 Mdot
.994 .17386 Mdot
.994 .17496 Mdot
.994 .17512 Mdot
.994 .1752 Mdot
.994 .1766 Mdot
.994 .17679 Mdot
.994 .1768 Mdot
.994 .17736 Mdot
.994 .17772 Mdot
.994 .17927 Mdot
.994 .17931 Mdot
.994 .18003 Mdot
.994 .18009 Mdot
.994 .1804 Mdot
.994 .18047 Mdot
.994 .18097 Mdot
.994 .18111 Mdot
.994 .18132 Mdot
.994 .18146 Mdot
.994 .18155 Mdot
.994 .18192 Mdot
.994 .1823 Mdot
.994 .18454 Mdot
.994 .18522 Mdot
.994 .18545 Mdot
.994 .18545 Mdot
.994 .18559 Mdot
.994 .18637 Mdot
.994 .18645 Mdot
.994 .1876 Mdot
.994 .18832 Mdot
.994 .18833 Mdot
.994 .18901 Mdot
.994 .19 Mdot
.994 .19025 Mdot
.994 .19027 Mdot
.994 .19123 Mdot
.994 .19244 Mdot
.994 .19247 Mdot
.994 .19346 Mdot
.994 .19388 Mdot
.994 .19447 Mdot
.994 .19463 Mdot
.994 .19559 Mdot
.994 .19569 Mdot
.994 .19672 Mdot
.994 .19689 Mdot
.994 .19737 Mdot
.994 .19741 Mdot
.994 .19851 Mdot
.994 .19915 Mdot
.994 .20088 Mdot
.994 .20147 Mdot
.994 .20158 Mdot
.994 .20341 Mdot
.994 .2035 Mdot
.994 .20398 Mdot
.994 .20464 Mdot
.994 .20474 Mdot
.994 .20482 Mdot
.994 .20524 Mdot
.994 .20573 Mdot
.994 .20633 Mdot
.994 .20703 Mdot
.994 .20769 Mdot
.994 .20843 Mdot
.994 .2099 Mdot
.994 .21012 Mdot
.994 .21016 Mdot
.994 .21111 Mdot
.994 .21149 Mdot
.994 .2118 Mdot
.994 .2122 Mdot
.994 .21243 Mdot
.994 .21396 Mdot
.994 .21426 Mdot
.994 .21428 Mdot
.994 .21431 Mdot
.994 .21454 Mdot
.994 .21512 Mdot
.994 .21515 Mdot
.994 .21528 Mdot
.994 .21658 Mdot
.994 .21676 Mdot
.994 .21775 Mdot
.994 .21786 Mdot
.994 .21813 Mdot
.994 .21826 Mdot
.994 .21969 Mdot
.994 .21992 Mdot
.994 .22 Mdot
.994 .22054 Mdot
.994 .22166 Mdot
.994 .2219 Mdot
.994 .22284 Mdot
.994 .22287 Mdot
.994 .22427 Mdot
.994 .22467 Mdot
.994 .22533 Mdot
.994 .22607 Mdot
.994 .22635 Mdot
.994 .22664 Mdot
.994 .22675 Mdot
.994 .22951 Mdot
.994 .23062 Mdot
.994 .23146 Mdot
.994 .23317 Mdot
.994 .23346 Mdot
.994 .23461 Mdot
.994 .23511 Mdot
.994 .23523 Mdot
.994 .23751 Mdot
.994 .23761 Mdot
.994 .23771 Mdot
.994 .23955 Mdot
.994 .23981 Mdot
.994 .2399 Mdot
.994 .24035 Mdot
.994 .2409 Mdot
.994 .24198 Mdot
.994 .24233 Mdot
.994 .24256 Mdot
.994 .24267 Mdot
.994 .24271 Mdot
.994 .24282 Mdot
.994 .24379 Mdot
.994 .2446 Mdot
.994 .24469 Mdot
.994 .24595 Mdot
.994 .24665 Mdot
.994 .24666 Mdot
.994 .24675 Mdot
.994 .24732 Mdot
.994 .24755 Mdot
.994 .24763 Mdot
.994 .24786 Mdot
.994 .24847 Mdot
.994 .24847 Mdot
.994 .24996 Mdot
.994 .25105 Mdot
.994 .2513 Mdot
.994 .25145 Mdot
.994 .25161 Mdot
.994 .25195 Mdot
.994 .25233 Mdot
.994 .25233 Mdot
.994 .25254 Mdot
.994 .25256 Mdot
.994 .25262 Mdot
.994 .25351 Mdot
.994 .2538 Mdot
.994 .25397 Mdot
.994 .25452 Mdot
.994 .25505 Mdot
.994 .2551 Mdot
.994 .25613 Mdot
.994 .25713 Mdot
.994 .25786 Mdot
.994 .25881 Mdot
.994 .25905 Mdot
.994 .26007 Mdot
.994 .26035 Mdot
.994 .26076 Mdot
.994 .26282 Mdot
.994 .26359 Mdot
.994 .26371 Mdot
.994 .26373 Mdot
.994 .26542 Mdot
.994 .26614 Mdot
.994 .2665 Mdot
.994 .26681 Mdot
.994 .26706 Mdot
.994 .26738 Mdot
.994 .26773 Mdot
.994 .26804 Mdot
.994 .26828 Mdot
.994 .26828 Mdot
.994 .26851 Mdot
.994 .26907 Mdot
.994 .26932 Mdot
.994 .26941 Mdot
.994 .26954 Mdot
.994 .26955 Mdot
.994 .27052 Mdot
.994 .27089 Mdot
.994 .27093 Mdot
.994 .27249 Mdot
.994 .27367 Mdot
.994 .27437 Mdot
.994 .27464 Mdot
.994 .27638 Mdot
.994 .27652 Mdot
.994 .27662 Mdot
.994 .2768 Mdot
.994 .27704 Mdot
.994 .27777 Mdot
.994 .27783 Mdot
.994 .27816 Mdot
.994 .27867 Mdot
.994 .27904 Mdot
.994 .27906 Mdot
.994 .27957 Mdot
.994 .28133 Mdot
.994 .28194 Mdot
.994 .28196 Mdot
.994 .28205 Mdot
.994 .28221 Mdot
.994 .28475 Mdot
.994 .28528 Mdot
.994 .28557 Mdot
.994 .28595 Mdot
.994 .28604 Mdot
.994 .28607 Mdot
.994 .28631 Mdot
.994 .28634 Mdot
.994 .28643 Mdot
.994 .28648 Mdot
.994 .28663 Mdot
.994 .28709 Mdot
.994 .28716 Mdot
.994 .28729 Mdot
.994 .28769 Mdot
.994 .288 Mdot
.994 .2886 Mdot
.994 .28938 Mdot
.994 .28938 Mdot
.994 .28962 Mdot
.994 .2902 Mdot
.994 .29044 Mdot
.994 .29105 Mdot
.994 .29132 Mdot
.994 .29157 Mdot
.994 .29207 Mdot
.994 .29327 Mdot
.994 .29352 Mdot
.994 .29363 Mdot
.994 .29409 Mdot
.994 .29409 Mdot
.994 .29518 Mdot
.994 .29583 Mdot
.994 .29612 Mdot
.994 .297 Mdot
.994 .2976 Mdot
.994 .29795 Mdot
.994 .29896 Mdot
.994 .29897 Mdot
.994 .29907 Mdot
.994 .29996 Mdot
.994 .30003 Mdot
.994 .30415 Mdot
.994 .30502 Mdot
.994 .30623 Mdot
.994 .30626 Mdot
.994 .30666 Mdot
.994 .30705 Mdot
.994 .30709 Mdot
.994 .30787 Mdot
.994 .31003 Mdot
.994 .31177 Mdot
.994 .31199 Mdot
.994 .31232 Mdot
.994 .31329 Mdot
.994 .31404 Mdot
.994 .31562 Mdot
.994 .31603 Mdot
.994 .31653 Mdot
.994 .31691 Mdot
.994 .3178 Mdot
.994 .31812 Mdot
.994 .3185 Mdot
.994 .31859 Mdot
.994 .31983 Mdot
.994 .32104 Mdot
.994 .32149 Mdot
.994 .32276 Mdot
.994 .32305 Mdot
.994 .32323 Mdot
.994 .32411 Mdot
.994 .3242 Mdot
.994 .32503 Mdot
.994 .32567 Mdot
.994 .32862 Mdot
.994 .32962 Mdot
.994 .33095 Mdot
.994 .3311 Mdot
.994 .33328 Mdot
.994 .33361 Mdot
.994 .33376 Mdot
.994 .33426 Mdot
.994 .3354 Mdot
.994 .33653 Mdot
.994 .33692 Mdot
.994 .33693 Mdot
.994 .33717 Mdot
.994 .33805 Mdot
.994 .3382 Mdot
.994 .33851 Mdot
.994 .33864 Mdot
.994 .33877 Mdot
.994 .33923 Mdot
.994 .34127 Mdot
.994 .34185 Mdot
.994 .34193 Mdot
.994 .34298 Mdot
.994 .34337 Mdot
.994 .34347 Mdot
.994 .34384 Mdot
.994 .34409 Mdot
.994 .34423 Mdot
.994 .34513 Mdot
.994 .34523 Mdot
.994 .3455 Mdot
.994 .34592 Mdot
.994 .34621 Mdot
.994 .34638 Mdot
.994 .34712 Mdot
.994 .34787 Mdot
.994 .34818 Mdot
.994 .34892 Mdot
.994 .34955 Mdot
.994 .34956 Mdot
.994 .35002 Mdot
.994 .35115 Mdot
.994 .35227 Mdot
.994 .35234 Mdot
.994 .35289 Mdot
.994 .35368 Mdot
.994 .35413 Mdot
.994 .35414 Mdot
.994 .35442 Mdot
.994 .35517 Mdot
.994 .35597 Mdot
.994 .35612 Mdot
.994 .35674 Mdot
.994 .35778 Mdot
.994 .35841 Mdot
.994 .35841 Mdot
.994 .35938 Mdot
.994 .35984 Mdot
.994 .35986 Mdot
.994 .36058 Mdot
.994 .36094 Mdot
.994 .36121 Mdot
.994 .36147 Mdot
.994 .36319 Mdot
.994 .36356 Mdot
.994 .36368 Mdot
.994 .36371 Mdot
.994 .36489 Mdot
.994 .36501 Mdot
.994 .36563 Mdot
.994 .36691 Mdot
.994 .36804 Mdot
.994 .3681 Mdot
.994 .36873 Mdot
.994 .36968 Mdot
.994 .37 Mdot
.994 .37007 Mdot
.994 .37089 Mdot
.994 .37201 Mdot
.994 .37207 Mdot
.994 .37213 Mdot
.994 .37239 Mdot
.994 .37368 Mdot
.994 .37413 Mdot
.994 .37418 Mdot
.994 .37429 Mdot
.994 .37448 Mdot
.994 .37449 Mdot
.994 .37457 Mdot
.994 .37624 Mdot
.994 .37655 Mdot
.994 .37658 Mdot
.994 .37689 Mdot
.994 .37747 Mdot
.994 .37784 Mdot
.994 .3779 Mdot
.994 .37797 Mdot
.994 .37912 Mdot
.994 .38009 Mdot
.994 .38137 Mdot
.994 .38314 Mdot
.994 .38365 Mdot
.994 .38469 Mdot
.994 .3848 Mdot
.994 .38512 Mdot
.994 .38598 Mdot
.994 .3862 Mdot
.994 .38643 Mdot
.994 .38906 Mdot
.994 .38951 Mdot
.994 .38977 Mdot
.994 .38985 Mdot
.994 .39003 Mdot
.994 .39054 Mdot
.994 .39098 Mdot
.994 .39119 Mdot
.994 .39152 Mdot
.994 .39229 Mdot
.994 .39248 Mdot
.994 .39264 Mdot
.994 .39348 Mdot
.994 .39446 Mdot
.994 .39488 Mdot
.994 .39543 Mdot
.994 .39552 Mdot
.994 .39565 Mdot
.994 .39618 Mdot
.994 .39703 Mdot
.994 .39781 Mdot
.994 .39832 Mdot
.994 .39835 Mdot
.994 .39874 Mdot
.994 .39887 Mdot
.994 .39894 Mdot
.994 .39897 Mdot
.994 .39983 Mdot
.994 .40012 Mdot
.994 .40197 Mdot
.994 .40275 Mdot
.994 .40301 Mdot
.994 .40318 Mdot
.994 .40326 Mdot
.994 .40444 Mdot
.994 .40498 Mdot
.994 .40514 Mdot
.994 .4059 Mdot
.994 .40617 Mdot
.994 .40653 Mdot
.994 .40666 Mdot
.994 .40709 Mdot
.994 .40731 Mdot
.994 .40752 Mdot
.994 .40777 Mdot
.994 .40837 Mdot
.994 .40864 Mdot
.994 .40936 Mdot
.994 .40988 Mdot
.994 .41081 Mdot
.994 .41139 Mdot
.994 .4114 Mdot
.994 .41144 Mdot
.994 .4115 Mdot
.994 .41172 Mdot
.994 .41197 Mdot
.994 .41279 Mdot
.994 .41313 Mdot
.994 .41317 Mdot
.994 .41345 Mdot
.994 .41514 Mdot
.994 .4153 Mdot
.994 .41563 Mdot
.994 .41602 Mdot
.994 .41615 Mdot
.994 .41638 Mdot
.994 .4177 Mdot
.994 .41836 Mdot
.994 .41858 Mdot
.994 .4191 Mdot
.994 .41936 Mdot
.994 .42138 Mdot
.994 .42196 Mdot
.994 .4222 Mdot
.994 .42265 Mdot
.994 .42282 Mdot
.994 .42366 Mdot
.994 .42371 Mdot
.994 .42386 Mdot
.994 .42389 Mdot
.994 .42411 Mdot
.994 .42489 Mdot
.994 .42495 Mdot
.994 .42596 Mdot
.994 .42613 Mdot
.994 .4266 Mdot
.994 .42752 Mdot
.994 .42847 Mdot
.994 .42853 Mdot
.994 .4292 Mdot
.994 .43026 Mdot
.994 .43052 Mdot
.994 .4307 Mdot
.994 .4313 Mdot
.994 .43179 Mdot
.994 .43211 Mdot
.994 .43263 Mdot
.994 .43342 Mdot
.994 .43457 Mdot
.994 .43488 Mdot
.994 .43544 Mdot
.994 .43601 Mdot
.994 .43624 Mdot
.994 .43625 Mdot
.994 .43656 Mdot
.994 .43694 Mdot
.994 .43847 Mdot
.994 .43912 Mdot
.994 .43956 Mdot
.994 .44041 Mdot
.994 .44144 Mdot
.994 .44174 Mdot
.994 .4418 Mdot
.994 .44196 Mdot
.994 .44247 Mdot
.994 .44337 Mdot
.994 .44394 Mdot
.994 .44561 Mdot
.994 .44859 Mdot
.994 .449 Mdot
.994 .44904 Mdot
.994 .44949 Mdot
.994 .44958 Mdot
.994 .4512 Mdot
.994 .45182 Mdot
.994 .45187 Mdot
.994 .45206 Mdot
.994 .45286 Mdot
.994 .45311 Mdot
.994 .45411 Mdot
.994 .45514 Mdot
.994 .45763 Mdot
.994 .45783 Mdot
.994 .45803 Mdot
.994 .45865 Mdot
.994 .4612 Mdot
.994 .4617 Mdot
.994 .46221 Mdot
.994 .46238 Mdot
.994 .46312 Mdot
.994 .46327 Mdot
.994 .46438 Mdot
.994 .46542 Mdot
.994 .46554 Mdot
.994 .46568 Mdot
.994 .4664 Mdot
.994 .46652 Mdot
.994 .46721 Mdot
.994 .46757 Mdot
.994 .46767 Mdot
.994 .4679 Mdot
.994 .46797 Mdot
.994 .46818 Mdot
.994 .46819 Mdot
.994 .46824 Mdot
.994 .46884 Mdot
.994 .47012 Mdot
.994 .47172 Mdot
.994 .4719 Mdot
.994 .47216 Mdot
.994 .47233 Mdot
.994 .47236 Mdot
.994 .47272 Mdot
.994 .47294 Mdot
.994 .47305 Mdot
.994 .47393 Mdot
.994 .47442 Mdot
.994 .4758 Mdot
.994 .47582 Mdot
.994 .476 Mdot
.994 .4765 Mdot
.994 .47702 Mdot
.994 .47713 Mdot
.994 .47713 Mdot
.994 .47725 Mdot
.994 .47758 Mdot
.994 .47774 Mdot
.994 .4782 Mdot
.994 .47942 Mdot
.994 .47943 Mdot
.994 .47949 Mdot
.994 .47988 Mdot
.994 .48112 Mdot
.994 .48126 Mdot
.994 .48189 Mdot
.994 .48237 Mdot
.994 .48378 Mdot
.994 .48456 Mdot
.994 .48504 Mdot
.994 .48505 Mdot
.994 .48515 Mdot
.994 .48534 Mdot
.994 .48567 Mdot
.994 .48635 Mdot
.994 .48709 Mdot
.994 .4871 Mdot
.994 .4874 Mdot
.994 .48752 Mdot
.994 .48756 Mdot
.994 .48767 Mdot
.994 .48945 Mdot
.994 .48994 Mdot
.994 .49001 Mdot
.994 .49036 Mdot
.994 .49118 Mdot
.994 .49141 Mdot
.994 .49145 Mdot
.994 .49251 Mdot
.994 .49261 Mdot
.994 .49375 Mdot
.994 .49381 Mdot
.994 .49407 Mdot
.994 .49464 Mdot
.994 .49479 Mdot
.994 .49663 Mdot
.994 .49808 Mdot
.994 .49822 Mdot
.994 .49873 Mdot
.994 .49927 Mdot
.994 .49997 Mdot
.994 .49999 Mdot
.994 .50046 Mdot
.994 .50142 Mdot
.994 .50146 Mdot
.994 .50236 Mdot
.994 .50249 Mdot
.994 .50305 Mdot
.994 .50386 Mdot
.994 .5043 Mdot
.994 .5043 Mdot
.994 .50554 Mdot
.994 .50761 Mdot
.994 .50794 Mdot
.994 .50884 Mdot
.994 .50914 Mdot
.994 .50947 Mdot
.994 .50971 Mdot
.994 .50976 Mdot
.994 .51074 Mdot
.994 .51223 Mdot
.994 .51278 Mdot
.994 .5128 Mdot
.994 .51312 Mdot
.994 .5137 Mdot
.994 .51456 Mdot
.994 .51526 Mdot
.994 .51528 Mdot
.994 .51589 Mdot
.994 .51637 Mdot
.994 .51638 Mdot
.994 .5165 Mdot
.994 .51701 Mdot
.994 .51771 Mdot
.994 .51833 Mdot
.994 .51872 Mdot
.994 .51879 Mdot
.994 .5188 Mdot
.994 .51925 Mdot
.994 .52038 Mdot
.994 .52087 Mdot
.994 .52098 Mdot
.994 .52105 Mdot
.994 .5213 Mdot
.994 .52134 Mdot
.994 .52188 Mdot
.994 .5219 Mdot
.994 .52315 Mdot
.994 .52325 Mdot
.994 .52399 Mdot
.994 .52407 Mdot
.994 .52462 Mdot
.994 .52525 Mdot
.994 .52673 Mdot
.994 .52717 Mdot
.994 .52821 Mdot
.994 .52854 Mdot
.994 .52913 Mdot
.994 .52952 Mdot
.994 .52995 Mdot
.994 .5305 Mdot
.994 .5307 Mdot
.994 .53092 Mdot
.994 .53144 Mdot
.994 .53248 Mdot
.994 .53275 Mdot
.994 .53325 Mdot
.994 .53399 Mdot
.994 .5342 Mdot
.994 .53491 Mdot
.994 .53497 Mdot
.994 .53518 Mdot
.994 .53538 Mdot
.994 .53574 Mdot
.994 .53622 Mdot
.994 .53706 Mdot
.994 .53722 Mdot
.994 .53766 Mdot
.994 .53779 Mdot
.994 .53836 Mdot
.994 .53843 Mdot
.994 .53945 Mdot
.994 .5402 Mdot
.994 .54023 Mdot
.994 .54124 Mdot
.994 .54242 Mdot
.994 .54334 Mdot
.994 .54359 Mdot
.994 .54385 Mdot
.994 .54448 Mdot
.994 .54474 Mdot
.994 .54478 Mdot
.994 .54597 Mdot
.994 .54599 Mdot
.994 .54617 Mdot
.994 .54649 Mdot
.994 .54651 Mdot
.994 .54699 Mdot
.994 .54703 Mdot
.994 .54779 Mdot
.994 .55005 Mdot
.994 .55155 Mdot
.994 .55231 Mdot
.994 .5526 Mdot
.994 .55318 Mdot
.994 .5533 Mdot
.994 .5536 Mdot
.994 .55393 Mdot
.994 .55412 Mdot
.994 .55418 Mdot
.994 .55426 Mdot
.994 .55465 Mdot
.994 .55471 Mdot
.994 .55489 Mdot
.994 .55499 Mdot
.994 .55529 Mdot
.994 .55619 Mdot
.994 .55635 Mdot
.994 .5566 Mdot
.994 .5574 Mdot
.994 .55801 Mdot
.994 .55858 Mdot
.994 .55889 Mdot
.994 .55919 Mdot
.994 .56075 Mdot
.994 .56075 Mdot
.994 .56122 Mdot
.994 .56154 Mdot
.994 .56237 Mdot
.994 .56285 Mdot
.994 .56353 Mdot
.994 .56407 Mdot
.994 .5646 Mdot
.994 .5651 Mdot
.994 .5661 Mdot
.994 .56849 Mdot
.994 .56898 Mdot
.994 .56919 Mdot
.994 .56938 Mdot
.994 .57011 Mdot
.994 .57011 Mdot
.994 .57066 Mdot
.994 .57227 Mdot
.994 .5723 Mdot
.994 .57247 Mdot
.994 .57358 Mdot
.994 .57416 Mdot
.994 .57423 Mdot
.994 .5746 Mdot
.994 .57516 Mdot
.994 .57589 Mdot
.994 .57709 Mdot
.994 .57769 Mdot
.994 .57778 Mdot
.994 .57859 Mdot
.994 .5798 Mdot
.994 .57981 Mdot
.994 .58002 Mdot
.994 .58098 Mdot
.994 .58178 Mdot
.994 .58193 Mdot
.994 .58345 Mdot
.994 .58363 Mdot
.994 .58439 Mdot
.994 .58504 Mdot
.994 .58679 Mdot
.994 .58756 Mdot
.994 .58854 Mdot
.994 .58937 Mdot
.994 .59011 Mdot
.994 .59185 Mdot
.994 .59251 Mdot
.994 .594 Mdot
.994 .59424 Mdot
.994 .5943 Mdot
.994 .59509 Mdot
.994 .59589 Mdot
.994 .59593 Mdot
.994 .59595 Mdot
.994 .59657 Mdot
.994 .59703 Mdot
.994 .5975 Mdot
.994 .60047 Mdot
.996 .02052 Mdot
.996 .02076 Mdot
.996 .02099 Mdot
.996 .02154 Mdot
.996 .02242 Mdot
.996 .02629 Mdot
.996 .02645 Mdot
.996 .02666 Mdot
.996 .02676 Mdot
.996 .02687 Mdot
.996 .02722 Mdot
.996 .02832 Mdot
.996 .02994 Mdot
.996 .03006 Mdot
.996 .03045 Mdot
.996 .03183 Mdot
.996 .03257 Mdot
.996 .03532 Mdot
.996 .03555 Mdot
.996 .03592 Mdot
.996 .03643 Mdot
.996 .03777 Mdot
.996 .03809 Mdot
.996 .03851 Mdot
.996 .03858 Mdot
.996 .0387 Mdot
.996 .03884 Mdot
.996 .03892 Mdot
.996 .03963 Mdot
.996 .04 Mdot
.996 .04173 Mdot
.996 .04181 Mdot
.996 .04235 Mdot
.996 .04388 Mdot
.996 .04478 Mdot
.996 .04504 Mdot
.996 .04527 Mdot
.996 .04606 Mdot
.996 .04881 Mdot
.996 .05029 Mdot
.996 .05048 Mdot
.996 .0513 Mdot
.996 .05199 Mdot
.996 .05239 Mdot
.996 .05275 Mdot
.996 .05305 Mdot
.996 .05337 Mdot
.996 .05376 Mdot
.996 .05389 Mdot
.996 .05437 Mdot
.996 .05576 Mdot
.996 .05622 Mdot
.996 .05653 Mdot
.996 .05695 Mdot
.996 .05741 Mdot
.996 .05797 Mdot
.996 .06002 Mdot
.996 .0604 Mdot
.996 .06063 Mdot
.996 .06128 Mdot
.996 .06128 Mdot
.996 .06211 Mdot
.996 .06225 Mdot
.996 .0625 Mdot
.996 .06272 Mdot
.996 .06277 Mdot
.996 .06293 Mdot
.996 .06435 Mdot
.996 .06509 Mdot
.996 .06582 Mdot
.996 .06716 Mdot
.996 .06806 Mdot
.996 .0682 Mdot
.996 .06828 Mdot
.996 .06853 Mdot
.996 .06869 Mdot
.996 .06977 Mdot
.996 .07241 Mdot
.996 .07262 Mdot
.996 .07281 Mdot
.996 .07357 Mdot
.996 .07413 Mdot
.996 .07461 Mdot
.996 .07474 Mdot
.996 .07511 Mdot
.996 .07559 Mdot
.996 .07583 Mdot
.996 .07716 Mdot
.996 .07768 Mdot
.996 .07768 Mdot
.996 .0777 Mdot
.996 .07794 Mdot
.996 .08034 Mdot
.996 .08046 Mdot
.996 .08049 Mdot
.996 .08245 Mdot
.996 .08264 Mdot
.996 .08333 Mdot
.996 .08335 Mdot
.996 .08401 Mdot
.996 .08486 Mdot
.996 .0849 Mdot
.996 .08535 Mdot
.996 .08547 Mdot
.996 .08558 Mdot
.996 .08596 Mdot
.996 .0863 Mdot
.996 .08686 Mdot
.996 .0876 Mdot
.996 .08827 Mdot
.996 .08859 Mdot
.996 .08897 Mdot
.996 .08975 Mdot
.996 .09047 Mdot
.996 .09061 Mdot
.996 .09108 Mdot
.996 .09121 Mdot
.996 .09171 Mdot
.996 .09249 Mdot
.996 .09276 Mdot
.996 .09277 Mdot
.996 .09371 Mdot
.996 .09408 Mdot
.996 .09408 Mdot
.996 .09443 Mdot
.996 .09614 Mdot
.996 .09648 Mdot
.996 .09739 Mdot
.996 .098 Mdot
.996 .09853 Mdot
.996 .09854 Mdot
.996 .09876 Mdot
.996 .09884 Mdot
.996 .09976 Mdot
.996 .09983 Mdot
.996 .10089 Mdot
.996 .10111 Mdot
.996 .1041 Mdot
.996 .10417 Mdot
.996 .10429 Mdot
.996 .10453 Mdot
.996 .10496 Mdot
.996 .10571 Mdot
.996 .10618 Mdot
.996 .10696 Mdot
.996 .10746 Mdot
.996 .10747 Mdot
.996 .10851 Mdot
.996 .10913 Mdot
.996 .10931 Mdot
.996 .1094 Mdot
.996 .1095 Mdot
.996 .1099 Mdot
.996 .11 Mdot
.996 .11034 Mdot
.996 .11045 Mdot
.996 .11076 Mdot
.996 .11249 Mdot
.996 .11359 Mdot
.996 .11507 Mdot
.996 .11525 Mdot
.996 .11651 Mdot
.996 .11919 Mdot
.996 .12047 Mdot
.996 .1206 Mdot
.996 .12097 Mdot
.996 .12126 Mdot
.996 .12142 Mdot
.996 .12191 Mdot
.996 .12203 Mdot
.996 .12224 Mdot
.996 .12337 Mdot
.996 .12394 Mdot
.996 .12401 Mdot
.996 .12438 Mdot
.996 .12763 Mdot
.996 .12964 Mdot
.996 .13007 Mdot
.996 .13038 Mdot
.996 .13043 Mdot
.996 .13104 Mdot
.996 .13131 Mdot
.996 .13195 Mdot
.996 .13286 Mdot
.996 .13307 Mdot
.996 .13397 Mdot
.996 .13403 Mdot
.996 .13428 Mdot
.996 .13503 Mdot
.996 .13535 Mdot
.996 .13598 Mdot
.996 .1363 Mdot
.996 .13646 Mdot
.996 .13685 Mdot
.996 .13885 Mdot
.996 .1391 Mdot
.996 .13971 Mdot
.996 .14015 Mdot
.996 .14015 Mdot
.996 .14018 Mdot
.996 .14066 Mdot
.996 .14077 Mdot
.996 .1428 Mdot
.996 .14478 Mdot
.996 .14518 Mdot
.996 .14544 Mdot
.996 .14568 Mdot
.996 .14574 Mdot
.996 .14615 Mdot
.996 .14957 Mdot
.996 .14965 Mdot
.996 .15 Mdot
.996 .15001 Mdot
.996 .15067 Mdot
.996 .15102 Mdot
.996 .15134 Mdot
.996 .1514 Mdot
.996 .15143 Mdot
.996 .15153 Mdot
.996 .15276 Mdot
.996 .15372 Mdot
.996 .15379 Mdot
.996 .15427 Mdot
.996 .15444 Mdot
.996 .15446 Mdot
.996 .15452 Mdot
.996 .15471 Mdot
.996 .15543 Mdot
.996 .15566 Mdot
.996 .15588 Mdot
.996 .15609 Mdot
.996 .15663 Mdot
.996 .15664 Mdot
.996 .15732 Mdot
.996 .15844 Mdot
.996 .15868 Mdot
.996 .1599 Mdot
.996 .16034 Mdot
.996 .16065 Mdot
.996 .16079 Mdot
.996 .16123 Mdot
.996 .16186 Mdot
.996 .16188 Mdot
.996 .16263 Mdot
.996 .16369 Mdot
.996 .16419 Mdot
.996 .16446 Mdot
.996 .16489 Mdot
.996 .1654 Mdot
.996 .16562 Mdot
.996 .16589 Mdot
.996 .16673 Mdot
.996 .16683 Mdot
.996 .16709 Mdot
.996 .16794 Mdot
.996 .16809 Mdot
.996 .16867 Mdot
.996 .16884 Mdot
.996 .16965 Mdot
.996 .17017 Mdot
.996 .17017 Mdot
.996 .1702 Mdot
.996 .17052 Mdot
.996 .17052 Mdot
.996 .17208 Mdot
.996 .17224 Mdot
.996 .17281 Mdot
.996 .17281 Mdot
.996 .17351 Mdot
.996 .17352 Mdot
.996 .17649 Mdot
.996 .17692 Mdot
.996 .17729 Mdot
.996 .17747 Mdot
.996 .17759 Mdot
.996 .1794 Mdot
.996 .17949 Mdot
.996 .17979 Mdot
.996 .18063 Mdot
.996 .18115 Mdot
.996 .18168 Mdot
.996 .1817 Mdot
.996 .18213 Mdot
.996 .18229 Mdot
.996 .18372 Mdot
.996 .18412 Mdot
.996 .18426 Mdot
.996 .18483 Mdot
.996 .18637 Mdot
.996 .18682 Mdot
.996 .18799 Mdot
.996 .18823 Mdot
.996 .18876 Mdot
.996 .1891 Mdot
.996 .19111 Mdot
.996 .19277 Mdot
.996 .1929 Mdot
.996 .19315 Mdot
.996 .19355 Mdot
.996 .19357 Mdot
.996 .19363 Mdot
.996 .19441 Mdot
.996 .19449 Mdot
.996 .19524 Mdot
.996 .19598 Mdot
.996 .19692 Mdot
.996 .19733 Mdot
.996 .19822 Mdot
.996 .19843 Mdot
.996 .19845 Mdot
.996 .19846 Mdot
.996 .19947 Mdot
.996 .19949 Mdot
.996 .20129 Mdot
.996 .20156 Mdot
.996 .20191 Mdot
.996 .20279 Mdot
.996 .20314 Mdot
.996 .20333 Mdot
.996 .20353 Mdot
.996 .20373 Mdot
.996 .20412 Mdot
.996 .20433 Mdot
.996 .20434 Mdot
.996 .20453 Mdot
.996 .20519 Mdot
.996 .20542 Mdot
.996 .20576 Mdot
.996 .20605 Mdot
.996 .2061 Mdot
.996 .20668 Mdot
.996 .20673 Mdot
.996 .20681 Mdot
.996 .20714 Mdot
.996 .20869 Mdot
.996 .20879 Mdot
.996 .20927 Mdot
.996 .20948 Mdot
.996 .21166 Mdot
.996 .21455 Mdot
.996 .21461 Mdot
.996 .21498 Mdot
.996 .2151 Mdot
.996 .21613 Mdot
.996 .2175 Mdot
.996 .21851 Mdot
.996 .21915 Mdot
.996 .22046 Mdot
.996 .22283 Mdot
.996 .22305 Mdot
.996 .22405 Mdot
.996 .22451 Mdot
.996 .22464 Mdot
.996 .22538 Mdot
.996 .22564 Mdot
.996 .22579 Mdot
.996 .22638 Mdot
.996 .22695 Mdot
.996 .22711 Mdot
.996 .22727 Mdot
.996 .2273 Mdot
.996 .22756 Mdot
.996 .22825 Mdot
.996 .22849 Mdot
.996 .22884 Mdot
.996 .2289 Mdot
.996 .23114 Mdot
.996 .23115 Mdot
.996 .23144 Mdot
.996 .2318 Mdot
.996 .23215 Mdot
.996 .23229 Mdot
.996 .23244 Mdot
.996 .23316 Mdot
.996 .23533 Mdot
.996 .23635 Mdot
.996 .23757 Mdot
.996 .23876 Mdot
.996 .2389 Mdot
.996 .23965 Mdot
.996 .24142 Mdot
.996 .24319 Mdot
.996 .24365 Mdot
.996 .244 Mdot
.996 .2445 Mdot
.996 .24481 Mdot
.996 .24512 Mdot
.996 .24522 Mdot
.996 .24551 Mdot
.996 .24643 Mdot
.996 .24681 Mdot
.996 .24698 Mdot
.996 .24726 Mdot
.996 .24809 Mdot
.996 .24825 Mdot
.996 .25005 Mdot
.996 .25047 Mdot
.996 .25228 Mdot
.996 .25239 Mdot
.996 .25289 Mdot
.996 .25438 Mdot
.996 .25442 Mdot
.996 .25503 Mdot
.996 .25609 Mdot
.996 .25627 Mdot
.996 .25634 Mdot
.996 .25692 Mdot
.996 .25724 Mdot
.996 .25736 Mdot
.996 .25801 Mdot
.996 .25838 Mdot
.996 .25936 Mdot
.996 .262 Mdot
.996 .26249 Mdot
.996 .2625 Mdot
.996 .26265 Mdot
.996 .26315 Mdot
.996 .26325 Mdot
.996 .2637 Mdot
.996 .26386 Mdot
.996 .26458 Mdot
.996 .26458 Mdot
.996 .26464 Mdot
.996 .2656 Mdot
.996 .26581 Mdot
.996 .26715 Mdot
.996 .26829 Mdot
.996 .26894 Mdot
.996 .26928 Mdot
.996 .26987 Mdot
.996 .26991 Mdot
.996 .27045 Mdot
.996 .27257 Mdot
.996 .2738 Mdot
.996 .2741 Mdot
.996 .2746 Mdot
.996 .27511 Mdot
.996 .27525 Mdot
.996 .2756 Mdot
.996 .27566 Mdot
.996 .27571 Mdot
.996 .27583 Mdot
.996 .27653 Mdot
.996 .27689 Mdot
.996 .2781 Mdot
.996 .2801 Mdot
.996 .2815 Mdot
.996 .28173 Mdot
.996 .28334 Mdot
.996 .28335 Mdot
.996 .2835 Mdot
.996 .2842 Mdot
.996 .28423 Mdot
.996 .28554 Mdot
.996 .28624 Mdot
.996 .28687 Mdot
.996 .28699 Mdot
.996 .28704 Mdot
.996 .28724 Mdot
.996 .28911 Mdot
.996 .2897 Mdot
.996 .29036 Mdot
.996 .2916 Mdot
.996 .29176 Mdot
.996 .29235 Mdot
.996 .2927 Mdot
.996 .29305 Mdot
.996 .29308 Mdot
.996 .29319 Mdot
.996 .2932 Mdot
.996 .29359 Mdot
.996 .29381 Mdot
.996 .29501 Mdot
.996 .29548 Mdot
.996 .29591 Mdot
.996 .29634 Mdot
.996 .29738 Mdot
.996 .2974 Mdot
.996 .29744 Mdot
.996 .29878 Mdot
.996 .29937 Mdot
.996 .30034 Mdot
.996 .30089 Mdot
.996 .30101 Mdot
.996 .30104 Mdot
.996 .30122 Mdot
.996 .3013 Mdot
.996 .30149 Mdot
.996 .3033 Mdot
.996 .30392 Mdot
.996 .3048 Mdot
.996 .30541 Mdot
.996 .30563 Mdot
.996 .30569 Mdot
.996 .30657 Mdot
.996 .30705 Mdot
.996 .30782 Mdot
.996 .30787 Mdot
.996 .3093 Mdot
.996 .30936 Mdot
.996 .30942 Mdot
.996 .31023 Mdot
.996 .31045 Mdot
.996 .31147 Mdot
.996 .31248 Mdot
.996 .31301 Mdot
.996 .31385 Mdot
.996 .31453 Mdot
.996 .31489 Mdot
.996 .31532 Mdot
.996 .31586 Mdot
.996 .31752 Mdot
.996 .31773 Mdot
.996 .31825 Mdot
.996 .31927 Mdot
.996 .31993 Mdot
.996 .32025 Mdot
.996 .32139 Mdot
.996 .32173 Mdot
.996 .32311 Mdot
.996 .32334 Mdot
.996 .32364 Mdot
.996 .32438 Mdot
.996 .32438 Mdot
.996 .32445 Mdot
.996 .32505 Mdot
.996 .32508 Mdot
.996 .32509 Mdot
.996 .3258 Mdot
.996 .32598 Mdot
.996 .32655 Mdot
.996 .32713 Mdot
.996 .32818 Mdot
.996 .32851 Mdot
.996 .32851 Mdot
.996 .3286 Mdot
.996 .32963 Mdot
.996 .32964 Mdot
.996 .32996 Mdot
.996 .33104 Mdot
.996 .33105 Mdot
.996 .33109 Mdot
.996 .33115 Mdot
.996 .33176 Mdot
.996 .33556 Mdot
.996 .33697 Mdot
.996 .33783 Mdot
.996 .33828 Mdot
.996 .33857 Mdot
.996 .33891 Mdot
.996 .33915 Mdot
.996 .3398 Mdot
.996 .34001 Mdot
.996 .34028 Mdot
.996 .34079 Mdot
.996 .34139 Mdot
.996 .34163 Mdot
.996 .3426 Mdot
.996 .34278 Mdot
.996 .34294 Mdot
.996 .34299 Mdot
.996 .34354 Mdot
.996 .34521 Mdot
.996 .34532 Mdot
.996 .34605 Mdot
.996 .34625 Mdot
.996 .34636 Mdot
.996 .34649 Mdot
.996 .34713 Mdot
.996 .34731 Mdot
.996 .34735 Mdot
.996 .34769 Mdot
.996 .34778 Mdot
.996 .34778 Mdot
.996 .34821 Mdot
.996 .34853 Mdot
.996 .34928 Mdot
.996 .35004 Mdot
.996 .35138 Mdot
.996 .35218 Mdot
.996 .35237 Mdot
.996 .35246 Mdot
.996 .35296 Mdot
.996 .35358 Mdot
.996 .35401 Mdot
.996 .35453 Mdot
.996 .3563 Mdot
.996 .35666 Mdot
.996 .35692 Mdot
.996 .35701 Mdot
.996 .35742 Mdot
.996 .35754 Mdot
.996 .35887 Mdot
.996 .35901 Mdot
.996 .35927 Mdot
.996 .35987 Mdot
.996 .36036 Mdot
.996 .36127 Mdot
.996 .36142 Mdot
.996 .3617 Mdot
.996 .36209 Mdot
.996 .36322 Mdot
.996 .36411 Mdot
.996 .36467 Mdot
.996 .36564 Mdot
.996 .36609 Mdot
.996 .36629 Mdot
.996 .36668 Mdot
.996 .36733 Mdot
.996 .3694 Mdot
.996 .36966 Mdot
.996 .36992 Mdot
.996 .37017 Mdot
.996 .37096 Mdot
.996 .37099 Mdot
.996 .37112 Mdot
.996 .37267 Mdot
.996 .37282 Mdot
.996 .37349 Mdot
.996 .37432 Mdot
.996 .3758 Mdot
.996 .37766 Mdot
.996 .37848 Mdot
.996 .37869 Mdot
.996 .37885 Mdot
.996 .38025 Mdot
.996 .38067 Mdot
.996 .38071 Mdot
.996 .38073 Mdot
.996 .38124 Mdot
.996 .38218 Mdot
.996 .38275 Mdot
.996 .38278 Mdot
.996 .38299 Mdot
.996 .38526 Mdot
.996 .38636 Mdot
.996 .38672 Mdot
.996 .38691 Mdot
.996 .38761 Mdot
.996 .38841 Mdot
.996 .38937 Mdot
.996 .39006 Mdot
.996 .39044 Mdot
.996 .39069 Mdot
.996 .39084 Mdot
.996 .39124 Mdot
.996 .39201 Mdot
.996 .39243 Mdot
.996 .39245 Mdot
.996 .39283 Mdot
.996 .39415 Mdot
.996 .3946 Mdot
.996 .39477 Mdot
.996 .39524 Mdot
.996 .39528 Mdot
.996 .39585 Mdot
.996 .39596 Mdot
.996 .39671 Mdot
.996 .39695 Mdot
.996 .39711 Mdot
.996 .39721 Mdot
.996 .39737 Mdot
.996 .39803 Mdot
.996 .40028 Mdot
.996 .40112 Mdot
.996 .40132 Mdot
.996 .40226 Mdot
.996 .40269 Mdot
.996 .40568 Mdot
.996 .40704 Mdot
.996 .40841 Mdot
.996 .41112 Mdot
.996 .41279 Mdot
.996 .41292 Mdot
.996 .41365 Mdot
.996 .41389 Mdot
.996 .41594 Mdot
.996 .41708 Mdot
.996 .41793 Mdot
.996 .41866 Mdot
.996 .4198 Mdot
.996 .42021 Mdot
.996 .42068 Mdot
.996 .42188 Mdot
.996 .42196 Mdot
.996 .42457 Mdot
.996 .42636 Mdot
.996 .42766 Mdot
.996 .42799 Mdot
.996 .42818 Mdot
.996 .42851 Mdot
.996 .429 Mdot
.996 .42928 Mdot
.996 .42973 Mdot
.996 .43049 Mdot
.996 .43071 Mdot
.996 .43171 Mdot
.996 .43184 Mdot
.996 .43191 Mdot
.996 .43264 Mdot
.996 .43285 Mdot
.996 .43289 Mdot
.996 .4332 Mdot
.996 .43409 Mdot
.996 .43435 Mdot
.996 .43487 Mdot
.996 .43517 Mdot
.996 .43634 Mdot
.996 .43672 Mdot
.996 .43748 Mdot
.996 .43748 Mdot
.996 .43752 Mdot
.996 .43781 Mdot
.996 .43813 Mdot
.996 .43819 Mdot
.996 .43834 Mdot
.996 .43871 Mdot
.996 .43988 Mdot
.996 .44007 Mdot
.996 .44056 Mdot
.996 .44068 Mdot
.996 .44098 Mdot
.996 .44124 Mdot
.996 .44138 Mdot
.996 .44148 Mdot
.996 .44224 Mdot
.996 .44361 Mdot
.996 .44552 Mdot
.996 .44583 Mdot
.996 .44586 Mdot
.996 .44642 Mdot
.996 .4471 Mdot
.996 .44715 Mdot
.996 .44784 Mdot
.996 .44813 Mdot
.996 .44842 Mdot
.996 .44851 Mdot
.996 .44889 Mdot
.996 .4496 Mdot
.996 .44986 Mdot
.996 .45179 Mdot
.996 .45417 Mdot
.996 .45622 Mdot
.996 .45633 Mdot
.996 .45673 Mdot
.996 .45679 Mdot
.996 .45793 Mdot
.996 .45864 Mdot
.996 .4598 Mdot
.996 .46081 Mdot
.996 .46085 Mdot
.996 .46094 Mdot
.996 .46102 Mdot
.996 .46129 Mdot
.996 .46178 Mdot
.996 .46278 Mdot
.996 .46457 Mdot
.996 .46488 Mdot
.996 .46531 Mdot
.996 .4663 Mdot
.996 .46693 Mdot
.996 .46983 Mdot
.996 .47063 Mdot
.996 .47075 Mdot
.996 .47145 Mdot
.996 .47245 Mdot
.996 .47306 Mdot
.996 .47359 Mdot
.996 .47368 Mdot
.996 .47389 Mdot
.996 .47446 Mdot
.996 .47523 Mdot
.996 .4763 Mdot
.996 .47657 Mdot
.996 .47688 Mdot
.996 .47706 Mdot
.996 .47738 Mdot
.996 .47795 Mdot
.996 .4796 Mdot
.996 .47991 Mdot
.996 .47996 Mdot
.996 .48021 Mdot
.996 .48029 Mdot
.996 .48186 Mdot
.996 .48236 Mdot
.996 .48287 Mdot
.996 .48338 Mdot
.996 .48351 Mdot
.996 .48434 Mdot
.996 .48752 Mdot
.996 .48794 Mdot
.996 .48816 Mdot
.996 .48882 Mdot
.996 .48917 Mdot
.996 .48957 Mdot
.996 .48998 Mdot
.996 .49087 Mdot
.996 .49214 Mdot
.996 .4922 Mdot
.996 .4928 Mdot
.996 .49341 Mdot
.996 .49393 Mdot
.996 .49552 Mdot
.996 .4957 Mdot
.996 .49588 Mdot
.996 .49603 Mdot
.996 .49719 Mdot
.996 .49783 Mdot
.996 .49796 Mdot
.996 .49805 Mdot
.996 .49872 Mdot
.996 .49929 Mdot
.996 .49936 Mdot
.996 .49959 Mdot
.996 .50009 Mdot
.996 .50139 Mdot
.996 .50205 Mdot
.996 .50237 Mdot
.996 .50357 Mdot
.996 .50408 Mdot
.996 .50436 Mdot
.996 .50701 Mdot
.996 .50725 Mdot
.996 .5073 Mdot
.996 .50808 Mdot
.996 .50824 Mdot
.996 .50828 Mdot
.996 .50831 Mdot
.996 .5086 Mdot
.996 .50877 Mdot
.996 .50948 Mdot
.996 .50959 Mdot
.996 .50979 Mdot
.996 .5107 Mdot
.996 .51102 Mdot
.996 .51244 Mdot
.996 .51245 Mdot
.996 .51256 Mdot
.996 .51301 Mdot
.996 .51405 Mdot
.996 .51447 Mdot
.996 .51489 Mdot
.996 .5149 Mdot
.996 .51613 Mdot
.996 .51714 Mdot
.996 .51731 Mdot
.996 .51757 Mdot
.996 .51769 Mdot
.996 .51928 Mdot
.996 .51983 Mdot
.996 .52113 Mdot
.996 .52181 Mdot
.996 .52196 Mdot
.996 .52298 Mdot
.996 .52306 Mdot
.996 .52347 Mdot
.996 .52414 Mdot
.996 .52496 Mdot
.996 .5256 Mdot
.996 .52646 Mdot
.996 .52646 Mdot
.996 .52664 Mdot
.996 .52731 Mdot
.996 .52739 Mdot
.996 .52776 Mdot
.996 .52837 Mdot
.996 .52903 Mdot
.996 .52929 Mdot
.996 .5295 Mdot
.996 .52989 Mdot
.996 .53081 Mdot
.996 .53135 Mdot
.996 .53142 Mdot
.996 .53157 Mdot
.996 .53241 Mdot
.996 .53343 Mdot
.996 .5337 Mdot
.996 .5344 Mdot
.996 .53453 Mdot
.996 .53462 Mdot
.996 .53486 Mdot
.996 .5349 Mdot
.996 .536 Mdot
.996 .53609 Mdot
.996 .53625 Mdot
.996 .53643 Mdot
.996 .53677 Mdot
.996 .53698 Mdot
.996 .5387 Mdot
.996 .53918 Mdot
.996 .53939 Mdot
.996 .54038 Mdot
.996 .5414 Mdot
.996 .54193 Mdot
.996 .54236 Mdot
.996 .54336 Mdot
.996 .54364 Mdot
.996 .54412 Mdot
.996 .54481 Mdot
.996 .54537 Mdot
.996 .54614 Mdot
.996 .54628 Mdot
.996 .54661 Mdot
.996 .54799 Mdot
.996 .54981 Mdot
.996 .54985 Mdot
.996 .55013 Mdot
.996 .5508 Mdot
.996 .55152 Mdot
.996 .55159 Mdot
.996 .55421 Mdot
.996 .55559 Mdot
.996 .55684 Mdot
.996 .55709 Mdot
.996 .55719 Mdot
.996 .55759 Mdot
.996 .55837 Mdot
.996 .55959 Mdot
.996 .55971 Mdot
.996 .55977 Mdot
.996 .55981 Mdot
.996 .56131 Mdot
.996 .56195 Mdot
.996 .56249 Mdot
.996 .5626 Mdot
.996 .5626 Mdot
.996 .5638 Mdot
.996 .56466 Mdot
.996 .56484 Mdot
.996 .56484 Mdot
.996 .56549 Mdot
.996 .56628 Mdot
.996 .56658 Mdot
.996 .56759 Mdot
.996 .56775 Mdot
.996 .56846 Mdot
.996 .56874 Mdot
.996 .56916 Mdot
.996 .56922 Mdot
.996 .56945 Mdot
.996 .56947 Mdot
.996 .56989 Mdot
.996 .57022 Mdot
.996 .57023 Mdot
.996 .57067 Mdot
.996 .57166 Mdot
.996 .57167 Mdot
.996 .57173 Mdot
.996 .57294 Mdot
.996 .57306 Mdot
.996 .57307 Mdot
.996 .57307 Mdot
.996 .574 Mdot
.996 .57455 Mdot
.996 .57485 Mdot
.996 .57513 Mdot
.996 .57561 Mdot
.996 .57571 Mdot
.996 .57779 Mdot
.996 .57783 Mdot
.996 .5779 Mdot
.996 .57835 Mdot
.996 .57902 Mdot
.996 .58058 Mdot
.996 .5813 Mdot
.996 .58175 Mdot
.996 .58193 Mdot
.996 .58325 Mdot
.996 .58369 Mdot
.996 .58477 Mdot
.996 .58501 Mdot
.996 .58508 Mdot
.996 .58527 Mdot
.996 .58543 Mdot
.996 .58559 Mdot
.996 .58597 Mdot
.996 .58631 Mdot
.996 .58672 Mdot
.996 .58958 Mdot
.996 .59004 Mdot
.996 .5908 Mdot
.996 .59112 Mdot
.996 .59198 Mdot
.996 .59257 Mdot
.996 .5927 Mdot
.996 .59378 Mdot
.996 .59403 Mdot
.996 .59422 Mdot
.996 .59433 Mdot
.996 .59571 Mdot
.996 .59608 Mdot
.996 .59678 Mdot
.996 .59704 Mdot
.996 .59858 Mdot
.996 .59868 Mdot
.996 .59879 Mdot
.996 .60081 Mdot
.996 .60125 Mdot
.996 .60153 Mdot
.996 .60164 Mdot
.996 .60176 Mdot
.998 .01743 Mdot
.998 .019 Mdot
.998 .01942 Mdot
.998 .01979 Mdot
.998 .01994 Mdot
.998 .01998 Mdot
.998 .02009 Mdot
.998 .02013 Mdot
.998 .02014 Mdot
.998 .02199 Mdot
.998 .02327 Mdot
.998 .02411 Mdot
.998 .02485 Mdot
.998 .0251 Mdot
.998 .02514 Mdot
.998 .02523 Mdot
.998 .02543 Mdot
.998 .02546 Mdot
.998 .02552 Mdot
.998 .02555 Mdot
.998 .02697 Mdot
.998 .0271 Mdot
.998 .02745 Mdot
.998 .0278 Mdot
.998 .02923 Mdot
.998 .02993 Mdot
.998 .03032 Mdot
.998 .03179 Mdot
.998 .03346 Mdot
.998 .03472 Mdot
.998 .03494 Mdot
.998 .03545 Mdot
.998 .03553 Mdot
.998 .0357 Mdot
.998 .03611 Mdot
.998 .03616 Mdot
.998 .03628 Mdot
.998 .03635 Mdot
.998 .03849 Mdot
.998 .03849 Mdot
.998 .03916 Mdot
.998 .03918 Mdot
.998 .03943 Mdot
.998 .04013 Mdot
.998 .04084 Mdot
.998 .04113 Mdot
.998 .04369 Mdot
.998 .04452 Mdot
.998 .04509 Mdot
.998 .04515 Mdot
.998 .04586 Mdot
.998 .04775 Mdot
.998 .04879 Mdot
.998 .04971 Mdot
.998 .05125 Mdot
.998 .05149 Mdot
.998 .05165 Mdot
.998 .05214 Mdot
.998 .05303 Mdot
.998 .05308 Mdot
.998 .05422 Mdot
.998 .05464 Mdot
.998 .05508 Mdot
.998 .05571 Mdot
.998 .0561 Mdot
.998 .05626 Mdot
.998 .05656 Mdot
.998 .05661 Mdot
.998 .05663 Mdot
.998 .05719 Mdot
.998 .05742 Mdot
.998 .05751 Mdot
.998 .05758 Mdot
.998 .05777 Mdot
.998 .05789 Mdot
.998 .05796 Mdot
.998 .05884 Mdot
.998 .05903 Mdot
.998 .06216 Mdot
.998 .06217 Mdot
.998 .06317 Mdot
.998 .06352 Mdot
.998 .06355 Mdot
.998 .06404 Mdot
.998 .06444 Mdot
.998 .06464 Mdot
.998 .06541 Mdot
.998 .06544 Mdot
.998 .06685 Mdot
.998 .06713 Mdot
.998 .06743 Mdot
.998 .06912 Mdot
.998 .07037 Mdot
.998 .07045 Mdot
.998 .07212 Mdot
.998 .07255 Mdot
.998 .0742 Mdot
.998 .07445 Mdot
.998 .07486 Mdot
.998 .07496 Mdot
.998 .07534 Mdot
.998 .07547 Mdot
.998 .07555 Mdot
.998 .07588 Mdot
.998 .07688 Mdot
.998 .07815 Mdot
.998 .07914 Mdot
.998 .07987 Mdot
.998 .08065 Mdot
.998 .08203 Mdot
.998 .08273 Mdot
.998 .08332 Mdot
.998 .08366 Mdot
.998 .08373 Mdot
.998 .08456 Mdot
.998 .08699 Mdot
.998 .08736 Mdot
.998 .08764 Mdot
.998 .08812 Mdot
.998 .08813 Mdot
.998 .08845 Mdot
.998 .08858 Mdot
.998 .08941 Mdot
.998 .09119 Mdot
.998 .09128 Mdot
.998 .0924 Mdot
.998 .09267 Mdot
.998 .09293 Mdot
.998 .09295 Mdot
.998 .09316 Mdot
.998 .09323 Mdot
.998 .09355 Mdot
.998 .09357 Mdot
.998 .09372 Mdot
.998 .09391 Mdot
.998 .0944 Mdot
.998 .09528 Mdot
.998 .09583 Mdot
.998 .09592 Mdot
.998 .09653 Mdot
.998 .09682 Mdot
.998 .09732 Mdot
.998 .09763 Mdot
.998 .098 Mdot
.998 .09824 Mdot
.998 .09833 Mdot
.998 .09838 Mdot
.998 .09895 Mdot
.998 .09949 Mdot
.998 .0998 Mdot
.998 .09995 Mdot
.998 .10014 Mdot
.998 .10028 Mdot
.998 .10065 Mdot
.998 .10089 Mdot
.998 .10102 Mdot
.998 .1028 Mdot
.998 .10316 Mdot
.998 .1033 Mdot
.998 .1042 Mdot
.998 .10588 Mdot
.998 .10657 Mdot
.998 .10671 Mdot
.998 .10722 Mdot
.998 .10942 Mdot
.998 .10944 Mdot
.998 .11077 Mdot
.998 .11142 Mdot
.998 .11212 Mdot
.998 .11219 Mdot
.998 .11273 Mdot
.998 .11318 Mdot
.998 .11397 Mdot
.998 .11408 Mdot
.998 .11414 Mdot
.998 .11436 Mdot
.998 .11472 Mdot
.998 .11554 Mdot
.998 .11591 Mdot
.998 .11597 Mdot
.998 .11736 Mdot
.998 .11876 Mdot
.998 .11878 Mdot
.998 .11933 Mdot
.998 .11994 Mdot
.998 .12055 Mdot
.998 .12331 Mdot
.998 .12377 Mdot
.998 .12402 Mdot
.998 .12467 Mdot
.998 .12579 Mdot
.998 .12596 Mdot
.998 .12929 Mdot
.998 .12931 Mdot
.998 .12989 Mdot
.998 .13015 Mdot
.998 .1306 Mdot
.998 .13084 Mdot
.998 .13085 Mdot
.998 .13137 Mdot
.998 .13344 Mdot
.998 .13394 Mdot
.998 .13417 Mdot
.998 .13423 Mdot
.998 .13477 Mdot
.998 .13496 Mdot
.998 .13536 Mdot
.998 .13572 Mdot
.998 .13597 Mdot
.998 .13614 Mdot
.998 .13681 Mdot
.998 .13842 Mdot
.998 .1388 Mdot
.998 .13937 Mdot
.998 .14051 Mdot
.998 .14102 Mdot
.998 .14133 Mdot
.998 .14267 Mdot
.998 .14331 Mdot
.998 .14476 Mdot
.998 .145 Mdot
.998 .14575 Mdot
.998 .14632 Mdot
.998 .14691 Mdot
.998 .14724 Mdot
.998 .14778 Mdot
.998 .14908 Mdot
.998 .14971 Mdot
.998 .1503 Mdot
.998 .15047 Mdot
.998 .15166 Mdot
.998 .15232 Mdot
.998 .15247 Mdot
.998 .15296 Mdot
.998 .15412 Mdot
.998 .15511 Mdot
.998 .15621 Mdot
.998 .1567 Mdot
.998 .15754 Mdot
.998 .15783 Mdot
.998 .15798 Mdot
.998 .15815 Mdot
.998 .1582 Mdot
.998 .15897 Mdot
.998 .15948 Mdot
.998 .15972 Mdot
.998 .16028 Mdot
.998 .16124 Mdot
.998 .16126 Mdot
.998 .16145 Mdot
.998 .16188 Mdot
.998 .16214 Mdot
.998 .16381 Mdot
.998 .16385 Mdot
.998 .16703 Mdot
.998 .16736 Mdot
.998 .16755 Mdot
.998 .1676 Mdot
.998 .16764 Mdot
.998 .16848 Mdot
.998 .16858 Mdot
.998 .16905 Mdot
.998 .16972 Mdot
.998 .16977 Mdot
.998 .16978 Mdot
.998 .17031 Mdot
.998 .17083 Mdot
.998 .17087 Mdot
.998 .17129 Mdot
.998 .17144 Mdot
.998 .17207 Mdot
.998 .17212 Mdot
.998 .17216 Mdot
.998 .17242 Mdot
.998 .1728 Mdot
.998 .17377 Mdot
.998 .17478 Mdot
.998 .17551 Mdot
.998 .17662 Mdot
.998 .17681 Mdot
.998 .17802 Mdot
.998 .17859 Mdot
.998 .17883 Mdot
.998 .17959 Mdot
.998 .17986 Mdot
.998 .18006 Mdot
.998 .18017 Mdot
.998 .18022 Mdot
.998 .18096 Mdot
.998 .18143 Mdot
.998 .18161 Mdot
.998 .1817 Mdot
.998 .18284 Mdot
.998 .18392 Mdot
.998 .18454 Mdot
.998 .18484 Mdot
.998 .18523 Mdot
.998 .18543 Mdot
.998 .1855 Mdot
.998 .18623 Mdot
.998 .18672 Mdot
.998 .18699 Mdot
.998 .18741 Mdot
.998 .18783 Mdot
.998 .18789 Mdot
.998 .19053 Mdot
.998 .19126 Mdot
.998 .19152 Mdot
.998 .19194 Mdot
.998 .1923 Mdot
.998 .19332 Mdot
.998 .19474 Mdot
.998 .1965 Mdot
.998 .19669 Mdot
.998 .1978 Mdot
.998 .19805 Mdot
.998 .19833 Mdot
.998 .19936 Mdot
.998 .19939 Mdot
.998 .19971 Mdot
.998 .19998 Mdot
.998 .20104 Mdot
.998 .20135 Mdot
.998 .20288 Mdot
.998 .20375 Mdot
.998 .20553 Mdot
.998 .20579 Mdot
.998 .20637 Mdot
.998 .20637 Mdot
.998 .20643 Mdot
.998 .20774 Mdot
.998 .20854 Mdot
.998 .20914 Mdot
.998 .20928 Mdot
.998 .20966 Mdot
.998 .21035 Mdot
.998 .21125 Mdot
.998 .21179 Mdot
.998 .21284 Mdot
.998 .21305 Mdot
.998 .21317 Mdot
.998 .21361 Mdot
.998 .2137 Mdot
.998 .21432 Mdot
.998 .21449 Mdot
.998 .21511 Mdot
.998 .21596 Mdot
.998 .2167 Mdot
.998 .21682 Mdot
.998 .21847 Mdot
.998 .21894 Mdot
.998 .21902 Mdot
.998 .21959 Mdot
.998 .22139 Mdot
.998 .22239 Mdot
.998 .22243 Mdot
.998 .2228 Mdot
.998 .22352 Mdot
.998 .22454 Mdot
.998 .22474 Mdot
.998 .22597 Mdot
.998 .22671 Mdot
.998 .2268 Mdot
.998 .22801 Mdot
.998 .23004 Mdot
.998 .23057 Mdot
.998 .23147 Mdot
.998 .2324 Mdot
.998 .23288 Mdot
.998 .23289 Mdot
.998 .23419 Mdot
.998 .2361 Mdot
.998 .23643 Mdot
.998 .23644 Mdot
.998 .23675 Mdot
.998 .23708 Mdot
.998 .2376 Mdot
.998 .23798 Mdot
.998 .23889 Mdot
.998 .23993 Mdot
.998 .24099 Mdot
.998 .24104 Mdot
.998 .24121 Mdot
.998 .24188 Mdot
.998 .24236 Mdot
.998 .24298 Mdot
.998 .24341 Mdot
.998 .24345 Mdot
.998 .2437 Mdot
.998 .24395 Mdot
.998 .24416 Mdot
.998 .2446 Mdot
.998 .24511 Mdot
.998 .24573 Mdot
.998 .24579 Mdot
.998 .24602 Mdot
.998 .2465 Mdot
.998 .24652 Mdot
.998 .24755 Mdot
.998 .24786 Mdot
.998 .24817 Mdot
.998 .24932 Mdot
.998 .25036 Mdot
.998 .25088 Mdot
.998 .25114 Mdot
.998 .2514 Mdot
.998 .25169 Mdot
.998 .2527 Mdot
.998 .25281 Mdot
.998 .25315 Mdot
.998 .25327 Mdot
.998 .25348 Mdot
.998 .25402 Mdot
.998 .25434 Mdot
.998 .25472 Mdot
.998 .25553 Mdot
.998 .25624 Mdot
.998 .25675 Mdot
.998 .25708 Mdot
.998 .25762 Mdot
.998 .25841 Mdot
.998 .26164 Mdot
.998 .26218 Mdot
.998 .26218 Mdot
.998 .26239 Mdot
.998 .26344 Mdot
.998 .26352 Mdot
.998 .26466 Mdot
.998 .2658 Mdot
.998 .26682 Mdot
.998 .26744 Mdot
.998 .26879 Mdot
.998 .26884 Mdot
.998 .27011 Mdot
.998 .27077 Mdot
.998 .27138 Mdot
.998 .27167 Mdot
.998 .2719 Mdot
.998 .27346 Mdot
.998 .27428 Mdot
.998 .27437 Mdot
.998 .27477 Mdot
.998 .27625 Mdot
.998 .2764 Mdot
.998 .27702 Mdot
.998 .2774 Mdot
.998 .27817 Mdot
.998 .27858 Mdot
.998 .279 Mdot
.998 .27924 Mdot
.998 .28 Mdot
.998 .2803 Mdot
.998 .28101 Mdot
.998 .28114 Mdot
.998 .28138 Mdot
.998 .28269 Mdot
.998 .28285 Mdot
.998 .28291 Mdot
.998 .28417 Mdot
.998 .28452 Mdot
.998 .28533 Mdot
.998 .28535 Mdot
.998 .28569 Mdot
.998 .28723 Mdot
.998 .2874 Mdot
.998 .28805 Mdot
.998 .28893 Mdot
.998 .28938 Mdot
.998 .28968 Mdot
.998 .28993 Mdot
.998 .29046 Mdot
.998 .29058 Mdot
.998 .29065 Mdot
.998 .29079 Mdot
.998 .29175 Mdot
.998 .29296 Mdot
.998 .29493 Mdot
.998 .29502 Mdot
.998 .29713 Mdot
.998 .29781 Mdot
.998 .29813 Mdot
.998 .29917 Mdot
.998 .29921 Mdot
.998 .29977 Mdot
.998 .29978 Mdot
.998 .30037 Mdot
.998 .30067 Mdot
.998 .30102 Mdot
.998 .30112 Mdot
.998 .302 Mdot
.998 .30265 Mdot
.998 .30281 Mdot
.998 .30366 Mdot
.998 .30415 Mdot
.998 .30432 Mdot
.998 .30527 Mdot
.998 .30637 Mdot
.998 .30718 Mdot
.998 .30721 Mdot
.998 .30759 Mdot
.998 .30768 Mdot
.998 .30846 Mdot
.998 .30892 Mdot
.998 .30897 Mdot
.998 .30898 Mdot
.998 .30979 Mdot
.998 .31018 Mdot
.998 .31029 Mdot
.998 .31038 Mdot
.998 .31045 Mdot
.998 .3123 Mdot
.998 .31239 Mdot
.998 .31292 Mdot
.998 .31507 Mdot
.998 .31789 Mdot
.998 .31834 Mdot
.998 .31873 Mdot
.998 .31939 Mdot
.998 .31977 Mdot
.998 .31987 Mdot
.998 .31996 Mdot
.998 .32164 Mdot
.998 .32183 Mdot
.998 .32276 Mdot
.998 .32307 Mdot
.998 .32309 Mdot
.998 .32351 Mdot
.998 .3241 Mdot
.998 .3242 Mdot
.998 .32423 Mdot
.998 .32503 Mdot
.998 .32528 Mdot
.998 .32546 Mdot
.998 .326 Mdot
.998 .32633 Mdot
.998 .32641 Mdot
.998 .32725 Mdot
.998 .32734 Mdot
.998 .32753 Mdot
.998 .32867 Mdot
.998 .32874 Mdot
.998 .3288 Mdot
.998 .32889 Mdot
.998 .32898 Mdot
.998 .32949 Mdot
.998 .33025 Mdot
.998 .33157 Mdot
.998 .3322 Mdot
.998 .33233 Mdot
.998 .33321 Mdot
.998 .33421 Mdot
.998 .33441 Mdot
.998 .33567 Mdot
.998 .33787 Mdot
.998 .33819 Mdot
.998 .33825 Mdot
.998 .3391 Mdot
.998 .34068 Mdot
.998 .34181 Mdot
.998 .34229 Mdot
.998 .3425 Mdot
.998 .3438 Mdot
.998 .34434 Mdot
.998 .34475 Mdot
.998 .34495 Mdot
.998 .34507 Mdot
.998 .34512 Mdot
.998 .34544 Mdot
.998 .34654 Mdot
.998 .34734 Mdot
.998 .34748 Mdot
.998 .3477 Mdot
.998 .34784 Mdot
.998 .34802 Mdot
.998 .3503 Mdot
.998 .35063 Mdot
.998 .35245 Mdot
.998 .35256 Mdot
.998 .35368 Mdot
.998 .35429 Mdot
.998 .35506 Mdot
.998 .35546 Mdot
.998 .35554 Mdot
.998 .35561 Mdot
.998 .35634 Mdot
.998 .35707 Mdot
.998 .35804 Mdot
.998 .35857 Mdot
.998 .35905 Mdot
.998 .35925 Mdot
.998 .3594 Mdot
.998 .36025 Mdot
.998 .36037 Mdot
.998 .36039 Mdot
.998 .36133 Mdot
.998 .36234 Mdot
.998 .36328 Mdot
.998 .36476 Mdot
.998 .36492 Mdot
.998 .36514 Mdot
.998 .36564 Mdot
.998 .3659 Mdot
.998 .36596 Mdot
.998 .3664 Mdot
.998 .36709 Mdot
.998 .36711 Mdot
.998 .36762 Mdot
.998 .36838 Mdot
.998 .36845 Mdot
.998 .36887 Mdot
.998 .36917 Mdot
.998 .37122 Mdot
.998 .37405 Mdot
.998 .37495 Mdot
.998 .37604 Mdot
.998 .37637 Mdot
.998 .37683 Mdot
.998 .37755 Mdot
.998 .37793 Mdot
.998 .37832 Mdot
.998 .37864 Mdot
.998 .38016 Mdot
.998 .38051 Mdot
.998 .38065 Mdot
.998 .38121 Mdot
.998 .38317 Mdot
.998 .38327 Mdot
.998 .38332 Mdot
.998 .38334 Mdot
.998 .38396 Mdot
.998 .3845 Mdot
.998 .38532 Mdot
.998 .38661 Mdot
.998 .3871 Mdot
.998 .38724 Mdot
.998 .38758 Mdot
.998 .38791 Mdot
.998 .38864 Mdot
.998 .38905 Mdot
.998 .3903 Mdot
.998 .39053 Mdot
.998 .39204 Mdot
.998 .39212 Mdot
.998 .3939 Mdot
.998 .39553 Mdot
.998 .39558 Mdot
.998 .39611 Mdot
.998 .39636 Mdot
.998 .39706 Mdot
.998 .39725 Mdot
.998 .39727 Mdot
.998 .39738 Mdot
.998 .39756 Mdot
.998 .39788 Mdot
.998 .39952 Mdot
.998 .39988 Mdot
.998 .4 Mdot
.998 .40159 Mdot
.998 .40163 Mdot
.998 .40213 Mdot
.998 .40278 Mdot
.998 .40296 Mdot
.998 .40306 Mdot
.998 .40383 Mdot
.998 .40469 Mdot
.998 .4052 Mdot
.998 .40528 Mdot
.998 .40699 Mdot
.998 .40714 Mdot
.998 .40807 Mdot
.998 .409 Mdot
.998 .4093 Mdot
.998 .41017 Mdot
.998 .41058 Mdot
.998 .41083 Mdot
.998 .41171 Mdot
.998 .41189 Mdot
.998 .41271 Mdot
.998 .41287 Mdot
.998 .41312 Mdot
.998 .41347 Mdot
.998 .41389 Mdot
.998 .4147 Mdot
.998 .4156 Mdot
.998 .41639 Mdot
.998 .41714 Mdot
.998 .41734 Mdot
.998 .41771 Mdot
.998 .41787 Mdot
.998 .41811 Mdot
.998 .41901 Mdot
.998 .42 Mdot
.998 .42008 Mdot
.998 .42141 Mdot
.998 .42235 Mdot
.998 .42251 Mdot
.998 .42326 Mdot
.998 .42349 Mdot
.998 .42365 Mdot
.998 .4242 Mdot
.998 .42725 Mdot
.998 .42749 Mdot
.998 .42813 Mdot
.998 .42848 Mdot
.998 .42871 Mdot
.998 .42873 Mdot
.998 .42911 Mdot
.998 .42922 Mdot
.998 .42931 Mdot
.998 .43004 Mdot
.998 .43052 Mdot
.998 .43102 Mdot
.998 .4315 Mdot
.998 .43206 Mdot
.998 .43216 Mdot
.998 .43352 Mdot
.998 .43392 Mdot
.998 .43542 Mdot
.998 .43638 Mdot
.998 .43785 Mdot
.998 .43803 Mdot
.998 .43898 Mdot
.998 .43914 Mdot
.998 .44045 Mdot
.998 .44216 Mdot
.998 .44262 Mdot
.998 .44451 Mdot
.998 .44511 Mdot
.998 .44555 Mdot
.998 .44593 Mdot
.998 .44735 Mdot
.998 .44739 Mdot
.998 .44805 Mdot
.998 .44872 Mdot
.998 .44899 Mdot
.998 .44921 Mdot
.998 .44997 Mdot
.998 .45018 Mdot
.998 .45019 Mdot
.998 .45256 Mdot
.998 .45279 Mdot
.998 .4542 Mdot
.998 .45527 Mdot
.998 .45651 Mdot
.998 .45655 Mdot
.998 .4566 Mdot
.998 .45665 Mdot
.998 .45685 Mdot
.998 .45726 Mdot
.998 .45728 Mdot
.998 .4579 Mdot
.998 .45856 Mdot
.998 .45959 Mdot
.998 .46034 Mdot
.998 .46075 Mdot
.998 .46187 Mdot
.998 .46214 Mdot
.998 .46217 Mdot
.998 .46285 Mdot
.998 .46425 Mdot
.998 .46588 Mdot
.998 .46636 Mdot
.998 .46647 Mdot
.998 .46653 Mdot
.998 .4668 Mdot
.998 .46729 Mdot
.998 .46806 Mdot
.998 .46815 Mdot
.998 .4691 Mdot
.998 .4695 Mdot
.998 .47034 Mdot
.998 .47042 Mdot
.998 .47108 Mdot
.998 .4712 Mdot
.998 .47126 Mdot
.998 .47177 Mdot
.998 .47227 Mdot
.998 .47269 Mdot
.998 .47326 Mdot
.998 .47357 Mdot
.998 .47459 Mdot
.998 .47505 Mdot
.998 .47583 Mdot
.998 .47594 Mdot
.998 .4764 Mdot
.998 .47736 Mdot
.998 .47739 Mdot
.998 .47945 Mdot
.998 .48007 Mdot
.998 .4807 Mdot
.998 .4807 Mdot
.998 .48298 Mdot
.998 .48479 Mdot
.998 .48506 Mdot
.998 .48539 Mdot
.998 .4861 Mdot
.998 .48623 Mdot
.998 .48636 Mdot
.998 .48662 Mdot
.998 .48714 Mdot
.998 .48772 Mdot
.998 .48787 Mdot
.998 .48891 Mdot
.998 .48894 Mdot
.998 .48973 Mdot
.998 .48996 Mdot
.998 .49031 Mdot
.998 .49063 Mdot
.998 .49087 Mdot
.998 .4912 Mdot
.998 .49129 Mdot
.998 .49131 Mdot
.998 .49184 Mdot
.998 .49237 Mdot
.998 .49282 Mdot
.998 .49301 Mdot
.998 .49327 Mdot
.998 .49359 Mdot
.998 .49376 Mdot
.998 .49537 Mdot
.998 .49654 Mdot
.998 .4968 Mdot
.998 .49782 Mdot
.998 .49842 Mdot
.998 .49847 Mdot
.998 .49956 Mdot
.998 .50043 Mdot
.998 .50113 Mdot
.998 .50232 Mdot
.998 .50236 Mdot
.998 .5026 Mdot
.998 .50428 Mdot
.998 .50459 Mdot
.998 .50499 Mdot
.998 .50594 Mdot
.998 .50701 Mdot
.998 .50757 Mdot
.998 .50866 Mdot
.998 .50866 Mdot
.998 .50895 Mdot
.998 .50908 Mdot
.998 .51041 Mdot
.998 .51117 Mdot
.998 .51133 Mdot
.998 .51186 Mdot
.998 .512 Mdot
.998 .51216 Mdot
.998 .51295 Mdot
.998 .5136 Mdot
.998 .51448 Mdot
.998 .51571 Mdot
.998 .51589 Mdot
.998 .51792 Mdot
.998 .51795 Mdot
.998 .51816 Mdot
.998 .51915 Mdot
.998 .52179 Mdot
.998 .52184 Mdot
.998 .52194 Mdot
.998 .52246 Mdot
.998 .52448 Mdot
.998 .5258 Mdot
.998 .527 Mdot
.998 .52702 Mdot
.998 .52736 Mdot
.998 .52759 Mdot
.998 .52764 Mdot
.998 .52806 Mdot
.998 .52808 Mdot
.998 .52837 Mdot
.998 .52996 Mdot
.998 .53117 Mdot
.998 .53215 Mdot
.998 .53279 Mdot
.998 .53282 Mdot
.998 .5329 Mdot
.998 .53298 Mdot
.998 .53312 Mdot
.998 .53354 Mdot
.998 .53379 Mdot
.998 .53434 Mdot
.998 .53542 Mdot
.998 .53675 Mdot
.998 .53704 Mdot
.998 .53801 Mdot
.998 .53828 Mdot
.998 .53845 Mdot
.998 .53903 Mdot
.998 .5394 Mdot
.998 .54057 Mdot
.998 .5414 Mdot
.998 .54165 Mdot
.998 .54223 Mdot
.998 .5427 Mdot
.998 .54423 Mdot
.998 .5448 Mdot
.998 .54483 Mdot
.998 .54624 Mdot
.998 .5465 Mdot
.998 .5465 Mdot
.998 .54662 Mdot
.998 .54698 Mdot
.998 .54727 Mdot
.998 .54959 Mdot
.998 .54992 Mdot
.998 .55004 Mdot
.998 .55165 Mdot
.998 .55255 Mdot
.998 .55325 Mdot
.998 .55417 Mdot
.998 .55458 Mdot
.998 .55486 Mdot
.998 .5549 Mdot
.998 .55557 Mdot
.998 .55656 Mdot
.998 .55833 Mdot
.998 .55859 Mdot
.998 .55866 Mdot
.998 .559 Mdot
.998 .55985 Mdot
.998 .5603 Mdot
.998 .56205 Mdot
.998 .56248 Mdot
.998 .56295 Mdot
.998 .56354 Mdot
.998 .56399 Mdot
.998 .56404 Mdot
.998 .565 Mdot
.998 .56509 Mdot
.998 .56518 Mdot
.998 .56534 Mdot
.998 .56538 Mdot
.998 .56548 Mdot
.998 .56549 Mdot
.998 .56562 Mdot
.998 .56576 Mdot
.998 .56767 Mdot
.998 .5679 Mdot
.998 .56828 Mdot
.998 .56847 Mdot
.998 .5701 Mdot
.998 .57014 Mdot
.998 .5703 Mdot
.998 .57095 Mdot
.998 .57204 Mdot
.998 .5724 Mdot
.998 .5729 Mdot
.998 .57403 Mdot
.998 .5742 Mdot
.998 .5745 Mdot
.998 .57454 Mdot
.998 .57475 Mdot
.998 .57592 Mdot
.998 .57676 Mdot
.998 .5768 Mdot
.998 .57742 Mdot
.998 .57842 Mdot
.998 .57928 Mdot
.998 .57967 Mdot
.998 .57976 Mdot
.998 .5804 Mdot
.998 .58248 Mdot
.998 .58257 Mdot
.998 .58301 Mdot
.998 .5832 Mdot
.998 .5834 Mdot
.998 .58368 Mdot
.998 .58371 Mdot
.998 .58414 Mdot
.998 .58488 Mdot
.998 .58546 Mdot
.998 .58548 Mdot
.998 .58617 Mdot
.998 .58625 Mdot
.998 .58637 Mdot
.998 .58715 Mdot
.998 .58813 Mdot
.998 .58943 Mdot
.998 .58975 Mdot
.998 .59145 Mdot
.998 .59243 Mdot
.998 .59277 Mdot
.998 .59277 Mdot
.998 .59466 Mdot
.998 .59686 Mdot
.998 .59705 Mdot
.998 .59812 Mdot
.998 .5983 Mdot
.998 .59847 Mdot
.998 .59854 Mdot
.998 .5993 Mdot
.998 .59947 Mdot
.998 .60103 Mdot
.998 .60196 Mdot
.998 .60199 Mdot
.998 .60204 Mdot
.998 .60206 Mdot
.998 .60213 Mdot
.998 .60232 Mdot
.998 .60253 Mdot
.998 .60332 Mdot
1 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[50]:=",
  ImageSize->{740.75, 457.813},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000AG0002[R000`400?l00000o`00003oo`3ooooo
0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0
ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3o
oomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?oo
o`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00l@3o
ool4000000H0oooo0P0000050?ooo`H00000_P3oool4000000H0oooo0P0000070?ooo`@00000_`3o
ool4000000H0oooo0P0000070?ooo`@00000_P3oool4000000H0oooo0P0000060?ooo`@00000a`3o
ool700000080oooo003`0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2
000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool2000000T0oooo00<000000?ooo`3oool0_@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0a`3oool0
0`000000oooo0?ooo`030?ooo`00l03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool00`3oool00?00oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`H00000_P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo0P0000030?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0a`3oool00`000000
oooo0?ooo`030?ooo`00l03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00@000000?ooo`3oool00000_`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`0000000P00002m0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool400000<X0oooo00<000000?ooo`3oool00`3oool00?00oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo00000;l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0a`3oool00`000000oooo0?ooo`030?ooo`00l03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2k0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002o0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2n0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0<L0oooo00<000000?ooo`3oool00`3oool00?00oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0^`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000_`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0_@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`350?ooo`<000001@3oool00?40oooo1000000>0?ooo`@00000_`3oool4
00000100oooo0P0000300?ooo`@000004@3oool300000;d0oooo1000000>0?ooo`@00000bP3oool0
0`000000oooo0?ooo`030?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3o
ool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003o0?ooool0oooo603oool00`000000oooo0?ooo`030?ooo`00:03ooooo00000?l00000o`00
003o000002h000001@3oool002P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0<03oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0000000D0oooo000X0?ooo`030000003o
ool0oooo0=80oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`3B0?ooo`030000003o
ool0oooo0=80oooo00<000000?ooo`3oool0cP3oool01@000000oooo0?ooo`3oool0000000D0oooo
000X0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?oo
o`3B0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0cP3oool01@000000oooo0000
003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo9P3o
ool00`000000oooo0?ooo`070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo
0?ooob@0oooo00D000000?ooo`3oool0oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3ooooo0?ooob80oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooobP0oooo00<000000?oo
o`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolR0?ooo`05
0000003oool0oooo0?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
ooooo`3ooolO0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000001`3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolO0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3ooolM0?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooad0oooo00<0
00000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolM0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3o
oolM0?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000L0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo6`3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooooo`3ooolI0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooo`3ooolK0?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooooo0?oooaT0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?oo
o`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oo
oaL0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolG0?oo
o`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo5`3oool0
0`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo0000
00070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooaD0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo
0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo
0?oooaD0oooo00D000000?ooo`3oool0oooo000000050?ooo`0:0000003oool0oooo0000003oool0
00000?ooo`000000oooo000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
ool0oooo4`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooooo`3ooolC0?ooo`030000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000090?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooa40oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000/0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo4`3oool00`000000oooo0000
00030?ooo`030000003oool0oooo00<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000
003oool000001`3oool002P0oooo1@00003o0?ooool0ooooo`3ooooo0?ooo`l0oooo00<000000?oo
o`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooooo0?ooo`h0oooo00@000000?ooo`3oool000000`3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0
000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo4@3oool00`00
0000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3o
ool<0?ooo`030000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool<0?ooo`030000003oool00000
00H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooooo0?ooo`X0oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool:
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000009
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooo`X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000L0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo203oool00`000000oooo0?ooo`060?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooo`3oool80?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0203oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3o
ool80?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`050000003oool0oooo0?oo
o`0000001@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000L0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo1P3oool01@000000oooo0000003oool0
000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00D000000?ooo`00
0000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooo`P0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooool0oooo1P3oool00`000000oooo000000030?ooo`030000003oool00000
00H0oooo00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo
0?ooo`@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0
000000D0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo0P3oool0
0`000000oooo000000030?ooo`050000003oool000000?ooo`0000002P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000080?ooo`030000003oool0oooo00D0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo0P3oool01@000000oooo0000003oool00000
00D0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000002@3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool40?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo00000005
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooo`3oool20?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooool0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooool0?ooo`040000
003oool0oooo000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooooj0?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo00000005
0?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00001@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo103oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooh0?ooo`030000003o
ool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00<000000?ooo`3o
ool0103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01@000000oooo0?ooo`3oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?oooo`0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool0
00000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000L0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooooX0oooo00<000000?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool00P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool0
00000?ooo`000000oooo000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
ooH0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooooP0oooo00<000000?ooo`3oool01P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooood0?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000/0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?oooo@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`070000
003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3oooob0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000060?oo
o`070000003oool0oooo0?ooo`000000oooo000000060?ooo`030000003oool0000000D0oooo00L0
00000?ooo`3oool0oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000090?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooood0?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00070?ooo`00:03oool500000?l0ooooo`3ooooo0?oooo00oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000001`3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooood0?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo000000070?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooood0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool010000000oooo0?ooo`0000050?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool02P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`0000070?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3oooob0?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooool03oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooon/0oooo00<000000?ooo`3oool0103o
ool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool00000
00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooon/0oooo00<000000?ooo`3oool00P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00001P3oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooon/0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooonT0oooo
00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000030?ooo`0;0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooi`3oool01`000000oooo0000003oool0
00000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
1P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oooW0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo0000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooU0?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`070000003o
ool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`030000003oool0000000H0oooo00<000000?ooo`0000002@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooi@3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooonD0oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000001@3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00L000000?ooo`3oool0oooo0000
003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooon<0oooo00/0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
1`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooh`3oool00`000000oooo0000
00050?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000002P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooooS0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000001P3oool00`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`0000030?ooo`030000003oool0000000H0oooo00<000000?ooo`0000002@3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooh`3oool02`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000001@3oool01`000000oooo0000003oool00000
0?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooog`3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
oml0oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000060?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooog03oool03000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`070000003oool0oooo0?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0oooog`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo
00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
20000000oooo0?ooo`000000oooo0000003oool000001@3oool00`000000oooo000000060?ooo`05
0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
oooofP3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`00
0000oooo000000080?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooooJ0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooJ0?ooo`030000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
oooofP3oool00`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo00000003
0?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?oo
o`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooF0?ooo`070000003oool000000?ooo`000000
oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?oo
o`070000003oool000000?ooo`000000oooo000000050?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooeP3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`070000003oool0
oooo0?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00D000000?ooo`000000
oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`000000203oool00`000000
oooo000000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooomH0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?oo
o`3oool00`3oool01@000000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
e03oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`0:0000003oool0oooo0000003oool0
00000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000000@0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooe03oool01@000000oooo0000003oool0000000<0oooo00@00000
0?ooo`3oool000000`3oool01`000000oooo0000003oool000000?ooo`0000001P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool002P0oooo1@00003o0?ooool0ooooo`3oooo@
0?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo000000030?ooo`040000003oool0oooo000000D0oooo00L000000?oo
o`3oool0oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000001`3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooe03oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool01P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000001@3oool02P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00P000000?oo
o`3oool000000?ooo`000000oooo000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooom00oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000050?ooo`0:0000003oool0oooo0000003o
ool000000?ooo`000000oooo000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooom00oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000040?oo
o`070000003oool000000?ooo`000000oooo000000050?ooo`030000003oool0000000X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0000000H0oooo00<000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0oooocP3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000001@3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000090?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo@0?ooo`030000003oool0000000T0oooo00H0
00000?ooo`3oool000000?ooo`0000050?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo000000050?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000T0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooolh0oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000050?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0?ooo`020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001`3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooob`3oool01P000000oooo0?ooo`000000oooo
000000<0oooo00<000000?ooo`3oool01@3oool04P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`00
00000`3oool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oool/0oooo00P00000
0?ooo`3oool000000?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`060000003oool0oooo0000003oool000000`3oool01@000000oooo0000003oool0000000<0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3oooo;0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000
oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000050?oo
o`060000003oool0oooo0000003oool000000`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooolT0oooo00<000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`3oool0oooo
0000003oool0000000<0oooo00<000000?ooo`0000001P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
1`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooob`3oool020000000oooo0?oo
o`000000oooo0000003oool000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooolD0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00060?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3oooo50?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooolD0oooo00D000000?ooo`000000oooo000000040?ooo`050000
003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000001P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3oooo30?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo00000004
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`0?0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooolD0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`03
0000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?oool<0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`030?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oool40oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`00
0000oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000002@3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo_`3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000001P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`070?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonl0?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool00000
0?ooo`0000001@3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonl0?ooo`060000003o
ool0oooo0000003oool000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool0
0`000000oooo000000070?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000
00070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooono0?ooo`030000003oool0
000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo`@3oool0
0`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?oookX0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003o
ool0000000P0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00H000000?ooo`3oool000000?ooo`00000;0?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooonh0?ooo`050000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000070?ooo`050000003o
ool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`00
0000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooonf0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`0000001P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool00`000000oooo0000000;0?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooonj0?ooo`030000003oool0oooo0080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?oo
o`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0oooo0?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`000P3o
ool4000000H0oooo0P0000050?ooo`H000003`3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oond0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0000003oool0000000<0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000L0oooo00000`3oool000000?ooo`030?ooo`030000003oool0
oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooond0?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`000000203oool03`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000070?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo/P3oool0
0`000000oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000D0oooo00@000000?ooo`3oool000001@3oool01@000000oooo0?ooo`3oool00000
00H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000T0oooo00000`3oool000000?ooo`030?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0403oool700000?l0ooooo`3ooooo0?oook80oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000001@3oool01@00
0000oooo0000003oool0000000P0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool00003
0?ooo`000000oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?oook00oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000060?ooo`030000003oool0000000D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00<0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000001@3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`0000<0oooo0000
003oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0oooo/03oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`06
0000003oool0oooo0000003oool000001`3oool01@000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool000030?ooo`000000oooo00<0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo[P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000H0oooo00l000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`000000103oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
00<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`070000003oool000000?ooo`000000oooo000000070?oo
o`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon`0?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool00000
0`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000001`3oool00080oooo1000000>0?ooo`@00000403oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000L0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3o
ool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`050?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon^0?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000L0
oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonY0?ooo`030000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000050?ooo`050000003oool000000?ooo`000000
103oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`3oool0oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooonW0?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo000000050?ooo`05
0000003oool000000?ooo`0000000P3oool00`000000oooo0000000<0?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`05
0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000001`3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooY`3oool01@000000oooo0000003o
ool0000000@0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0000000@0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003o
ool0000000D0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooonU0?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`0000030?ooo`030000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool01`000000oooo0000003oool000000?ooo`00
00001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooY@3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000040?oo
o`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool010000000
oooo0?ooo`0000050?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooojD0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000001@3oool020000000oooo0?ooo`000000oooo
0000003oool000000`3oool00`000000oooo000000060?ooo`050000003oool000000?ooo`000000
1@3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01@000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0
000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool01@00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooj<0oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`07
0000003oool0oooo0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonQ0?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000000:0?ooo`0?0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo
00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?oooj40oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooil0
oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000
003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
00050?ooo`050000003oool0oooo0?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooW`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000`3oool00`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`080000003oool0oooo0000
003oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000001`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
1`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooW@3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`030?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`050000003oool0oooo0?oo
o`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?oo
o`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooW@3oool00`000000
oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3ooonO0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000001P3oool01@000000oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooonH0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool0
00000`3oool01`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooV03o
ool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo
000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool00000
00H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooooV03oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000000`3oool0
1@000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo0000
00<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo
000000080?ooo`070000003oool000000?ooo`000000oooo0000000:0?ooo`030000003oool0oooo
00D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooiH0oooo
00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000T0oooo00<000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@00
0000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
oi@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00L00000
0?ooo`3oool0oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool00000
00D0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000001P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`0<0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool00`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?oooi@0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`000000103o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooU03oool01@000000oooo0000003o
ool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003o
ool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooTP3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo
000000030?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooi00oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0000000P0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`060?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo00000003
0?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?oo
o`000000103oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?oooi00oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000L0oooo00D000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo000000060?ooo`030000003oool0
000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`000000
1@3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000
oooo000000080?ooo`030000003oool0oooo00D0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0ooooSP3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool03@000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00070?ooo`00:03oool500000?l0ooooo`3ooooo0?ooohT0oooo00X000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000`3oool00`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00@00000
0?ooo`3oool000000`3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooh/0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00D0oooo00X000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon>0?ooo`05
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo
000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000T0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooohT0oooo00<000000?ooo`0000000P3oool0
3@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`060000003oool0oooo0000
003oool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00/000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooQ`3oool01@00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool010000000oooo0?ooo`0000030?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00040?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000H0
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?oooh/0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool00000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00<0oooo
010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo000000060?ooo`030000003oool0000000L0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooohD0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000030?ooo`080000003oool0oooo0000003oool0
00000?ooo`0000050?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`03
0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000L0oooo
00<000000?ooo`0000001P3oool01@000000oooo0000003oool0000000D0oooo00h000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?oo
o`3oool00P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
2P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000070?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooon50?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000002P3oool01@000000oooo0?ooo`3oool0000000@0oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooon30?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103o
ool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0000000<0oooo00`000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000040?ooo`0?0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`000000203oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000007
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon50?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon10?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`040000003oool0oooo000000<0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool0
20000000oooo0?ooo`000000oooo0000003oool000001@3oool00`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`0B0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool02P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`0000050?ooo`030000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooogl0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000001P3o
ool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103o
ool00`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
000000030?ooo`050000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon10?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool0103oool02@000000oooo0000003oool000000?ooo`000000oooo
000000050?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000
oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00@0
00000?ooo`3oool000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooomm0?ooo`030000003oool0000000D0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000030?ooo`0<
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool00`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0
000000@0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooNP3oool03P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`040000003oool0oooo000000<0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool00`000000
oooo000000080?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooogX0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000D0oooo00D00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000<0oooo00P00000
0?ooo`3oool000000?ooo`000000oooo000000T0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooogP0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?oo
o`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000203oool00`000000oooo0?ooo`050?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomh0?ooo`030000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`030000003o
ool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooomf0?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000060?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000003oool0
00000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooMP3oool0
1@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool000000?oo
o`000000oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000
003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooog@0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool01`000000oooo0000003oool000000?ooo`000000203oool00`000000
oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000000`3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomb0?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool00000103oool02@000000oooo0000003oool000000?oo
o`000000oooo000000080?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomb0?ooo`050000003oool0
00000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`040000003oool0oooo000000<0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000P0oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooog00oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
103oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000080?oo
o`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooooKP3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000<0oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool00`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooooL03oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000030?ooo`080000003o
ool0oooo0000003oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000001P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oom[0?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`050000003oool000000?oo
o`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`000000203oool03`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000001@3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo
000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom[0?ooo`0:0000003o
ool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`050000003oool000000?ooo`0000001@3oool04P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00D000000?ooo`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooomY0?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`00
00000`3oool01`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000;
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomW0?ooo`050000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool030000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000
0P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooomU0?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`070000
003oool000000?ooo`000000oooo000000050?ooo`030000003oool0000000@0oooo00D000000?oo
o`3oool0oooo000000050?ooo`060000003oool0oooo0000003oool000001@3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool0
oooo0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo
1@00003o0?ooool0ooooo`3ooomS0?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool0
00000?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000050?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000203oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00001@3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomS0?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`070000003oool000000?oo
o`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomS0?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool010000000
oooo0?ooo`0000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000001`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooH@3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000050?ooo`0:0000003oool0oooo0000
003oool000000?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooof40oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000050?ooo`0B0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooomQ0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?oo
o`0000001P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?oooed0oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?oo
o`030000003oool0000000H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool0
oooo0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000060?ooo`030000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?oooed0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000`3oool00`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool0000000P0oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`000000203oool01`000000oooo0000003oool000000?ooo`000000103o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooFP3oool00`000000oooo0?ooo`020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo0000
00D0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001P3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooeP0oooo00<000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000000:0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000<0oooo00P000000?ooo`3o
ool000000?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?oooeP0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000D0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?oooa<0oooo00<000000?ooo`3oool0o`3ooom00?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000080?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000<0oooo010000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000001P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool00`00
0000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomF0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooooE03oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01@000000oooo
0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<00000
0?ooo`0000001@3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`05
0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool00000
00T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooe80oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000005
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`030000003oool0000000D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooD03oool02@000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000D0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool0103oool03@000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?oo
o`030000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0
000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000030?oo
o`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000L0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?oooe00oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool000000?ooo`000000103oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000001@3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000007
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom>0?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000`3oool03P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool040000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0ooooC03oool00`000000oooo0?ooo`030?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000001@3oool0
1@000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000
oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom<0?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
4P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo01000000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0
oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000103oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooB@3oool04P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00X0
00000?ooo`3oool000000?ooo`000000oooo0000003oool00000203oool02`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool01@000000oooo0000
003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?oo
o`3oool0oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom70?oo
o`030000003oool0oooo0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000
oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000L0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooodL0oooo00<000000?ooo`0000000P3o
ool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000060?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooA@3oool01@000000oooo
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool0103oool02@000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0oooo@`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0000000D0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0000000D0
oooo00<000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000000`3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000001`3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo@@3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00L000000?oo
o`3oool0oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?oood40oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool040000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00D000000?oo
o`3oool0oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolo0?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000040?oo
o`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<0
00000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo?@3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0000
00040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000D0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooolj0?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`00
0000oooo000000050?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00D000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`050000003oool000000?ooo`0000002@3oool01P000000oooo0?oo
o`000000oooo000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0oooo>P3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000040?ooo`050000003oool000000?ooo`0000000`3oool0
1@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`0000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo
000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolh0?ooo`030000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000203oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000L0oooo
010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool00000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03o
ool500000?l0ooooo`3ooooo0?oooc@0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool030000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000001`3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo=P3oool01@000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo00000004
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00<000000?ooo`0000001@3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooold0?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo
000000030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolb0?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo0000
00090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool`0?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0
000000<0oooo00<000000?ooo`0000001P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000050?oo
o`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000
oooo000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobh0oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000060?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
ool^0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000
003oool0000000H0oooo00<000000?ooo`0000001@3oool04P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooob`0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooobT0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?oo
o`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0oooo:@3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0
oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000001P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
1@000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooobL0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0
00000?ooo`0000001@3oool01@000000oooo0?ooo`3oool0000000@0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobD0oooo00D000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000
003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00P0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooob<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`030000003oool0000000L0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00D0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
0`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolS0?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000040?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000203oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000050?ooo`080000003o
ool0oooo0000003oool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo0000
00060?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000001@3oool00`000000oooo000000040?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooolQ0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000003
0?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000002@3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo7`3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000H0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000000`3o
ool010000000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000004
0?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooob40oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000070?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`040000003oool0oooo
000000<0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool020000000
oooo0?ooo`000000oooo0000003oool000001@3oool01@000000oooo0?ooo`3oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003o
ool0oooo0000003oool000000?ooo`000000oooo000000L0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?oooa/0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<0
00000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo00000007
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolH0?ooo`0>0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`0@0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo0080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000000`3oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
5P3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool03`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
103oool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0oooo5P3oool00`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool040000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`03
0000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool000000080oooo00/00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo
0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000103oool00`000000
oooo0?ooo`030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo000000050?oo
o`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
1`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo503oool01@000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000000`3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool00000
0?ooo`000000oooo000000040?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa80oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool04000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000
003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?oooa00oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`050000003oool000000?ooo`00
00001`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000
003oool000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo403oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo303o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000030?ooo`0@
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000050?ooo`050000003oool000000?ooo`000000
103oool00`000000oooo000000030?ooo`030000003oool0000000P0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool90?ooo`0@0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L00000
0?ooo`3oool0oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo
0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo`T0oooo010000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000070?ooo`000P3oool4000000H0oooo0P0000070?ooo`@000003`3oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3oool70?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`03
0000003oool0000000D0oooo00<000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`030000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000H0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000/0oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00<0oooo0P000009
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo1@3oool0
0`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool0103oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000L0oooo00000`3oool000000?ooo`030?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool5
0?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003o
ool000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool0
0`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000001@3oool00`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool000030?ooo`00
0000oooo00<0oooo00<000000?ooo`3oool02P3oool6000000l0oooo1`00003o0?ooool0ooooo03o
ool01`000000oooo0?ooo`3oool000000?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo000000D0oooo00<000000?ooo`3oool0103oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000001@3oool00`00
0000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
4P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00
00<0oooo0000003oool00`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo00000100
oooo00<000000?ooo`3oool0o`3ooooo0?ooooh0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool01@000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0
000000<0oooo00<000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
1`3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool02`3oool010000000oooo0?oo
o`00000@0?ooo`030000003oool0oooo0?l0ooooo`3ooool0?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00<000000?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool01@3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0000000@0?ooo`030000003oool0oooo0?l0ooooo`3ooool0?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool01`000000oooo0000
003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`030000003oool0oooo0080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo
0?ooo`3oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo00000`3o
ool000000?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000403oool00`00
0000oooo0?ooo`3o0?ooool0oooom`3oool04P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool010000000
oooo0?ooo`0000030?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool01@00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000050?ooo`030000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000001`3oool00080oooo1000000@0?ooo`800000403oool0
0`000000oooo0?ooo`3o0?ooool0oooom`3oool04P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo
00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003o
ool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000001`3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooooD0oooo00<000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooool`3oool01@000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oo40oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`050000003oool000000?ooo`0000002@3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooonl0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?oo
o`050000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000/0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3oooo]0?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool0000000@0oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooon/0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`070000
003oool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooj@3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?oo
o`000000oooo000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooV0?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
000000040?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooon@0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooon80oooo
00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000P0oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`00
0000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool010000000oooo0?ooo`0000030?ooo`070000003oool0oooo0?ooo`000000oooo0000
00040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooP0?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000001P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooN0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooom`0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00D000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000003oool000000?oo
o`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooomX0oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
0000103oool00`000000oooo0?ooo`030?ooo`070000003oool000000?ooo`000000oooo00000004
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooomD0oooo00<0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000003
0?ooo`030000003oool0oooo0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00050?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooom<0oooo00D000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`05
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooood@3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool00`3oool01@000000
oooo0000003oool0000000P0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00X0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000001@3oool040000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool0103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool020000000oooo0?oo
o`000000oooo0000003oool000000`3oool00`000000oooo000000030?ooo`0B0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooll0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000P0oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3oooo=0?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000030?ooo`030000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo
000000030?ooo`030000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3oooo;0?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool00P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
oooob@3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000002P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool010000000oooo0?ooo`0000030?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?oool@0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo00000004
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000`3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo`P3oool01@00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
1@000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oool00oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oookh0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool0
1@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooonl0?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00L000000?oo
o`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?oo
o`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`00:03oool500000?l0ooooo`3ooonf0?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo]@3o
ool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000080?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000L0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooonc0?ooo`030000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000001P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`00
00000`3oool01@000000oooo0000003oool0000000H0oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo00000009
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo[`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0>0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000060?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo000000050?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooojd0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
00050?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool0
0`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooonY0?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`030000003oool0oooo00@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00001@3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool0
0`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000001@3oool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000T0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooonV0?ooo`0@0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooonT0?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0000000D0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooonP0?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooWP3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000060?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooVP3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?oooiD0oooo018000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000@0oooo00d000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01`00
0000oooo0000003oool000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooonA0?ooo`050000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo000000040?ooo`070000003o
ool0oooo0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo
00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooon?0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`000000
0P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00D000000?ooo`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooR`3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo0180
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`06
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooon70?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01@000000oooo0000003o
ool0000000@0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`00
00000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooh80oooo00<0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool04P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000<0oooo00`000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0
00000?ooo`0000001@3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomn0?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oomj0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000070?ooo`030000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`000000103oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooM@3oool040000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`0000030?ooo`030000003oool000000080oooo00/000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`05
0000003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003oool00000
00D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool00000
0?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooog40oooo00D000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`0@0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooom]0?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooI`3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo0000
00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
of00oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`05
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:
0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomJ0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`000000103oool03@000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000D0oooo00<000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooD`3oool0
4P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`000000203oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`0000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooC@3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00T0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`07
0000003oool0oooo0?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00/000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooA03oool040000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`030000003oool0000001@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo>03oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
0000000H0?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooobT0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
503oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000001P3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000050?ooo`0B0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`030?ooo`0B
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo
1@00003o0?ooool0oooo503oool00`000000oooo0?ooo`0^0?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003o
ool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolH0?ooo`030000003oool0
oooo0440oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
0`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000090?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooI`3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?oooaX0oooo00<000000?ooo`3oool0E03oool01@000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo0180
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?oooa`0oooo00<000000?ooo`3oool0F`3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolN0?ooo`030000003oool0oooo
05l0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000070?ooo`060000003oool0oooo0000003oool000000`3oool01@000000oooo0000003o
ool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000P0oooo
00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooolP0?ooo`030000003oool0oooo0640oooo018000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000090?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0oooo8P3oool00`000000oooo0?ooo`1V0?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
00030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool0
1@000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000002@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooob80oooo00<000000?ooo`3oool0JP3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000
00040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00<000000?ooo`0000001@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo018000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool04P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooobD0oooo00<000000?ooo`3oool0J`3oool00`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00@000000?oo
o`3oool000000`3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00H0oooo00<000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooobL0
oooo00<000000?ooo`3oool0KP3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?oo
o`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000080?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0oooo:@3oool00`000000oooo0?ooo`1`0?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000002@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooobT0oooo00<000000?ooo`000000M03oool01`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`070000003oool000000?ooo`000000oooo
000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo:`3oool00`000000oooo0000
001f0?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00L000000?oo
o`3oool0oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo;@3oool00`00
0000oooo0000001f0?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`0000000`3oool01@000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooobl0oooo
00<000000?ooo`3oool0M`3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0oooo00<0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo0000
00030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0oooo<@3oool00`000000oooo0?ooo`1i0?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000L0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooola0?ooo`030000
003oool0000007/0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo0000
00<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3o
ool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool0oooo
0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo<`3oool0
10000000oooo0?ooo`00001l0?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo
00<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0
000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolf0?ooo`030000003oool00000
07`0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00080?ooo`030000003oool0oooo00<0oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooocP0oooo00<000000?ooo`000000O@3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool020000000oooo0?ooo`00
0000oooo0000003oool000000`3oool00`000000oooo000000060?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`0000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool0
0`000000oooo0000001m0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00050?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?oo
o`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00D000000?ooo`3o
ool0oooo0000001m0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3oooll0?ooo`050000003oool0oooo0?ooo`000000O@3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000050?oo
o`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3oooln0?ooo`050000003oool0oooo
0?ooo`000000O@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000001@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0oooo@03oool01@000000oooo0000003oool0000007d0oooo00D000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00`000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000050?ooo`060000003oool0oooo
0000003oool000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0000000H0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooom20?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool0NP3oool00`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00H0
00000?ooo`3oool000000?ooo`00000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
@P3oool00`000000oooo000000020?ooo`030000003oool0000007`0oooo018000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000
003oool000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`07
0000003oool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooA03oool020000000oooo0?ooo`000000oooo0000003oool00000O@3oool01@000000oooo
0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`050000003oool000000?ooo`0000001@3oool040000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo000000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooA`3oool01`00
0000oooo0?ooo`3oool000000?ooo`000000O@3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooom90?ooo`070000
003oool0oooo0?ooo`000000oooo0000001m0?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00070?ooo`00:03oool500000?l0ooooo`3ooom90?ooo`070000003oool0oooo0?ooo`000000oooo
0000001m0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oood/0oooo00<000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo07P0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool0103oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000L0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooom=0?ooo`030000003oool0000000<0oooo
00H000000?ooo`3oool000000?ooo`00001j0?ooo`050000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000D0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooodl0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000007X0
oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`030000
003oool0oooo0080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000
003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003o
ool0000000@0oooo00D000000?ooo`000000oooo0000001h0?ooo`030000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`00
0000oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0000
00030?ooo`030000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomC0?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`000000oooo0000001h0?ooo`0:0000003oool0oooo
0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000001P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000@0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooe<0oooo
00@000000?ooo`3oool000001@3oool01@000000oooo0000003oool0000007T0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000001@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooEP3oool0
0`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool0000007L0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003oool0000000<0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000002@3o
ool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooF03oool00`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo07H0oooo00L000000?oo
o`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00D000000?oo
o`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooFP3oool00`000000oooo000000030?ooo`050000003o
ool000000?ooo`0000000P3oool00`000000oooo0000001d0?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo00000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo0000
00070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooG03oool00`000000oooo00000003
0?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool000000780oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomL
0?ooo`050000003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000780oooo00<000000?ooo`000000103oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000P0oooo00L000000?ooo`000000oooo0000003oool0000000L0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomN0?ooo`050000003oool000000?ooo`00
0000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000780oooo
00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
0000103oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00X000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000`3oool00`000000oooo000000040?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool03P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool020000000
oooo0?ooo`000000oooo0000003oool000000`3oool01@000000oooo0000003oool0000000H0oooo
00D000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
H03oool01@000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000006h0oooo00<000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000001@3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0
000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomR0?ooo`030000003oool00000
0080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000060?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooof@0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo0000001/0?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`3o
ool01@3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomT0?ooo`080000003oool0
oooo0000003oool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000006P0oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003o
ool0oooo0000003oool000000?ooo`000000oooo000000L0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooomW0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000006H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooJ@3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`1S0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooom[0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool000000640oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo
000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000
oooo000000<0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`00
00001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooofd0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo0000001O0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooofd0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000001K0?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0
000000P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooK`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000005H0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3oooma0?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000004X0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomc0?ooo`030000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0oooo03H0oooo00D000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooL`3oool00`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000002P0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`030000003oool0000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000
oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooM@3oool040000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool01`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooogP0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000070?ooo`00
0P3oool4000000H0oooo0P0000070?ooo`@000003`3oool00`000000oooo0?ooo`3o0?ooool0oooo
NP3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo
00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000007
0?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`030?ooo`8000001P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
og`0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool000000?ooo`000000
103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000P0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000001`3oool000030?ooo`000000oooo00<0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0o`3ooooo0?ooog`0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000050?oo
o`040000003oool0oooo000000D0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`030000003o
ool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool00003
0?ooo`000000oooo00<0oooo00<000000?ooo`3oool02`3oool2000000<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`3o0?ooool0ooooOP3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000
oooo000000030?ooo`030000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003o
ool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0000
00030?ooo`030000003oool0oooo00D0oooo00000`3oool000000?ooo`030?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`0000000P00000?0?ooo`L00000o`3ooooo0?ooog`0oooo00D00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo01800000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000002@3oool000030?oo
o`000000oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0?l0ooooo`3ooon20?ooo`030000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000L0oooo0000
0`3oool000000?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`3o0?ooool0ooooQ03oool04P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003o
ool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool0
3`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool01@000000oooo0000
003oool000000080oooo00<000000?ooo`0000002`3oool000030?ooo`000000oooo00<0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooo`3o
oon40?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool00`000000oooo000000090?ooo`000P3oool40000
0140oooo0`00000>0?ooo`030000003oool0oooo0?l0ooooo`3ooon70?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<0
00000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooon90?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001@3o
ool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`03
0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooR`3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool0
4P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00D00000
0?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000090?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooS@3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooohd0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00001P3oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooon?0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?oooi40oooo00D000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00<000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooi<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?oooiD0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooonE0?ooo`0B0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo0180
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000002@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?oooiP0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`050000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
VP3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`0@0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?oo
o`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooW03oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000
003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000
003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooWP3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000060?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooih0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo00000005
0?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooj00oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000003
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool00`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooonR0?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?oooj@0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000002@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooojH0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00001`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooonV0?oo
o`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo00000009
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooZ@3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000070?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooZ`3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01@00
0000oooo0?ooo`3oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00001@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000T0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooon]0?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000040?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000
00070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo[`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool00000103oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`030000
003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000
003oool0000000L0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo[`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003o
ool000000?ooo`000000oooo000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooona
0?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003o
ool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
/`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000L0oooo00<0
00000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000030?oo
o`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool00`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo1@00003o0?oo
ool0oooo/`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000002`3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oookP0oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo
0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooonh0?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000
00090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo^P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool030000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?oook`0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?oookh0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
103oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00D000000?ooo`3oool0oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0oooo`03oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000001P3o
ool01`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0
oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo`03oool01`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:
0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000
103oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000050?oo
o`030000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3oooo20?ooo`050000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000001P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`030000003oool0oooo00T0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3oooo40?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
ooo60?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooolT0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
4P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0oooob@3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000090?ooo`060000
003oool0oooo0000003oool000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0oooob`3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000D0oooo00<000000?ooo`0000001P3oool01@000000oooo0000003oool0000000L0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3oooo=0?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo00000005
0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000070?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooc`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool0oooo0080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000070?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooc`3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000001P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001`3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooom40oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`070000003o
ool0oooo0?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000001`3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooom<0oooo00D000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooe@3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`05
0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooG0?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooomX0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0oooofP3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooL
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00H0oooo00<000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooomh0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooon00oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooP
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0oooohP3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?oo
o`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool0
1@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000001P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooT0?ooo`030000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000005
0?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000002`3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooonH0oooo018000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool01@00
0000oooo0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooY0?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooj`3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`050000003oool000000?ooo`000000103oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`D00000o`3ooooo0?ooonT0
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
40000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000070?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooook@3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000001P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3oooo_0?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00D00000
0?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000002P3o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooool@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooc0?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooool`3oool01@00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000
00040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00060?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool0
1`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooooD0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`000000oooo00000006
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool04P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3oooog0?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?oo
o`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000L0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooj0?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`05
0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`0000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooonP3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000001P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
1`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooo`0oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo
000000050?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooooP3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`05
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`05
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool10?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00D000000?oo
o`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo0`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool02`00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00l000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0oooo1@3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000<0oooo01000000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000001P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooo`D0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool02@000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooo`L0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000050?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000T0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo`T0oooo010000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`3oool0
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo303oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool01@000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`05
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool00000
0?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool<0?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0oooo0?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool0
2P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000050?ooo`030000003oool00000
0080oooo00D000000?ooo`3oool0oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3oool>0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool@0?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`05
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
oa80oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
00<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo4P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
1@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolD0?ooo`050000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
1P3oool01@000000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool00`000000oooo00000007
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000T0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooolH0?ooo`0B0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000
003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3o
ool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000/0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa/0oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000001P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`070000
003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooolO0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0oooo7`3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103o
ool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000030?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0oooo7`3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool00`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<00000
0?ooo`0000001`3oool002P0oooo1@00003o0?ooool0ooooo`3ooolO0?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0oooo8`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooob<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
obD0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000D0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oolW0?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobT0oooo018000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
ob`0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00T0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooobh0oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000001@3oool00`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo;P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?oooc00oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`060000003o
ool0oooo0000003oool000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0oooo<P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0
00000?ooo`0000001@3oool010000000oooo0?ooo`0000030?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`00
00001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo=03oool01`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000001`3oool00`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooolf0?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo=P3oool01@000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000050?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000@0oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo>03o
ool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`050000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooocX0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000001@3oool02P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`0000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooolm0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000001@3oool01@00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooocd0oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`05
0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooocl0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?oood40oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`05
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00L000000?ooo`000000
oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oood<0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool030000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`080000003oool0oooo
0000003oool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3ooom50?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0ooooA`3oool00`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0ooooA`3oool00`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000D0
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooC03oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000002P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?oood`0oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000003
0?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000090?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooom>0?ooo`0=0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom@
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00H0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo
00020?ooo`@000001P3oool2000000H0oooo1000000@0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?oooe00oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000060?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo00000`3oool0
00000?ooo`030?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomB0?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`030000003oool0oooo00D0oooo00000`3oool000000?ooo`030?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?oooe@0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool01@3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo1`00003o0?ooool0oooo
o`3ooomB0?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001@3oool00`000000oooo
0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo00000`3oool000000?ooo`03
0?ooo`030000003oool0oooo00/0oooo1000000@0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?oooeH0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001@3oool02P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`0000070?ooo`0000<0oooo0000003oool00`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomH0?ooo`030000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00X0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool01@000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo
00000`3oool000000?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooeX0oooo0180
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00L000000?ooo`000000oooo
0000003oool0000000L0oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooed0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01@000000oooo0000003oool0000000L0oooo00020?ooo`@000003P3oool400000100oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooG`3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`0000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomQ
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooH@3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool00000103oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`3oool0oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?oo
o`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooooH`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`3oool01@3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomU0?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`050000003oool000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooomU0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooooI`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool00000103oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooJ@3oool0
0`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000D0oooo00@000000?ooo`3oool000000`3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`0000001P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooJ`3oool04000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000
003oool0000000L0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`070000003oool000000?ooo`000000oooo
000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom^0?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool00000103oool01`000000oooo0000003oool000000?ooo`0000001@3oool0
0`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom`0?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000
oooo000000030?ooo`030000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooog00oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000030?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomb
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00060?ooo`030000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooog@0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000050?ooo`0@0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool040000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103o
ool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooogH0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo
00D000000?ooo`000000oooo000000070?ooo`0B0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooogP0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomh0?ooo`03
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000001P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0
000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooogX0oooo018000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000001P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`0000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomm0?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooogl0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool00000103oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooO`3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooh<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooon30?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01`000000oooo0000
003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00D000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooon50?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
00070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon70?ooo`050000003oool0
oooo0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooQ`3oool0
1@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooohT0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool01@000000oooo0000003oool0000000@0oooo00d000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000L0oooo000X0?ooo`D00000o`3ooooo0?ooool0ooooR@3oool040000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00@00000
0?ooo`3oool000001@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon>0?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000103o
ool00`000000oooo0?ooo`030?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`05
0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
ooooT03oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool00`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00001P3oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?oooi00oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`000000oooo
000000040?ooo`030000003oool0000000D0oooo00<000000?ooo`000000103oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooooU03oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000002@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooU03oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool00000
0?ooo`0000001P3oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?oooiH0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?oooiP0oooo00<000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool00000
1@3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo000000090?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonH0?ooo`030000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
1`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooW@3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000001@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?oooid0oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool010000000
oooo0?ooo`0000030?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooW`3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo
0000003oool00000403oool01@000000oooo0000003oool0000000@0oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000
oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooj40
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000
003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooonQ0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000T0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooojD0oooo00L000000?ooo`3oool0oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000001`3oool04P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooooY@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonW0?ooo`050000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooZ@3oool00`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000060?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooonY0?ooo`030000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080
oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
2`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?oo
o`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooZ`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000L0oooo00<0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooojh0oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?oook00oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000030?oo
o`030000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oook80oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3o
ool01@000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000001@3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0
oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oook@0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000050?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooond
0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool00`00
0000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooonf0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonh
0?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`000000103oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000007
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonj0?ooo`030000003oool00000
0080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooo_03oool030000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00050?ooo`060000003oool0oooo0000003oool000000`3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00H0oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000090?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooonl0?ooo`060000003oool0oooo0000003oool000000`3oool0
1@000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo_`3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000002P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0
oooo000000090?ooo`00:03oool500000?l0ooooo`3ooooo0?oool40oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000050?oo
o`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?oo
o`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3oooo30?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo5
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000080?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo50?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00/0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooolT0oooo00<000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo000000040?ooo`050000
003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
b`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool01`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0oooob`3oool020000000oooo0?ooo`000000oooo0000003oool00000
0`3oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000L0oooo00D00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo>0?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000D0oooo00D000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0oooocP3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooom00oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooom80oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooom@0
oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooomH0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003o
ool000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
0`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooF0?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000
oooo000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`0000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooH0?oo
o`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000080?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000X0oooo00L0
00000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooomX0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001`3oool0
1@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooofP3oool00`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00D000000?ooo`000000oooo000000090?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooooL0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool0
00000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooog`3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00080?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooh`3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`040?oo
o`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooooh`3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00D000000?oo
o`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooonD0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooooi@3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooonL0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooonT0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool0
1@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000001P3oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooon/0oooo00<000000?ooo`3oool00P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3oooo`0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooob0?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
oo80oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooolP3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000009
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooood0?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooon03oool01@000000oooo0?ooo`3o
ool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool000000080oooo
00D000000?ooo`000000oooo000000090?ooo`00:03oool500000?l0ooooo`3ooooo0?oooo@0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooooP0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooooX0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o03oool010000000oooo0?ooo`0000030?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo000000060?ooo`030000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooool0oooo0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooo`80oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000001@3oool020000000oooo0?ooo`000000oooo
0000003oool000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool2
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
ool0oooo1P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3oool60?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooooo0?ooo`P0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3ooooo0?ooo`P0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`00
00030?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooo`3oool:0?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo
000000050?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo303oool00`000000
oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool>0?ooo`0B0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
0`000000oooo000000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooool0oooo4@3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000001`3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolC0?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000
oooo000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo4`3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
ooooo`3ooolE0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooool0oooo5`3oool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooooo0?oooaT0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo
0?oooaT0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oooo0?oooa/0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolM0?ooo`030000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo7@3oool00`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooooo`3ooolR0?ooo`070000003oool0oooo0?ooo`000000oooo000000070?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooob80oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooooo0?ooob@0oooo00D000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooooo0?ooobH0oooo00<000000?ooo`0000001`3oool001<0oooo1`00
000>0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo:03oool00`000000oooo0?oo
o`050?ooo`005P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooool0oooo:03oool00`000000oooo0?ooo`050?ooo`005P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool001H0oooo00<000000?ooo`3o
ool03`3oool700000?l0ooooo`3ooooo0?ooool0oooo;03oool001H0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000F0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`005P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool0
01@0oooo0`00000A0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool001H0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
ool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oo
oc00oooo003o0?ooool0ooooo`3ooooo0?oooe/0oooo003o0?ooool0ooooo`3ooooo0?oooe/0oooo
003o0?ooool0ooooo`3ooooo0?oooe/0oooo003o0?ooool0ooooo`3ooooo0?oooe/0oooo003o0?oo
ool0ooooo`3ooooo0?oooe/0oooo003o0?ooool0ooooo`3ooooo0?oooe/0oooo003o0?ooool0oooo
o`3ooooo0?oooe/0oooo003o0?ooool0ooooo`3ooooo0?oooe/0oooo0000\
\>"],
  ImageRangeCache->{{{0, 1110.13}, {685.688, 0}} -> {-0.0378501, -0.055521, \
0.00140806, 0.00238669}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BifuractionDiagram[SinMap[r], \ {r, 0, 1}];\)\)], "Input",
  CellLabel->"In[51]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.0147151 0.588628 [
[.2 .00222 -9 -9 ]
[.2 .00222 9 0 ]
[.4 .00222 -9 -9 ]
[.4 .00222 9 0 ]
[.6 .00222 -9 -9 ]
[.6 .00222 9 0 ]
[.8 .00222 -9 -9 ]
[.8 .00222 9 0 ]
[1 .00222 -3 -9 ]
[1 .00222 3 0 ]
[-0.0125 .13244 -18 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .25017 -18 -4.5 ]
[-0.0125 .25017 0 4.5 ]
[-0.0125 .36789 -18 -4.5 ]
[-0.0125 .36789 0 4.5 ]
[-0.0125 .48562 -18 -4.5 ]
[-0.0125 .48562 0 4.5 ]
[-0.0125 .60334 -6 -4.5 ]
[-0.0125 .60334 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .01472 m
.2 .02097 L
s
[(0.2)] .2 .00222 0 1 Mshowa
.4 .01472 m
.4 .02097 L
s
[(0.4)] .4 .00222 0 1 Mshowa
.6 .01472 m
.6 .02097 L
s
[(0.6)] .6 .00222 0 1 Mshowa
.8 .01472 m
.8 .02097 L
s
[(0.8)] .8 .00222 0 1 Mshowa
1 .01472 m
1 .02097 L
s
[(1)] 1 .00222 0 1 Mshowa
.125 Mabswid
.05 .01472 m
.05 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.15 .01472 m
.15 .01847 L
s
.25 .01472 m
.25 .01847 L
s
.3 .01472 m
.3 .01847 L
s
.35 .01472 m
.35 .01847 L
s
.45 .01472 m
.45 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.55 .01472 m
.55 .01847 L
s
.65 .01472 m
.65 .01847 L
s
.7 .01472 m
.7 .01847 L
s
.75 .01472 m
.75 .01847 L
s
.85 .01472 m
.85 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.95 .01472 m
.95 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
0 .13244 m
.00625 .13244 L
s
[(0.2)] -0.0125 .13244 1 0 Mshowa
0 .25017 m
.00625 .25017 L
s
[(0.4)] -0.0125 .25017 1 0 Mshowa
0 .36789 m
.00625 .36789 L
s
[(0.6)] -0.0125 .36789 1 0 Mshowa
0 .48562 m
.00625 .48562 L
s
[(0.8)] -0.0125 .48562 1 0 Mshowa
0 .60334 m
.00625 .60334 L
s
[(1)] -0.0125 .60334 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .2796 m
.00375 .2796 L
s
0 .30903 m
.00375 .30903 L
s
0 .33846 m
.00375 .33846 L
s
0 .39732 m
.00375 .39732 L
s
0 .42675 m
.00375 .42675 L
s
0 .45619 m
.00375 .45619 L
s
0 .51505 m
.00375 .51505 L
s
0 .54448 m
.00375 .54448 L
s
0 .57391 m
.00375 .57391 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
0 .01472 Mdot
.002 .01472 Mdot
.004 .01472 Mdot
.006 .01472 Mdot
.008 .01472 Mdot
.01 .01472 Mdot
.012 .01472 Mdot
.014 .01472 Mdot
.016 .01472 Mdot
.018 .01472 Mdot
.02 .01472 Mdot
.022 .01472 Mdot
.024 .01472 Mdot
.026 .01472 Mdot
.028 .01472 Mdot
.03 .01472 Mdot
.032 .01472 Mdot
.034 .01472 Mdot
.036 .01472 Mdot
.038 .01472 Mdot
.04 .01472 Mdot
.042 .01472 Mdot
.044 .01472 Mdot
.046 .01472 Mdot
.048 .01472 Mdot
.05 .01472 Mdot
.052 .01472 Mdot
.054 .01472 Mdot
.056 .01472 Mdot
.058 .01472 Mdot
.06 .01472 Mdot
.062 .01472 Mdot
.064 .01472 Mdot
.066 .01472 Mdot
.068 .01472 Mdot
.07 .01472 Mdot
.072 .01472 Mdot
.074 .01472 Mdot
.076 .01472 Mdot
.078 .01472 Mdot
.08 .01472 Mdot
.082 .01472 Mdot
.084 .01472 Mdot
.086 .01472 Mdot
.088 .01472 Mdot
.09 .01472 Mdot
.092 .01472 Mdot
.094 .01472 Mdot
.096 .01472 Mdot
.098 .01472 Mdot
.1 .01472 Mdot
.102 .01472 Mdot
.104 .01472 Mdot
.106 .01472 Mdot
.108 .01472 Mdot
.11 .01472 Mdot
.112 .01472 Mdot
.114 .01472 Mdot
.116 .01472 Mdot
.118 .01472 Mdot
.12 .01472 Mdot
.122 .01472 Mdot
.124 .01472 Mdot
.126 .01472 Mdot
.128 .01472 Mdot
.13 .01472 Mdot
.132 .01472 Mdot
.134 .01472 Mdot
.136 .01472 Mdot
.138 .01472 Mdot
.14 .01472 Mdot
.142 .01472 Mdot
.144 .01472 Mdot
.146 .01472 Mdot
.148 .01472 Mdot
.15 .01472 Mdot
.152 .01472 Mdot
.154 .01472 Mdot
.156 .01472 Mdot
.158 .01472 Mdot
.16 .01472 Mdot
.162 .01472 Mdot
.164 .01472 Mdot
.166 .01472 Mdot
.168 .01472 Mdot
.17 .01472 Mdot
.172 .01472 Mdot
.174 .01472 Mdot
.176 .01472 Mdot
.178 .01472 Mdot
.18 .01472 Mdot
.182 .01472 Mdot
.184 .01472 Mdot
.186 .01472 Mdot
.188 .01472 Mdot
.19 .01472 Mdot
.192 .01472 Mdot
.194 .01472 Mdot
.196 .01472 Mdot
.198 .01472 Mdot
.2 .01472 Mdot
.202 .01472 Mdot
.204 .01472 Mdot
.206 .01472 Mdot
.208 .01472 Mdot
.21 .01472 Mdot
.212 .01472 Mdot
.214 .01472 Mdot
.216 .01472 Mdot
.218 .01472 Mdot
.22 .01472 Mdot
.222 .01472 Mdot
.224 .01472 Mdot
.226 .01472 Mdot
.228 .01472 Mdot
.23 .01472 Mdot
.232 .01472 Mdot
.234 .01472 Mdot
.236 .01472 Mdot
.238 .01472 Mdot
.24 .01472 Mdot
.242 .01472 Mdot
.244 .01472 Mdot
.246 .01472 Mdot
.248 .01472 Mdot
.25 .01472 Mdot
.252 .01472 Mdot
.254 .01472 Mdot
.256 .01472 Mdot
.258 .01472 Mdot
.26 .01472 Mdot
.262 .01472 Mdot
.264 .01472 Mdot
.266 .01472 Mdot
.268 .01472 Mdot
.27 .01472 Mdot
.272 .01472 Mdot
.274 .01472 Mdot
.276 .01472 Mdot
.278 .01472 Mdot
.28 .01472 Mdot
.282 .01472 Mdot
.284 .01472 Mdot
.286 .01472 Mdot
.288 .01472 Mdot
.29 .01472 Mdot
.292 .01472 Mdot
.294 .01472 Mdot
.296 .01472 Mdot
.298 .01472 Mdot
.3 .01472 Mdot
.302 .01472 Mdot
.304 .01472 Mdot
.306 .01472 Mdot
.308 .01472 Mdot
.31 .01472 Mdot
.312 .01472 Mdot
.314 .01472 Mdot
.316 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.318 .01472 Mdot
.32 .0481 Mdot
.322 .06393 Mdot
.324 .0757 Mdot
.326 .08546 Mdot
.328 .09395 Mdot
.33 .10156 Mdot
.332 .1085 Mdot
.334 .1149 Mdot
.336 .12087 Mdot
.338 .12648 Mdot
.34 .13177 Mdot
.342 .1368 Mdot
.344 .14158 Mdot
.346 .14616 Mdot
.348 .15054 Mdot
.35 .15476 Mdot
.352 .15882 Mdot
.354 .16273 Mdot
.356 .16652 Mdot
.358 .17019 Mdot
.36 .17374 Mdot
.362 .17719 Mdot
.364 .18054 Mdot
.366 .18379 Mdot
.368 .18697 Mdot
.37 .19006 Mdot
.372 .19307 Mdot
.374 .19601 Mdot
.376 .19889 Mdot
.378 .2017 Mdot
.38 .20444 Mdot
.382 .20713 Mdot
.384 .20976 Mdot
.386 .21233 Mdot
.388 .21486 Mdot
.39 .21733 Mdot
.392 .21976 Mdot
.394 .22214 Mdot
.396 .22448 Mdot
.398 .22677 Mdot
.4 .22903 Mdot
.402 .23124 Mdot
.404 .23342 Mdot
.406 .23556 Mdot
.408 .23766 Mdot
.41 .23974 Mdot
.412 .24177 Mdot
.414 .24378 Mdot
.416 .24575 Mdot
.418 .2477 Mdot
.42 .24961 Mdot
.422 .2515 Mdot
.424 .25336 Mdot
.426 .25519 Mdot
.428 .25699 Mdot
.43 .25878 Mdot
.432 .26053 Mdot
.434 .26226 Mdot
.436 .26397 Mdot
.438 .26566 Mdot
.44 .26732 Mdot
.442 .26896 Mdot
.444 .27058 Mdot
.446 .27218 Mdot
.448 .27376 Mdot
.45 .27532 Mdot
.452 .27686 Mdot
.454 .27839 Mdot
.456 .27989 Mdot
.458 .28138 Mdot
.46 .28284 Mdot
.462 .2843 Mdot
.464 .28573 Mdot
.466 .28715 Mdot
.468 .28855 Mdot
.47 .28993 Mdot
.472 .29131 Mdot
.474 .29266 Mdot
.476 .294 Mdot
.478 .29533 Mdot
.48 .29664 Mdot
.482 .29794 Mdot
.484 .29922 Mdot
.486 .30049 Mdot
.488 .30175 Mdot
.49 .30299 Mdot
.492 .30422 Mdot
.494 .30544 Mdot
.496 .30665 Mdot
.498 .30785 Mdot
.5 .30903 Mdot
.502 .3102 Mdot
.504 .31136 Mdot
.506 .31251 Mdot
.508 .31365 Mdot
.51 .31477 Mdot
.512 .31589 Mdot
.514 .317 Mdot
.516 .31809 Mdot
.518 .31918 Mdot
.52 .32025 Mdot
.522 .32132 Mdot
.524 .32237 Mdot
.526 .32342 Mdot
.528 .32446 Mdot
.53 .32549 Mdot
.532 .3265 Mdot
.534 .32751 Mdot
.536 .32851 Mdot
.538 .32951 Mdot
.54 .33049 Mdot
.542 .33147 Mdot
.544 .33243 Mdot
.546 .33339 Mdot
.548 .33434 Mdot
.55 .33529 Mdot
.552 .33622 Mdot
.554 .33715 Mdot
.556 .33807 Mdot
.558 .33898 Mdot
.56 .33989 Mdot
.562 .34078 Mdot
.564 .34167 Mdot
.566 .34256 Mdot
.568 .34343 Mdot
.57 .3443 Mdot
.572 .34517 Mdot
.574 .34602 Mdot
.576 .34687 Mdot
.578 .34772 Mdot
.58 .34855 Mdot
.582 .34938 Mdot
.584 .35021 Mdot
.586 .35102 Mdot
.588 .35183 Mdot
.59 .35264 Mdot
.592 .35344 Mdot
.594 .35423 Mdot
.596 .35502 Mdot
.598 .3558 Mdot
.6 .35658 Mdot
.602 .35735 Mdot
.604 .35812 Mdot
.606 .35887 Mdot
.608 .35963 Mdot
.61 .36038 Mdot
.612 .36112 Mdot
.614 .36186 Mdot
.616 .36259 Mdot
.618 .36332 Mdot
.62 .36404 Mdot
.622 .36476 Mdot
.624 .36548 Mdot
.626 .36618 Mdot
.628 .36689 Mdot
.63 .36759 Mdot
.632 .36828 Mdot
.634 .36897 Mdot
.636 .36965 Mdot
.638 .37034 Mdot
.64 .37101 Mdot
.642 .37168 Mdot
.644 .37235 Mdot
.646 .37301 Mdot
.648 .37367 Mdot
.65 .37432 Mdot
.652 .37497 Mdot
.654 .37562 Mdot
.656 .37626 Mdot
.658 .3769 Mdot
.66 .37753 Mdot
.662 .37816 Mdot
.664 .37879 Mdot
.666 .37941 Mdot
.668 .38003 Mdot
.67 .38064 Mdot
.672 .38125 Mdot
.674 .38186 Mdot
.676 .38246 Mdot
.678 .38306 Mdot
.68 .38365 Mdot
.682 .38424 Mdot
.684 .38483 Mdot
.686 .38542 Mdot
.688 .386 Mdot
.69 .38658 Mdot
.692 .38715 Mdot
.694 .38772 Mdot
.696 .38829 Mdot
.698 .38885 Mdot
.7 .38941 Mdot
.702 .38997 Mdot
.704 .39052 Mdot
.706 .39108 Mdot
.708 .39162 Mdot
.71 .39217 Mdot
.712 .39271 Mdot
.714 .39325 Mdot
.716 .39378 Mdot
.718 .39432 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .3926 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39261 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39262 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39705 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.72 .39706 Mdot
.722 .37876 Mdot
.722 .41061 Mdot
.724 .37216 Mdot
.724 .41692 Mdot
.726 .36706 Mdot
.726 .42172 Mdot
.728 .36276 Mdot
.728 .42574 Mdot
.73 .35896 Mdot
.73 .42925 Mdot
.732 .35552 Mdot
.732 .43239 Mdot
.734 .35236 Mdot
.734 .43526 Mdot
.736 .34942 Mdot
.736 .43792 Mdot
.738 .34666 Mdot
.738 .44039 Mdot
.74 .34406 Mdot
.74 .44271 Mdot
.742 .34158 Mdot
.742 .4449 Mdot
.744 .33922 Mdot
.744 .44698 Mdot
.746 .33695 Mdot
.746 .44896 Mdot
.748 .33477 Mdot
.748 .45086 Mdot
.75 .33268 Mdot
.75 .45267 Mdot
.752 .33065 Mdot
.752 .45442 Mdot
.754 .32869 Mdot
.754 .4561 Mdot
.756 .32679 Mdot
.756 .45772 Mdot
.758 .32495 Mdot
.758 .45928 Mdot
.76 .32316 Mdot
.76 .4608 Mdot
.762 .32141 Mdot
.762 .46227 Mdot
.764 .31971 Mdot
.764 .4637 Mdot
.766 .31805 Mdot
.766 .46508 Mdot
.768 .31643 Mdot
.768 .46643 Mdot
.77 .31485 Mdot
.77 .46774 Mdot
.772 .3133 Mdot
.772 .46902 Mdot
.774 .31178 Mdot
.774 .47026 Mdot
.776 .31029 Mdot
.776 .47148 Mdot
.778 .30884 Mdot
.778 .47267 Mdot
.78 .30741 Mdot
.78 .47383 Mdot
.782 .30601 Mdot
.782 .47496 Mdot
.784 .30463 Mdot
.784 .47607 Mdot
.786 .30328 Mdot
.786 .47716 Mdot
.788 .30195 Mdot
.788 .47822 Mdot
.79 .30064 Mdot
.79 .47926 Mdot
.792 .29935 Mdot
.792 .48029 Mdot
.794 .29809 Mdot
.794 .48129 Mdot
.796 .29684 Mdot
.796 .48227 Mdot
.798 .29562 Mdot
.798 .48324 Mdot
.8 .29441 Mdot
.8 .48418 Mdot
.802 .29322 Mdot
.802 .48511 Mdot
.804 .29205 Mdot
.804 .48603 Mdot
.806 .29089 Mdot
.806 .48693 Mdot
.808 .28975 Mdot
.808 .48781 Mdot
.81 .28862 Mdot
.81 .48868 Mdot
.812 .28751 Mdot
.812 .48953 Mdot
.814 .28642 Mdot
.814 .49037 Mdot
.816 .28534 Mdot
.816 .4912 Mdot
.818 .28427 Mdot
.818 .49201 Mdot
.82 .28322 Mdot
.82 .49282 Mdot
.822 .28217 Mdot
.822 .49361 Mdot
.824 .28114 Mdot
.824 .49438 Mdot
.826 .28013 Mdot
.826 .49515 Mdot
.828 .27912 Mdot
.828 .4959 Mdot
.83 .27813 Mdot
.83 .49665 Mdot
.832 .27715 Mdot
.832 .49738 Mdot
.834 .26907 Mdot
.834 .28411 Mdot
.834 .49451 Mdot
.834 .50129 Mdot
.836 .26224 Mdot
.836 .29123 Mdot
.836 .49154 Mdot
.836 .50459 Mdot
.838 .25783 Mdot
.838 .29593 Mdot
.838 .48968 Mdot
.838 .50678 Mdot
.84 .25433 Mdot
.84 .29972 Mdot
.84 .48824 Mdot
.84 .50855 Mdot
.842 .25135 Mdot
.842 .30298 Mdot
.842 .48704 Mdot
.842 .51008 Mdot
.844 .24872 Mdot
.844 .30589 Mdot
.844 .48601 Mdot
.844 .51145 Mdot
.846 .24635 Mdot
.846 .30855 Mdot
.846 .48509 Mdot
.846 .51269 Mdot
.848 .24418 Mdot
.848 .311 Mdot
.848 .48427 Mdot
.848 .51384 Mdot
.85 .24217 Mdot
.85 .31329 Mdot
.85 .48353 Mdot
.85 .51492 Mdot
.852 .24029 Mdot
.852 .31545 Mdot
.852 .48285 Mdot
.852 .51593 Mdot
.854 .23852 Mdot
.854 .3175 Mdot
.854 .48223 Mdot
.854 .51689 Mdot
.856 .23684 Mdot
.856 .31945 Mdot
.856 .48165 Mdot
.856 .5178 Mdot
.858 .23525 Mdot
.858 .32131 Mdot
.858 .48111 Mdot
.858 .51867 Mdot
.86 .23052 Mdot
.86 .23831 Mdot
.86 .31294 Mdot
.86 .33047 Mdot
.86 .47715 Mdot
.86 .48531 Mdot
.86 .51762 Mdot
.86 .52082 Mdot
.862 .22789 Mdot
.862 .23988 Mdot
.862 .30782 Mdot
.862 .33515 Mdot
.862 .47528 Mdot
.862 .48795 Mdot
.862 .51719 Mdot
.862 .5221 Mdot
.864 .2259 Mdot
.864 .24081 Mdot
.864 .30405 Mdot
.864 .33847 Mdot
.864 .47405 Mdot
.864 .48995 Mdot
.864 .51703 Mdot
.864 .52311 Mdot
.866 .22302 Mdot
.866 .22305 Mdot
.866 .22324 Mdot
.866 .22359 Mdot
.866 .22366 Mdot
.866 .22383 Mdot
.866 .22445 Mdot
.866 .22457 Mdot
.866 .22499 Mdot
.866 .2254 Mdot
.866 .22559 Mdot
.866 .22662 Mdot
.866 .22727 Mdot
.866 .22734 Mdot
.866 .2337 Mdot
.866 .23386 Mdot
.866 .23529 Mdot
.866 .23775 Mdot
.866 .23823 Mdot
.866 .23929 Mdot
.866 .24043 Mdot
.866 .24076 Mdot
.866 .24251 Mdot
.866 .243 Mdot
.866 .24321 Mdot
.866 .24426 Mdot
.866 .24484 Mdot
.866 .24491 Mdot
.866 .29353 Mdot
.866 .29367 Mdot
.866 .29489 Mdot
.866 .29709 Mdot
.866 .29755 Mdot
.866 .29858 Mdot
.866 .30236 Mdot
.866 .30309 Mdot
.866 .30559 Mdot
.866 .30794 Mdot
.866 .30902 Mdot
.866 .31461 Mdot
.866 .31791 Mdot
.866 .31828 Mdot
.866 .33344 Mdot
.866 .33363 Mdot
.866 .33521 Mdot
.866 .33774 Mdot
.866 .33821 Mdot
.866 .33922 Mdot
.866 .34027 Mdot
.866 .34057 Mdot
.866 .34211 Mdot
.866 .34253 Mdot
.866 .34271 Mdot
.866 .34358 Mdot
.866 .34406 Mdot
.866 .34411 Mdot
.866 .4717 Mdot
.866 .47173 Mdot
.866 .47196 Mdot
.866 .47238 Mdot
.866 .47246 Mdot
.866 .47266 Mdot
.866 .4734 Mdot
.866 .47355 Mdot
.866 .47405 Mdot
.866 .47453 Mdot
.866 .47475 Mdot
.866 .47595 Mdot
.866 .4767 Mdot
.866 .47678 Mdot
.866 .48382 Mdot
.866 .48399 Mdot
.866 .48549 Mdot
.866 .48802 Mdot
.866 .48851 Mdot
.866 .48956 Mdot
.866 .49068 Mdot
.866 .491 Mdot
.866 .49268 Mdot
.866 .49314 Mdot
.866 .49334 Mdot
.866 .49431 Mdot
.866 .49485 Mdot
.866 .49491 Mdot
.866 .51556 Mdot
.866 .51558 Mdot
.866 .51582 Mdot
.866 .51625 Mdot
.866 .51634 Mdot
.866 .51654 Mdot
.866 .51726 Mdot
.866 .5174 Mdot
.866 .51786 Mdot
.866 .5183 Mdot
.866 .51849 Mdot
.866 .5195 Mdot
.866 .52008 Mdot
.866 .52015 Mdot
.866 .52272 Mdot
.866 .52275 Mdot
.866 .52302 Mdot
.866 .52343 Mdot
.866 .52351 Mdot
.866 .52367 Mdot
.866 .52384 Mdot
.866 .52389 Mdot
.866 .52414 Mdot
.866 .52421 Mdot
.866 .52424 Mdot
.866 .52438 Mdot
.866 .52446 Mdot
.866 .52447 Mdot
.868 .22057 Mdot
.868 .22057 Mdot
.868 .22058 Mdot
.868 .22058 Mdot
.868 .22058 Mdot
.868 .22058 Mdot
.868 .22058 Mdot
.868 .22059 Mdot
.868 .2206 Mdot
.868 .22061 Mdot
.868 .22062 Mdot
.868 .22063 Mdot
.868 .22064 Mdot
.868 .22066 Mdot
.868 .22067 Mdot
.868 .22073 Mdot
.868 .2208 Mdot
.868 .22082 Mdot
.868 .22083 Mdot
.868 .22088 Mdot
.868 .22092 Mdot
.868 .22098 Mdot
.868 .22114 Mdot
.868 .22124 Mdot
.868 .22127 Mdot
.868 .22129 Mdot
.868 .2213 Mdot
.868 .22138 Mdot
.868 .2216 Mdot
.868 .22173 Mdot
.868 .22189 Mdot
.868 .2221 Mdot
.868 .2221 Mdot
.868 .22214 Mdot
.868 .22219 Mdot
.868 .22219 Mdot
.868 .22224 Mdot
.868 .22226 Mdot
.868 .22227 Mdot
.868 .22233 Mdot
.868 .22234 Mdot
.868 .22245 Mdot
.868 .22246 Mdot
.868 .22261 Mdot
.868 .22262 Mdot
.868 .22263 Mdot
.868 .22264 Mdot
.868 .22264 Mdot
.868 .22264 Mdot
.868 .22264 Mdot
.868 .22265 Mdot
.868 .22273 Mdot
.868 .2228 Mdot
.868 .22281 Mdot
.868 .22286 Mdot
.868 .22288 Mdot
.868 .22288 Mdot
.868 .22289 Mdot
.868 .22292 Mdot
.868 .22292 Mdot
.868 .22294 Mdot
.868 .22296 Mdot
.868 .22296 Mdot
.868 .22306 Mdot
.868 .22313 Mdot
.868 .22321 Mdot
.868 .22339 Mdot
.868 .22341 Mdot
.868 .22343 Mdot
.868 .22364 Mdot
.868 .22369 Mdot
.868 .22379 Mdot
.868 .22383 Mdot
.868 .22402 Mdot
.868 .22404 Mdot
.868 .22411 Mdot
.868 .22412 Mdot
.868 .22422 Mdot
.868 .2243 Mdot
.868 .2243 Mdot
.868 .2243 Mdot
.868 .2243 Mdot
.868 .22433 Mdot
.868 .22444 Mdot
.868 .22447 Mdot
.868 .22461 Mdot
.868 .22461 Mdot
.868 .22472 Mdot
.868 .22488 Mdot
.868 .22501 Mdot
.868 .22507 Mdot
.868 .22533 Mdot
.868 .22545 Mdot
.868 .22552 Mdot
.868 .22609 Mdot
.868 .22658 Mdot
.868 .2267 Mdot
.868 .22691 Mdot
.868 .22694 Mdot
.868 .22699 Mdot
.868 .22716 Mdot
.868 .2272 Mdot
.868 .22731 Mdot
.868 .22773 Mdot
.868 .22784 Mdot
.868 .22787 Mdot
.868 .22793 Mdot
.868 .22797 Mdot
.868 .22813 Mdot
.868 .22816 Mdot
.868 .22817 Mdot
.868 .22822 Mdot
.868 .22831 Mdot
.868 .22833 Mdot
.868 .22842 Mdot
.868 .22844 Mdot
.868 .22848 Mdot
.868 .22849 Mdot
.868 .2288 Mdot
.868 .22886 Mdot
.868 .22899 Mdot
.868 .22902 Mdot
.868 .22904 Mdot
.868 .22925 Mdot
.868 .22994 Mdot
.868 .23007 Mdot
.868 .23026 Mdot
.868 .23031 Mdot
.868 .2304 Mdot
.868 .23052 Mdot
.868 .23074 Mdot
.868 .23083 Mdot
.868 .23085 Mdot
.868 .23085 Mdot
.868 .23091 Mdot
.868 .23099 Mdot
.868 .23136 Mdot
.868 .2314 Mdot
.868 .23163 Mdot
.868 .2318 Mdot
.868 .23188 Mdot
.868 .23195 Mdot
.868 .23205 Mdot
.868 .23209 Mdot
.868 .23221 Mdot
.868 .23221 Mdot
.868 .23229 Mdot
.868 .23238 Mdot
.868 .23239 Mdot
.868 .23239 Mdot
.868 .23239 Mdot
.868 .2324 Mdot
.868 .23241 Mdot
.868 .23241 Mdot
.868 .23273 Mdot
.868 .23408 Mdot
.868 .23425 Mdot
.868 .23455 Mdot
.868 .23519 Mdot
.868 .23536 Mdot
.868 .23568 Mdot
.868 .2361 Mdot
.868 .23638 Mdot
.868 .23638 Mdot
.868 .23676 Mdot
.868 .23684 Mdot
.868 .23714 Mdot
.868 .23721 Mdot
.868 .23722 Mdot
.868 .23722 Mdot
.868 .23723 Mdot
.868 .23744 Mdot
.868 .23771 Mdot
.868 .23775 Mdot
.868 .23793 Mdot
.868 .23799 Mdot
.868 .23853 Mdot
.868 .23862 Mdot
.868 .23891 Mdot
.868 .23906 Mdot
.868 .23967 Mdot
.868 .23973 Mdot
.868 .23979 Mdot
.868 .24032 Mdot
.868 .24054 Mdot
.868 .24077 Mdot
.868 .24108 Mdot
.868 .24108 Mdot
.868 .24113 Mdot
.868 .2412 Mdot
.868 .2412 Mdot
.868 .24127 Mdot
.868 .24129 Mdot
.868 .2413 Mdot
.868 .24138 Mdot
.868 .24154 Mdot
.868 .24154 Mdot
.868 .24178 Mdot
.868 .24202 Mdot
.868 .24205 Mdot
.868 .24205 Mdot
.868 .24206 Mdot
.868 .24206 Mdot
.868 .24208 Mdot
.868 .24211 Mdot
.868 .24213 Mdot
.868 .24261 Mdot
.868 .24264 Mdot
.868 .243 Mdot
.868 .24303 Mdot
.868 .24321 Mdot
.868 .24323 Mdot
.868 .24329 Mdot
.868 .24347 Mdot
.868 .24347 Mdot
.868 .24362 Mdot
.868 .24375 Mdot
.868 .24375 Mdot
.868 .24444 Mdot
.868 .24494 Mdot
.868 .2454 Mdot
.868 .24572 Mdot
.868 .24611 Mdot
.868 .2464 Mdot
.868 .24644 Mdot
.868 .2465 Mdot
.868 .24661 Mdot
.868 .24695 Mdot
.868 .24752 Mdot
.868 .24771 Mdot
.868 .24786 Mdot
.868 .24804 Mdot
.868 .24806 Mdot
.868 .24814 Mdot
.868 .24837 Mdot
.868 .2486 Mdot
.868 .24864 Mdot
.868 .24868 Mdot
.868 .24874 Mdot
.868 .24876 Mdot
.868 .24882 Mdot
.868 .24882 Mdot
.868 .24887 Mdot
.868 .24892 Mdot
.868 .24892 Mdot
.868 .24892 Mdot
.868 .24892 Mdot
.868 .24893 Mdot
.868 .24893 Mdot
.868 .24894 Mdot
.868 .2834 Mdot
.868 .28341 Mdot
.868 .28342 Mdot
.868 .28343 Mdot
.868 .28343 Mdot
.868 .28343 Mdot
.868 .28343 Mdot
.868 .28354 Mdot
.868 .28362 Mdot
.868 .28363 Mdot
.868 .28375 Mdot
.868 .2838 Mdot
.868 .28391 Mdot
.868 .28399 Mdot
.868 .28407 Mdot
.868 .28452 Mdot
.868 .285 Mdot
.868 .28516 Mdot
.868 .28519 Mdot
.868 .28555 Mdot
.868 .28587 Mdot
.868 .28625 Mdot
.868 .2874 Mdot
.868 .28811 Mdot
.868 .28834 Mdot
.868 .28846 Mdot
.868 .28854 Mdot
.868 .28913 Mdot
.868 .28995 Mdot
.868 .29062 Mdot
.868 .29157 Mdot
.868 .29262 Mdot
.868 .29409 Mdot
.868 .29409 Mdot
.868 .29436 Mdot
.868 .29468 Mdot
.868 .29469 Mdot
.868 .29507 Mdot
.868 .29519 Mdot
.868 .29523 Mdot
.868 .29563 Mdot
.868 .2957 Mdot
.868 .29647 Mdot
.868 .29652 Mdot
.868 .29756 Mdot
.868 .29761 Mdot
.868 .29766 Mdot
.868 .29772 Mdot
.868 .29772 Mdot
.868 .29774 Mdot
.868 .29774 Mdot
.868 .2978 Mdot
.868 .29833 Mdot
.868 .29883 Mdot
.868 .29885 Mdot
.868 .29919 Mdot
.868 .29936 Mdot
.868 .29938 Mdot
.868 .29943 Mdot
.868 .29959 Mdot
.868 .29959 Mdot
.868 .29973 Mdot
.868 .29985 Mdot
.868 .29985 Mdot
.868 .30052 Mdot
.868 .30102 Mdot
.868 .30151 Mdot
.868 .30269 Mdot
.868 .30282 Mdot
.868 .30296 Mdot
.868 .30431 Mdot
.868 .30464 Mdot
.868 .30529 Mdot
.868 .3055 Mdot
.868 .30673 Mdot
.868 .30687 Mdot
.868 .30725 Mdot
.868 .30735 Mdot
.868 .30796 Mdot
.868 .30845 Mdot
.868 .30845 Mdot
.868 .30847 Mdot
.868 .30848 Mdot
.868 .30864 Mdot
.868 .30934 Mdot
.868 .3095 Mdot
.868 .31038 Mdot
.868 .31039 Mdot
.868 .31104 Mdot
.868 .312 Mdot
.868 .31274 Mdot
.868 .31313 Mdot
.868 .31462 Mdot
.868 .31531 Mdot
.868 .31572 Mdot
.868 .31889 Mdot
.868 .31964 Mdot
.868 .31965 Mdot
.868 .31967 Mdot
.868 .3197 Mdot
.868 .3197 Mdot
.868 .3197 Mdot
.868 .31971 Mdot
.868 .31993 Mdot
.868 .32012 Mdot
.868 .32013 Mdot
.868 .3204 Mdot
.868 .32049 Mdot
.868 .32074 Mdot
.868 .32092 Mdot
.868 .32109 Mdot
.868 .3215 Mdot
.868 .32204 Mdot
.868 .32215 Mdot
.868 .32302 Mdot
.868 .32322 Mdot
.868 .32337 Mdot
.868 .32338 Mdot
.868 .32343 Mdot
.868 .32364 Mdot
.868 .32416 Mdot
.868 .32445 Mdot
.868 .32468 Mdot
.868 .32479 Mdot
.868 .32524 Mdot
.868 .32556 Mdot
.868 .32725 Mdot
.868 .32775 Mdot
.868 .32779 Mdot
.868 .32787 Mdot
.868 .32817 Mdot
.868 .32834 Mdot
.868 .32908 Mdot
.868 .32912 Mdot
.868 .32921 Mdot
.868 .32925 Mdot
.868 .32948 Mdot
.868 .32953 Mdot
.868 .32975 Mdot
.868 .32987 Mdot
.868 .3299 Mdot
.868 .32996 Mdot
.868 .33036 Mdot
.868 .33045 Mdot
.868 .33061 Mdot
.868 .33068 Mdot
.868 .33094 Mdot
.868 .33197 Mdot
.868 .33225 Mdot
.868 .33236 Mdot
.868 .33276 Mdot
.868 .33289 Mdot
.868 .33297 Mdot
.868 .33348 Mdot
.868 .33379 Mdot
.868 .335 Mdot
.868 .33641 Mdot
.868 .33659 Mdot
.868 .33689 Mdot
.868 .33753 Mdot
.868 .33769 Mdot
.868 .33801 Mdot
.868 .33841 Mdot
.868 .33868 Mdot
.868 .33868 Mdot
.868 .33904 Mdot
.868 .33911 Mdot
.868 .33939 Mdot
.868 .33946 Mdot
.868 .33946 Mdot
.868 .33947 Mdot
.868 .33947 Mdot
.868 .33967 Mdot
.868 .33991 Mdot
.868 .33995 Mdot
.868 .34011 Mdot
.868 .34016 Mdot
.868 .34065 Mdot
.868 .34074 Mdot
.868 .34099 Mdot
.868 .34112 Mdot
.868 .34165 Mdot
.868 .3417 Mdot
.868 .34175 Mdot
.868 .34221 Mdot
.868 .3424 Mdot
.868 .34259 Mdot
.868 .34285 Mdot
.868 .34285 Mdot
.868 .34289 Mdot
.868 .34295 Mdot
.868 .34295 Mdot
.868 .34301 Mdot
.868 .34303 Mdot
.868 .34304 Mdot
.868 .3431 Mdot
.868 .34323 Mdot
.868 .34324 Mdot
.868 .34343 Mdot
.868 .34362 Mdot
.868 .34365 Mdot
.868 .34365 Mdot
.868 .34366 Mdot
.868 .34366 Mdot
.868 .34368 Mdot
.868 .3437 Mdot
.868 .34371 Mdot
.868 .34411 Mdot
.868 .34413 Mdot
.868 .34442 Mdot
.868 .34444 Mdot
.868 .34459 Mdot
.868 .34461 Mdot
.868 .34465 Mdot
.868 .34479 Mdot
.868 .34479 Mdot
.868 .34491 Mdot
.868 .34501 Mdot
.868 .34501 Mdot
.868 .34556 Mdot
.868 .34594 Mdot
.868 .34629 Mdot
.868 .34654 Mdot
.868 .34684 Mdot
.868 .34705 Mdot
.868 .34708 Mdot
.868 .34712 Mdot
.868 .3472 Mdot
.868 .34746 Mdot
.868 .34788 Mdot
.868 .34802 Mdot
.868 .34813 Mdot
.868 .34826 Mdot
.868 .34827 Mdot
.868 .34833 Mdot
.868 .3485 Mdot
.868 .34866 Mdot
.868 .34869 Mdot
.868 .34872 Mdot
.868 .34876 Mdot
.868 .34878 Mdot
.868 .34882 Mdot
.868 .34883 Mdot
.868 .34886 Mdot
.868 .34889 Mdot
.868 .3489 Mdot
.868 .3489 Mdot
.868 .3489 Mdot
.868 .3489 Mdot
.868 .3489 Mdot
.868 .34891 Mdot
.868 .46976 Mdot
.868 .46976 Mdot
.868 .46976 Mdot
.868 .46976 Mdot
.868 .46976 Mdot
.868 .46976 Mdot
.868 .46976 Mdot
.868 .46978 Mdot
.868 .46979 Mdot
.868 .4698 Mdot
.868 .46982 Mdot
.868 .46982 Mdot
.868 .46984 Mdot
.868 .46986 Mdot
.868 .46987 Mdot
.868 .46995 Mdot
.868 .47003 Mdot
.868 .47006 Mdot
.868 .47007 Mdot
.868 .47013 Mdot
.868 .47019 Mdot
.868 .47025 Mdot
.868 .47045 Mdot
.868 .47058 Mdot
.868 .47062 Mdot
.868 .47064 Mdot
.868 .47065 Mdot
.868 .47076 Mdot
.868 .47102 Mdot
.868 .47119 Mdot
.868 .47137 Mdot
.868 .47164 Mdot
.868 .47164 Mdot
.868 .47168 Mdot
.868 .47174 Mdot
.868 .47174 Mdot
.868 .47181 Mdot
.868 .47183 Mdot
.868 .47184 Mdot
.868 .47191 Mdot
.868 .47192 Mdot
.868 .47206 Mdot
.868 .47207 Mdot
.868 .47226 Mdot
.868 .47227 Mdot
.868 .47228 Mdot
.868 .47229 Mdot
.868 .47229 Mdot
.868 .47229 Mdot
.868 .47229 Mdot
.868 .4723 Mdot
.868 .4724 Mdot
.868 .47249 Mdot
.868 .47249 Mdot
.868 .47255 Mdot
.868 .47258 Mdot
.868 .47259 Mdot
.868 .4726 Mdot
.868 .47263 Mdot
.868 .47263 Mdot
.868 .47265 Mdot
.868 .47267 Mdot
.868 .47267 Mdot
.868 .4728 Mdot
.868 .47289 Mdot
.868 .47298 Mdot
.868 .4732 Mdot
.868 .47322 Mdot
.868 .47325 Mdot
.868 .4735 Mdot
.868 .47356 Mdot
.868 .47368 Mdot
.868 .47372 Mdot
.868 .47395 Mdot
.868 .47398 Mdot
.868 .47405 Mdot
.868 .47407 Mdot
.868 .47419 Mdot
.868 .47428 Mdot
.868 .47429 Mdot
.868 .47429 Mdot
.868 .47429 Mdot
.868 .47432 Mdot
.868 .47446 Mdot
.868 .47449 Mdot
.868 .47466 Mdot
.868 .47466 Mdot
.868 .47479 Mdot
.868 .47498 Mdot
.868 .47513 Mdot
.868 .4752 Mdot
.868 .47551 Mdot
.868 .47565 Mdot
.868 .47573 Mdot
.868 .4764 Mdot
.868 .47697 Mdot
.868 .47711 Mdot
.868 .47735 Mdot
.868 .47739 Mdot
.868 .47745 Mdot
.868 .47764 Mdot
.868 .47769 Mdot
.868 .47782 Mdot
.868 .4783 Mdot
.868 .47842 Mdot
.868 .47845 Mdot
.868 .47853 Mdot
.868 .47857 Mdot
.868 .47876 Mdot
.868 .47879 Mdot
.868 .4788 Mdot
.868 .47886 Mdot
.868 .47896 Mdot
.868 .47898 Mdot
.868 .47909 Mdot
.868 .47911 Mdot
.868 .47915 Mdot
.868 .47917 Mdot
.868 .47951 Mdot
.868 .47959 Mdot
.868 .47973 Mdot
.868 .47977 Mdot
.868 .47979 Mdot
.868 .48002 Mdot
.868 .4808 Mdot
.868 .48095 Mdot
.868 .48115 Mdot
.868 .48121 Mdot
.868 .48131 Mdot
.868 .48144 Mdot
.868 .48168 Mdot
.868 .48178 Mdot
.868 .48181 Mdot
.868 .48181 Mdot
.868 .48188 Mdot
.868 .48197 Mdot
.868 .48237 Mdot
.868 .48242 Mdot
.868 .48267 Mdot
.868 .48286 Mdot
.868 .48294 Mdot
.868 .48302 Mdot
.868 .48313 Mdot
.868 .48317 Mdot
.868 .4833 Mdot
.868 .4833 Mdot
.868 .48339 Mdot
.868 .48349 Mdot
.868 .48349 Mdot
.868 .48349 Mdot
.868 .48349 Mdot
.868 .4835 Mdot
.868 .48351 Mdot
.868 .48352 Mdot
.868 .48386 Mdot
.868 .4853 Mdot
.868 .48549 Mdot
.868 .4858 Mdot
.868 .48648 Mdot
.868 .48665 Mdot
.868 .48699 Mdot
.868 .48742 Mdot
.868 .48771 Mdot
.868 .48772 Mdot
.868 .48811 Mdot
.868 .48819 Mdot
.868 .4885 Mdot
.868 .48857 Mdot
.868 .48857 Mdot
.868 .48858 Mdot
.868 .48859 Mdot
.868 .4888 Mdot
.868 .48908 Mdot
.868 .48912 Mdot
.868 .48929 Mdot
.868 .48935 Mdot
.868 .4899 Mdot
.868 .49 Mdot
.868 .49028 Mdot
.868 .49043 Mdot
.868 .49103 Mdot
.868 .4911 Mdot
.868 .49115 Mdot
.868 .49168 Mdot
.868 .49189 Mdot
.868 .49212 Mdot
.868 .49241 Mdot
.868 .49241 Mdot
.868 .49246 Mdot
.868 .49252 Mdot
.868 .49253 Mdot
.868 .4926 Mdot
.868 .49262 Mdot
.868 .49263 Mdot
.868 .4927 Mdot
.868 .49285 Mdot
.868 .49286 Mdot
.868 .49308 Mdot
.868 .49331 Mdot
.868 .49334 Mdot
.868 .49334 Mdot
.868 .49335 Mdot
.868 .49335 Mdot
.868 .49338 Mdot
.868 .4934 Mdot
.868 .49342 Mdot
.868 .49388 Mdot
.868 .4939 Mdot
.868 .49424 Mdot
.868 .49427 Mdot
.868 .49444 Mdot
.868 .49446 Mdot
.868 .49452 Mdot
.868 .49468 Mdot
.868 .49469 Mdot
.868 .49483 Mdot
.868 .49494 Mdot
.868 .49494 Mdot
.868 .49559 Mdot
.868 .49605 Mdot
.868 .49646 Mdot
.868 .49675 Mdot
.868 .49711 Mdot
.868 .49736 Mdot
.868 .4974 Mdot
.868 .49745 Mdot
.868 .49755 Mdot
.868 .49786 Mdot
.868 .49836 Mdot
.868 .49853 Mdot
.868 .49866 Mdot
.868 .49882 Mdot
.868 .49883 Mdot
.868 .4989 Mdot
.868 .4991 Mdot
.868 .4993 Mdot
.868 .49933 Mdot
.868 .49937 Mdot
.868 .49942 Mdot
.868 .49944 Mdot
.868 .49949 Mdot
.868 .49949 Mdot
.868 .49953 Mdot
.868 .49958 Mdot
.868 .49958 Mdot
.868 .49958 Mdot
.868 .49958 Mdot
.868 .49958 Mdot
.868 .49959 Mdot
.868 .49959 Mdot
.868 .51412 Mdot
.868 .51412 Mdot
.868 .51412 Mdot
.868 .51412 Mdot
.868 .51412 Mdot
.868 .51412 Mdot
.868 .51412 Mdot
.868 .51414 Mdot
.868 .51416 Mdot
.868 .51416 Mdot
.868 .51419 Mdot
.868 .5142 Mdot
.868 .51422 Mdot
.868 .51424 Mdot
.868 .51425 Mdot
.868 .51435 Mdot
.868 .51444 Mdot
.868 .51448 Mdot
.868 .51448 Mdot
.868 .51456 Mdot
.868 .51462 Mdot
.868 .5147 Mdot
.868 .51493 Mdot
.868 .51508 Mdot
.868 .51512 Mdot
.868 .51514 Mdot
.868 .51516 Mdot
.868 .51528 Mdot
.868 .51544 Mdot
.868 .51557 Mdot
.868 .51576 Mdot
.868 .51596 Mdot
.868 .51625 Mdot
.868 .51625 Mdot
.868 .5163 Mdot
.868 .51636 Mdot
.868 .51637 Mdot
.868 .51644 Mdot
.868 .51646 Mdot
.868 .51647 Mdot
.868 .51655 Mdot
.868 .51656 Mdot
.868 .51671 Mdot
.868 .51672 Mdot
.868 .51691 Mdot
.868 .51692 Mdot
.868 .51693 Mdot
.868 .51694 Mdot
.868 .51694 Mdot
.868 .51695 Mdot
.868 .51695 Mdot
.868 .51696 Mdot
.868 .51706 Mdot
.868 .51715 Mdot
.868 .51716 Mdot
.868 .51722 Mdot
.868 .51725 Mdot
.868 .51726 Mdot
.868 .51726 Mdot
.868 .51729 Mdot
.868 .5173 Mdot
.868 .51732 Mdot
.868 .51734 Mdot
.868 .51734 Mdot
.868 .51747 Mdot
.868 .51756 Mdot
.868 .51765 Mdot
.868 .51787 Mdot
.868 .51789 Mdot
.868 .51792 Mdot
.868 .51817 Mdot
.868 .51823 Mdot
.868 .51835 Mdot
.868 .51838 Mdot
.868 .51861 Mdot
.868 .51863 Mdot
.868 .5187 Mdot
.868 .51872 Mdot
.868 .51883 Mdot
.868 .51892 Mdot
.868 .51892 Mdot
.868 .51892 Mdot
.868 .51892 Mdot
.868 .51895 Mdot
.868 .51907 Mdot
.868 .5191 Mdot
.868 .51926 Mdot
.868 .51926 Mdot
.868 .51938 Mdot
.868 .51955 Mdot
.868 .51968 Mdot
.868 .51974 Mdot
.868 .52001 Mdot
.868 .52013 Mdot
.868 .5202 Mdot
.868 .52074 Mdot
.868 .52087 Mdot
.868 .52087 Mdot
.868 .52088 Mdot
.868 .52088 Mdot
.868 .52088 Mdot
.868 .52088 Mdot
.868 .52088 Mdot
.868 .52092 Mdot
.868 .52095 Mdot
.868 .52096 Mdot
.868 .521 Mdot
.868 .52102 Mdot
.868 .52106 Mdot
.868 .52109 Mdot
.868 .52112 Mdot
.868 .52119 Mdot
.868 .52128 Mdot
.868 .5213 Mdot
.868 .52145 Mdot
.868 .52148 Mdot
.868 .52151 Mdot
.868 .52151 Mdot
.868 .52151 Mdot
.868 .52155 Mdot
.868 .52164 Mdot
.868 .52169 Mdot
.868 .52173 Mdot
.868 .52174 Mdot
.868 .52182 Mdot
.868 .52187 Mdot
.868 .52215 Mdot
.868 .52224 Mdot
.868 .52224 Mdot
.868 .52226 Mdot
.868 .52231 Mdot
.868 .52233 Mdot
.868 .52246 Mdot
.868 .52246 Mdot
.868 .52248 Mdot
.868 .52249 Mdot
.868 .52252 Mdot
.868 .52253 Mdot
.868 .52257 Mdot
.868 .52259 Mdot
.868 .52259 Mdot
.868 .5226 Mdot
.868 .52267 Mdot
.868 .52268 Mdot
.868 .52271 Mdot
.868 .52272 Mdot
.868 .52276 Mdot
.868 .52293 Mdot
.868 .52298 Mdot
.868 .523 Mdot
.868 .52306 Mdot
.868 .52308 Mdot
.868 .5231 Mdot
.868 .52318 Mdot
.868 .52323 Mdot
.868 .52343 Mdot
.868 .52366 Mdot
.868 .52368 Mdot
.868 .52373 Mdot
.868 .52384 Mdot
.868 .52386 Mdot
.868 .52391 Mdot
.868 .52398 Mdot
.868 .52402 Mdot
.868 .52402 Mdot
.868 .52408 Mdot
.868 .52409 Mdot
.868 .52414 Mdot
.868 .52415 Mdot
.868 .52415 Mdot
.868 .52415 Mdot
.868 .52415 Mdot
.868 .52418 Mdot
.868 .52422 Mdot
.868 .52423 Mdot
.868 .52425 Mdot
.868 .52426 Mdot
.868 .52434 Mdot
.868 .52435 Mdot
.868 .52439 Mdot
.868 .52441 Mdot
.868 .5245 Mdot
.868 .52451 Mdot
.868 .52451 Mdot
.868 .52459 Mdot
.868 .52462 Mdot
.868 .52465 Mdot
.868 .52469 Mdot
.868 .52469 Mdot
.868 .52469 Mdot
.868 .5247 Mdot
.868 .5247 Mdot
.868 .52471 Mdot
.868 .52472 Mdot
.868 .52472 Mdot
.868 .52473 Mdot
.868 .52475 Mdot
.868 .52475 Mdot
.868 .52478 Mdot
.868 .52481 Mdot
.868 .52481 Mdot
.868 .52481 Mdot
.868 .52482 Mdot
.868 .52482 Mdot
.868 .52482 Mdot
.868 .52482 Mdot
.868 .52483 Mdot
.868 .52489 Mdot
.868 .52489 Mdot
.868 .52494 Mdot
.868 .52494 Mdot
.868 .52496 Mdot
.868 .52497 Mdot
.868 .52497 Mdot
.868 .525 Mdot
.868 .525 Mdot
.868 .52501 Mdot
.868 .52503 Mdot
.868 .52503 Mdot
.868 .52512 Mdot
.868 .52518 Mdot
.868 .52523 Mdot
.868 .52532 Mdot
.868 .52535 Mdot
.868 .52536 Mdot
.868 .52536 Mdot
.868 .52538 Mdot
.868 .52542 Mdot
.868 .52548 Mdot
.868 .5255 Mdot
.868 .52552 Mdot
.868 .52554 Mdot
.868 .52554 Mdot
.868 .52555 Mdot
.868 .52558 Mdot
.868 .52561 Mdot
.868 .52561 Mdot
.868 .52561 Mdot
.868 .52562 Mdot
.868 .52562 Mdot
.868 .52563 Mdot
.868 .52563 Mdot
.868 .52564 Mdot
.868 .52564 Mdot
.868 .52564 Mdot
.868 .52564 Mdot
.868 .52564 Mdot
.868 .52564 Mdot
.868 .52564 Mdot
.868 .52564 Mdot
.87 .2181 Mdot
.87 .22325 Mdot
.87 .23619 Mdot
.87 .24373 Mdot
.87 .25415 Mdot
.87 .2713 Mdot
.87 .29223 Mdot
.87 .30907 Mdot
.87 .34065 Mdot
.87 .35393 Mdot
.87 .46769 Mdot
.87 .47408 Mdot
.87 .48861 Mdot
.87 .49604 Mdot
.87 .50501 Mdot
.87 .51218 Mdot
.87 .51647 Mdot
.87 .51955 Mdot
.87 .52476 Mdot
.87 .52682 Mdot
.872 .2156 Mdot
.872 .2156 Mdot
.872 .2156 Mdot
.872 .2156 Mdot
.872 .21561 Mdot
.872 .21561 Mdot
.872 .21562 Mdot
.872 .21564 Mdot
.872 .21565 Mdot
.872 .21565 Mdot
.872 .21571 Mdot
.872 .21578 Mdot
.872 .21581 Mdot
.872 .21587 Mdot
.872 .21593 Mdot
.872 .21593 Mdot
.872 .21596 Mdot
.872 .21597 Mdot
.872 .21615 Mdot
.872 .21622 Mdot
.872 .21631 Mdot
.872 .21634 Mdot
.872 .21636 Mdot
.872 .21639 Mdot
.872 .21669 Mdot
.872 .2167 Mdot
.872 .21715 Mdot
.872 .21719 Mdot
.872 .21733 Mdot
.872 .21742 Mdot
.872 .21763 Mdot
.872 .21782 Mdot
.872 .21788 Mdot
.872 .2179 Mdot
.872 .21808 Mdot
.872 .21814 Mdot
.872 .21818 Mdot
.872 .21824 Mdot
.872 .21825 Mdot
.872 .21847 Mdot
.872 .21866 Mdot
.872 .21875 Mdot
.872 .21877 Mdot
.872 .21879 Mdot
.872 .21892 Mdot
.872 .21941 Mdot
.872 .22 Mdot
.872 .22038 Mdot
.872 .22046 Mdot
.872 .22066 Mdot
.872 .22126 Mdot
.872 .22152 Mdot
.872 .22155 Mdot
.872 .22179 Mdot
.872 .22194 Mdot
.872 .22203 Mdot
.872 .22204 Mdot
.872 .22208 Mdot
.872 .22209 Mdot
.872 .22236 Mdot
.872 .2226 Mdot
.872 .22266 Mdot
.872 .22295 Mdot
.872 .22306 Mdot
.872 .22346 Mdot
.872 .22356 Mdot
.872 .22375 Mdot
.872 .22381 Mdot
.872 .22387 Mdot
.872 .22401 Mdot
.872 .22404 Mdot
.872 .22483 Mdot
.872 .22503 Mdot
.872 .22529 Mdot
.872 .22538 Mdot
.872 .22542 Mdot
.872 .22572 Mdot
.872 .22585 Mdot
.872 .226 Mdot
.872 .22617 Mdot
.872 .22667 Mdot
.872 .22674 Mdot
.872 .22677 Mdot
.872 .22681 Mdot
.872 .22695 Mdot
.872 .22717 Mdot
.872 .22723 Mdot
.872 .22756 Mdot
.872 .22772 Mdot
.872 .22789 Mdot
.872 .22803 Mdot
.872 .22805 Mdot
.872 .22873 Mdot
.872 .22949 Mdot
.872 .23002 Mdot
.872 .23009 Mdot
.872 .23047 Mdot
.872 .23056 Mdot
.872 .23062 Mdot
.872 .23079 Mdot
.872 .23108 Mdot
.872 .2313 Mdot
.872 .23157 Mdot
.872 .23221 Mdot
.872 .23224 Mdot
.872 .2327 Mdot
.872 .23279 Mdot
.872 .23302 Mdot
.872 .23316 Mdot
.872 .23357 Mdot
.872 .23367 Mdot
.872 .23385 Mdot
.872 .23402 Mdot
.872 .23414 Mdot
.872 .23475 Mdot
.872 .23498 Mdot
.872 .23539 Mdot
.872 .23558 Mdot
.872 .23558 Mdot
.872 .2356 Mdot
.872 .23573 Mdot
.872 .23574 Mdot
.872 .23605 Mdot
.872 .23614 Mdot
.872 .23649 Mdot
.872 .23726 Mdot
.872 .23736 Mdot
.872 .23812 Mdot
.872 .23822 Mdot
.872 .23943 Mdot
.872 .23966 Mdot
.872 .24023 Mdot
.872 .24029 Mdot
.872 .24061 Mdot
.872 .24068 Mdot
.872 .2409 Mdot
.872 .24119 Mdot
.872 .24121 Mdot
.872 .24133 Mdot
.872 .24224 Mdot
.872 .24254 Mdot
.872 .24276 Mdot
.872 .2432 Mdot
.872 .24367 Mdot
.872 .24373 Mdot
.872 .24374 Mdot
.872 .24377 Mdot
.872 .24411 Mdot
.872 .24415 Mdot
.872 .24472 Mdot
.872 .24501 Mdot
.872 .24547 Mdot
.872 .24574 Mdot
.872 .24581 Mdot
.872 .24605 Mdot
.872 .24622 Mdot
.872 .24655 Mdot
.872 .24657 Mdot
.872 .24676 Mdot
.872 .24679 Mdot
.872 .24704 Mdot
.872 .24713 Mdot
.872 .24721 Mdot
.872 .24756 Mdot
.872 .24793 Mdot
.872 .2483 Mdot
.872 .24845 Mdot
.872 .24869 Mdot
.872 .24921 Mdot
.872 .24922 Mdot
.872 .24947 Mdot
.872 .24964 Mdot
.872 .24982 Mdot
.872 .24986 Mdot
.872 .25007 Mdot
.872 .25043 Mdot
.872 .2506 Mdot
.872 .25069 Mdot
.872 .25092 Mdot
.872 .25174 Mdot
.872 .25227 Mdot
.872 .25236 Mdot
.872 .25261 Mdot
.872 .25273 Mdot
.872 .25276 Mdot
.872 .25297 Mdot
.872 .25301 Mdot
.872 .25337 Mdot
.872 .25357 Mdot
.872 .25373 Mdot
.872 .25391 Mdot
.872 .25394 Mdot
.872 .25394 Mdot
.872 .25395 Mdot
.872 .25408 Mdot
.872 .25409 Mdot
.872 .25442 Mdot
.872 .25459 Mdot
.872 .25469 Mdot
.872 .25471 Mdot
.872 .2548 Mdot
.872 .25486 Mdot
.872 .25499 Mdot
.872 .25506 Mdot
.872 .25549 Mdot
.872 .25568 Mdot
.872 .25576 Mdot
.872 .25617 Mdot
.872 .25626 Mdot
.872 .25639 Mdot
.872 .25703 Mdot
.872 .25707 Mdot
.872 .2572 Mdot
.872 .25721 Mdot
.872 .2573 Mdot
.872 .25742 Mdot
.872 .25761 Mdot
.872 .25762 Mdot
.872 .25762 Mdot
.872 .25762 Mdot
.872 .25767 Mdot
.872 .25767 Mdot
.872 .25778 Mdot
.872 .25784 Mdot
.872 .25788 Mdot
.872 .25788 Mdot
.872 .25791 Mdot
.872 .25794 Mdot
.872 .25798 Mdot
.872 .25801 Mdot
.872 .25815 Mdot
.872 .25839 Mdot
.872 .25842 Mdot
.872 .25846 Mdot
.872 .25868 Mdot
.872 .25874 Mdot
.872 .25897 Mdot
.872 .25898 Mdot
.872 .25899 Mdot
.872 .25914 Mdot
.872 .25915 Mdot
.872 .25924 Mdot
.872 .25926 Mdot
.872 .25943 Mdot
.872 .25968 Mdot
.872 .25969 Mdot
.872 .25984 Mdot
.872 .25998 Mdot
.872 .26002 Mdot
.872 .26015 Mdot
.872 .26017 Mdot
.872 .26019 Mdot
.872 .26042 Mdot
.872 .26043 Mdot
.872 .26046 Mdot
.872 .26047 Mdot
.872 .26049 Mdot
.872 .26049 Mdot
.872 .26055 Mdot
.872 .26061 Mdot
.872 .26062 Mdot
.872 .26064 Mdot
.872 .26065 Mdot
.872 .26065 Mdot
.872 .26065 Mdot
.872 .26089 Mdot
.872 .26099 Mdot
.872 .26138 Mdot
.872 .26146 Mdot
.872 .26151 Mdot
.872 .26192 Mdot
.872 .26218 Mdot
.872 .26222 Mdot
.872 .2623 Mdot
.872 .26234 Mdot
.872 .26239 Mdot
.872 .26241 Mdot
.872 .26247 Mdot
.872 .26258 Mdot
.872 .26277 Mdot
.872 .26278 Mdot
.872 .26286 Mdot
.872 .26287 Mdot
.872 .26287 Mdot
.872 .26289 Mdot
.872 .26322 Mdot
.872 .26344 Mdot
.872 .2636 Mdot
.872 .26362 Mdot
.872 .26385 Mdot
.872 .26391 Mdot
.872 .26508 Mdot
.872 .26532 Mdot
.872 .26548 Mdot
.872 .26622 Mdot
.872 .26638 Mdot
.872 .26672 Mdot
.872 .26749 Mdot
.872 .26751 Mdot
.872 .26765 Mdot
.872 .26788 Mdot
.872 .268 Mdot
.872 .26817 Mdot
.872 .26821 Mdot
.872 .2684 Mdot
.872 .26872 Mdot
.872 .26932 Mdot
.872 .26935 Mdot
.872 .26959 Mdot
.872 .26962 Mdot
.872 .26962 Mdot
.872 .26967 Mdot
.872 .27001 Mdot
.872 .27032 Mdot
.872 .2707 Mdot
.872 .27137 Mdot
.872 .27146 Mdot
.872 .27186 Mdot
.872 .27191 Mdot
.872 .27215 Mdot
.872 .27263 Mdot
.872 .27281 Mdot
.872 .27383 Mdot
.872 .27544 Mdot
.872 .27591 Mdot
.872 .27607 Mdot
.872 .27641 Mdot
.872 .27713 Mdot
.872 .27755 Mdot
.872 .27763 Mdot
.872 .278 Mdot
.872 .27833 Mdot
.872 .27883 Mdot
.872 .27886 Mdot
.872 .27992 Mdot
.872 .28041 Mdot
.872 .28146 Mdot
.872 .28223 Mdot
.872 .28296 Mdot
.872 .28311 Mdot
.872 .28329 Mdot
.872 .28382 Mdot
.872 .28389 Mdot
.872 .28429 Mdot
.872 .28433 Mdot
.872 .28501 Mdot
.872 .28538 Mdot
.872 .28588 Mdot
.872 .28603 Mdot
.872 .28659 Mdot
.872 .28757 Mdot
.872 .2882 Mdot
.872 .28942 Mdot
.872 .2895 Mdot
.872 .29023 Mdot
.872 .29031 Mdot
.872 .29031 Mdot
.872 .29045 Mdot
.872 .29148 Mdot
.872 .29244 Mdot
.872 .2929 Mdot
.872 .29356 Mdot
.872 .29559 Mdot
.872 .29585 Mdot
.872 .2959 Mdot
.872 .29653 Mdot
.872 .29704 Mdot
.872 .29719 Mdot
.872 .2979 Mdot
.872 .29804 Mdot
.872 .29933 Mdot
.872 .29984 Mdot
.872 .30261 Mdot
.872 .30282 Mdot
.872 .30458 Mdot
.872 .30482 Mdot
.872 .3066 Mdot
.872 .30741 Mdot
.872 .30764 Mdot
.872 .30835 Mdot
.872 .30838 Mdot
.872 .30869 Mdot
.872 .30873 Mdot
.872 .30874 Mdot
.872 .30918 Mdot
.872 .31014 Mdot
.872 .3107 Mdot
.872 .31212 Mdot
.872 .31241 Mdot
.872 .31283 Mdot
.872 .31325 Mdot
.872 .31349 Mdot
.872 .31448 Mdot
.872 .31481 Mdot
.872 .31536 Mdot
.872 .31557 Mdot
.872 .3167 Mdot
.872 .31677 Mdot
.872 .31833 Mdot
.872 .31897 Mdot
.872 .31952 Mdot
.872 .32021 Mdot
.872 .32064 Mdot
.872 .32077 Mdot
.872 .32101 Mdot
.872 .32193 Mdot
.872 .32212 Mdot
.872 .32341 Mdot
.872 .3253 Mdot
.872 .32698 Mdot
.872 .32703 Mdot
.872 .32739 Mdot
.872 .32781 Mdot
.872 .32822 Mdot
.872 .32904 Mdot
.872 .32919 Mdot
.872 .32973 Mdot
.872 .33011 Mdot
.872 .33019 Mdot
.872 .33026 Mdot
.872 .33045 Mdot
.872 .33171 Mdot
.872 .33214 Mdot
.872 .33253 Mdot
.872 .33286 Mdot
.872 .33362 Mdot
.872 .3337 Mdot
.872 .33393 Mdot
.872 .33459 Mdot
.872 .33512 Mdot
.872 .33712 Mdot
.872 .33719 Mdot
.872 .33756 Mdot
.872 .3377 Mdot
.872 .33787 Mdot
.872 .33836 Mdot
.872 .3386 Mdot
.872 .33965 Mdot
.872 .33993 Mdot
.872 .34067 Mdot
.872 .34082 Mdot
.872 .34145 Mdot
.872 .34215 Mdot
.872 .34217 Mdot
.872 .34228 Mdot
.872 .34229 Mdot
.872 .34254 Mdot
.872 .34291 Mdot
.872 .34353 Mdot
.872 .34361 Mdot
.872 .3443 Mdot
.872 .34586 Mdot
.872 .34637 Mdot
.872 .34658 Mdot
.872 .34758 Mdot
.872 .34913 Mdot
.872 .3504 Mdot
.872 .35074 Mdot
.872 .3508 Mdot
.872 .35085 Mdot
.872 .35108 Mdot
.872 .35158 Mdot
.872 .35218 Mdot
.872 .35219 Mdot
.872 .35235 Mdot
.872 .35246 Mdot
.872 .35261 Mdot
.872 .35309 Mdot
.872 .35314 Mdot
.872 .35329 Mdot
.872 .35381 Mdot
.872 .35436 Mdot
.872 .35459 Mdot
.872 .35496 Mdot
.872 .35506 Mdot
.872 .35625 Mdot
.872 .3563 Mdot
.872 .35709 Mdot
.872 .35716 Mdot
.872 .35722 Mdot
.872 .3573 Mdot
.872 .35755 Mdot
.872 .35773 Mdot
.872 .35821 Mdot
.872 .35821 Mdot
.872 .35831 Mdot
.872 .35831 Mdot
.872 .35848 Mdot
.872 .35862 Mdot
.872 .35871 Mdot
.872 .35889 Mdot
.872 .35905 Mdot
.872 .35905 Mdot
.872 .35909 Mdot
.872 .35912 Mdot
.872 .35916 Mdot
.872 .35916 Mdot
.872 .35918 Mdot
.872 .35918 Mdot
.872 .35918 Mdot
.872 .35918 Mdot
.872 .4655 Mdot
.872 .4655 Mdot
.872 .4655 Mdot
.872 .4655 Mdot
.872 .46551 Mdot
.872 .46551 Mdot
.872 .46553 Mdot
.872 .46554 Mdot
.872 .46556 Mdot
.872 .46556 Mdot
.872 .46564 Mdot
.872 .46573 Mdot
.872 .46577 Mdot
.872 .46585 Mdot
.872 .46593 Mdot
.872 .46593 Mdot
.872 .46597 Mdot
.872 .46598 Mdot
.872 .46621 Mdot
.872 .4663 Mdot
.872 .46642 Mdot
.872 .46646 Mdot
.872 .46649 Mdot
.872 .46653 Mdot
.872 .46691 Mdot
.872 .46694 Mdot
.872 .46752 Mdot
.872 .46757 Mdot
.872 .46775 Mdot
.872 .46786 Mdot
.872 .46812 Mdot
.872 .46838 Mdot
.872 .46845 Mdot
.872 .46848 Mdot
.872 .46871 Mdot
.872 .46878 Mdot
.872 .46883 Mdot
.872 .46891 Mdot
.872 .46892 Mdot
.872 .46921 Mdot
.872 .46945 Mdot
.872 .46956 Mdot
.872 .46959 Mdot
.872 .46962 Mdot
.872 .46978 Mdot
.872 .47039 Mdot
.872 .47113 Mdot
.872 .47161 Mdot
.872 .47172 Mdot
.872 .47196 Mdot
.872 .4727 Mdot
.872 .47303 Mdot
.872 .47307 Mdot
.872 .47336 Mdot
.872 .47354 Mdot
.872 .47366 Mdot
.872 .47366 Mdot
.872 .47371 Mdot
.872 .47372 Mdot
.872 .47406 Mdot
.872 .47435 Mdot
.872 .47442 Mdot
.872 .47477 Mdot
.872 .47491 Mdot
.872 .4754 Mdot
.872 .47551 Mdot
.872 .47574 Mdot
.872 .47582 Mdot
.872 .47589 Mdot
.872 .47606 Mdot
.872 .4761 Mdot
.872 .47703 Mdot
.872 .47728 Mdot
.872 .47759 Mdot
.872 .4777 Mdot
.872 .47773 Mdot
.872 .47809 Mdot
.872 .47824 Mdot
.872 .47842 Mdot
.872 .47862 Mdot
.872 .4792 Mdot
.872 .47929 Mdot
.872 .47932 Mdot
.872 .47936 Mdot
.872 .47954 Mdot
.872 .47979 Mdot
.872 .47986 Mdot
.872 .48024 Mdot
.872 .48042 Mdot
.872 .48062 Mdot
.872 .48078 Mdot
.872 .4808 Mdot
.872 .48158 Mdot
.872 .48244 Mdot
.872 .48303 Mdot
.872 .48312 Mdot
.872 .48354 Mdot
.872 .48364 Mdot
.872 .4837 Mdot
.872 .4839 Mdot
.872 .48421 Mdot
.872 .48446 Mdot
.872 .48475 Mdot
.872 .48546 Mdot
.872 .48549 Mdot
.872 .486 Mdot
.872 .48609 Mdot
.872 .48634 Mdot
.872 .48649 Mdot
.872 .48693 Mdot
.872 .48704 Mdot
.872 .48723 Mdot
.872 .48742 Mdot
.872 .48755 Mdot
.872 .48819 Mdot
.872 .48843 Mdot
.872 .48886 Mdot
.872 .48906 Mdot
.872 .48906 Mdot
.872 .48908 Mdot
.872 .48922 Mdot
.872 .48923 Mdot
.872 .48955 Mdot
.872 .48965 Mdot
.872 .49001 Mdot
.872 .4908 Mdot
.872 .4909 Mdot
.872 .49168 Mdot
.872 .49178 Mdot
.872 .49299 Mdot
.872 .49322 Mdot
.872 .49378 Mdot
.872 .49384 Mdot
.872 .49415 Mdot
.872 .49422 Mdot
.872 .49444 Mdot
.872 .49472 Mdot
.872 .49474 Mdot
.872 .49485 Mdot
.872 .49574 Mdot
.872 .49602 Mdot
.872 .49622 Mdot
.872 .49664 Mdot
.872 .49708 Mdot
.872 .49715 Mdot
.872 .49715 Mdot
.872 .49718 Mdot
.872 .4975 Mdot
.872 .49753 Mdot
.872 .49806 Mdot
.872 .49833 Mdot
.872 .49875 Mdot
.872 .49899 Mdot
.872 .49905 Mdot
.872 .49927 Mdot
.872 .49943 Mdot
.872 .49972 Mdot
.872 .49974 Mdot
.872 .49991 Mdot
.872 .49994 Mdot
.872 .50017 Mdot
.872 .50024 Mdot
.872 .50031 Mdot
.872 .50062 Mdot
.872 .50095 Mdot
.872 .5014 Mdot
.872 .50161 Mdot
.872 .50206 Mdot
.872 .50207 Mdot
.872 .50229 Mdot
.872 .50243 Mdot
.872 .50258 Mdot
.872 .50262 Mdot
.872 .5028 Mdot
.872 .5031 Mdot
.872 .50325 Mdot
.872 .50331 Mdot
.872 .50351 Mdot
.872 .50419 Mdot
.872 .50462 Mdot
.872 .5047 Mdot
.872 .5049 Mdot
.872 .505 Mdot
.872 .50503 Mdot
.872 .50519 Mdot
.872 .50523 Mdot
.872 .50552 Mdot
.872 .50567 Mdot
.872 .50581 Mdot
.872 .50595 Mdot
.872 .50597 Mdot
.872 .50597 Mdot
.872 .50598 Mdot
.872 .50608 Mdot
.872 .50609 Mdot
.872 .50635 Mdot
.872 .50648 Mdot
.872 .50656 Mdot
.872 .50658 Mdot
.872 .50665 Mdot
.872 .5067 Mdot
.872 .5068 Mdot
.872 .50685 Mdot
.872 .50718 Mdot
.872 .50733 Mdot
.872 .5074 Mdot
.872 .50771 Mdot
.872 .50777 Mdot
.872 .50787 Mdot
.872 .50836 Mdot
.872 .50839 Mdot
.872 .50848 Mdot
.872 .50849 Mdot
.872 .50856 Mdot
.872 .50865 Mdot
.872 .50879 Mdot
.872 .5088 Mdot
.872 .5088 Mdot
.872 .5088 Mdot
.872 .50883 Mdot
.872 .50884 Mdot
.872 .50892 Mdot
.872 .50896 Mdot
.872 .50899 Mdot
.872 .50899 Mdot
.872 .50902 Mdot
.872 .50903 Mdot
.872 .50907 Mdot
.872 .50908 Mdot
.872 .50919 Mdot
.872 .50936 Mdot
.872 .50938 Mdot
.872 .50942 Mdot
.872 .50958 Mdot
.872 .50962 Mdot
.872 .50972 Mdot
.872 .50972 Mdot
.872 .50972 Mdot
.872 .50972 Mdot
.872 .50973 Mdot
.872 .50974 Mdot
.872 .50976 Mdot
.872 .50979 Mdot
.872 .50979 Mdot
.872 .5098 Mdot
.872 .5098 Mdot
.872 .50981 Mdot
.872 .50982 Mdot
.872 .50991 Mdot
.872 .50992 Mdot
.872 .50993 Mdot
.872 .50998 Mdot
.872 .51 Mdot
.872 .51006 Mdot
.872 .51012 Mdot
.872 .51012 Mdot
.872 .51023 Mdot
.872 .5103 Mdot
.872 .51031 Mdot
.872 .51034 Mdot
.872 .51035 Mdot
.872 .51041 Mdot
.872 .51041 Mdot
.872 .51042 Mdot
.872 .51051 Mdot
.872 .51054 Mdot
.872 .51063 Mdot
.872 .51065 Mdot
.872 .51066 Mdot
.872 .51076 Mdot
.872 .51082 Mdot
.872 .51083 Mdot
.872 .51085 Mdot
.872 .51086 Mdot
.872 .51087 Mdot
.872 .51087 Mdot
.872 .51089 Mdot
.872 .51091 Mdot
.872 .51096 Mdot
.872 .51096 Mdot
.872 .51098 Mdot
.872 .51098 Mdot
.872 .51098 Mdot
.872 .51098 Mdot
.872 .51106 Mdot
.872 .51111 Mdot
.872 .51115 Mdot
.872 .51115 Mdot
.872 .51121 Mdot
.872 .51122 Mdot
.872 .51149 Mdot
.872 .51154 Mdot
.872 .51158 Mdot
.872 .51175 Mdot
.872 .51178 Mdot
.872 .51186 Mdot
.872 .51204 Mdot
.872 .51207 Mdot
.872 .51212 Mdot
.872 .51215 Mdot
.872 .51218 Mdot
.872 .51219 Mdot
.872 .51223 Mdot
.872 .5123 Mdot
.872 .51244 Mdot
.872 .51244 Mdot
.872 .5125 Mdot
.872 .5125 Mdot
.872 .5125 Mdot
.872 .51251 Mdot
.872 .51259 Mdot
.872 .51265 Mdot
.872 .51274 Mdot
.872 .51288 Mdot
.872 .5129 Mdot
.872 .51299 Mdot
.872 .513 Mdot
.872 .51305 Mdot
.872 .51315 Mdot
.872 .51319 Mdot
.872 .51341 Mdot
.872 .51374 Mdot
.872 .51384 Mdot
.872 .51387 Mdot
.872 .51394 Mdot
.872 .51409 Mdot
.872 .51418 Mdot
.872 .5142 Mdot
.872 .51427 Mdot
.872 .51434 Mdot
.872 .51444 Mdot
.872 .51445 Mdot
.872 .51466 Mdot
.872 .51476 Mdot
.872 .51482 Mdot
.872 .51497 Mdot
.872 .51512 Mdot
.872 .51527 Mdot
.872 .5153 Mdot
.872 .51533 Mdot
.872 .51544 Mdot
.872 .51545 Mdot
.872 .51553 Mdot
.872 .51554 Mdot
.872 .51567 Mdot
.872 .51574 Mdot
.872 .51584 Mdot
.872 .51587 Mdot
.872 .51598 Mdot
.872 .51617 Mdot
.872 .51629 Mdot
.872 .51652 Mdot
.872 .51653 Mdot
.872 .51667 Mdot
.872 .51669 Mdot
.872 .51669 Mdot
.872 .51671 Mdot
.872 .51691 Mdot
.872 .51709 Mdot
.872 .51717 Mdot
.872 .51729 Mdot
.872 .51767 Mdot
.872 .51772 Mdot
.872 .51772 Mdot
.872 .51784 Mdot
.872 .51793 Mdot
.872 .51796 Mdot
.872 .51809 Mdot
.872 .51811 Mdot
.872 .51835 Mdot
.872 .51844 Mdot
.872 .51893 Mdot
.872 .51897 Mdot
.872 .51928 Mdot
.872 .51932 Mdot
.872 .51963 Mdot
.872 .51977 Mdot
.872 .51981 Mdot
.872 .51993 Mdot
.872 .51994 Mdot
.872 .51999 Mdot
.872 .52 Mdot
.872 .52 Mdot
.872 .52008 Mdot
.872 .52024 Mdot
.872 .52034 Mdot
.872 .52058 Mdot
.872 .52063 Mdot
.872 .5207 Mdot
.872 .52077 Mdot
.872 .52081 Mdot
.872 .52098 Mdot
.872 .52103 Mdot
.872 .52112 Mdot
.872 .52116 Mdot
.872 .52135 Mdot
.872 .52136 Mdot
.872 .52162 Mdot
.872 .52172 Mdot
.872 .52181 Mdot
.872 .52193 Mdot
.872 .522 Mdot
.872 .52202 Mdot
.872 .52206 Mdot
.872 .52221 Mdot
.872 .52224 Mdot
.872 .52245 Mdot
.872 .52276 Mdot
.872 .52303 Mdot
.872 .52304 Mdot
.872 .5231 Mdot
.872 .52316 Mdot
.872 .52323 Mdot
.872 .52336 Mdot
.872 .52338 Mdot
.872 .52347 Mdot
.872 .52353 Mdot
.872 .52354 Mdot
.872 .52356 Mdot
.872 .52358 Mdot
.872 .52379 Mdot
.872 .52385 Mdot
.872 .52391 Mdot
.872 .52397 Mdot
.872 .52409 Mdot
.872 .5241 Mdot
.872 .52414 Mdot
.872 .52424 Mdot
.872 .52432 Mdot
.872 .52464 Mdot
.872 .52465 Mdot
.872 .52471 Mdot
.872 .52473 Mdot
.872 .52475 Mdot
.872 .52483 Mdot
.872 .52487 Mdot
.872 .52503 Mdot
.872 .52508 Mdot
.872 .52519 Mdot
.872 .52521 Mdot
.872 .52531 Mdot
.872 .52542 Mdot
.872 .52542 Mdot
.872 .52544 Mdot
.872 .52544 Mdot
.872 .52548 Mdot
.872 .52554 Mdot
.872 .52563 Mdot
.872 .52564 Mdot
.872 .52575 Mdot
.872 .52599 Mdot
.872 .52607 Mdot
.872 .5261 Mdot
.872 .52625 Mdot
.872 .52649 Mdot
.872 .52668 Mdot
.872 .52673 Mdot
.872 .52674 Mdot
.872 .52675 Mdot
.872 .52678 Mdot
.872 .52686 Mdot
.872 .52695 Mdot
.872 .52695 Mdot
.872 .52697 Mdot
.872 .52699 Mdot
.872 .52701 Mdot
.872 .52708 Mdot
.872 .52709 Mdot
.872 .52712 Mdot
.872 .52719 Mdot
.872 .52728 Mdot
.872 .52731 Mdot
.872 .52737 Mdot
.872 .52738 Mdot
.872 .52756 Mdot
.872 .52757 Mdot
.872 .52769 Mdot
.872 .5277 Mdot
.872 .52771 Mdot
.872 .52772 Mdot
.872 .52775 Mdot
.872 .52778 Mdot
.872 .52785 Mdot
.872 .52785 Mdot
.872 .52787 Mdot
.872 .52787 Mdot
.872 .52789 Mdot
.872 .52791 Mdot
.872 .52793 Mdot
.872 .52796 Mdot
.872 .52798 Mdot
.872 .52798 Mdot
.872 .52798 Mdot
.872 .52799 Mdot
.872 .528 Mdot
.872 .528 Mdot
.872 .528 Mdot
.872 .528 Mdot
.872 .528 Mdot
.872 .528 Mdot
.874 .21309 Mdot
.874 .21309 Mdot
.874 .21309 Mdot
.874 .2131 Mdot
.874 .21313 Mdot
.874 .21314 Mdot
.874 .21322 Mdot
.874 .21325 Mdot
.874 .21328 Mdot
.874 .21332 Mdot
.874 .21337 Mdot
.874 .21342 Mdot
.874 .21353 Mdot
.874 .2136 Mdot
.874 .21365 Mdot
.874 .21365 Mdot
.874 .21369 Mdot
.874 .21382 Mdot
.874 .2139 Mdot
.874 .21395 Mdot
.874 .21403 Mdot
.874 .2141 Mdot
.874 .21446 Mdot
.874 .2145 Mdot
.874 .21451 Mdot
.874 .21468 Mdot
.874 .21469 Mdot
.874 .21476 Mdot
.874 .21479 Mdot
.874 .21488 Mdot
.874 .21491 Mdot
.874 .21491 Mdot
.874 .21497 Mdot
.874 .21525 Mdot
.874 .21531 Mdot
.874 .21534 Mdot
.874 .21539 Mdot
.874 .21614 Mdot
.874 .21627 Mdot
.874 .21633 Mdot
.874 .217 Mdot
.874 .21722 Mdot
.874 .21731 Mdot
.874 .21733 Mdot
.874 .21745 Mdot
.874 .21753 Mdot
.874 .21767 Mdot
.874 .21791 Mdot
.874 .21807 Mdot
.874 .21816 Mdot
.874 .21821 Mdot
.874 .21837 Mdot
.874 .21869 Mdot
.874 .21874 Mdot
.874 .21874 Mdot
.874 .2189 Mdot
.874 .21903 Mdot
.874 .21916 Mdot
.874 .21966 Mdot
.874 .21969 Mdot
.874 .21979 Mdot
.874 .21981 Mdot
.874 .21986 Mdot
.874 .21995 Mdot
.874 .21997 Mdot
.874 .22035 Mdot
.874 .22043 Mdot
.874 .2207 Mdot
.874 .22093 Mdot
.874 .22096 Mdot
.874 .22126 Mdot
.874 .22144 Mdot
.874 .22147 Mdot
.874 .22188 Mdot
.874 .22193 Mdot
.874 .22195 Mdot
.874 .22203 Mdot
.874 .22221 Mdot
.874 .22228 Mdot
.874 .22249 Mdot
.874 .22282 Mdot
.874 .22284 Mdot
.874 .22316 Mdot
.874 .22326 Mdot
.874 .22345 Mdot
.874 .22352 Mdot
.874 .22355 Mdot
.874 .22388 Mdot
.874 .2242 Mdot
.874 .22424 Mdot
.874 .22544 Mdot
.874 .22559 Mdot
.874 .22569 Mdot
.874 .22585 Mdot
.874 .22635 Mdot
.874 .22648 Mdot
.874 .22698 Mdot
.874 .22735 Mdot
.874 .22742 Mdot
.874 .2275 Mdot
.874 .2276 Mdot
.874 .22783 Mdot
.874 .22793 Mdot
.874 .22796 Mdot
.874 .22812 Mdot
.874 .22839 Mdot
.874 .22853 Mdot
.874 .22854 Mdot
.874 .22861 Mdot
.874 .22877 Mdot
.874 .22928 Mdot
.874 .22934 Mdot
.874 .22945 Mdot
.874 .23027 Mdot
.874 .23062 Mdot
.874 .23076 Mdot
.874 .23087 Mdot
.874 .23088 Mdot
.874 .2311 Mdot
.874 .23164 Mdot
.874 .23175 Mdot
.874 .23189 Mdot
.874 .23195 Mdot
.874 .23211 Mdot
.874 .23242 Mdot
.874 .23252 Mdot
.874 .23293 Mdot
.874 .23321 Mdot
.874 .23336 Mdot
.874 .23345 Mdot
.874 .23398 Mdot
.874 .23402 Mdot
.874 .23491 Mdot
.874 .23498 Mdot
.874 .235 Mdot
.874 .2351 Mdot
.874 .23586 Mdot
.874 .23636 Mdot
.874 .23677 Mdot
.874 .23705 Mdot
.874 .23713 Mdot
.874 .23837 Mdot
.874 .23845 Mdot
.874 .23876 Mdot
.874 .2389 Mdot
.874 .23894 Mdot
.874 .23901 Mdot
.874 .23939 Mdot
.874 .23942 Mdot
.874 .23948 Mdot
.874 .24134 Mdot
.874 .24151 Mdot
.874 .24181 Mdot
.874 .24226 Mdot
.874 .24229 Mdot
.874 .24292 Mdot
.874 .24293 Mdot
.874 .24301 Mdot
.874 .24304 Mdot
.874 .24305 Mdot
.874 .2431 Mdot
.874 .24312 Mdot
.874 .24336 Mdot
.874 .24341 Mdot
.874 .24391 Mdot
.874 .24402 Mdot
.874 .24404 Mdot
.874 .24427 Mdot
.874 .2443 Mdot
.874 .24436 Mdot
.874 .24446 Mdot
.874 .24481 Mdot
.874 .24499 Mdot
.874 .24504 Mdot
.874 .24515 Mdot
.874 .24518 Mdot
.874 .2452 Mdot
.874 .24538 Mdot
.874 .24554 Mdot
.874 .24556 Mdot
.874 .24617 Mdot
.874 .24638 Mdot
.874 .24662 Mdot
.874 .24692 Mdot
.874 .24717 Mdot
.874 .24732 Mdot
.874 .24737 Mdot
.874 .24738 Mdot
.874 .24764 Mdot
.874 .24765 Mdot
.874 .24768 Mdot
.874 .24775 Mdot
.874 .24806 Mdot
.874 .24857 Mdot
.874 .24863 Mdot
.874 .24868 Mdot
.874 .24906 Mdot
.874 .24934 Mdot
.874 .24938 Mdot
.874 .24955 Mdot
.874 .24966 Mdot
.874 .24998 Mdot
.874 .25035 Mdot
.874 .25038 Mdot
.874 .25093 Mdot
.874 .25122 Mdot
.874 .2519 Mdot
.874 .2521 Mdot
.874 .25287 Mdot
.874 .25314 Mdot
.874 .25374 Mdot
.874 .25378 Mdot
.874 .25387 Mdot
.874 .25414 Mdot
.874 .25419 Mdot
.874 .25426 Mdot
.874 .25469 Mdot
.874 .25495 Mdot
.874 .25504 Mdot
.874 .25506 Mdot
.874 .25564 Mdot
.874 .2557 Mdot
.874 .25598 Mdot
.874 .25626 Mdot
.874 .25649 Mdot
.874 .25656 Mdot
.874 .25715 Mdot
.874 .25725 Mdot
.874 .25741 Mdot
.874 .2575 Mdot
.874 .25753 Mdot
.874 .25754 Mdot
.874 .25784 Mdot
.874 .25803 Mdot
.874 .25913 Mdot
.874 .25942 Mdot
.874 .25943 Mdot
.874 .25958 Mdot
.874 .25998 Mdot
.874 .26002 Mdot
.874 .26015 Mdot
.874 .26032 Mdot
.874 .26048 Mdot
.874 .26051 Mdot
.874 .26086 Mdot
.874 .26086 Mdot
.874 .26092 Mdot
.874 .26107 Mdot
.874 .26133 Mdot
.874 .26137 Mdot
.874 .2614 Mdot
.874 .26156 Mdot
.874 .26162 Mdot
.874 .26263 Mdot
.874 .26275 Mdot
.874 .26317 Mdot
.874 .26335 Mdot
.874 .26369 Mdot
.874 .26371 Mdot
.874 .26414 Mdot
.874 .26421 Mdot
.874 .26432 Mdot
.874 .26434 Mdot
.874 .26479 Mdot
.874 .2654 Mdot
.874 .26542 Mdot
.874 .26543 Mdot
.874 .26559 Mdot
.874 .2656 Mdot
.874 .26563 Mdot
.874 .26589 Mdot
.874 .26609 Mdot
.874 .26625 Mdot
.874 .26679 Mdot
.874 .26691 Mdot
.874 .26703 Mdot
.874 .26706 Mdot
.874 .26713 Mdot
.874 .26729 Mdot
.874 .26752 Mdot
.874 .26763 Mdot
.874 .26765 Mdot
.874 .26781 Mdot
.874 .26782 Mdot
.874 .26789 Mdot
.874 .26824 Mdot
.874 .26827 Mdot
.874 .26845 Mdot
.874 .26849 Mdot
.874 .26849 Mdot
.874 .26851 Mdot
.874 .26904 Mdot
.874 .26956 Mdot
.874 .27106 Mdot
.874 .27144 Mdot
.874 .27278 Mdot
.874 .27337 Mdot
.874 .27446 Mdot
.874 .27452 Mdot
.874 .27527 Mdot
.874 .27591 Mdot
.874 .27614 Mdot
.874 .27648 Mdot
.874 .27657 Mdot
.874 .27714 Mdot
.874 .27791 Mdot
.874 .27801 Mdot
.874 .27813 Mdot
.874 .2792 Mdot
.874 .27983 Mdot
.874 .27998 Mdot
.874 .28004 Mdot
.874 .28006 Mdot
.874 .28059 Mdot
.874 .28062 Mdot
.874 .28072 Mdot
.874 .28105 Mdot
.874 .28156 Mdot
.874 .28219 Mdot
.874 .2827 Mdot
.874 .28313 Mdot
.874 .28443 Mdot
.874 .28448 Mdot
.874 .28483 Mdot
.874 .28521 Mdot
.874 .28524 Mdot
.874 .28532 Mdot
.874 .28555 Mdot
.874 .28566 Mdot
.874 .28604 Mdot
.874 .2868 Mdot
.874 .28702 Mdot
.874 .28715 Mdot
.874 .28721 Mdot
.874 .28772 Mdot
.874 .28775 Mdot
.874 .28799 Mdot
.874 .28909 Mdot
.874 .2892 Mdot
.874 .28972 Mdot
.874 .28975 Mdot
.874 .28988 Mdot
.874 .28989 Mdot
.874 .28995 Mdot
.874 .29013 Mdot
.874 .29017 Mdot
.874 .29154 Mdot
.874 .29163 Mdot
.874 .29261 Mdot
.874 .29329 Mdot
.874 .29366 Mdot
.874 .29787 Mdot
.874 .29801 Mdot
.874 .29807 Mdot
.874 .29894 Mdot
.874 .2991 Mdot
.874 .29919 Mdot
.874 .29952 Mdot
.874 .30024 Mdot
.874 .30043 Mdot
.874 .30331 Mdot
.874 .30348 Mdot
.874 .30414 Mdot
.874 .30511 Mdot
.874 .30629 Mdot
.874 .30809 Mdot
.874 .30834 Mdot
.874 .30837 Mdot
.874 .30854 Mdot
.874 .31067 Mdot
.874 .31078 Mdot
.874 .31206 Mdot
.874 .31227 Mdot
.874 .31263 Mdot
.874 .3133 Mdot
.874 .31429 Mdot
.874 .31455 Mdot
.874 .31531 Mdot
.874 .31568 Mdot
.874 .31585 Mdot
.874 .31618 Mdot
.874 .31645 Mdot
.874 .31777 Mdot
.874 .31832 Mdot
.874 .31834 Mdot
.874 .31861 Mdot
.874 .31895 Mdot
.874 .31983 Mdot
.874 .32187 Mdot
.874 .32215 Mdot
.874 .32228 Mdot
.874 .32357 Mdot
.874 .32397 Mdot
.874 .32413 Mdot
.874 .32418 Mdot
.874 .32452 Mdot
.874 .32518 Mdot
.874 .32559 Mdot
.874 .32567 Mdot
.874 .32593 Mdot
.874 .32651 Mdot
.874 .32677 Mdot
.874 .32696 Mdot
.874 .32715 Mdot
.874 .32808 Mdot
.874 .32933 Mdot
.874 .32968 Mdot
.874 .33094 Mdot
.874 .33135 Mdot
.874 .33161 Mdot
.874 .332 Mdot
.874 .33508 Mdot
.874 .33519 Mdot
.874 .336 Mdot
.874 .33686 Mdot
.874 .33694 Mdot
.874 .33711 Mdot
.874 .33762 Mdot
.874 .33787 Mdot
.874 .33871 Mdot
.874 .33876 Mdot
.874 .33961 Mdot
.874 .34016 Mdot
.874 .34035 Mdot
.874 .34082 Mdot
.874 .34103 Mdot
.874 .34109 Mdot
.874 .34122 Mdot
.874 .34228 Mdot
.874 .34235 Mdot
.874 .34282 Mdot
.874 .34361 Mdot
.874 .34369 Mdot
.874 .3443 Mdot
.874 .34501 Mdot
.874 .34522 Mdot
.874 .34622 Mdot
.874 .34627 Mdot
.874 .34651 Mdot
.874 .34664 Mdot
.874 .3467 Mdot
.874 .34697 Mdot
.874 .34704 Mdot
.874 .34838 Mdot
.874 .34871 Mdot
.874 .34905 Mdot
.874 .34948 Mdot
.874 .34949 Mdot
.874 .34962 Mdot
.874 .35047 Mdot
.874 .35089 Mdot
.874 .35102 Mdot
.874 .35126 Mdot
.874 .35168 Mdot
.874 .35232 Mdot
.874 .3527 Mdot
.874 .3529 Mdot
.874 .35323 Mdot
.874 .3533 Mdot
.874 .35354 Mdot
.874 .35412 Mdot
.874 .35589 Mdot
.874 .35606 Mdot
.874 .35642 Mdot
.874 .35842 Mdot
.874 .35857 Mdot
.874 .35864 Mdot
.874 .35882 Mdot
.874 .35956 Mdot
.874 .35972 Mdot
.874 .35972 Mdot
.874 .35981 Mdot
.874 .36005 Mdot
.874 .36013 Mdot
.874 .36031 Mdot
.874 .36033 Mdot
.874 .36079 Mdot
.874 .36083 Mdot
.874 .36094 Mdot
.874 .3619 Mdot
.874 .36209 Mdot
.874 .36232 Mdot
.874 .36243 Mdot
.874 .36267 Mdot
.874 .36301 Mdot
.874 .36311 Mdot
.874 .36312 Mdot
.874 .36326 Mdot
.874 .36345 Mdot
.874 .36374 Mdot
.874 .36388 Mdot
.874 .364 Mdot
.874 .36413 Mdot
.874 .36419 Mdot
.874 .36428 Mdot
.874 .3645 Mdot
.874 .36452 Mdot
.874 .36461 Mdot
.874 .36463 Mdot
.874 .36463 Mdot
.874 .36464 Mdot
.874 .46319 Mdot
.874 .4632 Mdot
.874 .4632 Mdot
.874 .46321 Mdot
.874 .46325 Mdot
.874 .46326 Mdot
.874 .46337 Mdot
.874 .46341 Mdot
.874 .46345 Mdot
.874 .46351 Mdot
.874 .46357 Mdot
.874 .46364 Mdot
.874 .46378 Mdot
.874 .46387 Mdot
.874 .46394 Mdot
.874 .46395 Mdot
.874 .464 Mdot
.874 .46417 Mdot
.874 .46429 Mdot
.874 .46434 Mdot
.874 .46446 Mdot
.874 .46455 Mdot
.874 .46502 Mdot
.874 .46508 Mdot
.874 .4651 Mdot
.874 .46532 Mdot
.874 .46533 Mdot
.874 .46542 Mdot
.874 .46546 Mdot
.874 .46558 Mdot
.874 .46562 Mdot
.874 .46562 Mdot
.874 .4657 Mdot
.874 .46606 Mdot
.874 .46615 Mdot
.874 .46618 Mdot
.874 .46626 Mdot
.874 .46724 Mdot
.874 .46741 Mdot
.874 .46749 Mdot
.874 .46835 Mdot
.874 .46864 Mdot
.874 .46875 Mdot
.874 .46878 Mdot
.874 .46894 Mdot
.874 .46904 Mdot
.874 .46922 Mdot
.874 .46953 Mdot
.874 .46974 Mdot
.874 .46985 Mdot
.874 .46991 Mdot
.874 .47012 Mdot
.874 .47052 Mdot
.874 .47058 Mdot
.874 .47059 Mdot
.874 .4708 Mdot
.874 .47096 Mdot
.874 .47112 Mdot
.874 .47176 Mdot
.874 .47179 Mdot
.874 .47192 Mdot
.874 .47195 Mdot
.874 .47201 Mdot
.874 .47212 Mdot
.874 .47215 Mdot
.874 .47262 Mdot
.874 .47273 Mdot
.874 .47306 Mdot
.874 .47335 Mdot
.874 .47339 Mdot
.874 .47376 Mdot
.874 .47398 Mdot
.874 .47402 Mdot
.874 .47452 Mdot
.874 .47458 Mdot
.874 .47461 Mdot
.874 .4747 Mdot
.874 .47493 Mdot
.874 .47502 Mdot
.874 .47527 Mdot
.874 .47567 Mdot
.874 .4757 Mdot
.874 .47609 Mdot
.874 .47621 Mdot
.874 .47645 Mdot
.874 .47653 Mdot
.874 .47656 Mdot
.874 .47696 Mdot
.874 .47734 Mdot
.874 .47739 Mdot
.874 .47882 Mdot
.874 .479 Mdot
.874 .47912 Mdot
.874 .47931 Mdot
.874 .47989 Mdot
.874 .48005 Mdot
.874 .48063 Mdot
.874 .48106 Mdot
.874 .48114 Mdot
.874 .48123 Mdot
.874 .48135 Mdot
.874 .48161 Mdot
.874 .48173 Mdot
.874 .48177 Mdot
.874 .48196 Mdot
.874 .48226 Mdot
.874 .48242 Mdot
.874 .48244 Mdot
.874 .48251 Mdot
.874 .48269 Mdot
.874 .48328 Mdot
.874 .48334 Mdot
.874 .48346 Mdot
.874 .48439 Mdot
.874 .48479 Mdot
.874 .48494 Mdot
.874 .48506 Mdot
.874 .48507 Mdot
.874 .48532 Mdot
.874 .48592 Mdot
.874 .48603 Mdot
.874 .48618 Mdot
.874 .48626 Mdot
.874 .48642 Mdot
.874 .48677 Mdot
.874 .48688 Mdot
.874 .48732 Mdot
.874 .48762 Mdot
.874 .48778 Mdot
.874 .48788 Mdot
.874 .48845 Mdot
.874 .4885 Mdot
.874 .48944 Mdot
.874 .48952 Mdot
.874 .48953 Mdot
.874 .48965 Mdot
.874 .49044 Mdot
.874 .49096 Mdot
.874 .49139 Mdot
.874 .49168 Mdot
.874 .49176 Mdot
.874 .49302 Mdot
.874 .4931 Mdot
.874 .49342 Mdot
.874 .49356 Mdot
.874 .4936 Mdot
.874 .49367 Mdot
.874 .49405 Mdot
.874 .49408 Mdot
.874 .49414 Mdot
.874 .49597 Mdot
.874 .49613 Mdot
.874 .49642 Mdot
.874 .49685 Mdot
.874 .49689 Mdot
.874 .49748 Mdot
.874 .4975 Mdot
.874 .49757 Mdot
.874 .4976 Mdot
.874 .4976 Mdot
.874 .49766 Mdot
.874 .49767 Mdot
.874 .4979 Mdot
.874 .49795 Mdot
.874 .49842 Mdot
.874 .49852 Mdot
.874 .49853 Mdot
.874 .49875 Mdot
.874 .49878 Mdot
.874 .49883 Mdot
.874 .49893 Mdot
.874 .49925 Mdot
.874 .49942 Mdot
.874 .49947 Mdot
.874 .49956 Mdot
.874 .4996 Mdot
.874 .49961 Mdot
.874 .49977 Mdot
.874 .49992 Mdot
.874 .49994 Mdot
.874 .5005 Mdot
.874 .50068 Mdot
.874 .5009 Mdot
.874 .50117 Mdot
.874 .50139 Mdot
.874 .50153 Mdot
.874 .50157 Mdot
.874 .50158 Mdot
.874 .50181 Mdot
.874 .50182 Mdot
.874 .50184 Mdot
.874 .50191 Mdot
.874 .50217 Mdot
.874 .50263 Mdot
.874 .50268 Mdot
.874 .50272 Mdot
.874 .50305 Mdot
.874 .50329 Mdot
.874 .50333 Mdot
.874 .50347 Mdot
.874 .50357 Mdot
.874 .50384 Mdot
.874 .50416 Mdot
.874 .50418 Mdot
.874 .50464 Mdot
.874 .50489 Mdot
.874 .50545 Mdot
.874 .50561 Mdot
.874 .50624 Mdot
.874 .50646 Mdot
.874 .50668 Mdot
.874 .50669 Mdot
.874 .50669 Mdot
.874 .50671 Mdot
.874 .50678 Mdot
.874 .50679 Mdot
.874 .50694 Mdot
.874 .50697 Mdot
.874 .50697 Mdot
.874 .50704 Mdot
.874 .50705 Mdot
.874 .50709 Mdot
.874 .50719 Mdot
.874 .50726 Mdot
.874 .50729 Mdot
.874 .5073 Mdot
.874 .50735 Mdot
.874 .5074 Mdot
.874 .50763 Mdot
.874 .50769 Mdot
.874 .50777 Mdot
.874 .50788 Mdot
.874 .50789 Mdot
.874 .5079 Mdot
.874 .50797 Mdot
.874 .50797 Mdot
.874 .50798 Mdot
.874 .50823 Mdot
.874 .50842 Mdot
.874 .50843 Mdot
.874 .50848 Mdot
.874 .5085 Mdot
.874 .50868 Mdot
.874 .50869 Mdot
.874 .50883 Mdot
.874 .50891 Mdot
.874 .50908 Mdot
.874 .50913 Mdot
.874 .50955 Mdot
.874 .50958 Mdot
.874 .50964 Mdot
.874 .50966 Mdot
.874 .50967 Mdot
.874 .50978 Mdot
.874 .50984 Mdot
.874 .50987 Mdot
.874 .50987 Mdot
.874 .51001 Mdot
.874 .51002 Mdot
.874 .51009 Mdot
.874 .51016 Mdot
.874 .51022 Mdot
.874 .51023 Mdot
.874 .5104 Mdot
.874 .51046 Mdot
.874 .51047 Mdot
.874 .51058 Mdot
.874 .51104 Mdot
.874 .51112 Mdot
.874 .51124 Mdot
.874 .51125 Mdot
.874 .51126 Mdot
.874 .51129 Mdot
.874 .51136 Mdot
.874 .5114 Mdot
.874 .51165 Mdot
.874 .51168 Mdot
.874 .51177 Mdot
.874 .51189 Mdot
.874 .512 Mdot
.874 .51203 Mdot
.874 .51227 Mdot
.874 .51227 Mdot
.874 .51231 Mdot
.874 .51242 Mdot
.874 .5126 Mdot
.874 .51262 Mdot
.874 .51264 Mdot
.874 .51275 Mdot
.874 .51279 Mdot
.874 .51281 Mdot
.874 .51305 Mdot
.874 .51317 Mdot
.874 .51348 Mdot
.874 .51356 Mdot
.874 .51384 Mdot
.874 .51396 Mdot
.874 .51419 Mdot
.874 .5142 Mdot
.874 .51435 Mdot
.874 .51448 Mdot
.874 .51453 Mdot
.874 .5146 Mdot
.874 .51461 Mdot
.874 .51473 Mdot
.874 .51488 Mdot
.874 .5149 Mdot
.874 .51493 Mdot
.874 .51514 Mdot
.874 .51526 Mdot
.874 .51529 Mdot
.874 .5153 Mdot
.874 .51531 Mdot
.874 .51541 Mdot
.874 .51542 Mdot
.874 .51544 Mdot
.874 .5155 Mdot
.874 .5156 Mdot
.874 .51573 Mdot
.874 .51582 Mdot
.874 .51591 Mdot
.874 .51616 Mdot
.874 .51616 Mdot
.874 .51623 Mdot
.874 .5163 Mdot
.874 .51631 Mdot
.874 .51632 Mdot
.874 .51637 Mdot
.874 .51639 Mdot
.874 .51646 Mdot
.874 .5166 Mdot
.874 .51665 Mdot
.874 .51667 Mdot
.874 .51668 Mdot
.874 .51678 Mdot
.874 .51678 Mdot
.874 .51683 Mdot
.874 .51703 Mdot
.874 .51705 Mdot
.874 .51715 Mdot
.874 .51716 Mdot
.874 .51718 Mdot
.874 .51718 Mdot
.874 .51719 Mdot
.874 .51723 Mdot
.874 .51723 Mdot
.874 .51749 Mdot
.874 .5175 Mdot
.874 .51768 Mdot
.874 .5178 Mdot
.874 .51787 Mdot
.874 .51863 Mdot
.874 .51865 Mdot
.874 .51866 Mdot
.874 .51881 Mdot
.874 .51884 Mdot
.874 .51886 Mdot
.874 .51892 Mdot
.874 .51904 Mdot
.874 .51908 Mdot
.874 .51958 Mdot
.874 .51961 Mdot
.874 .51972 Mdot
.874 .51989 Mdot
.874 .52009 Mdot
.874 .5204 Mdot
.874 .52044 Mdot
.874 .52044 Mdot
.874 .52047 Mdot
.874 .52083 Mdot
.874 .52085 Mdot
.874 .52106 Mdot
.874 .5211 Mdot
.874 .52116 Mdot
.874 .52127 Mdot
.874 .52143 Mdot
.874 .52148 Mdot
.874 .5216 Mdot
.874 .52166 Mdot
.874 .52169 Mdot
.874 .52174 Mdot
.874 .52179 Mdot
.874 .522 Mdot
.874 .52209 Mdot
.874 .5221 Mdot
.874 .52214 Mdot
.874 .5222 Mdot
.874 .52234 Mdot
.874 .52267 Mdot
.874 .52271 Mdot
.874 .52273 Mdot
.874 .52294 Mdot
.874 .523 Mdot
.874 .52303 Mdot
.874 .52304 Mdot
.874 .52309 Mdot
.874 .5232 Mdot
.874 .52326 Mdot
.874 .52328 Mdot
.874 .52332 Mdot
.874 .52341 Mdot
.874 .52345 Mdot
.874 .52348 Mdot
.874 .52351 Mdot
.874 .52366 Mdot
.874 .52385 Mdot
.874 .52391 Mdot
.874 .52411 Mdot
.874 .52417 Mdot
.874 .52421 Mdot
.874 .52427 Mdot
.874 .52475 Mdot
.874 .52477 Mdot
.874 .52489 Mdot
.874 .52502 Mdot
.874 .52504 Mdot
.874 .52506 Mdot
.874 .52514 Mdot
.874 .52518 Mdot
.874 .52531 Mdot
.874 .52532 Mdot
.874 .52545 Mdot
.874 .52553 Mdot
.874 .52556 Mdot
.874 .52563 Mdot
.874 .52566 Mdot
.874 .52567 Mdot
.874 .52569 Mdot
.874 .52585 Mdot
.874 .52586 Mdot
.874 .52593 Mdot
.874 .52605 Mdot
.874 .52616 Mdot
.874 .52626 Mdot
.874 .5263 Mdot
.874 .52645 Mdot
.874 .52646 Mdot
.874 .52649 Mdot
.874 .52651 Mdot
.874 .52652 Mdot
.874 .52656 Mdot
.874 .52657 Mdot
.874 .52677 Mdot
.874 .52682 Mdot
.874 .52687 Mdot
.874 .52694 Mdot
.874 .52694 Mdot
.874 .52696 Mdot
.874 .52708 Mdot
.874 .52715 Mdot
.874 .52717 Mdot
.874 .5272 Mdot
.874 .52726 Mdot
.874 .52736 Mdot
.874 .52742 Mdot
.874 .52745 Mdot
.874 .5275 Mdot
.874 .52751 Mdot
.874 .52754 Mdot
.874 .52763 Mdot
.874 .52789 Mdot
.874 .52791 Mdot
.874 .52797 Mdot
.874 .52826 Mdot
.874 .52829 Mdot
.874 .5283 Mdot
.874 .52832 Mdot
.874 .52843 Mdot
.874 .52845 Mdot
.874 .52845 Mdot
.874 .52847 Mdot
.874 .5285 Mdot
.874 .52851 Mdot
.874 .52854 Mdot
.874 .52854 Mdot
.874 .52861 Mdot
.874 .52862 Mdot
.874 .52863 Mdot
.874 .52877 Mdot
.874 .5288 Mdot
.874 .52884 Mdot
.874 .52885 Mdot
.874 .52889 Mdot
.874 .52894 Mdot
.874 .52895 Mdot
.874 .52895 Mdot
.874 .52897 Mdot
.874 .529 Mdot
.874 .52904 Mdot
.874 .52906 Mdot
.874 .52908 Mdot
.874 .5291 Mdot
.874 .52911 Mdot
.874 .52912 Mdot
.874 .52915 Mdot
.874 .52916 Mdot
.874 .52917 Mdot
.874 .52917 Mdot
.874 .52917 Mdot
.874 .52917 Mdot
.876 .21054 Mdot
.876 .21055 Mdot
.876 .21056 Mdot
.876 .21056 Mdot
.876 .21056 Mdot
.876 .21056 Mdot
.876 .21057 Mdot
.876 .21057 Mdot
.876 .21058 Mdot
.876 .2106 Mdot
.876 .21063 Mdot
.876 .21064 Mdot
.876 .21065 Mdot
.876 .21067 Mdot
.876 .21068 Mdot
.876 .2107 Mdot
.876 .21071 Mdot
.876 .21072 Mdot
.876 .21089 Mdot
.876 .21096 Mdot
.876 .21116 Mdot
.876 .21117 Mdot
.876 .21118 Mdot
.876 .21133 Mdot
.876 .21141 Mdot
.876 .21158 Mdot
.876 .21166 Mdot
.876 .21166 Mdot
.876 .21167 Mdot
.876 .21172 Mdot
.876 .21182 Mdot
.876 .21191 Mdot
.876 .21192 Mdot
.876 .21193 Mdot
.876 .21247 Mdot
.876 .21251 Mdot
.876 .21258 Mdot
.876 .21261 Mdot
.876 .21261 Mdot
.876 .21266 Mdot
.876 .2127 Mdot
.876 .21278 Mdot
.876 .21291 Mdot
.876 .21298 Mdot
.876 .21299 Mdot
.876 .21305 Mdot
.876 .21316 Mdot
.876 .21319 Mdot
.876 .21329 Mdot
.876 .21339 Mdot
.876 .21354 Mdot
.876 .2137 Mdot
.876 .21376 Mdot
.876 .21385 Mdot
.876 .21386 Mdot
.876 .21387 Mdot
.876 .21387 Mdot
.876 .21394 Mdot
.876 .21398 Mdot
.876 .21434 Mdot
.876 .21496 Mdot
.876 .2152 Mdot
.876 .2157 Mdot
.876 .21609 Mdot
.876 .21673 Mdot
.876 .21675 Mdot
.876 .21705 Mdot
.876 .21716 Mdot
.876 .21736 Mdot
.876 .21745 Mdot
.876 .21786 Mdot
.876 .21791 Mdot
.876 .21809 Mdot
.876 .21819 Mdot
.876 .21868 Mdot
.876 .2191 Mdot
.876 .21974 Mdot
.876 .21976 Mdot
.876 .21987 Mdot
.876 .21987 Mdot
.876 .21991 Mdot
.876 .21991 Mdot
.876 .22007 Mdot
.876 .22012 Mdot
.876 .22012 Mdot
.876 .22058 Mdot
.876 .22092 Mdot
.876 .22096 Mdot
.876 .22098 Mdot
.876 .22145 Mdot
.876 .22219 Mdot
.876 .22289 Mdot
.876 .2231 Mdot
.876 .22455 Mdot
.876 .22503 Mdot
.876 .22505 Mdot
.876 .22511 Mdot
.876 .22542 Mdot
.876 .22588 Mdot
.876 .22602 Mdot
.876 .22605 Mdot
.876 .22632 Mdot
.876 .22643 Mdot
.876 .22667 Mdot
.876 .22705 Mdot
.876 .22778 Mdot
.876 .22822 Mdot
.876 .2285 Mdot
.876 .22853 Mdot
.876 .22858 Mdot
.876 .22859 Mdot
.876 .22859 Mdot
.876 .2286 Mdot
.876 .22867 Mdot
.876 .22872 Mdot
.876 .22885 Mdot
.876 .22898 Mdot
.876 .22907 Mdot
.876 .22916 Mdot
.876 .22919 Mdot
.876 .22928 Mdot
.876 .22933 Mdot
.876 .22941 Mdot
.876 .22953 Mdot
.876 .22962 Mdot
.876 .22965 Mdot
.876 .22986 Mdot
.876 .23047 Mdot
.876 .23061 Mdot
.876 .23074 Mdot
.876 .23082 Mdot
.876 .23082 Mdot
.876 .23094 Mdot
.876 .23132 Mdot
.876 .23203 Mdot
.876 .23272 Mdot
.876 .23274 Mdot
.876 .23278 Mdot
.876 .23285 Mdot
.876 .2329 Mdot
.876 .23327 Mdot
.876 .23359 Mdot
.876 .2336 Mdot
.876 .23376 Mdot
.876 .23394 Mdot
.876 .23431 Mdot
.876 .23432 Mdot
.876 .23445 Mdot
.876 .23447 Mdot
.876 .23453 Mdot
.876 .23486 Mdot
.876 .23493 Mdot
.876 .23495 Mdot
.876 .23576 Mdot
.876 .23636 Mdot
.876 .23638 Mdot
.876 .2364 Mdot
.876 .23682 Mdot
.876 .23721 Mdot
.876 .23756 Mdot
.876 .23757 Mdot
.876 .23828 Mdot
.876 .23836 Mdot
.876 .23839 Mdot
.876 .23839 Mdot
.876 .23878 Mdot
.876 .24069 Mdot
.876 .24106 Mdot
.876 .24177 Mdot
.876 .24197 Mdot
.876 .24222 Mdot
.876 .24262 Mdot
.876 .24297 Mdot
.876 .24356 Mdot
.876 .24363 Mdot
.876 .24366 Mdot
.876 .24375 Mdot
.876 .24377 Mdot
.876 .24377 Mdot
.876 .24402 Mdot
.876 .2442 Mdot
.876 .24422 Mdot
.876 .24447 Mdot
.876 .24485 Mdot
.876 .24519 Mdot
.876 .24529 Mdot
.876 .2462 Mdot
.876 .24621 Mdot
.876 .24638 Mdot
.876 .24658 Mdot
.876 .24664 Mdot
.876 .24666 Mdot
.876 .24678 Mdot
.876 .24682 Mdot
.876 .24693 Mdot
.876 .24741 Mdot
.876 .2476 Mdot
.876 .24791 Mdot
.876 .24827 Mdot
.876 .24852 Mdot
.876 .24858 Mdot
.876 .24942 Mdot
.876 .24948 Mdot
.876 .24962 Mdot
.876 .25026 Mdot
.876 .25122 Mdot
.876 .25151 Mdot
.876 .25286 Mdot
.876 .25334 Mdot
.876 .25338 Mdot
.876 .25353 Mdot
.876 .2542 Mdot
.876 .25425 Mdot
.876 .25434 Mdot
.876 .2544 Mdot
.876 .25466 Mdot
.876 .25476 Mdot
.876 .25498 Mdot
.876 .25532 Mdot
.876 .25695 Mdot
.876 .25764 Mdot
.876 .2585 Mdot
.876 .25942 Mdot
.876 .25962 Mdot
.876 .25974 Mdot
.876 .25994 Mdot
.876 .25998 Mdot
.876 .26003 Mdot
.876 .26006 Mdot
.876 .26053 Mdot
.876 .26084 Mdot
.876 .26163 Mdot
.876 .26239 Mdot
.876 .26277 Mdot
.876 .2629 Mdot
.876 .26341 Mdot
.876 .26344 Mdot
.876 .2636 Mdot
.876 .26382 Mdot
.876 .26401 Mdot
.876 .26413 Mdot
.876 .26443 Mdot
.876 .2645 Mdot
.876 .26453 Mdot
.876 .26461 Mdot
.876 .26478 Mdot
.876 .26488 Mdot
.876 .26489 Mdot
.876 .26553 Mdot
.876 .266 Mdot
.876 .26616 Mdot
.876 .26617 Mdot
.876 .26645 Mdot
.876 .26645 Mdot
.876 .26647 Mdot
.876 .26654 Mdot
.876 .26659 Mdot
.876 .26698 Mdot
.876 .26721 Mdot
.876 .26748 Mdot
.876 .27012 Mdot
.876 .27012 Mdot
.876 .27014 Mdot
.876 .2702 Mdot
.876 .2707 Mdot
.876 .27072 Mdot
.876 .27125 Mdot
.876 .27156 Mdot
.876 .27157 Mdot
.876 .27158 Mdot
.876 .27203 Mdot
.876 .27264 Mdot
.876 .27296 Mdot
.876 .27341 Mdot
.876 .27393 Mdot
.876 .27422 Mdot
.876 .27426 Mdot
.876 .27432 Mdot
.876 .27435 Mdot
.876 .27437 Mdot
.876 .27549 Mdot
.876 .2759 Mdot
.876 .27608 Mdot
.876 .27619 Mdot
.876 .27671 Mdot
.876 .27688 Mdot
.876 .27691 Mdot
.876 .27698 Mdot
.876 .27708 Mdot
.876 .27716 Mdot
.876 .27728 Mdot
.876 .2773 Mdot
.876 .27739 Mdot
.876 .27746 Mdot
.876 .27757 Mdot
.876 .27768 Mdot
.876 .27773 Mdot
.876 .27779 Mdot
.876 .2778 Mdot
.876 .2778 Mdot
.876 .27781 Mdot
.876 .27785 Mdot
.876 .27788 Mdot
.876 .27812 Mdot
.876 .27852 Mdot
.876 .27953 Mdot
.876 .27975 Mdot
.876 .27985 Mdot
.876 .28011 Mdot
.876 .28013 Mdot
.876 .28027 Mdot
.876 .2807 Mdot
.876 .28106 Mdot
.876 .28108 Mdot
.876 .28302 Mdot
.876 .28324 Mdot
.876 .28398 Mdot
.876 .2848 Mdot
.876 .28536 Mdot
.876 .2854 Mdot
.876 .28579 Mdot
.876 .28634 Mdot
.876 .28634 Mdot
.876 .28639 Mdot
.876 .28659 Mdot
.876 .28664 Mdot
.876 .2868 Mdot
.876 .28812 Mdot
.876 .28889 Mdot
.876 .28977 Mdot
.876 .29033 Mdot
.876 .29078 Mdot
.876 .29239 Mdot
.876 .29322 Mdot
.876 .29761 Mdot
.876 .29851 Mdot
.876 .29852 Mdot
.876 .29858 Mdot
.876 .29877 Mdot
.876 .30043 Mdot
.876 .30047 Mdot
.876 .30128 Mdot
.876 .30221 Mdot
.876 .3032 Mdot
.876 .30324 Mdot
.876 .30328 Mdot
.876 .30473 Mdot
.876 .30667 Mdot
.876 .30671 Mdot
.876 .30688 Mdot
.876 .30767 Mdot
.876 .30783 Mdot
.876 .30786 Mdot
.876 .30818 Mdot
.876 .30821 Mdot
.876 .3091 Mdot
.876 .30953 Mdot
.876 .30992 Mdot
.876 .30994 Mdot
.876 .31073 Mdot
.876 .31163 Mdot
.876 .31175 Mdot
.876 .31192 Mdot
.876 .31204 Mdot
.876 .31208 Mdot
.876 .31376 Mdot
.876 .31552 Mdot
.876 .31647 Mdot
.876 .31676 Mdot
.876 .31677 Mdot
.876 .31697 Mdot
.876 .3173 Mdot
.876 .31764 Mdot
.876 .31918 Mdot
.876 .31969 Mdot
.876 .31976 Mdot
.876 .31998 Mdot
.876 .32028 Mdot
.876 .32049 Mdot
.876 .32062 Mdot
.876 .32086 Mdot
.876 .32093 Mdot
.876 .32116 Mdot
.876 .32138 Mdot
.876 .3217 Mdot
.876 .32202 Mdot
.876 .32215 Mdot
.876 .32234 Mdot
.876 .32235 Mdot
.876 .32237 Mdot
.876 .32239 Mdot
.876 .32252 Mdot
.876 .3226 Mdot
.876 .3233 Mdot
.876 .32442 Mdot
.876 .32628 Mdot
.876 .32726 Mdot
.876 .32788 Mdot
.876 .32816 Mdot
.876 .32886 Mdot
.876 .32892 Mdot
.876 .32929 Mdot
.876 .33048 Mdot
.876 .33128 Mdot
.876 .33142 Mdot
.876 .33147 Mdot
.876 .33273 Mdot
.876 .33651 Mdot
.876 .33705 Mdot
.876 .33888 Mdot
.876 .34086 Mdot
.876 .34209 Mdot
.876 .34215 Mdot
.876 .34225 Mdot
.876 .34314 Mdot
.876 .34438 Mdot
.876 .34439 Mdot
.876 .34451 Mdot
.876 .34493 Mdot
.876 .34494 Mdot
.876 .34504 Mdot
.876 .34505 Mdot
.876 .34535 Mdot
.876 .3454 Mdot
.876 .34709 Mdot
.876 .34821 Mdot
.876 .34954 Mdot
.876 .34979 Mdot
.876 .35028 Mdot
.876 .35041 Mdot
.876 .35153 Mdot
.876 .35177 Mdot
.876 .3523 Mdot
.876 .35259 Mdot
.876 .35341 Mdot
.876 .35346 Mdot
.876 .3552 Mdot
.876 .35625 Mdot
.876 .3575 Mdot
.876 .35761 Mdot
.876 .35826 Mdot
.876 .35994 Mdot
.876 .36093 Mdot
.876 .36104 Mdot
.876 .36122 Mdot
.876 .36124 Mdot
.876 .36127 Mdot
.876 .36128 Mdot
.876 .36154 Mdot
.876 .36171 Mdot
.876 .36213 Mdot
.876 .36254 Mdot
.876 .36281 Mdot
.876 .3631 Mdot
.876 .36318 Mdot
.876 .36346 Mdot
.876 .36362 Mdot
.876 .36367 Mdot
.876 .36386 Mdot
.876 .3642 Mdot
.876 .36444 Mdot
.876 .36452 Mdot
.876 .36467 Mdot
.876 .36468 Mdot
.876 .36475 Mdot
.876 .36495 Mdot
.876 .36507 Mdot
.876 .36654 Mdot
.876 .36655 Mdot
.876 .36658 Mdot
.876 .36684 Mdot
.876 .36711 Mdot
.876 .36726 Mdot
.876 .36727 Mdot
.876 .36728 Mdot
.876 .3675 Mdot
.876 .36796 Mdot
.876 .36818 Mdot
.876 .3686 Mdot
.876 .36862 Mdot
.876 .36865 Mdot
.876 .3692 Mdot
.876 .36939 Mdot
.876 .36987 Mdot
.876 .36988 Mdot
.876 .36992 Mdot
.876 .36996 Mdot
.876 .37 Mdot
.876 .37006 Mdot
.876 .37007 Mdot
.876 .37011 Mdot
.876 .3702 Mdot
.876 .37025 Mdot
.876 .37027 Mdot
.876 .37028 Mdot
.876 .3703 Mdot
.876 .37031 Mdot
.876 .37031 Mdot
.876 .37031 Mdot
.876 .37033 Mdot
.876 .37035 Mdot
.876 .46075 Mdot
.876 .46075 Mdot
.876 .46076 Mdot
.876 .46076 Mdot
.876 .46077 Mdot
.876 .46077 Mdot
.876 .46078 Mdot
.876 .46078 Mdot
.876 .46079 Mdot
.876 .46082 Mdot
.876 .46086 Mdot
.876 .46088 Mdot
.876 .46089 Mdot
.876 .46092 Mdot
.876 .46094 Mdot
.876 .46096 Mdot
.876 .46098 Mdot
.876 .46099 Mdot
.876 .46122 Mdot
.876 .46132 Mdot
.876 .4616 Mdot
.876 .46161 Mdot
.876 .46162 Mdot
.876 .46183 Mdot
.876 .46194 Mdot
.876 .46217 Mdot
.876 .46228 Mdot
.876 .46228 Mdot
.876 .46229 Mdot
.876 .46236 Mdot
.876 .4625 Mdot
.876 .46263 Mdot
.876 .46264 Mdot
.876 .46265 Mdot
.876 .46338 Mdot
.876 .46344 Mdot
.876 .46354 Mdot
.876 .46357 Mdot
.876 .46357 Mdot
.876 .46365 Mdot
.876 .46369 Mdot
.876 .46381 Mdot
.876 .46397 Mdot
.876 .46407 Mdot
.876 .46409 Mdot
.876 .46417 Mdot
.876 .46431 Mdot
.876 .46435 Mdot
.876 .46449 Mdot
.876 .46463 Mdot
.876 .46482 Mdot
.876 .46503 Mdot
.876 .46512 Mdot
.876 .46524 Mdot
.876 .46525 Mdot
.876 .46527 Mdot
.876 .46527 Mdot
.876 .46536 Mdot
.876 .46541 Mdot
.876 .4659 Mdot
.876 .46672 Mdot
.876 .46704 Mdot
.876 .4677 Mdot
.876 .46821 Mdot
.876 .46905 Mdot
.876 .46907 Mdot
.876 .46947 Mdot
.876 .4696 Mdot
.876 .46986 Mdot
.876 .46997 Mdot
.876 .47051 Mdot
.876 .47057 Mdot
.876 .47081 Mdot
.876 .47093 Mdot
.876 .47156 Mdot
.876 .47209 Mdot
.876 .4729 Mdot
.876 .47292 Mdot
.876 .47306 Mdot
.876 .47307 Mdot
.876 .47312 Mdot
.876 .47312 Mdot
.876 .47332 Mdot
.876 .47338 Mdot
.876 .47338 Mdot
.876 .47396 Mdot
.876 .47438 Mdot
.876 .47443 Mdot
.876 .47446 Mdot
.876 .47504 Mdot
.876 .47596 Mdot
.876 .47682 Mdot
.876 .47707 Mdot
.876 .47882 Mdot
.876 .4794 Mdot
.876 .47942 Mdot
.876 .47949 Mdot
.876 .47986 Mdot
.876 .4804 Mdot
.876 .48057 Mdot
.876 .4806 Mdot
.876 .48092 Mdot
.876 .48105 Mdot
.876 .48133 Mdot
.876 .48178 Mdot
.876 .48263 Mdot
.876 .48314 Mdot
.876 .48345 Mdot
.876 .48349 Mdot
.876 .48355 Mdot
.876 .48355 Mdot
.876 .48356 Mdot
.876 .48357 Mdot
.876 .48366 Mdot
.876 .48371 Mdot
.876 .48386 Mdot
.876 .484 Mdot
.876 .4841 Mdot
.876 .48421 Mdot
.876 .48424 Mdot
.876 .48435 Mdot
.876 .48441 Mdot
.876 .4845 Mdot
.876 .48463 Mdot
.876 .48473 Mdot
.876 .48477 Mdot
.876 .485 Mdot
.876 .48569 Mdot
.876 .48584 Mdot
.876 .48599 Mdot
.876 .48608 Mdot
.876 .48608 Mdot
.876 .48621 Mdot
.876 .48664 Mdot
.876 .48743 Mdot
.876 .48817 Mdot
.876 .48819 Mdot
.876 .48824 Mdot
.876 .48832 Mdot
.876 .48837 Mdot
.876 .48877 Mdot
.876 .48912 Mdot
.876 .48913 Mdot
.876 .4893 Mdot
.876 .4895 Mdot
.876 .48989 Mdot
.876 .4899 Mdot
.876 .49004 Mdot
.876 .49006 Mdot
.876 .49013 Mdot
.876 .49047 Mdot
.876 .49055 Mdot
.876 .49057 Mdot
.876 .49142 Mdot
.876 .49206 Mdot
.876 .49208 Mdot
.876 .4921 Mdot
.876 .49253 Mdot
.876 .49293 Mdot
.876 .49329 Mdot
.876 .49331 Mdot
.876 .49403 Mdot
.876 .49411 Mdot
.876 .49414 Mdot
.876 .49414 Mdot
.876 .49453 Mdot
.876 .49643 Mdot
.876 .49679 Mdot
.876 .49749 Mdot
.876 .49768 Mdot
.876 .49792 Mdot
.876 .4983 Mdot
.876 .49863 Mdot
.876 .4992 Mdot
.876 .49926 Mdot
.876 .49929 Mdot
.876 .49937 Mdot
.876 .49939 Mdot
.876 .49939 Mdot
.876 .49963 Mdot
.876 .49979 Mdot
.876 .49981 Mdot
.876 .50005 Mdot
.876 .5004 Mdot
.876 .50071 Mdot
.876 .50081 Mdot
.876 .50163 Mdot
.876 .50164 Mdot
.876 .50179 Mdot
.876 .50198 Mdot
.876 .50203 Mdot
.876 .50205 Mdot
.876 .50215 Mdot
.876 .5022 Mdot
.876 .50229 Mdot
.876 .50272 Mdot
.876 .50288 Mdot
.876 .50299 Mdot
.876 .503 Mdot
.876 .50302 Mdot
.876 .50302 Mdot
.876 .50302 Mdot
.876 .50302 Mdot
.876 .50305 Mdot
.876 .50307 Mdot
.876 .50312 Mdot
.876 .50316 Mdot
.876 .5032 Mdot
.876 .50323 Mdot
.876 .50324 Mdot
.876 .50329 Mdot
.876 .50332 Mdot
.876 .50337 Mdot
.876 .5034 Mdot
.876 .50341 Mdot
.876 .50348 Mdot
.876 .5037 Mdot
.876 .50375 Mdot
.876 .50382 Mdot
.876 .504 Mdot
.876 .50447 Mdot
.876 .50447 Mdot
.876 .50449 Mdot
.876 .50451 Mdot
.876 .50453 Mdot
.876 .50465 Mdot
.876 .50487 Mdot
.876 .50506 Mdot
.876 .50519 Mdot
.876 .50545 Mdot
.876 .50564 Mdot
.876 .50564 Mdot
.876 .50565 Mdot
.876 .50578 Mdot
.876 .506 Mdot
.876 .506 Mdot
.876 .50622 Mdot
.876 .50624 Mdot
.876 .50625 Mdot
.876 .50625 Mdot
.876 .50735 Mdot
.876 .50746 Mdot
.876 .50756 Mdot
.876 .50772 Mdot
.876 .50774 Mdot
.876 .50777 Mdot
.876 .50778 Mdot
.876 .50778 Mdot
.876 .5079 Mdot
.876 .5079 Mdot
.876 .50797 Mdot
.876 .50816 Mdot
.876 .50843 Mdot
.876 .50843 Mdot
.876 .50848 Mdot
.876 .50855 Mdot
.876 .50858 Mdot
.876 .50859 Mdot
.876 .50862 Mdot
.876 .50875 Mdot
.876 .50879 Mdot
.876 .50888 Mdot
.876 .50897 Mdot
.876 .50903 Mdot
.876 .50905 Mdot
.876 .50926 Mdot
.876 .50931 Mdot
.876 .50947 Mdot
.876 .50978 Mdot
.876 .51011 Mdot
.876 .51023 Mdot
.876 .51043 Mdot
.876 .51044 Mdot
.876 .51046 Mdot
.876 .51048 Mdot
.876 .51056 Mdot
.876 .51061 Mdot
.876 .51069 Mdot
.876 .51108 Mdot
.876 .51143 Mdot
.876 .51171 Mdot
.876 .51239 Mdot
.876 .51252 Mdot
.876 .51261 Mdot
.876 .51266 Mdot
.876 .51276 Mdot
.876 .51278 Mdot
.876 .51282 Mdot
.876 .51285 Mdot
.876 .51312 Mdot
.876 .51318 Mdot
.876 .5132 Mdot
.876 .51339 Mdot
.876 .51394 Mdot
.876 .51407 Mdot
.876 .51446 Mdot
.876 .51472 Mdot
.876 .51478 Mdot
.876 .5148 Mdot
.876 .51514 Mdot
.876 .51517 Mdot
.876 .51527 Mdot
.876 .51541 Mdot
.876 .51554 Mdot
.876 .51562 Mdot
.876 .51581 Mdot
.876 .51586 Mdot
.876 .51588 Mdot
.876 .51593 Mdot
.876 .51593 Mdot
.876 .51596 Mdot
.876 .51604 Mdot
.876 .51611 Mdot
.876 .51611 Mdot
.876 .51648 Mdot
.876 .51652 Mdot
.876 .51666 Mdot
.876 .51681 Mdot
.876 .51692 Mdot
.876 .51692 Mdot
.876 .517 Mdot
.876 .5171 Mdot
.876 .5171 Mdot
.876 .51711 Mdot
.876 .51714 Mdot
.876 .51715 Mdot
.876 .51718 Mdot
.876 .51742 Mdot
.876 .51757 Mdot
.876 .51773 Mdot
.876 .51783 Mdot
.876 .51791 Mdot
.876 .5182 Mdot
.876 .51835 Mdot
.876 .51912 Mdot
.876 .51927 Mdot
.876 .51927 Mdot
.876 .51928 Mdot
.876 .51932 Mdot
.876 .5196 Mdot
.876 .51961 Mdot
.876 .51975 Mdot
.876 .51991 Mdot
.876 .52008 Mdot
.876 .52008 Mdot
.876 .52009 Mdot
.876 .52033 Mdot
.876 .52066 Mdot
.876 .52067 Mdot
.876 .5207 Mdot
.876 .52083 Mdot
.876 .52085 Mdot
.876 .52086 Mdot
.876 .52091 Mdot
.876 .52092 Mdot
.876 .52106 Mdot
.876 .52114 Mdot
.876 .5212 Mdot
.876 .5212 Mdot
.876 .52133 Mdot
.876 .52148 Mdot
.876 .5215 Mdot
.876 .52153 Mdot
.876 .52155 Mdot
.876 .52155 Mdot
.876 .52183 Mdot
.876 .52211 Mdot
.876 .52227 Mdot
.876 .52231 Mdot
.876 .52232 Mdot
.876 .52235 Mdot
.876 .5224 Mdot
.876 .52246 Mdot
.876 .5227 Mdot
.876 .52278 Mdot
.876 .52279 Mdot
.876 .52283 Mdot
.876 .52288 Mdot
.876 .52291 Mdot
.876 .52293 Mdot
.876 .52297 Mdot
.876 .52298 Mdot
.876 .52302 Mdot
.876 .52305 Mdot
.876 .5231 Mdot
.876 .52315 Mdot
.876 .52317 Mdot
.876 .5232 Mdot
.876 .52321 Mdot
.876 .52321 Mdot
.876 .52321 Mdot
.876 .52323 Mdot
.876 .52324 Mdot
.876 .52335 Mdot
.876 .52353 Mdot
.876 .52382 Mdot
.876 .52397 Mdot
.876 .52407 Mdot
.876 .52411 Mdot
.876 .52422 Mdot
.876 .52423 Mdot
.876 .52429 Mdot
.876 .52447 Mdot
.876 .5246 Mdot
.876 .52462 Mdot
.876 .52463 Mdot
.876 .52482 Mdot
.876 .52539 Mdot
.876 .52548 Mdot
.876 .52575 Mdot
.876 .52605 Mdot
.876 .52623 Mdot
.876 .52624 Mdot
.876 .52626 Mdot
.876 .52639 Mdot
.876 .52658 Mdot
.876 .52658 Mdot
.876 .52659 Mdot
.876 .52666 Mdot
.876 .52666 Mdot
.876 .52667 Mdot
.876 .52668 Mdot
.876 .52672 Mdot
.876 .52673 Mdot
.876 .52698 Mdot
.876 .52714 Mdot
.876 .52734 Mdot
.876 .52738 Mdot
.876 .52745 Mdot
.876 .52747 Mdot
.876 .52763 Mdot
.876 .52767 Mdot
.876 .52775 Mdot
.876 .52779 Mdot
.876 .52791 Mdot
.876 .52791 Mdot
.876 .52817 Mdot
.876 .52832 Mdot
.876 .52852 Mdot
.876 .52861 Mdot
.876 .52886 Mdot
.876 .529 Mdot
.876 .52902 Mdot
.876 .52904 Mdot
.876 .52905 Mdot
.876 .52905 Mdot
.876 .52905 Mdot
.876 .52909 Mdot
.876 .52911 Mdot
.876 .52917 Mdot
.876 .52923 Mdot
.876 .52927 Mdot
.876 .52931 Mdot
.876 .52933 Mdot
.876 .52937 Mdot
.876 .52939 Mdot
.876 .5294 Mdot
.876 .52942 Mdot
.876 .52947 Mdot
.876 .52951 Mdot
.876 .52952 Mdot
.876 .52954 Mdot
.876 .52954 Mdot
.876 .52955 Mdot
.876 .52958 Mdot
.876 .5296 Mdot
.876 .52981 Mdot
.876 .52981 Mdot
.876 .52981 Mdot
.876 .52985 Mdot
.876 .52989 Mdot
.876 .52991 Mdot
.876 .52991 Mdot
.876 .52991 Mdot
.876 .52995 Mdot
.876 .53001 Mdot
.876 .53004 Mdot
.876 .5301 Mdot
.876 .53011 Mdot
.876 .53011 Mdot
.876 .53019 Mdot
.876 .53022 Mdot
.876 .53028 Mdot
.876 .53029 Mdot
.876 .53029 Mdot
.876 .5303 Mdot
.876 .5303 Mdot
.876 .53031 Mdot
.876 .53031 Mdot
.876 .53032 Mdot
.876 .53033 Mdot
.876 .53034 Mdot
.876 .53034 Mdot
.876 .53034 Mdot
.876 .53035 Mdot
.876 .53035 Mdot
.876 .53035 Mdot
.876 .53035 Mdot
.876 .53035 Mdot
.876 .53035 Mdot
.878 .20798 Mdot
.878 .20808 Mdot
.878 .2081 Mdot
.878 .2081 Mdot
.878 .20814 Mdot
.878 .20816 Mdot
.878 .2082 Mdot
.878 .20821 Mdot
.878 .20826 Mdot
.878 .20827 Mdot
.878 .20836 Mdot
.878 .20842 Mdot
.878 .20846 Mdot
.878 .20849 Mdot
.878 .20869 Mdot
.878 .20874 Mdot
.878 .20877 Mdot
.878 .20877 Mdot
.878 .2088 Mdot
.878 .20883 Mdot
.878 .20887 Mdot
.878 .20891 Mdot
.878 .20898 Mdot
.878 .209 Mdot
.878 .20927 Mdot
.878 .2094 Mdot
.878 .20995 Mdot
.878 .20998 Mdot
.878 .21001 Mdot
.878 .21001 Mdot
.878 .21004 Mdot
.878 .21011 Mdot
.878 .21037 Mdot
.878 .2105 Mdot
.878 .21062 Mdot
.878 .2109 Mdot
.878 .211 Mdot
.878 .21109 Mdot
.878 .21133 Mdot
.878 .21145 Mdot
.878 .21148 Mdot
.878 .21149 Mdot
.878 .21174 Mdot
.878 .21179 Mdot
.878 .2118 Mdot
.878 .21194 Mdot
.878 .21202 Mdot
.878 .21234 Mdot
.878 .21316 Mdot
.878 .21361 Mdot
.878 .21366 Mdot
.878 .21373 Mdot
.878 .21386 Mdot
.878 .21394 Mdot
.878 .21412 Mdot
.878 .21415 Mdot
.878 .2142 Mdot
.878 .2142 Mdot
.878 .21422 Mdot
.878 .21454 Mdot
.878 .21488 Mdot
.878 .21489 Mdot
.878 .21499 Mdot
.878 .2153 Mdot
.878 .21566 Mdot
.878 .21566 Mdot
.878 .21569 Mdot
.878 .21573 Mdot
.878 .21613 Mdot
.878 .21617 Mdot
.878 .21627 Mdot
.878 .21627 Mdot
.878 .21644 Mdot
.878 .21647 Mdot
.878 .21655 Mdot
.878 .21676 Mdot
.878 .21682 Mdot
.878 .21704 Mdot
.878 .21711 Mdot
.878 .2176 Mdot
.878 .21762 Mdot
.878 .21774 Mdot
.878 .21787 Mdot
.878 .21787 Mdot
.878 .21809 Mdot
.878 .21828 Mdot
.878 .2183 Mdot
.878 .21847 Mdot
.878 .21872 Mdot
.878 .21901 Mdot
.878 .21928 Mdot
.878 .21939 Mdot
.878 .21959 Mdot
.878 .2197 Mdot
.878 .21983 Mdot
.878 .21984 Mdot
.878 .21999 Mdot
.878 .22017 Mdot
.878 .22019 Mdot
.878 .2202 Mdot
.878 .22022 Mdot
.878 .22044 Mdot
.878 .22065 Mdot
.878 .22108 Mdot
.878 .22114 Mdot
.878 .22115 Mdot
.878 .2212 Mdot
.878 .22153 Mdot
.878 .22209 Mdot
.878 .22287 Mdot
.878 .22325 Mdot
.878 .22349 Mdot
.878 .22373 Mdot
.878 .22404 Mdot
.878 .22433 Mdot
.878 .22489 Mdot
.878 .22546 Mdot
.878 .22562 Mdot
.878 .22568 Mdot
.878 .22586 Mdot
.878 .22604 Mdot
.878 .22605 Mdot
.878 .22609 Mdot
.878 .2262 Mdot
.878 .22625 Mdot
.878 .22636 Mdot
.878 .22639 Mdot
.878 .2272 Mdot
.878 .22742 Mdot
.878 .22758 Mdot
.878 .22762 Mdot
.878 .22782 Mdot
.878 .22784 Mdot
.878 .22828 Mdot
.878 .22852 Mdot
.878 .229 Mdot
.878 .22906 Mdot
.878 .22909 Mdot
.878 .22915 Mdot
.878 .22976 Mdot
.878 .23029 Mdot
.878 .23032 Mdot
.878 .23042 Mdot
.878 .23064 Mdot
.878 .23077 Mdot
.878 .23114 Mdot
.878 .23143 Mdot
.878 .23183 Mdot
.878 .23206 Mdot
.878 .23222 Mdot
.878 .23231 Mdot
.878 .23322 Mdot
.878 .23427 Mdot
.878 .23449 Mdot
.878 .23463 Mdot
.878 .2348 Mdot
.878 .2352 Mdot
.878 .23529 Mdot
.878 .23585 Mdot
.878 .23589 Mdot
.878 .23594 Mdot
.878 .236 Mdot
.878 .23607 Mdot
.878 .23665 Mdot
.878 .23751 Mdot
.878 .23754 Mdot
.878 .23791 Mdot
.878 .23804 Mdot
.878 .23851 Mdot
.878 .23859 Mdot
.878 .2388 Mdot
.878 .23894 Mdot
.878 .23918 Mdot
.878 .2393 Mdot
.878 .24021 Mdot
.878 .24059 Mdot
.878 .24086 Mdot
.878 .2409 Mdot
.878 .24133 Mdot
.878 .24179 Mdot
.878 .24179 Mdot
.878 .24183 Mdot
.878 .24206 Mdot
.878 .24294 Mdot
.878 .24301 Mdot
.878 .24332 Mdot
.878 .24345 Mdot
.878 .24373 Mdot
.878 .24417 Mdot
.878 .24418 Mdot
.878 .24462 Mdot
.878 .24479 Mdot
.878 .24505 Mdot
.878 .24567 Mdot
.878 .2459 Mdot
.878 .24603 Mdot
.878 .2465 Mdot
.878 .24656 Mdot
.878 .24659 Mdot
.878 .24676 Mdot
.878 .2468 Mdot
.878 .24687 Mdot
.878 .24688 Mdot
.878 .2472 Mdot
.878 .24853 Mdot
.878 .24906 Mdot
.878 .24998 Mdot
.878 .25004 Mdot
.878 .25042 Mdot
.878 .25048 Mdot
.878 .25141 Mdot
.878 .25188 Mdot
.878 .2521 Mdot
.878 .25346 Mdot
.878 .25365 Mdot
.878 .25373 Mdot
.878 .25376 Mdot
.878 .25394 Mdot
.878 .25401 Mdot
.878 .25413 Mdot
.878 .25471 Mdot
.878 .25501 Mdot
.878 .25543 Mdot
.878 .25558 Mdot
.878 .25605 Mdot
.878 .25643 Mdot
.878 .25669 Mdot
.878 .25803 Mdot
.878 .25851 Mdot
.878 .25894 Mdot
.878 .25921 Mdot
.878 .26011 Mdot
.878 .26038 Mdot
.878 .26118 Mdot
.878 .26175 Mdot
.878 .26286 Mdot
.878 .2631 Mdot
.878 .26323 Mdot
.878 .26329 Mdot
.878 .26357 Mdot
.878 .26365 Mdot
.878 .26379 Mdot
.878 .26417 Mdot
.878 .265 Mdot
.878 .26546 Mdot
.878 .26621 Mdot
.878 .26624 Mdot
.878 .26653 Mdot
.878 .26684 Mdot
.878 .26727 Mdot
.878 .26788 Mdot
.878 .26795 Mdot
.878 .26812 Mdot
.878 .26821 Mdot
.878 .26882 Mdot
.878 .2701 Mdot
.878 .27014 Mdot
.878 .27022 Mdot
.878 .27064 Mdot
.878 .271 Mdot
.878 .27112 Mdot
.878 .27122 Mdot
.878 .27283 Mdot
.878 .27302 Mdot
.878 .27351 Mdot
.878 .27411 Mdot
.878 .27429 Mdot
.878 .27581 Mdot
.878 .27637 Mdot
.878 .27639 Mdot
.878 .27655 Mdot
.878 .27672 Mdot
.878 .27691 Mdot
.878 .2776 Mdot
.878 .27762 Mdot
.878 .27777 Mdot
.878 .27786 Mdot
.878 .27822 Mdot
.878 .27827 Mdot
.878 .27842 Mdot
.878 .27943 Mdot
.878 .27969 Mdot
.878 .27998 Mdot
.878 .28021 Mdot
.878 .28079 Mdot
.878 .28155 Mdot
.878 .28211 Mdot
.878 .28243 Mdot
.878 .28249 Mdot
.878 .28256 Mdot
.878 .283 Mdot
.878 .28322 Mdot
.878 .28345 Mdot
.878 .28347 Mdot
.878 .28348 Mdot
.878 .28369 Mdot
.878 .28386 Mdot
.878 .28387 Mdot
.878 .28401 Mdot
.878 .28433 Mdot
.878 .28445 Mdot
.878 .28508 Mdot
.878 .28536 Mdot
.878 .28555 Mdot
.878 .28579 Mdot
.878 .28605 Mdot
.878 .28605 Mdot
.878 .28621 Mdot
.878 .28637 Mdot
.878 .28696 Mdot
.878 .28705 Mdot
.878 .28731 Mdot
.878 .28739 Mdot
.878 .28764 Mdot
.878 .28775 Mdot
.878 .288 Mdot
.878 .28801 Mdot
.878 .28813 Mdot
.878 .28819 Mdot
.878 .2887 Mdot
.878 .28876 Mdot
.878 .28879 Mdot
.878 .2888 Mdot
.878 .28984 Mdot
.878 .29083 Mdot
.878 .29091 Mdot
.878 .29153 Mdot
.878 .29242 Mdot
.878 .29453 Mdot
.878 .29479 Mdot
.878 .29536 Mdot
.878 .29569 Mdot
.878 .29617 Mdot
.878 .29636 Mdot
.878 .29746 Mdot
.878 .29777 Mdot
.878 .29866 Mdot
.878 .29873 Mdot
.878 .30076 Mdot
.878 .30216 Mdot
.878 .30231 Mdot
.878 .30246 Mdot
.878 .30257 Mdot
.878 .30267 Mdot
.878 .30402 Mdot
.878 .30424 Mdot
.878 .30522 Mdot
.878 .30563 Mdot
.878 .30596 Mdot
.878 .30651 Mdot
.878 .30908 Mdot
.878 .31133 Mdot
.878 .31155 Mdot
.878 .31194 Mdot
.878 .31253 Mdot
.878 .31353 Mdot
.878 .31424 Mdot
.878 .31516 Mdot
.878 .31549 Mdot
.878 .31604 Mdot
.878 .31631 Mdot
.878 .31638 Mdot
.878 .31772 Mdot
.878 .31926 Mdot
.878 .31941 Mdot
.878 .31949 Mdot
.878 .31965 Mdot
.878 .32087 Mdot
.878 .32149 Mdot
.878 .32261 Mdot
.878 .32267 Mdot
.878 .32317 Mdot
.878 .32328 Mdot
.878 .32369 Mdot
.878 .32425 Mdot
.878 .32634 Mdot
.878 .32642 Mdot
.878 .32672 Mdot
.878 .32685 Mdot
.878 .32711 Mdot
.878 .32724 Mdot
.878 .32726 Mdot
.878 .32772 Mdot
.878 .3282 Mdot
.878 .32835 Mdot
.878 .32878 Mdot
.878 .33027 Mdot
.878 .33171 Mdot
.878 .33248 Mdot
.878 .3333 Mdot
.878 .33394 Mdot
.878 .33456 Mdot
.878 .33557 Mdot
.878 .33763 Mdot
.878 .33913 Mdot
.878 .34 Mdot
.878 .34015 Mdot
.878 .34016 Mdot
.878 .34033 Mdot
.878 .34147 Mdot
.878 .34205 Mdot
.878 .34264 Mdot
.878 .34269 Mdot
.878 .34271 Mdot
.878 .34276 Mdot
.878 .34325 Mdot
.878 .34367 Mdot
.878 .34369 Mdot
.878 .34405 Mdot
.878 .34433 Mdot
.878 .34486 Mdot
.878 .34515 Mdot
.878 .34591 Mdot
.878 .34667 Mdot
.878 .34735 Mdot
.878 .34781 Mdot
.878 .34787 Mdot
.878 .34837 Mdot
.878 .34897 Mdot
.878 .34899 Mdot
.878 .34933 Mdot
.878 .34965 Mdot
.878 .34971 Mdot
.878 .35104 Mdot
.878 .35124 Mdot
.878 .35182 Mdot
.878 .352 Mdot
.878 .35256 Mdot
.878 .3528 Mdot
.878 .35288 Mdot
.878 .35333 Mdot
.878 .35334 Mdot
.878 .35361 Mdot
.878 .35372 Mdot
.878 .35481 Mdot
.878 .35493 Mdot
.878 .355 Mdot
.878 .355 Mdot
.878 .35599 Mdot
.878 .35685 Mdot
.878 .3571 Mdot
.878 .35714 Mdot
.878 .35807 Mdot
.878 .35895 Mdot
.878 .359 Mdot
.878 .35902 Mdot
.878 .35915 Mdot
.878 .35922 Mdot
.878 .35971 Mdot
.878 .35995 Mdot
.878 .36029 Mdot
.878 .3605 Mdot
.878 .36064 Mdot
.878 .36186 Mdot
.878 .36415 Mdot
.878 .36503 Mdot
.878 .36526 Mdot
.878 .36564 Mdot
.878 .36565 Mdot
.878 .3658 Mdot
.878 .36648 Mdot
.878 .36652 Mdot
.878 .3666 Mdot
.878 .36694 Mdot
.878 .3676 Mdot
.878 .36785 Mdot
.878 .36813 Mdot
.878 .36891 Mdot
.878 .36924 Mdot
.878 .36961 Mdot
.878 .37033 Mdot
.878 .3706 Mdot
.878 .37061 Mdot
.878 .37069 Mdot
.878 .37077 Mdot
.878 .37229 Mdot
.878 .37266 Mdot
.878 .37341 Mdot
.878 .37347 Mdot
.878 .37367 Mdot
.878 .37377 Mdot
.878 .37388 Mdot
.878 .37398 Mdot
.878 .37406 Mdot
.878 .37406 Mdot
.878 .37413 Mdot
.878 .37428 Mdot
.878 .37482 Mdot
.878 .37493 Mdot
.878 .37505 Mdot
.878 .37519 Mdot
.878 .37545 Mdot
.878 .37549 Mdot
.878 .37561 Mdot
.878 .37564 Mdot
.878 .37576 Mdot
.878 .37581 Mdot
.878 .37592 Mdot
.878 .37592 Mdot
.878 .37597 Mdot
.878 .37625 Mdot
.878 .45818 Mdot
.878 .45832 Mdot
.878 .45835 Mdot
.878 .45835 Mdot
.878 .4584 Mdot
.878 .45843 Mdot
.878 .45849 Mdot
.878 .4585 Mdot
.878 .45856 Mdot
.878 .45858 Mdot
.878 .45872 Mdot
.878 .45879 Mdot
.878 .45885 Mdot
.878 .4589 Mdot
.878 .45918 Mdot
.878 .45925 Mdot
.878 .45929 Mdot
.878 .45929 Mdot
.878 .45933 Mdot
.878 .45938 Mdot
.878 .45943 Mdot
.878 .45948 Mdot
.878 .45958 Mdot
.878 .45961 Mdot
.878 .45999 Mdot
.878 .46018 Mdot
.878 .46094 Mdot
.878 .46098 Mdot
.878 .46102 Mdot
.878 .46102 Mdot
.878 .46116 Mdot
.878 .46152 Mdot
.878 .46171 Mdot
.878 .46187 Mdot
.878 .46226 Mdot
.878 .4624 Mdot
.878 .46252 Mdot
.878 .46284 Mdot
.878 .46302 Mdot
.878 .46306 Mdot
.878 .46307 Mdot
.878 .46341 Mdot
.878 .46348 Mdot
.878 .46349 Mdot
.878 .46368 Mdot
.878 .46379 Mdot
.878 .46423 Mdot
.878 .46535 Mdot
.878 .46594 Mdot
.878 .46601 Mdot
.878 .46611 Mdot
.878 .46628 Mdot
.878 .46639 Mdot
.878 .46663 Mdot
.878 .46667 Mdot
.878 .46673 Mdot
.878 .46674 Mdot
.878 .46677 Mdot
.878 .46719 Mdot
.878 .46764 Mdot
.878 .46766 Mdot
.878 .46779 Mdot
.878 .4682 Mdot
.878 .46868 Mdot
.878 .46868 Mdot
.878 .46871 Mdot
.878 .46877 Mdot
.878 .46929 Mdot
.878 .46934 Mdot
.878 .46947 Mdot
.878 .46948 Mdot
.878 .4697 Mdot
.878 .46973 Mdot
.878 .46985 Mdot
.878 .47012 Mdot
.878 .4702 Mdot
.878 .47048 Mdot
.878 .47058 Mdot
.878 .47121 Mdot
.878 .47124 Mdot
.878 .47139 Mdot
.878 .47156 Mdot
.878 .47157 Mdot
.878 .47185 Mdot
.878 .47208 Mdot
.878 .47211 Mdot
.878 .47233 Mdot
.878 .47265 Mdot
.878 .47302 Mdot
.878 .47337 Mdot
.878 .47351 Mdot
.878 .47376 Mdot
.878 .47389 Mdot
.878 .47406 Mdot
.878 .47407 Mdot
.878 .47427 Mdot
.878 .4745 Mdot
.878 .47452 Mdot
.878 .47453 Mdot
.878 .47455 Mdot
.878 .47483 Mdot
.878 .4751 Mdot
.878 .47563 Mdot
.878 .47571 Mdot
.878 .47572 Mdot
.878 .47579 Mdot
.878 .47619 Mdot
.878 .47689 Mdot
.878 .47785 Mdot
.878 .47831 Mdot
.878 .4786 Mdot
.878 .47889 Mdot
.878 .47927 Mdot
.878 .47962 Mdot
.878 .48028 Mdot
.878 .48097 Mdot
.878 .48116 Mdot
.878 .48123 Mdot
.878 .48145 Mdot
.878 .48166 Mdot
.878 .48167 Mdot
.878 .48172 Mdot
.878 .48184 Mdot
.878 .4819 Mdot
.878 .48204 Mdot
.878 .48208 Mdot
.878 .48302 Mdot
.878 .48328 Mdot
.878 .48346 Mdot
.878 .48351 Mdot
.878 .48374 Mdot
.878 .48376 Mdot
.878 .48427 Mdot
.878 .48455 Mdot
.878 .4851 Mdot
.878 .48517 Mdot
.878 .4852 Mdot
.878 .48527 Mdot
.878 .48596 Mdot
.878 .48656 Mdot
.878 .48659 Mdot
.878 .48671 Mdot
.878 .48696 Mdot
.878 .4871 Mdot
.878 .48752 Mdot
.878 .48783 Mdot
.878 .48828 Mdot
.878 .48854 Mdot
.878 .48871 Mdot
.878 .48881 Mdot
.878 .4898 Mdot
.878 .49093 Mdot
.878 .49117 Mdot
.878 .49132 Mdot
.878 .4915 Mdot
.878 .49193 Mdot
.878 .49203 Mdot
.878 .49261 Mdot
.878 .49266 Mdot
.878 .49271 Mdot
.878 .49277 Mdot
.878 .49284 Mdot
.878 .49345 Mdot
.878 .49433 Mdot
.878 .49436 Mdot
.878 .49475 Mdot
.878 .49488 Mdot
.878 .49536 Mdot
.878 .49544 Mdot
.878 .49564 Mdot
.878 .49579 Mdot
.878 .49603 Mdot
.878 .49615 Mdot
.878 .49706 Mdot
.878 .49744 Mdot
.878 .4977 Mdot
.878 .49774 Mdot
.878 .49816 Mdot
.878 .49861 Mdot
.878 .49861 Mdot
.878 .49862 Mdot
.878 .49865 Mdot
.878 .49887 Mdot
.878 .49889 Mdot
.878 .49895 Mdot
.878 .49895 Mdot
.878 .49905 Mdot
.878 .4991 Mdot
.878 .49921 Mdot
.878 .49924 Mdot
.878 .49936 Mdot
.878 .49939 Mdot
.878 .49964 Mdot
.878 .49971 Mdot
.878 .49978 Mdot
.878 .49978 Mdot
.878 .49989 Mdot
.878 .49999 Mdot
.878 .50007 Mdot
.878 .50019 Mdot
.878 .50046 Mdot
.878 .50051 Mdot
.878 .50065 Mdot
.878 .50071 Mdot
.878 .50071 Mdot
.878 .50078 Mdot
.878 .50087 Mdot
.878 .50088 Mdot
.878 .50089 Mdot
.878 .50098 Mdot
.878 .50108 Mdot
.878 .50126 Mdot
.878 .50129 Mdot
.878 .50132 Mdot
.878 .50146 Mdot
.878 .50169 Mdot
.878 .50201 Mdot
.878 .50226 Mdot
.878 .50235 Mdot
.878 .50248 Mdot
.878 .50259 Mdot
.878 .50301 Mdot
.878 .50308 Mdot
.878 .5031 Mdot
.878 .50325 Mdot
.878 .50329 Mdot
.878 .50335 Mdot
.878 .50336 Mdot
.878 .50365 Mdot
.878 .50373 Mdot
.878 .5038 Mdot
.878 .50387 Mdot
.878 .50387 Mdot
.878 .50411 Mdot
.878 .50475 Mdot
.878 .50482 Mdot
.878 .50508 Mdot
.878 .50528 Mdot
.878 .50536 Mdot
.878 .50603 Mdot
.878 .50608 Mdot
.878 .50613 Mdot
.878 .50627 Mdot
.878 .50645 Mdot
.878 .50648 Mdot
.878 .5065 Mdot
.878 .50704 Mdot
.878 .50729 Mdot
.878 .50733 Mdot
.878 .50739 Mdot
.878 .50743 Mdot
.878 .50768 Mdot
.878 .50786 Mdot
.878 .50799 Mdot
.878 .50811 Mdot
.878 .50812 Mdot
.878 .50843 Mdot
.878 .50862 Mdot
.878 .50896 Mdot
.878 .50912 Mdot
.878 .50918 Mdot
.878 .50921 Mdot
.878 .50933 Mdot
.878 .50935 Mdot
.878 .50941 Mdot
.878 .50951 Mdot
.878 .50996 Mdot
.878 .5102 Mdot
.878 .51053 Mdot
.878 .51064 Mdot
.878 .51101 Mdot
.878 .51112 Mdot
.878 .5113 Mdot
.878 .5115 Mdot
.878 .51205 Mdot
.878 .51215 Mdot
.878 .51231 Mdot
.878 .5125 Mdot
.878 .51256 Mdot
.878 .51273 Mdot
.878 .51286 Mdot
.878 .51309 Mdot
.878 .51315 Mdot
.878 .51317 Mdot
.878 .51325 Mdot
.878 .51326 Mdot
.878 .51329 Mdot
.878 .51337 Mdot
.878 .51393 Mdot
.878 .51401 Mdot
.878 .51421 Mdot
.878 .51459 Mdot
.878 .51461 Mdot
.878 .51477 Mdot
.878 .51479 Mdot
.878 .51517 Mdot
.878 .51538 Mdot
.878 .51592 Mdot
.878 .51605 Mdot
.878 .51605 Mdot
.878 .51608 Mdot
.878 .5161 Mdot
.878 .51617 Mdot
.878 .51618 Mdot
.878 .51621 Mdot
.878 .5164 Mdot
.878 .51645 Mdot
.878 .51654 Mdot
.878 .51679 Mdot
.878 .5169 Mdot
.878 .51697 Mdot
.878 .51714 Mdot
.878 .51715 Mdot
.878 .51733 Mdot
.878 .51744 Mdot
.878 .51749 Mdot
.878 .51762 Mdot
.878 .51764 Mdot
.878 .518 Mdot
.878 .51809 Mdot
.878 .51811 Mdot
.878 .51811 Mdot
.878 .51829 Mdot
.878 .51847 Mdot
.878 .51848 Mdot
.878 .51859 Mdot
.878 .51875 Mdot
.878 .51912 Mdot
.878 .51916 Mdot
.878 .51926 Mdot
.878 .51932 Mdot
.878 .5194 Mdot
.878 .51943 Mdot
.878 .51962 Mdot
.878 .51967 Mdot
.878 .51982 Mdot
.878 .51983 Mdot
.878 .52018 Mdot
.878 .52041 Mdot
.878 .52044 Mdot
.878 .52046 Mdot
.878 .52048 Mdot
.878 .5205 Mdot
.878 .52072 Mdot
.878 .52076 Mdot
.878 .52092 Mdot
.878 .52099 Mdot
.878 .52104 Mdot
.878 .52113 Mdot
.878 .52155 Mdot
.878 .52192 Mdot
.878 .52195 Mdot
.878 .52202 Mdot
.878 .52211 Mdot
.878 .52227 Mdot
.878 .52238 Mdot
.878 .52253 Mdot
.878 .52258 Mdot
.878 .52267 Mdot
.878 .52271 Mdot
.878 .52272 Mdot
.878 .52294 Mdot
.878 .52318 Mdot
.878 .5232 Mdot
.878 .52321 Mdot
.878 .52324 Mdot
.878 .52343 Mdot
.878 .52353 Mdot
.878 .5237 Mdot
.878 .52371 Mdot
.878 .52379 Mdot
.878 .5238 Mdot
.878 .52387 Mdot
.878 .52395 Mdot
.878 .52427 Mdot
.878 .52429 Mdot
.878 .52433 Mdot
.878 .52435 Mdot
.878 .52439 Mdot
.878 .52441 Mdot
.878 .52442 Mdot
.878 .52449 Mdot
.878 .52456 Mdot
.878 .52458 Mdot
.878 .52465 Mdot
.878 .52487 Mdot
.878 .52509 Mdot
.878 .52521 Mdot
.878 .52533 Mdot
.878 .52543 Mdot
.878 .52552 Mdot
.878 .52567 Mdot
.878 .52598 Mdot
.878 .5262 Mdot
.878 .52633 Mdot
.878 .52636 Mdot
.878 .52636 Mdot
.878 .52638 Mdot
.878 .52655 Mdot
.878 .52664 Mdot
.878 .52672 Mdot
.878 .52673 Mdot
.878 .52673 Mdot
.878 .52674 Mdot
.878 .52681 Mdot
.878 .52687 Mdot
.878 .52688 Mdot
.878 .52693 Mdot
.878 .52697 Mdot
.878 .52705 Mdot
.878 .52709 Mdot
.878 .5272 Mdot
.878 .52731 Mdot
.878 .52741 Mdot
.878 .52748 Mdot
.878 .52749 Mdot
.878 .52756 Mdot
.878 .52765 Mdot
.878 .52765 Mdot
.878 .5277 Mdot
.878 .52775 Mdot
.878 .52775 Mdot
.878 .52795 Mdot
.878 .52798 Mdot
.878 .52806 Mdot
.878 .52809 Mdot
.878 .52817 Mdot
.878 .5282 Mdot
.878 .52821 Mdot
.878 .52828 Mdot
.878 .52828 Mdot
.878 .52832 Mdot
.878 .52834 Mdot
.878 .52849 Mdot
.878 .52851 Mdot
.878 .52852 Mdot
.878 .52852 Mdot
.878 .52866 Mdot
.878 .52878 Mdot
.878 .52882 Mdot
.878 .52883 Mdot
.878 .52896 Mdot
.878 .52909 Mdot
.878 .52909 Mdot
.878 .52909 Mdot
.878 .52911 Mdot
.878 .52912 Mdot
.878 .52919 Mdot
.878 .52923 Mdot
.878 .52928 Mdot
.878 .52931 Mdot
.878 .52933 Mdot
.878 .5295 Mdot
.878 .52982 Mdot
.878 .52995 Mdot
.878 .52998 Mdot
.878 .53004 Mdot
.878 .53004 Mdot
.878 .53006 Mdot
.878 .53016 Mdot
.878 .53016 Mdot
.878 .53017 Mdot
.878 .53022 Mdot
.878 .53031 Mdot
.878 .53035 Mdot
.878 .53039 Mdot
.878 .5305 Mdot
.878 .53054 Mdot
.878 .5306 Mdot
.878 .5307 Mdot
.878 .53072 Mdot
.878 .53074 Mdot
.878 .53074 Mdot
.878 .53075 Mdot
.878 .53076 Mdot
.878 .53097 Mdot
.878 .53103 Mdot
.878 .53113 Mdot
.878 .53114 Mdot
.878 .53117 Mdot
.878 .53118 Mdot
.878 .5312 Mdot
.878 .53121 Mdot
.878 .53122 Mdot
.878 .53122 Mdot
.878 .53123 Mdot
.878 .53125 Mdot
.878 .53133 Mdot
.878 .53135 Mdot
.878 .53136 Mdot
.878 .53138 Mdot
.878 .53142 Mdot
.878 .53144 Mdot
.878 .53144 Mdot
.878 .53146 Mdot
.878 .53147 Mdot
.878 .53148 Mdot
.878 .53148 Mdot
.878 .53149 Mdot
.878 .53153 Mdot
.88 .2054 Mdot
.88 .2054 Mdot
.88 .20541 Mdot
.88 .20541 Mdot
.88 .20543 Mdot
.88 .20544 Mdot
.88 .20545 Mdot
.88 .20546 Mdot
.88 .2055 Mdot
.88 .20551 Mdot
.88 .20562 Mdot
.88 .20563 Mdot
.88 .20563 Mdot
.88 .20567 Mdot
.88 .20577 Mdot
.88 .20588 Mdot
.88 .20589 Mdot
.88 .20591 Mdot
.88 .20617 Mdot
.88 .2062 Mdot
.88 .20623 Mdot
.88 .20627 Mdot
.88 .20627 Mdot
.88 .20637 Mdot
.88 .20656 Mdot
.88 .20656 Mdot
.88 .20657 Mdot
.88 .20659 Mdot
.88 .20661 Mdot
.88 .20664 Mdot
.88 .20665 Mdot
.88 .20667 Mdot
.88 .20667 Mdot
.88 .20677 Mdot
.88 .20679 Mdot
.88 .20705 Mdot
.88 .20706 Mdot
.88 .20708 Mdot
.88 .20716 Mdot
.88 .20741 Mdot
.88 .20749 Mdot
.88 .2075 Mdot
.88 .20755 Mdot
.88 .20773 Mdot
.88 .20776 Mdot
.88 .2078 Mdot
.88 .20814 Mdot
.88 .2082 Mdot
.88 .20822 Mdot
.88 .20855 Mdot
.88 .20858 Mdot
.88 .20862 Mdot
.88 .20872 Mdot
.88 .20882 Mdot
.88 .20896 Mdot
.88 .20898 Mdot
.88 .20925 Mdot
.88 .2093 Mdot
.88 .20942 Mdot
.88 .20943 Mdot
.88 .21003 Mdot
.88 .21003 Mdot
.88 .21007 Mdot
.88 .21013 Mdot
.88 .2102 Mdot
.88 .21022 Mdot
.88 .21035 Mdot
.88 .21039 Mdot
.88 .21047 Mdot
.88 .21049 Mdot
.88 .21077 Mdot
.88 .21091 Mdot
.88 .21097 Mdot
.88 .21098 Mdot
.88 .21105 Mdot
.88 .21139 Mdot
.88 .21185 Mdot
.88 .21209 Mdot
.88 .21215 Mdot
.88 .21216 Mdot
.88 .21217 Mdot
.88 .21217 Mdot
.88 .21226 Mdot
.88 .21262 Mdot
.88 .21267 Mdot
.88 .2128 Mdot
.88 .213 Mdot
.88 .21392 Mdot
.88 .21411 Mdot
.88 .21423 Mdot
.88 .21431 Mdot
.88 .21436 Mdot
.88 .21441 Mdot
.88 .21456 Mdot
.88 .21464 Mdot
.88 .21486 Mdot
.88 .21548 Mdot
.88 .21563 Mdot
.88 .21576 Mdot
.88 .21579 Mdot
.88 .21599 Mdot
.88 .21601 Mdot
.88 .21604 Mdot
.88 .21735 Mdot
.88 .21736 Mdot
.88 .21766 Mdot
.88 .21793 Mdot
.88 .21802 Mdot
.88 .2182 Mdot
.88 .21841 Mdot
.88 .21855 Mdot
.88 .21941 Mdot
.88 .22009 Mdot
.88 .22066 Mdot
.88 .22084 Mdot
.88 .2211 Mdot
.88 .22176 Mdot
.88 .22201 Mdot
.88 .22246 Mdot
.88 .22267 Mdot
.88 .22279 Mdot
.88 .22334 Mdot
.88 .22345 Mdot
.88 .22357 Mdot
.88 .22405 Mdot
.88 .22515 Mdot
.88 .22558 Mdot
.88 .22594 Mdot
.88 .2268 Mdot
.88 .22681 Mdot
.88 .22693 Mdot
.88 .22743 Mdot
.88 .22774 Mdot
.88 .22838 Mdot
.88 .22931 Mdot
.88 .22983 Mdot
.88 .2305 Mdot
.88 .23052 Mdot
.88 .23103 Mdot
.88 .23115 Mdot
.88 .23157 Mdot
.88 .23159 Mdot
.88 .23184 Mdot
.88 .23194 Mdot
.88 .2323 Mdot
.88 .23246 Mdot
.88 .23251 Mdot
.88 .23286 Mdot
.88 .23297 Mdot
.88 .23319 Mdot
.88 .2339 Mdot
.88 .23393 Mdot
.88 .23429 Mdot
.88 .23461 Mdot
.88 .2351 Mdot
.88 .23515 Mdot
.88 .2352 Mdot
.88 .23526 Mdot
.88 .23541 Mdot
.88 .2368 Mdot
.88 .23686 Mdot
.88 .23721 Mdot
.88 .23744 Mdot
.88 .23752 Mdot
.88 .23781 Mdot
.88 .23908 Mdot
.88 .23962 Mdot
.88 .23967 Mdot
.88 .24017 Mdot
.88 .24032 Mdot
.88 .24037 Mdot
.88 .24064 Mdot
.88 .24074 Mdot
.88 .24086 Mdot
.88 .24148 Mdot
.88 .24154 Mdot
.88 .24172 Mdot
.88 .24188 Mdot
.88 .24245 Mdot
.88 .24311 Mdot
.88 .24338 Mdot
.88 .24542 Mdot
.88 .24597 Mdot
.88 .24703 Mdot
.88 .24737 Mdot
.88 .2476 Mdot
.88 .24794 Mdot
.88 .24812 Mdot
.88 .24837 Mdot
.88 .24859 Mdot
.88 .24898 Mdot
.88 .24954 Mdot
.88 .24996 Mdot
.88 .25048 Mdot
.88 .25051 Mdot
.88 .25062 Mdot
.88 .25069 Mdot
.88 .25072 Mdot
.88 .25156 Mdot
.88 .25163 Mdot
.88 .25199 Mdot
.88 .25318 Mdot
.88 .25393 Mdot
.88 .25502 Mdot
.88 .25512 Mdot
.88 .25547 Mdot
.88 .25568 Mdot
.88 .25619 Mdot
.88 .25676 Mdot
.88 .25688 Mdot
.88 .25712 Mdot
.88 .25771 Mdot
.88 .25812 Mdot
.88 .25878 Mdot
.88 .25898 Mdot
.88 .25902 Mdot
.88 .25949 Mdot
.88 .25951 Mdot
.88 .25955 Mdot
.88 .25961 Mdot
.88 .25992 Mdot
.88 .26108 Mdot
.88 .26127 Mdot
.88 .26255 Mdot
.88 .26378 Mdot
.88 .26492 Mdot
.88 .26565 Mdot
.88 .26568 Mdot
.88 .26578 Mdot
.88 .2661 Mdot
.88 .26613 Mdot
.88 .26648 Mdot
.88 .26731 Mdot
.88 .2675 Mdot
.88 .26755 Mdot
.88 .2677 Mdot
.88 .26793 Mdot
.88 .26797 Mdot
.88 .26891 Mdot
.88 .26901 Mdot
.88 .26905 Mdot
.88 .26946 Mdot
.88 .26968 Mdot
.88 .26993 Mdot
.88 .27044 Mdot
.88 .2706 Mdot
.88 .27097 Mdot
.88 .27108 Mdot
.88 .27134 Mdot
.88 .27159 Mdot
.88 .27161 Mdot
.88 .27191 Mdot
.88 .27237 Mdot
.88 .27289 Mdot
.88 .27328 Mdot
.88 .274 Mdot
.88 .27449 Mdot
.88 .27513 Mdot
.88 .27522 Mdot
.88 .27523 Mdot
.88 .27593 Mdot
.88 .27622 Mdot
.88 .27751 Mdot
.88 .27792 Mdot
.88 .27802 Mdot
.88 .27871 Mdot
.88 .27889 Mdot
.88 .27952 Mdot
.88 .28013 Mdot
.88 .28037 Mdot
.88 .28054 Mdot
.88 .2826 Mdot
.88 .28274 Mdot
.88 .28314 Mdot
.88 .28324 Mdot
.88 .28383 Mdot
.88 .28528 Mdot
.88 .28533 Mdot
.88 .28555 Mdot
.88 .28574 Mdot
.88 .28664 Mdot
.88 .28691 Mdot
.88 .28699 Mdot
.88 .28724 Mdot
.88 .2873 Mdot
.88 .2874 Mdot
.88 .28754 Mdot
.88 .28778 Mdot
.88 .28897 Mdot
.88 .28924 Mdot
.88 .28942 Mdot
.88 .28948 Mdot
.88 .28997 Mdot
.88 .29009 Mdot
.88 .2901 Mdot
.88 .29013 Mdot
.88 .29021 Mdot
.88 .29056 Mdot
.88 .29174 Mdot
.88 .29185 Mdot
.88 .29186 Mdot
.88 .29196 Mdot
.88 .29263 Mdot
.88 .29266 Mdot
.88 .29278 Mdot
.88 .29284 Mdot
.88 .29306 Mdot
.88 .2931 Mdot
.88 .29321 Mdot
.88 .29332 Mdot
.88 .29339 Mdot
.88 .29339 Mdot
.88 .29467 Mdot
.88 .29528 Mdot
.88 .29532 Mdot
.88 .29559 Mdot
.88 .29579 Mdot
.88 .29599 Mdot
.88 .29613 Mdot
.88 .29682 Mdot
.88 .29701 Mdot
.88 .29777 Mdot
.88 .29787 Mdot
.88 .29794 Mdot
.88 .29838 Mdot
.88 .29853 Mdot
.88 .29872 Mdot
.88 .29939 Mdot
.88 .29962 Mdot
.88 .29968 Mdot
.88 .29969 Mdot
.88 .30047 Mdot
.88 .30051 Mdot
.88 .30084 Mdot
.88 .30085 Mdot
.88 .30094 Mdot
.88 .30105 Mdot
.88 .30112 Mdot
.88 .30118 Mdot
.88 .30121 Mdot
.88 .30122 Mdot
.88 .30189 Mdot
.88 .30226 Mdot
.88 .30242 Mdot
.88 .30254 Mdot
.88 .30266 Mdot
.88 .30387 Mdot
.88 .30464 Mdot
.88 .30553 Mdot
.88 .3056 Mdot
.88 .30735 Mdot
.88 .30789 Mdot
.88 .30818 Mdot
.88 .30905 Mdot
.88 .30918 Mdot
.88 .30958 Mdot
.88 .31048 Mdot
.88 .31074 Mdot
.88 .31135 Mdot
.88 .31142 Mdot
.88 .31247 Mdot
.88 .31278 Mdot
.88 .31406 Mdot
.88 .31411 Mdot
.88 .31582 Mdot
.88 .31715 Mdot
.88 .31955 Mdot
.88 .32119 Mdot
.88 .32199 Mdot
.88 .3233 Mdot
.88 .3236 Mdot
.88 .32363 Mdot
.88 .32587 Mdot
.88 .32683 Mdot
.88 .32795 Mdot
.88 .33087 Mdot
.88 .33215 Mdot
.88 .33246 Mdot
.88 .33276 Mdot
.88 .33421 Mdot
.88 .33454 Mdot
.88 .3351 Mdot
.88 .33632 Mdot
.88 .33698 Mdot
.88 .33876 Mdot
.88 .33946 Mdot
.88 .33994 Mdot
.88 .34148 Mdot
.88 .34333 Mdot
.88 .34567 Mdot
.88 .34606 Mdot
.88 .34665 Mdot
.88 .34713 Mdot
.88 .34738 Mdot
.88 .34811 Mdot
.88 .34894 Mdot
.88 .34897 Mdot
.88 .35257 Mdot
.88 .35264 Mdot
.88 .35271 Mdot
.88 .3531 Mdot
.88 .35325 Mdot
.88 .35335 Mdot
.88 .3537 Mdot
.88 .35411 Mdot
.88 .35583 Mdot
.88 .35645 Mdot
.88 .35665 Mdot
.88 .35709 Mdot
.88 .35723 Mdot
.88 .35736 Mdot
.88 .35758 Mdot
.88 .3579 Mdot
.88 .35844 Mdot
.88 .36099 Mdot
.88 .36156 Mdot
.88 .36193 Mdot
.88 .36206 Mdot
.88 .36306 Mdot
.88 .36331 Mdot
.88 .36331 Mdot
.88 .36333 Mdot
.88 .36337 Mdot
.88 .36353 Mdot
.88 .36422 Mdot
.88 .3655 Mdot
.88 .36645 Mdot
.88 .36665 Mdot
.88 .36667 Mdot
.88 .36684 Mdot
.88 .36725 Mdot
.88 .36803 Mdot
.88 .36808 Mdot
.88 .3683 Mdot
.88 .3684 Mdot
.88 .36877 Mdot
.88 .36884 Mdot
.88 .36902 Mdot
.88 .3692 Mdot
.88 .36932 Mdot
.88 .36933 Mdot
.88 .37099 Mdot
.88 .37103 Mdot
.88 .37136 Mdot
.88 .37149 Mdot
.88 .37228 Mdot
.88 .37232 Mdot
.88 .37272 Mdot
.88 .37301 Mdot
.88 .37328 Mdot
.88 .37339 Mdot
.88 .37347 Mdot
.88 .37439 Mdot
.88 .37446 Mdot
.88 .37464 Mdot
.88 .37558 Mdot
.88 .37571 Mdot
.88 .37579 Mdot
.88 .3763 Mdot
.88 .37645 Mdot
.88 .37647 Mdot
.88 .37668 Mdot
.88 .37739 Mdot
.88 .37763 Mdot
.88 .37769 Mdot
.88 .3777 Mdot
.88 .37844 Mdot
.88 .37848 Mdot
.88 .37877 Mdot
.88 .37878 Mdot
.88 .37884 Mdot
.88 .37886 Mdot
.88 .37896 Mdot
.88 .37902 Mdot
.88 .37906 Mdot
.88 .37909 Mdot
.88 .3791 Mdot
.88 .37964 Mdot
.88 .3799 Mdot
.88 .37991 Mdot
.88 .38003 Mdot
.88 .38011 Mdot
.88 .38019 Mdot
.88 .38094 Mdot
.88 .38098 Mdot
.88 .38101 Mdot
.88 .38134 Mdot
.88 .38161 Mdot
.88 .38171 Mdot
.88 .38173 Mdot
.88 .38174 Mdot
.88 .38206 Mdot
.88 .38208 Mdot
.88 .38221 Mdot
.88 .38222 Mdot
.88 .38225 Mdot
.88 .3823 Mdot
.88 .38233 Mdot
.88 .38235 Mdot
.88 .38237 Mdot
.88 .38237 Mdot
.88 .45548 Mdot
.88 .45548 Mdot
.88 .45549 Mdot
.88 .4555 Mdot
.88 .45552 Mdot
.88 .45554 Mdot
.88 .45556 Mdot
.88 .45556 Mdot
.88 .45563 Mdot
.88 .45564 Mdot
.88 .4558 Mdot
.88 .45581 Mdot
.88 .45582 Mdot
.88 .45587 Mdot
.88 .45601 Mdot
.88 .45618 Mdot
.88 .45619 Mdot
.88 .45621 Mdot
.88 .45659 Mdot
.88 .45664 Mdot
.88 .45668 Mdot
.88 .45674 Mdot
.88 .45674 Mdot
.88 .45688 Mdot
.88 .45715 Mdot
.88 .45715 Mdot
.88 .45717 Mdot
.88 .45719 Mdot
.88 .45722 Mdot
.88 .45727 Mdot
.88 .45728 Mdot
.88 .45731 Mdot
.88 .45732 Mdot
.88 .45746 Mdot
.88 .45748 Mdot
.88 .45786 Mdot
.88 .45787 Mdot
.88 .4579 Mdot
.88 .45802 Mdot
.88 .45838 Mdot
.88 .45848 Mdot
.88 .4585 Mdot
.88 .45857 Mdot
.88 .45883 Mdot
.88 .45887 Mdot
.88 .45893 Mdot
.88 .45941 Mdot
.88 .4595 Mdot
.88 .45953 Mdot
.88 .46 Mdot
.88 .46003 Mdot
.88 .46009 Mdot
.88 .46023 Mdot
.88 .46037 Mdot
.88 .46057 Mdot
.88 .46059 Mdot
.88 .46098 Mdot
.88 .46105 Mdot
.88 .46121 Mdot
.88 .46124 Mdot
.88 .46206 Mdot
.88 .46207 Mdot
.88 .46213 Mdot
.88 .46221 Mdot
.88 .4623 Mdot
.88 .46234 Mdot
.88 .46252 Mdot
.88 .46257 Mdot
.88 .46268 Mdot
.88 .46271 Mdot
.88 .46309 Mdot
.88 .46329 Mdot
.88 .46338 Mdot
.88 .46338 Mdot
.88 .46349 Mdot
.88 .46395 Mdot
.88 .46458 Mdot
.88 .46492 Mdot
.88 .465 Mdot
.88 .46501 Mdot
.88 .46502 Mdot
.88 .46503 Mdot
.88 .46515 Mdot
.88 .46563 Mdot
.88 .4657 Mdot
.88 .46588 Mdot
.88 .46615 Mdot
.88 .4674 Mdot
.88 .46765 Mdot
.88 .46781 Mdot
.88 .46792 Mdot
.88 .46798 Mdot
.88 .46805 Mdot
.88 .46826 Mdot
.88 .46835 Mdot
.88 .46865 Mdot
.88 .46948 Mdot
.88 .46967 Mdot
.88 .46984 Mdot
.88 .46989 Mdot
.88 .47014 Mdot
.88 .47018 Mdot
.88 .47021 Mdot
.88 .47192 Mdot
.88 .47194 Mdot
.88 .47233 Mdot
.88 .47268 Mdot
.88 .47279 Mdot
.88 .47302 Mdot
.88 .4733 Mdot
.88 .47348 Mdot
.88 .47458 Mdot
.88 .47544 Mdot
.88 .47616 Mdot
.88 .47638 Mdot
.88 .47671 Mdot
.88 .47753 Mdot
.88 .47784 Mdot
.88 .4784 Mdot
.88 .47865 Mdot
.88 .47881 Mdot
.88 .47947 Mdot
.88 .47961 Mdot
.88 .47975 Mdot
.88 .48034 Mdot
.88 .48167 Mdot
.88 .48218 Mdot
.88 .48261 Mdot
.88 .48362 Mdot
.88 .48364 Mdot
.88 .48377 Mdot
.88 .48436 Mdot
.88 .48472 Mdot
.88 .48546 Mdot
.88 .48653 Mdot
.88 .48712 Mdot
.88 .48787 Mdot
.88 .4879 Mdot
.88 .48846 Mdot
.88 .4886 Mdot
.88 .48906 Mdot
.88 .4891 Mdot
.88 .48937 Mdot
.88 .48948 Mdot
.88 .48988 Mdot
.88 .49005 Mdot
.88 .49011 Mdot
.88 .49049 Mdot
.88 .49062 Mdot
.88 .49086 Mdot
.88 .49162 Mdot
.88 .49165 Mdot
.88 .49204 Mdot
.88 .49238 Mdot
.88 .4929 Mdot
.88 .49296 Mdot
.88 .49301 Mdot
.88 .49308 Mdot
.88 .49324 Mdot
.88 .49353 Mdot
.88 .49353 Mdot
.88 .49355 Mdot
.88 .49357 Mdot
.88 .4936 Mdot
.88 .49365 Mdot
.88 .49369 Mdot
.88 .4937 Mdot
.88 .49384 Mdot
.88 .49385 Mdot
.88 .49419 Mdot
.88 .4942 Mdot
.88 .49422 Mdot
.88 .49432 Mdot
.88 .49461 Mdot
.88 .49469 Mdot
.88 .49476 Mdot
.88 .49495 Mdot
.88 .49498 Mdot
.88 .49502 Mdot
.88 .49535 Mdot
.88 .49543 Mdot
.88 .49573 Mdot
.88 .49579 Mdot
.88 .49588 Mdot
.88 .49596 Mdot
.88 .49608 Mdot
.88 .4961 Mdot
.88 .49636 Mdot
.88 .49691 Mdot
.88 .49691 Mdot
.88 .49694 Mdot
.88 .49699 Mdot
.88 .49703 Mdot
.88 .49705 Mdot
.88 .49714 Mdot
.88 .49717 Mdot
.88 .49722 Mdot
.88 .49724 Mdot
.88 .49752 Mdot
.88 .49756 Mdot
.88 .49757 Mdot
.88 .49762 Mdot
.88 .49812 Mdot
.88 .49827 Mdot
.88 .49831 Mdot
.88 .49832 Mdot
.88 .49832 Mdot
.88 .49837 Mdot
.88 .49858 Mdot
.88 .49861 Mdot
.88 .49869 Mdot
.88 .4988 Mdot
.88 .49931 Mdot
.88 .49941 Mdot
.88 .49947 Mdot
.88 .49951 Mdot
.88 .49953 Mdot
.88 .49964 Mdot
.88 .49968 Mdot
.88 .49979 Mdot
.88 .50017 Mdot
.88 .50025 Mdot
.88 .50035 Mdot
.88 .50037 Mdot
.88 .50098 Mdot
.88 .50123 Mdot
.88 .50127 Mdot
.88 .50144 Mdot
.88 .50151 Mdot
.88 .50237 Mdot
.88 .50244 Mdot
.88 .50255 Mdot
.88 .5028 Mdot
.88 .50307 Mdot
.88 .50314 Mdot
.88 .50343 Mdot
.88 .50348 Mdot
.88 .50365 Mdot
.88 .50419 Mdot
.88 .50431 Mdot
.88 .5046 Mdot
.88 .50461 Mdot
.88 .50464 Mdot
.88 .50491 Mdot
.88 .50512 Mdot
.88 .50542 Mdot
.88 .50558 Mdot
.88 .5058 Mdot
.88 .50599 Mdot
.88 .50611 Mdot
.88 .50612 Mdot
.88 .50623 Mdot
.88 .50634 Mdot
.88 .50638 Mdot
.88 .50654 Mdot
.88 .5066 Mdot
.88 .50681 Mdot
.88 .50692 Mdot
.88 .50701 Mdot
.88 .50718 Mdot
.88 .5072 Mdot
.88 .50724 Mdot
.88 .50763 Mdot
.88 .50764 Mdot
.88 .50774 Mdot
.88 .5078 Mdot
.88 .50782 Mdot
.88 .5079 Mdot
.88 .50825 Mdot
.88 .50839 Mdot
.88 .5084 Mdot
.88 .50853 Mdot
.88 .50857 Mdot
.88 .50859 Mdot
.88 .50889 Mdot
.88 .50936 Mdot
.88 .50987 Mdot
.88 .51039 Mdot
.88 .51047 Mdot
.88 .51095 Mdot
.88 .51108 Mdot
.88 .5111 Mdot
.88 .51112 Mdot
.88 .51113 Mdot
.88 .51132 Mdot
.88 .51133 Mdot
.88 .51142 Mdot
.88 .51169 Mdot
.88 .51186 Mdot
.88 .5121 Mdot
.88 .5122 Mdot
.88 .51224 Mdot
.88 .51248 Mdot
.88 .51268 Mdot
.88 .51277 Mdot
.88 .51291 Mdot
.88 .51296 Mdot
.88 .5134 Mdot
.88 .51371 Mdot
.88 .51419 Mdot
.88 .51434 Mdot
.88 .51436 Mdot
.88 .51471 Mdot
.88 .51472 Mdot
.88 .51475 Mdot
.88 .51479 Mdot
.88 .5148 Mdot
.88 .51502 Mdot
.88 .51519 Mdot
.88 .51541 Mdot
.88 .51557 Mdot
.88 .51566 Mdot
.88 .51576 Mdot
.88 .51584 Mdot
.88 .51597 Mdot
.88 .51607 Mdot
.88 .5162 Mdot
.88 .51663 Mdot
.88 .51685 Mdot
.88 .51768 Mdot
.88 .51779 Mdot
.88 .51805 Mdot
.88 .51828 Mdot
.88 .51835 Mdot
.88 .51842 Mdot
.88 .51844 Mdot
.88 .51869 Mdot
.88 .51874 Mdot
.88 .51878 Mdot
.88 .51889 Mdot
.88 .51891 Mdot
.88 .51897 Mdot
.88 .51917 Mdot
.88 .51919 Mdot
.88 .51941 Mdot
.88 .51992 Mdot
.88 .52003 Mdot
.88 .52007 Mdot
.88 .52016 Mdot
.88 .5203 Mdot
.88 .52032 Mdot
.88 .52088 Mdot
.88 .52094 Mdot
.88 .52096 Mdot
.88 .52098 Mdot
.88 .521 Mdot
.88 .5212 Mdot
.88 .52133 Mdot
.88 .52147 Mdot
.88 .52148 Mdot
.88 .52176 Mdot
.88 .52185 Mdot
.88 .5219 Mdot
.88 .52203 Mdot
.88 .52206 Mdot
.88 .52212 Mdot
.88 .52226 Mdot
.88 .5223 Mdot
.88 .5224 Mdot
.88 .52241 Mdot
.88 .52258 Mdot
.88 .52263 Mdot
.88 .52283 Mdot
.88 .52284 Mdot
.88 .5231 Mdot
.88 .52331 Mdot
.88 .52368 Mdot
.88 .52393 Mdot
.88 .52405 Mdot
.88 .52425 Mdot
.88 .5243 Mdot
.88 .5243 Mdot
.88 .52464 Mdot
.88 .52479 Mdot
.88 .52496 Mdot
.88 .52539 Mdot
.88 .52558 Mdot
.88 .52563 Mdot
.88 .52567 Mdot
.88 .52589 Mdot
.88 .52594 Mdot
.88 .52602 Mdot
.88 .5262 Mdot
.88 .5263 Mdot
.88 .52656 Mdot
.88 .52666 Mdot
.88 .52673 Mdot
.88 .52696 Mdot
.88 .52722 Mdot
.88 .52756 Mdot
.88 .52762 Mdot
.88 .5277 Mdot
.88 .52777 Mdot
.88 .52781 Mdot
.88 .52791 Mdot
.88 .52803 Mdot
.88 .52804 Mdot
.88 .52855 Mdot
.88 .52856 Mdot
.88 .52857 Mdot
.88 .52865 Mdot
.88 .52866 Mdot
.88 .52871 Mdot
.88 .52877 Mdot
.88 .52901 Mdot
.88 .5291 Mdot
.88 .52913 Mdot
.88 .52919 Mdot
.88 .52921 Mdot
.88 .52923 Mdot
.88 .52926 Mdot
.88 .5293 Mdot
.88 .52938 Mdot
.88 .52974 Mdot
.88 .52982 Mdot
.88 .52987 Mdot
.88 .52989 Mdot
.88 .53003 Mdot
.88 .53006 Mdot
.88 .53007 Mdot
.88 .53007 Mdot
.88 .53007 Mdot
.88 .5301 Mdot
.88 .53019 Mdot
.88 .53037 Mdot
.88 .5305 Mdot
.88 .53053 Mdot
.88 .53054 Mdot
.88 .53056 Mdot
.88 .53062 Mdot
.88 .53072 Mdot
.88 .53073 Mdot
.88 .53076 Mdot
.88 .53078 Mdot
.88 .53083 Mdot
.88 .53084 Mdot
.88 .53086 Mdot
.88 .53089 Mdot
.88 .5309 Mdot
.88 .5309 Mdot
.88 .53114 Mdot
.88 .53114 Mdot
.88 .53119 Mdot
.88 .53121 Mdot
.88 .53131 Mdot
.88 .53132 Mdot
.88 .53138 Mdot
.88 .53142 Mdot
.88 .53145 Mdot
.88 .53147 Mdot
.88 .53148 Mdot
.88 .53161 Mdot
.88 .53162 Mdot
.88 .53164 Mdot
.88 .53177 Mdot
.88 .53179 Mdot
.88 .5318 Mdot
.88 .53187 Mdot
.88 .53189 Mdot
.88 .5319 Mdot
.88 .53192 Mdot
.88 .53202 Mdot
.88 .53206 Mdot
.88 .53206 Mdot
.88 .53206 Mdot
.88 .53217 Mdot
.88 .53217 Mdot
.88 .53221 Mdot
.88 .53221 Mdot
.88 .53222 Mdot
.88 .53222 Mdot
.88 .53224 Mdot
.88 .53225 Mdot
.88 .53225 Mdot
.88 .53226 Mdot
.88 .53226 Mdot
.88 .53233 Mdot
.88 .53237 Mdot
.88 .53237 Mdot
.88 .53239 Mdot
.88 .5324 Mdot
.88 .53241 Mdot
.88 .53251 Mdot
.88 .53252 Mdot
.88 .53252 Mdot
.88 .53257 Mdot
.88 .5326 Mdot
.88 .53262 Mdot
.88 .53262 Mdot
.88 .53262 Mdot
.88 .53267 Mdot
.88 .53267 Mdot
.88 .53269 Mdot
.88 .53269 Mdot
.88 .53269 Mdot
.88 .5327 Mdot
.88 .5327 Mdot
.88 .53271 Mdot
.88 .53271 Mdot
.88 .53271 Mdot
.882 .20282 Mdot
.882 .2035 Mdot
.882 .31012 Mdot
.882 .31509 Mdot
.882 .38668 Mdot
.882 .38862 Mdot
.882 .45268 Mdot
.882 .45369 Mdot
.882 .48774 Mdot
.882 .48993 Mdot
.882 .53361 Mdot
.882 .53388 Mdot
.884 .20017 Mdot
.884 .20017 Mdot
.884 .20017 Mdot
.884 .20017 Mdot
.884 .20017 Mdot
.884 .20017 Mdot
.884 .20017 Mdot
.884 .20018 Mdot
.884 .20018 Mdot
.884 .20018 Mdot
.884 .20018 Mdot
.884 .20019 Mdot
.884 .20021 Mdot
.884 .20021 Mdot
.884 .20022 Mdot
.884 .20022 Mdot
.884 .20022 Mdot
.884 .20026 Mdot
.884 .20027 Mdot
.884 .20027 Mdot
.884 .20029 Mdot
.884 .20032 Mdot
.884 .20047 Mdot
.884 .20058 Mdot
.884 .20065 Mdot
.884 .20069 Mdot
.884 .20074 Mdot
.884 .20079 Mdot
.884 .20088 Mdot
.884 .2009 Mdot
.884 .20092 Mdot
.884 .20095 Mdot
.884 .20101 Mdot
.884 .20101 Mdot
.884 .20111 Mdot
.884 .20113 Mdot
.884 .20121 Mdot
.884 .20123 Mdot
.884 .20123 Mdot
.884 .20127 Mdot
.884 .20132 Mdot
.884 .20133 Mdot
.884 .20134 Mdot
.884 .20135 Mdot
.884 .20136 Mdot
.884 .20139 Mdot
.884 .2014 Mdot
.884 .20141 Mdot
.884 .20141 Mdot
.884 .20142 Mdot
.884 .20142 Mdot
.884 .20144 Mdot
.884 .20166 Mdot
.884 .20174 Mdot
.884 .20198 Mdot
.884 .20198 Mdot
.884 .20205 Mdot
.884 .20222 Mdot
.884 .20283 Mdot
.884 .2029 Mdot
.884 .20292 Mdot
.884 .20298 Mdot
.884 .203 Mdot
.884 .20301 Mdot
.884 .20304 Mdot
.884 .20305 Mdot
.884 .20307 Mdot
.884 .20311 Mdot
.884 .20323 Mdot
.884 .20324 Mdot
.884 .20331 Mdot
.884 .20334 Mdot
.884 .20335 Mdot
.884 .20356 Mdot
.884 .2037 Mdot
.884 .20373 Mdot
.884 .2038 Mdot
.884 .20392 Mdot
.884 .20404 Mdot
.884 .20413 Mdot
.884 .20423 Mdot
.884 .20435 Mdot
.884 .20438 Mdot
.884 .20464 Mdot
.884 .20466 Mdot
.884 .20469 Mdot
.884 .20495 Mdot
.884 .20507 Mdot
.884 .20507 Mdot
.884 .20515 Mdot
.884 .20524 Mdot
.884 .20528 Mdot
.884 .20569 Mdot
.884 .20598 Mdot
.884 .20603 Mdot
.884 .20607 Mdot
.884 .20608 Mdot
.884 .20624 Mdot
.884 .20643 Mdot
.884 .20685 Mdot
.884 .2072 Mdot
.884 .20744 Mdot
.884 .2082 Mdot
.884 .20834 Mdot
.884 .20857 Mdot
.884 .20863 Mdot
.884 .20868 Mdot
.884 .20869 Mdot
.884 .20875 Mdot
.884 .20885 Mdot
.884 .20895 Mdot
.884 .20896 Mdot
.884 .20896 Mdot
.884 .209 Mdot
.884 .20902 Mdot
.884 .20906 Mdot
.884 .20917 Mdot
.884 .20921 Mdot
.884 .20922 Mdot
.884 .20924 Mdot
.884 .20926 Mdot
.884 .20927 Mdot
.884 .20927 Mdot
.884 .20927 Mdot
.884 .20928 Mdot
.884 .20928 Mdot
.884 .20928 Mdot
.884 .20928 Mdot
.884 .20928 Mdot
.884 .20928 Mdot
.884 .20984 Mdot
.884 .21007 Mdot
.884 .21019 Mdot
.884 .21134 Mdot
.884 .2115 Mdot
.884 .21395 Mdot
.884 .21411 Mdot
.884 .21656 Mdot
.884 .21679 Mdot
.884 .21833 Mdot
.884 .22252 Mdot
.884 .22444 Mdot
.884 .22447 Mdot
.884 .22569 Mdot
.884 .22764 Mdot
.884 .22824 Mdot
.884 .22839 Mdot
.884 .2287 Mdot
.884 .22872 Mdot
.884 .22932 Mdot
.884 .22934 Mdot
.884 .23025 Mdot
.884 .23112 Mdot
.884 .23123 Mdot
.884 .23126 Mdot
.884 .23162 Mdot
.884 .23174 Mdot
.884 .23219 Mdot
.884 .23323 Mdot
.884 .2336 Mdot
.884 .2337 Mdot
.884 .23385 Mdot
.884 .23408 Mdot
.884 .23415 Mdot
.884 .23416 Mdot
.884 .23417 Mdot
.884 .23424 Mdot
.884 .23425 Mdot
.884 .23426 Mdot
.884 .23426 Mdot
.884 .23428 Mdot
.884 .23428 Mdot
.884 .23815 Mdot
.884 .23936 Mdot
.884 .23971 Mdot
.884 .24021 Mdot
.884 .241 Mdot
.884 .24208 Mdot
.884 .24324 Mdot
.884 .25027 Mdot
.884 .25062 Mdot
.884 .25364 Mdot
.884 .25373 Mdot
.884 .25456 Mdot
.884 .25544 Mdot
.884 .25707 Mdot
.884 .25725 Mdot
.884 .26113 Mdot
.884 .2618 Mdot
.884 .26319 Mdot
.884 .26339 Mdot
.884 .26412 Mdot
.884 .26651 Mdot
.884 .26652 Mdot
.884 .26653 Mdot
.884 .26653 Mdot
.884 .26653 Mdot
.884 .26654 Mdot
.884 .26659 Mdot
.884 .26659 Mdot
.884 .2666 Mdot
.884 .26664 Mdot
.884 .26679 Mdot
.884 .26688 Mdot
.884 .26695 Mdot
.884 .26719 Mdot
.884 .26787 Mdot
.884 .26816 Mdot
.884 .26824 Mdot
.884 .26848 Mdot
.884 .2685 Mdot
.884 .26857 Mdot
.884 .26916 Mdot
.884 .26978 Mdot
.884 .2702 Mdot
.884 .27022 Mdot
.884 .27053 Mdot
.884 .27095 Mdot
.884 .27235 Mdot
.884 .27325 Mdot
.884 .27815 Mdot
.884 .2795 Mdot
.884 .27971 Mdot
.884 .28201 Mdot
.884 .28217 Mdot
.884 .28468 Mdot
.884 .28486 Mdot
.884 .28615 Mdot
.884 .28655 Mdot
.884 .28721 Mdot
.884 .28728 Mdot
.884 .2876 Mdot
.884 .28773 Mdot
.884 .28794 Mdot
.884 .28855 Mdot
.884 .28988 Mdot
.884 .29147 Mdot
.884 .29278 Mdot
.884 .29305 Mdot
.884 .29368 Mdot
.884 .29423 Mdot
.884 .29427 Mdot
.884 .29505 Mdot
.884 .2969 Mdot
.884 .29711 Mdot
.884 .29727 Mdot
.884 .29915 Mdot
.884 .29932 Mdot
.884 .30024 Mdot
.884 .3009 Mdot
.884 .30096 Mdot
.884 .30098 Mdot
.884 .30101 Mdot
.884 .30102 Mdot
.884 .30104 Mdot
.884 .30107 Mdot
.884 .30125 Mdot
.884 .30128 Mdot
.884 .30129 Mdot
.884 .30147 Mdot
.884 .30162 Mdot
.884 .30205 Mdot
.884 .30241 Mdot
.884 .30243 Mdot
.884 .30269 Mdot
.884 .30335 Mdot
.884 .3036 Mdot
.884 .30385 Mdot
.884 .30403 Mdot
.884 .30508 Mdot
.884 .30625 Mdot
.884 .30661 Mdot
.884 .30673 Mdot
.884 .30696 Mdot
.884 .30738 Mdot
.884 .30742 Mdot
.884 .30752 Mdot
.884 .3077 Mdot
.884 .30842 Mdot
.884 .30861 Mdot
.884 .30869 Mdot
.884 .3087 Mdot
.884 .30886 Mdot
.884 .30894 Mdot
.884 .30899 Mdot
.884 .30917 Mdot
.884 .30923 Mdot
.884 .30934 Mdot
.884 .30979 Mdot
.884 .30997 Mdot
.884 .3105 Mdot
.884 .31124 Mdot
.884 .3136 Mdot
.884 .31364 Mdot
.884 .31509 Mdot
.884 .3152 Mdot
.884 .31527 Mdot
.884 .31608 Mdot
.884 .31638 Mdot
.884 .31646 Mdot
.884 .31687 Mdot
.884 .31688 Mdot
.884 .31805 Mdot
.884 .31873 Mdot
.884 .31934 Mdot
.884 .321 Mdot
.884 .32113 Mdot
.884 .32118 Mdot
.884 .32124 Mdot
.884 .32127 Mdot
.884 .32131 Mdot
.884 .32139 Mdot
.884 .32165 Mdot
.884 .32167 Mdot
.884 .3218 Mdot
.884 .32187 Mdot
.884 .3219 Mdot
.884 .32231 Mdot
.884 .32259 Mdot
.884 .32264 Mdot
.884 .32277 Mdot
.884 .32322 Mdot
.884 .3234 Mdot
.884 .32356 Mdot
.884 .32429 Mdot
.884 .32433 Mdot
.884 .32482 Mdot
.884 .325 Mdot
.884 .32514 Mdot
.884 .32534 Mdot
.884 .326 Mdot
.884 .32643 Mdot
.884 .3265 Mdot
.884 .32657 Mdot
.884 .32682 Mdot
.884 .32709 Mdot
.884 .3277 Mdot
.884 .3285 Mdot
.884 .32969 Mdot
.884 .32997 Mdot
.884 .33005 Mdot
.884 .33011 Mdot
.884 .3302 Mdot
.884 .33044 Mdot
.884 .33046 Mdot
.884 .33051 Mdot
.884 .33052 Mdot
.884 .33058 Mdot
.884 .33072 Mdot
.884 .33076 Mdot
.884 .33079 Mdot
.884 .33082 Mdot
.884 .33083 Mdot
.884 .33083 Mdot
.884 .33083 Mdot
.884 .33084 Mdot
.884 .33084 Mdot
.884 .33085 Mdot
.884 .33085 Mdot
.884 .33085 Mdot
.884 .33178 Mdot
.884 .34332 Mdot
.884 .34763 Mdot
.884 .34827 Mdot
.884 .35517 Mdot
.884 .35564 Mdot
.884 .36257 Mdot
.884 .36305 Mdot
.884 .36634 Mdot
.884 .36666 Mdot
.884 .36734 Mdot
.884 .36892 Mdot
.884 .36893 Mdot
.884 .36893 Mdot
.884 .36893 Mdot
.884 .36893 Mdot
.884 .36894 Mdot
.884 .36896 Mdot
.884 .36896 Mdot
.884 .36896 Mdot
.884 .36898 Mdot
.884 .36905 Mdot
.884 .3691 Mdot
.884 .36913 Mdot
.884 .36924 Mdot
.884 .36956 Mdot
.884 .36969 Mdot
.884 .36973 Mdot
.884 .36984 Mdot
.884 .36985 Mdot
.884 .36989 Mdot
.884 .37016 Mdot
.884 .37045 Mdot
.884 .37064 Mdot
.884 .37065 Mdot
.884 .37079 Mdot
.884 .37099 Mdot
.884 .37162 Mdot
.884 .37203 Mdot
.884 .37422 Mdot
.884 .37491 Mdot
.884 .37591 Mdot
.884 .37713 Mdot
.884 .37768 Mdot
.884 .37813 Mdot
.884 .37816 Mdot
.884 .3783 Mdot
.884 .37844 Mdot
.884 .37925 Mdot
.884 .38045 Mdot
.884 .38056 Mdot
.884 .38082 Mdot
.884 .38105 Mdot
.884 .38107 Mdot
.884 .38139 Mdot
.884 .38214 Mdot
.884 .38223 Mdot
.884 .38229 Mdot
.884 .38305 Mdot
.884 .38312 Mdot
.884 .38349 Mdot
.884 .38375 Mdot
.884 .38404 Mdot
.884 .38436 Mdot
.884 .38472 Mdot
.884 .38492 Mdot
.884 .385 Mdot
.884 .38541 Mdot
.884 .38601 Mdot
.884 .38606 Mdot
.884 .38615 Mdot
.884 .38633 Mdot
.884 .38637 Mdot
.884 .38672 Mdot
.884 .38683 Mdot
.884 .38689 Mdot
.884 .38692 Mdot
.884 .38701 Mdot
.884 .38703 Mdot
.884 .38708 Mdot
.884 .38725 Mdot
.884 .38732 Mdot
.884 .38753 Mdot
.884 .38929 Mdot
.884 .38978 Mdot
.884 .38997 Mdot
.884 .38997 Mdot
.884 .39068 Mdot
.884 .39091 Mdot
.884 .39153 Mdot
.884 .39158 Mdot
.884 .3916 Mdot
.884 .39163 Mdot
.884 .39163 Mdot
.884 .39165 Mdot
.884 .39168 Mdot
.884 .39178 Mdot
.884 .39179 Mdot
.884 .39184 Mdot
.884 .39186 Mdot
.884 .39187 Mdot
.884 .39203 Mdot
.884 .39213 Mdot
.884 .39215 Mdot
.884 .3922 Mdot
.884 .39243 Mdot
.884 .3925 Mdot
.884 .39277 Mdot
.884 .39278 Mdot
.884 .39296 Mdot
.884 .39303 Mdot
.884 .39308 Mdot
.884 .39316 Mdot
.884 .3934 Mdot
.884 .39356 Mdot
.884 .39371 Mdot
.884 .39381 Mdot
.884 .39403 Mdot
.884 .39433 Mdot
.884 .39477 Mdot
.884 .39487 Mdot
.884 .3949 Mdot
.884 .39493 Mdot
.884 .39496 Mdot
.884 .39505 Mdot
.884 .39505 Mdot
.884 .39507 Mdot
.884 .39508 Mdot
.884 .3951 Mdot
.884 .39515 Mdot
.884 .39516 Mdot
.884 .39518 Mdot
.884 .39519 Mdot
.884 .39519 Mdot
.884 .39519 Mdot
.884 .39519 Mdot
.884 .39519 Mdot
.884 .39519 Mdot
.884 .39519 Mdot
.884 .3952 Mdot
.884 .3952 Mdot
.884 .44969 Mdot
.884 .44969 Mdot
.884 .44969 Mdot
.884 .44969 Mdot
.884 .44969 Mdot
.884 .44969 Mdot
.884 .44969 Mdot
.884 .44969 Mdot
.884 .44969 Mdot
.884 .4497 Mdot
.884 .4497 Mdot
.884 .44971 Mdot
.884 .44974 Mdot
.884 .44975 Mdot
.884 .44975 Mdot
.884 .44976 Mdot
.884 .44977 Mdot
.884 .44981 Mdot
.884 .44983 Mdot
.884 .44984 Mdot
.884 .44986 Mdot
.884 .44991 Mdot
.884 .45014 Mdot
.884 .4503 Mdot
.884 .45042 Mdot
.884 .45047 Mdot
.884 .45055 Mdot
.884 .45063 Mdot
.884 .45076 Mdot
.884 .4508 Mdot
.884 .45083 Mdot
.884 .45086 Mdot
.884 .45096 Mdot
.884 .45096 Mdot
.884 .45111 Mdot
.884 .45114 Mdot
.884 .45126 Mdot
.884 .45129 Mdot
.884 .4513 Mdot
.884 .45135 Mdot
.884 .45143 Mdot
.884 .45144 Mdot
.884 .45145 Mdot
.884 .45148 Mdot
.884 .45148 Mdot
.884 .45153 Mdot
.884 .45155 Mdot
.884 .45156 Mdot
.884 .45156 Mdot
.884 .45157 Mdot
.884 .45158 Mdot
.884 .45161 Mdot
.884 .45193 Mdot
.884 .45206 Mdot
.884 .45242 Mdot
.884 .45242 Mdot
.884 .45252 Mdot
.884 .45278 Mdot
.884 .45369 Mdot
.884 .4538 Mdot
.884 .45383 Mdot
.884 .45392 Mdot
.884 .45394 Mdot
.884 .45395 Mdot
.884 .454 Mdot
.884 .45402 Mdot
.884 .45405 Mdot
.884 .45411 Mdot
.884 .45429 Mdot
.884 .45431 Mdot
.884 .4544 Mdot
.884 .45445 Mdot
.884 .45447 Mdot
.884 .45478 Mdot
.884 .45499 Mdot
.884 .45503 Mdot
.884 .45513 Mdot
.884 .45532 Mdot
.884 .45548 Mdot
.884 .45563 Mdot
.884 .45576 Mdot
.884 .45595 Mdot
.884 .45599 Mdot
.884 .45637 Mdot
.884 .4564 Mdot
.884 .45645 Mdot
.884 .45683 Mdot
.884 .45699 Mdot
.884 .457 Mdot
.884 .45712 Mdot
.884 .45725 Mdot
.884 .4573 Mdot
.884 .45791 Mdot
.884 .45832 Mdot
.884 .45839 Mdot
.884 .45846 Mdot
.884 .45848 Mdot
.884 .4587 Mdot
.884 .45898 Mdot
.884 .45959 Mdot
.884 .46009 Mdot
.884 .46043 Mdot
.884 .46152 Mdot
.884 .46172 Mdot
.884 .46204 Mdot
.884 .46213 Mdot
.884 .4622 Mdot
.884 .46221 Mdot
.884 .46231 Mdot
.884 .46245 Mdot
.884 .46258 Mdot
.884 .4626 Mdot
.884 .4626 Mdot
.884 .46266 Mdot
.884 .46268 Mdot
.884 .46274 Mdot
.884 .4629 Mdot
.884 .46295 Mdot
.884 .46297 Mdot
.884 .46299 Mdot
.884 .46302 Mdot
.884 .46304 Mdot
.884 .46304 Mdot
.884 .46304 Mdot
.884 .46305 Mdot
.884 .46305 Mdot
.884 .46305 Mdot
.884 .46305 Mdot
.884 .46305 Mdot
.884 .46305 Mdot
.884 .46383 Mdot
.884 .46416 Mdot
.884 .46432 Mdot
.884 .46592 Mdot
.884 .46615 Mdot
.884 .46948 Mdot
.884 .46971 Mdot
.884 .47297 Mdot
.884 .47327 Mdot
.884 .47528 Mdot
.884 .48058 Mdot
.884 .481 Mdot
.884 .481 Mdot
.884 .481 Mdot
.884 .481 Mdot
.884 .481 Mdot
.884 .48101 Mdot
.884 .48101 Mdot
.884 .48101 Mdot
.884 .48101 Mdot
.884 .48102 Mdot
.884 .48104 Mdot
.884 .48106 Mdot
.884 .48112 Mdot
.884 .48115 Mdot
.884 .48115 Mdot
.884 .48118 Mdot
.884 .48118 Mdot
.884 .48129 Mdot
.884 .48133 Mdot
.884 .48136 Mdot
.884 .4814 Mdot
.884 .48153 Mdot
.884 .48206 Mdot
.884 .48242 Mdot
.884 .4827 Mdot
.884 .48282 Mdot
.884 .48293 Mdot
.884 .48296 Mdot
.884 .483 Mdot
.884 .48319 Mdot
.884 .48348 Mdot
.884 .48358 Mdot
.884 .48364 Mdot
.884 .48372 Mdot
.884 .48394 Mdot
.884 .48395 Mdot
.884 .48428 Mdot
.884 .48435 Mdot
.884 .48444 Mdot
.884 .48463 Mdot
.884 .48469 Mdot
.884 .48471 Mdot
.884 .48484 Mdot
.884 .48502 Mdot
.884 .48504 Mdot
.884 .48507 Mdot
.884 .48512 Mdot
.884 .48514 Mdot
.884 .48525 Mdot
.884 .48529 Mdot
.884 .48531 Mdot
.884 .48532 Mdot
.884 .48535 Mdot
.884 .48537 Mdot
.884 .48543 Mdot
.884 .48616 Mdot
.884 .48643 Mdot
.884 .48673 Mdot
.884 .48725 Mdot
.884 .48726 Mdot
.884 .48744 Mdot
.884 .48748 Mdot
.884 .4876 Mdot
.884 .48796 Mdot
.884 .488 Mdot
.884 .48805 Mdot
.884 .48868 Mdot
.884 .4887 Mdot
.884 .48974 Mdot
.884 .49006 Mdot
.884 .49029 Mdot
.884 .49037 Mdot
.884 .49057 Mdot
.884 .49062 Mdot
.884 .49064 Mdot
.884 .49072 Mdot
.884 .49074 Mdot
.884 .49078 Mdot
.884 .49085 Mdot
.884 .49085 Mdot
.884 .49088 Mdot
.884 .49097 Mdot
.884 .49128 Mdot
.884 .49136 Mdot
.884 .4914 Mdot
.884 .49142 Mdot
.884 .49161 Mdot
.884 .49171 Mdot
.884 .49176 Mdot
.884 .49191 Mdot
.884 .49242 Mdot
.884 .49288 Mdot
.884 .49296 Mdot
.884 .49306 Mdot
.884 .49317 Mdot
.884 .49346 Mdot
.884 .49357 Mdot
.884 .49358 Mdot
.884 .49373 Mdot
.884 .49392 Mdot
.884 .49398 Mdot
.884 .49406 Mdot
.884 .49407 Mdot
.884 .49408 Mdot
.884 .49416 Mdot
.884 .49417 Mdot
.884 .49418 Mdot
.884 .49418 Mdot
.884 .4942 Mdot
.884 .4942 Mdot
.884 .49423 Mdot
.884 .49451 Mdot
.884 .49491 Mdot
.884 .49498 Mdot
.884 .49579 Mdot
.884 .49586 Mdot
.884 .49595 Mdot
.884 .49674 Mdot
.884 .49708 Mdot
.884 .49709 Mdot
.884 .49733 Mdot
.884 .4976 Mdot
.884 .49771 Mdot
.884 .49827 Mdot
.884 .49894 Mdot
.884 .4995 Mdot
.884 .49976 Mdot
.884 .49985 Mdot
.884 .49991 Mdot
.884 .50004 Mdot
.884 .50007 Mdot
.884 .50035 Mdot
.884 .50052 Mdot
.884 .50106 Mdot
.884 .50114 Mdot
.884 .5022 Mdot
.884 .50226 Mdot
.884 .50323 Mdot
.884 .50331 Mdot
.884 .50388 Mdot
.884 .50592 Mdot
.884 .50629 Mdot
.884 .50687 Mdot
.884 .50705 Mdot
.884 .50718 Mdot
.884 .50718 Mdot
.884 .50736 Mdot
.884 .50761 Mdot
.884 .50785 Mdot
.884 .50789 Mdot
.884 .50789 Mdot
.884 .50799 Mdot
.884 .50802 Mdot
.884 .50815 Mdot
.884 .50842 Mdot
.884 .50852 Mdot
.884 .50855 Mdot
.884 .50859 Mdot
.884 .50865 Mdot
.884 .50867 Mdot
.884 .50867 Mdot
.884 .50867 Mdot
.884 .50869 Mdot
.884 .50869 Mdot
.884 .5087 Mdot
.884 .5087 Mdot
.884 .5087 Mdot
.884 .5087 Mdot
.884 .50969 Mdot
.884 .50998 Mdot
.884 .51007 Mdot
.884 .51064 Mdot
.884 .51091 Mdot
.884 .51249 Mdot
.884 .51257 Mdot
.884 .51323 Mdot
.884 .51359 Mdot
.884 .51392 Mdot
.884 .51396 Mdot
.884 .51518 Mdot
.884 .51532 Mdot
.884 .51815 Mdot
.884 .51862 Mdot
.884 .51905 Mdot
.884 .51936 Mdot
.884 .51956 Mdot
.884 .5197 Mdot
.884 .52019 Mdot
.884 .52172 Mdot
.884 .52173 Mdot
.884 .52173 Mdot
.884 .52173 Mdot
.884 .52174 Mdot
.884 .52174 Mdot
.884 .52177 Mdot
.884 .52177 Mdot
.884 .52178 Mdot
.884 .5218 Mdot
.884 .5219 Mdot
.884 .52195 Mdot
.884 .522 Mdot
.884 .52214 Mdot
.884 .52256 Mdot
.884 .52273 Mdot
.884 .52278 Mdot
.884 .52292 Mdot
.884 .52293 Mdot
.884 .52298 Mdot
.884 .52332 Mdot
.884 .52368 Mdot
.884 .52369 Mdot
.884 .52393 Mdot
.884 .52394 Mdot
.884 .52406 Mdot
.884 .52412 Mdot
.884 .52435 Mdot
.884 .52512 Mdot
.884 .5256 Mdot
.884 .52637 Mdot
.884 .52801 Mdot
.884 .52862 Mdot
.884 .5287 Mdot
.884 .52966 Mdot
.884 .52972 Mdot
.884 .53067 Mdot
.884 .53074 Mdot
.884 .53119 Mdot
.884 .53123 Mdot
.884 .53132 Mdot
.884 .53154 Mdot
.884 .53154 Mdot
.884 .53154 Mdot
.884 .53154 Mdot
.884 .53154 Mdot
.884 .53154 Mdot
.884 .53154 Mdot
.884 .53154 Mdot
.884 .53154 Mdot
.884 .53155 Mdot
.884 .53156 Mdot
.884 .53156 Mdot
.884 .53157 Mdot
.884 .53158 Mdot
.884 .53162 Mdot
.884 .53164 Mdot
.884 .53165 Mdot
.884 .53166 Mdot
.884 .53166 Mdot
.884 .53167 Mdot
.884 .5317 Mdot
.884 .53174 Mdot
.884 .53177 Mdot
.884 .53177 Mdot
.884 .53179 Mdot
.884 .53182 Mdot
.884 .5319 Mdot
.884 .53196 Mdot
.884 .53225 Mdot
.884 .53235 Mdot
.884 .53248 Mdot
.884 .53265 Mdot
.884 .53272 Mdot
.884 .53278 Mdot
.884 .53278 Mdot
.884 .5328 Mdot
.884 .53282 Mdot
.884 .53293 Mdot
.884 .53309 Mdot
.884 .53311 Mdot
.884 .53314 Mdot
.884 .53317 Mdot
.884 .53317 Mdot
.884 .53322 Mdot
.884 .53332 Mdot
.884 .53333 Mdot
.884 .53334 Mdot
.884 .53344 Mdot
.884 .53345 Mdot
.884 .5335 Mdot
.884 .53353 Mdot
.884 .53357 Mdot
.884 .53361 Mdot
.884 .53366 Mdot
.884 .53369 Mdot
.884 .5337 Mdot
.884 .53375 Mdot
.884 .53383 Mdot
.884 .53384 Mdot
.884 .53385 Mdot
.884 .53388 Mdot
.884 .53388 Mdot
.884 .53393 Mdot
.884 .53394 Mdot
.884 .53395 Mdot
.884 .53396 Mdot
.884 .53397 Mdot
.884 .53397 Mdot
.884 .53398 Mdot
.884 .534 Mdot
.884 .53401 Mdot
.884 .53404 Mdot
.884 .53427 Mdot
.884 .53434 Mdot
.884 .53436 Mdot
.884 .53436 Mdot
.884 .53446 Mdot
.884 .53449 Mdot
.884 .53457 Mdot
.884 .53458 Mdot
.884 .53458 Mdot
.884 .53459 Mdot
.884 .53459 Mdot
.884 .53459 Mdot
.884 .53459 Mdot
.884 .53461 Mdot
.884 .53461 Mdot
.884 .53461 Mdot
.884 .53462 Mdot
.884 .53462 Mdot
.884 .53464 Mdot
.884 .53465 Mdot
.884 .53466 Mdot
.884 .53466 Mdot
.884 .53469 Mdot
.884 .5347 Mdot
.884 .53474 Mdot
.884 .53474 Mdot
.884 .53476 Mdot
.884 .53477 Mdot
.884 .53478 Mdot
.884 .53479 Mdot
.884 .53482 Mdot
.884 .53484 Mdot
.884 .53486 Mdot
.884 .53488 Mdot
.884 .53491 Mdot
.884 .53495 Mdot
.884 .535 Mdot
.884 .53502 Mdot
.884 .53502 Mdot
.884 .53503 Mdot
.884 .53503 Mdot
.884 .53504 Mdot
.884 .53504 Mdot
.884 .53505 Mdot
.884 .53505 Mdot
.884 .53505 Mdot
.884 .53506 Mdot
.884 .53506 Mdot
.884 .53506 Mdot
.884 .53506 Mdot
.884 .53506 Mdot
.884 .53506 Mdot
.884 .53506 Mdot
.884 .53506 Mdot
.884 .53506 Mdot
.884 .53506 Mdot
.884 .53506 Mdot
.884 .53506 Mdot
.886 .19753 Mdot
.886 .19754 Mdot
.886 .19758 Mdot
.886 .19759 Mdot
.886 .19759 Mdot
.886 .19759 Mdot
.886 .19774 Mdot
.886 .19785 Mdot
.886 .19787 Mdot
.886 .19797 Mdot
.886 .198 Mdot
.886 .19809 Mdot
.886 .19814 Mdot
.886 .19819 Mdot
.886 .19829 Mdot
.886 .19831 Mdot
.886 .19877 Mdot
.886 .19877 Mdot
.886 .19881 Mdot
.886 .19905 Mdot
.886 .19907 Mdot
.886 .19912 Mdot
.886 .19922 Mdot
.886 .19926 Mdot
.886 .19934 Mdot
.886 .19945 Mdot
.886 .19962 Mdot
.886 .19969 Mdot
.886 .19974 Mdot
.886 .19978 Mdot
.886 .19986 Mdot
.886 .1999 Mdot
.886 .20007 Mdot
.886 .2001 Mdot
.886 .20021 Mdot
.886 .20035 Mdot
.886 .2005 Mdot
.886 .2006 Mdot
.886 .20067 Mdot
.886 .20098 Mdot
.886 .20103 Mdot
.886 .20118 Mdot
.886 .20123 Mdot
.886 .20135 Mdot
.886 .20176 Mdot
.886 .20232 Mdot
.886 .20246 Mdot
.886 .20265 Mdot
.886 .20295 Mdot
.886 .20297 Mdot
.886 .20319 Mdot
.886 .20348 Mdot
.886 .2036 Mdot
.886 .2038 Mdot
.886 .20396 Mdot
.886 .20426 Mdot
.886 .20427 Mdot
.886 .20468 Mdot
.886 .20495 Mdot
.886 .20511 Mdot
.886 .20514 Mdot
.886 .20514 Mdot
.886 .20518 Mdot
.886 .20525 Mdot
.886 .20528 Mdot
.886 .20548 Mdot
.886 .20569 Mdot
.886 .20582 Mdot
.886 .20589 Mdot
.886 .20591 Mdot
.886 .20595 Mdot
.886 .20606 Mdot
.886 .20626 Mdot
.886 .20645 Mdot
.886 .2067 Mdot
.886 .20699 Mdot
.886 .20714 Mdot
.886 .20722 Mdot
.886 .20765 Mdot
.886 .2079 Mdot
.886 .20842 Mdot
.886 .20854 Mdot
.886 .2086 Mdot
.886 .20874 Mdot
.886 .2091 Mdot
.886 .20928 Mdot
.886 .20936 Mdot
.886 .2096 Mdot
.886 .2098 Mdot
.886 .20998 Mdot
.886 .21008 Mdot
.886 .2102 Mdot
.886 .21023 Mdot
.886 .2104 Mdot
.886 .21083 Mdot
.886 .21084 Mdot
.886 .21098 Mdot
.886 .211 Mdot
.886 .21136 Mdot
.886 .21146 Mdot
.886 .21205 Mdot
.886 .21243 Mdot
.886 .21258 Mdot
.886 .21271 Mdot
.886 .21289 Mdot
.886 .21299 Mdot
.886 .21332 Mdot
.886 .21334 Mdot
.886 .21353 Mdot
.886 .21383 Mdot
.886 .21408 Mdot
.886 .21442 Mdot
.886 .21446 Mdot
.886 .21468 Mdot
.886 .21571 Mdot
.886 .21607 Mdot
.886 .21615 Mdot
.886 .21626 Mdot
.886 .21701 Mdot
.886 .21767 Mdot
.886 .21768 Mdot
.886 .21788 Mdot
.886 .2181 Mdot
.886 .21845 Mdot
.886 .21891 Mdot
.886 .21893 Mdot
.886 .21936 Mdot
.886 .21943 Mdot
.886 .21973 Mdot
.886 .21994 Mdot
.886 .22 Mdot
.886 .22004 Mdot
.886 .22043 Mdot
.886 .22046 Mdot
.886 .22092 Mdot
.886 .22129 Mdot
.886 .22149 Mdot
.886 .22238 Mdot
.886 .22263 Mdot
.886 .22299 Mdot
.886 .22342 Mdot
.886 .22376 Mdot
.886 .22383 Mdot
.886 .22449 Mdot
.886 .2256 Mdot
.886 .22564 Mdot
.886 .22565 Mdot
.886 .22573 Mdot
.886 .22596 Mdot
.886 .22608 Mdot
.886 .22626 Mdot
.886 .22633 Mdot
.886 .22641 Mdot
.886 .22675 Mdot
.886 .22826 Mdot
.886 .22834 Mdot
.886 .22977 Mdot
.886 .23108 Mdot
.886 .23109 Mdot
.886 .23169 Mdot
.886 .23225 Mdot
.886 .23285 Mdot
.886 .23288 Mdot
.886 .23352 Mdot
.886 .23386 Mdot
.886 .23405 Mdot
.886 .23429 Mdot
.886 .23514 Mdot
.886 .23565 Mdot
.886 .23683 Mdot
.886 .23702 Mdot
.886 .23804 Mdot
.886 .23829 Mdot
.886 .23865 Mdot
.886 .23924 Mdot
.886 .23931 Mdot
.886 .23956 Mdot
.886 .23992 Mdot
.886 .24072 Mdot
.886 .24098 Mdot
.886 .24148 Mdot
.886 .24241 Mdot
.886 .2431 Mdot
.886 .24337 Mdot
.886 .24388 Mdot
.886 .24442 Mdot
.886 .24492 Mdot
.886 .24555 Mdot
.886 .24589 Mdot
.886 .24708 Mdot
.886 .24751 Mdot
.886 .2479 Mdot
.886 .24808 Mdot
.886 .24861 Mdot
.886 .24907 Mdot
.886 .24959 Mdot
.886 .25005 Mdot
.886 .25029 Mdot
.886 .2516 Mdot
.886 .25173 Mdot
.886 .2523 Mdot
.886 .25251 Mdot
.886 .25256 Mdot
.886 .25501 Mdot
.886 .25605 Mdot
.886 .25618 Mdot
.886 .25693 Mdot
.886 .25721 Mdot
.886 .2573 Mdot
.886 .25751 Mdot
.886 .25774 Mdot
.886 .25856 Mdot
.886 .2589 Mdot
.886 .25918 Mdot
.886 .25975 Mdot
.886 .26123 Mdot
.886 .26169 Mdot
.886 .2619 Mdot
.886 .26242 Mdot
.886 .26278 Mdot
.886 .26338 Mdot
.886 .2645 Mdot
.886 .26502 Mdot
.886 .26549 Mdot
.886 .26589 Mdot
.886 .26628 Mdot
.886 .26663 Mdot
.886 .26702 Mdot
.886 .26702 Mdot
.886 .26787 Mdot
.886 .2688 Mdot
.886 .27034 Mdot
.886 .27144 Mdot
.886 .27196 Mdot
.886 .27221 Mdot
.886 .27363 Mdot
.886 .27472 Mdot
.886 .27476 Mdot
.886 .27526 Mdot
.886 .27597 Mdot
.886 .27625 Mdot
.886 .27715 Mdot
.886 .27777 Mdot
.886 .27824 Mdot
.886 .27936 Mdot
.886 .27967 Mdot
.886 .27989 Mdot
.886 .28118 Mdot
.886 .28154 Mdot
.886 .28256 Mdot
.886 .28272 Mdot
.886 .28333 Mdot
.886 .28336 Mdot
.886 .28359 Mdot
.886 .28377 Mdot
.886 .28424 Mdot
.886 .28512 Mdot
.886 .28525 Mdot
.886 .28611 Mdot
.886 .28659 Mdot
.886 .28669 Mdot
.886 .28686 Mdot
.886 .28799 Mdot
.886 .28818 Mdot
.886 .28829 Mdot
.886 .28872 Mdot
.886 .28898 Mdot
.886 .28901 Mdot
.886 .28916 Mdot
.886 .28917 Mdot
.886 .28977 Mdot
.886 .29033 Mdot
.886 .29224 Mdot
.886 .29227 Mdot
.886 .29274 Mdot
.886 .29518 Mdot
.886 .29528 Mdot
.886 .29567 Mdot
.886 .29694 Mdot
.886 .2975 Mdot
.886 .29862 Mdot
.886 .29906 Mdot
.886 .29967 Mdot
.886 .30011 Mdot
.886 .30016 Mdot
.886 .301 Mdot
.886 .30101 Mdot
.886 .30265 Mdot
.886 .30273 Mdot
.886 .30317 Mdot
.886 .30425 Mdot
.886 .30482 Mdot
.886 .30496 Mdot
.886 .30569 Mdot
.886 .30721 Mdot
.886 .30726 Mdot
.886 .30728 Mdot
.886 .30864 Mdot
.886 .30971 Mdot
.886 .31069 Mdot
.886 .31399 Mdot
.886 .31444 Mdot
.886 .31467 Mdot
.886 .31718 Mdot
.886 .3181 Mdot
.886 .3185 Mdot
.886 .3187 Mdot
.886 .3196 Mdot
.886 .31972 Mdot
.886 .31982 Mdot
.886 .32001 Mdot
.886 .3201 Mdot
.886 .32049 Mdot
.886 .32081 Mdot
.886 .32144 Mdot
.886 .32163 Mdot
.886 .32179 Mdot
.886 .32248 Mdot
.886 .3231 Mdot
.886 .32384 Mdot
.886 .32478 Mdot
.886 .32501 Mdot
.886 .32615 Mdot
.886 .32659 Mdot
.886 .32677 Mdot
.886 .32706 Mdot
.886 .32728 Mdot
.886 .32771 Mdot
.886 .32865 Mdot
.886 .32886 Mdot
.886 .32894 Mdot
.886 .32961 Mdot
.886 .32985 Mdot
.886 .32992 Mdot
.886 .33032 Mdot
.886 .33055 Mdot
.886 .33084 Mdot
.886 .33223 Mdot
.886 .33301 Mdot
.886 .33316 Mdot
.886 .33355 Mdot
.886 .33374 Mdot
.886 .33408 Mdot
.886 .33457 Mdot
.886 .3349 Mdot
.886 .33534 Mdot
.886 .33548 Mdot
.886 .33586 Mdot
.886 .33595 Mdot
.886 .33702 Mdot
.886 .33714 Mdot
.886 .33731 Mdot
.886 .3374 Mdot
.886 .33771 Mdot
.886 .33772 Mdot
.886 .3379 Mdot
.886 .33873 Mdot
.886 .33892 Mdot
.886 .34013 Mdot
.886 .3402 Mdot
.886 .34146 Mdot
.886 .34146 Mdot
.886 .34162 Mdot
.886 .34244 Mdot
.886 .34246 Mdot
.886 .34286 Mdot
.886 .34309 Mdot
.886 .34325 Mdot
.886 .34363 Mdot
.886 .34365 Mdot
.886 .34401 Mdot
.886 .34428 Mdot
.886 .34509 Mdot
.886 .34528 Mdot
.886 .34554 Mdot
.886 .34614 Mdot
.886 .34739 Mdot
.886 .34742 Mdot
.886 .34743 Mdot
.886 .34748 Mdot
.886 .34764 Mdot
.886 .34784 Mdot
.886 .34789 Mdot
.886 .34795 Mdot
.886 .34818 Mdot
.886 .3492 Mdot
.886 .35215 Mdot
.886 .35277 Mdot
.886 .35289 Mdot
.886 .35386 Mdot
.886 .35457 Mdot
.886 .35543 Mdot
.886 .35598 Mdot
.886 .35602 Mdot
.886 .35697 Mdot
.886 .35725 Mdot
.886 .35778 Mdot
.886 .35816 Mdot
.886 .35859 Mdot
.886 .35968 Mdot
.886 .36137 Mdot
.886 .36165 Mdot
.886 .36268 Mdot
.886 .36275 Mdot
.886 .36315 Mdot
.886 .36317 Mdot
.886 .36441 Mdot
.886 .36493 Mdot
.886 .36499 Mdot
.886 .36536 Mdot
.886 .36564 Mdot
.886 .36616 Mdot
.886 .36674 Mdot
.886 .36745 Mdot
.886 .36767 Mdot
.886 .36818 Mdot
.886 .36923 Mdot
.886 .36964 Mdot
.886 .36982 Mdot
.886 .37016 Mdot
.886 .37167 Mdot
.886 .3724 Mdot
.886 .37363 Mdot
.886 .37386 Mdot
.886 .3743 Mdot
.886 .37516 Mdot
.886 .37578 Mdot
.886 .37587 Mdot
.886 .37642 Mdot
.886 .37701 Mdot
.886 .37735 Mdot
.886 .37745 Mdot
.886 .37752 Mdot
.886 .37772 Mdot
.886 .37809 Mdot
.886 .3787 Mdot
.886 .37928 Mdot
.886 .37936 Mdot
.886 .37959 Mdot
.886 .37969 Mdot
.886 .37971 Mdot
.886 .37977 Mdot
.886 .38025 Mdot
.886 .38103 Mdot
.886 .38222 Mdot
.886 .38226 Mdot
.886 .38315 Mdot
.886 .38359 Mdot
.886 .38418 Mdot
.886 .38453 Mdot
.886 .38538 Mdot
.886 .38603 Mdot
.886 .38608 Mdot
.886 .38695 Mdot
.886 .3875 Mdot
.886 .38791 Mdot
.886 .38954 Mdot
.886 .39074 Mdot
.886 .39109 Mdot
.886 .39124 Mdot
.886 .39169 Mdot
.886 .39184 Mdot
.886 .39272 Mdot
.886 .39295 Mdot
.886 .39322 Mdot
.886 .39365 Mdot
.886 .39407 Mdot
.886 .39441 Mdot
.886 .39448 Mdot
.886 .39498 Mdot
.886 .39509 Mdot
.886 .39533 Mdot
.886 .39545 Mdot
.886 .39559 Mdot
.886 .39578 Mdot
.886 .39629 Mdot
.886 .39662 Mdot
.886 .39683 Mdot
.886 .39696 Mdot
.886 .39725 Mdot
.886 .39741 Mdot
.886 .39746 Mdot
.886 .39815 Mdot
.886 .39826 Mdot
.886 .39827 Mdot
.886 .3996 Mdot
.886 .39966 Mdot
.886 .39996 Mdot
.886 .4001 Mdot
.886 .40024 Mdot
.886 .40051 Mdot
.886 .40061 Mdot
.886 .40089 Mdot
.886 .40096 Mdot
.886 .40126 Mdot
.886 .40171 Mdot
.886 .40172 Mdot
.886 .40172 Mdot
.886 .40174 Mdot
.886 .40187 Mdot
.886 .40188 Mdot
.886 .44659 Mdot
.886 .4466 Mdot
.886 .44667 Mdot
.886 .44668 Mdot
.886 .44668 Mdot
.886 .44669 Mdot
.886 .44692 Mdot
.886 .44708 Mdot
.886 .44712 Mdot
.886 .44727 Mdot
.886 .44733 Mdot
.886 .44747 Mdot
.886 .44754 Mdot
.886 .44762 Mdot
.886 .44778 Mdot
.886 .44781 Mdot
.886 .44852 Mdot
.886 .44852 Mdot
.886 .44858 Mdot
.886 .44894 Mdot
.886 .44897 Mdot
.886 .44905 Mdot
.886 .44921 Mdot
.886 .44928 Mdot
.886 .44939 Mdot
.886 .44956 Mdot
.886 .44983 Mdot
.886 .44993 Mdot
.886 .45001 Mdot
.886 .45007 Mdot
.886 .45019 Mdot
.886 .45025 Mdot
.886 .45051 Mdot
.886 .45055 Mdot
.886 .45073 Mdot
.886 .45095 Mdot
.886 .45117 Mdot
.886 .45132 Mdot
.886 .45143 Mdot
.886 .4519 Mdot
.886 .45197 Mdot
.886 .45221 Mdot
.886 .45228 Mdot
.886 .45246 Mdot
.886 .45309 Mdot
.886 .45392 Mdot
.886 .45414 Mdot
.886 .45442 Mdot
.886 .45486 Mdot
.886 .45489 Mdot
.886 .45522 Mdot
.886 .45565 Mdot
.886 .45583 Mdot
.886 .45613 Mdot
.886 .45636 Mdot
.886 .45681 Mdot
.886 .45683 Mdot
.886 .45743 Mdot
.886 .45783 Mdot
.886 .45807 Mdot
.886 .4581 Mdot
.886 .4581 Mdot
.886 .45816 Mdot
.886 .45827 Mdot
.886 .45831 Mdot
.886 .4586 Mdot
.886 .45891 Mdot
.886 .45909 Mdot
.886 .45919 Mdot
.886 .45923 Mdot
.886 .45928 Mdot
.886 .45945 Mdot
.886 .45974 Mdot
.886 .46002 Mdot
.886 .46037 Mdot
.886 .4608 Mdot
.886 .46102 Mdot
.886 .46113 Mdot
.886 .46174 Mdot
.886 .4621 Mdot
.886 .46284 Mdot
.886 .46301 Mdot
.886 .4631 Mdot
.886 .4633 Mdot
.886 .46381 Mdot
.886 .46406 Mdot
.886 .46417 Mdot
.886 .46452 Mdot
.886 .4648 Mdot
.886 .46505 Mdot
.886 .46518 Mdot
.886 .46536 Mdot
.886 .46539 Mdot
.886 .46564 Mdot
.886 .46624 Mdot
.886 .46625 Mdot
.886 .46645 Mdot
.886 .46648 Mdot
.886 .46698 Mdot
.886 .46711 Mdot
.886 .46792 Mdot
.886 .46844 Mdot
.886 .46865 Mdot
.886 .46883 Mdot
.886 .46908 Mdot
.886 .46922 Mdot
.886 .46967 Mdot
.886 .46969 Mdot
.886 .46995 Mdot
.886 .47036 Mdot
.886 .47069 Mdot
.886 .47115 Mdot
.886 .47121 Mdot
.886 .4715 Mdot
.886 .47289 Mdot
.886 .47336 Mdot
.886 .47347 Mdot
.886 .4735 Mdot
.886 .47352 Mdot
.886 .47361 Mdot
.886 .47369 Mdot
.886 .47371 Mdot
.886 .47372 Mdot
.886 .47373 Mdot
.886 .47431 Mdot
.886 .47459 Mdot
.886 .47471 Mdot
.886 .4748 Mdot
.886 .47518 Mdot
.886 .4753 Mdot
.886 .47547 Mdot
.886 .47548 Mdot
.886 .47565 Mdot
.886 .47573 Mdot
.886 .47584 Mdot
.886 .47602 Mdot
.886 .47603 Mdot
.886 .47641 Mdot
.886 .47648 Mdot
.886 .47648 Mdot
.886 .47706 Mdot
.886 .47709 Mdot
.886 .47765 Mdot
.886 .47774 Mdot
.886 .47812 Mdot
.886 .4782 Mdot
.886 .4782 Mdot
.886 .47834 Mdot
.886 .47839 Mdot
.886 .47846 Mdot
.886 .47852 Mdot
.886 .47901 Mdot
.886 .47905 Mdot
.886 .47922 Mdot
.886 .47928 Mdot
.886 .47948 Mdot
.886 .47964 Mdot
.886 .47986 Mdot
.886 .48001 Mdot
.886 .4801 Mdot
.886 .48028 Mdot
.886 .48034 Mdot
.886 .4807 Mdot
.886 .48133 Mdot
.886 .48146 Mdot
.886 .48156 Mdot
.886 .48174 Mdot
.886 .48177 Mdot
.886 .48188 Mdot
.886 .48218 Mdot
.886 .48222 Mdot
.886 .48232 Mdot
.886 .48274 Mdot
.886 .48293 Mdot
.886 .48303 Mdot
.886 .48316 Mdot
.886 .48324 Mdot
.886 .48343 Mdot
.886 .48394 Mdot
.886 .48405 Mdot
.886 .48447 Mdot
.886 .4848 Mdot
.886 .48507 Mdot
.886 .48538 Mdot
.886 .48545 Mdot
.886 .48554 Mdot
.886 .48582 Mdot
.886 .48596 Mdot
.886 .48613 Mdot
.886 .48617 Mdot
.886 .48626 Mdot
.886 .4863 Mdot
.886 .48635 Mdot
.886 .48675 Mdot
.886 .48684 Mdot
.886 .48702 Mdot
.886 .48742 Mdot
.886 .48853 Mdot
.886 .48863 Mdot
.886 .48883 Mdot
.886 .49027 Mdot
.886 .4907 Mdot
.886 .49116 Mdot
.886 .49175 Mdot
.886 .49176 Mdot
.886 .49178 Mdot
.886 .49244 Mdot
.886 .49276 Mdot
.886 .49282 Mdot
.886 .49306 Mdot
.886 .49353 Mdot
.886 .49372 Mdot
.886 .49375 Mdot
.886 .49446 Mdot
.886 .49446 Mdot
.886 .49483 Mdot
.886 .49485 Mdot
.886 .49504 Mdot
.886 .4953 Mdot
.886 .49549 Mdot
.886 .49597 Mdot
.886 .49621 Mdot
.886 .49675 Mdot
.886 .49691 Mdot
.886 .49696 Mdot
.886 .49799 Mdot
.886 .49819 Mdot
.886 .49821 Mdot
.886 .49902 Mdot
.886 .49925 Mdot
.886 .49951 Mdot
.886 .49951 Mdot
.886 .49957 Mdot
.886 .49959 Mdot
.886 .4997 Mdot
.886 .49988 Mdot
.886 .49993 Mdot
.886 .50001 Mdot
.886 .50048 Mdot
.886 .50055 Mdot
.886 .50059 Mdot
.886 .5008 Mdot
.886 .50116 Mdot
.886 .50121 Mdot
.886 .50158 Mdot
.886 .50178 Mdot
.886 .50186 Mdot
.886 .50195 Mdot
.886 .50196 Mdot
.886 .50222 Mdot
.886 .50229 Mdot
.886 .50271 Mdot
.886 .50286 Mdot
.886 .5034 Mdot
.886 .5035 Mdot
.886 .50362 Mdot
.886 .50409 Mdot
.886 .50429 Mdot
.886 .50454 Mdot
.886 .50492 Mdot
.886 .50503 Mdot
.886 .50533 Mdot
.886 .50554 Mdot
.886 .50555 Mdot
.886 .506 Mdot
.886 .50659 Mdot
.886 .50669 Mdot
.886 .50691 Mdot
.886 .50736 Mdot
.886 .508 Mdot
.886 .50838 Mdot
.886 .50873 Mdot
.886 .50873 Mdot
.886 .50889 Mdot
.886 .50903 Mdot
.886 .50919 Mdot
.886 .50936 Mdot
.886 .50955 Mdot
.886 .50976 Mdot
.886 .51022 Mdot
.886 .51047 Mdot
.886 .51061 Mdot
.886 .51082 Mdot
.886 .51091 Mdot
.886 .51109 Mdot
.886 .5117 Mdot
.886 .51193 Mdot
.886 .51204 Mdot
.886 .51218 Mdot
.886 .51252 Mdot
.886 .51261 Mdot
.886 .51269 Mdot
.886 .51273 Mdot
.886 .51285 Mdot
.886 .51315 Mdot
.886 .5132 Mdot
.886 .51362 Mdot
.886 .51461 Mdot
.886 .51463 Mdot
.886 .51472 Mdot
.886 .51495 Mdot
.886 .515 Mdot
.886 .51553 Mdot
.886 .51563 Mdot
.886 .51581 Mdot
.886 .51602 Mdot
.886 .51621 Mdot
.886 .51642 Mdot
.886 .51649 Mdot
.886 .51665 Mdot
.886 .51682 Mdot
.886 .5173 Mdot
.886 .51743 Mdot
.886 .51769 Mdot
.886 .51789 Mdot
.886 .5181 Mdot
.886 .51831 Mdot
.886 .51841 Mdot
.886 .51869 Mdot
.886 .51906 Mdot
.886 .51926 Mdot
.886 .51936 Mdot
.886 .51968 Mdot
.886 .51983 Mdot
.886 .51992 Mdot
.886 .51995 Mdot
.886 .52019 Mdot
.886 .52033 Mdot
.886 .52043 Mdot
.886 .52084 Mdot
.886 .52091 Mdot
.886 .52138 Mdot
.886 .52158 Mdot
.886 .52192 Mdot
.886 .52201 Mdot
.886 .52209 Mdot
.886 .52222 Mdot
.886 .52248 Mdot
.886 .52249 Mdot
.886 .52272 Mdot
.886 .52295 Mdot
.886 .52318 Mdot
.886 .52319 Mdot
.886 .5237 Mdot
.886 .52427 Mdot
.886 .5243 Mdot
.886 .5249 Mdot
.886 .52503 Mdot
.886 .52506 Mdot
.886 .52509 Mdot
.886 .52516 Mdot
.886 .5252 Mdot
.886 .5253 Mdot
.886 .52532 Mdot
.886 .52533 Mdot
.886 .52535 Mdot
.886 .52578 Mdot
.886 .52604 Mdot
.886 .52607 Mdot
.886 .5262 Mdot
.886 .52637 Mdot
.886 .52651 Mdot
.886 .52661 Mdot
.886 .52696 Mdot
.886 .52703 Mdot
.886 .52718 Mdot
.886 .52736 Mdot
.886 .52737 Mdot
.886 .52752 Mdot
.886 .52754 Mdot
.886 .52756 Mdot
.886 .52765 Mdot
.886 .52776 Mdot
.886 .52779 Mdot
.886 .52796 Mdot
.886 .52797 Mdot
.886 .52814 Mdot
.886 .52828 Mdot
.886 .52837 Mdot
.886 .52844 Mdot
.886 .52845 Mdot
.886 .52871 Mdot
.886 .529 Mdot
.886 .52904 Mdot
.886 .52907 Mdot
.886 .52921 Mdot
.886 .52961 Mdot
.886 .5297 Mdot
.886 .52972 Mdot
.886 .52985 Mdot
.886 .52994 Mdot
.886 .53006 Mdot
.886 .53014 Mdot
.886 .53014 Mdot
.886 .53027 Mdot
.886 .53031 Mdot
.886 .53038 Mdot
.886 .53043 Mdot
.886 .53049 Mdot
.886 .53064 Mdot
.886 .53087 Mdot
.886 .5309 Mdot
.886 .53104 Mdot
.886 .53105 Mdot
.886 .5311 Mdot
.886 .53111 Mdot
.886 .53127 Mdot
.886 .53134 Mdot
.886 .53135 Mdot
.886 .5314 Mdot
.886 .53144 Mdot
.886 .53151 Mdot
.886 .53159 Mdot
.886 .53168 Mdot
.886 .53171 Mdot
.886 .53178 Mdot
.886 .53192 Mdot
.886 .53197 Mdot
.886 .532 Mdot
.886 .53204 Mdot
.886 .53224 Mdot
.886 .53234 Mdot
.886 .5325 Mdot
.886 .53254 Mdot
.886 .53259 Mdot
.886 .53271 Mdot
.886 .5328 Mdot
.886 .53288 Mdot
.886 .53295 Mdot
.886 .533 Mdot
.886 .53301 Mdot
.886 .53302 Mdot
.886 .53305 Mdot
.886 .5331 Mdot
.886 .53318 Mdot
.886 .53326 Mdot
.886 .53327 Mdot
.886 .5333 Mdot
.886 .53331 Mdot
.886 .53331 Mdot
.886 .53332 Mdot
.886 .53338 Mdot
.886 .53349 Mdot
.886 .53364 Mdot
.886 .53365 Mdot
.886 .53377 Mdot
.886 .53383 Mdot
.886 .5339 Mdot
.886 .53395 Mdot
.886 .53406 Mdot
.886 .53415 Mdot
.886 .53415 Mdot
.886 .53427 Mdot
.886 .53434 Mdot
.886 .5344 Mdot
.886 .53461 Mdot
.886 .53477 Mdot
.886 .53482 Mdot
.886 .53484 Mdot
.886 .5349 Mdot
.886 .53491 Mdot
.886 .53503 Mdot
.886 .53506 Mdot
.886 .5351 Mdot
.886 .53515 Mdot
.886 .53521 Mdot
.886 .53525 Mdot
.886 .53526 Mdot
.886 .53533 Mdot
.886 .53534 Mdot
.886 .53537 Mdot
.886 .53539 Mdot
.886 .53541 Mdot
.886 .53543 Mdot
.886 .5355 Mdot
.886 .53555 Mdot
.886 .53557 Mdot
.886 .53559 Mdot
.886 .53563 Mdot
.886 .53565 Mdot
.886 .53566 Mdot
.886 .53575 Mdot
.886 .53576 Mdot
.886 .53576 Mdot
.886 .53594 Mdot
.886 .53594 Mdot
.886 .53598 Mdot
.886 .536 Mdot
.886 .53602 Mdot
.886 .53606 Mdot
.886 .53607 Mdot
.886 .53611 Mdot
.886 .53612 Mdot
.886 .53616 Mdot
.886 .53621 Mdot
.886 .53622 Mdot
.886 .53622 Mdot
.886 .53622 Mdot
.886 .53624 Mdot
.886 .53624 Mdot
.888 .19487 Mdot
.888 .19488 Mdot
.888 .19488 Mdot
.888 .1949 Mdot
.888 .1949 Mdot
.888 .19493 Mdot
.888 .19493 Mdot
.888 .19498 Mdot
.888 .19506 Mdot
.888 .19506 Mdot
.888 .19511 Mdot
.888 .19511 Mdot
.888 .19518 Mdot
.888 .19526 Mdot
.888 .19527 Mdot
.888 .19528 Mdot
.888 .19528 Mdot
.888 .19532 Mdot
.888 .19539 Mdot
.888 .1954 Mdot
.888 .19571 Mdot
.888 .19573 Mdot
.888 .19585 Mdot
.888 .19592 Mdot
.888 .19602 Mdot
.888 .19615 Mdot
.888 .19623 Mdot
.888 .19639 Mdot
.888 .19653 Mdot
.888 .19669 Mdot
.888 .19671 Mdot
.888 .19671 Mdot
.888 .19689 Mdot
.888 .19713 Mdot
.888 .19717 Mdot
.888 .19726 Mdot
.888 .19751 Mdot
.888 .198 Mdot
.888 .19809 Mdot
.888 .19811 Mdot
.888 .19817 Mdot
.888 .19866 Mdot
.888 .19871 Mdot
.888 .19896 Mdot
.888 .19904 Mdot
.888 .19927 Mdot
.888 .19966 Mdot
.888 .20051 Mdot
.888 .20074 Mdot
.888 .20083 Mdot
.888 .2009 Mdot
.888 .20097 Mdot
.888 .20123 Mdot
.888 .20166 Mdot
.888 .20166 Mdot
.888 .20188 Mdot
.888 .20222 Mdot
.888 .2024 Mdot
.888 .20249 Mdot
.888 .20286 Mdot
.888 .20296 Mdot
.888 .20301 Mdot
.888 .20307 Mdot
.888 .20323 Mdot
.888 .20349 Mdot
.888 .20365 Mdot
.888 .20412 Mdot
.888 .20428 Mdot
.888 .20439 Mdot
.888 .20464 Mdot
.888 .20474 Mdot
.888 .20495 Mdot
.888 .20558 Mdot
.888 .20559 Mdot
.888 .2056 Mdot
.888 .20602 Mdot
.888 .20635 Mdot
.888 .20639 Mdot
.888 .20685 Mdot
.888 .20685 Mdot
.888 .20699 Mdot
.888 .2072 Mdot
.888 .20823 Mdot
.888 .20847 Mdot
.888 .20855 Mdot
.888 .20956 Mdot
.888 .21003 Mdot
.888 .21005 Mdot
.888 .21008 Mdot
.888 .21019 Mdot
.888 .21151 Mdot
.888 .21208 Mdot
.888 .21212 Mdot
.888 .2122 Mdot
.888 .21315 Mdot
.888 .21346 Mdot
.888 .21354 Mdot
.888 .21394 Mdot
.888 .21446 Mdot
.888 .21453 Mdot
.888 .2153 Mdot
.888 .21624 Mdot
.888 .21659 Mdot
.888 .21827 Mdot
.888 .21881 Mdot
.888 .22009 Mdot
.888 .22059 Mdot
.888 .22077 Mdot
.888 .22078 Mdot
.888 .22107 Mdot
.888 .22108 Mdot
.888 .22146 Mdot
.888 .22207 Mdot
.888 .22214 Mdot
.888 .2227 Mdot
.888 .22316 Mdot
.888 .22413 Mdot
.888 .22537 Mdot
.888 .22558 Mdot
.888 .22797 Mdot
.888 .22798 Mdot
.888 .2282 Mdot
.888 .2288 Mdot
.888 .229 Mdot
.888 .22915 Mdot
.888 .23023 Mdot
.888 .23043 Mdot
.888 .23093 Mdot
.888 .23107 Mdot
.888 .23108 Mdot
.888 .23157 Mdot
.888 .23171 Mdot
.888 .23227 Mdot
.888 .23254 Mdot
.888 .23346 Mdot
.888 .23346 Mdot
.888 .23387 Mdot
.888 .23462 Mdot
.888 .2347 Mdot
.888 .23475 Mdot
.888 .23513 Mdot
.888 .23534 Mdot
.888 .23539 Mdot
.888 .23582 Mdot
.888 .23649 Mdot
.888 .23658 Mdot
.888 .23677 Mdot
.888 .23702 Mdot
.888 .23742 Mdot
.888 .23746 Mdot
.888 .23771 Mdot
.888 .23774 Mdot
.888 .23798 Mdot
.888 .23829 Mdot
.888 .23858 Mdot
.888 .23917 Mdot
.888 .23959 Mdot
.888 .24022 Mdot
.888 .24025 Mdot
.888 .24065 Mdot
.888 .24084 Mdot
.888 .24215 Mdot
.888 .24247 Mdot
.888 .2425 Mdot
.888 .24277 Mdot
.888 .24394 Mdot
.888 .24451 Mdot
.888 .24466 Mdot
.888 .2453 Mdot
.888 .24702 Mdot
.888 .24737 Mdot
.888 .24756 Mdot
.888 .2476 Mdot
.888 .2476 Mdot
.888 .24778 Mdot
.888 .24801 Mdot
.888 .24826 Mdot
.888 .24861 Mdot
.888 .24871 Mdot
.888 .24877 Mdot
.888 .24908 Mdot
.888 .2491 Mdot
.888 .24915 Mdot
.888 .24922 Mdot
.888 .24934 Mdot
.888 .24941 Mdot
.888 .24947 Mdot
.888 .24963 Mdot
.888 .24984 Mdot
.888 .2499 Mdot
.888 .25064 Mdot
.888 .25072 Mdot
.888 .25116 Mdot
.888 .2512 Mdot
.888 .25136 Mdot
.888 .25198 Mdot
.888 .25221 Mdot
.888 .2523 Mdot
.888 .25234 Mdot
.888 .25237 Mdot
.888 .25269 Mdot
.888 .25282 Mdot
.888 .25319 Mdot
.888 .25322 Mdot
.888 .25362 Mdot
.888 .25368 Mdot
.888 .25445 Mdot
.888 .25467 Mdot
.888 .25471 Mdot
.888 .25508 Mdot
.888 .25537 Mdot
.888 .25543 Mdot
.888 .25546 Mdot
.888 .25549 Mdot
.888 .2555 Mdot
.888 .25569 Mdot
.888 .25592 Mdot
.888 .25605 Mdot
.888 .25617 Mdot
.888 .25626 Mdot
.888 .25628 Mdot
.888 .25656 Mdot
.888 .25746 Mdot
.888 .25779 Mdot
.888 .25788 Mdot
.888 .25881 Mdot
.888 .25897 Mdot
.888 .26054 Mdot
.888 .26111 Mdot
.888 .26128 Mdot
.888 .26145 Mdot
.888 .26159 Mdot
.888 .26174 Mdot
.888 .26177 Mdot
.888 .262 Mdot
.888 .26214 Mdot
.888 .26225 Mdot
.888 .2623 Mdot
.888 .26297 Mdot
.888 .26309 Mdot
.888 .26331 Mdot
.888 .26334 Mdot
.888 .26407 Mdot
.888 .26462 Mdot
.888 .26513 Mdot
.888 .26551 Mdot
.888 .26551 Mdot
.888 .2656 Mdot
.888 .26603 Mdot
.888 .2668 Mdot
.888 .26998 Mdot
.888 .27064 Mdot
.888 .27141 Mdot
.888 .27211 Mdot
.888 .27232 Mdot
.888 .27233 Mdot
.888 .27245 Mdot
.888 .27376 Mdot
.888 .27546 Mdot
.888 .27573 Mdot
.888 .27647 Mdot
.888 .2771 Mdot
.888 .27717 Mdot
.888 .27793 Mdot
.888 .278 Mdot
.888 .28088 Mdot
.888 .28098 Mdot
.888 .28101 Mdot
.888 .28103 Mdot
.888 .28147 Mdot
.888 .28244 Mdot
.888 .28251 Mdot
.888 .28401 Mdot
.888 .28504 Mdot
.888 .28551 Mdot
.888 .28646 Mdot
.888 .28699 Mdot
.888 .28719 Mdot
.888 .28775 Mdot
.888 .28794 Mdot
.888 .28854 Mdot
.888 .2886 Mdot
.888 .28921 Mdot
.888 .28933 Mdot
.888 .28957 Mdot
.888 .29031 Mdot
.888 .29032 Mdot
.888 .29092 Mdot
.888 .2914 Mdot
.888 .29151 Mdot
.888 .29164 Mdot
.888 .29331 Mdot
.888 .29437 Mdot
.888 .29451 Mdot
.888 .29497 Mdot
.888 .29505 Mdot
.888 .29599 Mdot
.888 .29611 Mdot
.888 .29614 Mdot
.888 .29634 Mdot
.888 .29813 Mdot
.888 .29824 Mdot
.888 .29929 Mdot
.888 .29929 Mdot
.888 .29933 Mdot
.888 .29978 Mdot
.888 .30016 Mdot
.888 .30091 Mdot
.888 .30165 Mdot
.888 .30235 Mdot
.888 .30375 Mdot
.888 .30381 Mdot
.888 .30417 Mdot
.888 .30445 Mdot
.888 .30546 Mdot
.888 .30547 Mdot
.888 .30583 Mdot
.888 .30585 Mdot
.888 .30716 Mdot
.888 .30766 Mdot
.888 .30841 Mdot
.888 .31012 Mdot
.888 .31015 Mdot
.888 .31052 Mdot
.888 .31092 Mdot
.888 .31145 Mdot
.888 .31305 Mdot
.888 .31353 Mdot
.888 .31366 Mdot
.888 .31368 Mdot
.888 .31562 Mdot
.888 .31616 Mdot
.888 .31674 Mdot
.888 .31741 Mdot
.888 .31925 Mdot
.888 .32013 Mdot
.888 .32069 Mdot
.888 .32408 Mdot
.888 .32608 Mdot
.888 .32675 Mdot
.888 .32804 Mdot
.888 .32933 Mdot
.888 .32959 Mdot
.888 .32979 Mdot
.888 .33119 Mdot
.888 .33148 Mdot
.888 .33183 Mdot
.888 .33254 Mdot
.888 .33257 Mdot
.888 .33337 Mdot
.888 .33341 Mdot
.888 .3339 Mdot
.888 .3339 Mdot
.888 .33427 Mdot
.888 .3353 Mdot
.888 .33837 Mdot
.888 .33888 Mdot
.888 .33892 Mdot
.888 .33899 Mdot
.888 .3398 Mdot
.888 .34046 Mdot
.888 .34389 Mdot
.888 .34524 Mdot
.888 .34595 Mdot
.888 .34622 Mdot
.888 .3467 Mdot
.888 .34709 Mdot
.888 .34891 Mdot
.888 .34904 Mdot
.888 .3506 Mdot
.888 .35061 Mdot
.888 .35075 Mdot
.888 .35113 Mdot
.888 .35135 Mdot
.888 .35215 Mdot
.888 .35285 Mdot
.888 .35327 Mdot
.888 .35399 Mdot
.888 .35423 Mdot
.888 .35467 Mdot
.888 .35512 Mdot
.888 .35537 Mdot
.888 .35646 Mdot
.888 .35728 Mdot
.888 .35786 Mdot
.888 .35788 Mdot
.888 .3581 Mdot
.888 .3582 Mdot
.888 .35892 Mdot
.888 .35911 Mdot
.888 .35988 Mdot
.888 .36168 Mdot
.888 .3618 Mdot
.888 .3624 Mdot
.888 .36273 Mdot
.888 .36276 Mdot
.888 .36284 Mdot
.888 .36295 Mdot
.888 .36363 Mdot
.888 .36371 Mdot
.888 .36402 Mdot
.888 .36414 Mdot
.888 .36418 Mdot
.888 .3642 Mdot
.888 .36422 Mdot
.888 .36462 Mdot
.888 .36464 Mdot
.888 .36535 Mdot
.888 .36555 Mdot
.888 .36573 Mdot
.888 .36575 Mdot
.888 .36596 Mdot
.888 .36602 Mdot
.888 .36612 Mdot
.888 .36613 Mdot
.888 .36627 Mdot
.888 .3685 Mdot
.888 .36873 Mdot
.888 .36946 Mdot
.888 .37246 Mdot
.888 .37309 Mdot
.888 .37349 Mdot
.888 .3735 Mdot
.888 .37485 Mdot
.888 .37497 Mdot
.888 .37594 Mdot
.888 .37716 Mdot
.888 .3772 Mdot
.888 .37722 Mdot
.888 .37908 Mdot
.888 .37969 Mdot
.888 .38 Mdot
.888 .38074 Mdot
.888 .38104 Mdot
.888 .38152 Mdot
.888 .3829 Mdot
.888 .38336 Mdot
.888 .38415 Mdot
.888 .38462 Mdot
.888 .38479 Mdot
.888 .38494 Mdot
.888 .38523 Mdot
.888 .38633 Mdot
.888 .3866 Mdot
.888 .38713 Mdot
.888 .38811 Mdot
.888 .38875 Mdot
.888 .38876 Mdot
.888 .39004 Mdot
.888 .39081 Mdot
.888 .39101 Mdot
.888 .39123 Mdot
.888 .39148 Mdot
.888 .39216 Mdot
.888 .39465 Mdot
.888 .39583 Mdot
.888 .39649 Mdot
.888 .39673 Mdot
.888 .39746 Mdot
.888 .3976 Mdot
.888 .39905 Mdot
.888 .39923 Mdot
.888 .39927 Mdot
.888 .39956 Mdot
.888 .401 Mdot
.888 .40172 Mdot
.888 .40198 Mdot
.888 .40212 Mdot
.888 .4028 Mdot
.888 .40334 Mdot
.888 .40334 Mdot
.888 .40339 Mdot
.888 .40388 Mdot
.888 .40427 Mdot
.888 .40475 Mdot
.888 .40499 Mdot
.888 .40537 Mdot
.888 .40565 Mdot
.888 .40586 Mdot
.888 .40622 Mdot
.888 .40628 Mdot
.888 .40717 Mdot
.888 .40721 Mdot
.888 .40742 Mdot
.888 .40753 Mdot
.888 .40754 Mdot
.888 .40757 Mdot
.888 .4076 Mdot
.888 .40784 Mdot
.888 .40803 Mdot
.888 .40804 Mdot
.888 .40818 Mdot
.888 .40818 Mdot
.888 .40843 Mdot
.888 .40856 Mdot
.888 .40856 Mdot
.888 .40864 Mdot
.888 .40866 Mdot
.888 .40869 Mdot
.888 .40869 Mdot
.888 .40874 Mdot
.888 .44336 Mdot
.888 .44338 Mdot
.888 .44338 Mdot
.888 .4434 Mdot
.888 .44342 Mdot
.888 .44345 Mdot
.888 .44346 Mdot
.888 .44353 Mdot
.888 .44366 Mdot
.888 .44366 Mdot
.888 .44374 Mdot
.888 .44374 Mdot
.888 .44385 Mdot
.888 .44398 Mdot
.888 .444 Mdot
.888 .44401 Mdot
.888 .44402 Mdot
.888 .44408 Mdot
.888 .44419 Mdot
.888 .44421 Mdot
.888 .44469 Mdot
.888 .44473 Mdot
.888 .44492 Mdot
.888 .44503 Mdot
.888 .44519 Mdot
.888 .44539 Mdot
.888 .44552 Mdot
.888 .44578 Mdot
.888 .44599 Mdot
.888 .44625 Mdot
.888 .44628 Mdot
.888 .44628 Mdot
.888 .44657 Mdot
.888 .44693 Mdot
.888 .447 Mdot
.888 .44714 Mdot
.888 .44753 Mdot
.888 .44829 Mdot
.888 .44844 Mdot
.888 .44846 Mdot
.888 .44856 Mdot
.888 .44933 Mdot
.888 .4494 Mdot
.888 .44979 Mdot
.888 .44991 Mdot
.888 .45026 Mdot
.888 .45087 Mdot
.888 .45217 Mdot
.888 .45252 Mdot
.888 .45265 Mdot
.888 .45276 Mdot
.888 .45287 Mdot
.888 .45327 Mdot
.888 .45392 Mdot
.888 .45392 Mdot
.888 .45426 Mdot
.888 .45476 Mdot
.888 .45503 Mdot
.888 .45517 Mdot
.888 .45573 Mdot
.888 .45587 Mdot
.888 .45595 Mdot
.888 .45604 Mdot
.888 .45627 Mdot
.888 .45667 Mdot
.888 .4569 Mdot
.888 .4576 Mdot
.888 .45784 Mdot
.888 .45799 Mdot
.888 .45836 Mdot
.888 .45852 Mdot
.888 .45882 Mdot
.888 .45975 Mdot
.888 .45976 Mdot
.888 .45978 Mdot
.888 .46039 Mdot
.888 .46087 Mdot
.888 .46093 Mdot
.888 .4616 Mdot
.888 .4616 Mdot
.888 .4618 Mdot
.888 .46211 Mdot
.888 .46358 Mdot
.888 .46393 Mdot
.888 .46404 Mdot
.888 .46513 Mdot
.888 .46519 Mdot
.888 .4652 Mdot
.888 .46525 Mdot
.888 .46528 Mdot
.888 .46538 Mdot
.888 .46539 Mdot
.888 .46547 Mdot
.888 .46557 Mdot
.888 .46592 Mdot
.888 .46592 Mdot
.888 .46612 Mdot
.888 .46613 Mdot
.888 .46613 Mdot
.888 .46616 Mdot
.888 .46621 Mdot
.888 .46636 Mdot
.888 .4664 Mdot
.888 .46673 Mdot
.888 .46678 Mdot
.888 .46682 Mdot
.888 .46684 Mdot
.888 .46699 Mdot
.888 .46728 Mdot
.888 .46734 Mdot
.888 .4682 Mdot
.888 .46857 Mdot
.888 .46866 Mdot
.888 .469 Mdot
.888 .46905 Mdot
.888 .46915 Mdot
.888 .46916 Mdot
.888 .46944 Mdot
.888 .46983 Mdot
.888 .47034 Mdot
.888 .47046 Mdot
.888 .47067 Mdot
.888 .47088 Mdot
.888 .47099 Mdot
.888 .47133 Mdot
.888 .47153 Mdot
.888 .47186 Mdot
.888 .47223 Mdot
.888 .47234 Mdot
.888 .47251 Mdot
.888 .47258 Mdot
.888 .47258 Mdot
.888 .47331 Mdot
.888 .47337 Mdot
.888 .47422 Mdot
.888 .4744 Mdot
.888 .47462 Mdot
.888 .47475 Mdot
.888 .47508 Mdot
.888 .4757 Mdot
.888 .47728 Mdot
.888 .47758 Mdot
.888 .47795 Mdot
.888 .47799 Mdot
.888 .478 Mdot
.888 .47823 Mdot
.888 .47963 Mdot
.888 .4801 Mdot
.888 .48027 Mdot
.888 .48027 Mdot
.888 .48049 Mdot
.888 .48051 Mdot
.888 .48087 Mdot
.888 .48088 Mdot
.888 .4812 Mdot
.888 .48136 Mdot
.888 .48149 Mdot
.888 .48212 Mdot
.888 .48221 Mdot
.888 .48233 Mdot
.888 .4829 Mdot
.888 .48348 Mdot
.888 .48378 Mdot
.888 .48467 Mdot
.888 .48618 Mdot
.888 .48642 Mdot
.888 .48681 Mdot
.888 .48762 Mdot
.888 .48792 Mdot
.888 .48817 Mdot
.888 .48841 Mdot
.888 .48926 Mdot
.888 .48927 Mdot
.888 .48932 Mdot
.888 .48953 Mdot
.888 .49023 Mdot
.888 .49046 Mdot
.888 .49063 Mdot
.888 .4908 Mdot
.888 .49081 Mdot
.888 .49155 Mdot
.888 .49187 Mdot
.888 .49209 Mdot
.888 .49266 Mdot
.888 .49267 Mdot
.888 .49282 Mdot
.888 .49283 Mdot
.888 .49326 Mdot
.888 .49338 Mdot
.888 .49353 Mdot
.888 .49356 Mdot
.888 .49416 Mdot
.888 .49446 Mdot
.888 .49478 Mdot
.888 .4951 Mdot
.888 .49526 Mdot
.888 .49546 Mdot
.888 .49548 Mdot
.888 .49548 Mdot
.888 .49592 Mdot
.888 .49597 Mdot
.888 .49673 Mdot
.888 .49682 Mdot
.888 .49683 Mdot
.888 .49688 Mdot
.888 .49728 Mdot
.888 .49732 Mdot
.888 .49751 Mdot
.888 .49757 Mdot
.888 .49802 Mdot
.888 .49873 Mdot
.888 .49878 Mdot
.888 .49882 Mdot
.888 .49903 Mdot
.888 .49928 Mdot
.888 .49928 Mdot
.888 .4996 Mdot
.888 .4997 Mdot
.888 .49975 Mdot
.888 .50001 Mdot
.888 .50003 Mdot
.888 .50029 Mdot
.888 .50037 Mdot
.888 .5006 Mdot
.888 .50068 Mdot
.888 .50091 Mdot
.888 .50131 Mdot
.888 .5015 Mdot
.888 .50193 Mdot
.888 .50256 Mdot
.888 .50259 Mdot
.888 .503 Mdot
.888 .50318 Mdot
.888 .50318 Mdot
.888 .5032 Mdot
.888 .50324 Mdot
.888 .50444 Mdot
.888 .50447 Mdot
.888 .50478 Mdot
.888 .50481 Mdot
.888 .50507 Mdot
.888 .50538 Mdot
.888 .50549 Mdot
.888 .50619 Mdot
.888 .50673 Mdot
.888 .50678 Mdot
.888 .50679 Mdot
.888 .50687 Mdot
.888 .50716 Mdot
.888 .50747 Mdot
.888 .50775 Mdot
.888 .50905 Mdot
.888 .50937 Mdot
.888 .50954 Mdot
.888 .50958 Mdot
.888 .50958 Mdot
.888 .50974 Mdot
.888 .50994 Mdot
.888 .51017 Mdot
.888 .51047 Mdot
.888 .51048 Mdot
.888 .51057 Mdot
.888 .51062 Mdot
.888 .51089 Mdot
.888 .51091 Mdot
.888 .51095 Mdot
.888 .51101 Mdot
.888 .5111 Mdot
.888 .51111 Mdot
.888 .51118 Mdot
.888 .51123 Mdot
.888 .5113 Mdot
.888 .51137 Mdot
.888 .5116 Mdot
.888 .51224 Mdot
.888 .51231 Mdot
.888 .51268 Mdot
.888 .51272 Mdot
.888 .51285 Mdot
.888 .51322 Mdot
.888 .51333 Mdot
.888 .51334 Mdot
.888 .51338 Mdot
.888 .51342 Mdot
.888 .51348 Mdot
.888 .51357 Mdot
.888 .51364 Mdot
.888 .51365 Mdot
.888 .51366 Mdot
.888 .51367 Mdot
.888 .5137 Mdot
.888 .51381 Mdot
.888 .51396 Mdot
.888 .51398 Mdot
.888 .51407 Mdot
.888 .51438 Mdot
.888 .5144 Mdot
.888 .51456 Mdot
.888 .51458 Mdot
.888 .51473 Mdot
.888 .51478 Mdot
.888 .51491 Mdot
.888 .51492 Mdot
.888 .51493 Mdot
.888 .51497 Mdot
.888 .51506 Mdot
.888 .51531 Mdot
.888 .51538 Mdot
.888 .51539 Mdot
.888 .51557 Mdot
.888 .5156 Mdot
.888 .5159 Mdot
.888 .51592 Mdot
.888 .51601 Mdot
.888 .51607 Mdot
.888 .5161 Mdot
.888 .51612 Mdot
.888 .51617 Mdot
.888 .5162 Mdot
.888 .51622 Mdot
.888 .51623 Mdot
.888 .51635 Mdot
.888 .51638 Mdot
.888 .51656 Mdot
.888 .51666 Mdot
.888 .51675 Mdot
.888 .51682 Mdot
.888 .51682 Mdot
.888 .51684 Mdot
.888 .51691 Mdot
.888 .51705 Mdot
.888 .51774 Mdot
.888 .518 Mdot
.888 .51806 Mdot
.888 .51828 Mdot
.888 .51875 Mdot
.888 .51886 Mdot
.888 .51887 Mdot
.888 .519 Mdot
.888 .51952 Mdot
.888 .51959 Mdot
.888 .51975 Mdot
.888 .51977 Mdot
.888 .52001 Mdot
.888 .52018 Mdot
.888 .52041 Mdot
.888 .52053 Mdot
.888 .52065 Mdot
.888 .52075 Mdot
.888 .52076 Mdot
.888 .52086 Mdot
.888 .52088 Mdot
.888 .52104 Mdot
.888 .52113 Mdot
.888 .52121 Mdot
.888 .52125 Mdot
.888 .52151 Mdot
.888 .52168 Mdot
.888 .5217 Mdot
.888 .52178 Mdot
.888 .52193 Mdot
.888 .52195 Mdot
.888 .52198 Mdot
.888 .52228 Mdot
.888 .52244 Mdot
.888 .52244 Mdot
.888 .5228 Mdot
.888 .52291 Mdot
.888 .52313 Mdot
.888 .52319 Mdot
.888 .52338 Mdot
.888 .52338 Mdot
.888 .52344 Mdot
.888 .52364 Mdot
.888 .52371 Mdot
.888 .52414 Mdot
.888 .5242 Mdot
.888 .52428 Mdot
.888 .52451 Mdot
.888 .5246 Mdot
.888 .5246 Mdot
.888 .52554 Mdot
.888 .52562 Mdot
.888 .52611 Mdot
.888 .52649 Mdot
.888 .52667 Mdot
.888 .52689 Mdot
.888 .52691 Mdot
.888 .52715 Mdot
.888 .5273 Mdot
.888 .5273 Mdot
.888 .52742 Mdot
.888 .52742 Mdot
.888 .52749 Mdot
.888 .52768 Mdot
.888 .52818 Mdot
.888 .5284 Mdot
.888 .52905 Mdot
.888 .52918 Mdot
.888 .52955 Mdot
.888 .52985 Mdot
.888 .52988 Mdot
.888 .53008 Mdot
.888 .53023 Mdot
.888 .53026 Mdot
.888 .53038 Mdot
.888 .53075 Mdot
.888 .53078 Mdot
.888 .5308 Mdot
.888 .53102 Mdot
.888 .53153 Mdot
.888 .53157 Mdot
.888 .53158 Mdot
.888 .53159 Mdot
.888 .53177 Mdot
.888 .53216 Mdot
.888 .53219 Mdot
.888 .53229 Mdot
.888 .53268 Mdot
.888 .53276 Mdot
.888 .53282 Mdot
.888 .53282 Mdot
.888 .533 Mdot
.888 .53301 Mdot
.888 .53314 Mdot
.888 .5333 Mdot
.888 .5333 Mdot
.888 .53331 Mdot
.888 .53355 Mdot
.888 .53363 Mdot
.888 .53367 Mdot
.888 .53377 Mdot
.888 .53381 Mdot
.888 .53387 Mdot
.888 .53405 Mdot
.888 .53411 Mdot
.888 .53421 Mdot
.888 .53427 Mdot
.888 .53429 Mdot
.888 .53431 Mdot
.888 .53435 Mdot
.888 .5345 Mdot
.888 .53453 Mdot
.888 .5346 Mdot
.888 .53473 Mdot
.888 .53481 Mdot
.888 .53481 Mdot
.888 .53498 Mdot
.888 .53508 Mdot
.888 .53511 Mdot
.888 .53513 Mdot
.888 .53517 Mdot
.888 .53525 Mdot
.888 .53558 Mdot
.888 .53573 Mdot
.888 .53582 Mdot
.888 .53585 Mdot
.888 .53595 Mdot
.888 .53596 Mdot
.888 .53615 Mdot
.888 .53618 Mdot
.888 .53618 Mdot
.888 .53622 Mdot
.888 .5364 Mdot
.888 .5365 Mdot
.888 .53653 Mdot
.888 .53655 Mdot
.888 .53664 Mdot
.888 .53671 Mdot
.888 .53671 Mdot
.888 .53672 Mdot
.888 .53678 Mdot
.888 .53683 Mdot
.888 .53689 Mdot
.888 .53693 Mdot
.888 .53697 Mdot
.888 .53701 Mdot
.888 .53704 Mdot
.888 .53708 Mdot
.888 .53709 Mdot
.888 .53721 Mdot
.888 .53721 Mdot
.888 .53724 Mdot
.888 .53726 Mdot
.888 .53726 Mdot
.888 .53726 Mdot
.888 .53727 Mdot
.888 .5373 Mdot
.888 .53732 Mdot
.888 .53732 Mdot
.888 .53734 Mdot
.888 .53734 Mdot
.888 .53737 Mdot
.888 .53739 Mdot
.888 .53739 Mdot
.888 .5374 Mdot
.888 .5374 Mdot
.888 .53741 Mdot
.888 .53741 Mdot
.888 .53741 Mdot
.89 .19217 Mdot
.89 .19217 Mdot
.89 .19218 Mdot
.89 .19219 Mdot
.89 .19219 Mdot
.89 .19221 Mdot
.89 .19228 Mdot
.89 .1923 Mdot
.89 .1923 Mdot
.89 .19238 Mdot
.89 .19239 Mdot
.89 .19242 Mdot
.89 .19243 Mdot
.89 .19254 Mdot
.89 .19257 Mdot
.89 .19258 Mdot
.89 .19279 Mdot
.89 .19292 Mdot
.89 .19303 Mdot
.89 .19312 Mdot
.89 .19336 Mdot
.89 .19353 Mdot
.89 .19354 Mdot
.89 .19358 Mdot
.89 .19359 Mdot
.89 .19363 Mdot
.89 .19369 Mdot
.89 .19383 Mdot
.89 .19396 Mdot
.89 .19425 Mdot
.89 .19441 Mdot
.89 .19447 Mdot
.89 .19462 Mdot
.89 .19468 Mdot
.89 .19487 Mdot
.89 .19515 Mdot
.89 .19522 Mdot
.89 .19535 Mdot
.89 .19547 Mdot
.89 .19547 Mdot
.89 .19556 Mdot
.89 .19572 Mdot
.89 .19588 Mdot
.89 .19591 Mdot
.89 .19594 Mdot
.89 .19596 Mdot
.89 .19614 Mdot
.89 .19667 Mdot
.89 .19708 Mdot
.89 .19715 Mdot
.89 .1975 Mdot
.89 .19791 Mdot
.89 .19807 Mdot
.89 .19808 Mdot
.89 .19819 Mdot
.89 .19822 Mdot
.89 .1983 Mdot
.89 .1986 Mdot
.89 .19863 Mdot
.89 .19866 Mdot
.89 .19898 Mdot
.89 .19905 Mdot
.89 .19949 Mdot
.89 .19961 Mdot
.89 .20015 Mdot
.89 .20044 Mdot
.89 .20051 Mdot
.89 .20064 Mdot
.89 .20075 Mdot
.89 .20077 Mdot
.89 .20089 Mdot
.89 .20103 Mdot
.89 .20114 Mdot
.89 .20124 Mdot
.89 .20162 Mdot
.89 .20175 Mdot
.89 .20209 Mdot
.89 .20242 Mdot
.89 .20297 Mdot
.89 .20298 Mdot
.89 .20324 Mdot
.89 .20341 Mdot
.89 .20356 Mdot
.89 .20388 Mdot
.89 .20414 Mdot
.89 .20427 Mdot
.89 .20436 Mdot
.89 .20451 Mdot
.89 .2046 Mdot
.89 .20502 Mdot
.89 .20502 Mdot
.89 .20511 Mdot
.89 .20516 Mdot
.89 .20527 Mdot
.89 .20607 Mdot
.89 .20652 Mdot
.89 .20664 Mdot
.89 .20676 Mdot
.89 .20753 Mdot
.89 .20845 Mdot
.89 .20849 Mdot
.89 .20852 Mdot
.89 .20879 Mdot
.89 .20884 Mdot
.89 .20918 Mdot
.89 .20967 Mdot
.89 .21036 Mdot
.89 .21052 Mdot
.89 .21133 Mdot
.89 .21167 Mdot
.89 .21183 Mdot
.89 .21249 Mdot
.89 .21407 Mdot
.89 .21487 Mdot
.89 .21491 Mdot
.89 .21611 Mdot
.89 .21741 Mdot
.89 .21764 Mdot
.89 .21774 Mdot
.89 .21938 Mdot
.89 .21969 Mdot
.89 .21975 Mdot
.89 .21993 Mdot
.89 .21998 Mdot
.89 .22072 Mdot
.89 .22104 Mdot
.89 .2212 Mdot
.89 .22141 Mdot
.89 .2222 Mdot
.89 .22223 Mdot
.89 .22242 Mdot
.89 .22257 Mdot
.89 .22269 Mdot
.89 .22349 Mdot
.89 .22446 Mdot
.89 .22451 Mdot
.89 .22472 Mdot
.89 .22616 Mdot
.89 .22659 Mdot
.89 .22734 Mdot
.89 .22872 Mdot
.89 .22909 Mdot
.89 .22942 Mdot
.89 .22992 Mdot
.89 .23 Mdot
.89 .23025 Mdot
.89 .23293 Mdot
.89 .23308 Mdot
.89 .23388 Mdot
.89 .23416 Mdot
.89 .23514 Mdot
.89 .23648 Mdot
.89 .23654 Mdot
.89 .23682 Mdot
.89 .23697 Mdot
.89 .23713 Mdot
.89 .23731 Mdot
.89 .23815 Mdot
.89 .23835 Mdot
.89 .23972 Mdot
.89 .24002 Mdot
.89 .24038 Mdot
.89 .24051 Mdot
.89 .24157 Mdot
.89 .24298 Mdot
.89 .24399 Mdot
.89 .24415 Mdot
.89 .24439 Mdot
.89 .24453 Mdot
.89 .24482 Mdot
.89 .24547 Mdot
.89 .24627 Mdot
.89 .247 Mdot
.89 .24809 Mdot
.89 .24877 Mdot
.89 .24881 Mdot
.89 .24885 Mdot
.89 .2495 Mdot
.89 .24967 Mdot
.89 .25059 Mdot
.89 .25128 Mdot
.89 .25172 Mdot
.89 .2524 Mdot
.89 .25304 Mdot
.89 .25326 Mdot
.89 .25446 Mdot
.89 .25448 Mdot
.89 .2545 Mdot
.89 .25484 Mdot
.89 .25539 Mdot
.89 .2565 Mdot
.89 .25672 Mdot
.89 .25684 Mdot
.89 .25693 Mdot
.89 .25746 Mdot
.89 .25883 Mdot
.89 .25918 Mdot
.89 .2606 Mdot
.89 .26069 Mdot
.89 .26077 Mdot
.89 .26226 Mdot
.89 .26288 Mdot
.89 .26297 Mdot
.89 .26469 Mdot
.89 .26546 Mdot
.89 .26631 Mdot
.89 .26796 Mdot
.89 .2681 Mdot
.89 .26813 Mdot
.89 .26876 Mdot
.89 .26929 Mdot
.89 .26959 Mdot
.89 .26961 Mdot
.89 .27014 Mdot
.89 .27028 Mdot
.89 .27039 Mdot
.89 .27061 Mdot
.89 .27112 Mdot
.89 .27116 Mdot
.89 .27128 Mdot
.89 .27154 Mdot
.89 .2727 Mdot
.89 .2739 Mdot
.89 .27483 Mdot
.89 .27723 Mdot
.89 .27831 Mdot
.89 .27904 Mdot
.89 .27946 Mdot
.89 .27976 Mdot
.89 .27981 Mdot
.89 .28005 Mdot
.89 .28008 Mdot
.89 .28011 Mdot
.89 .28095 Mdot
.89 .28167 Mdot
.89 .28178 Mdot
.89 .28312 Mdot
.89 .28379 Mdot
.89 .28413 Mdot
.89 .28488 Mdot
.89 .28503 Mdot
.89 .28551 Mdot
.89 .28551 Mdot
.89 .2865 Mdot
.89 .28689 Mdot
.89 .28761 Mdot
.89 .28806 Mdot
.89 .28838 Mdot
.89 .28847 Mdot
.89 .28883 Mdot
.89 .28953 Mdot
.89 .28968 Mdot
.89 .29082 Mdot
.89 .29149 Mdot
.89 .29166 Mdot
.89 .29191 Mdot
.89 .29253 Mdot
.89 .29308 Mdot
.89 .2932 Mdot
.89 .29479 Mdot
.89 .29516 Mdot
.89 .29523 Mdot
.89 .29527 Mdot
.89 .29558 Mdot
.89 .29589 Mdot
.89 .29607 Mdot
.89 .2963 Mdot
.89 .29773 Mdot
.89 .29785 Mdot
.89 .2982 Mdot
.89 .29835 Mdot
.89 .29875 Mdot
.89 .2995 Mdot
.89 .29984 Mdot
.89 .30022 Mdot
.89 .3004 Mdot
.89 .30056 Mdot
.89 .30067 Mdot
.89 .3007 Mdot
.89 .30207 Mdot
.89 .30473 Mdot
.89 .30574 Mdot
.89 .3058 Mdot
.89 .30645 Mdot
.89 .30666 Mdot
.89 .30799 Mdot
.89 .30875 Mdot
.89 .30887 Mdot
.89 .3096 Mdot
.89 .30986 Mdot
.89 .31042 Mdot
.89 .31156 Mdot
.89 .31256 Mdot
.89 .31268 Mdot
.89 .31355 Mdot
.89 .3136 Mdot
.89 .31465 Mdot
.89 .3152 Mdot
.89 .31564 Mdot
.89 .31681 Mdot
.89 .31753 Mdot
.89 .32076 Mdot
.89 .32136 Mdot
.89 .32149 Mdot
.89 .322 Mdot
.89 .32294 Mdot
.89 .32418 Mdot
.89 .32641 Mdot
.89 .32661 Mdot
.89 .32673 Mdot
.89 .32716 Mdot
.89 .32719 Mdot
.89 .32768 Mdot
.89 .32778 Mdot
.89 .32984 Mdot
.89 .32998 Mdot
.89 .33015 Mdot
.89 .33032 Mdot
.89 .33057 Mdot
.89 .33102 Mdot
.89 .33194 Mdot
.89 .33284 Mdot
.89 .33353 Mdot
.89 .33379 Mdot
.89 .33402 Mdot
.89 .33417 Mdot
.89 .33469 Mdot
.89 .3347 Mdot
.89 .33478 Mdot
.89 .33484 Mdot
.89 .33573 Mdot
.89 .33616 Mdot
.89 .3396 Mdot
.89 .34042 Mdot
.89 .3407 Mdot
.89 .34137 Mdot
.89 .34262 Mdot
.89 .34326 Mdot
.89 .34512 Mdot
.89 .34528 Mdot
.89 .34674 Mdot
.89 .34859 Mdot
.89 .34869 Mdot
.89 .35101 Mdot
.89 .35128 Mdot
.89 .35282 Mdot
.89 .35302 Mdot
.89 .35332 Mdot
.89 .35351 Mdot
.89 .35564 Mdot
.89 .35635 Mdot
.89 .3571 Mdot
.89 .35714 Mdot
.89 .35756 Mdot
.89 .35803 Mdot
.89 .35813 Mdot
.89 .35903 Mdot
.89 .3593 Mdot
.89 .35986 Mdot
.89 .36141 Mdot
.89 .36189 Mdot
.89 .3623 Mdot
.89 .36392 Mdot
.89 .364 Mdot
.89 .36446 Mdot
.89 .36534 Mdot
.89 .36576 Mdot
.89 .36634 Mdot
.89 .36635 Mdot
.89 .36652 Mdot
.89 .3673 Mdot
.89 .36741 Mdot
.89 .3675 Mdot
.89 .36775 Mdot
.89 .37025 Mdot
.89 .37029 Mdot
.89 .37141 Mdot
.89 .37251 Mdot
.89 .37258 Mdot
.89 .37287 Mdot
.89 .3731 Mdot
.89 .37323 Mdot
.89 .37347 Mdot
.89 .37357 Mdot
.89 .37389 Mdot
.89 .37396 Mdot
.89 .37457 Mdot
.89 .37548 Mdot
.89 .37695 Mdot
.89 .37725 Mdot
.89 .37742 Mdot
.89 .37757 Mdot
.89 .37767 Mdot
.89 .37769 Mdot
.89 .37838 Mdot
.89 .37893 Mdot
.89 .3792 Mdot
.89 .37934 Mdot
.89 .37965 Mdot
.89 .3799 Mdot
.89 .3803 Mdot
.89 .38046 Mdot
.89 .38106 Mdot
.89 .38203 Mdot
.89 .38229 Mdot
.89 .38236 Mdot
.89 .38246 Mdot
.89 .3827 Mdot
.89 .38297 Mdot
.89 .38359 Mdot
.89 .38373 Mdot
.89 .38376 Mdot
.89 .38378 Mdot
.89 .38402 Mdot
.89 .38409 Mdot
.89 .38473 Mdot
.89 .38478 Mdot
.89 .38491 Mdot
.89 .38541 Mdot
.89 .38555 Mdot
.89 .38569 Mdot
.89 .38576 Mdot
.89 .38582 Mdot
.89 .38586 Mdot
.89 .38587 Mdot
.89 .3864 Mdot
.89 .38741 Mdot
.89 .38779 Mdot
.89 .38892 Mdot
.89 .38924 Mdot
.89 .38954 Mdot
.89 .38997 Mdot
.89 .39034 Mdot
.89 .39038 Mdot
.89 .3907 Mdot
.89 .39111 Mdot
.89 .39131 Mdot
.89 .39216 Mdot
.89 .39378 Mdot
.89 .39412 Mdot
.89 .39544 Mdot
.89 .39565 Mdot
.89 .3966 Mdot
.89 .3967 Mdot
.89 .39677 Mdot
.89 .39766 Mdot
.89 .3979 Mdot
.89 .39799 Mdot
.89 .39831 Mdot
.89 .39834 Mdot
.89 .39883 Mdot
.89 .40003 Mdot
.89 .40108 Mdot
.89 .40131 Mdot
.89 .40251 Mdot
.89 .40408 Mdot
.89 .40461 Mdot
.89 .40467 Mdot
.89 .40478 Mdot
.89 .40484 Mdot
.89 .40581 Mdot
.89 .40607 Mdot
.89 .40608 Mdot
.89 .40642 Mdot
.89 .40682 Mdot
.89 .40701 Mdot
.89 .40784 Mdot
.89 .40842 Mdot
.89 .40857 Mdot
.89 .40901 Mdot
.89 .40921 Mdot
.89 .40969 Mdot
.89 .41055 Mdot
.89 .41092 Mdot
.89 .41132 Mdot
.89 .41149 Mdot
.89 .41162 Mdot
.89 .41166 Mdot
.89 .41176 Mdot
.89 .41179 Mdot
.89 .4123 Mdot
.89 .413 Mdot
.89 .41327 Mdot
.89 .4136 Mdot
.89 .41397 Mdot
.89 .41459 Mdot
.89 .41461 Mdot
.89 .41473 Mdot
.89 .41503 Mdot
.89 .41507 Mdot
.89 .41517 Mdot
.89 .41519 Mdot
.89 .41541 Mdot
.89 .41543 Mdot
.89 .41547 Mdot
.89 .41568 Mdot
.89 .41573 Mdot
.89 .41575 Mdot
.89 .41578 Mdot
.89 .41579 Mdot
.89 .41579 Mdot
.89 .43997 Mdot
.89 .43997 Mdot
.89 .43998 Mdot
.89 .43999 Mdot
.89 .44 Mdot
.89 .44003 Mdot
.89 .44015 Mdot
.89 .44017 Mdot
.89 .44018 Mdot
.89 .4403 Mdot
.89 .44031 Mdot
.89 .44037 Mdot
.89 .44039 Mdot
.89 .44056 Mdot
.89 .44062 Mdot
.89 .44063 Mdot
.89 .44098 Mdot
.89 .44118 Mdot
.89 .44136 Mdot
.89 .44151 Mdot
.89 .4419 Mdot
.89 .44218 Mdot
.89 .44219 Mdot
.89 .44225 Mdot
.89 .44227 Mdot
.89 .44234 Mdot
.89 .44243 Mdot
.89 .44265 Mdot
.89 .44286 Mdot
.89 .44332 Mdot
.89 .44358 Mdot
.89 .44369 Mdot
.89 .44393 Mdot
.89 .44401 Mdot
.89 .44433 Mdot
.89 .44478 Mdot
.89 .44488 Mdot
.89 .44509 Mdot
.89 .44528 Mdot
.89 .44528 Mdot
.89 .44542 Mdot
.89 .44594 Mdot
.89 .44598 Mdot
.89 .44603 Mdot
.89 .44607 Mdot
.89 .44635 Mdot
.89 .44719 Mdot
.89 .44783 Mdot
.89 .44794 Mdot
.89 .4485 Mdot
.89 .44913 Mdot
.89 .44939 Mdot
.89 .44941 Mdot
.89 .44957 Mdot
.89 .44962 Mdot
.89 .44975 Mdot
.89 .45022 Mdot
.89 .45025 Mdot
.89 .4503 Mdot
.89 .4508 Mdot
.89 .45091 Mdot
.89 .45159 Mdot
.89 .45177 Mdot
.89 .45261 Mdot
.89 .45305 Mdot
.89 .45315 Mdot
.89 .45336 Mdot
.89 .45352 Mdot
.89 .45355 Mdot
.89 .45374 Mdot
.89 .45395 Mdot
.89 .45411 Mdot
.89 .45427 Mdot
.89 .45485 Mdot
.89 .45504 Mdot
.89 .45555 Mdot
.89 .45582 Mdot
.89 .45583 Mdot
.89 .45585 Mdot
.89 .45588 Mdot
.89 .45591 Mdot
.89 .45599 Mdot
.89 .45605 Mdot
.89 .45631 Mdot
.89 .45638 Mdot
.89 .4564 Mdot
.89 .45672 Mdot
.89 .45676 Mdot
.89 .45688 Mdot
.89 .45689 Mdot
.89 .4569 Mdot
.89 .45697 Mdot
.89 .45729 Mdot
.89 .45742 Mdot
.89 .45754 Mdot
.89 .45759 Mdot
.89 .45763 Mdot
.89 .45776 Mdot
.89 .45825 Mdot
.89 .45855 Mdot
.89 .45862 Mdot
.89 .45882 Mdot
.89 .45895 Mdot
.89 .4591 Mdot
.89 .45917 Mdot
.89 .45931 Mdot
.89 .45958 Mdot
.89 .45992 Mdot
.89 .45993 Mdot
.89 .45998 Mdot
.89 .46006 Mdot
.89 .46014 Mdot
.89 .46029 Mdot
.89 .46102 Mdot
.89 .46146 Mdot
.89 .46176 Mdot
.89 .4618 Mdot
.89 .46195 Mdot
.89 .46201 Mdot
.89 .46212 Mdot
.89 .46219 Mdot
.89 .4623 Mdot
.89 .46244 Mdot
.89 .46247 Mdot
.89 .46302 Mdot
.89 .46356 Mdot
.89 .46358 Mdot
.89 .46479 Mdot
.89 .46491 Mdot
.89 .46496 Mdot
.89 .46501 Mdot
.89 .46539 Mdot
.89 .46547 Mdot
.89 .46547 Mdot
.89 .46576 Mdot
.89 .46595 Mdot
.89 .46638 Mdot
.89 .4666 Mdot
.89 .46664 Mdot
.89 .46741 Mdot
.89 .46761 Mdot
.89 .46784 Mdot
.89 .46858 Mdot
.89 .46885 Mdot
.89 .46897 Mdot
.89 .4694 Mdot
.89 .46945 Mdot
.89 .46967 Mdot
.89 .46987 Mdot
.89 .46989 Mdot
.89 .47024 Mdot
.89 .47058 Mdot
.89 .47158 Mdot
.89 .47167 Mdot
.89 .47181 Mdot
.89 .4719 Mdot
.89 .47262 Mdot
.89 .47275 Mdot
.89 .47382 Mdot
.89 .47387 Mdot
.89 .47473 Mdot
.89 .47548 Mdot
.89 .47633 Mdot
.89 .47663 Mdot
.89 .4772 Mdot
.89 .4775 Mdot
.89 .47763 Mdot
.89 .478 Mdot
.89 .47957 Mdot
.89 .47977 Mdot
.89 .48017 Mdot
.89 .48019 Mdot
.89 .48023 Mdot
.89 .48023 Mdot
.89 .48047 Mdot
.89 .48054 Mdot
.89 .48064 Mdot
.89 .48076 Mdot
.89 .48107 Mdot
.89 .48148 Mdot
.89 .48189 Mdot
.89 .48209 Mdot
.89 .4822 Mdot
.89 .48228 Mdot
.89 .48235 Mdot
.89 .48241 Mdot
.89 .48334 Mdot
.89 .48338 Mdot
.89 .4836 Mdot
.89 .48361 Mdot
.89 .4838 Mdot
.89 .48386 Mdot
.89 .48395 Mdot
.89 .48494 Mdot
.89 .48549 Mdot
.89 .4859 Mdot
.89 .48613 Mdot
.89 .48619 Mdot
.89 .48645 Mdot
.89 .48787 Mdot
.89 .48818 Mdot
.89 .4887 Mdot
.89 .48889 Mdot
.89 .48913 Mdot
.89 .48959 Mdot
.89 .4896 Mdot
.89 .48999 Mdot
.89 .49004 Mdot
.89 .49047 Mdot
.89 .49097 Mdot
.89 .49121 Mdot
.89 .49132 Mdot
.89 .49164 Mdot
.89 .49169 Mdot
.89 .49202 Mdot
.89 .49259 Mdot
.89 .49268 Mdot
.89 .49296 Mdot
.89 .49299 Mdot
.89 .49342 Mdot
.89 .49456 Mdot
.89 .49515 Mdot
.89 .49516 Mdot
.89 .49521 Mdot
.89 .49528 Mdot
.89 .49535 Mdot
.89 .49551 Mdot
.89 .49566 Mdot
.89 .49598 Mdot
.89 .49615 Mdot
.89 .49621 Mdot
.89 .49636 Mdot
.89 .49641 Mdot
.89 .49702 Mdot
.89 .49712 Mdot
.89 .49719 Mdot
.89 .49732 Mdot
.89 .49746 Mdot
.89 .49747 Mdot
.89 .4975 Mdot
.89 .49766 Mdot
.89 .49833 Mdot
.89 .49838 Mdot
.89 .49861 Mdot
.89 .49888 Mdot
.89 .49898 Mdot
.89 .49905 Mdot
.89 .49933 Mdot
.89 .49981 Mdot
.89 .49987 Mdot
.89 .50017 Mdot
.89 .50032 Mdot
.89 .50036 Mdot
.89 .50049 Mdot
.89 .50068 Mdot
.89 .50098 Mdot
.89 .50115 Mdot
.89 .50156 Mdot
.89 .50156 Mdot
.89 .50176 Mdot
.89 .50182 Mdot
.89 .50214 Mdot
.89 .50228 Mdot
.89 .50256 Mdot
.89 .50311 Mdot
.89 .50316 Mdot
.89 .50346 Mdot
.89 .50381 Mdot
.89 .50382 Mdot
.89 .50383 Mdot
.89 .50393 Mdot
.89 .50395 Mdot
.89 .50408 Mdot
.89 .50425 Mdot
.89 .50455 Mdot
.89 .505 Mdot
.89 .50599 Mdot
.89 .50638 Mdot
.89 .50687 Mdot
.89 .50735 Mdot
.89 .50745 Mdot
.89 .5075 Mdot
.89 .50752 Mdot
.89 .50772 Mdot
.89 .50781 Mdot
.89 .50786 Mdot
.89 .50792 Mdot
.89 .50813 Mdot
.89 .50814 Mdot
.89 .50827 Mdot
.89 .50848 Mdot
.89 .50874 Mdot
.89 .50875 Mdot
.89 .50881 Mdot
.89 .50948 Mdot
.89 .50983 Mdot
.89 .51014 Mdot
.89 .51084 Mdot
.89 .51088 Mdot
.89 .51113 Mdot
.89 .51174 Mdot
.89 .51177 Mdot
.89 .5118 Mdot
.89 .51238 Mdot
.89 .51252 Mdot
.89 .51307 Mdot
.89 .51329 Mdot
.89 .51332 Mdot
.89 .51337 Mdot
.89 .51346 Mdot
.89 .51391 Mdot
.89 .51413 Mdot
.89 .51427 Mdot
.89 .51427 Mdot
.89 .51428 Mdot
.89 .51476 Mdot
.89 .51485 Mdot
.89 .51511 Mdot
.89 .51538 Mdot
.89 .51556 Mdot
.89 .51583 Mdot
.89 .5162 Mdot
.89 .51627 Mdot
.89 .51653 Mdot
.89 .51655 Mdot
.89 .51656 Mdot
.89 .51684 Mdot
.89 .51727 Mdot
.89 .51756 Mdot
.89 .51788 Mdot
.89 .51814 Mdot
.89 .51825 Mdot
.89 .51831 Mdot
.89 .5184 Mdot
.89 .51847 Mdot
.89 .51887 Mdot
.89 .51943 Mdot
.89 .51985 Mdot
.89 .5199 Mdot
.89 .52005 Mdot
.89 .52016 Mdot
.89 .52071 Mdot
.89 .52078 Mdot
.89 .52112 Mdot
.89 .52119 Mdot
.89 .52125 Mdot
.89 .52131 Mdot
.89 .52142 Mdot
.89 .52144 Mdot
.89 .52198 Mdot
.89 .52236 Mdot
.89 .52247 Mdot
.89 .52278 Mdot
.89 .52284 Mdot
.89 .5239 Mdot
.89 .52399 Mdot
.89 .52403 Mdot
.89 .52422 Mdot
.89 .52435 Mdot
.89 .5245 Mdot
.89 .52504 Mdot
.89 .52533 Mdot
.89 .5255 Mdot
.89 .52606 Mdot
.89 .52615 Mdot
.89 .52616 Mdot
.89 .52654 Mdot
.89 .52685 Mdot
.89 .5269 Mdot
.89 .52696 Mdot
.89 .52703 Mdot
.89 .52705 Mdot
.89 .52735 Mdot
.89 .52743 Mdot
.89 .52749 Mdot
.89 .52762 Mdot
.89 .52791 Mdot
.89 .52793 Mdot
.89 .528 Mdot
.89 .52802 Mdot
.89 .52814 Mdot
.89 .52878 Mdot
.89 .52882 Mdot
.89 .52891 Mdot
.89 .52941 Mdot
.89 .52988 Mdot
.89 .52989 Mdot
.89 .5302 Mdot
.89 .53081 Mdot
.89 .53106 Mdot
.89 .53113 Mdot
.89 .53126 Mdot
.89 .53157 Mdot
.89 .53163 Mdot
.89 .5319 Mdot
.89 .53209 Mdot
.89 .53222 Mdot
.89 .53224 Mdot
.89 .53234 Mdot
.89 .53235 Mdot
.89 .53237 Mdot
.89 .53272 Mdot
.89 .53302 Mdot
.89 .53306 Mdot
.89 .53311 Mdot
.89 .53328 Mdot
.89 .53359 Mdot
.89 .53363 Mdot
.89 .53365 Mdot
.89 .53368 Mdot
.89 .53369 Mdot
.89 .53385 Mdot
.89 .53388 Mdot
.89 .53394 Mdot
.89 .53397 Mdot
.89 .53402 Mdot
.89 .53412 Mdot
.89 .53425 Mdot
.89 .5343 Mdot
.89 .53437 Mdot
.89 .53447 Mdot
.89 .53447 Mdot
.89 .53468 Mdot
.89 .53481 Mdot
.89 .53494 Mdot
.89 .53499 Mdot
.89 .53513 Mdot
.89 .53518 Mdot
.89 .53521 Mdot
.89 .53527 Mdot
.89 .53532 Mdot
.89 .53532 Mdot
.89 .53536 Mdot
.89 .53542 Mdot
.89 .53544 Mdot
.89 .53555 Mdot
.89 .53576 Mdot
.89 .5358 Mdot
.89 .53597 Mdot
.89 .536 Mdot
.89 .53612 Mdot
.89 .53614 Mdot
.89 .53614 Mdot
.89 .53626 Mdot
.89 .53629 Mdot
.89 .5363 Mdot
.89 .53634 Mdot
.89 .53635 Mdot
.89 .53641 Mdot
.89 .53656 Mdot
.89 .5367 Mdot
.89 .53673 Mdot
.89 .53688 Mdot
.89 .53708 Mdot
.89 .53715 Mdot
.89 .53716 Mdot
.89 .53717 Mdot
.89 .53718 Mdot
.89 .53725 Mdot
.89 .53731 Mdot
.89 .53734 Mdot
.89 .53734 Mdot
.89 .53738 Mdot
.89 .53744 Mdot
.89 .53746 Mdot
.89 .53757 Mdot
.89 .53764 Mdot
.89 .53766 Mdot
.89 .53772 Mdot
.89 .53774 Mdot
.89 .53781 Mdot
.89 .53792 Mdot
.89 .53796 Mdot
.89 .53802 Mdot
.89 .53804 Mdot
.89 .53805 Mdot
.89 .53806 Mdot
.89 .53807 Mdot
.89 .53808 Mdot
.89 .53814 Mdot
.89 .53823 Mdot
.89 .53827 Mdot
.89 .53831 Mdot
.89 .53836 Mdot
.89 .53844 Mdot
.89 .53844 Mdot
.89 .53846 Mdot
.89 .53849 Mdot
.89 .5385 Mdot
.89 .53851 Mdot
.89 .53852 Mdot
.89 .53854 Mdot
.89 .53855 Mdot
.89 .53855 Mdot
.89 .53858 Mdot
.89 .53859 Mdot
.89 .53859 Mdot
.89 .53859 Mdot
.89 .53859 Mdot
.89 .53859 Mdot
.892 .18946 Mdot
.892 .18947 Mdot
.892 .18953 Mdot
.892 .18956 Mdot
.892 .18958 Mdot
.892 .18969 Mdot
.892 .18972 Mdot
.892 .18975 Mdot
.892 .18978 Mdot
.892 .18982 Mdot
.892 .18989 Mdot
.892 .18993 Mdot
.892 .19003 Mdot
.892 .19023 Mdot
.892 .19025 Mdot
.892 .19032 Mdot
.892 .19046 Mdot
.892 .19066 Mdot
.892 .19094 Mdot
.892 .19095 Mdot
.892 .1912 Mdot
.892 .19133 Mdot
.892 .1916 Mdot
.892 .19161 Mdot
.892 .19191 Mdot
.892 .19203 Mdot
.892 .19212 Mdot
.892 .19215 Mdot
.892 .19244 Mdot
.892 .19248 Mdot
.892 .19286 Mdot
.892 .19302 Mdot
.892 .19304 Mdot
.892 .19322 Mdot
.892 .19354 Mdot
.892 .19373 Mdot
.892 .19382 Mdot
.892 .19384 Mdot
.892 .19387 Mdot
.892 .19413 Mdot
.892 .19441 Mdot
.892 .19457 Mdot
.892 .19467 Mdot
.892 .19469 Mdot
.892 .19473 Mdot
.892 .19489 Mdot
.892 .19491 Mdot
.892 .19497 Mdot
.892 .19505 Mdot
.892 .19578 Mdot
.892 .19579 Mdot
.892 .19579 Mdot
.892 .19582 Mdot
.892 .19586 Mdot
.892 .19606 Mdot
.892 .1963 Mdot
.892 .19644 Mdot
.892 .1967 Mdot
.892 .19696 Mdot
.892 .19707 Mdot
.892 .1971 Mdot
.892 .19736 Mdot
.892 .19774 Mdot
.892 .19816 Mdot
.892 .19882 Mdot
.892 .19895 Mdot
.892 .19986 Mdot
.892 .20002 Mdot
.892 .20015 Mdot
.892 .20091 Mdot
.892 .20169 Mdot
.892 .20169 Mdot
.892 .20191 Mdot
.892 .20207 Mdot
.892 .20229 Mdot
.892 .20248 Mdot
.892 .20287 Mdot
.892 .20288 Mdot
.892 .20296 Mdot
.892 .2031 Mdot
.892 .20328 Mdot
.892 .20354 Mdot
.892 .2038 Mdot
.892 .2038 Mdot
.892 .20396 Mdot
.892 .2041 Mdot
.892 .20418 Mdot
.892 .20449 Mdot
.892 .2046 Mdot
.892 .20485 Mdot
.892 .20511 Mdot
.892 .20512 Mdot
.892 .20574 Mdot
.892 .20674 Mdot
.892 .2068 Mdot
.892 .20697 Mdot
.892 .20708 Mdot
.892 .20721 Mdot
.892 .20743 Mdot
.892 .20812 Mdot
.892 .20813 Mdot
.892 .20982 Mdot
.892 .21029 Mdot
.892 .21043 Mdot
.892 .21072 Mdot
.892 .21093 Mdot
.892 .21186 Mdot
.892 .21288 Mdot
.892 .21296 Mdot
.892 .21319 Mdot
.892 .21369 Mdot
.892 .21388 Mdot
.892 .21396 Mdot
.892 .2146 Mdot
.892 .21523 Mdot
.892 .21565 Mdot
.892 .21635 Mdot
.892 .21769 Mdot
.892 .21777 Mdot
.892 .21829 Mdot
.892 .21861 Mdot
.892 .21871 Mdot
.892 .21902 Mdot
.892 .21916 Mdot
.892 .21936 Mdot
.892 .22005 Mdot
.892 .22048 Mdot
.892 .22134 Mdot
.892 .22177 Mdot
.892 .2219 Mdot
.892 .2219 Mdot
.892 .22229 Mdot
.892 .22233 Mdot
.892 .22236 Mdot
.892 .22248 Mdot
.892 .2228 Mdot
.892 .22295 Mdot
.892 .22316 Mdot
.892 .22432 Mdot
.892 .22552 Mdot
.892 .22666 Mdot
.892 .2269 Mdot
.892 .22705 Mdot
.892 .22771 Mdot
.892 .22849 Mdot
.892 .22916 Mdot
.892 .22993 Mdot
.892 .23035 Mdot
.892 .231 Mdot
.892 .23225 Mdot
.892 .23263 Mdot
.892 .23271 Mdot
.892 .23296 Mdot
.892 .233 Mdot
.892 .23329 Mdot
.892 .23389 Mdot
.892 .23433 Mdot
.892 .23443 Mdot
.892 .23453 Mdot
.892 .23518 Mdot
.892 .23549 Mdot
.892 .23583 Mdot
.892 .23597 Mdot
.892 .23727 Mdot
.892 .23843 Mdot
.892 .23848 Mdot
.892 .23865 Mdot
.892 .23915 Mdot
.892 .23925 Mdot
.892 .23948 Mdot
.892 .24008 Mdot
.892 .24089 Mdot
.892 .24119 Mdot
.892 .24218 Mdot
.892 .24359 Mdot
.892 .244 Mdot
.892 .24586 Mdot
.892 .24645 Mdot
.892 .24741 Mdot
.892 .24764 Mdot
.892 .24775 Mdot
.892 .24895 Mdot
.892 .25387 Mdot
.892 .25392 Mdot
.892 .25403 Mdot
.892 .25451 Mdot
.892 .2548 Mdot
.892 .25665 Mdot
.892 .25817 Mdot
.892 .25849 Mdot
.892 .25993 Mdot
.892 .26035 Mdot
.892 .26076 Mdot
.892 .26082 Mdot
.892 .26106 Mdot
.892 .26156 Mdot
.892 .26158 Mdot
.892 .26269 Mdot
.892 .26306 Mdot
.892 .26375 Mdot
.892 .26508 Mdot
.892 .26666 Mdot
.892 .26938 Mdot
.892 .26997 Mdot
.892 .27034 Mdot
.892 .27056 Mdot
.892 .27097 Mdot
.892 .27367 Mdot
.892 .27417 Mdot
.892 .27435 Mdot
.892 .2744 Mdot
.892 .27606 Mdot
.892 .27629 Mdot
.892 .27677 Mdot
.892 .27816 Mdot
.892 .27874 Mdot
.892 .27893 Mdot
.892 .28022 Mdot
.892 .28078 Mdot
.892 .28102 Mdot
.892 .28125 Mdot
.892 .28185 Mdot
.892 .28225 Mdot
.892 .2825 Mdot
.892 .28267 Mdot
.892 .2828 Mdot
.892 .2829 Mdot
.892 .28347 Mdot
.892 .28408 Mdot
.892 .28408 Mdot
.892 .28571 Mdot
.892 .28603 Mdot
.892 .288 Mdot
.892 .289 Mdot
.892 .28934 Mdot
.892 .28937 Mdot
.892 .28986 Mdot
.892 .29021 Mdot
.892 .2904 Mdot
.892 .29101 Mdot
.892 .29107 Mdot
.892 .29113 Mdot
.892 .29268 Mdot
.892 .29277 Mdot
.892 .29293 Mdot
.892 .29319 Mdot
.892 .29416 Mdot
.892 .29433 Mdot
.892 .29557 Mdot
.892 .29561 Mdot
.892 .2959 Mdot
.892 .29666 Mdot
.892 .29675 Mdot
.892 .29735 Mdot
.892 .29742 Mdot
.892 .29763 Mdot
.892 .2986 Mdot
.892 .29862 Mdot
.892 .30034 Mdot
.892 .30038 Mdot
.892 .30194 Mdot
.892 .30245 Mdot
.892 .30272 Mdot
.892 .30367 Mdot
.892 .30479 Mdot
.892 .30665 Mdot
.892 .30685 Mdot
.892 .30869 Mdot
.892 .3092 Mdot
.892 .31079 Mdot
.892 .31239 Mdot
.892 .31261 Mdot
.892 .31283 Mdot
.892 .31301 Mdot
.892 .31366 Mdot
.892 .31389 Mdot
.892 .31524 Mdot
.892 .31682 Mdot
.892 .3184 Mdot
.892 .31875 Mdot
.892 .32015 Mdot
.892 .32284 Mdot
.892 .3234 Mdot
.892 .32392 Mdot
.892 .32398 Mdot
.892 .32442 Mdot
.892 .32531 Mdot
.892 .32562 Mdot
.892 .32566 Mdot
.892 .32575 Mdot
.892 .32586 Mdot
.892 .32694 Mdot
.892 .32694 Mdot
.892 .32732 Mdot
.892 .32854 Mdot
.892 .32953 Mdot
.892 .33084 Mdot
.892 .33099 Mdot
.892 .3322 Mdot
.892 .33316 Mdot
.892 .33421 Mdot
.892 .33437 Mdot
.892 .33477 Mdot
.892 .33517 Mdot
.892 .33605 Mdot
.892 .33606 Mdot
.892 .33634 Mdot
.892 .33641 Mdot
.892 .33671 Mdot
.892 .33729 Mdot
.892 .33872 Mdot
.892 .33877 Mdot
.892 .33892 Mdot
.892 .33902 Mdot
.892 .33991 Mdot
.892 .34166 Mdot
.892 .34216 Mdot
.892 .34288 Mdot
.892 .34425 Mdot
.892 .34445 Mdot
.892 .34492 Mdot
.892 .34537 Mdot
.892 .34567 Mdot
.892 .34617 Mdot
.892 .34715 Mdot
.892 .34779 Mdot
.892 .34799 Mdot
.892 .34822 Mdot
.892 .34896 Mdot
.892 .34952 Mdot
.892 .34979 Mdot
.892 .34988 Mdot
.892 .34988 Mdot
.892 .35012 Mdot
.892 .35015 Mdot
.892 .35017 Mdot
.892 .35025 Mdot
.892 .35055 Mdot
.892 .35068 Mdot
.892 .35214 Mdot
.892 .35283 Mdot
.892 .35306 Mdot
.892 .35346 Mdot
.892 .35391 Mdot
.892 .35476 Mdot
.892 .35608 Mdot
.892 .35629 Mdot
.892 .35634 Mdot
.892 .35666 Mdot
.892 .35735 Mdot
.892 .35787 Mdot
.892 .35806 Mdot
.892 .35883 Mdot
.892 .35945 Mdot
.892 .35948 Mdot
.892 .35983 Mdot
.892 .36 Mdot
.892 .36032 Mdot
.892 .36074 Mdot
.892 .36089 Mdot
.892 .36212 Mdot
.892 .36233 Mdot
.892 .36477 Mdot
.892 .36712 Mdot
.892 .36715 Mdot
.892 .3672 Mdot
.892 .36742 Mdot
.892 .36756 Mdot
.892 .36842 Mdot
.892 .36926 Mdot
.892 .36991 Mdot
.892 .3701 Mdot
.892 .37028 Mdot
.892 .37064 Mdot
.892 .37114 Mdot
.892 .37131 Mdot
.892 .37288 Mdot
.892 .37431 Mdot
.892 .37456 Mdot
.892 .37474 Mdot
.892 .37609 Mdot
.892 .37616 Mdot
.892 .37618 Mdot
.892 .37697 Mdot
.892 .37774 Mdot
.892 .37805 Mdot
.892 .379 Mdot
.892 .37924 Mdot
.892 .3795 Mdot
.892 .37966 Mdot
.892 .37989 Mdot
.892 .38014 Mdot
.892 .38014 Mdot
.892 .38092 Mdot
.892 .3817 Mdot
.892 .38224 Mdot
.892 .38243 Mdot
.892 .38264 Mdot
.892 .3829 Mdot
.892 .38292 Mdot
.892 .38356 Mdot
.892 .3841 Mdot
.892 .38464 Mdot
.892 .38466 Mdot
.892 .38532 Mdot
.892 .3858 Mdot
.892 .38646 Mdot
.892 .38647 Mdot
.892 .38725 Mdot
.892 .38735 Mdot
.892 .38882 Mdot
.892 .38976 Mdot
.892 .39093 Mdot
.892 .39109 Mdot
.892 .39148 Mdot
.892 .39197 Mdot
.892 .39311 Mdot
.892 .39324 Mdot
.892 .3947 Mdot
.892 .39508 Mdot
.892 .39569 Mdot
.892 .39707 Mdot
.892 .39753 Mdot
.892 .39834 Mdot
.892 .39876 Mdot
.892 .39935 Mdot
.892 .39947 Mdot
.892 .39957 Mdot
.892 .40027 Mdot
.892 .40034 Mdot
.892 .40068 Mdot
.892 .40128 Mdot
.892 .40146 Mdot
.892 .40217 Mdot
.892 .40224 Mdot
.892 .40256 Mdot
.892 .40266 Mdot
.892 .40317 Mdot
.892 .40338 Mdot
.892 .40353 Mdot
.892 .40378 Mdot
.892 .40397 Mdot
.892 .40407 Mdot
.892 .4041 Mdot
.892 .40419 Mdot
.892 .4042 Mdot
.892 .40422 Mdot
.892 .40432 Mdot
.892 .40531 Mdot
.892 .40547 Mdot
.892 .40575 Mdot
.892 .40627 Mdot
.892 .40629 Mdot
.892 .4064 Mdot
.892 .40663 Mdot
.892 .40681 Mdot
.892 .40687 Mdot
.892 .40735 Mdot
.892 .40747 Mdot
.892 .40752 Mdot
.892 .40782 Mdot
.892 .40831 Mdot
.892 .40913 Mdot
.892 .40992 Mdot
.892 .41002 Mdot
.892 .41006 Mdot
.892 .41035 Mdot
.892 .41091 Mdot
.892 .41184 Mdot
.892 .4124 Mdot
.892 .41246 Mdot
.892 .41291 Mdot
.892 .41405 Mdot
.892 .41418 Mdot
.892 .41502 Mdot
.892 .4154 Mdot
.892 .41576 Mdot
.892 .41663 Mdot
.892 .41666 Mdot
.892 .41746 Mdot
.892 .41785 Mdot
.892 .41858 Mdot
.892 .41862 Mdot
.892 .41944 Mdot
.892 .42005 Mdot
.892 .42046 Mdot
.892 .42065 Mdot
.892 .42073 Mdot
.892 .4213 Mdot
.892 .4216 Mdot
.892 .42173 Mdot
.892 .42193 Mdot
.892 .42205 Mdot
.892 .42213 Mdot
.892 .42223 Mdot
.892 .42232 Mdot
.892 .42265 Mdot
.892 .4227 Mdot
.892 .42279 Mdot
.892 .42297 Mdot
.892 .42297 Mdot
.892 .43644 Mdot
.892 .43645 Mdot
.892 .43655 Mdot
.892 .4366 Mdot
.892 .43663 Mdot
.892 .43682 Mdot
.892 .43687 Mdot
.892 .43692 Mdot
.892 .43697 Mdot
.892 .43704 Mdot
.892 .43715 Mdot
.892 .43722 Mdot
.892 .43739 Mdot
.892 .43771 Mdot
.892 .43775 Mdot
.892 .43786 Mdot
.892 .4381 Mdot
.892 .43844 Mdot
.892 .4389 Mdot
.892 .43892 Mdot
.892 .43932 Mdot
.892 .43954 Mdot
.892 .43998 Mdot
.892 .44 Mdot
.892 .44048 Mdot
.892 .44068 Mdot
.892 .44089 Mdot
.892 .44136 Mdot
.892 .44143 Mdot
.892 .44205 Mdot
.892 .4423 Mdot
.892 .44233 Mdot
.892 .44264 Mdot
.892 .44314 Mdot
.892 .44345 Mdot
.892 .4436 Mdot
.892 .44363 Mdot
.892 .44368 Mdot
.892 .44411 Mdot
.892 .44455 Mdot
.892 .44481 Mdot
.892 .44497 Mdot
.892 .445 Mdot
.892 .44507 Mdot
.892 .44533 Mdot
.892 .44536 Mdot
.892 .44545 Mdot
.892 .44558 Mdot
.892 .44564 Mdot
.892 .44565 Mdot
.892 .44592 Mdot
.892 .44608 Mdot
.892 .44616 Mdot
.892 .44669 Mdot
.892 .44674 Mdot
.892 .44675 Mdot
.892 .44676 Mdot
.892 .44681 Mdot
.892 .44682 Mdot
.892 .44687 Mdot
.892 .44697 Mdot
.892 .44711 Mdot
.892 .44719 Mdot
.892 .4473 Mdot
.892 .44757 Mdot
.892 .44762 Mdot
.892 .44779 Mdot
.892 .44783 Mdot
.892 .44821 Mdot
.892 .4483 Mdot
.892 .44862 Mdot
.892 .4488 Mdot
.892 .44883 Mdot
.892 .4492 Mdot
.892 .44925 Mdot
.892 .44932 Mdot
.892 .44962 Mdot
.892 .44984 Mdot
.892 .45027 Mdot
.892 .45051 Mdot
.892 .45122 Mdot
.892 .45154 Mdot
.892 .45174 Mdot
.892 .45249 Mdot
.892 .45255 Mdot
.892 .45314 Mdot
.892 .45339 Mdot
.892 .45359 Mdot
.892 .45367 Mdot
.892 .45427 Mdot
.892 .45475 Mdot
.892 .4555 Mdot
.892 .45554 Mdot
.892 .45594 Mdot
.892 .45595 Mdot
.892 .45628 Mdot
.892 .45652 Mdot
.892 .45686 Mdot
.892 .45686 Mdot
.892 .45714 Mdot
.892 .4574 Mdot
.892 .45773 Mdot
.892 .45774 Mdot
.892 .45787 Mdot
.892 .45797 Mdot
.892 .45807 Mdot
.892 .45834 Mdot
.892 .45873 Mdot
.892 .45911 Mdot
.892 .45911 Mdot
.892 .45924 Mdot
.892 .45935 Mdot
.892 .45943 Mdot
.892 .45956 Mdot
.892 .45968 Mdot
.892 .46015 Mdot
.892 .4603 Mdot
.892 .46068 Mdot
.892 .46107 Mdot
.892 .46108 Mdot
.892 .46112 Mdot
.892 .46178 Mdot
.892 .46187 Mdot
.892 .46199 Mdot
.892 .46269 Mdot
.892 .46345 Mdot
.892 .46353 Mdot
.892 .46378 Mdot
.892 .46395 Mdot
.892 .46404 Mdot
.892 .46413 Mdot
.892 .46445 Mdot
.892 .46486 Mdot
.892 .46527 Mdot
.892 .46533 Mdot
.892 .46544 Mdot
.892 .46547 Mdot
.892 .46548 Mdot
.892 .46661 Mdot
.892 .46777 Mdot
.892 .46787 Mdot
.892 .46846 Mdot
.892 .46853 Mdot
.892 .46873 Mdot
.892 .46888 Mdot
.892 .46896 Mdot
.892 .46913 Mdot
.892 .46914 Mdot
.892 .46943 Mdot
.892 .4698 Mdot
.892 .46988 Mdot
.892 .47013 Mdot
.892 .47046 Mdot
.892 .47061 Mdot
.892 .47063 Mdot
.892 .47073 Mdot
.892 .47135 Mdot
.892 .47174 Mdot
.892 .47196 Mdot
.892 .47214 Mdot
.892 .47225 Mdot
.892 .47257 Mdot
.892 .47325 Mdot
.892 .47331 Mdot
.892 .47345 Mdot
.892 .47349 Mdot
.892 .4735 Mdot
.892 .47351 Mdot
.892 .47362 Mdot
.892 .47362 Mdot
.892 .47366 Mdot
.892 .47379 Mdot
.892 .47405 Mdot
.892 .47439 Mdot
.892 .47449 Mdot
.892 .47459 Mdot
.892 .47488 Mdot
.892 .47534 Mdot
.892 .47556 Mdot
.892 .4757 Mdot
.892 .47591 Mdot
.892 .47612 Mdot
.892 .47621 Mdot
.892 .47684 Mdot
.892 .47717 Mdot
.892 .4774 Mdot
.892 .4782 Mdot
.892 .4786 Mdot
.892 .47865 Mdot
.892 .47871 Mdot
.892 .47874 Mdot
.892 .47939 Mdot
.892 .47965 Mdot
.892 .47978 Mdot
.892 .47982 Mdot
.892 .47994 Mdot
.892 .47994 Mdot
.892 .48034 Mdot
.892 .48052 Mdot
.892 .4807 Mdot
.892 .48078 Mdot
.892 .48125 Mdot
.892 .48167 Mdot
.892 .48222 Mdot
.892 .48228 Mdot
.892 .48287 Mdot
.892 .48331 Mdot
.892 .48385 Mdot
.892 .48402 Mdot
.892 .48402 Mdot
.892 .4845 Mdot
.892 .48455 Mdot
.892 .48459 Mdot
.892 .48461 Mdot
.892 .48474 Mdot
.892 .48514 Mdot
.892 .48533 Mdot
.892 .48536 Mdot
.892 .48559 Mdot
.892 .48584 Mdot
.892 .48702 Mdot
.892 .48763 Mdot
.892 .48778 Mdot
.892 .48847 Mdot
.892 .48916 Mdot
.892 .48975 Mdot
.892 .48985 Mdot
.892 .49013 Mdot
.892 .49021 Mdot
.892 .49031 Mdot
.892 .4904 Mdot
.892 .49109 Mdot
.892 .49178 Mdot
.892 .492 Mdot
.892 .49279 Mdot
.892 .49287 Mdot
.892 .49367 Mdot
.892 .49416 Mdot
.892 .49456 Mdot
.892 .49467 Mdot
.892 .49489 Mdot
.892 .49555 Mdot
.892 .49557 Mdot
.892 .4963 Mdot
.892 .49631 Mdot
.892 .49672 Mdot
.892 .49681 Mdot
.892 .49684 Mdot
.892 .49709 Mdot
.892 .49713 Mdot
.892 .49746 Mdot
.892 .49758 Mdot
.892 .49759 Mdot
.892 .49812 Mdot
.892 .49819 Mdot
.892 .4986 Mdot
.892 .49871 Mdot
.892 .49877 Mdot
.892 .49881 Mdot
.892 .49946 Mdot
.892 .49949 Mdot
.892 .49951 Mdot
.892 .49977 Mdot
.892 .49985 Mdot
.892 .5 Mdot
.892 .5002 Mdot
.892 .50021 Mdot
.892 .50036 Mdot
.892 .50077 Mdot
.892 .5016 Mdot
.892 .50173 Mdot
.892 .50241 Mdot
.892 .50241 Mdot
.892 .50266 Mdot
.892 .5029 Mdot
.892 .50294 Mdot
.892 .50299 Mdot
.892 .50306 Mdot
.892 .50317 Mdot
.892 .50333 Mdot
.892 .50358 Mdot
.892 .50368 Mdot
.892 .50378 Mdot
.892 .50401 Mdot
.892 .50454 Mdot
.892 .50462 Mdot
.892 .50486 Mdot
.892 .50543 Mdot
.892 .50563 Mdot
.892 .50573 Mdot
.892 .50641 Mdot
.892 .50643 Mdot
.892 .5065 Mdot
.892 .50671 Mdot
.892 .50781 Mdot
.892 .50798 Mdot
.892 .50807 Mdot
.892 .50822 Mdot
.892 .50846 Mdot
.892 .50957 Mdot
.892 .51021 Mdot
.892 .51075 Mdot
.892 .51103 Mdot
.892 .51118 Mdot
.892 .51163 Mdot
.892 .51164 Mdot
.892 .51184 Mdot
.892 .51194 Mdot
.892 .51196 Mdot
.892 .51213 Mdot
.892 .5123 Mdot
.892 .51288 Mdot
.892 .513 Mdot
.892 .51362 Mdot
.892 .51436 Mdot
.892 .51448 Mdot
.892 .51467 Mdot
.892 .51471 Mdot
.892 .51474 Mdot
.892 .5167 Mdot
.892 .51718 Mdot
.892 .51722 Mdot
.892 .51732 Mdot
.892 .5177 Mdot
.892 .51793 Mdot
.892 .51867 Mdot
.892 .51883 Mdot
.892 .51939 Mdot
.892 .51978 Mdot
.892 .5199 Mdot
.892 .52022 Mdot
.892 .52046 Mdot
.892 .52055 Mdot
.892 .52059 Mdot
.892 .52078 Mdot
.892 .52085 Mdot
.892 .52087 Mdot
.892 .52133 Mdot
.892 .52184 Mdot
.892 .5219 Mdot
.892 .52203 Mdot
.892 .52215 Mdot
.892 .52241 Mdot
.892 .52245 Mdot
.892 .52249 Mdot
.892 .52266 Mdot
.892 .5229 Mdot
.892 .52301 Mdot
.892 .52302 Mdot
.892 .52312 Mdot
.892 .52316 Mdot
.892 .5233 Mdot
.892 .52379 Mdot
.892 .52405 Mdot
.892 .52421 Mdot
.892 .52451 Mdot
.892 .52478 Mdot
.892 .52508 Mdot
.892 .52534 Mdot
.892 .5254 Mdot
.892 .52549 Mdot
.892 .52594 Mdot
.892 .5264 Mdot
.892 .52685 Mdot
.892 .52693 Mdot
.892 .52712 Mdot
.892 .52716 Mdot
.892 .52718 Mdot
.892 .52719 Mdot
.892 .52734 Mdot
.892 .52734 Mdot
.892 .52739 Mdot
.892 .52756 Mdot
.892 .52789 Mdot
.892 .52806 Mdot
.892 .52833 Mdot
.892 .52841 Mdot
.892 .52846 Mdot
.892 .52858 Mdot
.892 .52862 Mdot
.892 .52874 Mdot
.892 .52894 Mdot
.892 .52898 Mdot
.892 .52949 Mdot
.892 .52976 Mdot
.892 .52993 Mdot
.892 .53017 Mdot
.892 .53041 Mdot
.892 .53045 Mdot
.892 .53052 Mdot
.892 .53071 Mdot
.892 .5308 Mdot
.892 .53083 Mdot
.892 .53122 Mdot
.892 .53158 Mdot
.892 .53166 Mdot
.892 .53178 Mdot
.892 .53183 Mdot
.892 .53201 Mdot
.892 .53266 Mdot
.892 .53266 Mdot
.892 .53293 Mdot
.892 .53301 Mdot
.892 .53306 Mdot
.892 .5331 Mdot
.892 .53317 Mdot
.892 .53319 Mdot
.892 .53357 Mdot
.892 .53381 Mdot
.892 .53381 Mdot
.892 .53391 Mdot
.892 .53401 Mdot
.892 .53405 Mdot
.892 .53417 Mdot
.892 .5342 Mdot
.892 .53426 Mdot
.892 .53432 Mdot
.892 .53432 Mdot
.892 .53442 Mdot
.892 .53452 Mdot
.892 .53459 Mdot
.892 .53464 Mdot
.892 .53467 Mdot
.892 .53467 Mdot
.892 .53482 Mdot
.892 .53489 Mdot
.892 .53498 Mdot
.892 .53504 Mdot
.892 .53512 Mdot
.892 .53512 Mdot
.892 .53542 Mdot
.892 .53571 Mdot
.892 .53576 Mdot
.892 .53582 Mdot
.892 .53617 Mdot
.892 .53622 Mdot
.892 .53647 Mdot
.892 .53663 Mdot
.892 .53677 Mdot
.892 .53687 Mdot
.892 .53688 Mdot
.892 .53693 Mdot
.892 .53703 Mdot
.892 .53713 Mdot
.892 .53718 Mdot
.892 .53727 Mdot
.892 .53735 Mdot
.892 .53736 Mdot
.892 .53737 Mdot
.892 .53737 Mdot
.892 .53738 Mdot
.892 .53765 Mdot
.892 .53768 Mdot
.892 .53771 Mdot
.892 .53771 Mdot
.892 .53777 Mdot
.892 .53779 Mdot
.892 .5378 Mdot
.892 .53783 Mdot
.892 .5379 Mdot
.892 .538 Mdot
.892 .5381 Mdot
.892 .53811 Mdot
.892 .53812 Mdot
.892 .53816 Mdot
.892 .53823 Mdot
.892 .53835 Mdot
.892 .53842 Mdot
.892 .53842 Mdot
.892 .53848 Mdot
.892 .53863 Mdot
.892 .53864 Mdot
.892 .53875 Mdot
.892 .53876 Mdot
.892 .5388 Mdot
.892 .53885 Mdot
.892 .53896 Mdot
.892 .53896 Mdot
.892 .53906 Mdot
.892 .53911 Mdot
.892 .53921 Mdot
.892 .53921 Mdot
.892 .53932 Mdot
.892 .5394 Mdot
.892 .53945 Mdot
.892 .53947 Mdot
.892 .53948 Mdot
.892 .53956 Mdot
.892 .53959 Mdot
.892 .53961 Mdot
.892 .53964 Mdot
.892 .53965 Mdot
.892 .53966 Mdot
.892 .53968 Mdot
.892 .53969 Mdot
.892 .53973 Mdot
.892 .53974 Mdot
.892 .53975 Mdot
.892 .53977 Mdot
.892 .53977 Mdot
.894 .18673 Mdot
.894 .18674 Mdot
.894 .18674 Mdot
.894 .18674 Mdot
.894 .18674 Mdot
.894 .18674 Mdot
.894 .18675 Mdot
.894 .18676 Mdot
.894 .18678 Mdot
.894 .1868 Mdot
.894 .18682 Mdot
.894 .18682 Mdot
.894 .18683 Mdot
.894 .18703 Mdot
.894 .18705 Mdot
.894 .18705 Mdot
.894 .18706 Mdot
.894 .18709 Mdot
.894 .18724 Mdot
.894 .18759 Mdot
.894 .1876 Mdot
.894 .18768 Mdot
.894 .18773 Mdot
.894 .18781 Mdot
.894 .18784 Mdot
.894 .18816 Mdot
.894 .18818 Mdot
.894 .18835 Mdot
.894 .1885 Mdot
.894 .18867 Mdot
.894 .18868 Mdot
.894 .18878 Mdot
.894 .18898 Mdot
.894 .18908 Mdot
.894 .18922 Mdot
.894 .18945 Mdot
.894 .18952 Mdot
.894 .19002 Mdot
.894 .19045 Mdot
.894 .19051 Mdot
.894 .19053 Mdot
.894 .19059 Mdot
.894 .19071 Mdot
.894 .19079 Mdot
.894 .19086 Mdot
.894 .191 Mdot
.894 .19114 Mdot
.894 .19132 Mdot
.894 .19176 Mdot
.894 .19185 Mdot
.894 .19199 Mdot
.894 .19235 Mdot
.894 .19245 Mdot
.894 .19262 Mdot
.894 .19272 Mdot
.894 .19274 Mdot
.894 .19303 Mdot
.894 .19355 Mdot
.894 .19357 Mdot
.894 .19388 Mdot
.894 .1941 Mdot
.894 .19413 Mdot
.894 .19423 Mdot
.894 .19461 Mdot
.894 .19599 Mdot
.894 .19615 Mdot
.894 .19638 Mdot
.894 .19644 Mdot
.894 .19721 Mdot
.894 .1977 Mdot
.894 .19815 Mdot
.894 .19831 Mdot
.894 .20089 Mdot
.894 .20106 Mdot
.894 .20215 Mdot
.894 .20277 Mdot
.894 .20277 Mdot
.894 .2036 Mdot
.894 .20455 Mdot
.894 .20461 Mdot
.894 .20484 Mdot
.894 .2054 Mdot
.894 .20566 Mdot
.894 .2061 Mdot
.894 .20629 Mdot
.894 .20891 Mdot
.894 .21051 Mdot
.894 .21056 Mdot
.894 .21074 Mdot
.894 .21082 Mdot
.894 .21083 Mdot
.894 .21164 Mdot
.894 .21174 Mdot
.894 .21191 Mdot
.894 .21224 Mdot
.894 .21245 Mdot
.894 .2131 Mdot
.894 .21401 Mdot
.894 .21439 Mdot
.894 .21458 Mdot
.894 .21517 Mdot
.894 .21521 Mdot
.894 .21552 Mdot
.894 .21688 Mdot
.894 .21704 Mdot
.894 .21711 Mdot
.894 .21955 Mdot
.894 .22078 Mdot
.894 .22083 Mdot
.894 .22094 Mdot
.894 .2211 Mdot
.894 .22254 Mdot
.894 .22259 Mdot
.894 .22276 Mdot
.894 .2235 Mdot
.894 .2238 Mdot
.894 .22414 Mdot
.894 .2243 Mdot
.894 .22533 Mdot
.894 .22702 Mdot
.894 .22791 Mdot
.894 .22845 Mdot
.894 .22914 Mdot
.894 .22915 Mdot
.894 .23039 Mdot
.894 .23143 Mdot
.894 .23207 Mdot
.894 .23245 Mdot
.894 .23282 Mdot
.894 .23286 Mdot
.894 .23334 Mdot
.894 .23361 Mdot
.894 .23375 Mdot
.894 .23417 Mdot
.894 .23434 Mdot
.894 .23463 Mdot
.894 .23675 Mdot
.894 .23852 Mdot
.894 .23882 Mdot
.894 .23915 Mdot
.894 .23967 Mdot
.894 .24116 Mdot
.894 .24164 Mdot
.894 .24243 Mdot
.894 .24253 Mdot
.894 .24297 Mdot
.894 .24401 Mdot
.894 .24443 Mdot
.894 .24484 Mdot
.894 .2468 Mdot
.894 .24717 Mdot
.894 .24839 Mdot
.894 .24859 Mdot
.894 .24893 Mdot
.894 .24921 Mdot
.894 .24924 Mdot
.894 .24976 Mdot
.894 .25019 Mdot
.894 .25235 Mdot
.894 .2532 Mdot
.894 .25415 Mdot
.894 .25529 Mdot
.894 .25534 Mdot
.894 .25598 Mdot
.894 .25673 Mdot
.894 .25717 Mdot
.894 .2596 Mdot
.894 .2599 Mdot
.894 .26053 Mdot
.894 .26074 Mdot
.894 .26109 Mdot
.894 .26235 Mdot
.894 .26526 Mdot
.894 .26546 Mdot
.894 .26564 Mdot
.894 .26609 Mdot
.894 .26622 Mdot
.894 .26721 Mdot
.894 .26731 Mdot
.894 .26808 Mdot
.894 .26966 Mdot
.894 .2697 Mdot
.894 .27072 Mdot
.894 .27096 Mdot
.894 .27136 Mdot
.894 .27175 Mdot
.894 .27285 Mdot
.894 .273 Mdot
.894 .27343 Mdot
.894 .27403 Mdot
.894 .27409 Mdot
.894 .27768 Mdot
.894 .27897 Mdot
.894 .27979 Mdot
.894 .28052 Mdot
.894 .28053 Mdot
.894 .28109 Mdot
.894 .2821 Mdot
.894 .28227 Mdot
.894 .28501 Mdot
.894 .28549 Mdot
.894 .28689 Mdot
.894 .28695 Mdot
.894 .28741 Mdot
.894 .28976 Mdot
.894 .29047 Mdot
.894 .29122 Mdot
.894 .29163 Mdot
.894 .29166 Mdot
.894 .2918 Mdot
.894 .29205 Mdot
.894 .29275 Mdot
.894 .29311 Mdot
.894 .29382 Mdot
.894 .29509 Mdot
.894 .2952 Mdot
.894 .29535 Mdot
.894 .29618 Mdot
.894 .29719 Mdot
.894 .29785 Mdot
.894 .29889 Mdot
.894 .29913 Mdot
.894 .30055 Mdot
.894 .30169 Mdot
.894 .30196 Mdot
.894 .30245 Mdot
.894 .30399 Mdot
.894 .30504 Mdot
.894 .30507 Mdot
.894 .30519 Mdot
.894 .30576 Mdot
.894 .30684 Mdot
.894 .30695 Mdot
.894 .30744 Mdot
.894 .30786 Mdot
.894 .30834 Mdot
.894 .30843 Mdot
.894 .30858 Mdot
.894 .30899 Mdot
.894 .30929 Mdot
.894 .30958 Mdot
.894 .30987 Mdot
.894 .31088 Mdot
.894 .31109 Mdot
.894 .31307 Mdot
.894 .31327 Mdot
.894 .31557 Mdot
.894 .31594 Mdot
.894 .31648 Mdot
.894 .31756 Mdot
.894 .31805 Mdot
.894 .31845 Mdot
.894 .31891 Mdot
.894 .31966 Mdot
.894 .31988 Mdot
.894 .32072 Mdot
.894 .32282 Mdot
.894 .32318 Mdot
.894 .32332 Mdot
.894 .32344 Mdot
.894 .32369 Mdot
.894 .32392 Mdot
.894 .32508 Mdot
.894 .32757 Mdot
.894 .32802 Mdot
.894 .32835 Mdot
.894 .32848 Mdot
.894 .32897 Mdot
.894 .33084 Mdot
.894 .33204 Mdot
.894 .33321 Mdot
.894 .33914 Mdot
.894 .33933 Mdot
.894 .3398 Mdot
.894 .34001 Mdot
.894 .34053 Mdot
.894 .3426 Mdot
.894 .3438 Mdot
.894 .34384 Mdot
.894 .34404 Mdot
.894 .3447 Mdot
.894 .34483 Mdot
.894 .34567 Mdot
.894 .34657 Mdot
.894 .34713 Mdot
.894 .34825 Mdot
.894 .35078 Mdot
.894 .35095 Mdot
.894 .35186 Mdot
.894 .3529 Mdot
.894 .35351 Mdot
.894 .35449 Mdot
.894 .355 Mdot
.894 .35531 Mdot
.894 .3557 Mdot
.894 .3564 Mdot
.894 .35773 Mdot
.894 .35775 Mdot
.894 .35801 Mdot
.894 .35823 Mdot
.894 .35855 Mdot
.894 .3587 Mdot
.894 .35982 Mdot
.894 .36074 Mdot
.894 .36106 Mdot
.894 .36232 Mdot
.894 .36298 Mdot
.894 .36349 Mdot
.894 .3637 Mdot
.894 .36503 Mdot
.894 .36561 Mdot
.894 .36587 Mdot
.894 .366 Mdot
.894 .36601 Mdot
.894 .36626 Mdot
.894 .36647 Mdot
.894 .36747 Mdot
.894 .37075 Mdot
.894 .37116 Mdot
.894 .37141 Mdot
.894 .37196 Mdot
.894 .37331 Mdot
.894 .37338 Mdot
.894 .37357 Mdot
.894 .37409 Mdot
.894 .37442 Mdot
.894 .3751 Mdot
.894 .3758 Mdot
.894 .37596 Mdot
.894 .37648 Mdot
.894 .37665 Mdot
.894 .37693 Mdot
.894 .37953 Mdot
.894 .37976 Mdot
.894 .38016 Mdot
.894 .38023 Mdot
.894 .3815 Mdot
.894 .38204 Mdot
.894 .38207 Mdot
.894 .38225 Mdot
.894 .38316 Mdot
.894 .38388 Mdot
.894 .38394 Mdot
.894 .38404 Mdot
.894 .3853 Mdot
.894 .38624 Mdot
.894 .38672 Mdot
.894 .38725 Mdot
.894 .38777 Mdot
.894 .38795 Mdot
.894 .38852 Mdot
.894 .38896 Mdot
.894 .38917 Mdot
.894 .38957 Mdot
.894 .38979 Mdot
.894 .38994 Mdot
.894 .39012 Mdot
.894 .3902 Mdot
.894 .39035 Mdot
.894 .39046 Mdot
.894 .39057 Mdot
.894 .39067 Mdot
.894 .39111 Mdot
.894 .39183 Mdot
.894 .3919 Mdot
.894 .39286 Mdot
.894 .39305 Mdot
.894 .39343 Mdot
.894 .39361 Mdot
.894 .39418 Mdot
.894 .39542 Mdot
.894 .3956 Mdot
.894 .39568 Mdot
.894 .39609 Mdot
.894 .39745 Mdot
.894 .3981 Mdot
.894 .39892 Mdot
.894 .40125 Mdot
.894 .40143 Mdot
.894 .40213 Mdot
.894 .40255 Mdot
.894 .40262 Mdot
.894 .40317 Mdot
.894 .4049 Mdot
.894 .40526 Mdot
.894 .40655 Mdot
.894 .40678 Mdot
.894 .4074 Mdot
.894 .40793 Mdot
.894 .40823 Mdot
.894 .40834 Mdot
.894 .40876 Mdot
.894 .40898 Mdot
.894 .40922 Mdot
.894 .40966 Mdot
.894 .40985 Mdot
.894 .40994 Mdot
.894 .40998 Mdot
.894 .40999 Mdot
.894 .41007 Mdot
.894 .41014 Mdot
.894 .41047 Mdot
.894 .41156 Mdot
.894 .41169 Mdot
.894 .41243 Mdot
.894 .41249 Mdot
.894 .41277 Mdot
.894 .41299 Mdot
.894 .41328 Mdot
.894 .4136 Mdot
.894 .41453 Mdot
.894 .41466 Mdot
.894 .41468 Mdot
.894 .4151 Mdot
.894 .41535 Mdot
.894 .41565 Mdot
.894 .41589 Mdot
.894 .41594 Mdot
.894 .41635 Mdot
.894 .41666 Mdot
.894 .41682 Mdot
.894 .41723 Mdot
.894 .41742 Mdot
.894 .41756 Mdot
.894 .41763 Mdot
.894 .41776 Mdot
.894 .41783 Mdot
.894 .41788 Mdot
.894 .41794 Mdot
.894 .41797 Mdot
.894 .41802 Mdot
.894 .41806 Mdot
.894 .41809 Mdot
.894 .41813 Mdot
.894 .41827 Mdot
.894 .41851 Mdot
.894 .41853 Mdot
.894 .41885 Mdot
.894 .41891 Mdot
.894 .41904 Mdot
.894 .41909 Mdot
.894 .41928 Mdot
.894 .41969 Mdot
.894 .41978 Mdot
.894 .42057 Mdot
.894 .42205 Mdot
.894 .42225 Mdot
.894 .42282 Mdot
.894 .42294 Mdot
.894 .42337 Mdot
.894 .42365 Mdot
.894 .4241 Mdot
.894 .42425 Mdot
.894 .4244 Mdot
.894 .42446 Mdot
.894 .42451 Mdot
.894 .42454 Mdot
.894 .42456 Mdot
.894 .42467 Mdot
.894 .42508 Mdot
.894 .42551 Mdot
.894 .42602 Mdot
.894 .42607 Mdot
.894 .42639 Mdot
.894 .42647 Mdot
.894 .42649 Mdot
.894 .42663 Mdot
.894 .42679 Mdot
.894 .42699 Mdot
.894 .42703 Mdot
.894 .4271 Mdot
.894 .42712 Mdot
.894 .42714 Mdot
.894 .42716 Mdot
.894 .42717 Mdot
.894 .42719 Mdot
.894 .42721 Mdot
.894 .42722 Mdot
.894 .42736 Mdot
.894 .42748 Mdot
.894 .42775 Mdot
.894 .42778 Mdot
.894 .4288 Mdot
.894 .42923 Mdot
.894 .42933 Mdot
.894 .42935 Mdot
.894 .42937 Mdot
.894 .42942 Mdot
.894 .43 Mdot
.894 .43003 Mdot
.894 .43004 Mdot
.894 .43008 Mdot
.894 .43014 Mdot
.894 .4302 Mdot
.894 .43024 Mdot
.894 .43026 Mdot
.894 .43026 Mdot
.894 .43027 Mdot
.894 .43027 Mdot
.894 .43028 Mdot
.894 .43028 Mdot
.894 .43278 Mdot
.894 .43278 Mdot
.894 .43279 Mdot
.894 .43279 Mdot
.894 .43279 Mdot
.894 .43279 Mdot
.894 .4328 Mdot
.894 .43282 Mdot
.894 .43286 Mdot
.894 .43289 Mdot
.894 .43292 Mdot
.894 .43293 Mdot
.894 .43294 Mdot
.894 .43328 Mdot
.894 .43331 Mdot
.894 .43332 Mdot
.894 .43333 Mdot
.894 .43339 Mdot
.894 .43364 Mdot
.894 .43423 Mdot
.894 .43424 Mdot
.894 .43439 Mdot
.894 .43447 Mdot
.894 .43454 Mdot
.894 .43455 Mdot
.894 .43456 Mdot
.894 .43457 Mdot
.894 .43458 Mdot
.894 .43459 Mdot
.894 .4346 Mdot
.894 .43461 Mdot
.894 .43465 Mdot
.894 .43468 Mdot
.894 .43479 Mdot
.894 .43488 Mdot
.894 .43496 Mdot
.894 .43497 Mdot
.894 .43502 Mdot
.894 .4352 Mdot
.894 .43523 Mdot
.894 .43552 Mdot
.894 .43577 Mdot
.894 .436 Mdot
.894 .43606 Mdot
.894 .43608 Mdot
.894 .43609 Mdot
.894 .43612 Mdot
.894 .43615 Mdot
.894 .43624 Mdot
.894 .43632 Mdot
.894 .43658 Mdot
.894 .43674 Mdot
.894 .43698 Mdot
.894 .43705 Mdot
.894 .43737 Mdot
.894 .43748 Mdot
.894 .43831 Mdot
.894 .43875 Mdot
.894 .4388 Mdot
.894 .43903 Mdot
.894 .43914 Mdot
.894 .43917 Mdot
.894 .43924 Mdot
.894 .43927 Mdot
.894 .43945 Mdot
.894 .43946 Mdot
.894 .43959 Mdot
.894 .43967 Mdot
.894 .43969 Mdot
.894 .43971 Mdot
.894 .43973 Mdot
.894 .43976 Mdot
.894 .43977 Mdot
.894 .43981 Mdot
.894 .43983 Mdot
.894 .43987 Mdot
.894 .43995 Mdot
.894 .43998 Mdot
.894 .44007 Mdot
.894 .44017 Mdot
.894 .44039 Mdot
.894 .44048 Mdot
.894 .44065 Mdot
.894 .44088 Mdot
.894 .44091 Mdot
.894 .44104 Mdot
.894 .4412 Mdot
.894 .44134 Mdot
.894 .44157 Mdot
.894 .44158 Mdot
.894 .44165 Mdot
.894 .44217 Mdot
.894 .44234 Mdot
.894 .44249 Mdot
.894 .44262 Mdot
.894 .44277 Mdot
.894 .4428 Mdot
.894 .4432 Mdot
.894 .44327 Mdot
.894 .44386 Mdot
.894 .44404 Mdot
.894 .44408 Mdot
.894 .44412 Mdot
.894 .44413 Mdot
.894 .44415 Mdot
.894 .4442 Mdot
.894 .4443 Mdot
.894 .44454 Mdot
.894 .44467 Mdot
.894 .44478 Mdot
.894 .44501 Mdot
.894 .44507 Mdot
.894 .44523 Mdot
.894 .44551 Mdot
.894 .44584 Mdot
.894 .44597 Mdot
.894 .44665 Mdot
.894 .44685 Mdot
.894 .44776 Mdot
.894 .44805 Mdot
.894 .44809 Mdot
.894 .44831 Mdot
.894 .44868 Mdot
.894 .44877 Mdot
.894 .44999 Mdot
.894 .45042 Mdot
.894 .45075 Mdot
.894 .45146 Mdot
.894 .45167 Mdot
.894 .45171 Mdot
.894 .4518 Mdot
.894 .45244 Mdot
.894 .45273 Mdot
.894 .45282 Mdot
.894 .45302 Mdot
.894 .45312 Mdot
.894 .45361 Mdot
.894 .45365 Mdot
.894 .45401 Mdot
.894 .45424 Mdot
.894 .45429 Mdot
.894 .45434 Mdot
.894 .4544 Mdot
.894 .45447 Mdot
.894 .45452 Mdot
.894 .45461 Mdot
.894 .45468 Mdot
.894 .4548 Mdot
.894 .455 Mdot
.894 .4551 Mdot
.894 .45533 Mdot
.894 .45561 Mdot
.894 .4557 Mdot
.894 .45597 Mdot
.894 .45624 Mdot
.894 .45648 Mdot
.894 .45695 Mdot
.894 .45758 Mdot
.894 .45763 Mdot
.894 .45766 Mdot
.894 .45802 Mdot
.894 .45847 Mdot
.894 .45856 Mdot
.894 .45857 Mdot
.894 .45885 Mdot
.894 .45948 Mdot
.894 .45951 Mdot
.894 .45971 Mdot
.894 .45982 Mdot
.894 .4611 Mdot
.894 .46124 Mdot
.894 .46132 Mdot
.894 .46158 Mdot
.894 .46166 Mdot
.894 .46199 Mdot
.894 .46233 Mdot
.894 .46249 Mdot
.894 .46274 Mdot
.894 .46283 Mdot
.894 .46287 Mdot
.894 .46352 Mdot
.894 .46379 Mdot
.894 .46391 Mdot
.894 .46411 Mdot
.894 .46569 Mdot
.894 .46617 Mdot
.894 .46627 Mdot
.894 .46639 Mdot
.894 .46639 Mdot
.894 .46646 Mdot
.894 .46658 Mdot
.894 .46686 Mdot
.894 .46749 Mdot
.894 .46759 Mdot
.894 .46783 Mdot
.894 .46815 Mdot
.894 .46874 Mdot
.894 .4689 Mdot
.894 .46933 Mdot
.894 .46986 Mdot
.894 .46993 Mdot
.894 .47008 Mdot
.894 .47018 Mdot
.894 .4703 Mdot
.894 .47031 Mdot
.894 .47094 Mdot
.894 .47127 Mdot
.894 .47145 Mdot
.894 .47159 Mdot
.894 .47183 Mdot
.894 .47229 Mdot
.894 .47257 Mdot
.894 .47305 Mdot
.894 .47347 Mdot
.894 .47355 Mdot
.894 .47472 Mdot
.894 .47523 Mdot
.894 .47549 Mdot
.894 .4759 Mdot
.894 .47629 Mdot
.894 .47635 Mdot
.894 .47665 Mdot
.894 .47674 Mdot
.894 .47676 Mdot
.894 .47731 Mdot
.894 .47825 Mdot
.894 .47848 Mdot
.894 .47858 Mdot
.894 .47879 Mdot
.894 .47888 Mdot
.894 .48154 Mdot
.894 .48207 Mdot
.894 .4826 Mdot
.894 .48343 Mdot
.894 .48365 Mdot
.894 .48371 Mdot
.894 .48385 Mdot
.894 .48405 Mdot
.894 .48515 Mdot
.894 .48567 Mdot
.894 .48577 Mdot
.894 .48587 Mdot
.894 .48593 Mdot
.894 .48599 Mdot
.894 .48615 Mdot
.894 .48707 Mdot
.894 .48743 Mdot
.894 .48753 Mdot
.894 .48786 Mdot
.894 .48806 Mdot
.894 .48823 Mdot
.894 .48845 Mdot
.894 .48892 Mdot
.894 .48915 Mdot
.894 .48931 Mdot
.894 .49031 Mdot
.894 .4904 Mdot
.894 .49125 Mdot
.894 .49134 Mdot
.894 .49178 Mdot
.894 .4919 Mdot
.894 .49202 Mdot
.894 .49215 Mdot
.894 .49233 Mdot
.894 .49239 Mdot
.894 .49243 Mdot
.894 .49264 Mdot
.894 .49282 Mdot
.894 .49303 Mdot
.894 .49308 Mdot
.894 .49354 Mdot
.894 .49378 Mdot
.894 .49383 Mdot
.894 .49385 Mdot
.894 .49429 Mdot
.894 .49495 Mdot
.894 .49516 Mdot
.894 .49527 Mdot
.894 .49575 Mdot
.894 .49636 Mdot
.894 .49646 Mdot
.894 .4969 Mdot
.894 .49718 Mdot
.894 .4976 Mdot
.894 .49795 Mdot
.894 .49801 Mdot
.894 .49806 Mdot
.894 .49859 Mdot
.894 .49889 Mdot
.894 .49904 Mdot
.894 .49934 Mdot
.894 .49944 Mdot
.894 .4995 Mdot
.894 .49951 Mdot
.894 .49969 Mdot
.894 .5 Mdot
.894 .5003 Mdot
.894 .50128 Mdot
.894 .50147 Mdot
.894 .50149 Mdot
.894 .50207 Mdot
.894 .50227 Mdot
.894 .50341 Mdot
.894 .50348 Mdot
.894 .5039 Mdot
.894 .50413 Mdot
.894 .50413 Mdot
.894 .50443 Mdot
.894 .50477 Mdot
.894 .5053 Mdot
.894 .50677 Mdot
.894 .5068 Mdot
.894 .50704 Mdot
.894 .50722 Mdot
.894 .50728 Mdot
.894 .50773 Mdot
.894 .50789 Mdot
.894 .50805 Mdot
.894 .50815 Mdot
.894 .50856 Mdot
.894 .50858 Mdot
.894 .50922 Mdot
.894 .50954 Mdot
.894 .50958 Mdot
.894 .50998 Mdot
.894 .51003 Mdot
.894 .51021 Mdot
.894 .51029 Mdot
.894 .51037 Mdot
.894 .51154 Mdot
.894 .51205 Mdot
.894 .51219 Mdot
.894 .51228 Mdot
.894 .51253 Mdot
.894 .51265 Mdot
.894 .51363 Mdot
.894 .5138 Mdot
.894 .5141 Mdot
.894 .51436 Mdot
.894 .51438 Mdot
.894 .51483 Mdot
.894 .51522 Mdot
.894 .51556 Mdot
.894 .51642 Mdot
.894 .51659 Mdot
.894 .5168 Mdot
.894 .51681 Mdot
.894 .51692 Mdot
.894 .51706 Mdot
.894 .51713 Mdot
.894 .51762 Mdot
.894 .51776 Mdot
.894 .51854 Mdot
.894 .5187 Mdot
.894 .51887 Mdot
.894 .51928 Mdot
.894 .51946 Mdot
.894 .51949 Mdot
.894 .5198 Mdot
.894 .52 Mdot
.894 .52058 Mdot
.894 .52079 Mdot
.894 .52092 Mdot
.894 .52103 Mdot
.894 .52173 Mdot
.894 .52256 Mdot
.894 .52268 Mdot
.894 .52274 Mdot
.894 .52291 Mdot
.894 .52296 Mdot
.894 .52307 Mdot
.894 .52325 Mdot
.894 .52327 Mdot
.894 .52342 Mdot
.894 .52356 Mdot
.894 .52381 Mdot
.894 .52422 Mdot
.894 .5247 Mdot
.894 .52471 Mdot
.894 .52498 Mdot
.894 .52519 Mdot
.894 .52553 Mdot
.894 .52619 Mdot
.894 .52659 Mdot
.894 .52665 Mdot
.894 .52679 Mdot
.894 .5269 Mdot
.894 .52719 Mdot
.894 .52726 Mdot
.894 .52727 Mdot
.894 .52783 Mdot
.894 .52789 Mdot
.894 .52794 Mdot
.894 .52796 Mdot
.894 .52843 Mdot
.894 .52937 Mdot
.894 .5294 Mdot
.894 .52946 Mdot
.894 .52999 Mdot
.894 .5301 Mdot
.894 .53012 Mdot
.894 .53035 Mdot
.894 .53042 Mdot
.894 .53057 Mdot
.894 .53092 Mdot
.894 .53117 Mdot
.894 .53125 Mdot
.894 .53137 Mdot
.894 .53144 Mdot
.894 .53148 Mdot
.894 .53179 Mdot
.894 .53179 Mdot
.894 .53183 Mdot
.894 .53189 Mdot
.894 .53191 Mdot
.894 .53253 Mdot
.894 .53353 Mdot
.894 .5336 Mdot
.894 .53377 Mdot
.894 .53387 Mdot
.894 .53408 Mdot
.894 .53417 Mdot
.894 .53419 Mdot
.894 .53455 Mdot
.894 .53487 Mdot
.894 .53487 Mdot
.894 .53511 Mdot
.894 .53552 Mdot
.894 .53559 Mdot
.894 .53657 Mdot
.894 .53663 Mdot
.894 .5368 Mdot
.894 .53699 Mdot
.894 .53728 Mdot
.894 .5373 Mdot
.894 .53739 Mdot
.894 .53745 Mdot
.894 .53797 Mdot
.894 .53812 Mdot
.894 .53815 Mdot
.894 .53817 Mdot
.894 .53825 Mdot
.894 .53837 Mdot
.894 .53837 Mdot
.894 .53857 Mdot
.894 .53868 Mdot
.894 .53869 Mdot
.894 .53872 Mdot
.894 .53879 Mdot
.894 .53896 Mdot
.894 .53902 Mdot
.894 .53905 Mdot
.894 .53922 Mdot
.894 .53929 Mdot
.894 .53934 Mdot
.894 .53939 Mdot
.894 .53942 Mdot
.894 .53945 Mdot
.894 .53949 Mdot
.894 .53952 Mdot
.894 .53952 Mdot
.894 .53955 Mdot
.894 .53971 Mdot
.894 .5399 Mdot
.894 .53992 Mdot
.894 .54001 Mdot
.894 .54007 Mdot
.894 .5401 Mdot
.894 .54018 Mdot
.894 .54021 Mdot
.894 .54022 Mdot
.894 .54028 Mdot
.894 .54034 Mdot
.894 .5404 Mdot
.894 .54041 Mdot
.894 .54053 Mdot
.894 .54054 Mdot
.894 .54057 Mdot
.894 .54059 Mdot
.894 .54062 Mdot
.894 .54063 Mdot
.894 .54076 Mdot
.894 .54081 Mdot
.894 .54083 Mdot
.894 .54083 Mdot
.894 .54083 Mdot
.894 .54084 Mdot
.894 .54091 Mdot
.894 .54092 Mdot
.894 .54092 Mdot
.894 .54092 Mdot
.894 .54093 Mdot
.894 .54094 Mdot
.894 .54094 Mdot
.894 .54094 Mdot
.894 .54095 Mdot
.894 .54095 Mdot
.894 .54095 Mdot
.894 .54095 Mdot
.894 .54095 Mdot
.896 .18398 Mdot
.896 .18399 Mdot
.896 .18403 Mdot
.896 .18403 Mdot
.896 .18405 Mdot
.896 .18405 Mdot
.896 .18409 Mdot
.896 .18411 Mdot
.896 .18412 Mdot
.896 .18413 Mdot
.896 .18419 Mdot
.896 .18423 Mdot
.896 .1843 Mdot
.896 .18431 Mdot
.896 .18443 Mdot
.896 .18449 Mdot
.896 .18452 Mdot
.896 .18569 Mdot
.896 .1859 Mdot
.896 .18593 Mdot
.896 .18617 Mdot
.896 .18636 Mdot
.896 .18638 Mdot
.896 .18656 Mdot
.896 .18694 Mdot
.896 .18711 Mdot
.896 .18769 Mdot
.896 .18781 Mdot
.896 .18794 Mdot
.896 .18828 Mdot
.896 .18906 Mdot
.896 .18909 Mdot
.896 .1891 Mdot
.896 .18935 Mdot
.896 .18942 Mdot
.896 .18965 Mdot
.896 .18974 Mdot
.896 .18985 Mdot
.896 .18999 Mdot
.896 .1903 Mdot
.896 .19059 Mdot
.896 .19195 Mdot
.896 .19272 Mdot
.896 .19278 Mdot
.896 .19331 Mdot
.896 .19333 Mdot
.896 .19368 Mdot
.896 .1939 Mdot
.896 .19429 Mdot
.896 .19442 Mdot
.896 .19444 Mdot
.896 .1945 Mdot
.896 .19468 Mdot
.896 .19471 Mdot
.896 .19518 Mdot
.896 .19567 Mdot
.896 .19583 Mdot
.896 .19603 Mdot
.896 .19609 Mdot
.896 .19669 Mdot
.896 .19675 Mdot
.896 .19751 Mdot
.896 .19757 Mdot
.896 .19762 Mdot
.896 .19801 Mdot
.896 .19815 Mdot
.896 .19839 Mdot
.896 .19899 Mdot
.896 .19915 Mdot
.896 .19963 Mdot
.896 .19968 Mdot
.896 .20007 Mdot
.896 .20148 Mdot
.896 .20159 Mdot
.896 .20199 Mdot
.896 .20207 Mdot
.896 .20221 Mdot
.896 .20253 Mdot
.896 .20269 Mdot
.896 .20321 Mdot
.896 .20322 Mdot
.896 .20431 Mdot
.896 .20574 Mdot
.896 .20613 Mdot
.896 .20737 Mdot
.896 .20794 Mdot
.896 .20813 Mdot
.896 .20821 Mdot
.896 .20821 Mdot
.896 .20827 Mdot
.896 .20844 Mdot
.896 .20869 Mdot
.896 .20916 Mdot
.896 .20945 Mdot
.896 .21096 Mdot
.896 .21097 Mdot
.896 .21112 Mdot
.896 .21167 Mdot
.896 .21238 Mdot
.896 .21248 Mdot
.896 .21279 Mdot
.896 .2128 Mdot
.896 .21291 Mdot
.896 .21385 Mdot
.896 .21487 Mdot
.896 .21514 Mdot
.896 .21555 Mdot
.896 .21622 Mdot
.896 .21651 Mdot
.896 .21668 Mdot
.896 .21713 Mdot
.896 .21725 Mdot
.896 .21746 Mdot
.896 .21766 Mdot
.896 .21773 Mdot
.896 .2179 Mdot
.896 .21821 Mdot
.896 .21851 Mdot
.896 .21893 Mdot
.896 .219 Mdot
.896 .21903 Mdot
.896 .21922 Mdot
.896 .21945 Mdot
.896 .2197 Mdot
.896 .221 Mdot
.896 .22142 Mdot
.896 .22222 Mdot
.896 .22317 Mdot
.896 .22333 Mdot
.896 .22353 Mdot
.896 .22356 Mdot
.896 .22561 Mdot
.896 .22588 Mdot
.896 .22621 Mdot
.896 .22639 Mdot
.896 .22701 Mdot
.896 .22711 Mdot
.896 .22755 Mdot
.896 .22884 Mdot
.896 .23147 Mdot
.896 .23209 Mdot
.896 .23218 Mdot
.896 .2329 Mdot
.896 .23373 Mdot
.896 .23564 Mdot
.896 .23618 Mdot
.896 .23678 Mdot
.896 .23736 Mdot
.896 .23834 Mdot
.896 .24027 Mdot
.896 .24057 Mdot
.896 .24108 Mdot
.896 .24159 Mdot
.896 .2418 Mdot
.896 .24216 Mdot
.896 .24264 Mdot
.896 .24285 Mdot
.896 .24304 Mdot
.896 .24322 Mdot
.896 .24325 Mdot
.896 .24375 Mdot
.896 .24386 Mdot
.896 .24495 Mdot
.896 .24535 Mdot
.896 .24641 Mdot
.896 .24782 Mdot
.896 .24853 Mdot
.896 .24866 Mdot
.896 .25129 Mdot
.896 .2535 Mdot
.896 .25432 Mdot
.896 .25459 Mdot
.896 .25484 Mdot
.896 .2551 Mdot
.896 .2562 Mdot
.896 .25699 Mdot
.896 .25942 Mdot
.896 .25975 Mdot
.896 .26188 Mdot
.896 .26281 Mdot
.896 .26539 Mdot
.896 .26564 Mdot
.896 .26684 Mdot
.896 .2669 Mdot
.896 .26734 Mdot
.896 .2678 Mdot
.896 .2683 Mdot
.896 .26841 Mdot
.896 .26859 Mdot
.896 .26929 Mdot
.896 .26946 Mdot
.896 .27013 Mdot
.896 .27034 Mdot
.896 .27084 Mdot
.896 .2716 Mdot
.896 .27209 Mdot
.896 .27335 Mdot
.896 .2741 Mdot
.896 .2779 Mdot
.896 .27833 Mdot
.896 .27846 Mdot
.896 .27891 Mdot
.896 .28141 Mdot
.896 .28247 Mdot
.896 .2829 Mdot
.896 .2837 Mdot
.896 .28443 Mdot
.896 .28582 Mdot
.896 .28612 Mdot
.896 .28629 Mdot
.896 .28741 Mdot
.896 .28803 Mdot
.896 .29084 Mdot
.896 .29124 Mdot
.896 .29219 Mdot
.896 .29304 Mdot
.896 .29497 Mdot
.896 .29519 Mdot
.896 .29687 Mdot
.896 .30385 Mdot
.896 .30402 Mdot
.896 .30432 Mdot
.896 .3065 Mdot
.896 .30717 Mdot
.896 .30755 Mdot
.896 .30759 Mdot
.896 .3088 Mdot
.896 .30909 Mdot
.896 .3108 Mdot
.896 .31133 Mdot
.896 .31164 Mdot
.896 .31172 Mdot
.896 .31225 Mdot
.896 .3125 Mdot
.896 .313 Mdot
.896 .31305 Mdot
.896 .31827 Mdot
.896 .31882 Mdot
.896 .3189 Mdot
.896 .31948 Mdot
.896 .31992 Mdot
.896 .31998 Mdot
.896 .32038 Mdot
.896 .32152 Mdot
.896 .32265 Mdot
.896 .32368 Mdot
.896 .32497 Mdot
.896 .32503 Mdot
.896 .32541 Mdot
.896 .32552 Mdot
.896 .32601 Mdot
.896 .32616 Mdot
.896 .32636 Mdot
.896 .329 Mdot
.896 .32995 Mdot
.896 .33068 Mdot
.896 .33108 Mdot
.896 .33133 Mdot
.896 .33191 Mdot
.896 .332 Mdot
.896 .3322 Mdot
.896 .33274 Mdot
.896 .33325 Mdot
.896 .33342 Mdot
.896 .33368 Mdot
.896 .3343 Mdot
.896 .3351 Mdot
.896 .3352 Mdot
.896 .33571 Mdot
.896 .33594 Mdot
.896 .3365 Mdot
.896 .33708 Mdot
.896 .33712 Mdot
.896 .33748 Mdot
.896 .33871 Mdot
.896 .33881 Mdot
.896 .33921 Mdot
.896 .33933 Mdot
.896 .34017 Mdot
.896 .34104 Mdot
.896 .34216 Mdot
.896 .34246 Mdot
.896 .34339 Mdot
.896 .34381 Mdot
.896 .34401 Mdot
.896 .34401 Mdot
.896 .34406 Mdot
.896 .34418 Mdot
.896 .34436 Mdot
.896 .34491 Mdot
.896 .34598 Mdot
.896 .34608 Mdot
.896 .34695 Mdot
.896 .34701 Mdot
.896 .34723 Mdot
.896 .3473 Mdot
.896 .34904 Mdot
.896 .35005 Mdot
.896 .35012 Mdot
.896 .35037 Mdot
.896 .35042 Mdot
.896 .35053 Mdot
.896 .35091 Mdot
.896 .3512 Mdot
.896 .35134 Mdot
.896 .35148 Mdot
.896 .35163 Mdot
.896 .35314 Mdot
.896 .3537 Mdot
.896 .35379 Mdot
.896 .3539 Mdot
.896 .35392 Mdot
.896 .3551 Mdot
.896 .35543 Mdot
.896 .35554 Mdot
.896 .35588 Mdot
.896 .35594 Mdot
.896 .35689 Mdot
.896 .35868 Mdot
.896 .35906 Mdot
.896 .3595 Mdot
.896 .36049 Mdot
.896 .36076 Mdot
.896 .36136 Mdot
.896 .36281 Mdot
.896 .36356 Mdot
.896 .36397 Mdot
.896 .36407 Mdot
.896 .36417 Mdot
.896 .36425 Mdot
.896 .36427 Mdot
.896 .36451 Mdot
.896 .36508 Mdot
.896 .36527 Mdot
.896 .36577 Mdot
.896 .36643 Mdot
.896 .36682 Mdot
.896 .36803 Mdot
.896 .36903 Mdot
.896 .36964 Mdot
.896 .36975 Mdot
.896 .37059 Mdot
.896 .37179 Mdot
.896 .37546 Mdot
.896 .37554 Mdot
.896 .37583 Mdot
.896 .37617 Mdot
.896 .37677 Mdot
.896 .37932 Mdot
.896 .37948 Mdot
.896 .37954 Mdot
.896 .38111 Mdot
.896 .38159 Mdot
.896 .38253 Mdot
.896 .38259 Mdot
.896 .38302 Mdot
.896 .38326 Mdot
.896 .38448 Mdot
.896 .38484 Mdot
.896 .38916 Mdot
.896 .38933 Mdot
.896 .39012 Mdot
.896 .39036 Mdot
.896 .3905 Mdot
.896 .39196 Mdot
.896 .39199 Mdot
.896 .39227 Mdot
.896 .39246 Mdot
.896 .39431 Mdot
.896 .39491 Mdot
.896 .39505 Mdot
.896 .39545 Mdot
.896 .3962 Mdot
.896 .39666 Mdot
.896 .3968 Mdot
.896 .39683 Mdot
.896 .397 Mdot
.896 .39713 Mdot
.896 .39803 Mdot
.896 .39875 Mdot
.896 .39931 Mdot
.896 .39949 Mdot
.896 .39964 Mdot
.896 .40012 Mdot
.896 .40079 Mdot
.896 .40134 Mdot
.896 .40151 Mdot
.896 .40213 Mdot
.896 .40261 Mdot
.896 .40306 Mdot
.896 .40313 Mdot
.896 .40313 Mdot
.896 .40314 Mdot
.896 .40324 Mdot
.896 .40343 Mdot
.896 .40379 Mdot
.896 .40382 Mdot
.896 .40411 Mdot
.896 .40413 Mdot
.896 .40423 Mdot
.896 .40481 Mdot
.896 .40517 Mdot
.896 .40531 Mdot
.896 .40543 Mdot
.896 .40553 Mdot
.896 .40562 Mdot
.896 .40617 Mdot
.896 .40636 Mdot
.896 .40643 Mdot
.896 .40643 Mdot
.896 .40682 Mdot
.896 .40697 Mdot
.896 .40742 Mdot
.896 .40801 Mdot
.896 .40814 Mdot
.896 .40828 Mdot
.896 .4087 Mdot
.896 .40975 Mdot
.896 .40982 Mdot
.896 .41018 Mdot
.896 .41035 Mdot
.896 .41056 Mdot
.896 .41109 Mdot
.896 .41142 Mdot
.896 .41161 Mdot
.896 .41165 Mdot
.896 .41352 Mdot
.896 .41354 Mdot
.896 .41364 Mdot
.896 .41395 Mdot
.896 .41478 Mdot
.896 .41583 Mdot
.896 .41805 Mdot
.896 .4183 Mdot
.896 .41891 Mdot
.896 .41901 Mdot
.896 .41987 Mdot
.896 .42029 Mdot
.896 .42059 Mdot
.896 .42089 Mdot
.896 .42112 Mdot
.896 .42141 Mdot
.896 .42157 Mdot
.896 .42179 Mdot
.896 .42253 Mdot
.896 .42256 Mdot
.896 .42256 Mdot
.896 .42256 Mdot
.896 .42259 Mdot
.896 .42265 Mdot
.896 .42277 Mdot
.896 .42278 Mdot
.896 .42288 Mdot
.896 .42292 Mdot
.896 .42311 Mdot
.896 .42322 Mdot
.896 .42327 Mdot
.896 .42331 Mdot
.896 .42364 Mdot
.896 .42382 Mdot
.896 .42396 Mdot
.896 .4242 Mdot
.896 .42425 Mdot
.896 .42487 Mdot
.896 .42492 Mdot
.896 .425 Mdot
.896 .42517 Mdot
.896 .42535 Mdot
.896 .42597 Mdot
.896 .42598 Mdot
.896 .42601 Mdot
.896 .42639 Mdot
.896 .42673 Mdot
.896 .42755 Mdot
.896 .42779 Mdot
.896 .42849 Mdot
.896 .42859 Mdot
.896 .42897 Mdot
.896 .42897 Mdot
.896 .42898 Mdot
.896 .42904 Mdot
.896 .42904 Mdot
.896 .42908 Mdot
.896 .42909 Mdot
.896 .42915 Mdot
.896 .42919 Mdot
.896 .4292 Mdot
.896 .42922 Mdot
.896 .42933 Mdot
.896 .42939 Mdot
.896 .42944 Mdot
.896 .42951 Mdot
.896 .42953 Mdot
.896 .42974 Mdot
.896 .42976 Mdot
.896 .42984 Mdot
.896 .4299 Mdot
.896 .43011 Mdot
.896 .43011 Mdot
.896 .43064 Mdot
.896 .43072 Mdot
.896 .43098 Mdot
.896 .43127 Mdot
.896 .43138 Mdot
.896 .4315 Mdot
.896 .43179 Mdot
.896 .43193 Mdot
.896 .43197 Mdot
.896 .43206 Mdot
.896 .43228 Mdot
.896 .43234 Mdot
.896 .43244 Mdot
.896 .43261 Mdot
.896 .43268 Mdot
.896 .43275 Mdot
.896 .43291 Mdot
.896 .43307 Mdot
.896 .43311 Mdot
.896 .43342 Mdot
.896 .43342 Mdot
.896 .43362 Mdot
.896 .4338 Mdot
.896 .43407 Mdot
.896 .43429 Mdot
.896 .43435 Mdot
.896 .43475 Mdot
.896 .43488 Mdot
.896 .43535 Mdot
.896 .43555 Mdot
.896 .43576 Mdot
.896 .43578 Mdot
.896 .43578 Mdot
.896 .43613 Mdot
.896 .43624 Mdot
.896 .43634 Mdot
.896 .43638 Mdot
.896 .43641 Mdot
.896 .43676 Mdot
.896 .43679 Mdot
.896 .43692 Mdot
.896 .437 Mdot
.896 .4371 Mdot
.896 .43729 Mdot
.896 .43731 Mdot
.896 .43733 Mdot
.896 .4374 Mdot
.896 .43751 Mdot
.896 .43752 Mdot
.896 .43758 Mdot
.896 .43759 Mdot
.896 .43765 Mdot
.896 .43769 Mdot
.896 .43771 Mdot
.896 .43771 Mdot
.896 .43771 Mdot
.896 .43772 Mdot
.896 .43814 Mdot
.896 .43826 Mdot
.896 .43835 Mdot
.896 .43851 Mdot
.896 .43864 Mdot
.896 .43881 Mdot
.896 .43897 Mdot
.896 .43921 Mdot
.896 .43969 Mdot
.896 .43974 Mdot
.896 .44007 Mdot
.896 .44022 Mdot
.896 .44143 Mdot
.896 .44201 Mdot
.896 .44246 Mdot
.896 .44263 Mdot
.896 .44268 Mdot
.896 .44269 Mdot
.896 .4437 Mdot
.896 .44372 Mdot
.896 .44383 Mdot
.896 .44401 Mdot
.896 .44429 Mdot
.896 .44441 Mdot
.896 .44449 Mdot
.896 .44469 Mdot
.896 .44472 Mdot
.896 .44529 Mdot
.896 .44551 Mdot
.896 .44559 Mdot
.896 .44566 Mdot
.896 .44597 Mdot
.896 .44621 Mdot
.896 .44629 Mdot
.896 .44649 Mdot
.896 .4465 Mdot
.896 .44653 Mdot
.896 .44663 Mdot
.896 .44692 Mdot
.896 .44697 Mdot
.896 .44702 Mdot
.896 .44709 Mdot
.896 .44716 Mdot
.896 .44735 Mdot
.896 .44766 Mdot
.896 .44771 Mdot
.896 .44772 Mdot
.896 .44787 Mdot
.896 .44789 Mdot
.896 .44808 Mdot
.896 .44818 Mdot
.896 .44823 Mdot
.896 .44824 Mdot
.896 .44824 Mdot
.896 .44827 Mdot
.896 .44851 Mdot
.896 .44876 Mdot
.896 .44909 Mdot
.896 .44918 Mdot
.896 .44946 Mdot
.896 .44981 Mdot
.896 .45006 Mdot
.896 .45014 Mdot
.896 .45023 Mdot
.896 .45053 Mdot
.896 .45089 Mdot
.896 .45136 Mdot
.896 .45143 Mdot
.896 .45151 Mdot
.896 .45153 Mdot
.896 .4516 Mdot
.896 .45184 Mdot
.896 .45223 Mdot
.896 .45243 Mdot
.896 .4525 Mdot
.896 .45281 Mdot
.896 .45375 Mdot
.896 .45385 Mdot
.896 .45399 Mdot
.896 .45401 Mdot
.896 .45475 Mdot
.896 .45482 Mdot
.896 .45494 Mdot
.896 .45534 Mdot
.896 .45543 Mdot
.896 .45759 Mdot
.896 .45777 Mdot
.896 .45838 Mdot
.896 .4585 Mdot
.896 .45871 Mdot
.896 .45874 Mdot
.896 .4592 Mdot
.896 .45944 Mdot
.896 .46022 Mdot
.896 .46025 Mdot
.896 .46033 Mdot
.896 .46157 Mdot
.896 .46187 Mdot
.896 .46204 Mdot
.896 .46218 Mdot
.896 .46221 Mdot
.896 .46399 Mdot
.896 .46457 Mdot
.896 .46498 Mdot
.896 .46503 Mdot
.896 .46532 Mdot
.896 .4658 Mdot
.896 .46638 Mdot
.896 .46656 Mdot
.896 .46688 Mdot
.896 .46712 Mdot
.896 .46721 Mdot
.896 .46748 Mdot
.896 .46759 Mdot
.896 .4676 Mdot
.896 .46764 Mdot
.896 .46769 Mdot
.896 .46773 Mdot
.896 .46793 Mdot
.896 .46828 Mdot
.896 .46897 Mdot
.896 .46925 Mdot
.896 .46938 Mdot
.896 .46984 Mdot
.896 .47005 Mdot
.896 .47023 Mdot
.896 .47107 Mdot
.896 .47151 Mdot
.896 .47154 Mdot
.896 .4717 Mdot
.896 .47174 Mdot
.896 .4719 Mdot
.896 .47245 Mdot
.896 .47246 Mdot
.896 .47251 Mdot
.896 .47255 Mdot
.896 .47281 Mdot
.896 .47351 Mdot
.896 .47358 Mdot
.896 .47364 Mdot
.896 .4737 Mdot
.896 .47384 Mdot
.896 .47402 Mdot
.896 .47407 Mdot
.896 .47409 Mdot
.896 .4742 Mdot
.896 .47424 Mdot
.896 .4747 Mdot
.896 .4755 Mdot
.896 .47553 Mdot
.896 .47563 Mdot
.896 .47566 Mdot
.896 .47605 Mdot
.896 .4761 Mdot
.896 .47659 Mdot
.896 .47684 Mdot
.896 .47692 Mdot
.896 .47698 Mdot
.896 .477 Mdot
.896 .477 Mdot
.896 .47709 Mdot
.896 .47728 Mdot
.896 .4777 Mdot
.896 .47784 Mdot
.896 .47835 Mdot
.896 .47874 Mdot
.896 .47912 Mdot
.896 .47917 Mdot
.896 .47935 Mdot
.896 .4794 Mdot
.896 .47995 Mdot
.896 .48011 Mdot
.896 .48013 Mdot
.896 .48039 Mdot
.896 .48064 Mdot
.896 .48074 Mdot
.896 .48097 Mdot
.896 .48102 Mdot
.896 .48138 Mdot
.896 .48165 Mdot
.896 .48177 Mdot
.896 .48184 Mdot
.896 .48207 Mdot
.896 .48231 Mdot
.896 .4824 Mdot
.896 .48244 Mdot
.896 .4827 Mdot
.896 .48281 Mdot
.896 .48299 Mdot
.896 .48331 Mdot
.896 .48373 Mdot
.896 .48489 Mdot
.896 .48498 Mdot
.896 .48505 Mdot
.896 .48526 Mdot
.896 .48531 Mdot
.896 .48548 Mdot
.896 .48551 Mdot
.896 .48607 Mdot
.896 .48652 Mdot
.896 .48702 Mdot
.896 .48752 Mdot
.896 .48769 Mdot
.896 .48772 Mdot
.896 .48791 Mdot
.896 .48816 Mdot
.896 .4882 Mdot
.896 .48843 Mdot
.896 .49069 Mdot
.896 .49072 Mdot
.896 .49093 Mdot
.896 .49104 Mdot
.896 .49127 Mdot
.896 .4913 Mdot
.896 .49143 Mdot
.896 .49166 Mdot
.896 .49239 Mdot
.896 .49252 Mdot
.896 .49303 Mdot
.896 .49305 Mdot
.896 .49321 Mdot
.896 .4935 Mdot
.896 .49443 Mdot
.896 .49455 Mdot
.896 .49463 Mdot
.896 .49758 Mdot
.896 .49828 Mdot
.896 .49838 Mdot
.896 .49918 Mdot
.896 .49954 Mdot
.896 .49993 Mdot
.896 .5001 Mdot
.896 .50127 Mdot
.896 .50153 Mdot
.896 .50199 Mdot
.896 .50206 Mdot
.896 .50219 Mdot
.896 .50276 Mdot
.896 .50306 Mdot
.896 .5034 Mdot
.896 .50357 Mdot
.896 .50401 Mdot
.896 .50504 Mdot
.896 .50522 Mdot
.896 .50528 Mdot
.896 .50545 Mdot
.896 .507 Mdot
.896 .50731 Mdot
.896 .50782 Mdot
.896 .50802 Mdot
.896 .50833 Mdot
.896 .50854 Mdot
.896 .50862 Mdot
.896 .50889 Mdot
.896 .50896 Mdot
.896 .50925 Mdot
.896 .50932 Mdot
.896 .50937 Mdot
.896 .50956 Mdot
.896 .50975 Mdot
.896 .50993 Mdot
.896 .50996 Mdot
.896 .51044 Mdot
.896 .51054 Mdot
.896 .51158 Mdot
.896 .51196 Mdot
.896 .51281 Mdot
.896 .51294 Mdot
.896 .51392 Mdot
.896 .51423 Mdot
.896 .51467 Mdot
.896 .51477 Mdot
.896 .51487 Mdot
.896 .51498 Mdot
.896 .51531 Mdot
.896 .51619 Mdot
.896 .51723 Mdot
.896 .51728 Mdot
.896 .51757 Mdot
.896 .51812 Mdot
.896 .51854 Mdot
.896 .5187 Mdot
.896 .51913 Mdot
.896 .51917 Mdot
.896 .51937 Mdot
.896 .51938 Mdot
.896 .51945 Mdot
.896 .51953 Mdot
.896 .51961 Mdot
.896 .5198 Mdot
.896 .51994 Mdot
.896 .52002 Mdot
.896 .52022 Mdot
.896 .52043 Mdot
.896 .52055 Mdot
.896 .5213 Mdot
.896 .52169 Mdot
.896 .52191 Mdot
.896 .52215 Mdot
.896 .52236 Mdot
.896 .52311 Mdot
.896 .52343 Mdot
.896 .52371 Mdot
.896 .52375 Mdot
.896 .52399 Mdot
.896 .52501 Mdot
.896 .52551 Mdot
.896 .52568 Mdot
.896 .52572 Mdot
.896 .52596 Mdot
.896 .52603 Mdot
.896 .52616 Mdot
.896 .52626 Mdot
.896 .52706 Mdot
.896 .52707 Mdot
.896 .52715 Mdot
.896 .52721 Mdot
.896 .52758 Mdot
.896 .52789 Mdot
.896 .52805 Mdot
.896 .52855 Mdot
.896 .52865 Mdot
.896 .52873 Mdot
.896 .52881 Mdot
.896 .52882 Mdot
.896 .52885 Mdot
.896 .52901 Mdot
.896 .52912 Mdot
.896 .52924 Mdot
.896 .52931 Mdot
.896 .52934 Mdot
.896 .52941 Mdot
.896 .52949 Mdot
.896 .52954 Mdot
.896 .52971 Mdot
.896 .52978 Mdot
.896 .52989 Mdot
.896 .53015 Mdot
.896 .53031 Mdot
.896 .53041 Mdot
.896 .5308 Mdot
.896 .53092 Mdot
.896 .53116 Mdot
.896 .5312 Mdot
.896 .53121 Mdot
.896 .53133 Mdot
.896 .53136 Mdot
.896 .53164 Mdot
.896 .53185 Mdot
.896 .5319 Mdot
.896 .53191 Mdot
.896 .53248 Mdot
.896 .53259 Mdot
.896 .53278 Mdot
.896 .53287 Mdot
.896 .53294 Mdot
.896 .53296 Mdot
.896 .53296 Mdot
.896 .53299 Mdot
.896 .53306 Mdot
.896 .53328 Mdot
.896 .53375 Mdot
.896 .5339 Mdot
.896 .53445 Mdot
.896 .53486 Mdot
.896 .53487 Mdot
.896 .53506 Mdot
.896 .53512 Mdot
.896 .53525 Mdot
.896 .5353 Mdot
.896 .53533 Mdot
.896 .53548 Mdot
.896 .53552 Mdot
.896 .53606 Mdot
.896 .53621 Mdot
.896 .53622 Mdot
.896 .53641 Mdot
.896 .53647 Mdot
.896 .5367 Mdot
.896 .53679 Mdot
.896 .53684 Mdot
.896 .53699 Mdot
.896 .537 Mdot
.896 .53703 Mdot
.896 .53732 Mdot
.896 .53734 Mdot
.896 .53757 Mdot
.896 .53759 Mdot
.896 .53766 Mdot
.896 .53772 Mdot
.896 .53791 Mdot
.896 .53809 Mdot
.896 .5381 Mdot
.896 .53817 Mdot
.896 .53819 Mdot
.896 .5382 Mdot
.896 .53825 Mdot
.896 .53839 Mdot
.896 .53848 Mdot
.896 .53861 Mdot
.896 .53862 Mdot
.896 .53882 Mdot
.896 .53884 Mdot
.896 .53913 Mdot
.896 .53964 Mdot
.896 .53975 Mdot
.896 .53987 Mdot
.896 .53992 Mdot
.896 .53996 Mdot
.896 .54 Mdot
.896 .54008 Mdot
.896 .54011 Mdot
.896 .5402 Mdot
.896 .54021 Mdot
.896 .54022 Mdot
.896 .54051 Mdot
.896 .54064 Mdot
.896 .54069 Mdot
.896 .54073 Mdot
.896 .54095 Mdot
.896 .54102 Mdot
.896 .54116 Mdot
.896 .54123 Mdot
.896 .54123 Mdot
.896 .54131 Mdot
.896 .54139 Mdot
.896 .54141 Mdot
.896 .54148 Mdot
.896 .54192 Mdot
.896 .54194 Mdot
.896 .54196 Mdot
.896 .542 Mdot
.896 .54201 Mdot
.896 .54203 Mdot
.896 .54205 Mdot
.896 .54207 Mdot
.896 .54207 Mdot
.896 .54208 Mdot
.896 .54209 Mdot
.896 .5421 Mdot
.896 .5421 Mdot
.896 .54211 Mdot
.896 .54211 Mdot
.896 .54213 Mdot
.896 .54213 Mdot
.898 .18123 Mdot
.898 .18125 Mdot
.898 .18128 Mdot
.898 .18135 Mdot
.898 .18138 Mdot
.898 .18141 Mdot
.898 .1815 Mdot
.898 .18156 Mdot
.898 .18165 Mdot
.898 .18174 Mdot
.898 .18182 Mdot
.898 .18195 Mdot
.898 .18209 Mdot
.898 .18212 Mdot
.898 .18216 Mdot
.898 .18224 Mdot
.898 .18242 Mdot
.898 .18262 Mdot
.898 .18265 Mdot
.898 .18275 Mdot
.898 .18277 Mdot
.898 .18289 Mdot
.898 .18307 Mdot
.898 .1831 Mdot
.898 .18315 Mdot
.898 .18324 Mdot
.898 .18334 Mdot
.898 .18335 Mdot
.898 .1834 Mdot
.898 .18385 Mdot
.898 .18423 Mdot
.898 .18447 Mdot
.898 .18455 Mdot
.898 .18532 Mdot
.898 .18537 Mdot
.898 .18545 Mdot
.898 .18555 Mdot
.898 .18606 Mdot
.898 .18629 Mdot
.898 .18632 Mdot
.898 .18659 Mdot
.898 .18688 Mdot
.898 .18761 Mdot
.898 .18763 Mdot
.898 .18774 Mdot
.898 .18802 Mdot
.898 .18888 Mdot
.898 .18941 Mdot
.898 .18964 Mdot
.898 .1897 Mdot
.898 .18999 Mdot
.898 .19002 Mdot
.898 .1901 Mdot
.898 .19032 Mdot
.898 .1913 Mdot
.898 .19224 Mdot
.898 .19276 Mdot
.898 .19331 Mdot
.898 .19394 Mdot
.898 .19441 Mdot
.898 .19466 Mdot
.898 .19484 Mdot
.898 .19494 Mdot
.898 .19567 Mdot
.898 .19598 Mdot
.898 .19655 Mdot
.898 .197 Mdot
.898 .19751 Mdot
.898 .19778 Mdot
.898 .19801 Mdot
.898 .19808 Mdot
.898 .19827 Mdot
.898 .19831 Mdot
.898 .20008 Mdot
.898 .20136 Mdot
.898 .202 Mdot
.898 .20208 Mdot
.898 .20229 Mdot
.898 .20232 Mdot
.898 .20295 Mdot
.898 .20326 Mdot
.898 .20396 Mdot
.898 .20464 Mdot
.898 .20586 Mdot
.898 .20654 Mdot
.898 .20682 Mdot
.898 .20686 Mdot
.898 .20721 Mdot
.898 .20726 Mdot
.898 .20734 Mdot
.898 .20744 Mdot
.898 .2076 Mdot
.898 .20785 Mdot
.898 .20815 Mdot
.898 .20891 Mdot
.898 .20953 Mdot
.898 .21037 Mdot
.898 .21122 Mdot
.898 .21152 Mdot
.898 .21382 Mdot
.898 .21395 Mdot
.898 .21398 Mdot
.898 .215 Mdot
.898 .21532 Mdot
.898 .21672 Mdot
.898 .21685 Mdot
.898 .21809 Mdot
.898 .21828 Mdot
.898 .21862 Mdot
.898 .21901 Mdot
.898 .21909 Mdot
.898 .21928 Mdot
.898 .2196 Mdot
.898 .22018 Mdot
.898 .22069 Mdot
.898 .22126 Mdot
.898 .22188 Mdot
.898 .22301 Mdot
.898 .22331 Mdot
.898 .22397 Mdot
.898 .22402 Mdot
.898 .22527 Mdot
.898 .22534 Mdot
.898 .22547 Mdot
.898 .22587 Mdot
.898 .23007 Mdot
.898 .23012 Mdot
.898 .23199 Mdot
.898 .23214 Mdot
.898 .23306 Mdot
.898 .23374 Mdot
.898 .23581 Mdot
.898 .2359 Mdot
.898 .23711 Mdot
.898 .23717 Mdot
.898 .23777 Mdot
.898 .23817 Mdot
.898 .23846 Mdot
.898 .23847 Mdot
.898 .23951 Mdot
.898 .23979 Mdot
.898 .23991 Mdot
.898 .23993 Mdot
.898 .24037 Mdot
.898 .24107 Mdot
.898 .24167 Mdot
.898 .24171 Mdot
.898 .24197 Mdot
.898 .24275 Mdot
.898 .24279 Mdot
.898 .24288 Mdot
.898 .24297 Mdot
.898 .24304 Mdot
.898 .24312 Mdot
.898 .24366 Mdot
.898 .24393 Mdot
.898 .24415 Mdot
.898 .2445 Mdot
.898 .24621 Mdot
.898 .24682 Mdot
.898 .2471 Mdot
.898 .24731 Mdot
.898 .24768 Mdot
.898 .2483 Mdot
.898 .24899 Mdot
.898 .24942 Mdot
.898 .25034 Mdot
.898 .2513 Mdot
.898 .25285 Mdot
.898 .25291 Mdot
.898 .2534 Mdot
.898 .2537 Mdot
.898 .25425 Mdot
.898 .25426 Mdot
.898 .25432 Mdot
.898 .25511 Mdot
.898 .2556 Mdot
.898 .25623 Mdot
.898 .25627 Mdot
.898 .25765 Mdot
.898 .2582 Mdot
.898 .25917 Mdot
.898 .26166 Mdot
.898 .26173 Mdot
.898 .26246 Mdot
.898 .26249 Mdot
.898 .26286 Mdot
.898 .26303 Mdot
.898 .26367 Mdot
.898 .26465 Mdot
.898 .26498 Mdot
.898 .26517 Mdot
.898 .26533 Mdot
.898 .26556 Mdot
.898 .26576 Mdot
.898 .26587 Mdot
.898 .26756 Mdot
.898 .26776 Mdot
.898 .26839 Mdot
.898 .2685 Mdot
.898 .26997 Mdot
.898 .27017 Mdot
.898 .2713 Mdot
.898 .27172 Mdot
.898 .27281 Mdot
.898 .27286 Mdot
.898 .2729 Mdot
.898 .27314 Mdot
.898 .27317 Mdot
.898 .27386 Mdot
.898 .27475 Mdot
.898 .27526 Mdot
.898 .27651 Mdot
.898 .27653 Mdot
.898 .27669 Mdot
.898 .27727 Mdot
.898 .2783 Mdot
.898 .27983 Mdot
.898 .27999 Mdot
.898 .28025 Mdot
.898 .28049 Mdot
.898 .28216 Mdot
.898 .28285 Mdot
.898 .28312 Mdot
.898 .28336 Mdot
.898 .28383 Mdot
.898 .28446 Mdot
.898 .28809 Mdot
.898 .28883 Mdot
.898 .29062 Mdot
.898 .2931 Mdot
.898 .29314 Mdot
.898 .29351 Mdot
.898 .29465 Mdot
.898 .29473 Mdot
.898 .29759 Mdot
.898 .29861 Mdot
.898 .29874 Mdot
.898 .29874 Mdot
.898 .29901 Mdot
.898 .29936 Mdot
.898 .29992 Mdot
.898 .30488 Mdot
.898 .30523 Mdot
.898 .30715 Mdot
.898 .30802 Mdot
.898 .31045 Mdot
.898 .3116 Mdot
.898 .31195 Mdot
.898 .31215 Mdot
.898 .3137 Mdot
.898 .31415 Mdot
.898 .3145 Mdot
.898 .31509 Mdot
.898 .31562 Mdot
.898 .31572 Mdot
.898 .31589 Mdot
.898 .31618 Mdot
.898 .31678 Mdot
.898 .31739 Mdot
.898 .31749 Mdot
.898 .31776 Mdot
.898 .31782 Mdot
.898 .31862 Mdot
.898 .31883 Mdot
.898 .32127 Mdot
.898 .32175 Mdot
.898 .32191 Mdot
.898 .32355 Mdot
.898 .32371 Mdot
.898 .32538 Mdot
.898 .32582 Mdot
.898 .32687 Mdot
.898 .3269 Mdot
.898 .32705 Mdot
.898 .32856 Mdot
.898 .32951 Mdot
.898 .32959 Mdot
.898 .32993 Mdot
.898 .33007 Mdot
.898 .33032 Mdot
.898 .33145 Mdot
.898 .33248 Mdot
.898 .33302 Mdot
.898 .33512 Mdot
.898 .33619 Mdot
.898 .33671 Mdot
.898 .33712 Mdot
.898 .33801 Mdot
.898 .33826 Mdot
.898 .3413 Mdot
.898 .34204 Mdot
.898 .34227 Mdot
.898 .34469 Mdot
.898 .34533 Mdot
.898 .34543 Mdot
.898 .34561 Mdot
.898 .34581 Mdot
.898 .34733 Mdot
.898 .34964 Mdot
.898 .35136 Mdot
.898 .35144 Mdot
.898 .35278 Mdot
.898 .35371 Mdot
.898 .35404 Mdot
.898 .35629 Mdot
.898 .35662 Mdot
.898 .35886 Mdot
.898 .35993 Mdot
.898 .36075 Mdot
.898 .36243 Mdot
.898 .36275 Mdot
.898 .36309 Mdot
.898 .3631 Mdot
.898 .3636 Mdot
.898 .36402 Mdot
.898 .36464 Mdot
.898 .36478 Mdot
.898 .36517 Mdot
.898 .36525 Mdot
.898 .36529 Mdot
.898 .36532 Mdot
.898 .36558 Mdot
.898 .3657 Mdot
.898 .36581 Mdot
.898 .36597 Mdot
.898 .36704 Mdot
.898 .36717 Mdot
.898 .36727 Mdot
.898 .36744 Mdot
.898 .36803 Mdot
.898 .36823 Mdot
.898 .36978 Mdot
.898 .37 Mdot
.898 .37014 Mdot
.898 .37038 Mdot
.898 .37041 Mdot
.898 .37126 Mdot
.898 .37209 Mdot
.898 .3725 Mdot
.898 .37359 Mdot
.898 .37389 Mdot
.898 .37406 Mdot
.898 .3748 Mdot
.898 .376 Mdot
.898 .37707 Mdot
.898 .37752 Mdot
.898 .37816 Mdot
.898 .37826 Mdot
.898 .3789 Mdot
.898 .3791 Mdot
.898 .37966 Mdot
.898 .38105 Mdot
.898 .38114 Mdot
.898 .38179 Mdot
.898 .38205 Mdot
.898 .38243 Mdot
.898 .38267 Mdot
.898 .38404 Mdot
.898 .38593 Mdot
.898 .38649 Mdot
.898 .38652 Mdot
.898 .38757 Mdot
.898 .38799 Mdot
.898 .38808 Mdot
.898 .38821 Mdot
.898 .38842 Mdot
.898 .3902 Mdot
.898 .39033 Mdot
.898 .39101 Mdot
.898 .39132 Mdot
.898 .39333 Mdot
.898 .39349 Mdot
.898 .39361 Mdot
.898 .39381 Mdot
.898 .394 Mdot
.898 .3942 Mdot
.898 .39441 Mdot
.898 .39462 Mdot
.898 .39465 Mdot
.898 .39477 Mdot
.898 .39511 Mdot
.898 .39596 Mdot
.898 .39612 Mdot
.898 .39674 Mdot
.898 .39752 Mdot
.898 .39789 Mdot
.898 .39794 Mdot
.898 .3988 Mdot
.898 .39892 Mdot
.898 .40067 Mdot
.898 .40164 Mdot
.898 .40173 Mdot
.898 .40299 Mdot
.898 .40387 Mdot
.898 .40417 Mdot
.898 .40474 Mdot
.898 .4055 Mdot
.898 .40607 Mdot
.898 .4061 Mdot
.898 .40695 Mdot
.898 .4078 Mdot
.898 .40888 Mdot
.898 .4097 Mdot
.898 .4098 Mdot
.898 .40991 Mdot
.898 .41008 Mdot
.898 .41041 Mdot
.898 .41059 Mdot
.898 .41063 Mdot
.898 .41064 Mdot
.898 .41076 Mdot
.898 .41127 Mdot
.898 .41132 Mdot
.898 .41158 Mdot
.898 .41209 Mdot
.898 .41216 Mdot
.898 .41228 Mdot
.898 .41229 Mdot
.898 .41256 Mdot
.898 .41283 Mdot
.898 .41297 Mdot
.898 .41332 Mdot
.898 .41347 Mdot
.898 .41371 Mdot
.898 .41445 Mdot
.898 .41459 Mdot
.898 .41483 Mdot
.898 .41504 Mdot
.898 .41529 Mdot
.898 .41618 Mdot
.898 .41626 Mdot
.898 .41731 Mdot
.898 .41749 Mdot
.898 .4175 Mdot
.898 .41784 Mdot
.898 .41801 Mdot
.898 .41805 Mdot
.898 .41811 Mdot
.898 .41869 Mdot
.898 .41873 Mdot
.898 .41895 Mdot
.898 .41905 Mdot
.898 .4197 Mdot
.898 .41986 Mdot
.898 .41992 Mdot
.898 .42012 Mdot
.898 .42013 Mdot
.898 .42017 Mdot
.898 .42061 Mdot
.898 .42081 Mdot
.898 .42118 Mdot
.898 .42119 Mdot
.898 .42147 Mdot
.898 .42242 Mdot
.898 .42283 Mdot
.898 .42383 Mdot
.898 .42384 Mdot
.898 .42439 Mdot
.898 .42501 Mdot
.898 .42504 Mdot
.898 .42508 Mdot
.898 .42513 Mdot
.898 .42524 Mdot
.898 .42531 Mdot
.898 .42532 Mdot
.898 .42536 Mdot
.898 .42552 Mdot
.898 .42554 Mdot
.898 .42562 Mdot
.898 .42579 Mdot
.898 .42585 Mdot
.898 .42586 Mdot
.898 .42595 Mdot
.898 .42603 Mdot
.898 .42608 Mdot
.898 .42619 Mdot
.898 .42624 Mdot
.898 .42632 Mdot
.898 .42656 Mdot
.898 .42661 Mdot
.898 .42669 Mdot
.898 .42684 Mdot
.898 .42713 Mdot
.898 .42715 Mdot
.898 .4275 Mdot
.898 .42756 Mdot
.898 .42756 Mdot
.898 .42767 Mdot
.898 .42773 Mdot
.898 .42776 Mdot
.898 .42797 Mdot
.898 .42829 Mdot
.898 .42834 Mdot
.898 .42843 Mdot
.898 .42844 Mdot
.898 .42858 Mdot
.898 .42877 Mdot
.898 .42878 Mdot
.898 .42887 Mdot
.898 .42932 Mdot
.898 .42965 Mdot
.898 .42965 Mdot
.898 .42983 Mdot
.898 .43014 Mdot
.898 .43021 Mdot
.898 .43032 Mdot
.898 .43038 Mdot
.898 .43074 Mdot
.898 .43088 Mdot
.898 .43092 Mdot
.898 .43158 Mdot
.898 .43164 Mdot
.898 .43182 Mdot
.898 .43222 Mdot
.898 .43224 Mdot
.898 .4323 Mdot
.898 .43244 Mdot
.898 .43261 Mdot
.898 .43272 Mdot
.898 .43296 Mdot
.898 .43307 Mdot
.898 .43311 Mdot
.898 .43348 Mdot
.898 .4338 Mdot
.898 .43389 Mdot
.898 .43393 Mdot
.898 .43411 Mdot
.898 .43421 Mdot
.898 .4344 Mdot
.898 .4349 Mdot
.898 .43534 Mdot
.898 .4354 Mdot
.898 .43565 Mdot
.898 .43615 Mdot
.898 .43618 Mdot
.898 .43627 Mdot
.898 .43637 Mdot
.898 .43637 Mdot
.898 .43654 Mdot
.898 .43667 Mdot
.898 .43684 Mdot
.898 .43719 Mdot
.898 .4375 Mdot
.898 .43751 Mdot
.898 .43806 Mdot
.898 .43829 Mdot
.898 .43882 Mdot
.898 .43897 Mdot
.898 .43898 Mdot
.898 .43919 Mdot
.898 .4393 Mdot
.898 .43954 Mdot
.898 .43956 Mdot
.898 .43957 Mdot
.898 .43968 Mdot
.898 .43971 Mdot
.898 .4398 Mdot
.898 .44016 Mdot
.898 .44021 Mdot
.898 .44033 Mdot
.898 .44036 Mdot
.898 .44067 Mdot
.898 .44071 Mdot
.898 .44073 Mdot
.898 .44082 Mdot
.898 .44101 Mdot
.898 .44101 Mdot
.898 .44111 Mdot
.898 .44169 Mdot
.898 .44173 Mdot
.898 .44222 Mdot
.898 .44235 Mdot
.898 .44246 Mdot
.898 .44259 Mdot
.898 .44267 Mdot
.898 .44307 Mdot
.898 .4432 Mdot
.898 .44328 Mdot
.898 .44347 Mdot
.898 .44354 Mdot
.898 .44369 Mdot
.898 .44384 Mdot
.898 .44384 Mdot
.898 .44391 Mdot
.898 .44395 Mdot
.898 .44422 Mdot
.898 .44435 Mdot
.898 .44438 Mdot
.898 .44466 Mdot
.898 .44472 Mdot
.898 .44473 Mdot
.898 .44475 Mdot
.898 .44484 Mdot
.898 .44502 Mdot
.898 .44511 Mdot
.898 .44517 Mdot
.898 .44523 Mdot
.898 .44566 Mdot
.898 .44624 Mdot
.898 .44668 Mdot
.898 .44713 Mdot
.898 .44715 Mdot
.898 .44745 Mdot
.898 .44785 Mdot
.898 .44815 Mdot
.898 .44831 Mdot
.898 .44877 Mdot
.898 .44942 Mdot
.898 .44947 Mdot
.898 .44997 Mdot
.898 .45088 Mdot
.898 .45094 Mdot
.898 .45138 Mdot
.898 .45141 Mdot
.898 .4516 Mdot
.898 .452 Mdot
.898 .45232 Mdot
.898 .4524 Mdot
.898 .45283 Mdot
.898 .45301 Mdot
.898 .45307 Mdot
.898 .45309 Mdot
.898 .45319 Mdot
.898 .4533 Mdot
.898 .4534 Mdot
.898 .45349 Mdot
.898 .4536 Mdot
.898 .45366 Mdot
.898 .45374 Mdot
.898 .45476 Mdot
.898 .45491 Mdot
.898 .45526 Mdot
.898 .45532 Mdot
.898 .45622 Mdot
.898 .45632 Mdot
.898 .45639 Mdot
.898 .45643 Mdot
.898 .45664 Mdot
.898 .45717 Mdot
.898 .45718 Mdot
.898 .45746 Mdot
.898 .4584 Mdot
.898 .45908 Mdot
.898 .4592 Mdot
.898 .45938 Mdot
.898 .45951 Mdot
.898 .45983 Mdot
.898 .45987 Mdot
.898 .46056 Mdot
.898 .46083 Mdot
.898 .46093 Mdot
.898 .46124 Mdot
.898 .46129 Mdot
.898 .4616 Mdot
.898 .46183 Mdot
.898 .46234 Mdot
.898 .46292 Mdot
.898 .46328 Mdot
.898 .46336 Mdot
.898 .46351 Mdot
.898 .46403 Mdot
.898 .46423 Mdot
.898 .46463 Mdot
.898 .46504 Mdot
.898 .46506 Mdot
.898 .46517 Mdot
.898 .46524 Mdot
.898 .46534 Mdot
.898 .46608 Mdot
.898 .46618 Mdot
.898 .46646 Mdot
.898 .46654 Mdot
.898 .46659 Mdot
.898 .46665 Mdot
.898 .46716 Mdot
.898 .46723 Mdot
.898 .46728 Mdot
.898 .46734 Mdot
.898 .46746 Mdot
.898 .46748 Mdot
.898 .4675 Mdot
.898 .46754 Mdot
.898 .46772 Mdot
.898 .46779 Mdot
.898 .46808 Mdot
.898 .46828 Mdot
.898 .46852 Mdot
.898 .46852 Mdot
.898 .46868 Mdot
.898 .46883 Mdot
.898 .46962 Mdot
.898 .47 Mdot
.898 .4705 Mdot
.898 .47155 Mdot
.898 .4717 Mdot
.898 .47274 Mdot
.898 .4729 Mdot
.898 .47333 Mdot
.898 .47394 Mdot
.898 .47398 Mdot
.898 .47477 Mdot
.898 .47583 Mdot
.898 .47651 Mdot
.898 .47661 Mdot
.898 .47669 Mdot
.898 .47674 Mdot
.898 .47703 Mdot
.898 .47812 Mdot
.898 .47822 Mdot
.898 .47856 Mdot
.898 .47992 Mdot
.898 .48004 Mdot
.898 .48044 Mdot
.898 .48062 Mdot
.898 .48085 Mdot
.898 .48133 Mdot
.898 .48226 Mdot
.898 .4825 Mdot
.898 .48296 Mdot
.898 .48346 Mdot
.898 .48357 Mdot
.898 .48363 Mdot
.898 .48378 Mdot
.898 .48382 Mdot
.898 .48423 Mdot
.898 .4849 Mdot
.898 .48497 Mdot
.898 .48498 Mdot
.898 .48544 Mdot
.898 .48563 Mdot
.898 .48636 Mdot
.898 .48643 Mdot
.898 .48715 Mdot
.898 .48722 Mdot
.898 .48743 Mdot
.898 .48849 Mdot
.898 .48857 Mdot
.898 .48892 Mdot
.898 .48895 Mdot
.898 .48907 Mdot
.898 .48911 Mdot
.898 .48937 Mdot
.898 .48963 Mdot
.898 .48976 Mdot
.898 .48983 Mdot
.898 .48987 Mdot
.898 .4901 Mdot
.898 .49036 Mdot
.898 .49051 Mdot
.898 .4907 Mdot
.898 .49136 Mdot
.898 .49145 Mdot
.898 .4916 Mdot
.898 .49209 Mdot
.898 .49313 Mdot
.898 .4935 Mdot
.898 .49431 Mdot
.898 .49447 Mdot
.898 .49656 Mdot
.898 .4968 Mdot
.898 .49694 Mdot
.898 .49706 Mdot
.898 .49706 Mdot
.898 .49711 Mdot
.898 .49754 Mdot
.898 .49874 Mdot
.898 .49877 Mdot
.898 .49925 Mdot
.898 .4994 Mdot
.898 .49942 Mdot
.898 .50045 Mdot
.898 .50119 Mdot
.898 .5015 Mdot
.898 .503 Mdot
.898 .50326 Mdot
.898 .50345 Mdot
.898 .50355 Mdot
.898 .50366 Mdot
.898 .50394 Mdot
.898 .50463 Mdot
.898 .50473 Mdot
.898 .50484 Mdot
.898 .5049 Mdot
.898 .50553 Mdot
.898 .50595 Mdot
.898 .50618 Mdot
.898 .50625 Mdot
.898 .50626 Mdot
.898 .50677 Mdot
.898 .50698 Mdot
.898 .50734 Mdot
.898 .50762 Mdot
.898 .50763 Mdot
.898 .50773 Mdot
.898 .50775 Mdot
.898 .50777 Mdot
.898 .50821 Mdot
.898 .50838 Mdot
.898 .50884 Mdot
.898 .50892 Mdot
.898 .50951 Mdot
.898 .50955 Mdot
.898 .50981 Mdot
.898 .50989 Mdot
.898 .51057 Mdot
.898 .51062 Mdot
.898 .5107 Mdot
.898 .51079 Mdot
.898 .51085 Mdot
.898 .51093 Mdot
.898 .51107 Mdot
.898 .51146 Mdot
.898 .51172 Mdot
.898 .51178 Mdot
.898 .51193 Mdot
.898 .51194 Mdot
.898 .51224 Mdot
.898 .51226 Mdot
.898 .51326 Mdot
.898 .51365 Mdot
.898 .51387 Mdot
.898 .51442 Mdot
.898 .51444 Mdot
.898 .51469 Mdot
.898 .51488 Mdot
.898 .51519 Mdot
.898 .51522 Mdot
.898 .51522 Mdot
.898 .51544 Mdot
.898 .51556 Mdot
.898 .51576 Mdot
.898 .51578 Mdot
.898 .5164 Mdot
.898 .51678 Mdot
.898 .51714 Mdot
.898 .51731 Mdot
.898 .51758 Mdot
.898 .51783 Mdot
.898 .51797 Mdot
.898 .51806 Mdot
.898 .51817 Mdot
.898 .51841 Mdot
.898 .51908 Mdot
.898 .51922 Mdot
.898 .5193 Mdot
.898 .51941 Mdot
.898 .51962 Mdot
.898 .51966 Mdot
.898 .51968 Mdot
.898 .51972 Mdot
.898 .51975 Mdot
.898 .51977 Mdot
.898 .52007 Mdot
.898 .52018 Mdot
.898 .52019 Mdot
.898 .52043 Mdot
.898 .5207 Mdot
.898 .52087 Mdot
.898 .52088 Mdot
.898 .52093 Mdot
.898 .52104 Mdot
.898 .52145 Mdot
.898 .52145 Mdot
.898 .52156 Mdot
.898 .52172 Mdot
.898 .52195 Mdot
.898 .52198 Mdot
.898 .52245 Mdot
.898 .52249 Mdot
.898 .52329 Mdot
.898 .52356 Mdot
.898 .52391 Mdot
.898 .52397 Mdot
.898 .5247 Mdot
.898 .52472 Mdot
.898 .52635 Mdot
.898 .5265 Mdot
.898 .52655 Mdot
.898 .52658 Mdot
.898 .52706 Mdot
.898 .52708 Mdot
.898 .52733 Mdot
.898 .52745 Mdot
.898 .52789 Mdot
.898 .52813 Mdot
.898 .52835 Mdot
.898 .52854 Mdot
.898 .52876 Mdot
.898 .52889 Mdot
.898 .52896 Mdot
.898 .52899 Mdot
.898 .52914 Mdot
.898 .52927 Mdot
.898 .52934 Mdot
.898 .52982 Mdot
.898 .52987 Mdot
.898 .53041 Mdot
.898 .53053 Mdot
.898 .53092 Mdot
.898 .53093 Mdot
.898 .53098 Mdot
.898 .53186 Mdot
.898 .53198 Mdot
.898 .5323 Mdot
.898 .53262 Mdot
.898 .53286 Mdot
.898 .53315 Mdot
.898 .53326 Mdot
.898 .53336 Mdot
.898 .53342 Mdot
.898 .53346 Mdot
.898 .53348 Mdot
.898 .5335 Mdot
.898 .53364 Mdot
.898 .53365 Mdot
.898 .53376 Mdot
.898 .53402 Mdot
.898 .53448 Mdot
.898 .53474 Mdot
.898 .53501 Mdot
.898 .53512 Mdot
.898 .53536 Mdot
.898 .53537 Mdot
.898 .53545 Mdot
.898 .53548 Mdot
.898 .53573 Mdot
.898 .53621 Mdot
.898 .53688 Mdot
.898 .5369 Mdot
.898 .53697 Mdot
.898 .53699 Mdot
.898 .53708 Mdot
.898 .53718 Mdot
.898 .53737 Mdot
.898 .53755 Mdot
.898 .53776 Mdot
.898 .53788 Mdot
.898 .53815 Mdot
.898 .53819 Mdot
.898 .53826 Mdot
.898 .53835 Mdot
.898 .53853 Mdot
.898 .53876 Mdot
.898 .53897 Mdot
.898 .53917 Mdot
.898 .53952 Mdot
.898 .53989 Mdot
.898 .53997 Mdot
.898 .54 Mdot
.898 .54002 Mdot
.898 .54012 Mdot
.898 .54015 Mdot
.898 .54023 Mdot
.898 .54043 Mdot
.898 .54075 Mdot
.898 .54086 Mdot
.898 .5409 Mdot
.898 .54091 Mdot
.898 .54118 Mdot
.898 .54129 Mdot
.898 .54139 Mdot
.898 .5414 Mdot
.898 .54149 Mdot
.898 .54168 Mdot
.898 .54172 Mdot
.898 .54175 Mdot
.898 .54177 Mdot
.898 .54205 Mdot
.898 .54208 Mdot
.898 .54218 Mdot
.898 .54232 Mdot
.898 .54249 Mdot
.898 .54251 Mdot
.898 .54251 Mdot
.898 .54255 Mdot
.898 .54258 Mdot
.898 .5426 Mdot
.898 .54261 Mdot
.898 .54268 Mdot
.898 .54272 Mdot
.898 .54273 Mdot
.898 .54276 Mdot
.898 .54278 Mdot
.898 .54285 Mdot
.898 .54292 Mdot
.898 .54295 Mdot
.898 .54297 Mdot
.898 .54298 Mdot
.898 .54303 Mdot
.898 .54308 Mdot
.898 .54311 Mdot
.898 .54314 Mdot
.898 .54317 Mdot
.898 .54319 Mdot
.898 .54323 Mdot
.898 .54324 Mdot
.898 .54325 Mdot
.898 .54328 Mdot
.898 .54329 Mdot
.898 .5433 Mdot
.9 .17847 Mdot
.9 .17847 Mdot
.9 .17847 Mdot
.9 .17857 Mdot
.9 .17858 Mdot
.9 .17866 Mdot
.9 .17868 Mdot
.9 .17872 Mdot
.9 .17886 Mdot
.9 .17888 Mdot
.9 .1789 Mdot
.9 .17895 Mdot
.9 .17959 Mdot
.9 .17961 Mdot
.9 .17973 Mdot
.9 .17975 Mdot
.9 .18015 Mdot
.9 .18067 Mdot
.9 .18077 Mdot
.9 .18088 Mdot
.9 .18094 Mdot
.9 .181 Mdot
.9 .18101 Mdot
.9 .18106 Mdot
.9 .18111 Mdot
.9 .18116 Mdot
.9 .18131 Mdot
.9 .18134 Mdot
.9 .18147 Mdot
.9 .18164 Mdot
.9 .18167 Mdot
.9 .18179 Mdot
.9 .18186 Mdot
.9 .18195 Mdot
.9 .18195 Mdot
.9 .18206 Mdot
.9 .18216 Mdot
.9 .18229 Mdot
.9 .18267 Mdot
.9 .18292 Mdot
.9 .18329 Mdot
.9 .18396 Mdot
.9 .18396 Mdot
.9 .18487 Mdot
.9 .18504 Mdot
.9 .18513 Mdot
.9 .1852 Mdot
.9 .18534 Mdot
.9 .18574 Mdot
.9 .18585 Mdot
.9 .18599 Mdot
.9 .18606 Mdot
.9 .18628 Mdot
.9 .18631 Mdot
.9 .18675 Mdot
.9 .18676 Mdot
.9 .18692 Mdot
.9 .18784 Mdot
.9 .1882 Mdot
.9 .18864 Mdot
.9 .18967 Mdot
.9 .18968 Mdot
.9 .18979 Mdot
.9 .18992 Mdot
.9 .18998 Mdot
.9 .19083 Mdot
.9 .19091 Mdot
.9 .19098 Mdot
.9 .19156 Mdot
.9 .19158 Mdot
.9 .19167 Mdot
.9 .19282 Mdot
.9 .19359 Mdot
.9 .19375 Mdot
.9 .19534 Mdot
.9 .19574 Mdot
.9 .19596 Mdot
.9 .19619 Mdot
.9 .19651 Mdot
.9 .1968 Mdot
.9 .19714 Mdot
.9 .19793 Mdot
.9 .19864 Mdot
.9 .19886 Mdot
.9 .19976 Mdot
.9 .20022 Mdot
.9 .20051 Mdot
.9 .20117 Mdot
.9 .20253 Mdot
.9 .20288 Mdot
.9 .2029 Mdot
.9 .20294 Mdot
.9 .20314 Mdot
.9 .2039 Mdot
.9 .20544 Mdot
.9 .20546 Mdot
.9 .2073 Mdot
.9 .20792 Mdot
.9 .20798 Mdot
.9 .20818 Mdot
.9 .20818 Mdot
.9 .2087 Mdot
.9 .20955 Mdot
.9 .21005 Mdot
.9 .21117 Mdot
.9 .21292 Mdot
.9 .21434 Mdot
.9 .21451 Mdot
.9 .21588 Mdot
.9 .217 Mdot
.9 .21725 Mdot
.9 .21767 Mdot
.9 .22105 Mdot
.9 .22159 Mdot
.9 .22188 Mdot
.9 .22192 Mdot
.9 .22253 Mdot
.9 .22307 Mdot
.9 .22411 Mdot
.9 .22439 Mdot
.9 .22454 Mdot
.9 .22478 Mdot
.9 .22521 Mdot
.9 .22624 Mdot
.9 .22841 Mdot
.9 .22981 Mdot
.9 .23023 Mdot
.9 .2305 Mdot
.9 .23221 Mdot
.9 .23229 Mdot
.9 .2326 Mdot
.9 .23282 Mdot
.9 .23302 Mdot
.9 .23303 Mdot
.9 .2331 Mdot
.9 .23384 Mdot
.9 .2343 Mdot
.9 .23435 Mdot
.9 .2347 Mdot
.9 .23543 Mdot
.9 .23649 Mdot
.9 .23667 Mdot
.9 .23712 Mdot
.9 .23734 Mdot
.9 .23858 Mdot
.9 .23865 Mdot
.9 .24037 Mdot
.9 .24226 Mdot
.9 .2436 Mdot
.9 .24392 Mdot
.9 .2443 Mdot
.9 .24626 Mdot
.9 .24806 Mdot
.9 .24845 Mdot
.9 .24889 Mdot
.9 .24923 Mdot
.9 .25021 Mdot
.9 .2511 Mdot
.9 .25127 Mdot
.9 .25142 Mdot
.9 .25435 Mdot
.9 .25446 Mdot
.9 .25527 Mdot
.9 .25642 Mdot
.9 .25655 Mdot
.9 .25666 Mdot
.9 .25682 Mdot
.9 .25786 Mdot
.9 .25992 Mdot
.9 .26082 Mdot
.9 .2609 Mdot
.9 .26105 Mdot
.9 .26161 Mdot
.9 .26242 Mdot
.9 .26272 Mdot
.9 .26463 Mdot
.9 .26488 Mdot
.9 .2665 Mdot
.9 .26746 Mdot
.9 .26854 Mdot
.9 .26957 Mdot
.9 .27012 Mdot
.9 .27046 Mdot
.9 .27046 Mdot
.9 .2706 Mdot
.9 .27064 Mdot
.9 .27231 Mdot
.9 .27338 Mdot
.9 .27392 Mdot
.9 .27407 Mdot
.9 .2741 Mdot
.9 .27411 Mdot
.9 .27437 Mdot
.9 .27714 Mdot
.9 .27731 Mdot
.9 .27789 Mdot
.9 .27905 Mdot
.9 .27931 Mdot
.9 .27951 Mdot
.9 .2823 Mdot
.9 .28349 Mdot
.9 .2835 Mdot
.9 .28423 Mdot
.9 .28516 Mdot
.9 .28529 Mdot
.9 .28653 Mdot
.9 .28703 Mdot
.9 .28853 Mdot
.9 .28872 Mdot
.9 .28873 Mdot
.9 .28928 Mdot
.9 .28932 Mdot
.9 .28986 Mdot
.9 .29001 Mdot
.9 .29073 Mdot
.9 .29094 Mdot
.9 .29249 Mdot
.9 .29562 Mdot
.9 .29584 Mdot
.9 .29613 Mdot
.9 .29636 Mdot
.9 .29643 Mdot
.9 .29675 Mdot
.9 .29708 Mdot
.9 .2974 Mdot
.9 .29751 Mdot
.9 .30092 Mdot
.9 .30099 Mdot
.9 .30143 Mdot
.9 .30393 Mdot
.9 .30418 Mdot
.9 .30427 Mdot
.9 .30622 Mdot
.9 .30743 Mdot
.9 .30755 Mdot
.9 .31052 Mdot
.9 .31175 Mdot
.9 .31245 Mdot
.9 .31262 Mdot
.9 .31287 Mdot
.9 .31368 Mdot
.9 .31668 Mdot
.9 .31828 Mdot
.9 .31956 Mdot
.9 .31979 Mdot
.9 .32004 Mdot
.9 .32018 Mdot
.9 .32031 Mdot
.9 .32032 Mdot
.9 .32044 Mdot
.9 .32102 Mdot
.9 .32206 Mdot
.9 .32223 Mdot
.9 .32261 Mdot
.9 .32284 Mdot
.9 .32351 Mdot
.9 .32393 Mdot
.9 .32454 Mdot
.9 .32557 Mdot
.9 .32688 Mdot
.9 .32724 Mdot
.9 .32752 Mdot
.9 .32837 Mdot
.9 .32846 Mdot
.9 .33062 Mdot
.9 .33264 Mdot
.9 .33265 Mdot
.9 .33296 Mdot
.9 .3339 Mdot
.9 .33397 Mdot
.9 .33466 Mdot
.9 .33646 Mdot
.9 .33661 Mdot
.9 .33801 Mdot
.9 .33836 Mdot
.9 .33925 Mdot
.9 .33953 Mdot
.9 .34162 Mdot
.9 .34197 Mdot
.9 .34219 Mdot
.9 .34269 Mdot
.9 .34576 Mdot
.9 .34701 Mdot
.9 .34881 Mdot
.9 .35146 Mdot
.9 .35238 Mdot
.9 .35303 Mdot
.9 .35579 Mdot
.9 .35582 Mdot
.9 .35615 Mdot
.9 .35737 Mdot
.9 .35759 Mdot
.9 .35927 Mdot
.9 .35999 Mdot
.9 .36034 Mdot
.9 .3612 Mdot
.9 .3616 Mdot
.9 .36161 Mdot
.9 .36201 Mdot
.9 .36223 Mdot
.9 .36226 Mdot
.9 .36243 Mdot
.9 .3633 Mdot
.9 .36338 Mdot
.9 .3643 Mdot
.9 .36433 Mdot
.9 .36514 Mdot
.9 .36602 Mdot
.9 .36866 Mdot
.9 .36902 Mdot
.9 .37007 Mdot
.9 .37013 Mdot
.9 .3714 Mdot
.9 .37145 Mdot
.9 .37229 Mdot
.9 .37234 Mdot
.9 .37239 Mdot
.9 .37246 Mdot
.9 .37289 Mdot
.9 .37417 Mdot
.9 .37423 Mdot
.9 .3748 Mdot
.9 .37492 Mdot
.9 .3757 Mdot
.9 .37646 Mdot
.9 .37684 Mdot
.9 .37728 Mdot
.9 .37791 Mdot
.9 .37804 Mdot
.9 .37804 Mdot
.9 .3781 Mdot
.9 .37811 Mdot
.9 .37877 Mdot
.9 .37919 Mdot
.9 .37946 Mdot
.9 .37947 Mdot
.9 .37958 Mdot
.9 .38149 Mdot
.9 .38308 Mdot
.9 .38308 Mdot
.9 .3844 Mdot
.9 .38525 Mdot
.9 .38551 Mdot
.9 .38642 Mdot
.9 .38764 Mdot
.9 .38774 Mdot
.9 .38785 Mdot
.9 .38797 Mdot
.9 .38809 Mdot
.9 .3882 Mdot
.9 .38947 Mdot
.9 .38949 Mdot
.9 .39054 Mdot
.9 .39063 Mdot
.9 .39066 Mdot
.9 .39135 Mdot
.9 .39177 Mdot
.9 .39358 Mdot
.9 .39597 Mdot
.9 .39605 Mdot
.9 .39623 Mdot
.9 .39623 Mdot
.9 .39627 Mdot
.9 .39682 Mdot
.9 .39688 Mdot
.9 .39709 Mdot
.9 .39732 Mdot
.9 .39746 Mdot
.9 .39767 Mdot
.9 .39801 Mdot
.9 .39846 Mdot
.9 .39858 Mdot
.9 .39867 Mdot
.9 .39896 Mdot
.9 .39899 Mdot
.9 .39971 Mdot
.9 .40039 Mdot
.9 .40049 Mdot
.9 .40083 Mdot
.9 .40166 Mdot
.9 .40171 Mdot
.9 .40229 Mdot
.9 .40258 Mdot
.9 .40267 Mdot
.9 .40336 Mdot
.9 .40348 Mdot
.9 .40473 Mdot
.9 .40572 Mdot
.9 .40659 Mdot
.9 .4071 Mdot
.9 .40799 Mdot
.9 .40811 Mdot
.9 .40858 Mdot
.9 .40912 Mdot
.9 .40947 Mdot
.9 .40974 Mdot
.9 .41001 Mdot
.9 .41009 Mdot
.9 .41042 Mdot
.9 .41045 Mdot
.9 .41074 Mdot
.9 .41102 Mdot
.9 .4113 Mdot
.9 .41215 Mdot
.9 .41226 Mdot
.9 .41303 Mdot
.9 .41304 Mdot
.9 .41331 Mdot
.9 .41333 Mdot
.9 .41335 Mdot
.9 .41337 Mdot
.9 .41351 Mdot
.9 .41392 Mdot
.9 .41394 Mdot
.9 .41412 Mdot
.9 .41441 Mdot
.9 .41465 Mdot
.9 .41477 Mdot
.9 .41516 Mdot
.9 .41518 Mdot
.9 .41539 Mdot
.9 .41561 Mdot
.9 .41562 Mdot
.9 .41565 Mdot
.9 .41626 Mdot
.9 .41677 Mdot
.9 .41677 Mdot
.9 .41719 Mdot
.9 .41747 Mdot
.9 .41823 Mdot
.9 .41826 Mdot
.9 .41834 Mdot
.9 .41837 Mdot
.9 .41841 Mdot
.9 .41882 Mdot
.9 .41882 Mdot
.9 .41916 Mdot
.9 .41919 Mdot
.9 .41955 Mdot
.9 .4209 Mdot
.9 .42098 Mdot
.9 .42098 Mdot
.9 .42099 Mdot
.9 .42117 Mdot
.9 .42119 Mdot
.9 .42133 Mdot
.9 .42137 Mdot
.9 .42144 Mdot
.9 .42169 Mdot
.9 .42173 Mdot
.9 .42176 Mdot
.9 .42186 Mdot
.9 .42235 Mdot
.9 .42246 Mdot
.9 .42274 Mdot
.9 .42292 Mdot
.9 .42302 Mdot
.9 .42305 Mdot
.9 .42327 Mdot
.9 .42331 Mdot
.9 .42371 Mdot
.9 .42403 Mdot
.9 .42476 Mdot
.9 .4248 Mdot
.9 .42495 Mdot
.9 .42512 Mdot
.9 .42533 Mdot
.9 .42541 Mdot
.9 .42544 Mdot
.9 .42554 Mdot
.9 .42555 Mdot
.9 .42565 Mdot
.9 .42574 Mdot
.9 .42583 Mdot
.9 .4261 Mdot
.9 .42614 Mdot
.9 .42639 Mdot
.9 .42648 Mdot
.9 .42649 Mdot
.9 .42654 Mdot
.9 .42667 Mdot
.9 .42668 Mdot
.9 .42674 Mdot
.9 .42683 Mdot
.9 .42691 Mdot
.9 .42695 Mdot
.9 .42708 Mdot
.9 .42723 Mdot
.9 .42724 Mdot
.9 .42743 Mdot
.9 .4276 Mdot
.9 .4276 Mdot
.9 .42774 Mdot
.9 .42783 Mdot
.9 .42808 Mdot
.9 .42811 Mdot
.9 .42812 Mdot
.9 .42827 Mdot
.9 .4285 Mdot
.9 .42894 Mdot
.9 .42945 Mdot
.9 .42954 Mdot
.9 .42961 Mdot
.9 .43021 Mdot
.9 .43042 Mdot
.9 .43077 Mdot
.9 .43077 Mdot
.9 .43079 Mdot
.9 .43084 Mdot
.9 .43089 Mdot
.9 .43091 Mdot
.9 .43118 Mdot
.9 .43131 Mdot
.9 .43136 Mdot
.9 .43219 Mdot
.9 .43222 Mdot
.9 .43223 Mdot
.9 .43236 Mdot
.9 .43238 Mdot
.9 .43266 Mdot
.9 .43267 Mdot
.9 .43267 Mdot
.9 .43281 Mdot
.9 .43281 Mdot
.9 .43293 Mdot
.9 .43301 Mdot
.9 .43301 Mdot
.9 .43318 Mdot
.9 .43326 Mdot
.9 .43327 Mdot
.9 .43329 Mdot
.9 .43376 Mdot
.9 .43379 Mdot
.9 .43386 Mdot
.9 .43402 Mdot
.9 .43403 Mdot
.9 .43406 Mdot
.9 .43409 Mdot
.9 .4343 Mdot
.9 .43442 Mdot
.9 .4348 Mdot
.9 .43485 Mdot
.9 .43552 Mdot
.9 .43561 Mdot
.9 .43561 Mdot
.9 .43563 Mdot
.9 .43582 Mdot
.9 .4359 Mdot
.9 .43629 Mdot
.9 .43633 Mdot
.9 .43642 Mdot
.9 .4365 Mdot
.9 .43653 Mdot
.9 .43653 Mdot
.9 .43713 Mdot
.9 .43747 Mdot
.9 .43749 Mdot
.9 .43808 Mdot
.9 .43852 Mdot
.9 .43862 Mdot
.9 .43878 Mdot
.9 .43884 Mdot
.9 .43964 Mdot
.9 .44038 Mdot
.9 .44058 Mdot
.9 .44059 Mdot
.9 .44078 Mdot
.9 .44078 Mdot
.9 .441 Mdot
.9 .44102 Mdot
.9 .44104 Mdot
.9 .44108 Mdot
.9 .4411 Mdot
.9 .44152 Mdot
.9 .44166 Mdot
.9 .44189 Mdot
.9 .4419 Mdot
.9 .44217 Mdot
.9 .4425 Mdot
.9 .44252 Mdot
.9 .44252 Mdot
.9 .44264 Mdot
.9 .44276 Mdot
.9 .44277 Mdot
.9 .44298 Mdot
.9 .44304 Mdot
.9 .44317 Mdot
.9 .44333 Mdot
.9 .44343 Mdot
.9 .44344 Mdot
.9 .44366 Mdot
.9 .44373 Mdot
.9 .44374 Mdot
.9 .44375 Mdot
.9 .44376 Mdot
.9 .44391 Mdot
.9 .44391 Mdot
.9 .44432 Mdot
.9 .44439 Mdot
.9 .44484 Mdot
.9 .44499 Mdot
.9 .44514 Mdot
.9 .44529 Mdot
.9 .44531 Mdot
.9 .44548 Mdot
.9 .44553 Mdot
.9 .44567 Mdot
.9 .44581 Mdot
.9 .446 Mdot
.9 .44628 Mdot
.9 .44653 Mdot
.9 .44659 Mdot
.9 .44707 Mdot
.9 .44733 Mdot
.9 .44779 Mdot
.9 .44831 Mdot
.9 .44896 Mdot
.9 .44902 Mdot
.9 .44938 Mdot
.9 .44943 Mdot
.9 .44958 Mdot
.9 .44988 Mdot
.9 .44991 Mdot
.9 .45033 Mdot
.9 .45051 Mdot
.9 .45056 Mdot
.9 .45091 Mdot
.9 .45128 Mdot
.9 .4513 Mdot
.9 .45145 Mdot
.9 .45149 Mdot
.9 .45156 Mdot
.9 .45178 Mdot
.9 .45196 Mdot
.9 .45207 Mdot
.9 .45214 Mdot
.9 .45226 Mdot
.9 .45236 Mdot
.9 .45239 Mdot
.9 .45267 Mdot
.9 .45269 Mdot
.9 .4527 Mdot
.9 .45279 Mdot
.9 .45283 Mdot
.9 .45404 Mdot
.9 .45495 Mdot
.9 .45517 Mdot
.9 .45551 Mdot
.9 .45553 Mdot
.9 .45557 Mdot
.9 .4561 Mdot
.9 .45611 Mdot
.9 .45674 Mdot
.9 .4568 Mdot
.9 .45686 Mdot
.9 .45692 Mdot
.9 .45697 Mdot
.9 .45702 Mdot
.9 .45763 Mdot
.9 .45808 Mdot
.9 .45821 Mdot
.9 .45863 Mdot
.9 .45928 Mdot
.9 .45928 Mdot
.9 .46006 Mdot
.9 .461 Mdot
.9 .46105 Mdot
.9 .46105 Mdot
.9 .46118 Mdot
.9 .46139 Mdot
.9 .46171 Mdot
.9 .46172 Mdot
.9 .46174 Mdot
.9 .46174 Mdot
.9 .46181 Mdot
.9 .46211 Mdot
.9 .46233 Mdot
.9 .46251 Mdot
.9 .46288 Mdot
.9 .46326 Mdot
.9 .46331 Mdot
.9 .46359 Mdot
.9 .46362 Mdot
.9 .46423 Mdot
.9 .46444 Mdot
.9 .46447 Mdot
.9 .46449 Mdot
.9 .46452 Mdot
.9 .46492 Mdot
.9 .46494 Mdot
.9 .46555 Mdot
.9 .46558 Mdot
.9 .46608 Mdot
.9 .46625 Mdot
.9 .4675 Mdot
.9 .46792 Mdot
.9 .4683 Mdot
.9 .46832 Mdot
.9 .46874 Mdot
.9 .46878 Mdot
.9 .46919 Mdot
.9 .46927 Mdot
.9 .46928 Mdot
.9 .46939 Mdot
.9 .46958 Mdot
.9 .46958 Mdot
.9 .46977 Mdot
.9 .47017 Mdot
.9 .47033 Mdot
.9 .47067 Mdot
.9 .47145 Mdot
.9 .47155 Mdot
.9 .47212 Mdot
.9 .47227 Mdot
.9 .47228 Mdot
.9 .47355 Mdot
.9 .47385 Mdot
.9 .47427 Mdot
.9 .47549 Mdot
.9 .4763 Mdot
.9 .47687 Mdot
.9 .47826 Mdot
.9 .47848 Mdot
.9 .47858 Mdot
.9 .47874 Mdot
.9 .47968 Mdot
.9 .4798 Mdot
.9 .4802 Mdot
.9 .48036 Mdot
.9 .48098 Mdot
.9 .48105 Mdot
.9 .48185 Mdot
.9 .48215 Mdot
.9 .48218 Mdot
.9 .4826 Mdot
.9 .48274 Mdot
.9 .48274 Mdot
.9 .48364 Mdot
.9 .48458 Mdot
.9 .48462 Mdot
.9 .485 Mdot
.9 .48512 Mdot
.9 .48528 Mdot
.9 .48585 Mdot
.9 .4863 Mdot
.9 .48657 Mdot
.9 .48675 Mdot
.9 .48704 Mdot
.9 .48714 Mdot
.9 .4873 Mdot
.9 .48738 Mdot
.9 .48783 Mdot
.9 .48808 Mdot
.9 .48813 Mdot
.9 .48814 Mdot
.9 .48819 Mdot
.9 .48825 Mdot
.9 .48836 Mdot
.9 .48846 Mdot
.9 .48902 Mdot
.9 .4897 Mdot
.9 .49099 Mdot
.9 .49134 Mdot
.9 .49145 Mdot
.9 .49152 Mdot
.9 .49182 Mdot
.9 .49234 Mdot
.9 .49361 Mdot
.9 .49366 Mdot
.9 .49417 Mdot
.9 .495 Mdot
.9 .49503 Mdot
.9 .49514 Mdot
.9 .49619 Mdot
.9 .49638 Mdot
.9 .49641 Mdot
.9 .49784 Mdot
.9 .49788 Mdot
.9 .49802 Mdot
.9 .49815 Mdot
.9 .49829 Mdot
.9 .49832 Mdot
.9 .49841 Mdot
.9 .49853 Mdot
.9 .49863 Mdot
.9 .49993 Mdot
.9 .50057 Mdot
.9 .50066 Mdot
.9 .50096 Mdot
.9 .50102 Mdot
.9 .50124 Mdot
.9 .50126 Mdot
.9 .50149 Mdot
.9 .50149 Mdot
.9 .50157 Mdot
.9 .50219 Mdot
.9 .50239 Mdot
.9 .5029 Mdot
.9 .50296 Mdot
.9 .50334 Mdot
.9 .50364 Mdot
.9 .50365 Mdot
.9 .50413 Mdot
.9 .50527 Mdot
.9 .50535 Mdot
.9 .50546 Mdot
.9 .50594 Mdot
.9 .50617 Mdot
.9 .50737 Mdot
.9 .50747 Mdot
.9 .50748 Mdot
.9 .50749 Mdot
.9 .50755 Mdot
.9 .50777 Mdot
.9 .5082 Mdot
.9 .50888 Mdot
.9 .50889 Mdot
.9 .50895 Mdot
.9 .50895 Mdot
.9 .50909 Mdot
.9 .50931 Mdot
.9 .50972 Mdot
.9 .51016 Mdot
.9 .51055 Mdot
.9 .5112 Mdot
.9 .51129 Mdot
.9 .51206 Mdot
.9 .51218 Mdot
.9 .5125 Mdot
.9 .51273 Mdot
.9 .51279 Mdot
.9 .51282 Mdot
.9 .51318 Mdot
.9 .514 Mdot
.9 .51441 Mdot
.9 .51448 Mdot
.9 .51452 Mdot
.9 .51457 Mdot
.9 .51503 Mdot
.9 .51535 Mdot
.9 .51539 Mdot
.9 .51656 Mdot
.9 .51661 Mdot
.9 .51668 Mdot
.9 .51703 Mdot
.9 .51742 Mdot
.9 .51756 Mdot
.9 .51773 Mdot
.9 .51788 Mdot
.9 .51859 Mdot
.9 .51936 Mdot
.9 .51951 Mdot
.9 .51964 Mdot
.9 .52016 Mdot
.9 .5209 Mdot
.9 .52157 Mdot
.9 .5216 Mdot
.9 .52208 Mdot
.9 .52217 Mdot
.9 .52234 Mdot
.9 .52241 Mdot
.9 .52283 Mdot
.9 .52311 Mdot
.9 .52324 Mdot
.9 .52326 Mdot
.9 .52344 Mdot
.9 .52373 Mdot
.9 .52376 Mdot
.9 .52376 Mdot
.9 .52384 Mdot
.9 .52392 Mdot
.9 .52405 Mdot
.9 .52408 Mdot
.9 .52474 Mdot
.9 .52484 Mdot
.9 .525 Mdot
.9 .52555 Mdot
.9 .52638 Mdot
.9 .52678 Mdot
.9 .52695 Mdot
.9 .52704 Mdot
.9 .5271 Mdot
.9 .52721 Mdot
.9 .52761 Mdot
.9 .52782 Mdot
.9 .52805 Mdot
.9 .52807 Mdot
.9 .52818 Mdot
.9 .52838 Mdot
.9 .52968 Mdot
.9 .52984 Mdot
.9 .52994 Mdot
.9 .53036 Mdot
.9 .53089 Mdot
.9 .53095 Mdot
.9 .53149 Mdot
.9 .53216 Mdot
.9 .53259 Mdot
.9 .53278 Mdot
.9 .5331 Mdot
.9 .5333 Mdot
.9 .5333 Mdot
.9 .53337 Mdot
.9 .5334 Mdot
.9 .53363 Mdot
.9 .53433 Mdot
.9 .53434 Mdot
.9 .53492 Mdot
.9 .53521 Mdot
.9 .53528 Mdot
.9 .5353 Mdot
.9 .53531 Mdot
.9 .53544 Mdot
.9 .53596 Mdot
.9 .5362 Mdot
.9 .53631 Mdot
.9 .53649 Mdot
.9 .53683 Mdot
.9 .53691 Mdot
.9 .53718 Mdot
.9 .53748 Mdot
.9 .5376 Mdot
.9 .53771 Mdot
.9 .53783 Mdot
.9 .53792 Mdot
.9 .538 Mdot
.9 .53815 Mdot
.9 .53875 Mdot
.9 .53881 Mdot
.9 .5391 Mdot
.9 .53953 Mdot
.9 .53957 Mdot
.9 .53957 Mdot
.9 .53979 Mdot
.9 .53982 Mdot
.9 .53984 Mdot
.9 .54016 Mdot
.9 .54019 Mdot
.9 .54024 Mdot
.9 .54028 Mdot
.9 .54028 Mdot
.9 .54067 Mdot
.9 .54083 Mdot
.9 .54097 Mdot
.9 .54131 Mdot
.9 .54137 Mdot
.9 .54137 Mdot
.9 .54154 Mdot
.9 .54155 Mdot
.9 .54163 Mdot
.9 .54166 Mdot
.9 .54171 Mdot
.9 .54175 Mdot
.9 .5419 Mdot
.9 .54196 Mdot
.9 .54198 Mdot
.9 .54201 Mdot
.9 .54208 Mdot
.9 .54242 Mdot
.9 .54242 Mdot
.9 .54267 Mdot
.9 .54281 Mdot
.9 .5429 Mdot
.9 .54304 Mdot
.9 .54309 Mdot
.9 .54312 Mdot
.9 .54317 Mdot
.9 .54317 Mdot
.9 .5432 Mdot
.9 .54323 Mdot
.9 .54327 Mdot
.9 .54328 Mdot
.9 .54334 Mdot
.9 .5434 Mdot
.9 .5434 Mdot
.9 .54346 Mdot
.9 .54348 Mdot
.9 .5435 Mdot
.9 .54352 Mdot
.9 .54352 Mdot
.9 .54354 Mdot
.9 .54357 Mdot
.9 .54361 Mdot
.9 .54364 Mdot
.9 .54383 Mdot
.9 .54398 Mdot
.9 .54399 Mdot
.9 .54404 Mdot
.9 .54404 Mdot
.9 .54428 Mdot
.9 .5443 Mdot
.9 .54431 Mdot
.9 .54432 Mdot
.9 .54437 Mdot
.9 .54438 Mdot
.9 .54439 Mdot
.9 .54442 Mdot
.9 .54442 Mdot
.9 .54446 Mdot
.9 .54446 Mdot
.9 .54446 Mdot
.902 .17561 Mdot
.902 .17562 Mdot
.902 .17562 Mdot
.902 .17566 Mdot
.902 .17567 Mdot
.902 .17571 Mdot
.902 .17572 Mdot
.902 .17582 Mdot
.902 .17588 Mdot
.902 .1759 Mdot
.902 .17593 Mdot
.902 .17601 Mdot
.902 .17602 Mdot
.902 .17613 Mdot
.902 .17617 Mdot
.902 .17632 Mdot
.902 .17635 Mdot
.902 .17658 Mdot
.902 .177 Mdot
.902 .17754 Mdot
.902 .17846 Mdot
.902 .17885 Mdot
.902 .17889 Mdot
.902 .17901 Mdot
.902 .17927 Mdot
.902 .1794 Mdot
.902 .17964 Mdot
.902 .18004 Mdot
.902 .18017 Mdot
.902 .18044 Mdot
.902 .18052 Mdot
.902 .18084 Mdot
.902 .18089 Mdot
.902 .1809 Mdot
.902 .18095 Mdot
.902 .18117 Mdot
.902 .18128 Mdot
.902 .18172 Mdot
.902 .18199 Mdot
.902 .18202 Mdot
.902 .1821 Mdot
.902 .18281 Mdot
.902 .18302 Mdot
.902 .18334 Mdot
.902 .18394 Mdot
.902 .18402 Mdot
.902 .18435 Mdot
.902 .18445 Mdot
.902 .1845 Mdot
.902 .18462 Mdot
.902 .18489 Mdot
.902 .18516 Mdot
.902 .18529 Mdot
.902 .18533 Mdot
.902 .18534 Mdot
.902 .18541 Mdot
.902 .18547 Mdot
.902 .18554 Mdot
.902 .18583 Mdot
.902 .1864 Mdot
.902 .18687 Mdot
.902 .18688 Mdot
.902 .18706 Mdot
.902 .18748 Mdot
.902 .18792 Mdot
.902 .1888 Mdot
.902 .18884 Mdot
.902 .18897 Mdot
.902 .18951 Mdot
.902 .19033 Mdot
.902 .19071 Mdot
.902 .19071 Mdot
.902 .19097 Mdot
.902 .19116 Mdot
.902 .1921 Mdot
.902 .19215 Mdot
.902 .1923 Mdot
.902 .19278 Mdot
.902 .19383 Mdot
.902 .19403 Mdot
.902 .19407 Mdot
.902 .1941 Mdot
.902 .19425 Mdot
.902 .19436 Mdot
.902 .19473 Mdot
.902 .19483 Mdot
.902 .19486 Mdot
.902 .19497 Mdot
.902 .19525 Mdot
.902 .19537 Mdot
.902 .19553 Mdot
.902 .19587 Mdot
.902 .19603 Mdot
.902 .1961 Mdot
.902 .19641 Mdot
.902 .19729 Mdot
.902 .19773 Mdot
.902 .19783 Mdot
.902 .19826 Mdot
.902 .19868 Mdot
.902 .19956 Mdot
.902 .19976 Mdot
.902 .19977 Mdot
.902 .2001 Mdot
.902 .20056 Mdot
.902 .20066 Mdot
.902 .20121 Mdot
.902 .20136 Mdot
.902 .20352 Mdot
.902 .20854 Mdot
.902 .20943 Mdot
.902 .21059 Mdot
.902 .21122 Mdot
.902 .21389 Mdot
.902 .21462 Mdot
.902 .21488 Mdot
.902 .21503 Mdot
.902 .21765 Mdot
.902 .21771 Mdot
.902 .21804 Mdot
.902 .21849 Mdot
.902 .21962 Mdot
.902 .22 Mdot
.902 .2203 Mdot
.902 .22052 Mdot
.902 .22302 Mdot
.902 .22328 Mdot
.902 .22378 Mdot
.902 .22449 Mdot
.902 .22561 Mdot
.902 .22634 Mdot
.902 .22645 Mdot
.902 .22684 Mdot
.902 .22954 Mdot
.902 .2312 Mdot
.902 .23174 Mdot
.902 .23256 Mdot
.902 .23286 Mdot
.902 .23348 Mdot
.902 .23555 Mdot
.902 .23802 Mdot
.902 .23806 Mdot
.902 .23991 Mdot
.902 .24013 Mdot
.902 .24204 Mdot
.902 .24223 Mdot
.902 .24354 Mdot
.902 .24631 Mdot
.902 .24791 Mdot
.902 .24915 Mdot
.902 .25097 Mdot
.902 .25288 Mdot
.902 .25406 Mdot
.902 .25534 Mdot
.902 .25589 Mdot
.902 .25615 Mdot
.902 .25833 Mdot
.902 .25852 Mdot
.902 .25953 Mdot
.902 .2603 Mdot
.902 .26274 Mdot
.902 .26299 Mdot
.902 .26321 Mdot
.902 .26477 Mdot
.902 .26492 Mdot
.902 .26801 Mdot
.902 .26857 Mdot
.902 .27331 Mdot
.902 .27341 Mdot
.902 .27445 Mdot
.902 .2746 Mdot
.902 .27721 Mdot
.902 .27726 Mdot
.902 .27739 Mdot
.902 .27766 Mdot
.902 .27788 Mdot
.902 .2781 Mdot
.902 .27821 Mdot
.902 .2783 Mdot
.902 .27869 Mdot
.902 .27881 Mdot
.902 .27887 Mdot
.902 .27992 Mdot
.902 .28046 Mdot
.902 .28134 Mdot
.902 .28174 Mdot
.902 .28209 Mdot
.902 .28338 Mdot
.902 .2835 Mdot
.902 .28354 Mdot
.902 .28441 Mdot
.902 .28529 Mdot
.902 .28548 Mdot
.902 .28598 Mdot
.902 .28715 Mdot
.902 .28716 Mdot
.902 .28735 Mdot
.902 .28798 Mdot
.902 .2883 Mdot
.902 .2887 Mdot
.902 .28879 Mdot
.902 .29022 Mdot
.902 .29118 Mdot
.902 .29128 Mdot
.902 .29171 Mdot
.902 .29235 Mdot
.902 .2925 Mdot
.902 .29284 Mdot
.902 .293 Mdot
.902 .29363 Mdot
.902 .2954 Mdot
.902 .29611 Mdot
.902 .29634 Mdot
.902 .2972 Mdot
.902 .2993 Mdot
.902 .30077 Mdot
.902 .30397 Mdot
.902 .30455 Mdot
.902 .30508 Mdot
.902 .3054 Mdot
.902 .3058 Mdot
.902 .30683 Mdot
.902 .30752 Mdot
.902 .30818 Mdot
.902 .30849 Mdot
.902 .3094 Mdot
.902 .31075 Mdot
.902 .31132 Mdot
.902 .31283 Mdot
.902 .31346 Mdot
.902 .31429 Mdot
.902 .31495 Mdot
.902 .31503 Mdot
.902 .31594 Mdot
.902 .32163 Mdot
.902 .32243 Mdot
.902 .3231 Mdot
.902 .32378 Mdot
.902 .32399 Mdot
.902 .32455 Mdot
.902 .32513 Mdot
.902 .32514 Mdot
.902 .32673 Mdot
.902 .32812 Mdot
.902 .32852 Mdot
.902 .32988 Mdot
.902 .32994 Mdot
.902 .33039 Mdot
.902 .33085 Mdot
.902 .33098 Mdot
.902 .33105 Mdot
.902 .33113 Mdot
.902 .33146 Mdot
.902 .33257 Mdot
.902 .3332 Mdot
.902 .3352 Mdot
.902 .33631 Mdot
.902 .33655 Mdot
.902 .33755 Mdot
.902 .33773 Mdot
.902 .33902 Mdot
.902 .33922 Mdot
.902 .33946 Mdot
.902 .33986 Mdot
.902 .34027 Mdot
.902 .34109 Mdot
.902 .34177 Mdot
.902 .34211 Mdot
.902 .34218 Mdot
.902 .34251 Mdot
.902 .34282 Mdot
.902 .34361 Mdot
.902 .34385 Mdot
.902 .34418 Mdot
.902 .34425 Mdot
.902 .34624 Mdot
.902 .35075 Mdot
.902 .35113 Mdot
.902 .35271 Mdot
.902 .35337 Mdot
.902 .35489 Mdot
.902 .35593 Mdot
.902 .35614 Mdot
.902 .3563 Mdot
.902 .35642 Mdot
.902 .35789 Mdot
.902 .35815 Mdot
.902 .3591 Mdot
.902 .35948 Mdot
.902 .36109 Mdot
.902 .36257 Mdot
.902 .36301 Mdot
.902 .36516 Mdot
.902 .36603 Mdot
.902 .36613 Mdot
.902 .36701 Mdot
.902 .36768 Mdot
.902 .36961 Mdot
.902 .37093 Mdot
.902 .37225 Mdot
.902 .37279 Mdot
.902 .37301 Mdot
.902 .37312 Mdot
.902 .37403 Mdot
.902 .37411 Mdot
.902 .37484 Mdot
.902 .37593 Mdot
.902 .37664 Mdot
.902 .3767 Mdot
.902 .38043 Mdot
.902 .38049 Mdot
.902 .38149 Mdot
.902 .3815 Mdot
.902 .38155 Mdot
.902 .38166 Mdot
.902 .38174 Mdot
.902 .38182 Mdot
.902 .38187 Mdot
.902 .3819 Mdot
.902 .38205 Mdot
.902 .38209 Mdot
.902 .38211 Mdot
.902 .38271 Mdot
.902 .38304 Mdot
.902 .38319 Mdot
.902 .38333 Mdot
.902 .3838 Mdot
.902 .38385 Mdot
.902 .38386 Mdot
.902 .38419 Mdot
.902 .38451 Mdot
.902 .38477 Mdot
.902 .3852 Mdot
.902 .38527 Mdot
.902 .38562 Mdot
.902 .38576 Mdot
.902 .3858 Mdot
.902 .38667 Mdot
.902 .3867 Mdot
.902 .38709 Mdot
.902 .38714 Mdot
.902 .38727 Mdot
.902 .38732 Mdot
.902 .38755 Mdot
.902 .38818 Mdot
.902 .38844 Mdot
.902 .38883 Mdot
.902 .38957 Mdot
.902 .39009 Mdot
.902 .39142 Mdot
.902 .39185 Mdot
.902 .39221 Mdot
.902 .39268 Mdot
.902 .39279 Mdot
.902 .3931 Mdot
.902 .39376 Mdot
.902 .39449 Mdot
.902 .395 Mdot
.902 .39534 Mdot
.902 .39727 Mdot
.902 .39799 Mdot
.902 .39825 Mdot
.902 .39844 Mdot
.902 .39898 Mdot
.902 .39944 Mdot
.902 .40004 Mdot
.902 .40019 Mdot
.902 .40039 Mdot
.902 .40044 Mdot
.902 .40054 Mdot
.902 .40091 Mdot
.902 .40112 Mdot
.902 .40178 Mdot
.902 .40214 Mdot
.902 .40222 Mdot
.902 .40255 Mdot
.902 .40261 Mdot
.902 .4031 Mdot
.902 .40331 Mdot
.902 .40371 Mdot
.902 .40393 Mdot
.902 .40404 Mdot
.902 .40406 Mdot
.902 .40427 Mdot
.902 .40453 Mdot
.902 .40461 Mdot
.902 .40471 Mdot
.902 .40474 Mdot
.902 .40538 Mdot
.902 .40696 Mdot
.902 .40768 Mdot
.902 .40817 Mdot
.902 .40851 Mdot
.902 .40866 Mdot
.902 .40913 Mdot
.902 .40922 Mdot
.902 .40964 Mdot
.902 .41016 Mdot
.902 .41063 Mdot
.902 .41077 Mdot
.902 .41146 Mdot
.902 .41174 Mdot
.902 .41177 Mdot
.902 .41205 Mdot
.902 .41226 Mdot
.902 .41288 Mdot
.902 .4133 Mdot
.902 .41371 Mdot
.902 .41389 Mdot
.902 .41396 Mdot
.902 .41399 Mdot
.902 .41428 Mdot
.902 .4143 Mdot
.902 .41488 Mdot
.902 .41511 Mdot
.902 .41513 Mdot
.902 .41631 Mdot
.902 .41633 Mdot
.902 .41665 Mdot
.902 .41665 Mdot
.902 .41667 Mdot
.902 .41673 Mdot
.902 .41675 Mdot
.902 .41677 Mdot
.902 .41678 Mdot
.902 .41682 Mdot
.902 .41684 Mdot
.902 .41704 Mdot
.902 .41714 Mdot
.902 .41719 Mdot
.902 .41723 Mdot
.902 .41738 Mdot
.902 .4174 Mdot
.902 .41761 Mdot
.902 .41769 Mdot
.902 .41782 Mdot
.902 .41785 Mdot
.902 .41796 Mdot
.902 .418 Mdot
.902 .41801 Mdot
.902 .41842 Mdot
.902 .41844 Mdot
.902 .41848 Mdot
.902 .41857 Mdot
.902 .41877 Mdot
.902 .41885 Mdot
.902 .41897 Mdot
.902 .41921 Mdot
.902 .41993 Mdot
.902 .42005 Mdot
.902 .42019 Mdot
.902 .42054 Mdot
.902 .42093 Mdot
.902 .42104 Mdot
.902 .42188 Mdot
.902 .42234 Mdot
.902 .42258 Mdot
.902 .42264 Mdot
.902 .42266 Mdot
.902 .42287 Mdot
.902 .42335 Mdot
.902 .4235 Mdot
.902 .42357 Mdot
.902 .42377 Mdot
.902 .4238 Mdot
.902 .42388 Mdot
.902 .42402 Mdot
.902 .42474 Mdot
.902 .42497 Mdot
.902 .42512 Mdot
.902 .42523 Mdot
.902 .42543 Mdot
.902 .42546 Mdot
.902 .42559 Mdot
.902 .42617 Mdot
.902 .42626 Mdot
.902 .42627 Mdot
.902 .42636 Mdot
.902 .42643 Mdot
.902 .42663 Mdot
.902 .42676 Mdot
.902 .42695 Mdot
.902 .42697 Mdot
.902 .42698 Mdot
.902 .42708 Mdot
.902 .42727 Mdot
.902 .42774 Mdot
.902 .42788 Mdot
.902 .42788 Mdot
.902 .42822 Mdot
.902 .42822 Mdot
.902 .42828 Mdot
.902 .42841 Mdot
.902 .42843 Mdot
.902 .42846 Mdot
.902 .42852 Mdot
.902 .42859 Mdot
.902 .4289 Mdot
.902 .42893 Mdot
.902 .42967 Mdot
.902 .42977 Mdot
.902 .43005 Mdot
.902 .43015 Mdot
.902 .43017 Mdot
.902 .43061 Mdot
.902 .43068 Mdot
.902 .43107 Mdot
.902 .43121 Mdot
.902 .43128 Mdot
.902 .43147 Mdot
.902 .43147 Mdot
.902 .43158 Mdot
.902 .43166 Mdot
.902 .43168 Mdot
.902 .43171 Mdot
.902 .43181 Mdot
.902 .43182 Mdot
.902 .43209 Mdot
.902 .43222 Mdot
.902 .43239 Mdot
.902 .43256 Mdot
.902 .43265 Mdot
.902 .43269 Mdot
.902 .43285 Mdot
.902 .43305 Mdot
.902 .43333 Mdot
.902 .43353 Mdot
.902 .4338 Mdot
.902 .43387 Mdot
.902 .43403 Mdot
.902 .43409 Mdot
.902 .43411 Mdot
.902 .43416 Mdot
.902 .43423 Mdot
.902 .43423 Mdot
.902 .43434 Mdot
.902 .43437 Mdot
.902 .43446 Mdot
.902 .43468 Mdot
.902 .43497 Mdot
.902 .43498 Mdot
.902 .43519 Mdot
.902 .43567 Mdot
.902 .43569 Mdot
.902 .43586 Mdot
.902 .4359 Mdot
.902 .43593 Mdot
.902 .43595 Mdot
.902 .43607 Mdot
.902 .43626 Mdot
.902 .43626 Mdot
.902 .4366 Mdot
.902 .43671 Mdot
.902 .43676 Mdot
.902 .43677 Mdot
.902 .43696 Mdot
.902 .43707 Mdot
.902 .43763 Mdot
.902 .43774 Mdot
.902 .4378 Mdot
.902 .43849 Mdot
.902 .43853 Mdot
.902 .43855 Mdot
.902 .4387 Mdot
.902 .43917 Mdot
.902 .43934 Mdot
.902 .44006 Mdot
.902 .44011 Mdot
.902 .44033 Mdot
.902 .4406 Mdot
.902 .44066 Mdot
.902 .44118 Mdot
.902 .44125 Mdot
.902 .44129 Mdot
.902 .4414 Mdot
.902 .44145 Mdot
.902 .44148 Mdot
.902 .44171 Mdot
.902 .4418 Mdot
.902 .44181 Mdot
.902 .44237 Mdot
.902 .44238 Mdot
.902 .44262 Mdot
.902 .44263 Mdot
.902 .44326 Mdot
.902 .44327 Mdot
.902 .4434 Mdot
.902 .44371 Mdot
.902 .44372 Mdot
.902 .44387 Mdot
.902 .44389 Mdot
.902 .44393 Mdot
.902 .44402 Mdot
.902 .44424 Mdot
.902 .44447 Mdot
.902 .4448 Mdot
.902 .44491 Mdot
.902 .44506 Mdot
.902 .44508 Mdot
.902 .44522 Mdot
.902 .44559 Mdot
.902 .44566 Mdot
.902 .44591 Mdot
.902 .44618 Mdot
.902 .44641 Mdot
.902 .44645 Mdot
.902 .4467 Mdot
.902 .44678 Mdot
.902 .44696 Mdot
.902 .44722 Mdot
.902 .44759 Mdot
.902 .44842 Mdot
.902 .44876 Mdot
.902 .44877 Mdot
.902 .44882 Mdot
.902 .44886 Mdot
.902 .449 Mdot
.902 .44911 Mdot
.902 .44912 Mdot
.902 .44918 Mdot
.902 .44929 Mdot
.902 .4495 Mdot
.902 .44961 Mdot
.902 .44986 Mdot
.902 .44989 Mdot
.902 .45006 Mdot
.902 .4501 Mdot
.902 .45029 Mdot
.902 .45063 Mdot
.902 .45073 Mdot
.902 .45092 Mdot
.902 .45098 Mdot
.902 .451 Mdot
.902 .4511 Mdot
.902 .45118 Mdot
.902 .45149 Mdot
.902 .45173 Mdot
.902 .452 Mdot
.902 .4521 Mdot
.902 .45223 Mdot
.902 .4526 Mdot
.902 .45358 Mdot
.902 .45375 Mdot
.902 .454 Mdot
.902 .45437 Mdot
.902 .45471 Mdot
.902 .45486 Mdot
.902 .45492 Mdot
.902 .45515 Mdot
.902 .45533 Mdot
.902 .45555 Mdot
.902 .45621 Mdot
.902 .45647 Mdot
.902 .45684 Mdot
.902 .45704 Mdot
.902 .45716 Mdot
.902 .45748 Mdot
.902 .45759 Mdot
.902 .45762 Mdot
.902 .45768 Mdot
.902 .45771 Mdot
.902 .4579 Mdot
.902 .45792 Mdot
.902 .45834 Mdot
.902 .45836 Mdot
.902 .45842 Mdot
.902 .45843 Mdot
.902 .4586 Mdot
.902 .45864 Mdot
.902 .45885 Mdot
.902 .45898 Mdot
.902 .45914 Mdot
.902 .4593 Mdot
.902 .4593 Mdot
.902 .45933 Mdot
.902 .45956 Mdot
.902 .45963 Mdot
.902 .4597 Mdot
.902 .45986 Mdot
.902 .46015 Mdot
.902 .46016 Mdot
.902 .46019 Mdot
.902 .46026 Mdot
.902 .46027 Mdot
.902 .4603 Mdot
.902 .46034 Mdot
.902 .46038 Mdot
.902 .46043 Mdot
.902 .46045 Mdot
.902 .46046 Mdot
.902 .46095 Mdot
.902 .46097 Mdot
.902 .46278 Mdot
.902 .46281 Mdot
.902 .46315 Mdot
.902 .46368 Mdot
.902 .46403 Mdot
.902 .46407 Mdot
.902 .4645 Mdot
.902 .46455 Mdot
.902 .46466 Mdot
.902 .46492 Mdot
.902 .46555 Mdot
.902 .46617 Mdot
.902 .46709 Mdot
.902 .46741 Mdot
.902 .46782 Mdot
.902 .46786 Mdot
.902 .46827 Mdot
.902 .46928 Mdot
.902 .46949 Mdot
.902 .47018 Mdot
.902 .47093 Mdot
.902 .4711 Mdot
.902 .47154 Mdot
.902 .47166 Mdot
.902 .47234 Mdot
.902 .4724 Mdot
.902 .47247 Mdot
.902 .47257 Mdot
.902 .47305 Mdot
.902 .47374 Mdot
.902 .47405 Mdot
.902 .47477 Mdot
.902 .47494 Mdot
.902 .47699 Mdot
.902 .47788 Mdot
.902 .47792 Mdot
.902 .47806 Mdot
.902 .47817 Mdot
.902 .47853 Mdot
.902 .47867 Mdot
.902 .47881 Mdot
.902 .47885 Mdot
.902 .479 Mdot
.902 .4793 Mdot
.902 .47967 Mdot
.902 .47985 Mdot
.902 .48003 Mdot
.902 .48014 Mdot
.902 .48023 Mdot
.902 .4808 Mdot
.902 .48088 Mdot
.902 .48133 Mdot
.902 .48143 Mdot
.902 .48192 Mdot
.902 .48281 Mdot
.902 .48308 Mdot
.902 .48358 Mdot
.902 .48372 Mdot
.902 .48375 Mdot
.902 .48378 Mdot
.902 .48384 Mdot
.902 .48404 Mdot
.902 .48424 Mdot
.902 .48427 Mdot
.902 .48486 Mdot
.902 .48504 Mdot
.902 .48564 Mdot
.902 .48634 Mdot
.902 .48634 Mdot
.902 .48659 Mdot
.902 .48684 Mdot
.902 .48693 Mdot
.902 .48723 Mdot
.902 .48751 Mdot
.902 .48786 Mdot
.902 .49031 Mdot
.902 .4907 Mdot
.902 .49074 Mdot
.902 .49102 Mdot
.902 .49137 Mdot
.902 .49164 Mdot
.902 .49228 Mdot
.902 .49252 Mdot
.902 .4931 Mdot
.902 .49349 Mdot
.902 .49361 Mdot
.902 .49389 Mdot
.902 .49419 Mdot
.902 .49462 Mdot
.902 .49479 Mdot
.902 .49492 Mdot
.902 .49515 Mdot
.902 .49539 Mdot
.902 .49674 Mdot
.902 .49735 Mdot
.902 .49823 Mdot
.902 .49859 Mdot
.902 .49868 Mdot
.902 .49898 Mdot
.902 .49971 Mdot
.902 .49997 Mdot
.902 .50004 Mdot
.902 .50018 Mdot
.902 .50024 Mdot
.902 .50051 Mdot
.902 .50068 Mdot
.902 .50073 Mdot
.902 .50112 Mdot
.902 .50171 Mdot
.902 .50175 Mdot
.902 .50192 Mdot
.902 .50205 Mdot
.902 .5023 Mdot
.902 .50238 Mdot
.902 .50239 Mdot
.902 .50287 Mdot
.902 .50307 Mdot
.902 .50315 Mdot
.902 .50351 Mdot
.902 .50387 Mdot
.902 .50388 Mdot
.902 .50393 Mdot
.902 .50446 Mdot
.902 .5046 Mdot
.902 .50477 Mdot
.902 .50513 Mdot
.902 .50535 Mdot
.902 .50577 Mdot
.902 .5058 Mdot
.902 .50585 Mdot
.902 .50601 Mdot
.902 .50604 Mdot
.902 .50609 Mdot
.902 .50618 Mdot
.902 .50627 Mdot
.902 .50638 Mdot
.902 .50643 Mdot
.902 .50645 Mdot
.902 .50751 Mdot
.902 .50757 Mdot
.902 .50799 Mdot
.902 .50803 Mdot
.902 .50994 Mdot
.902 .51016 Mdot
.902 .5114 Mdot
.902 .51146 Mdot
.902 .51209 Mdot
.902 .51217 Mdot
.902 .51227 Mdot
.902 .51325 Mdot
.902 .51355 Mdot
.902 .51395 Mdot
.902 .51403 Mdot
.902 .51489 Mdot
.902 .515 Mdot
.902 .51521 Mdot
.902 .51572 Mdot
.902 .51619 Mdot
.902 .51694 Mdot
.902 .51766 Mdot
.902 .51814 Mdot
.902 .51877 Mdot
.902 .51986 Mdot
.902 .52037 Mdot
.902 .52044 Mdot
.902 .52119 Mdot
.902 .52127 Mdot
.902 .52199 Mdot
.902 .52201 Mdot
.902 .52297 Mdot
.902 .52377 Mdot
.902 .52401 Mdot
.902 .52413 Mdot
.902 .52444 Mdot
.902 .52465 Mdot
.902 .5253 Mdot
.902 .52633 Mdot
.902 .52648 Mdot
.902 .52653 Mdot
.902 .52681 Mdot
.902 .52724 Mdot
.902 .52751 Mdot
.902 .5277 Mdot
.902 .5278 Mdot
.902 .52876 Mdot
.902 .52885 Mdot
.902 .52896 Mdot
.902 .52911 Mdot
.902 .52954 Mdot
.902 .52971 Mdot
.902 .52983 Mdot
.902 .52986 Mdot
.902 .53086 Mdot
.902 .53091 Mdot
.902 .53102 Mdot
.902 .53129 Mdot
.902 .53231 Mdot
.902 .53255 Mdot
.902 .53299 Mdot
.902 .53333 Mdot
.902 .53522 Mdot
.902 .53604 Mdot
.902 .53609 Mdot
.902 .5363 Mdot
.902 .53634 Mdot
.902 .53651 Mdot
.902 .53664 Mdot
.902 .53664 Mdot
.902 .53672 Mdot
.902 .53705 Mdot
.902 .5372 Mdot
.902 .53737 Mdot
.902 .53741 Mdot
.902 .53757 Mdot
.902 .5379 Mdot
.902 .53802 Mdot
.902 .53804 Mdot
.902 .53811 Mdot
.902 .53823 Mdot
.902 .53829 Mdot
.902 .53834 Mdot
.902 .53844 Mdot
.902 .53848 Mdot
.902 .53849 Mdot
.902 .53853 Mdot
.902 .53867 Mdot
.902 .53871 Mdot
.902 .53877 Mdot
.902 .53878 Mdot
.902 .53879 Mdot
.902 .53887 Mdot
.902 .53926 Mdot
.902 .53944 Mdot
.902 .5395 Mdot
.902 .53952 Mdot
.902 .53987 Mdot
.902 .53994 Mdot
.902 .54004 Mdot
.902 .54004 Mdot
.902 .54018 Mdot
.902 .54049 Mdot
.902 .54069 Mdot
.902 .54074 Mdot
.902 .54075 Mdot
.902 .54108 Mdot
.902 .54124 Mdot
.902 .5414 Mdot
.902 .54147 Mdot
.902 .54147 Mdot
.902 .54165 Mdot
.902 .54186 Mdot
.902 .54197 Mdot
.902 .54199 Mdot
.902 .54202 Mdot
.902 .54204 Mdot
.902 .54205 Mdot
.902 .54206 Mdot
.902 .54211 Mdot
.902 .54221 Mdot
.902 .54231 Mdot
.902 .54235 Mdot
.902 .54237 Mdot
.902 .54241 Mdot
.902 .54253 Mdot
.902 .54256 Mdot
.902 .54279 Mdot
.902 .5429 Mdot
.902 .54298 Mdot
.902 .54325 Mdot
.902 .54328 Mdot
.902 .54329 Mdot
.902 .54339 Mdot
.902 .54355 Mdot
.902 .54359 Mdot
.902 .54368 Mdot
.902 .5437 Mdot
.902 .5437 Mdot
.902 .54372 Mdot
.902 .54384 Mdot
.902 .54386 Mdot
.902 .54397 Mdot
.902 .54401 Mdot
.902 .54416 Mdot
.902 .54425 Mdot
.902 .5443 Mdot
.902 .5444 Mdot
.902 .54444 Mdot
.902 .54446 Mdot
.902 .5446 Mdot
.902 .54494 Mdot
.902 .54514 Mdot
.902 .5453 Mdot
.902 .54538 Mdot
.902 .54539 Mdot
.902 .54545 Mdot
.902 .54546 Mdot
.902 .54551 Mdot
.902 .54551 Mdot
.902 .54554 Mdot
.902 .54555 Mdot
.902 .54556 Mdot
.902 .54558 Mdot
.902 .54562 Mdot
.902 .54562 Mdot
.902 .54563 Mdot
.902 .54564 Mdot
.902 .54565 Mdot
.902 .54566 Mdot
.902 .54566 Mdot
.904 .17278 Mdot
.904 .17278 Mdot
.904 .17279 Mdot
.904 .17282 Mdot
.904 .17286 Mdot
.904 .17287 Mdot
.904 .17289 Mdot
.904 .17289 Mdot
.904 .17292 Mdot
.904 .17296 Mdot
.904 .17315 Mdot
.904 .17321 Mdot
.904 .17326 Mdot
.904 .17331 Mdot
.904 .17331 Mdot
.904 .17333 Mdot
.904 .17344 Mdot
.904 .17344 Mdot
.904 .17345 Mdot
.904 .17351 Mdot
.904 .17351 Mdot
.904 .17374 Mdot
.904 .17382 Mdot
.904 .17394 Mdot
.904 .17405 Mdot
.904 .17416 Mdot
.904 .1742 Mdot
.904 .17431 Mdot
.904 .1744 Mdot
.904 .17445 Mdot
.904 .17519 Mdot
.904 .17545 Mdot
.904 .17598 Mdot
.904 .17694 Mdot
.904 .17707 Mdot
.904 .1777 Mdot
.904 .17781 Mdot
.904 .17788 Mdot
.904 .17882 Mdot
.904 .17909 Mdot
.904 .17931 Mdot
.904 .17948 Mdot
.904 .17952 Mdot
.904 .17974 Mdot
.904 .17992 Mdot
.904 .18055 Mdot
.904 .18057 Mdot
.904 .18114 Mdot
.904 .1812 Mdot
.904 .18181 Mdot
.904 .18202 Mdot
.904 .18265 Mdot
.904 .18424 Mdot
.904 .18518 Mdot
.904 .18529 Mdot
.904 .18534 Mdot
.904 .18546 Mdot
.904 .1859 Mdot
.904 .18703 Mdot
.904 .18759 Mdot
.904 .18832 Mdot
.904 .18869 Mdot
.904 .18935 Mdot
.904 .18985 Mdot
.904 .18997 Mdot
.904 .19019 Mdot
.904 .19054 Mdot
.904 .19136 Mdot
.904 .19191 Mdot
.904 .19208 Mdot
.904 .19377 Mdot
.904 .19509 Mdot
.904 .19517 Mdot
.904 .19534 Mdot
.904 .19559 Mdot
.904 .19661 Mdot
.904 .19697 Mdot
.904 .19706 Mdot
.904 .19714 Mdot
.904 .19717 Mdot
.904 .19894 Mdot
.904 .19953 Mdot
.904 .19995 Mdot
.904 .20044 Mdot
.904 .20095 Mdot
.904 .2015 Mdot
.904 .20168 Mdot
.904 .20194 Mdot
.904 .202 Mdot
.904 .20204 Mdot
.904 .20367 Mdot
.904 .20385 Mdot
.904 .20416 Mdot
.904 .20534 Mdot
.904 .206 Mdot
.904 .20628 Mdot
.904 .20641 Mdot
.904 .20708 Mdot
.904 .20738 Mdot
.904 .20759 Mdot
.904 .2076 Mdot
.904 .2077 Mdot
.904 .20849 Mdot
.904 .20908 Mdot
.904 .2094 Mdot
.904 .20942 Mdot
.904 .21047 Mdot
.904 .21126 Mdot
.904 .2116 Mdot
.904 .21261 Mdot
.904 .2143 Mdot
.904 .21518 Mdot
.904 .21528 Mdot
.904 .21616 Mdot
.904 .21712 Mdot
.904 .21769 Mdot
.904 .2182 Mdot
.904 .21828 Mdot
.904 .21869 Mdot
.904 .21966 Mdot
.904 .2206 Mdot
.904 .22213 Mdot
.904 .22252 Mdot
.904 .22272 Mdot
.904 .22299 Mdot
.904 .22375 Mdot
.904 .22434 Mdot
.904 .22536 Mdot
.904 .22547 Mdot
.904 .22602 Mdot
.904 .22611 Mdot
.904 .2262 Mdot
.904 .22649 Mdot
.904 .22743 Mdot
.904 .22751 Mdot
.904 .22756 Mdot
.904 .22819 Mdot
.904 .22878 Mdot
.904 .22947 Mdot
.904 .2299 Mdot
.904 .23057 Mdot
.904 .23076 Mdot
.904 .23126 Mdot
.904 .23318 Mdot
.904 .23378 Mdot
.904 .23397 Mdot
.904 .23454 Mdot
.904 .23474 Mdot
.904 .23481 Mdot
.904 .23539 Mdot
.904 .23629 Mdot
.904 .23669 Mdot
.904 .23678 Mdot
.904 .23684 Mdot
.904 .2377 Mdot
.904 .23797 Mdot
.904 .23802 Mdot
.904 .23811 Mdot
.904 .23856 Mdot
.904 .23908 Mdot
.904 .23915 Mdot
.904 .23941 Mdot
.904 .23946 Mdot
.904 .23949 Mdot
.904 .23989 Mdot
.904 .24013 Mdot
.904 .24038 Mdot
.904 .24139 Mdot
.904 .24194 Mdot
.904 .24299 Mdot
.904 .24311 Mdot
.904 .24374 Mdot
.904 .24389 Mdot
.904 .244 Mdot
.904 .24436 Mdot
.904 .2444 Mdot
.904 .24449 Mdot
.904 .24512 Mdot
.904 .24517 Mdot
.904 .24547 Mdot
.904 .2462 Mdot
.904 .24676 Mdot
.904 .2469 Mdot
.904 .24692 Mdot
.904 .24699 Mdot
.904 .24701 Mdot
.904 .24784 Mdot
.904 .24794 Mdot
.904 .24892 Mdot
.904 .24898 Mdot
.904 .24913 Mdot
.904 .24918 Mdot
.904 .24952 Mdot
.904 .25004 Mdot
.904 .25085 Mdot
.904 .25117 Mdot
.904 .25234 Mdot
.904 .2524 Mdot
.904 .25259 Mdot
.904 .2533 Mdot
.904 .25342 Mdot
.904 .25375 Mdot
.904 .25403 Mdot
.904 .25494 Mdot
.904 .25518 Mdot
.904 .25527 Mdot
.904 .25559 Mdot
.904 .25614 Mdot
.904 .25642 Mdot
.904 .25675 Mdot
.904 .25679 Mdot
.904 .25726 Mdot
.904 .25782 Mdot
.904 .25833 Mdot
.904 .25863 Mdot
.904 .25926 Mdot
.904 .25946 Mdot
.904 .26074 Mdot
.904 .26126 Mdot
.904 .26148 Mdot
.904 .26179 Mdot
.904 .26263 Mdot
.904 .26518 Mdot
.904 .26538 Mdot
.904 .26584 Mdot
.904 .26645 Mdot
.904 .26665 Mdot
.904 .267 Mdot
.904 .26748 Mdot
.904 .26754 Mdot
.904 .26755 Mdot
.904 .26768 Mdot
.904 .26827 Mdot
.904 .26835 Mdot
.904 .26852 Mdot
.904 .26968 Mdot
.904 .26987 Mdot
.904 .27104 Mdot
.904 .27107 Mdot
.904 .27112 Mdot
.904 .27129 Mdot
.904 .2714 Mdot
.904 .27211 Mdot
.904 .27273 Mdot
.904 .27439 Mdot
.904 .27441 Mdot
.904 .27454 Mdot
.904 .27479 Mdot
.904 .27573 Mdot
.904 .27586 Mdot
.904 .27692 Mdot
.904 .27825 Mdot
.904 .27981 Mdot
.904 .27999 Mdot
.904 .2801 Mdot
.904 .28053 Mdot
.904 .28209 Mdot
.904 .28261 Mdot
.904 .28424 Mdot
.904 .2844 Mdot
.904 .28535 Mdot
.904 .28778 Mdot
.904 .28802 Mdot
.904 .28955 Mdot
.904 .29089 Mdot
.904 .29094 Mdot
.904 .29148 Mdot
.904 .29326 Mdot
.904 .29336 Mdot
.904 .29457 Mdot
.904 .29653 Mdot
.904 .29819 Mdot
.904 .3 Mdot
.904 .30014 Mdot
.904 .30038 Mdot
.904 .30116 Mdot
.904 .3015 Mdot
.904 .30304 Mdot
.904 .30307 Mdot
.904 .30335 Mdot
.904 .30392 Mdot
.904 .3042 Mdot
.904 .30444 Mdot
.904 .30604 Mdot
.904 .30636 Mdot
.904 .30665 Mdot
.904 .30692 Mdot
.904 .30935 Mdot
.904 .30954 Mdot
.904 .30981 Mdot
.904 .31053 Mdot
.904 .31107 Mdot
.904 .31139 Mdot
.904 .31331 Mdot
.904 .31412 Mdot
.904 .31424 Mdot
.904 .31471 Mdot
.904 .31474 Mdot
.904 .31588 Mdot
.904 .31617 Mdot
.904 .31725 Mdot
.904 .31736 Mdot
.904 .32045 Mdot
.904 .32327 Mdot
.904 .32453 Mdot
.904 .3262 Mdot
.904 .32688 Mdot
.904 .32746 Mdot
.904 .3277 Mdot
.904 .32853 Mdot
.904 .32924 Mdot
.904 .32931 Mdot
.904 .33099 Mdot
.904 .33377 Mdot
.904 .33394 Mdot
.904 .33437 Mdot
.904 .33662 Mdot
.904 .33695 Mdot
.904 .33854 Mdot
.904 .33922 Mdot
.904 .33967 Mdot
.904 .34214 Mdot
.904 .34251 Mdot
.904 .34359 Mdot
.904 .34492 Mdot
.904 .34561 Mdot
.904 .34629 Mdot
.904 .34807 Mdot
.904 .34913 Mdot
.904 .3502 Mdot
.904 .35159 Mdot
.904 .35345 Mdot
.904 .35441 Mdot
.904 .35489 Mdot
.904 .35495 Mdot
.904 .35596 Mdot
.904 .35654 Mdot
.904 .3578 Mdot
.904 .3589 Mdot
.904 .35904 Mdot
.904 .36029 Mdot
.904 .36057 Mdot
.904 .36061 Mdot
.904 .36066 Mdot
.904 .36133 Mdot
.904 .36226 Mdot
.904 .3644 Mdot
.904 .36466 Mdot
.904 .36479 Mdot
.904 .36506 Mdot
.904 .3657 Mdot
.904 .36612 Mdot
.904 .36624 Mdot
.904 .36626 Mdot
.904 .3663 Mdot
.904 .36651 Mdot
.904 .36674 Mdot
.904 .36677 Mdot
.904 .36691 Mdot
.904 .36692 Mdot
.904 .3671 Mdot
.904 .36733 Mdot
.904 .36778 Mdot
.904 .36848 Mdot
.904 .36881 Mdot
.904 .3691 Mdot
.904 .36942 Mdot
.904 .36944 Mdot
.904 .36957 Mdot
.904 .36988 Mdot
.904 .37018 Mdot
.904 .37019 Mdot
.904 .37023 Mdot
.904 .37058 Mdot
.904 .37063 Mdot
.904 .37152 Mdot
.904 .372 Mdot
.904 .37248 Mdot
.904 .37251 Mdot
.904 .37307 Mdot
.904 .37319 Mdot
.904 .37383 Mdot
.904 .37431 Mdot
.904 .37451 Mdot
.904 .37474 Mdot
.904 .37532 Mdot
.904 .3754 Mdot
.904 .37592 Mdot
.904 .37621 Mdot
.904 .37634 Mdot
.904 .37775 Mdot
.904 .37825 Mdot
.904 .37839 Mdot
.904 .3786 Mdot
.904 .37942 Mdot
.904 .37996 Mdot
.904 .37997 Mdot
.904 .38059 Mdot
.904 .38123 Mdot
.904 .38172 Mdot
.904 .38217 Mdot
.904 .38336 Mdot
.904 .38493 Mdot
.904 .38528 Mdot
.904 .38616 Mdot
.904 .38625 Mdot
.904 .38728 Mdot
.904 .38812 Mdot
.904 .3909 Mdot
.904 .39102 Mdot
.904 .39155 Mdot
.904 .39166 Mdot
.904 .3928 Mdot
.904 .39289 Mdot
.904 .39378 Mdot
.904 .39387 Mdot
.904 .39412 Mdot
.904 .39441 Mdot
.904 .39538 Mdot
.904 .39554 Mdot
.904 .39603 Mdot
.904 .39639 Mdot
.904 .39643 Mdot
.904 .39881 Mdot
.904 .39959 Mdot
.904 .40013 Mdot
.904 .40039 Mdot
.904 .40185 Mdot
.904 .40204 Mdot
.904 .4034 Mdot
.904 .40362 Mdot
.904 .40456 Mdot
.904 .40468 Mdot
.904 .40502 Mdot
.904 .40567 Mdot
.904 .40589 Mdot
.904 .40714 Mdot
.904 .40818 Mdot
.904 .40848 Mdot
.904 .40916 Mdot
.904 .40991 Mdot
.904 .40996 Mdot
.904 .41044 Mdot
.904 .41174 Mdot
.904 .41186 Mdot
.904 .41219 Mdot
.904 .41223 Mdot
.904 .41224 Mdot
.904 .41225 Mdot
.904 .41232 Mdot
.904 .41239 Mdot
.904 .4124 Mdot
.904 .41245 Mdot
.904 .41245 Mdot
.904 .41251 Mdot
.904 .41258 Mdot
.904 .41294 Mdot
.904 .41304 Mdot
.904 .41313 Mdot
.904 .41323 Mdot
.904 .41324 Mdot
.904 .41328 Mdot
.904 .41338 Mdot
.904 .41348 Mdot
.904 .41348 Mdot
.904 .41349 Mdot
.904 .4136 Mdot
.904 .41362 Mdot
.904 .41405 Mdot
.904 .4142 Mdot
.904 .41442 Mdot
.904 .41462 Mdot
.904 .41477 Mdot
.904 .41484 Mdot
.904 .41491 Mdot
.904 .41509 Mdot
.904 .41512 Mdot
.904 .41528 Mdot
.904 .41537 Mdot
.904 .41541 Mdot
.904 .41586 Mdot
.904 .41655 Mdot
.904 .41675 Mdot
.904 .41695 Mdot
.904 .41724 Mdot
.904 .41822 Mdot
.904 .4185 Mdot
.904 .41885 Mdot
.904 .41998 Mdot
.904 .42002 Mdot
.904 .42019 Mdot
.904 .42022 Mdot
.904 .42058 Mdot
.904 .42061 Mdot
.904 .42139 Mdot
.904 .4216 Mdot
.904 .42171 Mdot
.904 .42172 Mdot
.904 .42343 Mdot
.904 .42349 Mdot
.904 .42392 Mdot
.904 .42399 Mdot
.904 .42432 Mdot
.904 .42443 Mdot
.904 .42464 Mdot
.904 .4247 Mdot
.904 .4251 Mdot
.904 .42543 Mdot
.904 .42552 Mdot
.904 .42574 Mdot
.904 .42599 Mdot
.904 .42655 Mdot
.904 .42659 Mdot
.904 .42708 Mdot
.904 .42762 Mdot
.904 .42772 Mdot
.904 .42882 Mdot
.904 .42919 Mdot
.904 .42925 Mdot
.904 .42938 Mdot
.904 .4303 Mdot
.904 .43061 Mdot
.904 .43096 Mdot
.904 .43111 Mdot
.904 .43146 Mdot
.904 .4322 Mdot
.904 .43312 Mdot
.904 .43434 Mdot
.904 .43476 Mdot
.904 .43496 Mdot
.904 .43504 Mdot
.904 .43524 Mdot
.904 .43593 Mdot
.904 .43601 Mdot
.904 .43722 Mdot
.904 .43782 Mdot
.904 .43796 Mdot
.904 .43808 Mdot
.904 .43869 Mdot
.904 .43893 Mdot
.904 .43921 Mdot
.904 .44017 Mdot
.904 .44078 Mdot
.904 .4408 Mdot
.904 .44101 Mdot
.904 .4411 Mdot
.904 .44174 Mdot
.904 .44193 Mdot
.904 .44276 Mdot
.904 .44298 Mdot
.904 .44335 Mdot
.904 .44359 Mdot
.904 .44376 Mdot
.904 .44393 Mdot
.904 .44467 Mdot
.904 .4453 Mdot
.904 .44548 Mdot
.904 .44554 Mdot
.904 .44623 Mdot
.904 .44648 Mdot
.904 .4465 Mdot
.904 .4469 Mdot
.904 .44725 Mdot
.904 .44741 Mdot
.904 .44795 Mdot
.904 .4486 Mdot
.904 .44872 Mdot
.904 .44906 Mdot
.904 .44923 Mdot
.904 .4493 Mdot
.904 .44978 Mdot
.904 .4499 Mdot
.904 .45059 Mdot
.904 .45069 Mdot
.904 .45144 Mdot
.904 .45157 Mdot
.904 .45185 Mdot
.904 .45224 Mdot
.904 .45345 Mdot
.904 .45347 Mdot
.904 .45366 Mdot
.904 .4539 Mdot
.904 .45398 Mdot
.904 .45447 Mdot
.904 .45462 Mdot
.904 .45474 Mdot
.904 .45478 Mdot
.904 .45523 Mdot
.904 .45528 Mdot
.904 .45585 Mdot
.904 .4559 Mdot
.904 .45617 Mdot
.904 .45623 Mdot
.904 .4576 Mdot
.904 .45802 Mdot
.904 .45853 Mdot
.904 .45857 Mdot
.904 .459 Mdot
.904 .45917 Mdot
.904 .45994 Mdot
.904 .46052 Mdot
.904 .46074 Mdot
.904 .46098 Mdot
.904 .46129 Mdot
.904 .46159 Mdot
.904 .4616 Mdot
.904 .46186 Mdot
.904 .46226 Mdot
.904 .46236 Mdot
.904 .46242 Mdot
.904 .46266 Mdot
.904 .46334 Mdot
.904 .4634 Mdot
.904 .46354 Mdot
.904 .46379 Mdot
.904 .46383 Mdot
.904 .46411 Mdot
.904 .46422 Mdot
.904 .46432 Mdot
.904 .46454 Mdot
.904 .46485 Mdot
.904 .4649 Mdot
.904 .46517 Mdot
.904 .46518 Mdot
.904 .46542 Mdot
.904 .46564 Mdot
.904 .46607 Mdot
.904 .46609 Mdot
.904 .46625 Mdot
.904 .46627 Mdot
.904 .46628 Mdot
.904 .46642 Mdot
.904 .46657 Mdot
.904 .46663 Mdot
.904 .46664 Mdot
.904 .46679 Mdot
.904 .46692 Mdot
.904 .46708 Mdot
.904 .46741 Mdot
.904 .46762 Mdot
.904 .46773 Mdot
.904 .46781 Mdot
.904 .46782 Mdot
.904 .46788 Mdot
.904 .4679 Mdot
.904 .46801 Mdot
.904 .4681 Mdot
.904 .46812 Mdot
.904 .46813 Mdot
.904 .46819 Mdot
.904 .46839 Mdot
.904 .46869 Mdot
.904 .46881 Mdot
.904 .46887 Mdot
.904 .469 Mdot
.904 .46999 Mdot
.904 .47042 Mdot
.904 .47074 Mdot
.904 .47076 Mdot
.904 .47078 Mdot
.904 .4709 Mdot
.904 .47148 Mdot
.904 .47155 Mdot
.904 .47205 Mdot
.904 .47264 Mdot
.904 .4729 Mdot
.904 .47336 Mdot
.904 .47339 Mdot
.904 .47361 Mdot
.904 .47405 Mdot
.904 .4749 Mdot
.904 .47553 Mdot
.904 .47602 Mdot
.904 .47649 Mdot
.904 .4773 Mdot
.904 .4776 Mdot
.904 .47791 Mdot
.904 .47851 Mdot
.904 .47899 Mdot
.904 .47916 Mdot
.904 .48026 Mdot
.904 .48046 Mdot
.904 .48076 Mdot
.904 .48147 Mdot
.904 .48161 Mdot
.904 .48261 Mdot
.904 .4828 Mdot
.904 .48287 Mdot
.904 .48409 Mdot
.904 .48482 Mdot
.904 .48485 Mdot
.904 .48516 Mdot
.904 .48552 Mdot
.904 .48563 Mdot
.904 .48588 Mdot
.904 .48618 Mdot
.904 .4869 Mdot
.904 .48745 Mdot
.904 .48866 Mdot
.904 .48999 Mdot
.904 .49004 Mdot
.904 .4905 Mdot
.904 .49062 Mdot
.904 .49111 Mdot
.904 .49112 Mdot
.904 .49132 Mdot
.904 .49137 Mdot
.904 .49172 Mdot
.904 .49253 Mdot
.904 .49267 Mdot
.904 .4929 Mdot
.904 .4932 Mdot
.904 .49331 Mdot
.904 .4934 Mdot
.904 .49442 Mdot
.904 .49454 Mdot
.904 .49466 Mdot
.904 .49479 Mdot
.904 .49546 Mdot
.904 .49557 Mdot
.904 .49568 Mdot
.904 .49592 Mdot
.904 .49604 Mdot
.904 .49605 Mdot
.904 .4967 Mdot
.904 .49684 Mdot
.904 .49716 Mdot
.904 .49727 Mdot
.904 .49732 Mdot
.904 .49808 Mdot
.904 .49876 Mdot
.904 .49958 Mdot
.904 .50008 Mdot
.904 .50012 Mdot
.904 .50085 Mdot
.904 .50108 Mdot
.904 .5011 Mdot
.904 .50165 Mdot
.904 .50228 Mdot
.904 .50238 Mdot
.904 .50337 Mdot
.904 .50376 Mdot
.904 .50383 Mdot
.904 .50449 Mdot
.904 .5047 Mdot
.904 .50534 Mdot
.904 .50551 Mdot
.904 .50556 Mdot
.904 .50563 Mdot
.904 .50626 Mdot
.904 .5068 Mdot
.904 .50723 Mdot
.904 .50728 Mdot
.904 .50766 Mdot
.904 .50777 Mdot
.904 .50781 Mdot
.904 .50782 Mdot
.904 .50849 Mdot
.904 .50874 Mdot
.904 .50903 Mdot
.904 .50907 Mdot
.904 .50914 Mdot
.904 .50916 Mdot
.904 .50917 Mdot
.904 .50964 Mdot
.904 .50972 Mdot
.904 .51018 Mdot
.904 .51025 Mdot
.904 .51028 Mdot
.904 .51052 Mdot
.904 .51057 Mdot
.904 .51058 Mdot
.904 .5106 Mdot
.904 .51079 Mdot
.904 .51093 Mdot
.904 .51101 Mdot
.904 .51126 Mdot
.904 .51144 Mdot
.904 .51152 Mdot
.904 .51254 Mdot
.904 .51287 Mdot
.904 .51299 Mdot
.904 .51308 Mdot
.904 .51328 Mdot
.904 .51379 Mdot
.904 .51387 Mdot
.904 .51412 Mdot
.904 .51424 Mdot
.904 .51444 Mdot
.904 .51467 Mdot
.904 .51485 Mdot
.904 .51487 Mdot
.904 .515 Mdot
.904 .51511 Mdot
.904 .51533 Mdot
.904 .51545 Mdot
.904 .51549 Mdot
.904 .51558 Mdot
.904 .51594 Mdot
.904 .51605 Mdot
.904 .51618 Mdot
.904 .51623 Mdot
.904 .51651 Mdot
.904 .51658 Mdot
.904 .51661 Mdot
.904 .51707 Mdot
.904 .51719 Mdot
.904 .51751 Mdot
.904 .51771 Mdot
.904 .51785 Mdot
.904 .51787 Mdot
.904 .51793 Mdot
.904 .51795 Mdot
.904 .51834 Mdot
.904 .51838 Mdot
.904 .5187 Mdot
.904 .51871 Mdot
.904 .51873 Mdot
.904 .51874 Mdot
.904 .5188 Mdot
.904 .51902 Mdot
.904 .5193 Mdot
.904 .51942 Mdot
.904 .51944 Mdot
.904 .51968 Mdot
.904 .51972 Mdot
.904 .51974 Mdot
.904 .51987 Mdot
.904 .51992 Mdot
.904 .51998 Mdot
.904 .52022 Mdot
.904 .52027 Mdot
.904 .52068 Mdot
.904 .52089 Mdot
.904 .52128 Mdot
.904 .52138 Mdot
.904 .52148 Mdot
.904 .52163 Mdot
.904 .52164 Mdot
.904 .52166 Mdot
.904 .52176 Mdot
.904 .52179 Mdot
.904 .52199 Mdot
.904 .52217 Mdot
.904 .5222 Mdot
.904 .52222 Mdot
.904 .52232 Mdot
.904 .52266 Mdot
.904 .52268 Mdot
.904 .52272 Mdot
.904 .52287 Mdot
.904 .52322 Mdot
.904 .52344 Mdot
.904 .52347 Mdot
.904 .52355 Mdot
.904 .52377 Mdot
.904 .52384 Mdot
.904 .52407 Mdot
.904 .52482 Mdot
.904 .52501 Mdot
.904 .52508 Mdot
.904 .52534 Mdot
.904 .52551 Mdot
.904 .52577 Mdot
.904 .526 Mdot
.904 .52624 Mdot
.904 .52626 Mdot
.904 .52629 Mdot
.904 .52665 Mdot
.904 .52676 Mdot
.904 .5268 Mdot
.904 .52683 Mdot
.904 .52704 Mdot
.904 .52708 Mdot
.904 .52747 Mdot
.904 .5277 Mdot
.904 .52799 Mdot
.904 .52809 Mdot
.904 .52817 Mdot
.904 .52832 Mdot
.904 .52891 Mdot
.904 .52926 Mdot
.904 .52963 Mdot
.904 .52979 Mdot
.904 .52982 Mdot
.904 .53001 Mdot
.904 .53023 Mdot
.904 .5306 Mdot
.904 .53093 Mdot
.904 .53097 Mdot
.904 .53131 Mdot
.904 .53195 Mdot
.904 .53233 Mdot
.904 .53246 Mdot
.904 .53276 Mdot
.904 .53316 Mdot
.904 .53316 Mdot
.904 .53328 Mdot
.904 .53351 Mdot
.904 .5338 Mdot
.904 .53384 Mdot
.904 .53385 Mdot
.904 .53393 Mdot
.904 .53404 Mdot
.904 .53429 Mdot
.904 .53434 Mdot
.904 .53445 Mdot
.904 .5347 Mdot
.904 .53514 Mdot
.904 .53526 Mdot
.904 .53532 Mdot
.904 .53594 Mdot
.904 .53595 Mdot
.904 .53598 Mdot
.904 .53608 Mdot
.904 .53614 Mdot
.904 .53635 Mdot
.904 .53654 Mdot
.904 .53673 Mdot
.904 .53688 Mdot
.904 .5371 Mdot
.904 .53777 Mdot
.904 .53778 Mdot
.904 .53781 Mdot
.904 .53784 Mdot
.904 .53798 Mdot
.904 .53836 Mdot
.904 .53845 Mdot
.904 .53852 Mdot
.904 .53855 Mdot
.904 .53904 Mdot
.904 .53967 Mdot
.904 .53973 Mdot
.904 .53994 Mdot
.904 .54025 Mdot
.904 .54038 Mdot
.904 .54046 Mdot
.904 .54051 Mdot
.904 .54069 Mdot
.904 .54094 Mdot
.904 .54107 Mdot
.904 .54134 Mdot
.904 .54155 Mdot
.904 .54198 Mdot
.904 .54214 Mdot
.904 .54218 Mdot
.904 .5422 Mdot
.904 .54224 Mdot
.904 .54259 Mdot
.904 .54318 Mdot
.904 .54342 Mdot
.904 .54349 Mdot
.904 .54372 Mdot
.904 .54374 Mdot
.904 .54395 Mdot
.904 .54396 Mdot
.904 .54419 Mdot
.904 .54426 Mdot
.904 .54434 Mdot
.904 .54436 Mdot
.904 .54442 Mdot
.904 .5445 Mdot
.904 .5446 Mdot
.904 .54495 Mdot
.904 .54497 Mdot
.904 .54502 Mdot
.904 .54525 Mdot
.904 .5453 Mdot
.904 .54565 Mdot
.904 .54585 Mdot
.904 .54594 Mdot
.904 .54622 Mdot
.904 .54624 Mdot
.904 .54627 Mdot
.904 .54631 Mdot
.904 .54632 Mdot
.904 .54636 Mdot
.904 .5464 Mdot
.904 .54645 Mdot
.904 .54648 Mdot
.904 .54656 Mdot
.904 .54657 Mdot
.904 .54659 Mdot
.904 .54659 Mdot
.904 .54659 Mdot
.904 .54663 Mdot
.904 .54664 Mdot
.904 .54664 Mdot
.904 .54666 Mdot
.904 .54668 Mdot
.904 .5467 Mdot
.904 .54677 Mdot
.904 .54678 Mdot
.904 .54679 Mdot
.904 .54679 Mdot
.904 .5468 Mdot
.904 .5468 Mdot
.904 .54682 Mdot
.904 .54683 Mdot
.904 .54683 Mdot
.904 .54683 Mdot
.906 .16992 Mdot
.906 .16994 Mdot
.906 .16996 Mdot
.906 .17 Mdot
.906 .17002 Mdot
.906 .17002 Mdot
.906 .17009 Mdot
.906 .17015 Mdot
.906 .17021 Mdot
.906 .1703 Mdot
.906 .17034 Mdot
.906 .17061 Mdot
.906 .17067 Mdot
.906 .17075 Mdot
.906 .17086 Mdot
.906 .17096 Mdot
.906 .17129 Mdot
.906 .17135 Mdot
.906 .17139 Mdot
.906 .17141 Mdot
.906 .17145 Mdot
.906 .17186 Mdot
.906 .17192 Mdot
.906 .17201 Mdot
.906 .17223 Mdot
.906 .17224 Mdot
.906 .1728 Mdot
.906 .17295 Mdot
.906 .17312 Mdot
.906 .17352 Mdot
.906 .17362 Mdot
.906 .17364 Mdot
.906 .17378 Mdot
.906 .17385 Mdot
.906 .17406 Mdot
.906 .17407 Mdot
.906 .17465 Mdot
.906 .17469 Mdot
.906 .17482 Mdot
.906 .17488 Mdot
.906 .17512 Mdot
.906 .17532 Mdot
.906 .17769 Mdot
.906 .17796 Mdot
.906 .17873 Mdot
.906 .17874 Mdot
.906 .17921 Mdot
.906 .17967 Mdot
.906 .17999 Mdot
.906 .18015 Mdot
.906 .18029 Mdot
.906 .18029 Mdot
.906 .181 Mdot
.906 .18126 Mdot
.906 .18212 Mdot
.906 .18239 Mdot
.906 .1826 Mdot
.906 .18314 Mdot
.906 .1839 Mdot
.906 .18394 Mdot
.906 .18411 Mdot
.906 .185 Mdot
.906 .18528 Mdot
.906 .1854 Mdot
.906 .18556 Mdot
.906 .1856 Mdot
.906 .18594 Mdot
.906 .18623 Mdot
.906 .18704 Mdot
.906 .19005 Mdot
.906 .19043 Mdot
.906 .1908 Mdot
.906 .19172 Mdot
.906 .1923 Mdot
.906 .19348 Mdot
.906 .1943 Mdot
.906 .1945 Mdot
.906 .19455 Mdot
.906 .19455 Mdot
.906 .19504 Mdot
.906 .19527 Mdot
.906 .19633 Mdot
.906 .19691 Mdot
.906 .19743 Mdot
.906 .19936 Mdot
.906 .20049 Mdot
.906 .20053 Mdot
.906 .20096 Mdot
.906 .20128 Mdot
.906 .20198 Mdot
.906 .2022 Mdot
.906 .20255 Mdot
.906 .20263 Mdot
.906 .20363 Mdot
.906 .20468 Mdot
.906 .20478 Mdot
.906 .20495 Mdot
.906 .20507 Mdot
.906 .20543 Mdot
.906 .20563 Mdot
.906 .20569 Mdot
.906 .2057 Mdot
.906 .206 Mdot
.906 .20634 Mdot
.906 .20639 Mdot
.906 .20691 Mdot
.906 .20693 Mdot
.906 .20698 Mdot
.906 .20763 Mdot
.906 .20783 Mdot
.906 .20831 Mdot
.906 .20851 Mdot
.906 .20893 Mdot
.906 .20897 Mdot
.906 .21008 Mdot
.906 .21087 Mdot
.906 .21106 Mdot
.906 .21186 Mdot
.906 .21197 Mdot
.906 .21249 Mdot
.906 .21255 Mdot
.906 .21274 Mdot
.906 .21347 Mdot
.906 .21457 Mdot
.906 .21465 Mdot
.906 .21518 Mdot
.906 .21524 Mdot
.906 .2158 Mdot
.906 .21642 Mdot
.906 .21647 Mdot
.906 .2174 Mdot
.906 .21868 Mdot
.906 .21871 Mdot
.906 .21937 Mdot
.906 .21943 Mdot
.906 .21968 Mdot
.906 .22047 Mdot
.906 .22059 Mdot
.906 .22095 Mdot
.906 .221 Mdot
.906 .2211 Mdot
.906 .22157 Mdot
.906 .22357 Mdot
.906 .2239 Mdot
.906 .22428 Mdot
.906 .22446 Mdot
.906 .22457 Mdot
.906 .22479 Mdot
.906 .22508 Mdot
.906 .22525 Mdot
.906 .22561 Mdot
.906 .22585 Mdot
.906 .22665 Mdot
.906 .22717 Mdot
.906 .22742 Mdot
.906 .22854 Mdot
.906 .22867 Mdot
.906 .22901 Mdot
.906 .22903 Mdot
.906 .23064 Mdot
.906 .23135 Mdot
.906 .23147 Mdot
.906 .23159 Mdot
.906 .23196 Mdot
.906 .23237 Mdot
.906 .23264 Mdot
.906 .2329 Mdot
.906 .23345 Mdot
.906 .23346 Mdot
.906 .23392 Mdot
.906 .23529 Mdot
.906 .23729 Mdot
.906 .23792 Mdot
.906 .23805 Mdot
.906 .23831 Mdot
.906 .23877 Mdot
.906 .23906 Mdot
.906 .23997 Mdot
.906 .24072 Mdot
.906 .24112 Mdot
.906 .24131 Mdot
.906 .24273 Mdot
.906 .24275 Mdot
.906 .24361 Mdot
.906 .24417 Mdot
.906 .2464 Mdot
.906 .24709 Mdot
.906 .24804 Mdot
.906 .24865 Mdot
.906 .24927 Mdot
.906 .2507 Mdot
.906 .25104 Mdot
.906 .25303 Mdot
.906 .25346 Mdot
.906 .25408 Mdot
.906 .25483 Mdot
.906 .25635 Mdot
.906 .25647 Mdot
.906 .25698 Mdot
.906 .25703 Mdot
.906 .25712 Mdot
.906 .25731 Mdot
.906 .25747 Mdot
.906 .25994 Mdot
.906 .2606 Mdot
.906 .26109 Mdot
.906 .26177 Mdot
.906 .2621 Mdot
.906 .26352 Mdot
.906 .26402 Mdot
.906 .26412 Mdot
.906 .2652 Mdot
.906 .26638 Mdot
.906 .26639 Mdot
.906 .26693 Mdot
.906 .26715 Mdot
.906 .26756 Mdot
.906 .26836 Mdot
.906 .26898 Mdot
.906 .26903 Mdot
.906 .26938 Mdot
.906 .27003 Mdot
.906 .2703 Mdot
.906 .27106 Mdot
.906 .27383 Mdot
.906 .27399 Mdot
.906 .27434 Mdot
.906 .27598 Mdot
.906 .27642 Mdot
.906 .27712 Mdot
.906 .28015 Mdot
.906 .2814 Mdot
.906 .28144 Mdot
.906 .28296 Mdot
.906 .28368 Mdot
.906 .2842 Mdot
.906 .28441 Mdot
.906 .28556 Mdot
.906 .2866 Mdot
.906 .28692 Mdot
.906 .28728 Mdot
.906 .28928 Mdot
.906 .29384 Mdot
.906 .2939 Mdot
.906 .29485 Mdot
.906 .29487 Mdot
.906 .29525 Mdot
.906 .29723 Mdot
.906 .29844 Mdot
.906 .29846 Mdot
.906 .29921 Mdot
.906 .30071 Mdot
.906 .30196 Mdot
.906 .30303 Mdot
.906 .30376 Mdot
.906 .30479 Mdot
.906 .30529 Mdot
.906 .30617 Mdot
.906 .30682 Mdot
.906 .30682 Mdot
.906 .30712 Mdot
.906 .30765 Mdot
.906 .30879 Mdot
.906 .30977 Mdot
.906 .31233 Mdot
.906 .31349 Mdot
.906 .31535 Mdot
.906 .31574 Mdot
.906 .31715 Mdot
.906 .31746 Mdot
.906 .3175 Mdot
.906 .31761 Mdot
.906 .3187 Mdot
.906 .31907 Mdot
.906 .32113 Mdot
.906 .32148 Mdot
.906 .32222 Mdot
.906 .3224 Mdot
.906 .32245 Mdot
.906 .32269 Mdot
.906 .32442 Mdot
.906 .32453 Mdot
.906 .3249 Mdot
.906 .32521 Mdot
.906 .32843 Mdot
.906 .32971 Mdot
.906 .32971 Mdot
.906 .33026 Mdot
.906 .33132 Mdot
.906 .33147 Mdot
.906 .33223 Mdot
.906 .33338 Mdot
.906 .33513 Mdot
.906 .3353 Mdot
.906 .33611 Mdot
.906 .33637 Mdot
.906 .33648 Mdot
.906 .33696 Mdot
.906 .33721 Mdot
.906 .34036 Mdot
.906 .34065 Mdot
.906 .34295 Mdot
.906 .34354 Mdot
.906 .34368 Mdot
.906 .34372 Mdot
.906 .34497 Mdot
.906 .34536 Mdot
.906 .34571 Mdot
.906 .34773 Mdot
.906 .34824 Mdot
.906 .34882 Mdot
.906 .35034 Mdot
.906 .3504 Mdot
.906 .35057 Mdot
.906 .35079 Mdot
.906 .35095 Mdot
.906 .35095 Mdot
.906 .35133 Mdot
.906 .35136 Mdot
.906 .35171 Mdot
.906 .35209 Mdot
.906 .3522 Mdot
.906 .35248 Mdot
.906 .35259 Mdot
.906 .35284 Mdot
.906 .35349 Mdot
.906 .35448 Mdot
.906 .35483 Mdot
.906 .35486 Mdot
.906 .35497 Mdot
.906 .35536 Mdot
.906 .356 Mdot
.906 .35632 Mdot
.906 .35662 Mdot
.906 .35694 Mdot
.906 .35814 Mdot
.906 .35848 Mdot
.906 .35851 Mdot
.906 .35863 Mdot
.906 .35904 Mdot
.906 .3591 Mdot
.906 .35928 Mdot
.906 .35931 Mdot
.906 .35936 Mdot
.906 .35959 Mdot
.906 .36119 Mdot
.906 .36133 Mdot
.906 .36141 Mdot
.906 .36209 Mdot
.906 .36234 Mdot
.906 .36246 Mdot
.906 .36299 Mdot
.906 .36306 Mdot
.906 .36322 Mdot
.906 .36431 Mdot
.906 .36437 Mdot
.906 .36442 Mdot
.906 .36479 Mdot
.906 .36491 Mdot
.906 .36528 Mdot
.906 .36529 Mdot
.906 .36549 Mdot
.906 .36612 Mdot
.906 .3673 Mdot
.906 .36747 Mdot
.906 .36767 Mdot
.906 .3678 Mdot
.906 .3682 Mdot
.906 .36853 Mdot
.906 .3687 Mdot
.906 .3694 Mdot
.906 .36978 Mdot
.906 .37126 Mdot
.906 .37191 Mdot
.906 .37217 Mdot
.906 .37276 Mdot
.906 .3729 Mdot
.906 .37372 Mdot
.906 .37414 Mdot
.906 .37506 Mdot
.906 .37511 Mdot
.906 .37537 Mdot
.906 .37544 Mdot
.906 .37551 Mdot
.906 .37649 Mdot
.906 .37721 Mdot
.906 .37789 Mdot
.906 .37812 Mdot
.906 .37854 Mdot
.906 .37899 Mdot
.906 .3792 Mdot
.906 .37944 Mdot
.906 .37998 Mdot
.906 .38038 Mdot
.906 .38049 Mdot
.906 .38181 Mdot
.906 .38187 Mdot
.906 .382 Mdot
.906 .38261 Mdot
.906 .38303 Mdot
.906 .38561 Mdot
.906 .38938 Mdot
.906 .39021 Mdot
.906 .39063 Mdot
.906 .39184 Mdot
.906 .39349 Mdot
.906 .39535 Mdot
.906 .39574 Mdot
.906 .39636 Mdot
.906 .39707 Mdot
.906 .39827 Mdot
.906 .3987 Mdot
.906 .39878 Mdot
.906 .3995 Mdot
.906 .3996 Mdot
.906 .40107 Mdot
.906 .40107 Mdot
.906 .40125 Mdot
.906 .40188 Mdot
.906 .40314 Mdot
.906 .40322 Mdot
.906 .40325 Mdot
.906 .4045 Mdot
.906 .40556 Mdot
.906 .40596 Mdot
.906 .40684 Mdot
.906 .40767 Mdot
.906 .40769 Mdot
.906 .40774 Mdot
.906 .40781 Mdot
.906 .40786 Mdot
.906 .40786 Mdot
.906 .40799 Mdot
.906 .4081 Mdot
.906 .40822 Mdot
.906 .40825 Mdot
.906 .40834 Mdot
.906 .40838 Mdot
.906 .40846 Mdot
.906 .40866 Mdot
.906 .40897 Mdot
.906 .40909 Mdot
.906 .40925 Mdot
.906 .40945 Mdot
.906 .40965 Mdot
.906 .41012 Mdot
.906 .41024 Mdot
.906 .41028 Mdot
.906 .41041 Mdot
.906 .41048 Mdot
.906 .41049 Mdot
.906 .41051 Mdot
.906 .41058 Mdot
.906 .41136 Mdot
.906 .41144 Mdot
.906 .41148 Mdot
.906 .41165 Mdot
.906 .41208 Mdot
.906 .41209 Mdot
.906 .41221 Mdot
.906 .41225 Mdot
.906 .41305 Mdot
.906 .41315 Mdot
.906 .41343 Mdot
.906 .41365 Mdot
.906 .41377 Mdot
.906 .41423 Mdot
.906 .41451 Mdot
.906 .4147 Mdot
.906 .41474 Mdot
.906 .41499 Mdot
.906 .41513 Mdot
.906 .41541 Mdot
.906 .41553 Mdot
.906 .41555 Mdot
.906 .41629 Mdot
.906 .41637 Mdot
.906 .41649 Mdot
.906 .41664 Mdot
.906 .4167 Mdot
.906 .41694 Mdot
.906 .41707 Mdot
.906 .41751 Mdot
.906 .41776 Mdot
.906 .41789 Mdot
.906 .41987 Mdot
.906 .42012 Mdot
.906 .42025 Mdot
.906 .42184 Mdot
.906 .42204 Mdot
.906 .42226 Mdot
.906 .42263 Mdot
.906 .42277 Mdot
.906 .42305 Mdot
.906 .42415 Mdot
.906 .42418 Mdot
.906 .42419 Mdot
.906 .42491 Mdot
.906 .42504 Mdot
.906 .42531 Mdot
.906 .42578 Mdot
.906 .42588 Mdot
.906 .42638 Mdot
.906 .42646 Mdot
.906 .42676 Mdot
.906 .427 Mdot
.906 .42701 Mdot
.906 .42745 Mdot
.906 .42828 Mdot
.906 .42831 Mdot
.906 .42835 Mdot
.906 .42875 Mdot
.906 .42941 Mdot
.906 .42949 Mdot
.906 .42954 Mdot
.906 .43004 Mdot
.906 .4301 Mdot
.906 .43029 Mdot
.906 .43042 Mdot
.906 .43077 Mdot
.906 .43114 Mdot
.906 .43129 Mdot
.906 .43148 Mdot
.906 .4321 Mdot
.906 .43248 Mdot
.906 .43268 Mdot
.906 .43312 Mdot
.906 .43344 Mdot
.906 .4335 Mdot
.906 .43365 Mdot
.906 .43382 Mdot
.906 .43404 Mdot
.906 .43434 Mdot
.906 .43459 Mdot
.906 .4347 Mdot
.906 .43526 Mdot
.906 .43537 Mdot
.906 .43586 Mdot
.906 .43604 Mdot
.906 .43608 Mdot
.906 .43636 Mdot
.906 .43638 Mdot
.906 .43643 Mdot
.906 .43702 Mdot
.906 .43704 Mdot
.906 .43752 Mdot
.906 .43811 Mdot
.906 .43844 Mdot
.906 .4387 Mdot
.906 .43892 Mdot
.906 .43934 Mdot
.906 .43994 Mdot
.906 .44017 Mdot
.906 .44049 Mdot
.906 .4406 Mdot
.906 .44146 Mdot
.906 .44153 Mdot
.906 .44167 Mdot
.906 .4428 Mdot
.906 .44348 Mdot
.906 .44355 Mdot
.906 .44359 Mdot
.906 .44406 Mdot
.906 .44469 Mdot
.906 .445 Mdot
.906 .44531 Mdot
.906 .44574 Mdot
.906 .44576 Mdot
.906 .44616 Mdot
.906 .44666 Mdot
.906 .44679 Mdot
.906 .44685 Mdot
.906 .44762 Mdot
.906 .44778 Mdot
.906 .44783 Mdot
.906 .44856 Mdot
.906 .44902 Mdot
.906 .44923 Mdot
.906 .44977 Mdot
.906 .45041 Mdot
.906 .45043 Mdot
.906 .45047 Mdot
.906 .45111 Mdot
.906 .45144 Mdot
.906 .45153 Mdot
.906 .45153 Mdot
.906 .45227 Mdot
.906 .45233 Mdot
.906 .45269 Mdot
.906 .45273 Mdot
.906 .45295 Mdot
.906 .45356 Mdot
.906 .45391 Mdot
.906 .45423 Mdot
.906 .45442 Mdot
.906 .45535 Mdot
.906 .45617 Mdot
.906 .45677 Mdot
.906 .45698 Mdot
.906 .45739 Mdot
.906 .45924 Mdot
.906 .4605 Mdot
.906 .46071 Mdot
.906 .461 Mdot
.906 .46106 Mdot
.906 .46109 Mdot
.906 .46173 Mdot
.906 .46178 Mdot
.906 .46197 Mdot
.906 .46223 Mdot
.906 .46235 Mdot
.906 .46245 Mdot
.906 .46267 Mdot
.906 .46287 Mdot
.906 .46298 Mdot
.906 .46331 Mdot
.906 .46365 Mdot
.906 .46412 Mdot
.906 .46415 Mdot
.906 .46419 Mdot
.906 .46431 Mdot
.906 .46434 Mdot
.906 .46477 Mdot
.906 .46497 Mdot
.906 .46536 Mdot
.906 .46543 Mdot
.906 .46571 Mdot
.906 .46583 Mdot
.906 .46614 Mdot
.906 .46684 Mdot
.906 .46702 Mdot
.906 .46734 Mdot
.906 .46742 Mdot
.906 .46758 Mdot
.906 .46777 Mdot
.906 .46783 Mdot
.906 .46792 Mdot
.906 .468 Mdot
.906 .46855 Mdot
.906 .46884 Mdot
.906 .46894 Mdot
.906 .46894 Mdot
.906 .46912 Mdot
.906 .46917 Mdot
.906 .46934 Mdot
.906 .46937 Mdot
.906 .4694 Mdot
.906 .4699 Mdot
.906 .46998 Mdot
.906 .47001 Mdot
.906 .47025 Mdot
.906 .47031 Mdot
.906 .47043 Mdot
.906 .47074 Mdot
.906 .47078 Mdot
.906 .47084 Mdot
.906 .47158 Mdot
.906 .47169 Mdot
.906 .47171 Mdot
.906 .47172 Mdot
.906 .47181 Mdot
.906 .47183 Mdot
.906 .47202 Mdot
.906 .47208 Mdot
.906 .47209 Mdot
.906 .47225 Mdot
.906 .4728 Mdot
.906 .47295 Mdot
.906 .47308 Mdot
.906 .47323 Mdot
.906 .47352 Mdot
.906 .4737 Mdot
.906 .47375 Mdot
.906 .47376 Mdot
.906 .47392 Mdot
.906 .47437 Mdot
.906 .47467 Mdot
.906 .47478 Mdot
.906 .47483 Mdot
.906 .47496 Mdot
.906 .47501 Mdot
.906 .47518 Mdot
.906 .47534 Mdot
.906 .47535 Mdot
.906 .47553 Mdot
.906 .47553 Mdot
.906 .4756 Mdot
.906 .4757 Mdot
.906 .47577 Mdot
.906 .4758 Mdot
.906 .47649 Mdot
.906 .47675 Mdot
.906 .47698 Mdot
.906 .47788 Mdot
.906 .47804 Mdot
.906 .47822 Mdot
.906 .47878 Mdot
.906 .47879 Mdot
.906 .47886 Mdot
.906 .47912 Mdot
.906 .48014 Mdot
.906 .48027 Mdot
.906 .48167 Mdot
.906 .48178 Mdot
.906 .48199 Mdot
.906 .48204 Mdot
.906 .48215 Mdot
.906 .48251 Mdot
.906 .48258 Mdot
.906 .48335 Mdot
.906 .48385 Mdot
.906 .48418 Mdot
.906 .48425 Mdot
.906 .48471 Mdot
.906 .48495 Mdot
.906 .48495 Mdot
.906 .48551 Mdot
.906 .48691 Mdot
.906 .48704 Mdot
.906 .4872 Mdot
.906 .48724 Mdot
.906 .48799 Mdot
.906 .4881 Mdot
.906 .48811 Mdot
.906 .48819 Mdot
.906 .48851 Mdot
.906 .48866 Mdot
.906 .48955 Mdot
.906 .4897 Mdot
.906 .49017 Mdot
.906 .49021 Mdot
.906 .49023 Mdot
.906 .49036 Mdot
.906 .49096 Mdot
.906 .49113 Mdot
.906 .49192 Mdot
.906 .49241 Mdot
.906 .49349 Mdot
.906 .49391 Mdot
.906 .49439 Mdot
.906 .49461 Mdot
.906 .49474 Mdot
.906 .49474 Mdot
.906 .49501 Mdot
.906 .49538 Mdot
.906 .49559 Mdot
.906 .49602 Mdot
.906 .49632 Mdot
.906 .49677 Mdot
.906 .49729 Mdot
.906 .49792 Mdot
.906 .49823 Mdot
.906 .49823 Mdot
.906 .49873 Mdot
.906 .49956 Mdot
.906 .49971 Mdot
.906 .49972 Mdot
.906 .50011 Mdot
.906 .50014 Mdot
.906 .50201 Mdot
.906 .50283 Mdot
.906 .50297 Mdot
.906 .50311 Mdot
.906 .50353 Mdot
.906 .504 Mdot
.906 .50408 Mdot
.906 .5043 Mdot
.906 .50459 Mdot
.906 .50521 Mdot
.906 .50522 Mdot
.906 .50573 Mdot
.906 .50696 Mdot
.906 .50724 Mdot
.906 .50742 Mdot
.906 .50808 Mdot
.906 .50822 Mdot
.906 .50828 Mdot
.906 .50939 Mdot
.906 .50969 Mdot
.906 .5098 Mdot
.906 .51006 Mdot
.906 .51021 Mdot
.906 .51023 Mdot
.906 .51047 Mdot
.906 .51079 Mdot
.906 .51096 Mdot
.906 .51104 Mdot
.906 .51126 Mdot
.906 .51126 Mdot
.906 .51173 Mdot
.906 .51216 Mdot
.906 .5122 Mdot
.906 .5124 Mdot
.906 .51296 Mdot
.906 .51309 Mdot
.906 .51336 Mdot
.906 .51356 Mdot
.906 .51382 Mdot
.906 .5148 Mdot
.906 .51486 Mdot
.906 .51493 Mdot
.906 .51497 Mdot
.906 .51499 Mdot
.906 .51519 Mdot
.906 .51524 Mdot
.906 .51583 Mdot
.906 .51613 Mdot
.906 .51637 Mdot
.906 .51654 Mdot
.906 .51732 Mdot
.906 .51746 Mdot
.906 .51802 Mdot
.906 .51826 Mdot
.906 .5185 Mdot
.906 .51887 Mdot
.906 .51914 Mdot
.906 .52001 Mdot
.906 .52022 Mdot
.906 .52056 Mdot
.906 .52057 Mdot
.906 .52112 Mdot
.906 .52119 Mdot
.906 .52135 Mdot
.906 .52164 Mdot
.906 .52199 Mdot
.906 .5221 Mdot
.906 .52228 Mdot
.906 .52238 Mdot
.906 .52243 Mdot
.906 .52268 Mdot
.906 .52345 Mdot
.906 .52398 Mdot
.906 .52415 Mdot
.906 .52416 Mdot
.906 .52437 Mdot
.906 .52447 Mdot
.906 .52457 Mdot
.906 .52473 Mdot
.906 .52487 Mdot
.906 .52492 Mdot
.906 .52497 Mdot
.906 .52524 Mdot
.906 .52586 Mdot
.906 .52586 Mdot
.906 .52599 Mdot
.906 .52604 Mdot
.906 .52647 Mdot
.906 .52657 Mdot
.906 .52677 Mdot
.906 .52707 Mdot
.906 .52717 Mdot
.906 .5273 Mdot
.906 .52737 Mdot
.906 .52748 Mdot
.906 .52757 Mdot
.906 .5276 Mdot
.906 .52767 Mdot
.906 .52782 Mdot
.906 .52795 Mdot
.906 .52871 Mdot
.906 .52889 Mdot
.906 .52893 Mdot
.906 .52894 Mdot
.906 .52908 Mdot
.906 .52913 Mdot
.906 .52943 Mdot
.906 .52952 Mdot
.906 .52955 Mdot
.906 .5298 Mdot
.906 .52981 Mdot
.906 .53029 Mdot
.906 .53065 Mdot
.906 .53067 Mdot
.906 .5309 Mdot
.906 .53112 Mdot
.906 .53114 Mdot
.906 .53134 Mdot
.906 .53137 Mdot
.906 .53179 Mdot
.906 .53206 Mdot
.906 .53214 Mdot
.906 .53216 Mdot
.906 .53235 Mdot
.906 .5324 Mdot
.906 .5327 Mdot
.906 .53277 Mdot
.906 .53307 Mdot
.906 .53349 Mdot
.906 .5335 Mdot
.906 .53366 Mdot
.906 .53374 Mdot
.906 .53392 Mdot
.906 .53399 Mdot
.906 .53424 Mdot
.906 .53426 Mdot
.906 .53426 Mdot
.906 .53446 Mdot
.906 .53448 Mdot
.906 .53461 Mdot
.906 .53472 Mdot
.906 .53472 Mdot
.906 .53475 Mdot
.906 .53482 Mdot
.906 .53496 Mdot
.906 .535 Mdot
.906 .53506 Mdot
.906 .5351 Mdot
.906 .5355 Mdot
.906 .53587 Mdot
.906 .5359 Mdot
.906 .53603 Mdot
.906 .53612 Mdot
.906 .53638 Mdot
.906 .5365 Mdot
.906 .53666 Mdot
.906 .53668 Mdot
.906 .5371 Mdot
.906 .53782 Mdot
.906 .53802 Mdot
.906 .53823 Mdot
.906 .53863 Mdot
.906 .53871 Mdot
.906 .5389 Mdot
.906 .5389 Mdot
.906 .53892 Mdot
.906 .53899 Mdot
.906 .5393 Mdot
.906 .53974 Mdot
.906 .53995 Mdot
.906 .5403 Mdot
.906 .54043 Mdot
.906 .54057 Mdot
.906 .54169 Mdot
.906 .54199 Mdot
.906 .5421 Mdot
.906 .54223 Mdot
.906 .54224 Mdot
.906 .5423 Mdot
.906 .54235 Mdot
.906 .54245 Mdot
.906 .54278 Mdot
.906 .54284 Mdot
.906 .54286 Mdot
.906 .54314 Mdot
.906 .54334 Mdot
.906 .54341 Mdot
.906 .54351 Mdot
.906 .54383 Mdot
.906 .54393 Mdot
.906 .54419 Mdot
.906 .54419 Mdot
.906 .54424 Mdot
.906 .5443 Mdot
.906 .54442 Mdot
.906 .54459 Mdot
.906 .54477 Mdot
.906 .54477 Mdot
.906 .54505 Mdot
.906 .54515 Mdot
.906 .54603 Mdot
.906 .5461 Mdot
.906 .54619 Mdot
.906 .54621 Mdot
.906 .54626 Mdot
.906 .54627 Mdot
.906 .54649 Mdot
.906 .54649 Mdot
.906 .54657 Mdot
.906 .5466 Mdot
.906 .54665 Mdot
.906 .54665 Mdot
.906 .54669 Mdot
.906 .54684 Mdot
.906 .5469 Mdot
.906 .54696 Mdot
.906 .54716 Mdot
.906 .54716 Mdot
.906 .54725 Mdot
.906 .54728 Mdot
.906 .5473 Mdot
.906 .54745 Mdot
.906 .54747 Mdot
.906 .54747 Mdot
.906 .54749 Mdot
.906 .54751 Mdot
.906 .54763 Mdot
.906 .54767 Mdot
.906 .54771 Mdot
.906 .54774 Mdot
.906 .54776 Mdot
.906 .54786 Mdot
.906 .54788 Mdot
.906 .54791 Mdot
.906 .54793 Mdot
.906 .54795 Mdot
.906 .54797 Mdot
.906 .54797 Mdot
.906 .54798 Mdot
.906 .548 Mdot
.906 .54801 Mdot
.906 .54801 Mdot
.908 .16705 Mdot
.908 .16705 Mdot
.908 .16705 Mdot
.908 .16706 Mdot
.908 .16706 Mdot
.908 .16707 Mdot
.908 .16708 Mdot
.908 .16714 Mdot
.908 .16721 Mdot
.908 .16721 Mdot
.908 .16722 Mdot
.908 .16722 Mdot
.908 .16726 Mdot
.908 .16734 Mdot
.908 .16747 Mdot
.908 .16747 Mdot
.908 .16759 Mdot
.908 .16759 Mdot
.908 .16779 Mdot
.908 .16808 Mdot
.908 .16835 Mdot
.908 .16838 Mdot
.908 .16852 Mdot
.908 .1687 Mdot
.908 .16938 Mdot
.908 .16951 Mdot
.908 .16954 Mdot
.908 .1696 Mdot
.908 .16989 Mdot
.908 .17054 Mdot
.908 .17101 Mdot
.908 .17116 Mdot
.908 .17127 Mdot
.908 .17156 Mdot
.908 .17167 Mdot
.908 .17192 Mdot
.908 .17259 Mdot
.908 .17272 Mdot
.908 .17326 Mdot
.908 .17352 Mdot
.908 .17387 Mdot
.908 .17426 Mdot
.908 .17436 Mdot
.908 .17451 Mdot
.908 .17517 Mdot
.908 .17594 Mdot
.908 .17601 Mdot
.908 .17668 Mdot
.908 .17803 Mdot
.908 .17839 Mdot
.908 .17869 Mdot
.908 .17983 Mdot
.908 .17983 Mdot
.908 .17985 Mdot
.908 .17988 Mdot
.908 .17989 Mdot
.908 .17998 Mdot
.908 .18001 Mdot
.908 .18025 Mdot
.908 .18041 Mdot
.908 .18086 Mdot
.908 .18086 Mdot
.908 .18089 Mdot
.908 .18091 Mdot
.908 .1812 Mdot
.908 .18172 Mdot
.908 .18258 Mdot
.908 .18259 Mdot
.908 .18288 Mdot
.908 .18338 Mdot
.908 .18343 Mdot
.908 .18348 Mdot
.908 .18406 Mdot
.908 .18449 Mdot
.908 .18468 Mdot
.908 .18492 Mdot
.908 .18656 Mdot
.908 .18661 Mdot
.908 .1871 Mdot
.908 .18736 Mdot
.908 .1883 Mdot
.908 .1893 Mdot
.908 .1895 Mdot
.908 .19073 Mdot
.908 .19202 Mdot
.908 .19225 Mdot
.908 .19241 Mdot
.908 .19259 Mdot
.908 .193 Mdot
.908 .19322 Mdot
.908 .19327 Mdot
.908 .19332 Mdot
.908 .19431 Mdot
.908 .19562 Mdot
.908 .19582 Mdot
.908 .19585 Mdot
.908 .19603 Mdot
.908 .19696 Mdot
.908 .19707 Mdot
.908 .19785 Mdot
.908 .19841 Mdot
.908 .19865 Mdot
.908 .19923 Mdot
.908 .19988 Mdot
.908 .19991 Mdot
.908 .20016 Mdot
.908 .20074 Mdot
.908 .20074 Mdot
.908 .20091 Mdot
.908 .20115 Mdot
.908 .20164 Mdot
.908 .20175 Mdot
.908 .20198 Mdot
.908 .20236 Mdot
.908 .20293 Mdot
.908 .20376 Mdot
.908 .20377 Mdot
.908 .20383 Mdot
.908 .20459 Mdot
.908 .20586 Mdot
.908 .20626 Mdot
.908 .2078 Mdot
.908 .20795 Mdot
.908 .20885 Mdot
.908 .20975 Mdot
.908 .20997 Mdot
.908 .20999 Mdot
.908 .2109 Mdot
.908 .21109 Mdot
.908 .21183 Mdot
.908 .21324 Mdot
.908 .21421 Mdot
.908 .21569 Mdot
.908 .21641 Mdot
.908 .21778 Mdot
.908 .2183 Mdot
.908 .21959 Mdot
.908 .2197 Mdot
.908 .22042 Mdot
.908 .22056 Mdot
.908 .22087 Mdot
.908 .22227 Mdot
.908 .22227 Mdot
.908 .22319 Mdot
.908 .2232 Mdot
.908 .22334 Mdot
.908 .22341 Mdot
.908 .22342 Mdot
.908 .22359 Mdot
.908 .22389 Mdot
.908 .22415 Mdot
.908 .22444 Mdot
.908 .22469 Mdot
.908 .22469 Mdot
.908 .22686 Mdot
.908 .22692 Mdot
.908 .22757 Mdot
.908 .22786 Mdot
.908 .22795 Mdot
.908 .22802 Mdot
.908 .22838 Mdot
.908 .22958 Mdot
.908 .23026 Mdot
.908 .23557 Mdot
.908 .23565 Mdot
.908 .2359 Mdot
.908 .23708 Mdot
.908 .23747 Mdot
.908 .23771 Mdot
.908 .23898 Mdot
.908 .23967 Mdot
.908 .24061 Mdot
.908 .24156 Mdot
.908 .24162 Mdot
.908 .24207 Mdot
.908 .24211 Mdot
.908 .24468 Mdot
.908 .24472 Mdot
.908 .24681 Mdot
.908 .24683 Mdot
.908 .24814 Mdot
.908 .24855 Mdot
.908 .2498 Mdot
.908 .2499 Mdot
.908 .25073 Mdot
.908 .25312 Mdot
.908 .25609 Mdot
.908 .25624 Mdot
.908 .25632 Mdot
.908 .25642 Mdot
.908 .25756 Mdot
.908 .25771 Mdot
.908 .25778 Mdot
.908 .25813 Mdot
.908 .2591 Mdot
.908 .26016 Mdot
.908 .26219 Mdot
.908 .26258 Mdot
.908 .26319 Mdot
.908 .26331 Mdot
.908 .2638 Mdot
.908 .26439 Mdot
.908 .26525 Mdot
.908 .26621 Mdot
.908 .26666 Mdot
.908 .26669 Mdot
.908 .26775 Mdot
.908 .26825 Mdot
.908 .2684 Mdot
.908 .2685 Mdot
.908 .26901 Mdot
.908 .26943 Mdot
.908 .27081 Mdot
.908 .27175 Mdot
.908 .27263 Mdot
.908 .2733 Mdot
.908 .27352 Mdot
.908 .27393 Mdot
.908 .27421 Mdot
.908 .27693 Mdot
.908 .27997 Mdot
.908 .28533 Mdot
.908 .28563 Mdot
.908 .28748 Mdot
.908 .28833 Mdot
.908 .29007 Mdot
.908 .29026 Mdot
.908 .29137 Mdot
.908 .29173 Mdot
.908 .2927 Mdot
.908 .29371 Mdot
.908 .29478 Mdot
.908 .29496 Mdot
.908 .29523 Mdot
.908 .29607 Mdot
.908 .29797 Mdot
.908 .29815 Mdot
.908 .30013 Mdot
.908 .30112 Mdot
.908 .30306 Mdot
.908 .30455 Mdot
.908 .30455 Mdot
.908 .30529 Mdot
.908 .30618 Mdot
.908 .30693 Mdot
.908 .30785 Mdot
.908 .30834 Mdot
.908 .30838 Mdot
.908 .3086 Mdot
.908 .30901 Mdot
.908 .30903 Mdot
.908 .31011 Mdot
.908 .31181 Mdot
.908 .31182 Mdot
.908 .31185 Mdot
.908 .31222 Mdot
.908 .31411 Mdot
.908 .31414 Mdot
.908 .31606 Mdot
.908 .31701 Mdot
.908 .31744 Mdot
.908 .31962 Mdot
.908 .31996 Mdot
.908 .32071 Mdot
.908 .32377 Mdot
.908 .32394 Mdot
.908 .32555 Mdot
.908 .32716 Mdot
.908 .32767 Mdot
.908 .32881 Mdot
.908 .32982 Mdot
.908 .33205 Mdot
.908 .33387 Mdot
.908 .33387 Mdot
.908 .33389 Mdot
.908 .33393 Mdot
.908 .33393 Mdot
.908 .33402 Mdot
.908 .33405 Mdot
.908 .33428 Mdot
.908 .33443 Mdot
.908 .33486 Mdot
.908 .33487 Mdot
.908 .33489 Mdot
.908 .33491 Mdot
.908 .33518 Mdot
.908 .33566 Mdot
.908 .33644 Mdot
.908 .33644 Mdot
.908 .3367 Mdot
.908 .33713 Mdot
.908 .33717 Mdot
.908 .33722 Mdot
.908 .33771 Mdot
.908 .33824 Mdot
.908 .33844 Mdot
.908 .33977 Mdot
.908 .33981 Mdot
.908 .3402 Mdot
.908 .3404 Mdot
.908 .34188 Mdot
.908 .34203 Mdot
.908 .34293 Mdot
.908 .34401 Mdot
.908 .34425 Mdot
.908 .34468 Mdot
.908 .34472 Mdot
.908 .34643 Mdot
.908 .34646 Mdot
.908 .34658 Mdot
.908 .34718 Mdot
.908 .34775 Mdot
.908 .34811 Mdot
.908 .34826 Mdot
.908 .34903 Mdot
.908 .3492 Mdot
.908 .34956 Mdot
.908 .3501 Mdot
.908 .35017 Mdot
.908 .35054 Mdot
.908 .35087 Mdot
.908 .35136 Mdot
.908 .35258 Mdot
.908 .35376 Mdot
.908 .35488 Mdot
.908 .35538 Mdot
.908 .35662 Mdot
.908 .35713 Mdot
.908 .35827 Mdot
.908 .35922 Mdot
.908 .35987 Mdot
.908 .36118 Mdot
.908 .36118 Mdot
.908 .36163 Mdot
.908 .3617 Mdot
.908 .36173 Mdot
.908 .36209 Mdot
.908 .36223 Mdot
.908 .36235 Mdot
.908 .36235 Mdot
.908 .36337 Mdot
.908 .3634 Mdot
.908 .3637 Mdot
.908 .36384 Mdot
.908 .36388 Mdot
.908 .36391 Mdot
.908 .36408 Mdot
.908 .36463 Mdot
.908 .36736 Mdot
.908 .36747 Mdot
.908 .36799 Mdot
.908 .36881 Mdot
.908 .36911 Mdot
.908 .36994 Mdot
.908 .37013 Mdot
.908 .37015 Mdot
.908 .37212 Mdot
.908 .37212 Mdot
.908 .37266 Mdot
.908 .37283 Mdot
.908 .37372 Mdot
.908 .37468 Mdot
.908 .37586 Mdot
.908 .37592 Mdot
.908 .37652 Mdot
.908 .37666 Mdot
.908 .37704 Mdot
.908 .37823 Mdot
.908 .37862 Mdot
.908 .37866 Mdot
.908 .37885 Mdot
.908 .3794 Mdot
.908 .37977 Mdot
.908 .37993 Mdot
.908 .37995 Mdot
.908 .38053 Mdot
.908 .38063 Mdot
.908 .38082 Mdot
.908 .38149 Mdot
.908 .38184 Mdot
.908 .38264 Mdot
.908 .38274 Mdot
.908 .38374 Mdot
.908 .38484 Mdot
.908 .38674 Mdot
.908 .38685 Mdot
.908 .3875 Mdot
.908 .38841 Mdot
.908 .38886 Mdot
.908 .38899 Mdot
.908 .38932 Mdot
.908 .39187 Mdot
.908 .39221 Mdot
.908 .39286 Mdot
.908 .39522 Mdot
.908 .3958 Mdot
.908 .39592 Mdot
.908 .39655 Mdot
.908 .39656 Mdot
.908 .39871 Mdot
.908 .3997 Mdot
.908 .40079 Mdot
.908 .40096 Mdot
.908 .40132 Mdot
.908 .40294 Mdot
.908 .40294 Mdot
.908 .40295 Mdot
.908 .40296 Mdot
.908 .40296 Mdot
.908 .40299 Mdot
.908 .403 Mdot
.908 .40308 Mdot
.908 .40312 Mdot
.908 .40326 Mdot
.908 .40326 Mdot
.908 .40327 Mdot
.908 .40328 Mdot
.908 .40336 Mdot
.908 .40351 Mdot
.908 .40376 Mdot
.908 .40376 Mdot
.908 .40398 Mdot
.908 .404 Mdot
.908 .40401 Mdot
.908 .40417 Mdot
.908 .40433 Mdot
.908 .4044 Mdot
.908 .40483 Mdot
.908 .40495 Mdot
.908 .40502 Mdot
.908 .40548 Mdot
.908 .40553 Mdot
.908 .40582 Mdot
.908 .40616 Mdot
.908 .40637 Mdot
.908 .40638 Mdot
.908 .40692 Mdot
.908 .40693 Mdot
.908 .40733 Mdot
.908 .40744 Mdot
.908 .40749 Mdot
.908 .40773 Mdot
.908 .40779 Mdot
.908 .4079 Mdot
.908 .4082 Mdot
.908 .40846 Mdot
.908 .40956 Mdot
.908 .40972 Mdot
.908 .41062 Mdot
.908 .41091 Mdot
.908 .41111 Mdot
.908 .41152 Mdot
.908 .41152 Mdot
.908 .41166 Mdot
.908 .41168 Mdot
.908 .41169 Mdot
.908 .41185 Mdot
.908 .41188 Mdot
.908 .41188 Mdot
.908 .41221 Mdot
.908 .4123 Mdot
.908 .41234 Mdot
.908 .41236 Mdot
.908 .41237 Mdot
.908 .41242 Mdot
.908 .41259 Mdot
.908 .41343 Mdot
.908 .41363 Mdot
.908 .41388 Mdot
.908 .41398 Mdot
.908 .4149 Mdot
.908 .41491 Mdot
.908 .41507 Mdot
.908 .4154 Mdot
.908 .41606 Mdot
.908 .41626 Mdot
.908 .41679 Mdot
.908 .41692 Mdot
.908 .41698 Mdot
.908 .41726 Mdot
.908 .4175 Mdot
.908 .41753 Mdot
.908 .41759 Mdot
.908 .41779 Mdot
.908 .41849 Mdot
.908 .41945 Mdot
.908 .41992 Mdot
.908 .42007 Mdot
.908 .4201 Mdot
.908 .4213 Mdot
.908 .42244 Mdot
.908 .4231 Mdot
.908 .42341 Mdot
.908 .4238 Mdot
.908 .42391 Mdot
.908 .42445 Mdot
.908 .425 Mdot
.908 .42548 Mdot
.908 .42565 Mdot
.908 .42577 Mdot
.908 .42646 Mdot
.908 .42707 Mdot
.908 .42707 Mdot
.908 .42712 Mdot
.908 .42713 Mdot
.908 .42717 Mdot
.908 .42719 Mdot
.908 .42729 Mdot
.908 .42732 Mdot
.908 .42733 Mdot
.908 .42735 Mdot
.908 .42741 Mdot
.908 .42767 Mdot
.908 .42784 Mdot
.908 .42813 Mdot
.908 .42818 Mdot
.908 .42894 Mdot
.908 .42895 Mdot
.908 .42897 Mdot
.908 .429 Mdot
.908 .42903 Mdot
.908 .42955 Mdot
.908 .43049 Mdot
.908 .4308 Mdot
.908 .43154 Mdot
.908 .43176 Mdot
.908 .43197 Mdot
.908 .43202 Mdot
.908 .43203 Mdot
.908 .43204 Mdot
.908 .43214 Mdot
.908 .43231 Mdot
.908 .43255 Mdot
.908 .43344 Mdot
.908 .43351 Mdot
.908 .43353 Mdot
.908 .43362 Mdot
.908 .43464 Mdot
.908 .43532 Mdot
.908 .43541 Mdot
.908 .43548 Mdot
.908 .43551 Mdot
.908 .43563 Mdot
.908 .43575 Mdot
.908 .43617 Mdot
.908 .43718 Mdot
.908 .43762 Mdot
.908 .4379 Mdot
.908 .43809 Mdot
.908 .4381 Mdot
.908 .43811 Mdot
.908 .4382 Mdot
.908 .43857 Mdot
.908 .43895 Mdot
.908 .43901 Mdot
.908 .43911 Mdot
.908 .43996 Mdot
.908 .44024 Mdot
.908 .4404 Mdot
.908 .44076 Mdot
.908 .44202 Mdot
.908 .44238 Mdot
.908 .44326 Mdot
.908 .44337 Mdot
.908 .4434 Mdot
.908 .44342 Mdot
.908 .44373 Mdot
.908 .44408 Mdot
.908 .44471 Mdot
.908 .4448 Mdot
.908 .44529 Mdot
.908 .44557 Mdot
.908 .44602 Mdot
.908 .44611 Mdot
.908 .44614 Mdot
.908 .44615 Mdot
.908 .44617 Mdot
.908 .44622 Mdot
.908 .44639 Mdot
.908 .44641 Mdot
.908 .44649 Mdot
.908 .4465 Mdot
.908 .44658 Mdot
.908 .44658 Mdot
.908 .4476 Mdot
.908 .4483 Mdot
.908 .4487 Mdot
.908 .44875 Mdot
.908 .44896 Mdot
.908 .44897 Mdot
.908 .44925 Mdot
.908 .44925 Mdot
.908 .44995 Mdot
.908 .45004 Mdot
.908 .4503 Mdot
.908 .45038 Mdot
.908 .45048 Mdot
.908 .45094 Mdot
.908 .45183 Mdot
.908 .45202 Mdot
.908 .4521 Mdot
.908 .45265 Mdot
.908 .45316 Mdot
.908 .45424 Mdot
.908 .45424 Mdot
.908 .45455 Mdot
.908 .45461 Mdot
.908 .4549 Mdot
.908 .45608 Mdot
.908 .4564 Mdot
.908 .45657 Mdot
.908 .45783 Mdot
.908 .45799 Mdot
.908 .45805 Mdot
.908 .45827 Mdot
.908 .45872 Mdot
.908 .45904 Mdot
.908 .45909 Mdot
.908 .46002 Mdot
.908 .46055 Mdot
.908 .46103 Mdot
.908 .46108 Mdot
.908 .46147 Mdot
.908 .46164 Mdot
.908 .46196 Mdot
.908 .46205 Mdot
.908 .4621 Mdot
.908 .46238 Mdot
.908 .46239 Mdot
.908 .46247 Mdot
.908 .46264 Mdot
.908 .46291 Mdot
.908 .463 Mdot
.908 .46302 Mdot
.908 .4632 Mdot
.908 .46377 Mdot
.908 .46395 Mdot
.908 .46402 Mdot
.908 .46431 Mdot
.908 .46433 Mdot
.908 .46489 Mdot
.908 .46535 Mdot
.908 .46577 Mdot
.908 .46585 Mdot
.908 .4661 Mdot
.908 .46611 Mdot
.908 .46703 Mdot
.908 .46704 Mdot
.908 .46713 Mdot
.908 .46752 Mdot
.908 .46766 Mdot
.908 .46804 Mdot
.908 .46829 Mdot
.908 .46834 Mdot
.908 .4696 Mdot
.908 .46986 Mdot
.908 .46994 Mdot
.908 .46995 Mdot
.908 .46997 Mdot
.908 .47004 Mdot
.908 .47018 Mdot
.908 .47019 Mdot
.908 .47066 Mdot
.908 .47066 Mdot
.908 .47072 Mdot
.908 .47078 Mdot
.908 .47094 Mdot
.908 .47096 Mdot
.908 .47099 Mdot
.908 .4712 Mdot
.908 .4712 Mdot
.908 .4718 Mdot
.908 .4721 Mdot
.908 .47254 Mdot
.908 .47306 Mdot
.908 .47329 Mdot
.908 .47386 Mdot
.908 .47408 Mdot
.908 .47459 Mdot
.908 .47567 Mdot
.908 .47589 Mdot
.908 .47605 Mdot
.908 .47621 Mdot
.908 .47624 Mdot
.908 .47649 Mdot
.908 .47665 Mdot
.908 .47673 Mdot
.908 .47707 Mdot
.908 .47714 Mdot
.908 .4773 Mdot
.908 .47755 Mdot
.908 .47783 Mdot
.908 .47788 Mdot
.908 .47789 Mdot
.908 .47865 Mdot
.908 .47867 Mdot
.908 .47887 Mdot
.908 .47897 Mdot
.908 .47945 Mdot
.908 .47985 Mdot
.908 .47992 Mdot
.908 .48057 Mdot
.908 .48066 Mdot
.908 .48083 Mdot
.908 .48085 Mdot
.908 .48144 Mdot
.908 .48152 Mdot
.908 .48176 Mdot
.908 .48197 Mdot
.908 .48199 Mdot
.908 .48201 Mdot
.908 .4822 Mdot
.908 .48232 Mdot
.908 .48232 Mdot
.908 .48266 Mdot
.908 .48287 Mdot
.908 .48299 Mdot
.908 .48299 Mdot
.908 .48301 Mdot
.908 .48301 Mdot
.908 .48319 Mdot
.908 .48326 Mdot
.908 .48336 Mdot
.908 .48338 Mdot
.908 .48341 Mdot
.908 .48342 Mdot
.908 .48343 Mdot
.908 .48344 Mdot
.908 .48344 Mdot
.908 .48424 Mdot
.908 .48521 Mdot
.908 .48564 Mdot
.908 .48614 Mdot
.908 .48636 Mdot
.908 .48705 Mdot
.908 .48775 Mdot
.908 .48782 Mdot
.908 .48913 Mdot
.908 .48945 Mdot
.908 .48959 Mdot
.908 .49053 Mdot
.908 .49071 Mdot
.908 .49111 Mdot
.908 .49192 Mdot
.908 .49194 Mdot
.908 .49273 Mdot
.908 .49289 Mdot
.908 .49291 Mdot
.908 .49291 Mdot
.908 .49362 Mdot
.908 .49408 Mdot
.908 .49409 Mdot
.908 .49426 Mdot
.908 .49435 Mdot
.908 .49437 Mdot
.908 .49458 Mdot
.908 .49496 Mdot
.908 .49527 Mdot
.908 .49564 Mdot
.908 .49595 Mdot
.908 .49595 Mdot
.908 .49658 Mdot
.908 .49738 Mdot
.908 .49779 Mdot
.908 .49861 Mdot
.908 .49869 Mdot
.908 .49947 Mdot
.908 .49982 Mdot
.908 .49993 Mdot
.908 .5 Mdot
.908 .50044 Mdot
.908 .50086 Mdot
.908 .50125 Mdot
.908 .5014 Mdot
.908 .50186 Mdot
.908 .50194 Mdot
.908 .50265 Mdot
.908 .50299 Mdot
.908 .50374 Mdot
.908 .50387 Mdot
.908 .50604 Mdot
.908 .50726 Mdot
.908 .50836 Mdot
.908 .50847 Mdot
.908 .50863 Mdot
.908 .50872 Mdot
.908 .50899 Mdot
.908 .50934 Mdot
.908 .50972 Mdot
.908 .51027 Mdot
.908 .51043 Mdot
.908 .51064 Mdot
.908 .51068 Mdot
.908 .51074 Mdot
.908 .51094 Mdot
.908 .51136 Mdot
.908 .51137 Mdot
.908 .51155 Mdot
.908 .51193 Mdot
.908 .51227 Mdot
.908 .5125 Mdot
.908 .5127 Mdot
.908 .51275 Mdot
.908 .51299 Mdot
.908 .51315 Mdot
.908 .51395 Mdot
.908 .51437 Mdot
.908 .51474 Mdot
.908 .51488 Mdot
.908 .51491 Mdot
.908 .51497 Mdot
.908 .51542 Mdot
.908 .51546 Mdot
.908 .51549 Mdot
.908 .51555 Mdot
.908 .51671 Mdot
.908 .51765 Mdot
.908 .51797 Mdot
.908 .51801 Mdot
.908 .5185 Mdot
.908 .51866 Mdot
.908 .51917 Mdot
.908 .51918 Mdot
.908 .51999 Mdot
.908 .52001 Mdot
.908 .521 Mdot
.908 .52102 Mdot
.908 .52119 Mdot
.908 .52121 Mdot
.908 .52158 Mdot
.908 .52194 Mdot
.908 .52221 Mdot
.908 .5227 Mdot
.908 .5228 Mdot
.908 .52294 Mdot
.908 .5234 Mdot
.908 .5235 Mdot
.908 .52353 Mdot
.908 .52557 Mdot
.908 .52583 Mdot
.908 .52628 Mdot
.908 .52643 Mdot
.908 .52645 Mdot
.908 .52648 Mdot
.908 .5266 Mdot
.908 .52684 Mdot
.908 .52687 Mdot
.908 .52769 Mdot
.908 .52769 Mdot
.908 .52779 Mdot
.908 .5279 Mdot
.908 .528 Mdot
.908 .52811 Mdot
.908 .52818 Mdot
.908 .52818 Mdot
.908 .52821 Mdot
.908 .52826 Mdot
.908 .52827 Mdot
.908 .52862 Mdot
.908 .52862 Mdot
.908 .52915 Mdot
.908 .52927 Mdot
.908 .52932 Mdot
.908 .52959 Mdot
.908 .52963 Mdot
.908 .53012 Mdot
.908 .53032 Mdot
.908 .53084 Mdot
.908 .53111 Mdot
.908 .53167 Mdot
.908 .53204 Mdot
.908 .53257 Mdot
.908 .53285 Mdot
.908 .53292 Mdot
.908 .53326 Mdot
.908 .53327 Mdot
.908 .53336 Mdot
.908 .53369 Mdot
.908 .53403 Mdot
.908 .53409 Mdot
.908 .53467 Mdot
.908 .53482 Mdot
.908 .53529 Mdot
.908 .53558 Mdot
.908 .5356 Mdot
.908 .5356 Mdot
.908 .53591 Mdot
.908 .53613 Mdot
.908 .53627 Mdot
.908 .53636 Mdot
.908 .5364 Mdot
.908 .53658 Mdot
.908 .53667 Mdot
.908 .53673 Mdot
.908 .53674 Mdot
.908 .53695 Mdot
.908 .53705 Mdot
.908 .53706 Mdot
.908 .5373 Mdot
.908 .53752 Mdot
.908 .53761 Mdot
.908 .53781 Mdot
.908 .53811 Mdot
.908 .53815 Mdot
.908 .53849 Mdot
.908 .53856 Mdot
.908 .53857 Mdot
.908 .53865 Mdot
.908 .53913 Mdot
.908 .5395 Mdot
.908 .53952 Mdot
.908 .53954 Mdot
.908 .53962 Mdot
.908 .53978 Mdot
.908 .53984 Mdot
.908 .5399 Mdot
.908 .53999 Mdot
.908 .54047 Mdot
.908 .54092 Mdot
.908 .541 Mdot
.908 .54137 Mdot
.908 .54172 Mdot
.908 .54181 Mdot
.908 .54199 Mdot
.908 .54201 Mdot
.908 .54262 Mdot
.908 .54271 Mdot
.908 .54278 Mdot
.908 .54294 Mdot
.908 .54315 Mdot
.908 .54317 Mdot
.908 .54319 Mdot
.908 .54337 Mdot
.908 .54348 Mdot
.908 .54348 Mdot
.908 .5438 Mdot
.908 .54399 Mdot
.908 .5441 Mdot
.908 .5441 Mdot
.908 .54412 Mdot
.908 .54412 Mdot
.908 .54428 Mdot
.908 .54434 Mdot
.908 .54443 Mdot
.908 .54444 Mdot
.908 .54448 Mdot
.908 .54448 Mdot
.908 .54449 Mdot
.908 .5445 Mdot
.908 .5445 Mdot
.908 .54492 Mdot
.908 .54503 Mdot
.908 .54516 Mdot
.908 .54566 Mdot
.908 .5459 Mdot
.908 .54593 Mdot
.908 .54621 Mdot
.908 .54645 Mdot
.908 .54651 Mdot
.908 .54655 Mdot
.908 .54669 Mdot
.908 .54682 Mdot
.908 .54691 Mdot
.908 .54711 Mdot
.908 .54716 Mdot
.908 .5474 Mdot
.908 .5475 Mdot
.908 .54754 Mdot
.908 .54764 Mdot
.908 .54768 Mdot
.908 .54774 Mdot
.908 .54791 Mdot
.908 .54815 Mdot
.908 .54826 Mdot
.908 .54828 Mdot
.908 .54829 Mdot
.908 .54833 Mdot
.908 .54859 Mdot
.908 .54865 Mdot
.908 .5487 Mdot
.908 .54871 Mdot
.908 .54881 Mdot
.908 .54892 Mdot
.908 .54899 Mdot
.908 .54899 Mdot
.908 .54904 Mdot
.908 .54904 Mdot
.908 .54908 Mdot
.908 .54911 Mdot
.908 .54913 Mdot
.908 .54913 Mdot
.908 .54913 Mdot
.908 .54913 Mdot
.908 .54916 Mdot
.908 .54918 Mdot
.908 .54918 Mdot
.908 .54919 Mdot
.908 .54919 Mdot
.908 .54919 Mdot
.908 .54919 Mdot
.908 .54919 Mdot
.91 .16421 Mdot
.91 .16422 Mdot
.91 .16423 Mdot
.91 .16424 Mdot
.91 .16424 Mdot
.91 .16436 Mdot
.91 .16438 Mdot
.91 .16457 Mdot
.91 .16469 Mdot
.91 .1649 Mdot
.91 .1651 Mdot
.91 .16511 Mdot
.91 .1652 Mdot
.91 .16529 Mdot
.91 .16534 Mdot
.91 .16547 Mdot
.91 .16548 Mdot
.91 .16558 Mdot
.91 .1656 Mdot
.91 .16563 Mdot
.91 .16565 Mdot
.91 .16566 Mdot
.91 .16592 Mdot
.91 .16598 Mdot
.91 .16603 Mdot
.91 .16628 Mdot
.91 .16632 Mdot
.91 .16644 Mdot
.91 .16644 Mdot
.91 .16648 Mdot
.91 .16664 Mdot
.91 .16679 Mdot
.91 .16684 Mdot
.91 .16692 Mdot
.91 .167 Mdot
.91 .16715 Mdot
.91 .16731 Mdot
.91 .16745 Mdot
.91 .16763 Mdot
.91 .16766 Mdot
.91 .16767 Mdot
.91 .16788 Mdot
.91 .16812 Mdot
.91 .16814 Mdot
.91 .16848 Mdot
.91 .16879 Mdot
.91 .16883 Mdot
.91 .16902 Mdot
.91 .16927 Mdot
.91 .16928 Mdot
.91 .16952 Mdot
.91 .16958 Mdot
.91 .17002 Mdot
.91 .1701 Mdot
.91 .17023 Mdot
.91 .17033 Mdot
.91 .17034 Mdot
.91 .17054 Mdot
.91 .17115 Mdot
.91 .17128 Mdot
.91 .17142 Mdot
.91 .17155 Mdot
.91 .17158 Mdot
.91 .17186 Mdot
.91 .1721 Mdot
.91 .17306 Mdot
.91 .17342 Mdot
.91 .17365 Mdot
.91 .1743 Mdot
.91 .17435 Mdot
.91 .17457 Mdot
.91 .17548 Mdot
.91 .17599 Mdot
.91 .17614 Mdot
.91 .17626 Mdot
.91 .17643 Mdot
.91 .17671 Mdot
.91 .17724 Mdot
.91 .17743 Mdot
.91 .17765 Mdot
.91 .1778 Mdot
.91 .1783 Mdot
.91 .1788 Mdot
.91 .17992 Mdot
.91 .18049 Mdot
.91 .18089 Mdot
.91 .18228 Mdot
.91 .18249 Mdot
.91 .18258 Mdot
.91 .18331 Mdot
.91 .18384 Mdot
.91 .18409 Mdot
.91 .18423 Mdot
.91 .1848 Mdot
.91 .18505 Mdot
.91 .18528 Mdot
.91 .1861 Mdot
.91 .18613 Mdot
.91 .18637 Mdot
.91 .18707 Mdot
.91 .18906 Mdot
.91 .18929 Mdot
.91 .18951 Mdot
.91 .18953 Mdot
.91 .18976 Mdot
.91 .19005 Mdot
.91 .19141 Mdot
.91 .19153 Mdot
.91 .19206 Mdot
.91 .19215 Mdot
.91 .19249 Mdot
.91 .19324 Mdot
.91 .19357 Mdot
.91 .19429 Mdot
.91 .19433 Mdot
.91 .19445 Mdot
.91 .19612 Mdot
.91 .19672 Mdot
.91 .19676 Mdot
.91 .19683 Mdot
.91 .19693 Mdot
.91 .19807 Mdot
.91 .19928 Mdot
.91 .1993 Mdot
.91 .19943 Mdot
.91 .19998 Mdot
.91 .20042 Mdot
.91 .2026 Mdot
.91 .20283 Mdot
.91 .20414 Mdot
.91 .20479 Mdot
.91 .20485 Mdot
.91 .20519 Mdot
.91 .20576 Mdot
.91 .20583 Mdot
.91 .20597 Mdot
.91 .20718 Mdot
.91 .20841 Mdot
.91 .20848 Mdot
.91 .20968 Mdot
.91 .21041 Mdot
.91 .21087 Mdot
.91 .21242 Mdot
.91 .21266 Mdot
.91 .21666 Mdot
.91 .21836 Mdot
.91 .22012 Mdot
.91 .22037 Mdot
.91 .22062 Mdot
.91 .22156 Mdot
.91 .22191 Mdot
.91 .22205 Mdot
.91 .22325 Mdot
.91 .22366 Mdot
.91 .22404 Mdot
.91 .2248 Mdot
.91 .2252 Mdot
.91 .22572 Mdot
.91 .22605 Mdot
.91 .22781 Mdot
.91 .22844 Mdot
.91 .22891 Mdot
.91 .23113 Mdot
.91 .2312 Mdot
.91 .23309 Mdot
.91 .23335 Mdot
.91 .23371 Mdot
.91 .23397 Mdot
.91 .2346 Mdot
.91 .23558 Mdot
.91 .23689 Mdot
.91 .23828 Mdot
.91 .23907 Mdot
.91 .24042 Mdot
.91 .24345 Mdot
.91 .24382 Mdot
.91 .24383 Mdot
.91 .24406 Mdot
.91 .24443 Mdot
.91 .24466 Mdot
.91 .24517 Mdot
.91 .24523 Mdot
.91 .24565 Mdot
.91 .2462 Mdot
.91 .24636 Mdot
.91 .24761 Mdot
.91 .24818 Mdot
.91 .24911 Mdot
.91 .24967 Mdot
.91 .24971 Mdot
.91 .25037 Mdot
.91 .25064 Mdot
.91 .25075 Mdot
.91 .25406 Mdot
.91 .2543 Mdot
.91 .25521 Mdot
.91 .25657 Mdot
.91 .25838 Mdot
.91 .26156 Mdot
.91 .26194 Mdot
.91 .26395 Mdot
.91 .26402 Mdot
.91 .26496 Mdot
.91 .2657 Mdot
.91 .26776 Mdot
.91 .26777 Mdot
.91 .2693 Mdot
.91 .26933 Mdot
.91 .27132 Mdot
.91 .27275 Mdot
.91 .27388 Mdot
.91 .27404 Mdot
.91 .27405 Mdot
.91 .27437 Mdot
.91 .27579 Mdot
.91 .27651 Mdot
.91 .2775 Mdot
.91 .27825 Mdot
.91 .28296 Mdot
.91 .28357 Mdot
.91 .28379 Mdot
.91 .28505 Mdot
.91 .2852 Mdot
.91 .29017 Mdot
.91 .29155 Mdot
.91 .29338 Mdot
.91 .29414 Mdot
.91 .29608 Mdot
.91 .29675 Mdot
.91 .29706 Mdot
.91 .29771 Mdot
.91 .29814 Mdot
.91 .29849 Mdot
.91 .29859 Mdot
.91 .29896 Mdot
.91 .29958 Mdot
.91 .30112 Mdot
.91 .30197 Mdot
.91 .30231 Mdot
.91 .30398 Mdot
.91 .30461 Mdot
.91 .30573 Mdot
.91 .30699 Mdot
.91 .30713 Mdot
.91 .31063 Mdot
.91 .31106 Mdot
.91 .31213 Mdot
.91 .315 Mdot
.91 .31577 Mdot
.91 .31639 Mdot
.91 .31655 Mdot
.91 .31698 Mdot
.91 .31729 Mdot
.91 .31734 Mdot
.91 .31742 Mdot
.91 .31749 Mdot
.91 .31749 Mdot
.91 .3182 Mdot
.91 .31836 Mdot
.91 .31919 Mdot
.91 .31948 Mdot
.91 .32025 Mdot
.91 .32052 Mdot
.91 .3207 Mdot
.91 .32157 Mdot
.91 .32192 Mdot
.91 .322 Mdot
.91 .32238 Mdot
.91 .32279 Mdot
.91 .32284 Mdot
.91 .32341 Mdot
.91 .32398 Mdot
.91 .32428 Mdot
.91 .32469 Mdot
.91 .32505 Mdot
.91 .32513 Mdot
.91 .32579 Mdot
.91 .3259 Mdot
.91 .32608 Mdot
.91 .32622 Mdot
.91 .32623 Mdot
.91 .32732 Mdot
.91 .3275 Mdot
.91 .32768 Mdot
.91 .32785 Mdot
.91 .32823 Mdot
.91 .32853 Mdot
.91 .32968 Mdot
.91 .3301 Mdot
.91 .33035 Mdot
.91 .33108 Mdot
.91 .33113 Mdot
.91 .33137 Mdot
.91 .33234 Mdot
.91 .33313 Mdot
.91 .33329 Mdot
.91 .33357 Mdot
.91 .33409 Mdot
.91 .33462 Mdot
.91 .33555 Mdot
.91 .33655 Mdot
.91 .33704 Mdot
.91 .33739 Mdot
.91 .33856 Mdot
.91 .33873 Mdot
.91 .3388 Mdot
.91 .33939 Mdot
.91 .34001 Mdot
.91 .34012 Mdot
.91 .34075 Mdot
.91 .34093 Mdot
.91 .34157 Mdot
.91 .34175 Mdot
.91 .34385 Mdot
.91 .34438 Mdot
.91 .34539 Mdot
.91 .34574 Mdot
.91 .34581 Mdot
.91 .34603 Mdot
.91 .34652 Mdot
.91 .3472 Mdot
.91 .34723 Mdot
.91 .3473 Mdot
.91 .34836 Mdot
.91 .3488 Mdot
.91 .34886 Mdot
.91 .34956 Mdot
.91 .35037 Mdot
.91 .3507 Mdot
.91 .35096 Mdot
.91 .35222 Mdot
.91 .35346 Mdot
.91 .3535 Mdot
.91 .35368 Mdot
.91 .354 Mdot
.91 .35477 Mdot
.91 .35544 Mdot
.91 .35547 Mdot
.91 .35674 Mdot
.91 .35754 Mdot
.91 .35766 Mdot
.91 .36052 Mdot
.91 .36137 Mdot
.91 .36161 Mdot
.91 .36205 Mdot
.91 .36222 Mdot
.91 .36229 Mdot
.91 .36304 Mdot
.91 .36322 Mdot
.91 .36357 Mdot
.91 .36415 Mdot
.91 .36495 Mdot
.91 .36524 Mdot
.91 .36545 Mdot
.91 .36644 Mdot
.91 .36647 Mdot
.91 .36758 Mdot
.91 .36796 Mdot
.91 .36954 Mdot
.91 .37186 Mdot
.91 .37195 Mdot
.91 .3721 Mdot
.91 .3722 Mdot
.91 .37243 Mdot
.91 .3726 Mdot
.91 .3745 Mdot
.91 .37466 Mdot
.91 .37596 Mdot
.91 .37605 Mdot
.91 .37641 Mdot
.91 .37694 Mdot
.91 .37885 Mdot
.91 .37975 Mdot
.91 .38013 Mdot
.91 .3804 Mdot
.91 .38117 Mdot
.91 .38173 Mdot
.91 .38174 Mdot
.91 .38299 Mdot
.91 .3834 Mdot
.91 .38346 Mdot
.91 .38358 Mdot
.91 .38664 Mdot
.91 .38737 Mdot
.91 .38742 Mdot
.91 .3905 Mdot
.91 .39116 Mdot
.91 .39139 Mdot
.91 .39149 Mdot
.91 .39171 Mdot
.91 .39186 Mdot
.91 .39197 Mdot
.91 .39213 Mdot
.91 .39314 Mdot
.91 .39381 Mdot
.91 .39486 Mdot
.91 .39789 Mdot
.91 .39808 Mdot
.91 .39818 Mdot
.91 .39819 Mdot
.91 .39822 Mdot
.91 .39824 Mdot
.91 .39824 Mdot
.91 .39847 Mdot
.91 .39852 Mdot
.91 .39879 Mdot
.91 .39889 Mdot
.91 .39913 Mdot
.91 .39922 Mdot
.91 .39928 Mdot
.91 .39956 Mdot
.91 .39967 Mdot
.91 .39982 Mdot
.91 .39995 Mdot
.91 .39996 Mdot
.91 .40015 Mdot
.91 .40033 Mdot
.91 .40042 Mdot
.91 .40056 Mdot
.91 .40067 Mdot
.91 .4007 Mdot
.91 .40091 Mdot
.91 .40094 Mdot
.91 .401 Mdot
.91 .40105 Mdot
.91 .40105 Mdot
.91 .40145 Mdot
.91 .40151 Mdot
.91 .40156 Mdot
.91 .40169 Mdot
.91 .40178 Mdot
.91 .40215 Mdot
.91 .40228 Mdot
.91 .40236 Mdot
.91 .40259 Mdot
.91 .40261 Mdot
.91 .40268 Mdot
.91 .40299 Mdot
.91 .40324 Mdot
.91 .40329 Mdot
.91 .40338 Mdot
.91 .40354 Mdot
.91 .40371 Mdot
.91 .404 Mdot
.91 .40432 Mdot
.91 .40447 Mdot
.91 .40458 Mdot
.91 .40495 Mdot
.91 .405 Mdot
.91 .40502 Mdot
.91 .40521 Mdot
.91 .40543 Mdot
.91 .40569 Mdot
.91 .40589 Mdot
.91 .40594 Mdot
.91 .4066 Mdot
.91 .40677 Mdot
.91 .40708 Mdot
.91 .40721 Mdot
.91 .40728 Mdot
.91 .40743 Mdot
.91 .40764 Mdot
.91 .40768 Mdot
.91 .408 Mdot
.91 .40814 Mdot
.91 .40816 Mdot
.91 .40863 Mdot
.91 .40873 Mdot
.91 .40881 Mdot
.91 .4092 Mdot
.91 .40959 Mdot
.91 .40975 Mdot
.91 .40999 Mdot
.91 .41019 Mdot
.91 .4102 Mdot
.91 .41059 Mdot
.91 .41084 Mdot
.91 .41176 Mdot
.91 .41202 Mdot
.91 .41228 Mdot
.91 .41253 Mdot
.91 .41259 Mdot
.91 .41269 Mdot
.91 .41312 Mdot
.91 .41357 Mdot
.91 .41358 Mdot
.91 .41404 Mdot
.91 .41452 Mdot
.91 .41526 Mdot
.91 .41531 Mdot
.91 .41534 Mdot
.91 .41541 Mdot
.91 .41604 Mdot
.91 .41609 Mdot
.91 .41649 Mdot
.91 .41651 Mdot
.91 .41662 Mdot
.91 .41678 Mdot
.91 .41737 Mdot
.91 .41776 Mdot
.91 .41784 Mdot
.91 .41825 Mdot
.91 .41825 Mdot
.91 .41881 Mdot
.91 .41974 Mdot
.91 .41997 Mdot
.91 .42092 Mdot
.91 .42119 Mdot
.91 .42137 Mdot
.91 .42142 Mdot
.91 .42173 Mdot
.91 .42225 Mdot
.91 .42318 Mdot
.91 .42324 Mdot
.91 .42346 Mdot
.91 .42359 Mdot
.91 .424 Mdot
.91 .42427 Mdot
.91 .42429 Mdot
.91 .4252 Mdot
.91 .42542 Mdot
.91 .42611 Mdot
.91 .42618 Mdot
.91 .42628 Mdot
.91 .42716 Mdot
.91 .42773 Mdot
.91 .42815 Mdot
.91 .42854 Mdot
.91 .4289 Mdot
.91 .42895 Mdot
.91 .42918 Mdot
.91 .42945 Mdot
.91 .42962 Mdot
.91 .42991 Mdot
.91 .43042 Mdot
.91 .43107 Mdot
.91 .43133 Mdot
.91 .43223 Mdot
.91 .43241 Mdot
.91 .43266 Mdot
.91 .43279 Mdot
.91 .43295 Mdot
.91 .43346 Mdot
.91 .43354 Mdot
.91 .43424 Mdot
.91 .43514 Mdot
.91 .43519 Mdot
.91 .43563 Mdot
.91 .43588 Mdot
.91 .43638 Mdot
.91 .43652 Mdot
.91 .43688 Mdot
.91 .43732 Mdot
.91 .43742 Mdot
.91 .4377 Mdot
.91 .43772 Mdot
.91 .43792 Mdot
.91 .43837 Mdot
.91 .43868 Mdot
.91 .43916 Mdot
.91 .43922 Mdot
.91 .43963 Mdot
.91 .44025 Mdot
.91 .4407 Mdot
.91 .44085 Mdot
.91 .44182 Mdot
.91 .44269 Mdot
.91 .44319 Mdot
.91 .44349 Mdot
.91 .44396 Mdot
.91 .44427 Mdot
.91 .44436 Mdot
.91 .44443 Mdot
.91 .44466 Mdot
.91 .44503 Mdot
.91 .44505 Mdot
.91 .44507 Mdot
.91 .44546 Mdot
.91 .44572 Mdot
.91 .44596 Mdot
.91 .44642 Mdot
.91 .44739 Mdot
.91 .44824 Mdot
.91 .44844 Mdot
.91 .44886 Mdot
.91 .44902 Mdot
.91 .44915 Mdot
.91 .44933 Mdot
.91 .44949 Mdot
.91 .45004 Mdot
.91 .45029 Mdot
.91 .45067 Mdot
.91 .45129 Mdot
.91 .45185 Mdot
.91 .45217 Mdot
.91 .4522 Mdot
.91 .45265 Mdot
.91 .45302 Mdot
.91 .4531 Mdot
.91 .4533 Mdot
.91 .45332 Mdot
.91 .45354 Mdot
.91 .4539 Mdot
.91 .45399 Mdot
.91 .4555 Mdot
.91 .45602 Mdot
.91 .45635 Mdot
.91 .45685 Mdot
.91 .45693 Mdot
.91 .45699 Mdot
.91 .45706 Mdot
.91 .45716 Mdot
.91 .45722 Mdot
.91 .45733 Mdot
.91 .45765 Mdot
.91 .45916 Mdot
.91 .45918 Mdot
.91 .45954 Mdot
.91 .46102 Mdot
.91 .46108 Mdot
.91 .46111 Mdot
.91 .4613 Mdot
.91 .4619 Mdot
.91 .46191 Mdot
.91 .46218 Mdot
.91 .46255 Mdot
.91 .46268 Mdot
.91 .46286 Mdot
.91 .46329 Mdot
.91 .4642 Mdot
.91 .46445 Mdot
.91 .46462 Mdot
.91 .46466 Mdot
.91 .46528 Mdot
.91 .46535 Mdot
.91 .46625 Mdot
.91 .46633 Mdot
.91 .46644 Mdot
.91 .46648 Mdot
.91 .46655 Mdot
.91 .4666 Mdot
.91 .46768 Mdot
.91 .46842 Mdot
.91 .4686 Mdot
.91 .46911 Mdot
.91 .46912 Mdot
.91 .46958 Mdot
.91 .46968 Mdot
.91 .46981 Mdot
.91 .47018 Mdot
.91 .47045 Mdot
.91 .47061 Mdot
.91 .47069 Mdot
.91 .47104 Mdot
.91 .47107 Mdot
.91 .47115 Mdot
.91 .47135 Mdot
.91 .47147 Mdot
.91 .47186 Mdot
.91 .47316 Mdot
.91 .47321 Mdot
.91 .47358 Mdot
.91 .47415 Mdot
.91 .47417 Mdot
.91 .47447 Mdot
.91 .47482 Mdot
.91 .47496 Mdot
.91 .47505 Mdot
.91 .47506 Mdot
.91 .47562 Mdot
.91 .47619 Mdot
.91 .4763 Mdot
.91 .47645 Mdot
.91 .47682 Mdot
.91 .47713 Mdot
.91 .47716 Mdot
.91 .47735 Mdot
.91 .47783 Mdot
.91 .47786 Mdot
.91 .47787 Mdot
.91 .47818 Mdot
.91 .4784 Mdot
.91 .47849 Mdot
.91 .47852 Mdot
.91 .47868 Mdot
.91 .47913 Mdot
.91 .47936 Mdot
.91 .48029 Mdot
.91 .48037 Mdot
.91 .48066 Mdot
.91 .48073 Mdot
.91 .48101 Mdot
.91 .48106 Mdot
.91 .48133 Mdot
.91 .48159 Mdot
.91 .48162 Mdot
.91 .4817 Mdot
.91 .48221 Mdot
.91 .48236 Mdot
.91 .48258 Mdot
.91 .48302 Mdot
.91 .48342 Mdot
.91 .48365 Mdot
.91 .48388 Mdot
.91 .484 Mdot
.91 .48407 Mdot
.91 .48442 Mdot
.91 .48484 Mdot
.91 .48494 Mdot
.91 .48496 Mdot
.91 .48527 Mdot
.91 .48539 Mdot
.91 .48556 Mdot
.91 .48606 Mdot
.91 .48619 Mdot
.91 .48636 Mdot
.91 .48643 Mdot
.91 .48651 Mdot
.91 .48658 Mdot
.91 .48705 Mdot
.91 .48706 Mdot
.91 .48712 Mdot
.91 .4872 Mdot
.91 .48725 Mdot
.91 .48753 Mdot
.91 .48756 Mdot
.91 .48772 Mdot
.91 .48789 Mdot
.91 .48802 Mdot
.91 .48826 Mdot
.91 .48851 Mdot
.91 .48853 Mdot
.91 .48871 Mdot
.91 .48887 Mdot
.91 .4889 Mdot
.91 .48905 Mdot
.91 .48942 Mdot
.91 .4895 Mdot
.91 .48961 Mdot
.91 .48994 Mdot
.91 .49006 Mdot
.91 .49042 Mdot
.91 .49049 Mdot
.91 .49079 Mdot
.91 .49079 Mdot
.91 .49082 Mdot
.91 .49085 Mdot
.91 .49087 Mdot
.91 .491 Mdot
.91 .49118 Mdot
.91 .49125 Mdot
.91 .49151 Mdot
.91 .49184 Mdot
.91 .49305 Mdot
.91 .4935 Mdot
.91 .49368 Mdot
.91 .49514 Mdot
.91 .4952 Mdot
.91 .49573 Mdot
.91 .4962 Mdot
.91 .49646 Mdot
.91 .49715 Mdot
.91 .49729 Mdot
.91 .49764 Mdot
.91 .49828 Mdot
.91 .49853 Mdot
.91 .49869 Mdot
.91 .49873 Mdot
.91 .49887 Mdot
.91 .49905 Mdot
.91 .49932 Mdot
.91 .49945 Mdot
.91 .49972 Mdot
.91 .50052 Mdot
.91 .50083 Mdot
.91 .50158 Mdot
.91 .50214 Mdot
.91 .50416 Mdot
.91 .50422 Mdot
.91 .50473 Mdot
.91 .50482 Mdot
.91 .50507 Mdot
.91 .50697 Mdot
.91 .50727 Mdot
.91 .50766 Mdot
.91 .50795 Mdot
.91 .50852 Mdot
.91 .50865 Mdot
.91 .50866 Mdot
.91 .50872 Mdot
.91 .50917 Mdot
.91 .50974 Mdot
.91 .51053 Mdot
.91 .51054 Mdot
.91 .51115 Mdot
.91 .51116 Mdot
.91 .51197 Mdot
.91 .51226 Mdot
.91 .51264 Mdot
.91 .51267 Mdot
.91 .51346 Mdot
.91 .51361 Mdot
.91 .51486 Mdot
.91 .51557 Mdot
.91 .5161 Mdot
.91 .51646 Mdot
.91 .51655 Mdot
.91 .51784 Mdot
.91 .51789 Mdot
.91 .51799 Mdot
.91 .51825 Mdot
.91 .51826 Mdot
.91 .51848 Mdot
.91 .51884 Mdot
.91 .51906 Mdot
.91 .51955 Mdot
.91 .51961 Mdot
.91 .51983 Mdot
.91 .51999 Mdot
.91 .52001 Mdot
.91 .52021 Mdot
.91 .5203 Mdot
.91 .52044 Mdot
.91 .52053 Mdot
.91 .52054 Mdot
.91 .52068 Mdot
.91 .52185 Mdot
.91 .52237 Mdot
.91 .52267 Mdot
.91 .52321 Mdot
.91 .52371 Mdot
.91 .52375 Mdot
.91 .52409 Mdot
.91 .52433 Mdot
.91 .52443 Mdot
.91 .52456 Mdot
.91 .52467 Mdot
.91 .52539 Mdot
.91 .52542 Mdot
.91 .52626 Mdot
.91 .52644 Mdot
.91 .52668 Mdot
.91 .52735 Mdot
.91 .52748 Mdot
.91 .52768 Mdot
.91 .52783 Mdot
.91 .52812 Mdot
.91 .52826 Mdot
.91 .52842 Mdot
.91 .52887 Mdot
.91 .52893 Mdot
.91 .52906 Mdot
.91 .52941 Mdot
.91 .52951 Mdot
.91 .5296 Mdot
.91 .53027 Mdot
.91 .53091 Mdot
.91 .53242 Mdot
.91 .53251 Mdot
.91 .5331 Mdot
.91 .53327 Mdot
.91 .53354 Mdot
.91 .53399 Mdot
.91 .53402 Mdot
.91 .53448 Mdot
.91 .53493 Mdot
.91 .53499 Mdot
.91 .53501 Mdot
.91 .53523 Mdot
.91 .53535 Mdot
.91 .53538 Mdot
.91 .53562 Mdot
.91 .53611 Mdot
.91 .5362 Mdot
.91 .53701 Mdot
.91 .53717 Mdot
.91 .53738 Mdot
.91 .53742 Mdot
.91 .53743 Mdot
.91 .53788 Mdot
.91 .53831 Mdot
.91 .53834 Mdot
.91 .53837 Mdot
.91 .53839 Mdot
.91 .53861 Mdot
.91 .53923 Mdot
.91 .53927 Mdot
.91 .53929 Mdot
.91 .53956 Mdot
.91 .53968 Mdot
.91 .53996 Mdot
.91 .54008 Mdot
.91 .54012 Mdot
.91 .54031 Mdot
.91 .54036 Mdot
.91 .54086 Mdot
.91 .54097 Mdot
.91 .54105 Mdot
.91 .54106 Mdot
.91 .54114 Mdot
.91 .54123 Mdot
.91 .54196 Mdot
.91 .54222 Mdot
.91 .54231 Mdot
.91 .54232 Mdot
.91 .54262 Mdot
.91 .54271 Mdot
.91 .5428 Mdot
.91 .54301 Mdot
.91 .54306 Mdot
.91 .54315 Mdot
.91 .54335 Mdot
.91 .54362 Mdot
.91 .54365 Mdot
.91 .54373 Mdot
.91 .54424 Mdot
.91 .54439 Mdot
.91 .5446 Mdot
.91 .54501 Mdot
.91 .54519 Mdot
.91 .54538 Mdot
.91 .54543 Mdot
.91 .54551 Mdot
.91 .54558 Mdot
.91 .54578 Mdot
.91 .54588 Mdot
.91 .54594 Mdot
.91 .54599 Mdot
.91 .54604 Mdot
.91 .54623 Mdot
.91 .54656 Mdot
.91 .54664 Mdot
.91 .54666 Mdot
.91 .5469 Mdot
.91 .54698 Mdot
.91 .54711 Mdot
.91 .54747 Mdot
.91 .54755 Mdot
.91 .54766 Mdot
.91 .54767 Mdot
.91 .54772 Mdot
.91 .54777 Mdot
.91 .54781 Mdot
.91 .54804 Mdot
.91 .54811 Mdot
.91 .54811 Mdot
.91 .54815 Mdot
.91 .5482 Mdot
.91 .54823 Mdot
.91 .54839 Mdot
.91 .54841 Mdot
.91 .5485 Mdot
.91 .5485 Mdot
.91 .54859 Mdot
.91 .54866 Mdot
.91 .54867 Mdot
.91 .54879 Mdot
.91 .54891 Mdot
.91 .54892 Mdot
.91 .54901 Mdot
.91 .54908 Mdot
.91 .54909 Mdot
.91 .5491 Mdot
.91 .54917 Mdot
.91 .54922 Mdot
.91 .54927 Mdot
.91 .54933 Mdot
.91 .54936 Mdot
.91 .54939 Mdot
.91 .54941 Mdot
.91 .54946 Mdot
.91 .54952 Mdot
.91 .54953 Mdot
.91 .54954 Mdot
.91 .54958 Mdot
.91 .54959 Mdot
.91 .54969 Mdot
.91 .5497 Mdot
.91 .54973 Mdot
.91 .54982 Mdot
.91 .54982 Mdot
.91 .54983 Mdot
.91 .54984 Mdot
.91 .54985 Mdot
.91 .54988 Mdot
.91 .54989 Mdot
.91 .54993 Mdot
.91 .54995 Mdot
.91 .54999 Mdot
.91 .55002 Mdot
.91 .55002 Mdot
.91 .55009 Mdot
.91 .55017 Mdot
.91 .55022 Mdot
.91 .55028 Mdot
.91 .55029 Mdot
.91 .55033 Mdot
.91 .55033 Mdot
.91 .55034 Mdot
.91 .55034 Mdot
.91 .55035 Mdot
.912 .16128 Mdot
.912 .16298 Mdot
.912 .29995 Mdot
.912 .31041 Mdot
.912 .39312 Mdot
.912 .39654 Mdot
.912 .49404 Mdot
.912 .49838 Mdot
.912 .55091 Mdot
.912 .55153 Mdot
.914 .15831 Mdot
.914 .15843 Mdot
.914 .15844 Mdot
.914 .15848 Mdot
.914 .15855 Mdot
.914 .15858 Mdot
.914 .15861 Mdot
.914 .15867 Mdot
.914 .15867 Mdot
.914 .15876 Mdot
.914 .15877 Mdot
.914 .15888 Mdot
.914 .15899 Mdot
.914 .15903 Mdot
.914 .15906 Mdot
.914 .15921 Mdot
.914 .15923 Mdot
.914 .15923 Mdot
.914 .15925 Mdot
.914 .15932 Mdot
.914 .15938 Mdot
.914 .15943 Mdot
.914 .15943 Mdot
.914 .15949 Mdot
.914 .15957 Mdot
.914 .15964 Mdot
.914 .15966 Mdot
.914 .15969 Mdot
.914 .15974 Mdot
.914 .1599 Mdot
.914 .16002 Mdot
.914 .16003 Mdot
.914 .16011 Mdot
.914 .1605 Mdot
.914 .1612 Mdot
.914 .16126 Mdot
.914 .16169 Mdot
.914 .16211 Mdot
.914 .16219 Mdot
.914 .16337 Mdot
.914 .16338 Mdot
.914 .16357 Mdot
.914 .16369 Mdot
.914 .16379 Mdot
.914 .16379 Mdot
.914 .16386 Mdot
.914 .1639 Mdot
.914 .16394 Mdot
.914 .16449 Mdot
.914 .16451 Mdot
.914 .16464 Mdot
.914 .16478 Mdot
.914 .16508 Mdot
.914 .16518 Mdot
.914 .16518 Mdot
.914 .16546 Mdot
.914 .1656 Mdot
.914 .16567 Mdot
.914 .16576 Mdot
.914 .166 Mdot
.914 .16613 Mdot
.914 .16641 Mdot
.914 .16661 Mdot
.914 .1667 Mdot
.914 .16674 Mdot
.914 .167 Mdot
.914 .16724 Mdot
.914 .16729 Mdot
.914 .16769 Mdot
.914 .16778 Mdot
.914 .16781 Mdot
.914 .16788 Mdot
.914 .16795 Mdot
.914 .16816 Mdot
.914 .16849 Mdot
.914 .16867 Mdot
.914 .16872 Mdot
.914 .16889 Mdot
.914 .16914 Mdot
.914 .16954 Mdot
.914 .16974 Mdot
.914 .16978 Mdot
.914 .17042 Mdot
.914 .17044 Mdot
.914 .17048 Mdot
.914 .17072 Mdot
.914 .17108 Mdot
.914 .17108 Mdot
.914 .17146 Mdot
.914 .17147 Mdot
.914 .17164 Mdot
.914 .17175 Mdot
.914 .17184 Mdot
.914 .17187 Mdot
.914 .17228 Mdot
.914 .17236 Mdot
.914 .17241 Mdot
.914 .17255 Mdot
.914 .17262 Mdot
.914 .17268 Mdot
.914 .1734 Mdot
.914 .17454 Mdot
.914 .17455 Mdot
.914 .17637 Mdot
.914 .1767 Mdot
.914 .17675 Mdot
.914 .17907 Mdot
.914 .17961 Mdot
.914 .18008 Mdot
.914 .18071 Mdot
.914 .18086 Mdot
.914 .18109 Mdot
.914 .18176 Mdot
.914 .18237 Mdot
.914 .18263 Mdot
.914 .18301 Mdot
.914 .18349 Mdot
.914 .18376 Mdot
.914 .184 Mdot
.914 .18412 Mdot
.914 .18417 Mdot
.914 .18434 Mdot
.914 .18676 Mdot
.914 .18712 Mdot
.914 .18751 Mdot
.914 .18847 Mdot
.914 .18933 Mdot
.914 .18986 Mdot
.914 .19 Mdot
.914 .19157 Mdot
.914 .19161 Mdot
.914 .19394 Mdot
.914 .19423 Mdot
.914 .1946 Mdot
.914 .19497 Mdot
.914 .19616 Mdot
.914 .19687 Mdot
.914 .19733 Mdot
.914 .19827 Mdot
.914 .19875 Mdot
.914 .20099 Mdot
.914 .20111 Mdot
.914 .20157 Mdot
.914 .20393 Mdot
.914 .2073 Mdot
.914 .20776 Mdot
.914 .20812 Mdot
.914 .20953 Mdot
.914 .20979 Mdot
.914 .2104 Mdot
.914 .21043 Mdot
.914 .21114 Mdot
.914 .21338 Mdot
.914 .2135 Mdot
.914 .21589 Mdot
.914 .2163 Mdot
.914 .21842 Mdot
.914 .21849 Mdot
.914 .22004 Mdot
.914 .2206 Mdot
.914 .22359 Mdot
.914 .22365 Mdot
.914 .22377 Mdot
.914 .22394 Mdot
.914 .22397 Mdot
.914 .22641 Mdot
.914 .22708 Mdot
.914 .22811 Mdot
.914 .22936 Mdot
.914 .22989 Mdot
.914 .23118 Mdot
.914 .23273 Mdot
.914 .23445 Mdot
.914 .23544 Mdot
.914 .23552 Mdot
.914 .236 Mdot
.914 .23731 Mdot
.914 .23794 Mdot
.914 .23803 Mdot
.914 .23852 Mdot
.914 .23905 Mdot
.914 .24022 Mdot
.914 .24083 Mdot
.914 .24141 Mdot
.914 .24234 Mdot
.914 .24278 Mdot
.914 .2462 Mdot
.914 .24641 Mdot
.914 .24665 Mdot
.914 .24765 Mdot
.914 .24768 Mdot
.914 .24881 Mdot
.914 .25122 Mdot
.914 .25275 Mdot
.914 .2541 Mdot
.914 .25435 Mdot
.914 .25747 Mdot
.914 .2589 Mdot
.914 .26024 Mdot
.914 .26046 Mdot
.914 .2622 Mdot
.914 .26579 Mdot
.914 .26605 Mdot
.914 .26714 Mdot
.914 .26735 Mdot
.914 .26774 Mdot
.914 .26913 Mdot
.914 .27012 Mdot
.914 .27219 Mdot
.914 .27392 Mdot
.914 .27421 Mdot
.914 .27473 Mdot
.914 .275 Mdot
.914 .27947 Mdot
.914 .28128 Mdot
.914 .28228 Mdot
.914 .28298 Mdot
.914 .28305 Mdot
.914 .28322 Mdot
.914 .2833 Mdot
.914 .2837 Mdot
.914 .28389 Mdot
.914 .28406 Mdot
.914 .28442 Mdot
.914 .28443 Mdot
.914 .28478 Mdot
.914 .28501 Mdot
.914 .28506 Mdot
.914 .28572 Mdot
.914 .28576 Mdot
.914 .28597 Mdot
.914 .28639 Mdot
.914 .28665 Mdot
.914 .28682 Mdot
.914 .28707 Mdot
.914 .28774 Mdot
.914 .28783 Mdot
.914 .28786 Mdot
.914 .28796 Mdot
.914 .28842 Mdot
.914 .28847 Mdot
.914 .28875 Mdot
.914 .28905 Mdot
.914 .2891 Mdot
.914 .28946 Mdot
.914 .28995 Mdot
.914 .29037 Mdot
.914 .29046 Mdot
.914 .29064 Mdot
.914 .29101 Mdot
.914 .29101 Mdot
.914 .29154 Mdot
.914 .29194 Mdot
.914 .29271 Mdot
.914 .29278 Mdot
.914 .29283 Mdot
.914 .29327 Mdot
.914 .29355 Mdot
.914 .29564 Mdot
.914 .29887 Mdot
.914 .30001 Mdot
.914 .30037 Mdot
.914 .30097 Mdot
.914 .30106 Mdot
.914 .30156 Mdot
.914 .30194 Mdot
.914 .30212 Mdot
.914 .30244 Mdot
.914 .30308 Mdot
.914 .30384 Mdot
.914 .30493 Mdot
.914 .30528 Mdot
.914 .30568 Mdot
.914 .30619 Mdot
.914 .3087 Mdot
.914 .31139 Mdot
.914 .3115 Mdot
.914 .31259 Mdot
.914 .31314 Mdot
.914 .31366 Mdot
.914 .31369 Mdot
.914 .31469 Mdot
.914 .31487 Mdot
.914 .31555 Mdot
.914 .3156 Mdot
.914 .31568 Mdot
.914 .31629 Mdot
.914 .31631 Mdot
.914 .31675 Mdot
.914 .31696 Mdot
.914 .31726 Mdot
.914 .31802 Mdot
.914 .31825 Mdot
.914 .32071 Mdot
.914 .32083 Mdot
.914 .32167 Mdot
.914 .32257 Mdot
.914 .3245 Mdot
.914 .32498 Mdot
.914 .32512 Mdot
.914 .32513 Mdot
.914 .32614 Mdot
.914 .32632 Mdot
.914 .32692 Mdot
.914 .3278 Mdot
.914 .32826 Mdot
.914 .32885 Mdot
.914 .33039 Mdot
.914 .33063 Mdot
.914 .33118 Mdot
.914 .33298 Mdot
.914 .334 Mdot
.914 .33428 Mdot
.914 .33439 Mdot
.914 .33488 Mdot
.914 .33513 Mdot
.914 .33679 Mdot
.914 .33831 Mdot
.914 .33862 Mdot
.914 .34045 Mdot
.914 .34085 Mdot
.914 .34121 Mdot
.914 .34168 Mdot
.914 .34178 Mdot
.914 .34196 Mdot
.914 .34244 Mdot
.914 .34288 Mdot
.914 .34366 Mdot
.914 .34402 Mdot
.914 .3441 Mdot
.914 .34425 Mdot
.914 .3461 Mdot
.914 .34636 Mdot
.914 .34697 Mdot
.914 .34751 Mdot
.914 .34785 Mdot
.914 .3489 Mdot
.914 .35049 Mdot
.914 .35161 Mdot
.914 .3528 Mdot
.914 .35306 Mdot
.914 .35429 Mdot
.914 .35435 Mdot
.914 .3546 Mdot
.914 .358 Mdot
.914 .35871 Mdot
.914 .35884 Mdot
.914 .35914 Mdot
.914 .35951 Mdot
.914 .36065 Mdot
.914 .36178 Mdot
.914 .36198 Mdot
.914 .36296 Mdot
.914 .363 Mdot
.914 .36533 Mdot
.914 .36539 Mdot
.914 .36546 Mdot
.914 .36547 Mdot
.914 .36655 Mdot
.914 .36728 Mdot
.914 .36782 Mdot
.914 .36805 Mdot
.914 .3686 Mdot
.914 .36997 Mdot
.914 .37061 Mdot
.914 .37115 Mdot
.914 .37144 Mdot
.914 .37233 Mdot
.914 .37258 Mdot
.914 .37281 Mdot
.914 .37318 Mdot
.914 .37336 Mdot
.914 .37471 Mdot
.914 .37488 Mdot
.914 .37527 Mdot
.914 .37774 Mdot
.914 .38215 Mdot
.914 .38276 Mdot
.914 .38326 Mdot
.914 .38434 Mdot
.914 .38495 Mdot
.914 .38505 Mdot
.914 .38523 Mdot
.914 .3875 Mdot
.914 .38785 Mdot
.914 .38809 Mdot
.914 .38811 Mdot
.914 .38819 Mdot
.914 .38833 Mdot
.914 .3884 Mdot
.914 .38846 Mdot
.914 .38858 Mdot
.914 .38858 Mdot
.914 .38878 Mdot
.914 .3888 Mdot
.914 .38902 Mdot
.914 .38903 Mdot
.914 .3891 Mdot
.914 .38925 Mdot
.914 .38933 Mdot
.914 .38939 Mdot
.914 .38948 Mdot
.914 .3897 Mdot
.914 .38973 Mdot
.914 .38974 Mdot
.914 .38978 Mdot
.914 .38993 Mdot
.914 .39004 Mdot
.914 .39014 Mdot
.914 .39016 Mdot
.914 .39028 Mdot
.914 .39045 Mdot
.914 .39059 Mdot
.914 .39062 Mdot
.914 .39068 Mdot
.914 .3908 Mdot
.914 .3908 Mdot
.914 .39111 Mdot
.914 .39137 Mdot
.914 .39139 Mdot
.914 .39141 Mdot
.914 .39155 Mdot
.914 .39234 Mdot
.914 .3934 Mdot
.914 .39378 Mdot
.914 .3939 Mdot
.914 .39457 Mdot
.914 .39478 Mdot
.914 .39503 Mdot
.914 .39538 Mdot
.914 .39549 Mdot
.914 .39562 Mdot
.914 .39579 Mdot
.914 .39642 Mdot
.914 .3966 Mdot
.914 .39749 Mdot
.914 .39784 Mdot
.914 .39818 Mdot
.914 .39819 Mdot
.914 .39851 Mdot
.914 .39857 Mdot
.914 .39878 Mdot
.914 .3988 Mdot
.914 .39882 Mdot
.914 .39902 Mdot
.914 .39902 Mdot
.914 .39916 Mdot
.914 .39923 Mdot
.914 .39932 Mdot
.914 .40041 Mdot
.914 .40045 Mdot
.914 .40071 Mdot
.914 .401 Mdot
.914 .4016 Mdot
.914 .4018 Mdot
.914 .4018 Mdot
.914 .40212 Mdot
.914 .40236 Mdot
.914 .40263 Mdot
.914 .40278 Mdot
.914 .40296 Mdot
.914 .40344 Mdot
.914 .40351 Mdot
.914 .40368 Mdot
.914 .40424 Mdot
.914 .40464 Mdot
.914 .40483 Mdot
.914 .4049 Mdot
.914 .40542 Mdot
.914 .40588 Mdot
.914 .40598 Mdot
.914 .40654 Mdot
.914 .40666 Mdot
.914 .40677 Mdot
.914 .40695 Mdot
.914 .407 Mdot
.914 .40715 Mdot
.914 .40728 Mdot
.914 .40752 Mdot
.914 .4077 Mdot
.914 .40834 Mdot
.914 .4087 Mdot
.914 .4088 Mdot
.914 .40912 Mdot
.914 .4096 Mdot
.914 .41038 Mdot
.914 .41077 Mdot
.914 .41085 Mdot
.914 .41188 Mdot
.914 .41209 Mdot
.914 .41213 Mdot
.914 .41222 Mdot
.914 .41233 Mdot
.914 .41267 Mdot
.914 .41301 Mdot
.914 .41307 Mdot
.914 .41337 Mdot
.914 .41338 Mdot
.914 .41408 Mdot
.914 .4141 Mdot
.914 .41412 Mdot
.914 .41445 Mdot
.914 .41467 Mdot
.914 .41483 Mdot
.914 .4149 Mdot
.914 .41506 Mdot
.914 .41548 Mdot
.914 .41567 Mdot
.914 .41583 Mdot
.914 .41592 Mdot
.914 .41618 Mdot
.914 .41626 Mdot
.914 .41633 Mdot
.914 .41644 Mdot
.914 .4169 Mdot
.914 .41781 Mdot
.914 .41913 Mdot
.914 .41946 Mdot
.914 .41997 Mdot
.914 .42 Mdot
.914 .42005 Mdot
.914 .42121 Mdot
.914 .42132 Mdot
.914 .42172 Mdot
.914 .4225 Mdot
.914 .42285 Mdot
.914 .42299 Mdot
.914 .42313 Mdot
.914 .4234 Mdot
.914 .42373 Mdot
.914 .42403 Mdot
.914 .42411 Mdot
.914 .42512 Mdot
.914 .42554 Mdot
.914 .42675 Mdot
.914 .42841 Mdot
.914 .42843 Mdot
.914 .42903 Mdot
.914 .42916 Mdot
.914 .42939 Mdot
.914 .43027 Mdot
.914 .43037 Mdot
.914 .4309 Mdot
.914 .43106 Mdot
.914 .4314 Mdot
.914 .43145 Mdot
.914 .43149 Mdot
.914 .43167 Mdot
.914 .4321 Mdot
.914 .43223 Mdot
.914 .4326 Mdot
.914 .43312 Mdot
.914 .43331 Mdot
.914 .43334 Mdot
.914 .43407 Mdot
.914 .43441 Mdot
.914 .43464 Mdot
.914 .43487 Mdot
.914 .43556 Mdot
.914 .43588 Mdot
.914 .43628 Mdot
.914 .4364 Mdot
.914 .43669 Mdot
.914 .43689 Mdot
.914 .4373 Mdot
.914 .43733 Mdot
.914 .43754 Mdot
.914 .43762 Mdot
.914 .43792 Mdot
.914 .43858 Mdot
.914 .43865 Mdot
.914 .43898 Mdot
.914 .43989 Mdot
.914 .44055 Mdot
.914 .44077 Mdot
.914 .44152 Mdot
.914 .44184 Mdot
.914 .44192 Mdot
.914 .44199 Mdot
.914 .44218 Mdot
.914 .44259 Mdot
.914 .4428 Mdot
.914 .44286 Mdot
.914 .44348 Mdot
.914 .44379 Mdot
.914 .44397 Mdot
.914 .44514 Mdot
.914 .44547 Mdot
.914 .44588 Mdot
.914 .4461 Mdot
.914 .44661 Mdot
.914 .44713 Mdot
.914 .44716 Mdot
.914 .44752 Mdot
.914 .44775 Mdot
.914 .44999 Mdot
.914 .45042 Mdot
.914 .45049 Mdot
.914 .45202 Mdot
.914 .45272 Mdot
.914 .45438 Mdot
.914 .45438 Mdot
.914 .45452 Mdot
.914 .45485 Mdot
.914 .45502 Mdot
.914 .45547 Mdot
.914 .45555 Mdot
.914 .45601 Mdot
.914 .45607 Mdot
.914 .45624 Mdot
.914 .45647 Mdot
.914 .45704 Mdot
.914 .45802 Mdot
.914 .45831 Mdot
.914 .45896 Mdot
.914 .45914 Mdot
.914 .45917 Mdot
.914 .45991 Mdot
.914 .461 Mdot
.914 .46109 Mdot
.914 .46114 Mdot
.914 .46143 Mdot
.914 .46195 Mdot
.914 .46219 Mdot
.914 .46248 Mdot
.914 .46457 Mdot
.914 .46573 Mdot
.914 .46592 Mdot
.914 .466 Mdot
.914 .46663 Mdot
.914 .46671 Mdot
.914 .46689 Mdot
.914 .46699 Mdot
.914 .46711 Mdot
.914 .46752 Mdot
.914 .46766 Mdot
.914 .46791 Mdot
.914 .46821 Mdot
.914 .46884 Mdot
.914 .4691 Mdot
.914 .4692 Mdot
.914 .46945 Mdot
.914 .46979 Mdot
.914 .47028 Mdot
.914 .47029 Mdot
.914 .47032 Mdot
.914 .47035 Mdot
.914 .47142 Mdot
.914 .47143 Mdot
.914 .47188 Mdot
.914 .47197 Mdot
.914 .47249 Mdot
.914 .47301 Mdot
.914 .47317 Mdot
.914 .47331 Mdot
.914 .47337 Mdot
.914 .47369 Mdot
.914 .47522 Mdot
.914 .47533 Mdot
.914 .47536 Mdot
.914 .47591 Mdot
.914 .47603 Mdot
.914 .47656 Mdot
.914 .47706 Mdot
.914 .47777 Mdot
.914 .47823 Mdot
.914 .47838 Mdot
.914 .47862 Mdot
.914 .4789 Mdot
.914 .47901 Mdot
.914 .47983 Mdot
.914 .47989 Mdot
.914 .47993 Mdot
.914 .48008 Mdot
.914 .48043 Mdot
.914 .48062 Mdot
.914 .48083 Mdot
.914 .48091 Mdot
.914 .48096 Mdot
.914 .48116 Mdot
.914 .48132 Mdot
.914 .48149 Mdot
.914 .48229 Mdot
.914 .48243 Mdot
.914 .48309 Mdot
.914 .48381 Mdot
.914 .48392 Mdot
.914 .48413 Mdot
.914 .48418 Mdot
.914 .4843 Mdot
.914 .48474 Mdot
.914 .48552 Mdot
.914 .48575 Mdot
.914 .48586 Mdot
.914 .48652 Mdot
.914 .48677 Mdot
.914 .48697 Mdot
.914 .48734 Mdot
.914 .4876 Mdot
.914 .48768 Mdot
.914 .48811 Mdot
.914 .48811 Mdot
.914 .48817 Mdot
.914 .48838 Mdot
.914 .4892 Mdot
.914 .48958 Mdot
.914 .48994 Mdot
.914 .48999 Mdot
.914 .49103 Mdot
.914 .49112 Mdot
.914 .49145 Mdot
.914 .49157 Mdot
.914 .49166 Mdot
.914 .49184 Mdot
.914 .49185 Mdot
.914 .49211 Mdot
.914 .49214 Mdot
.914 .49216 Mdot
.914 .49245 Mdot
.914 .49252 Mdot
.914 .49294 Mdot
.914 .49296 Mdot
.914 .49318 Mdot
.914 .4934 Mdot
.914 .49386 Mdot
.914 .49391 Mdot
.914 .49503 Mdot
.914 .49525 Mdot
.914 .49607 Mdot
.914 .49628 Mdot
.914 .49644 Mdot
.914 .49659 Mdot
.914 .49704 Mdot
.914 .49736 Mdot
.914 .49762 Mdot
.914 .49775 Mdot
.914 .49783 Mdot
.914 .49798 Mdot
.914 .49819 Mdot
.914 .49822 Mdot
.914 .49847 Mdot
.914 .49862 Mdot
.914 .49909 Mdot
.914 .50041 Mdot
.914 .50126 Mdot
.914 .50137 Mdot
.914 .50155 Mdot
.914 .50157 Mdot
.914 .5016 Mdot
.914 .50191 Mdot
.914 .50208 Mdot
.914 .50229 Mdot
.914 .50229 Mdot
.914 .50244 Mdot
.914 .50251 Mdot
.914 .50255 Mdot
.914 .50272 Mdot
.914 .50292 Mdot
.914 .50307 Mdot
.914 .50309 Mdot
.914 .50321 Mdot
.914 .50332 Mdot
.914 .50334 Mdot
.914 .50353 Mdot
.914 .50357 Mdot
.914 .50358 Mdot
.914 .50362 Mdot
.914 .50389 Mdot
.914 .50399 Mdot
.914 .50406 Mdot
.914 .50416 Mdot
.914 .50433 Mdot
.914 .50441 Mdot
.914 .50443 Mdot
.914 .5047 Mdot
.914 .50472 Mdot
.914 .50481 Mdot
.914 .50495 Mdot
.914 .50495 Mdot
.914 .5051 Mdot
.914 .50517 Mdot
.914 .50524 Mdot
.914 .50541 Mdot
.914 .50544 Mdot
.914 .50551 Mdot
.914 .50554 Mdot
.914 .50582 Mdot
.914 .50622 Mdot
.914 .50694 Mdot
.914 .50873 Mdot
.914 .50883 Mdot
.914 .50904 Mdot
.914 .50915 Mdot
.914 .50984 Mdot
.914 .51066 Mdot
.914 .51105 Mdot
.914 .5116 Mdot
.914 .51176 Mdot
.914 .51184 Mdot
.914 .51227 Mdot
.914 .51237 Mdot
.914 .51378 Mdot
.914 .51446 Mdot
.914 .51455 Mdot
.914 .51507 Mdot
.914 .51563 Mdot
.914 .51685 Mdot
.914 .51695 Mdot
.914 .51747 Mdot
.914 .51806 Mdot
.914 .519 Mdot
.914 .51943 Mdot
.914 .51945 Mdot
.914 .51983 Mdot
.914 .52001 Mdot
.914 .52132 Mdot
.914 .52149 Mdot
.914 .52185 Mdot
.914 .52207 Mdot
.914 .52231 Mdot
.914 .52275 Mdot
.914 .52296 Mdot
.914 .52315 Mdot
.914 .52318 Mdot
.914 .52342 Mdot
.914 .52392 Mdot
.914 .52411 Mdot
.914 .52413 Mdot
.914 .52451 Mdot
.914 .52517 Mdot
.914 .52576 Mdot
.914 .52625 Mdot
.914 .52645 Mdot
.914 .52693 Mdot
.914 .52732 Mdot
.914 .52757 Mdot
.914 .52849 Mdot
.914 .5285 Mdot
.914 .52857 Mdot
.914 .52861 Mdot
.914 .52864 Mdot
.914 .52976 Mdot
.914 .52997 Mdot
.914 .53056 Mdot
.914 .53059 Mdot
.914 .53138 Mdot
.914 .53154 Mdot
.914 .53243 Mdot
.914 .53248 Mdot
.914 .53332 Mdot
.914 .53358 Mdot
.914 .53359 Mdot
.914 .53382 Mdot
.914 .53392 Mdot
.914 .53445 Mdot
.914 .53458 Mdot
.914 .53475 Mdot
.914 .53601 Mdot
.914 .53689 Mdot
.914 .53706 Mdot
.914 .5371 Mdot
.914 .53793 Mdot
.914 .53811 Mdot
.914 .53846 Mdot
.914 .53863 Mdot
.914 .53889 Mdot
.914 .53933 Mdot
.914 .53947 Mdot
.914 .5396 Mdot
.914 .53971 Mdot
.914 .54057 Mdot
.914 .54058 Mdot
.914 .54116 Mdot
.914 .54122 Mdot
.914 .54141 Mdot
.914 .54173 Mdot
.914 .54208 Mdot
.914 .54222 Mdot
.914 .54236 Mdot
.914 .54324 Mdot
.914 .54331 Mdot
.914 .54332 Mdot
.914 .54337 Mdot
.914 .54346 Mdot
.914 .54356 Mdot
.914 .54373 Mdot
.914 .54387 Mdot
.914 .54396 Mdot
.914 .54419 Mdot
.914 .54443 Mdot
.914 .54452 Mdot
.914 .54457 Mdot
.914 .5448 Mdot
.914 .54498 Mdot
.914 .54518 Mdot
.914 .54602 Mdot
.914 .54604 Mdot
.914 .54616 Mdot
.914 .54683 Mdot
.914 .54683 Mdot
.914 .54725 Mdot
.914 .54751 Mdot
.914 .54753 Mdot
.914 .54756 Mdot
.914 .54761 Mdot
.914 .54762 Mdot
.914 .54765 Mdot
.914 .5478 Mdot
.914 .54781 Mdot
.914 .54784 Mdot
.914 .54789 Mdot
.914 .54795 Mdot
.914 .54795 Mdot
.914 .54809 Mdot
.914 .54809 Mdot
.914 .54822 Mdot
.914 .54831 Mdot
.914 .54832 Mdot
.914 .54833 Mdot
.914 .54856 Mdot
.914 .54858 Mdot
.914 .54865 Mdot
.914 .5488 Mdot
.914 .54889 Mdot
.914 .54895 Mdot
.914 .54897 Mdot
.914 .54903 Mdot
.914 .54915 Mdot
.914 .54923 Mdot
.914 .54925 Mdot
.914 .54928 Mdot
.914 .54929 Mdot
.914 .54932 Mdot
.914 .54947 Mdot
.914 .54949 Mdot
.914 .54957 Mdot
.914 .54967 Mdot
.914 .54968 Mdot
.914 .54971 Mdot
.914 .54979 Mdot
.914 .54989 Mdot
.914 .54993 Mdot
.914 .55002 Mdot
.914 .55006 Mdot
.914 .55008 Mdot
.914 .55013 Mdot
.914 .55023 Mdot
.914 .55023 Mdot
.914 .55027 Mdot
.914 .55038 Mdot
.914 .55043 Mdot
.914 .55048 Mdot
.914 .55048 Mdot
.914 .55068 Mdot
.914 .5507 Mdot
.914 .55071 Mdot
.914 .55074 Mdot
.914 .55074 Mdot
.914 .55077 Mdot
.914 .55082 Mdot
.914 .55089 Mdot
.914 .55089 Mdot
.914 .55132 Mdot
.914 .55135 Mdot
.914 .5515 Mdot
.914 .55165 Mdot
.914 .55168 Mdot
.914 .55193 Mdot
.914 .55207 Mdot
.914 .5521 Mdot
.914 .5521 Mdot
.914 .55215 Mdot
.914 .5522 Mdot
.914 .55222 Mdot
.914 .55223 Mdot
.914 .55224 Mdot
.914 .55226 Mdot
.914 .55229 Mdot
.914 .55231 Mdot
.914 .55232 Mdot
.914 .55234 Mdot
.914 .55235 Mdot
.914 .55238 Mdot
.914 .55239 Mdot
.914 .55239 Mdot
.914 .55239 Mdot
.914 .55245 Mdot
.914 .55246 Mdot
.914 .55248 Mdot
.914 .55251 Mdot
.914 .55255 Mdot
.914 .55256 Mdot
.914 .55259 Mdot
.914 .55259 Mdot
.914 .55261 Mdot
.914 .55262 Mdot
.914 .55263 Mdot
.914 .55266 Mdot
.914 .55267 Mdot
.914 .55268 Mdot
.914 .55272 Mdot
.916 .15536 Mdot
.916 .15537 Mdot
.916 .15537 Mdot
.916 .15541 Mdot
.916 .15542 Mdot
.916 .15543 Mdot
.916 .1555 Mdot
.916 .15556 Mdot
.916 .15569 Mdot
.916 .15572 Mdot
.916 .15572 Mdot
.916 .15579 Mdot
.916 .15586 Mdot
.916 .15594 Mdot
.916 .15604 Mdot
.916 .15613 Mdot
.916 .15614 Mdot
.916 .1562 Mdot
.916 .15622 Mdot
.916 .15638 Mdot
.916 .1566 Mdot
.916 .15675 Mdot
.916 .15689 Mdot
.916 .15694 Mdot
.916 .15699 Mdot
.916 .1572 Mdot
.916 .1579 Mdot
.916 .15799 Mdot
.916 .15822 Mdot
.916 .15829 Mdot
.916 .15832 Mdot
.916 .15841 Mdot
.916 .15846 Mdot
.916 .15854 Mdot
.916 .15855 Mdot
.916 .15862 Mdot
.916 .1587 Mdot
.916 .15873 Mdot
.916 .15876 Mdot
.916 .15956 Mdot
.916 .15981 Mdot
.916 .16031 Mdot
.916 .16053 Mdot
.916 .16064 Mdot
.916 .16115 Mdot
.916 .16153 Mdot
.916 .16154 Mdot
.916 .16164 Mdot
.916 .1617 Mdot
.916 .16182 Mdot
.916 .16227 Mdot
.916 .16239 Mdot
.916 .16259 Mdot
.916 .16279 Mdot
.916 .16328 Mdot
.916 .16523 Mdot
.916 .16601 Mdot
.916 .16609 Mdot
.916 .16649 Mdot
.916 .16655 Mdot
.916 .16694 Mdot
.916 .16721 Mdot
.916 .16728 Mdot
.916 .16745 Mdot
.916 .16764 Mdot
.916 .16788 Mdot
.916 .16814 Mdot
.916 .16817 Mdot
.916 .16854 Mdot
.916 .16857 Mdot
.916 .16865 Mdot
.916 .16919 Mdot
.916 .16921 Mdot
.916 .16926 Mdot
.916 .16956 Mdot
.916 .16965 Mdot
.916 .16979 Mdot
.916 .17012 Mdot
.916 .17031 Mdot
.916 .17082 Mdot
.916 .17186 Mdot
.916 .17246 Mdot
.916 .17256 Mdot
.916 .17311 Mdot
.916 .17327 Mdot
.916 .1747 Mdot
.916 .17528 Mdot
.916 .17532 Mdot
.916 .17558 Mdot
.916 .1768 Mdot
.916 .17728 Mdot
.916 .17849 Mdot
.916 .17866 Mdot
.916 .18002 Mdot
.916 .18014 Mdot
.916 .18048 Mdot
.916 .18066 Mdot
.916 .18073 Mdot
.916 .18094 Mdot
.916 .18141 Mdot
.916 .18235 Mdot
.916 .18255 Mdot
.916 .18264 Mdot
.916 .18323 Mdot
.916 .18352 Mdot
.916 .18383 Mdot
.916 .18404 Mdot
.916 .18602 Mdot
.916 .18729 Mdot
.916 .18734 Mdot
.916 .1876 Mdot
.916 .18763 Mdot
.916 .18784 Mdot
.916 .18842 Mdot
.916 .18843 Mdot
.916 .18846 Mdot
.916 .18884 Mdot
.916 .18911 Mdot
.916 .18936 Mdot
.916 .18967 Mdot
.916 .19034 Mdot
.916 .1912 Mdot
.916 .19178 Mdot
.916 .19189 Mdot
.916 .19259 Mdot
.916 .1926 Mdot
.916 .19291 Mdot
.916 .19297 Mdot
.916 .19303 Mdot
.916 .19325 Mdot
.916 .1943 Mdot
.916 .19443 Mdot
.916 .19445 Mdot
.916 .19463 Mdot
.916 .19494 Mdot
.916 .19526 Mdot
.916 .19569 Mdot
.916 .19579 Mdot
.916 .19583 Mdot
.916 .19627 Mdot
.916 .19634 Mdot
.916 .19641 Mdot
.916 .19741 Mdot
.916 .19882 Mdot
.916 .19994 Mdot
.916 .20031 Mdot
.916 .20296 Mdot
.916 .20335 Mdot
.916 .20347 Mdot
.916 .20442 Mdot
.916 .2059 Mdot
.916 .207 Mdot
.916 .20847 Mdot
.916 .21004 Mdot
.916 .21019 Mdot
.916 .21209 Mdot
.916 .21472 Mdot
.916 .21543 Mdot
.916 .21622 Mdot
.916 .21691 Mdot
.916 .21809 Mdot
.916 .22133 Mdot
.916 .22174 Mdot
.916 .22269 Mdot
.916 .22297 Mdot
.916 .22432 Mdot
.916 .22463 Mdot
.916 .22478 Mdot
.916 .22567 Mdot
.916 .22608 Mdot
.916 .23083 Mdot
.916 .23263 Mdot
.916 .23292 Mdot
.916 .2337 Mdot
.916 .23408 Mdot
.916 .23493 Mdot
.916 .24054 Mdot
.916 .24217 Mdot
.916 .24688 Mdot
.916 .24783 Mdot
.916 .25057 Mdot
.916 .25113 Mdot
.916 .25119 Mdot
.916 .25133 Mdot
.916 .25408 Mdot
.916 .25462 Mdot
.916 .25685 Mdot
.916 .25782 Mdot
.916 .26107 Mdot
.916 .26133 Mdot
.916 .2648 Mdot
.916 .26483 Mdot
.916 .26487 Mdot
.916 .26512 Mdot
.916 .26514 Mdot
.916 .26519 Mdot
.916 .26561 Mdot
.916 .26589 Mdot
.916 .26597 Mdot
.916 .26656 Mdot
.916 .26669 Mdot
.916 .26676 Mdot
.916 .26693 Mdot
.916 .26694 Mdot
.916 .26734 Mdot
.916 .26741 Mdot
.916 .26775 Mdot
.916 .26825 Mdot
.916 .26883 Mdot
.916 .26899 Mdot
.916 .26938 Mdot
.916 .2694 Mdot
.916 .26976 Mdot
.916 .26988 Mdot
.916 .27006 Mdot
.916 .27089 Mdot
.916 .27216 Mdot
.916 .27229 Mdot
.916 .27307 Mdot
.916 .27314 Mdot
.916 .2739 Mdot
.916 .27422 Mdot
.916 .27454 Mdot
.916 .27478 Mdot
.916 .27583 Mdot
.916 .27683 Mdot
.916 .27835 Mdot
.916 .27995 Mdot
.916 .28008 Mdot
.916 .28062 Mdot
.916 .28203 Mdot
.916 .28248 Mdot
.916 .28265 Mdot
.916 .28294 Mdot
.916 .28316 Mdot
.916 .2835 Mdot
.916 .284 Mdot
.916 .28408 Mdot
.916 .2841 Mdot
.916 .28446 Mdot
.916 .28474 Mdot
.916 .28497 Mdot
.916 .28516 Mdot
.916 .28533 Mdot
.916 .28541 Mdot
.916 .28613 Mdot
.916 .29033 Mdot
.916 .29058 Mdot
.916 .29085 Mdot
.916 .29101 Mdot
.916 .29176 Mdot
.916 .29185 Mdot
.916 .29198 Mdot
.916 .29254 Mdot
.916 .29378 Mdot
.916 .29497 Mdot
.916 .29639 Mdot
.916 .29645 Mdot
.916 .2965 Mdot
.916 .29666 Mdot
.916 .29696 Mdot
.916 .29707 Mdot
.916 .29791 Mdot
.916 .29972 Mdot
.916 .30027 Mdot
.916 .30209 Mdot
.916 .30268 Mdot
.916 .30276 Mdot
.916 .30298 Mdot
.916 .303 Mdot
.916 .30336 Mdot
.916 .30379 Mdot
.916 .30452 Mdot
.916 .30488 Mdot
.916 .30489 Mdot
.916 .30507 Mdot
.916 .30595 Mdot
.916 .30646 Mdot
.916 .30721 Mdot
.916 .30738 Mdot
.916 .30814 Mdot
.916 .30946 Mdot
.916 .30972 Mdot
.916 .31073 Mdot
.916 .31388 Mdot
.916 .31665 Mdot
.916 .31711 Mdot
.916 .3175 Mdot
.916 .31765 Mdot
.916 .31996 Mdot
.916 .32062 Mdot
.916 .32077 Mdot
.916 .32083 Mdot
.916 .32126 Mdot
.916 .32128 Mdot
.916 .32349 Mdot
.916 .32462 Mdot
.916 .32478 Mdot
.916 .32606 Mdot
.916 .32645 Mdot
.916 .32833 Mdot
.916 .33059 Mdot
.916 .33142 Mdot
.916 .3315 Mdot
.916 .33198 Mdot
.916 .33238 Mdot
.916 .33357 Mdot
.916 .33457 Mdot
.916 .33462 Mdot
.916 .33498 Mdot
.916 .33693 Mdot
.916 .33752 Mdot
.916 .33926 Mdot
.916 .33974 Mdot
.916 .33994 Mdot
.916 .34086 Mdot
.916 .34211 Mdot
.916 .3432 Mdot
.916 .34364 Mdot
.916 .34369 Mdot
.916 .34537 Mdot
.916 .34556 Mdot
.916 .34796 Mdot
.916 .34815 Mdot
.916 .34866 Mdot
.916 .34891 Mdot
.916 .34941 Mdot
.916 .35134 Mdot
.916 .35216 Mdot
.916 .35227 Mdot
.916 .35263 Mdot
.916 .35381 Mdot
.916 .35457 Mdot
.916 .35516 Mdot
.916 .35535 Mdot
.916 .35693 Mdot
.916 .35747 Mdot
.916 .35821 Mdot
.916 .35875 Mdot
.916 .35947 Mdot
.916 .36031 Mdot
.916 .36244 Mdot
.916 .36276 Mdot
.916 .36313 Mdot
.916 .36542 Mdot
.916 .3656 Mdot
.916 .36602 Mdot
.916 .36614 Mdot
.916 .36731 Mdot
.916 .36949 Mdot
.916 .37035 Mdot
.916 .37067 Mdot
.916 .37082 Mdot
.916 .37342 Mdot
.916 .37406 Mdot
.916 .37624 Mdot
.916 .37729 Mdot
.916 .3775 Mdot
.916 .37757 Mdot
.916 .3786 Mdot
.916 .3788 Mdot
.916 .37962 Mdot
.916 .37998 Mdot
.916 .38116 Mdot
.916 .38125 Mdot
.916 .3825 Mdot
.916 .38251 Mdot
.916 .38252 Mdot
.916 .38261 Mdot
.916 .38262 Mdot
.916 .38264 Mdot
.916 .38279 Mdot
.916 .38288 Mdot
.916 .38291 Mdot
.916 .38317 Mdot
.916 .38319 Mdot
.916 .38326 Mdot
.916 .38326 Mdot
.916 .3834 Mdot
.916 .38342 Mdot
.916 .38354 Mdot
.916 .38372 Mdot
.916 .38393 Mdot
.916 .38412 Mdot
.916 .38413 Mdot
.916 .38425 Mdot
.916 .3843 Mdot
.916 .38465 Mdot
.916 .38509 Mdot
.916 .38541 Mdot
.916 .3857 Mdot
.916 .38581 Mdot
.916 .38592 Mdot
.916 .386 Mdot
.916 .38636 Mdot
.916 .38671 Mdot
.916 .38777 Mdot
.916 .38782 Mdot
.916 .388 Mdot
.916 .38847 Mdot
.916 .38863 Mdot
.916 .38868 Mdot
.916 .38878 Mdot
.916 .38886 Mdot
.916 .38897 Mdot
.916 .38914 Mdot
.916 .38916 Mdot
.916 .38917 Mdot
.916 .38929 Mdot
.916 .38939 Mdot
.916 .38947 Mdot
.916 .38953 Mdot
.916 .38959 Mdot
.916 .38961 Mdot
.916 .38985 Mdot
.916 .39125 Mdot
.916 .39133 Mdot
.916 .39142 Mdot
.916 .39147 Mdot
.916 .39172 Mdot
.916 .39175 Mdot
.916 .39179 Mdot
.916 .39278 Mdot
.916 .39324 Mdot
.916 .39326 Mdot
.916 .39333 Mdot
.916 .39346 Mdot
.916 .39432 Mdot
.916 .3945 Mdot
.916 .39527 Mdot
.916 .3953 Mdot
.916 .39538 Mdot
.916 .39549 Mdot
.916 .39563 Mdot
.916 .39586 Mdot
.916 .39598 Mdot
.916 .39598 Mdot
.916 .39604 Mdot
.916 .39648 Mdot
.916 .39678 Mdot
.916 .39702 Mdot
.916 .39744 Mdot
.916 .39752 Mdot
.916 .39784 Mdot
.916 .39884 Mdot
.916 .39971 Mdot
.916 .39985 Mdot
.916 .40002 Mdot
.916 .40074 Mdot
.916 .40095 Mdot
.916 .40099 Mdot
.916 .40101 Mdot
.916 .40114 Mdot
.916 .40219 Mdot
.916 .40224 Mdot
.916 .40275 Mdot
.916 .40403 Mdot
.916 .40428 Mdot
.916 .40431 Mdot
.916 .40445 Mdot
.916 .40458 Mdot
.916 .40494 Mdot
.916 .40525 Mdot
.916 .40526 Mdot
.916 .40537 Mdot
.916 .40615 Mdot
.916 .40667 Mdot
.916 .40682 Mdot
.916 .40688 Mdot
.916 .40716 Mdot
.916 .40754 Mdot
.916 .408 Mdot
.916 .40852 Mdot
.916 .40858 Mdot
.916 .40931 Mdot
.916 .40936 Mdot
.916 .40952 Mdot
.916 .40974 Mdot
.916 .41032 Mdot
.916 .41057 Mdot
.916 .4106 Mdot
.916 .41071 Mdot
.916 .41129 Mdot
.916 .41147 Mdot
.916 .41152 Mdot
.916 .412 Mdot
.916 .41238 Mdot
.916 .41254 Mdot
.916 .41276 Mdot
.916 .41301 Mdot
.916 .41374 Mdot
.916 .41385 Mdot
.916 .41453 Mdot
.916 .41475 Mdot
.916 .41574 Mdot
.916 .416 Mdot
.916 .41609 Mdot
.916 .41614 Mdot
.916 .41691 Mdot
.916 .4171 Mdot
.916 .41806 Mdot
.916 .41814 Mdot
.916 .41845 Mdot
.916 .41851 Mdot
.916 .41875 Mdot
.916 .41886 Mdot
.916 .41921 Mdot
.916 .41972 Mdot
.916 .4198 Mdot
.916 .41988 Mdot
.916 .42085 Mdot
.916 .42117 Mdot
.916 .42147 Mdot
.916 .42159 Mdot
.916 .42225 Mdot
.916 .42234 Mdot
.916 .42282 Mdot
.916 .42361 Mdot
.916 .42407 Mdot
.916 .42472 Mdot
.916 .42476 Mdot
.916 .4251 Mdot
.916 .42511 Mdot
.916 .42601 Mdot
.916 .42608 Mdot
.916 .42637 Mdot
.916 .42789 Mdot
.916 .42825 Mdot
.916 .42856 Mdot
.916 .42915 Mdot
.916 .43035 Mdot
.916 .43056 Mdot
.916 .43074 Mdot
.916 .43106 Mdot
.916 .43125 Mdot
.916 .43128 Mdot
.916 .4319 Mdot
.916 .43224 Mdot
.916 .43225 Mdot
.916 .43235 Mdot
.916 .43265 Mdot
.916 .43274 Mdot
.916 .4332 Mdot
.916 .43359 Mdot
.916 .43396 Mdot
.916 .43408 Mdot
.916 .43466 Mdot
.916 .43506 Mdot
.916 .4351 Mdot
.916 .43528 Mdot
.916 .4354 Mdot
.916 .43564 Mdot
.916 .43581 Mdot
.916 .43583 Mdot
.916 .43605 Mdot
.916 .43638 Mdot
.916 .43645 Mdot
.916 .43686 Mdot
.916 .43716 Mdot
.916 .43739 Mdot
.916 .43793 Mdot
.916 .43821 Mdot
.916 .43831 Mdot
.916 .43842 Mdot
.916 .43908 Mdot
.916 .43976 Mdot
.916 .44058 Mdot
.916 .44074 Mdot
.916 .44126 Mdot
.916 .44144 Mdot
.916 .44147 Mdot
.916 .44182 Mdot
.916 .44206 Mdot
.916 .44313 Mdot
.916 .4432 Mdot
.916 .44352 Mdot
.916 .44404 Mdot
.916 .44408 Mdot
.916 .44412 Mdot
.916 .44439 Mdot
.916 .44457 Mdot
.916 .44463 Mdot
.916 .44476 Mdot
.916 .44499 Mdot
.916 .44599 Mdot
.916 .44602 Mdot
.916 .44607 Mdot
.916 .44672 Mdot
.916 .44683 Mdot
.916 .44718 Mdot
.916 .44762 Mdot
.916 .44786 Mdot
.916 .44814 Mdot
.916 .44838 Mdot
.916 .449 Mdot
.916 .44929 Mdot
.916 .45075 Mdot
.916 .45157 Mdot
.916 .45173 Mdot
.916 .45191 Mdot
.916 .45206 Mdot
.916 .45219 Mdot
.916 .45308 Mdot
.916 .45311 Mdot
.916 .45363 Mdot
.916 .45369 Mdot
.916 .4537 Mdot
.916 .45373 Mdot
.916 .45383 Mdot
.916 .45419 Mdot
.916 .45427 Mdot
.916 .45434 Mdot
.916 .45542 Mdot
.916 .45594 Mdot
.916 .45615 Mdot
.916 .45618 Mdot
.916 .45618 Mdot
.916 .45648 Mdot
.916 .457 Mdot
.916 .45748 Mdot
.916 .45752 Mdot
.916 .45823 Mdot
.916 .45826 Mdot
.916 .45839 Mdot
.916 .45841 Mdot
.916 .45845 Mdot
.916 .45917 Mdot
.916 .45929 Mdot
.916 .4594 Mdot
.916 .4595 Mdot
.916 .45969 Mdot
.916 .46018 Mdot
.916 .46069 Mdot
.916 .46103 Mdot
.916 .46226 Mdot
.916 .46238 Mdot
.916 .46251 Mdot
.916 .46329 Mdot
.916 .46333 Mdot
.916 .46389 Mdot
.916 .46406 Mdot
.916 .46445 Mdot
.916 .46454 Mdot
.916 .46503 Mdot
.916 .46506 Mdot
.916 .46516 Mdot
.916 .46565 Mdot
.916 .46667 Mdot
.916 .46697 Mdot
.916 .46817 Mdot
.916 .46824 Mdot
.916 .46839 Mdot
.916 .46879 Mdot
.916 .46979 Mdot
.916 .47033 Mdot
.916 .47038 Mdot
.916 .47057 Mdot
.916 .47066 Mdot
.916 .4717 Mdot
.916 .47187 Mdot
.916 .47202 Mdot
.916 .47298 Mdot
.916 .47336 Mdot
.916 .47369 Mdot
.916 .47393 Mdot
.916 .47427 Mdot
.916 .47451 Mdot
.916 .47522 Mdot
.916 .4753 Mdot
.916 .47557 Mdot
.916 .47591 Mdot
.916 .47644 Mdot
.916 .47659 Mdot
.916 .47664 Mdot
.916 .47701 Mdot
.916 .47787 Mdot
.916 .47809 Mdot
.916 .4782 Mdot
.916 .47842 Mdot
.916 .47851 Mdot
.916 .47956 Mdot
.916 .47965 Mdot
.916 .48039 Mdot
.916 .48041 Mdot
.916 .4806 Mdot
.916 .48108 Mdot
.916 .48162 Mdot
.916 .48203 Mdot
.916 .48211 Mdot
.916 .48232 Mdot
.916 .48308 Mdot
.916 .48334 Mdot
.916 .48418 Mdot
.916 .48433 Mdot
.916 .48435 Mdot
.916 .48479 Mdot
.916 .4853 Mdot
.916 .48547 Mdot
.916 .48568 Mdot
.916 .48571 Mdot
.916 .48607 Mdot
.916 .48703 Mdot
.916 .48784 Mdot
.916 .488 Mdot
.916 .48855 Mdot
.916 .48861 Mdot
.916 .4891 Mdot
.916 .49003 Mdot
.916 .49004 Mdot
.916 .49022 Mdot
.916 .49024 Mdot
.916 .49031 Mdot
.916 .49059 Mdot
.916 .49156 Mdot
.916 .49162 Mdot
.916 .49179 Mdot
.916 .49198 Mdot
.916 .49314 Mdot
.916 .49445 Mdot
.916 .49487 Mdot
.916 .49498 Mdot
.916 .49553 Mdot
.916 .49584 Mdot
.916 .49591 Mdot
.916 .49622 Mdot
.916 .49643 Mdot
.916 .4968 Mdot
.916 .49687 Mdot
.916 .49687 Mdot
.916 .49702 Mdot
.916 .49732 Mdot
.916 .4975 Mdot
.916 .49765 Mdot
.916 .49765 Mdot
.916 .49775 Mdot
.916 .49778 Mdot
.916 .49802 Mdot
.916 .49877 Mdot
.916 .49899 Mdot
.916 .49973 Mdot
.916 .50008 Mdot
.916 .50012 Mdot
.916 .50024 Mdot
.916 .50031 Mdot
.916 .50033 Mdot
.916 .50035 Mdot
.916 .50093 Mdot
.916 .50141 Mdot
.916 .50192 Mdot
.916 .50214 Mdot
.916 .5022 Mdot
.916 .50223 Mdot
.916 .50254 Mdot
.916 .5026 Mdot
.916 .50271 Mdot
.916 .50281 Mdot
.916 .5045 Mdot
.916 .5048 Mdot
.916 .50483 Mdot
.916 .50489 Mdot
.916 .50497 Mdot
.916 .50506 Mdot
.916 .50518 Mdot
.916 .50532 Mdot
.916 .50533 Mdot
.916 .50536 Mdot
.916 .50556 Mdot
.916 .5057 Mdot
.916 .50578 Mdot
.916 .5059 Mdot
.916 .50597 Mdot
.916 .50615 Mdot
.916 .50672 Mdot
.916 .50693 Mdot
.916 .50698 Mdot
.916 .50762 Mdot
.916 .50822 Mdot
.916 .50862 Mdot
.916 .50904 Mdot
.916 .50913 Mdot
.916 .50926 Mdot
.916 .50939 Mdot
.916 .50969 Mdot
.916 .50971 Mdot
.916 .51002 Mdot
.916 .51008 Mdot
.916 .51058 Mdot
.916 .5109 Mdot
.916 .51098 Mdot
.916 .51103 Mdot
.916 .51117 Mdot
.916 .51118 Mdot
.916 .51133 Mdot
.916 .51139 Mdot
.916 .51162 Mdot
.916 .51182 Mdot
.916 .51195 Mdot
.916 .51198 Mdot
.916 .51213 Mdot
.916 .51214 Mdot
.916 .51221 Mdot
.916 .51223 Mdot
.916 .51228 Mdot
.916 .51252 Mdot
.916 .51255 Mdot
.916 .51266 Mdot
.916 .51282 Mdot
.916 .51284 Mdot
.916 .51285 Mdot
.916 .51295 Mdot
.916 .51296 Mdot
.916 .51298 Mdot
.916 .51433 Mdot
.916 .51444 Mdot
.916 .5157 Mdot
.916 .51608 Mdot
.916 .51695 Mdot
.916 .51716 Mdot
.916 .51822 Mdot
.916 .51827 Mdot
.916 .5183 Mdot
.916 .51851 Mdot
.916 .51957 Mdot
.916 .51994 Mdot
.916 .52175 Mdot
.916 .52237 Mdot
.916 .52451 Mdot
.916 .52484 Mdot
.916 .52498 Mdot
.916 .52528 Mdot
.916 .52539 Mdot
.916 .52607 Mdot
.916 .52787 Mdot
.916 .52802 Mdot
.916 .52836 Mdot
.916 .52841 Mdot
.916 .52853 Mdot
.916 .52904 Mdot
.916 .52915 Mdot
.916 .52951 Mdot
.916 .52966 Mdot
.916 .53088 Mdot
.916 .53132 Mdot
.916 .53158 Mdot
.916 .53188 Mdot
.916 .53214 Mdot
.916 .53312 Mdot
.916 .53383 Mdot
.916 .53389 Mdot
.916 .53447 Mdot
.916 .53502 Mdot
.916 .53543 Mdot
.916 .53598 Mdot
.916 .53633 Mdot
.916 .53638 Mdot
.916 .53652 Mdot
.916 .5375 Mdot
.916 .53764 Mdot
.916 .53805 Mdot
.916 .53857 Mdot
.916 .53894 Mdot
.916 .53897 Mdot
.916 .53899 Mdot
.916 .53916 Mdot
.916 .53917 Mdot
.916 .53921 Mdot
.916 .53937 Mdot
.916 .53948 Mdot
.916 .5396 Mdot
.916 .53967 Mdot
.916 .53967 Mdot
.916 .53972 Mdot
.916 .54011 Mdot
.916 .54019 Mdot
.916 .54021 Mdot
.916 .54023 Mdot
.916 .54035 Mdot
.916 .54035 Mdot
.916 .54061 Mdot
.916 .54065 Mdot
.916 .54086 Mdot
.916 .54118 Mdot
.916 .54143 Mdot
.916 .54154 Mdot
.916 .54163 Mdot
.916 .54173 Mdot
.916 .54187 Mdot
.916 .54188 Mdot
.916 .54188 Mdot
.916 .5421 Mdot
.916 .54217 Mdot
.916 .54219 Mdot
.916 .54228 Mdot
.916 .5423 Mdot
.916 .54276 Mdot
.916 .54349 Mdot
.916 .54357 Mdot
.916 .54368 Mdot
.916 .54379 Mdot
.916 .544 Mdot
.916 .54404 Mdot
.916 .54445 Mdot
.916 .54462 Mdot
.916 .5447 Mdot
.916 .54472 Mdot
.916 .54479 Mdot
.916 .54491 Mdot
.916 .54496 Mdot
.916 .54546 Mdot
.916 .54552 Mdot
.916 .54596 Mdot
.916 .54613 Mdot
.916 .54658 Mdot
.916 .54667 Mdot
.916 .54669 Mdot
.916 .5469 Mdot
.916 .54742 Mdot
.916 .54748 Mdot
.916 .54767 Mdot
.916 .54771 Mdot
.916 .54793 Mdot
.916 .54831 Mdot
.916 .54849 Mdot
.916 .54856 Mdot
.916 .54868 Mdot
.916 .54873 Mdot
.916 .54877 Mdot
.916 .54887 Mdot
.916 .54889 Mdot
.916 .5489 Mdot
.916 .5491 Mdot
.916 .54912 Mdot
.916 .54913 Mdot
.916 .54927 Mdot
.916 .54928 Mdot
.916 .54938 Mdot
.916 .54946 Mdot
.916 .54953 Mdot
.916 .54959 Mdot
.916 .54962 Mdot
.916 .54972 Mdot
.916 .54986 Mdot
.916 .54988 Mdot
.916 .55002 Mdot
.916 .55005 Mdot
.916 .55033 Mdot
.916 .55104 Mdot
.916 .55122 Mdot
.916 .55129 Mdot
.916 .55136 Mdot
.916 .55141 Mdot
.916 .55157 Mdot
.916 .55161 Mdot
.916 .55163 Mdot
.916 .55167 Mdot
.916 .55167 Mdot
.916 .55181 Mdot
.916 .55199 Mdot
.916 .55203 Mdot
.916 .55211 Mdot
.916 .55229 Mdot
.916 .55238 Mdot
.916 .55267 Mdot
.916 .55268 Mdot
.916 .55269 Mdot
.916 .55272 Mdot
.916 .55275 Mdot
.916 .55275 Mdot
.916 .55278 Mdot
.916 .5528 Mdot
.916 .55283 Mdot
.916 .55284 Mdot
.916 .55287 Mdot
.916 .55295 Mdot
.916 .55298 Mdot
.916 .55323 Mdot
.916 .55331 Mdot
.916 .55333 Mdot
.916 .55335 Mdot
.916 .5534 Mdot
.916 .55345 Mdot
.916 .55353 Mdot
.916 .55359 Mdot
.916 .5536 Mdot
.916 .55362 Mdot
.916 .55362 Mdot
.916 .55365 Mdot
.916 .55369 Mdot
.916 .55372 Mdot
.916 .55374 Mdot
.916 .55377 Mdot
.916 .55377 Mdot
.916 .55378 Mdot
.916 .55383 Mdot
.916 .55385 Mdot
.916 .55387 Mdot
.916 .55388 Mdot
.916 .55388 Mdot
.916 .55389 Mdot
.916 .55389 Mdot
.916 .5539 Mdot
.918 .15239 Mdot
.918 .1524 Mdot
.918 .15241 Mdot
.918 .15243 Mdot
.918 .15247 Mdot
.918 .15256 Mdot
.918 .15263 Mdot
.918 .15266 Mdot
.918 .15268 Mdot
.918 .15268 Mdot
.918 .1527 Mdot
.918 .15281 Mdot
.918 .15284 Mdot
.918 .15291 Mdot
.918 .153 Mdot
.918 .15304 Mdot
.918 .15307 Mdot
.918 .1531 Mdot
.918 .1531 Mdot
.918 .15326 Mdot
.918 .15333 Mdot
.918 .15339 Mdot
.918 .15342 Mdot
.918 .15361 Mdot
.918 .15373 Mdot
.918 .15377 Mdot
.918 .15385 Mdot
.918 .154 Mdot
.918 .15418 Mdot
.918 .15428 Mdot
.918 .15446 Mdot
.918 .15467 Mdot
.918 .15499 Mdot
.918 .15505 Mdot
.918 .15551 Mdot
.918 .15586 Mdot
.918 .15587 Mdot
.918 .15622 Mdot
.918 .15696 Mdot
.918 .15714 Mdot
.918 .1573 Mdot
.918 .1574 Mdot
.918 .15783 Mdot
.918 .15822 Mdot
.918 .15839 Mdot
.918 .15844 Mdot
.918 .15849 Mdot
.918 .15917 Mdot
.918 .15933 Mdot
.918 .15938 Mdot
.918 .15951 Mdot
.918 .15978 Mdot
.918 .16043 Mdot
.918 .1607 Mdot
.918 .16095 Mdot
.918 .16116 Mdot
.918 .16158 Mdot
.918 .1617 Mdot
.918 .16186 Mdot
.918 .16217 Mdot
.918 .16225 Mdot
.918 .1625 Mdot
.918 .16256 Mdot
.918 .16326 Mdot
.918 .16346 Mdot
.918 .16437 Mdot
.918 .16446 Mdot
.918 .16476 Mdot
.918 .1652 Mdot
.918 .16574 Mdot
.918 .16604 Mdot
.918 .16638 Mdot
.918 .16681 Mdot
.918 .16706 Mdot
.918 .16712 Mdot
.918 .16722 Mdot
.918 .16746 Mdot
.918 .1676 Mdot
.918 .16808 Mdot
.918 .16897 Mdot
.918 .16911 Mdot
.918 .16927 Mdot
.918 .16946 Mdot
.918 .17012 Mdot
.918 .17041 Mdot
.918 .17097 Mdot
.918 .17102 Mdot
.918 .17178 Mdot
.918 .17217 Mdot
.918 .17268 Mdot
.918 .17278 Mdot
.918 .17354 Mdot
.918 .17369 Mdot
.918 .17383 Mdot
.918 .17399 Mdot
.918 .17457 Mdot
.918 .17468 Mdot
.918 .17495 Mdot
.918 .17545 Mdot
.918 .17555 Mdot
.918 .17567 Mdot
.918 .1761 Mdot
.918 .17622 Mdot
.918 .17637 Mdot
.918 .17699 Mdot
.918 .17727 Mdot
.918 .17743 Mdot
.918 .17766 Mdot
.918 .17766 Mdot
.918 .178 Mdot
.918 .17857 Mdot
.918 .18156 Mdot
.918 .18174 Mdot
.918 .18202 Mdot
.918 .18462 Mdot
.918 .1854 Mdot
.918 .18736 Mdot
.918 .18812 Mdot
.918 .18822 Mdot
.918 .18873 Mdot
.918 .18918 Mdot
.918 .1895 Mdot
.918 .19036 Mdot
.918 .19156 Mdot
.918 .19204 Mdot
.918 .19221 Mdot
.918 .1926 Mdot
.918 .1932 Mdot
.918 .19497 Mdot
.918 .19512 Mdot
.918 .19525 Mdot
.918 .19637 Mdot
.918 .19651 Mdot
.918 .19715 Mdot
.918 .19759 Mdot
.918 .19777 Mdot
.918 .19961 Mdot
.918 .20033 Mdot
.918 .20153 Mdot
.918 .20213 Mdot
.918 .20407 Mdot
.918 .20626 Mdot
.918 .20628 Mdot
.918 .2074 Mdot
.918 .20777 Mdot
.918 .20961 Mdot
.918 .21027 Mdot
.918 .21152 Mdot
.918 .21156 Mdot
.918 .21183 Mdot
.918 .21262 Mdot
.918 .21275 Mdot
.918 .21314 Mdot
.918 .21465 Mdot
.918 .2171 Mdot
.918 .21745 Mdot
.918 .21835 Mdot
.918 .21839 Mdot
.918 .2191 Mdot
.918 .21925 Mdot
.918 .22133 Mdot
.918 .22134 Mdot
.918 .22171 Mdot
.918 .22218 Mdot
.918 .22236 Mdot
.918 .22266 Mdot
.918 .22399 Mdot
.918 .2249 Mdot
.918 .22525 Mdot
.918 .22592 Mdot
.918 .22657 Mdot
.918 .22685 Mdot
.918 .22702 Mdot
.918 .22705 Mdot
.918 .22741 Mdot
.918 .22778 Mdot
.918 .22867 Mdot
.918 .22874 Mdot
.918 .22917 Mdot
.918 .22994 Mdot
.918 .23043 Mdot
.918 .23051 Mdot
.918 .23087 Mdot
.918 .2309 Mdot
.918 .23106 Mdot
.918 .23109 Mdot
.918 .23148 Mdot
.918 .23456 Mdot
.918 .23587 Mdot
.918 .23731 Mdot
.918 .24179 Mdot
.918 .24553 Mdot
.918 .24605 Mdot
.918 .24745 Mdot
.918 .24753 Mdot
.918 .24754 Mdot
.918 .24768 Mdot
.918 .24771 Mdot
.918 .24792 Mdot
.918 .24823 Mdot
.918 .24844 Mdot
.918 .24881 Mdot
.918 .24896 Mdot
.918 .24911 Mdot
.918 .24912 Mdot
.918 .24919 Mdot
.918 .24986 Mdot
.918 .25001 Mdot
.918 .25039 Mdot
.918 .25096 Mdot
.918 .25109 Mdot
.918 .25117 Mdot
.918 .25136 Mdot
.918 .25153 Mdot
.918 .25153 Mdot
.918 .25243 Mdot
.918 .25282 Mdot
.918 .25322 Mdot
.918 .25338 Mdot
.918 .25447 Mdot
.918 .25515 Mdot
.918 .25539 Mdot
.918 .2559 Mdot
.918 .25678 Mdot
.918 .25765 Mdot
.918 .25783 Mdot
.918 .25838 Mdot
.918 .25944 Mdot
.918 .2607 Mdot
.918 .26131 Mdot
.918 .26167 Mdot
.918 .26263 Mdot
.918 .26295 Mdot
.918 .26411 Mdot
.918 .2654 Mdot
.918 .26561 Mdot
.918 .26571 Mdot
.918 .26665 Mdot
.918 .26733 Mdot
.918 .26788 Mdot
.918 .26794 Mdot
.918 .26956 Mdot
.918 .27003 Mdot
.918 .27166 Mdot
.918 .27431 Mdot
.918 .27454 Mdot
.918 .27544 Mdot
.918 .27555 Mdot
.918 .27563 Mdot
.918 .27603 Mdot
.918 .2761 Mdot
.918 .27666 Mdot
.918 .27717 Mdot
.918 .27729 Mdot
.918 .27739 Mdot
.918 .27808 Mdot
.918 .27885 Mdot
.918 .27946 Mdot
.918 .27995 Mdot
.918 .28073 Mdot
.918 .28114 Mdot
.918 .28233 Mdot
.918 .28245 Mdot
.918 .28266 Mdot
.918 .28275 Mdot
.918 .28342 Mdot
.918 .28374 Mdot
.918 .28402 Mdot
.918 .28535 Mdot
.918 .28647 Mdot
.918 .28755 Mdot
.918 .28763 Mdot
.918 .28798 Mdot
.918 .28816 Mdot
.918 .2883 Mdot
.918 .28902 Mdot
.918 .28932 Mdot
.918 .28964 Mdot
.918 .29044 Mdot
.918 .29095 Mdot
.918 .29102 Mdot
.918 .29215 Mdot
.918 .29228 Mdot
.918 .29308 Mdot
.918 .29388 Mdot
.918 .29413 Mdot
.918 .29628 Mdot
.918 .29696 Mdot
.918 .29789 Mdot
.918 .298 Mdot
.918 .29964 Mdot
.918 .29987 Mdot
.918 .301 Mdot
.918 .30112 Mdot
.918 .30207 Mdot
.918 .3024 Mdot
.918 .30264 Mdot
.918 .30324 Mdot
.918 .30365 Mdot
.918 .3041 Mdot
.918 .30442 Mdot
.918 .30529 Mdot
.918 .3053 Mdot
.918 .30546 Mdot
.918 .30751 Mdot
.918 .30798 Mdot
.918 .30962 Mdot
.918 .31004 Mdot
.918 .31108 Mdot
.918 .31194 Mdot
.918 .31241 Mdot
.918 .31285 Mdot
.918 .31351 Mdot
.918 .31456 Mdot
.918 .3147 Mdot
.918 .31482 Mdot
.918 .31589 Mdot
.918 .31659 Mdot
.918 .31731 Mdot
.918 .31772 Mdot
.918 .31886 Mdot
.918 .31935 Mdot
.918 .32179 Mdot
.918 .32241 Mdot
.918 .32364 Mdot
.918 .32434 Mdot
.918 .32553 Mdot
.918 .32585 Mdot
.918 .32683 Mdot
.918 .32727 Mdot
.918 .32929 Mdot
.918 .33078 Mdot
.918 .33085 Mdot
.918 .3318 Mdot
.918 .3328 Mdot
.918 .33309 Mdot
.918 .33353 Mdot
.918 .33503 Mdot
.918 .33525 Mdot
.918 .33615 Mdot
.918 .33703 Mdot
.918 .33717 Mdot
.918 .33787 Mdot
.918 .33856 Mdot
.918 .3395 Mdot
.918 .3399 Mdot
.918 .34055 Mdot
.918 .34132 Mdot
.918 .34159 Mdot
.918 .34212 Mdot
.918 .34305 Mdot
.918 .34325 Mdot
.918 .34336 Mdot
.918 .34351 Mdot
.918 .34413 Mdot
.918 .34431 Mdot
.918 .34611 Mdot
.918 .34622 Mdot
.918 .34967 Mdot
.918 .35047 Mdot
.918 .35092 Mdot
.918 .35208 Mdot
.918 .35299 Mdot
.918 .35403 Mdot
.918 .3541 Mdot
.918 .3547 Mdot
.918 .35477 Mdot
.918 .35534 Mdot
.918 .35765 Mdot
.918 .35969 Mdot
.918 .36158 Mdot
.918 .36218 Mdot
.918 .3623 Mdot
.918 .36272 Mdot
.918 .36525 Mdot
.918 .36556 Mdot
.918 .36848 Mdot
.918 .36875 Mdot
.918 .36965 Mdot
.918 .3706 Mdot
.918 .37077 Mdot
.918 .3731 Mdot
.918 .37484 Mdot
.918 .37647 Mdot
.918 .37699 Mdot
.918 .37702 Mdot
.918 .37703 Mdot
.918 .37708 Mdot
.918 .37709 Mdot
.918 .37717 Mdot
.918 .37729 Mdot
.918 .37736 Mdot
.918 .3775 Mdot
.918 .37756 Mdot
.918 .37761 Mdot
.918 .37762 Mdot
.918 .37764 Mdot
.918 .37789 Mdot
.918 .37795 Mdot
.918 .37809 Mdot
.918 .3783 Mdot
.918 .37835 Mdot
.918 .37838 Mdot
.918 .37845 Mdot
.918 .37851 Mdot
.918 .37851 Mdot
.918 .37884 Mdot
.918 .37899 Mdot
.918 .37913 Mdot
.918 .37919 Mdot
.918 .37959 Mdot
.918 .37984 Mdot
.918 .37993 Mdot
.918 .38011 Mdot
.918 .38043 Mdot
.918 .38081 Mdot
.918 .38101 Mdot
.918 .38139 Mdot
.918 .38184 Mdot
.918 .38205 Mdot
.918 .38252 Mdot
.918 .38264 Mdot
.918 .38304 Mdot
.918 .38357 Mdot
.918 .38361 Mdot
.918 .38394 Mdot
.918 .38417 Mdot
.918 .38436 Mdot
.918 .38438 Mdot
.918 .38495 Mdot
.918 .38511 Mdot
.918 .38567 Mdot
.918 .38666 Mdot
.918 .38703 Mdot
.918 .38738 Mdot
.918 .38759 Mdot
.918 .38786 Mdot
.918 .38832 Mdot
.918 .38848 Mdot
.918 .38875 Mdot
.918 .38928 Mdot
.918 .38942 Mdot
.918 .38964 Mdot
.918 .38975 Mdot
.918 .38984 Mdot
.918 .39115 Mdot
.918 .39125 Mdot
.918 .39159 Mdot
.918 .39169 Mdot
.918 .39196 Mdot
.918 .39212 Mdot
.918 .39251 Mdot
.918 .39255 Mdot
.918 .39307 Mdot
.918 .39385 Mdot
.918 .39436 Mdot
.918 .3944 Mdot
.918 .39492 Mdot
.918 .395 Mdot
.918 .39536 Mdot
.918 .39581 Mdot
.918 .39607 Mdot
.918 .3962 Mdot
.918 .39645 Mdot
.918 .39678 Mdot
.918 .39742 Mdot
.918 .39757 Mdot
.918 .39809 Mdot
.918 .39822 Mdot
.918 .39854 Mdot
.918 .39909 Mdot
.918 .3993 Mdot
.918 .39963 Mdot
.918 .40004 Mdot
.918 .40026 Mdot
.918 .40048 Mdot
.918 .40111 Mdot
.918 .40186 Mdot
.918 .40205 Mdot
.918 .40243 Mdot
.918 .40264 Mdot
.918 .40301 Mdot
.918 .40311 Mdot
.918 .40354 Mdot
.918 .40415 Mdot
.918 .40461 Mdot
.918 .40463 Mdot
.918 .40522 Mdot
.918 .40589 Mdot
.918 .40596 Mdot
.918 .40675 Mdot
.918 .40696 Mdot
.918 .40724 Mdot
.918 .40736 Mdot
.918 .40756 Mdot
.918 .40787 Mdot
.918 .40803 Mdot
.918 .40831 Mdot
.918 .40836 Mdot
.918 .4084 Mdot
.918 .40863 Mdot
.918 .40868 Mdot
.918 .40922 Mdot
.918 .40925 Mdot
.918 .41052 Mdot
.918 .411 Mdot
.918 .41127 Mdot
.918 .41158 Mdot
.918 .4116 Mdot
.918 .41197 Mdot
.918 .41265 Mdot
.918 .41326 Mdot
.918 .41382 Mdot
.918 .41403 Mdot
.918 .41415 Mdot
.918 .4149 Mdot
.918 .41499 Mdot
.918 .41585 Mdot
.918 .4162 Mdot
.918 .41648 Mdot
.918 .41721 Mdot
.918 .4182 Mdot
.918 .41839 Mdot
.918 .41876 Mdot
.918 .41985 Mdot
.918 .42014 Mdot
.918 .4204 Mdot
.918 .4207 Mdot
.918 .42181 Mdot
.918 .42201 Mdot
.918 .42252 Mdot
.918 .42347 Mdot
.918 .42365 Mdot
.918 .42389 Mdot
.918 .42397 Mdot
.918 .4247 Mdot
.918 .42492 Mdot
.918 .42521 Mdot
.918 .42527 Mdot
.918 .42605 Mdot
.918 .42636 Mdot
.918 .42689 Mdot
.918 .42719 Mdot
.918 .42746 Mdot
.918 .42761 Mdot
.918 .42761 Mdot
.918 .42768 Mdot
.918 .42786 Mdot
.918 .42825 Mdot
.918 .42929 Mdot
.918 .43227 Mdot
.918 .43289 Mdot
.918 .43332 Mdot
.918 .43339 Mdot
.918 .43478 Mdot
.918 .43497 Mdot
.918 .4351 Mdot
.918 .43561 Mdot
.918 .43639 Mdot
.918 .4373 Mdot
.918 .43753 Mdot
.918 .43787 Mdot
.918 .44026 Mdot
.918 .44036 Mdot
.918 .44048 Mdot
.918 .44124 Mdot
.918 .44165 Mdot
.918 .44234 Mdot
.918 .44509 Mdot
.918 .44642 Mdot
.918 .4466 Mdot
.918 .44747 Mdot
.918 .44754 Mdot
.918 .44824 Mdot
.918 .44879 Mdot
.918 .44933 Mdot
.918 .45 Mdot
.918 .45027 Mdot
.918 .4503 Mdot
.918 .45041 Mdot
.918 .45043 Mdot
.918 .45068 Mdot
.918 .45114 Mdot
.918 .45164 Mdot
.918 .45231 Mdot
.918 .45255 Mdot
.918 .45307 Mdot
.918 .45312 Mdot
.918 .45341 Mdot
.918 .45406 Mdot
.918 .45438 Mdot
.918 .45449 Mdot
.918 .45496 Mdot
.918 .45506 Mdot
.918 .45533 Mdot
.918 .45655 Mdot
.918 .45668 Mdot
.918 .45707 Mdot
.918 .45738 Mdot
.918 .45801 Mdot
.918 .45826 Mdot
.918 .45847 Mdot
.918 .45894 Mdot
.918 .45977 Mdot
.918 .4601 Mdot
.918 .4603 Mdot
.918 .46052 Mdot
.918 .46157 Mdot
.918 .46192 Mdot
.918 .46228 Mdot
.918 .4624 Mdot
.918 .46257 Mdot
.918 .46282 Mdot
.918 .46329 Mdot
.918 .46503 Mdot
.918 .46553 Mdot
.918 .46562 Mdot
.918 .46591 Mdot
.918 .46667 Mdot
.918 .46748 Mdot
.918 .46856 Mdot
.918 .46863 Mdot
.918 .46907 Mdot
.918 .46948 Mdot
.918 .46961 Mdot
.918 .47094 Mdot
.918 .47108 Mdot
.918 .47223 Mdot
.918 .47242 Mdot
.918 .47248 Mdot
.918 .47275 Mdot
.918 .4736 Mdot
.918 .47452 Mdot
.918 .47556 Mdot
.918 .47581 Mdot
.918 .47584 Mdot
.918 .47611 Mdot
.918 .47614 Mdot
.918 .4766 Mdot
.918 .477 Mdot
.918 .47752 Mdot
.918 .47772 Mdot
.918 .47807 Mdot
.918 .47959 Mdot
.918 .47964 Mdot
.918 .48043 Mdot
.918 .48051 Mdot
.918 .48078 Mdot
.918 .48085 Mdot
.918 .4809 Mdot
.918 .48098 Mdot
.918 .48139 Mdot
.918 .48162 Mdot
.918 .48174 Mdot
.918 .48207 Mdot
.918 .48235 Mdot
.918 .48253 Mdot
.918 .48293 Mdot
.918 .48323 Mdot
.918 .48353 Mdot
.918 .4836 Mdot
.918 .48397 Mdot
.918 .48436 Mdot
.918 .48446 Mdot
.918 .4851 Mdot
.918 .48529 Mdot
.918 .48541 Mdot
.918 .48585 Mdot
.918 .48625 Mdot
.918 .48628 Mdot
.918 .48692 Mdot
.918 .48778 Mdot
.918 .48796 Mdot
.918 .48838 Mdot
.918 .48852 Mdot
.918 .48902 Mdot
.918 .48932 Mdot
.918 .48984 Mdot
.918 .4901 Mdot
.918 .49112 Mdot
.918 .49133 Mdot
.918 .4918 Mdot
.918 .49198 Mdot
.918 .49228 Mdot
.918 .49257 Mdot
.918 .49302 Mdot
.918 .49307 Mdot
.918 .49313 Mdot
.918 .49357 Mdot
.918 .49384 Mdot
.918 .49402 Mdot
.918 .49422 Mdot
.918 .49457 Mdot
.918 .495 Mdot
.918 .49518 Mdot
.918 .49586 Mdot
.918 .49605 Mdot
.918 .49689 Mdot
.918 .49696 Mdot
.918 .49697 Mdot
.918 .49732 Mdot
.918 .49745 Mdot
.918 .49764 Mdot
.918 .49781 Mdot
.918 .49805 Mdot
.918 .49815 Mdot
.918 .49828 Mdot
.918 .49868 Mdot
.918 .49872 Mdot
.918 .49918 Mdot
.918 .49928 Mdot
.918 .49995 Mdot
.918 .49999 Mdot
.918 .50037 Mdot
.918 .50065 Mdot
.918 .50152 Mdot
.918 .50162 Mdot
.918 .50195 Mdot
.918 .50227 Mdot
.918 .50232 Mdot
.918 .50278 Mdot
.918 .5028 Mdot
.918 .50301 Mdot
.918 .50333 Mdot
.918 .50346 Mdot
.918 .50358 Mdot
.918 .50387 Mdot
.918 .50393 Mdot
.918 .504 Mdot
.918 .50414 Mdot
.918 .50417 Mdot
.918 .50461 Mdot
.918 .50506 Mdot
.918 .50559 Mdot
.918 .5057 Mdot
.918 .50583 Mdot
.918 .5061 Mdot
.918 .50613 Mdot
.918 .50621 Mdot
.918 .50626 Mdot
.918 .50674 Mdot
.918 .5069 Mdot
.918 .50721 Mdot
.918 .50741 Mdot
.918 .50765 Mdot
.918 .50795 Mdot
.918 .50823 Mdot
.918 .50827 Mdot
.918 .50832 Mdot
.918 .50852 Mdot
.918 .50874 Mdot
.918 .50877 Mdot
.918 .50893 Mdot
.918 .50896 Mdot
.918 .509 Mdot
.918 .50936 Mdot
.918 .50945 Mdot
.918 .5105 Mdot
.918 .51114 Mdot
.918 .51132 Mdot
.918 .51196 Mdot
.918 .51198 Mdot
.918 .5122 Mdot
.918 .51246 Mdot
.918 .51283 Mdot
.918 .51287 Mdot
.918 .51296 Mdot
.918 .51346 Mdot
.918 .51391 Mdot
.918 .51404 Mdot
.918 .51441 Mdot
.918 .51455 Mdot
.918 .51479 Mdot
.918 .51528 Mdot
.918 .51569 Mdot
.918 .51591 Mdot
.918 .51597 Mdot
.918 .51631 Mdot
.918 .51665 Mdot
.918 .51685 Mdot
.918 .51694 Mdot
.918 .51721 Mdot
.918 .51763 Mdot
.918 .51769 Mdot
.918 .51784 Mdot
.918 .518 Mdot
.918 .51834 Mdot
.918 .51834 Mdot
.918 .51841 Mdot
.918 .51848 Mdot
.918 .51851 Mdot
.918 .51856 Mdot
.918 .51878 Mdot
.918 .51893 Mdot
.918 .51899 Mdot
.918 .51924 Mdot
.918 .51927 Mdot
.918 .51928 Mdot
.918 .51933 Mdot
.918 .51939 Mdot
.918 .51953 Mdot
.918 .51961 Mdot
.918 .51974 Mdot
.918 .51981 Mdot
.918 .51982 Mdot
.918 .51988 Mdot
.918 .51988 Mdot
.918 .51992 Mdot
.918 .52045 Mdot
.918 .52065 Mdot
.918 .52208 Mdot
.918 .52379 Mdot
.918 .52434 Mdot
.918 .52484 Mdot
.918 .526 Mdot
.918 .52615 Mdot
.918 .52616 Mdot
.918 .52622 Mdot
.918 .52623 Mdot
.918 .52637 Mdot
.918 .5264 Mdot
.918 .52659 Mdot
.918 .52688 Mdot
.918 .52704 Mdot
.918 .52707 Mdot
.918 .5274 Mdot
.918 .52754 Mdot
.918 .52768 Mdot
.918 .52769 Mdot
.918 .52775 Mdot
.918 .52786 Mdot
.918 .5281 Mdot
.918 .52836 Mdot
.918 .52849 Mdot
.918 .52883 Mdot
.918 .52933 Mdot
.918 .52944 Mdot
.918 .52951 Mdot
.918 .52968 Mdot
.918 .52983 Mdot
.918 .52983 Mdot
.918 .53061 Mdot
.918 .53067 Mdot
.918 .53093 Mdot
.918 .53095 Mdot
.918 .53128 Mdot
.918 .53141 Mdot
.918 .53233 Mdot
.918 .53289 Mdot
.918 .53304 Mdot
.918 .53309 Mdot
.918 .53338 Mdot
.918 .53348 Mdot
.918 .5335 Mdot
.918 .53396 Mdot
.918 .5342 Mdot
.918 .53489 Mdot
.918 .53503 Mdot
.918 .53544 Mdot
.918 .53545 Mdot
.918 .53626 Mdot
.918 .53698 Mdot
.918 .5372 Mdot
.918 .53764 Mdot
.918 .53791 Mdot
.918 .53859 Mdot
.918 .53865 Mdot
.918 .53882 Mdot
.918 .53905 Mdot
.918 .5391 Mdot
.918 .53952 Mdot
.918 .53956 Mdot
.918 .53962 Mdot
.918 .54027 Mdot
.918 .54049 Mdot
.918 .54063 Mdot
.918 .5407 Mdot
.918 .54087 Mdot
.918 .54131 Mdot
.918 .54163 Mdot
.918 .54175 Mdot
.918 .54191 Mdot
.918 .54209 Mdot
.918 .54213 Mdot
.918 .54241 Mdot
.918 .54313 Mdot
.918 .54341 Mdot
.918 .54436 Mdot
.918 .54446 Mdot
.918 .54453 Mdot
.918 .54562 Mdot
.918 .54582 Mdot
.918 .54595 Mdot
.918 .54595 Mdot
.918 .54603 Mdot
.918 .54609 Mdot
.918 .54619 Mdot
.918 .54642 Mdot
.918 .54647 Mdot
.918 .54652 Mdot
.918 .54667 Mdot
.918 .54672 Mdot
.918 .54675 Mdot
.918 .54694 Mdot
.918 .54703 Mdot
.918 .54707 Mdot
.918 .54728 Mdot
.918 .54734 Mdot
.918 .54739 Mdot
.918 .54745 Mdot
.918 .54772 Mdot
.918 .54776 Mdot
.918 .54794 Mdot
.918 .54808 Mdot
.918 .54836 Mdot
.918 .54838 Mdot
.918 .54858 Mdot
.918 .54868 Mdot
.918 .54892 Mdot
.918 .54899 Mdot
.918 .54905 Mdot
.918 .5491 Mdot
.918 .54942 Mdot
.918 .5496 Mdot
.918 .54965 Mdot
.918 .54973 Mdot
.918 .54977 Mdot
.918 .54979 Mdot
.918 .54988 Mdot
.918 .55004 Mdot
.918 .55016 Mdot
.918 .55027 Mdot
.918 .55046 Mdot
.918 .55062 Mdot
.918 .55073 Mdot
.918 .55076 Mdot
.918 .55109 Mdot
.918 .55116 Mdot
.918 .55141 Mdot
.918 .55144 Mdot
.918 .55153 Mdot
.918 .55156 Mdot
.918 .55167 Mdot
.918 .55173 Mdot
.918 .55177 Mdot
.918 .55192 Mdot
.918 .552 Mdot
.918 .55209 Mdot
.918 .55219 Mdot
.918 .55242 Mdot
.918 .55252 Mdot
.918 .55256 Mdot
.918 .55258 Mdot
.918 .55264 Mdot
.918 .55288 Mdot
.918 .5529 Mdot
.918 .55292 Mdot
.918 .55298 Mdot
.918 .55312 Mdot
.918 .55327 Mdot
.918 .55331 Mdot
.918 .55337 Mdot
.918 .55343 Mdot
.918 .5537 Mdot
.918 .55382 Mdot
.918 .55383 Mdot
.918 .55395 Mdot
.918 .55412 Mdot
.918 .55414 Mdot
.918 .55426 Mdot
.918 .55433 Mdot
.918 .5544 Mdot
.918 .55443 Mdot
.918 .55449 Mdot
.918 .55455 Mdot
.918 .55458 Mdot
.918 .55459 Mdot
.918 .55464 Mdot
.918 .5547 Mdot
.918 .55471 Mdot
.918 .55474 Mdot
.918 .55476 Mdot
.918 .55482 Mdot
.918 .55482 Mdot
.918 .55483 Mdot
.918 .55484 Mdot
.918 .55485 Mdot
.918 .55489 Mdot
.918 .55491 Mdot
.918 .55492 Mdot
.918 .55496 Mdot
.918 .55497 Mdot
.918 .55497 Mdot
.918 .55498 Mdot
.918 .55499 Mdot
.918 .55501 Mdot
.918 .55504 Mdot
.918 .55506 Mdot
.918 .55507 Mdot
.918 .55507 Mdot
.918 .55507 Mdot
.92 .14939 Mdot
.92 .14939 Mdot
.92 .14939 Mdot
.92 .14941 Mdot
.92 .1495 Mdot
.92 .14958 Mdot
.92 .14968 Mdot
.92 .15003 Mdot
.92 .15015 Mdot
.92 .15025 Mdot
.92 .15061 Mdot
.92 .15077 Mdot
.92 .15102 Mdot
.92 .15109 Mdot
.92 .15131 Mdot
.92 .15134 Mdot
.92 .15147 Mdot
.92 .15189 Mdot
.92 .15193 Mdot
.92 .15196 Mdot
.92 .15203 Mdot
.92 .15224 Mdot
.92 .15225 Mdot
.92 .15266 Mdot
.92 .15271 Mdot
.92 .15301 Mdot
.92 .15352 Mdot
.92 .15388 Mdot
.92 .1549 Mdot
.92 .15498 Mdot
.92 .1552 Mdot
.92 .15545 Mdot
.92 .15563 Mdot
.92 .15607 Mdot
.92 .15645 Mdot
.92 .15661 Mdot
.92 .15673 Mdot
.92 .15693 Mdot
.92 .15702 Mdot
.92 .15717 Mdot
.92 .15782 Mdot
.92 .15802 Mdot
.92 .15859 Mdot
.92 .15939 Mdot
.92 .15947 Mdot
.92 .15958 Mdot
.92 .15971 Mdot
.92 .1603 Mdot
.92 .16064 Mdot
.92 .16083 Mdot
.92 .16132 Mdot
.92 .16173 Mdot
.92 .16372 Mdot
.92 .16417 Mdot
.92 .16438 Mdot
.92 .16447 Mdot
.92 .16574 Mdot
.92 .16584 Mdot
.92 .16618 Mdot
.92 .167 Mdot
.92 .16723 Mdot
.92 .16904 Mdot
.92 .16945 Mdot
.92 .1697 Mdot
.92 .17033 Mdot
.92 .17065 Mdot
.92 .17119 Mdot
.92 .17132 Mdot
.92 .17143 Mdot
.92 .17244 Mdot
.92 .17258 Mdot
.92 .17333 Mdot
.92 .17335 Mdot
.92 .17341 Mdot
.92 .17369 Mdot
.92 .17392 Mdot
.92 .17442 Mdot
.92 .17473 Mdot
.92 .17474 Mdot
.92 .17488 Mdot
.92 .17581 Mdot
.92 .17656 Mdot
.92 .17678 Mdot
.92 .17689 Mdot
.92 .17767 Mdot
.92 .17768 Mdot
.92 .17773 Mdot
.92 .17779 Mdot
.92 .17786 Mdot
.92 .17794 Mdot
.92 .17795 Mdot
.92 .17851 Mdot
.92 .17858 Mdot
.92 .17868 Mdot
.92 .17928 Mdot
.92 .17947 Mdot
.92 .1796 Mdot
.92 .18038 Mdot
.92 .18249 Mdot
.92 .18293 Mdot
.92 .18314 Mdot
.92 .18317 Mdot
.92 .18342 Mdot
.92 .18522 Mdot
.92 .18606 Mdot
.92 .18705 Mdot
.92 .18743 Mdot
.92 .18782 Mdot
.92 .18981 Mdot
.92 .19001 Mdot
.92 .19031 Mdot
.92 .19205 Mdot
.92 .19226 Mdot
.92 .19255 Mdot
.92 .19325 Mdot
.92 .19359 Mdot
.92 .19373 Mdot
.92 .19394 Mdot
.92 .1948 Mdot
.92 .19504 Mdot
.92 .19507 Mdot
.92 .19603 Mdot
.92 .19653 Mdot
.92 .19653 Mdot
.92 .19677 Mdot
.92 .19698 Mdot
.92 .19755 Mdot
.92 .19755 Mdot
.92 .19829 Mdot
.92 .19865 Mdot
.92 .19909 Mdot
.92 .19918 Mdot
.92 .19994 Mdot
.92 .20094 Mdot
.92 .20193 Mdot
.92 .20513 Mdot
.92 .20852 Mdot
.92 .20872 Mdot
.92 .20985 Mdot
.92 .21087 Mdot
.92 .21159 Mdot
.92 .21345 Mdot
.92 .21403 Mdot
.92 .21454 Mdot
.92 .2193 Mdot
.92 .21959 Mdot
.92 .2205 Mdot
.92 .22235 Mdot
.92 .22297 Mdot
.92 .22299 Mdot
.92 .22318 Mdot
.92 .22318 Mdot
.92 .22343 Mdot
.92 .22465 Mdot
.92 .22493 Mdot
.92 .2254 Mdot
.92 .22583 Mdot
.92 .22672 Mdot
.92 .22841 Mdot
.92 .22937 Mdot
.92 .22967 Mdot
.92 .23032 Mdot
.92 .23033 Mdot
.92 .23034 Mdot
.92 .23041 Mdot
.92 .23065 Mdot
.92 .2309 Mdot
.92 .23111 Mdot
.92 .23131 Mdot
.92 .23132 Mdot
.92 .23134 Mdot
.92 .23137 Mdot
.92 .23153 Mdot
.92 .2317 Mdot
.92 .23189 Mdot
.92 .23242 Mdot
.92 .23381 Mdot
.92 .2342 Mdot
.92 .23448 Mdot
.92 .23451 Mdot
.92 .2347 Mdot
.92 .23505 Mdot
.92 .23538 Mdot
.92 .23546 Mdot
.92 .23595 Mdot
.92 .2365 Mdot
.92 .23706 Mdot
.92 .23744 Mdot
.92 .23795 Mdot
.92 .23934 Mdot
.92 .23937 Mdot
.92 .23977 Mdot
.92 .24035 Mdot
.92 .24101 Mdot
.92 .24119 Mdot
.92 .2419 Mdot
.92 .24285 Mdot
.92 .24396 Mdot
.92 .24433 Mdot
.92 .24454 Mdot
.92 .24473 Mdot
.92 .24476 Mdot
.92 .24511 Mdot
.92 .24522 Mdot
.92 .24592 Mdot
.92 .24621 Mdot
.92 .24635 Mdot
.92 .24636 Mdot
.92 .24636 Mdot
.92 .24644 Mdot
.92 .24702 Mdot
.92 .24714 Mdot
.92 .24858 Mdot
.92 .24875 Mdot
.92 .24906 Mdot
.92 .24967 Mdot
.92 .24975 Mdot
.92 .2508 Mdot
.92 .25131 Mdot
.92 .25359 Mdot
.92 .25385 Mdot
.92 .25468 Mdot
.92 .255 Mdot
.92 .25598 Mdot
.92 .25607 Mdot
.92 .25765 Mdot
.92 .25919 Mdot
.92 .26016 Mdot
.92 .26054 Mdot
.92 .26058 Mdot
.92 .2608 Mdot
.92 .26164 Mdot
.92 .26175 Mdot
.92 .26187 Mdot
.92 .26187 Mdot
.92 .26212 Mdot
.92 .26262 Mdot
.92 .26264 Mdot
.92 .26276 Mdot
.92 .26332 Mdot
.92 .2634 Mdot
.92 .26394 Mdot
.92 .26421 Mdot
.92 .26531 Mdot
.92 .26542 Mdot
.92 .26653 Mdot
.92 .26696 Mdot
.92 .26753 Mdot
.92 .26924 Mdot
.92 .26936 Mdot
.92 .26963 Mdot
.92 .27092 Mdot
.92 .27141 Mdot
.92 .27149 Mdot
.92 .27161 Mdot
.92 .27199 Mdot
.92 .27206 Mdot
.92 .2721 Mdot
.92 .27246 Mdot
.92 .27257 Mdot
.92 .27261 Mdot
.92 .27264 Mdot
.92 .27264 Mdot
.92 .27323 Mdot
.92 .27338 Mdot
.92 .27387 Mdot
.92 .2745 Mdot
.92 .2746 Mdot
.92 .27461 Mdot
.92 .27517 Mdot
.92 .27533 Mdot
.92 .27552 Mdot
.92 .27557 Mdot
.92 .27558 Mdot
.92 .27611 Mdot
.92 .27703 Mdot
.92 .27712 Mdot
.92 .27753 Mdot
.92 .27843 Mdot
.92 .27875 Mdot
.92 .28019 Mdot
.92 .28105 Mdot
.92 .28134 Mdot
.92 .28143 Mdot
.92 .28253 Mdot
.92 .28507 Mdot
.92 .2865 Mdot
.92 .28712 Mdot
.92 .28726 Mdot
.92 .28738 Mdot
.92 .28747 Mdot
.92 .28924 Mdot
.92 .29002 Mdot
.92 .2902 Mdot
.92 .29032 Mdot
.92 .29056 Mdot
.92 .29071 Mdot
.92 .29142 Mdot
.92 .29202 Mdot
.92 .29226 Mdot
.92 .29292 Mdot
.92 .29608 Mdot
.92 .29672 Mdot
.92 .29752 Mdot
.92 .29752 Mdot
.92 .29811 Mdot
.92 .29818 Mdot
.92 .29826 Mdot
.92 .29921 Mdot
.92 .29952 Mdot
.92 .30014 Mdot
.92 .30103 Mdot
.92 .30151 Mdot
.92 .30271 Mdot
.92 .30309 Mdot
.92 .30538 Mdot
.92 .30604 Mdot
.92 .30682 Mdot
.92 .30882 Mdot
.92 .30896 Mdot
.92 .30943 Mdot
.92 .30988 Mdot
.92 .31446 Mdot
.92 .31771 Mdot
.92 .31847 Mdot
.92 .32009 Mdot
.92 .32144 Mdot
.92 .32287 Mdot
.92 .32346 Mdot
.92 .32502 Mdot
.92 .32545 Mdot
.92 .32713 Mdot
.92 .32905 Mdot
.92 .3297 Mdot
.92 .3319 Mdot
.92 .3321 Mdot
.92 .33259 Mdot
.92 .33486 Mdot
.92 .33526 Mdot
.92 .33545 Mdot
.92 .33768 Mdot
.92 .33982 Mdot
.92 .3403 Mdot
.92 .34111 Mdot
.92 .34184 Mdot
.92 .34323 Mdot
.92 .3449 Mdot
.92 .34554 Mdot
.92 .34559 Mdot
.92 .34884 Mdot
.92 .34899 Mdot
.92 .35005 Mdot
.92 .35131 Mdot
.92 .35291 Mdot
.92 .35396 Mdot
.92 .35448 Mdot
.92 .35485 Mdot
.92 .3567 Mdot
.92 .3567 Mdot
.92 .35708 Mdot
.92 .35839 Mdot
.92 .36259 Mdot
.92 .36469 Mdot
.92 .36687 Mdot
.92 .36804 Mdot
.92 .3683 Mdot
.92 .36838 Mdot
.92 .36849 Mdot
.92 .36911 Mdot
.92 .36984 Mdot
.92 .37053 Mdot
.92 .3713 Mdot
.92 .3713 Mdot
.92 .37131 Mdot
.92 .37133 Mdot
.92 .37143 Mdot
.92 .37153 Mdot
.92 .37172 Mdot
.92 .37193 Mdot
.92 .37268 Mdot
.92 .37295 Mdot
.92 .37303 Mdot
.92 .37317 Mdot
.92 .37395 Mdot
.92 .37429 Mdot
.92 .37483 Mdot
.92 .37484 Mdot
.92 .37499 Mdot
.92 .37546 Mdot
.92 .37553 Mdot
.92 .3758 Mdot
.92 .37657 Mdot
.92 .37671 Mdot
.92 .37679 Mdot
.92 .37686 Mdot
.92 .377 Mdot
.92 .37731 Mdot
.92 .37741 Mdot
.92 .37747 Mdot
.92 .37747 Mdot
.92 .37747 Mdot
.92 .3775 Mdot
.92 .37776 Mdot
.92 .37835 Mdot
.92 .37847 Mdot
.92 .3791 Mdot
.92 .37928 Mdot
.92 .3802 Mdot
.92 .3805 Mdot
.92 .38097 Mdot
.92 .38245 Mdot
.92 .38258 Mdot
.92 .38297 Mdot
.92 .38305 Mdot
.92 .38305 Mdot
.92 .38314 Mdot
.92 .38331 Mdot
.92 .38331 Mdot
.92 .38377 Mdot
.92 .38428 Mdot
.92 .38466 Mdot
.92 .38481 Mdot
.92 .38501 Mdot
.92 .38559 Mdot
.92 .38573 Mdot
.92 .38633 Mdot
.92 .3864 Mdot
.92 .38655 Mdot
.92 .38656 Mdot
.92 .38675 Mdot
.92 .387 Mdot
.92 .38738 Mdot
.92 .38741 Mdot
.92 .3876 Mdot
.92 .38791 Mdot
.92 .38822 Mdot
.92 .38825 Mdot
.92 .38879 Mdot
.92 .38927 Mdot
.92 .38956 Mdot
.92 .38968 Mdot
.92 .39004 Mdot
.92 .39087 Mdot
.92 .39154 Mdot
.92 .39159 Mdot
.92 .39163 Mdot
.92 .39165 Mdot
.92 .39248 Mdot
.92 .39254 Mdot
.92 .39258 Mdot
.92 .3927 Mdot
.92 .39293 Mdot
.92 .3932 Mdot
.92 .39442 Mdot
.92 .39511 Mdot
.92 .39542 Mdot
.92 .39551 Mdot
.92 .39599 Mdot
.92 .39614 Mdot
.92 .39652 Mdot
.92 .39664 Mdot
.92 .39735 Mdot
.92 .3978 Mdot
.92 .39842 Mdot
.92 .39862 Mdot
.92 .40017 Mdot
.92 .40117 Mdot
.92 .4014 Mdot
.92 .40189 Mdot
.92 .4023 Mdot
.92 .40274 Mdot
.92 .40292 Mdot
.92 .40339 Mdot
.92 .4048 Mdot
.92 .40546 Mdot
.92 .40552 Mdot
.92 .40567 Mdot
.92 .40635 Mdot
.92 .40653 Mdot
.92 .40783 Mdot
.92 .40797 Mdot
.92 .40843 Mdot
.92 .40884 Mdot
.92 .40952 Mdot
.92 .4105 Mdot
.92 .41054 Mdot
.92 .41086 Mdot
.92 .41123 Mdot
.92 .4117 Mdot
.92 .41201 Mdot
.92 .41216 Mdot
.92 .41227 Mdot
.92 .41281 Mdot
.92 .41281 Mdot
.92 .41331 Mdot
.92 .41454 Mdot
.92 .41515 Mdot
.92 .41579 Mdot
.92 .41621 Mdot
.92 .41623 Mdot
.92 .41626 Mdot
.92 .41644 Mdot
.92 .41666 Mdot
.92 .41686 Mdot
.92 .41759 Mdot
.92 .41862 Mdot
.92 .41883 Mdot
.92 .41886 Mdot
.92 .41889 Mdot
.92 .42033 Mdot
.92 .42037 Mdot
.92 .42048 Mdot
.92 .42058 Mdot
.92 .42102 Mdot
.92 .42146 Mdot
.92 .42177 Mdot
.92 .42201 Mdot
.92 .42218 Mdot
.92 .4224 Mdot
.92 .42254 Mdot
.92 .423 Mdot
.92 .42301 Mdot
.92 .42328 Mdot
.92 .42428 Mdot
.92 .42499 Mdot
.92 .42505 Mdot
.92 .42645 Mdot
.92 .42686 Mdot
.92 .42707 Mdot
.92 .42737 Mdot
.92 .42854 Mdot
.92 .42855 Mdot
.92 .42864 Mdot
.92 .42875 Mdot
.92 .42889 Mdot
.92 .42903 Mdot
.92 .42906 Mdot
.92 .42922 Mdot
.92 .4301 Mdot
.92 .43023 Mdot
.92 .43041 Mdot
.92 .431 Mdot
.92 .43152 Mdot
.92 .43187 Mdot
.92 .43194 Mdot
.92 .4321 Mdot
.92 .43262 Mdot
.92 .43354 Mdot
.92 .4341 Mdot
.92 .43737 Mdot
.92 .43818 Mdot
.92 .43854 Mdot
.92 .43861 Mdot
.92 .43906 Mdot
.92 .44002 Mdot
.92 .44101 Mdot
.92 .44227 Mdot
.92 .44265 Mdot
.92 .44357 Mdot
.92 .44376 Mdot
.92 .44384 Mdot
.92 .44397 Mdot
.92 .44459 Mdot
.92 .44549 Mdot
.92 .44551 Mdot
.92 .44615 Mdot
.92 .44653 Mdot
.92 .44684 Mdot
.92 .44685 Mdot
.92 .44708 Mdot
.92 .44861 Mdot
.92 .44888 Mdot
.92 .44894 Mdot
.92 .44917 Mdot
.92 .44941 Mdot
.92 .4496 Mdot
.92 .44976 Mdot
.92 .44978 Mdot
.92 .45028 Mdot
.92 .45062 Mdot
.92 .45113 Mdot
.92 .45179 Mdot
.92 .45229 Mdot
.92 .45265 Mdot
.92 .45335 Mdot
.92 .45409 Mdot
.92 .45445 Mdot
.92 .45494 Mdot
.92 .45571 Mdot
.92 .4558 Mdot
.92 .45611 Mdot
.92 .45668 Mdot
.92 .45692 Mdot
.92 .45699 Mdot
.92 .45727 Mdot
.92 .45865 Mdot
.92 .45869 Mdot
.92 .45909 Mdot
.92 .45911 Mdot
.92 .45912 Mdot
.92 .45915 Mdot
.92 .45987 Mdot
.92 .4601 Mdot
.92 .46047 Mdot
.92 .46072 Mdot
.92 .46074 Mdot
.92 .46114 Mdot
.92 .46153 Mdot
.92 .46154 Mdot
.92 .46164 Mdot
.92 .46193 Mdot
.92 .46227 Mdot
.92 .46236 Mdot
.92 .46307 Mdot
.92 .4632 Mdot
.92 .4632 Mdot
.92 .46323 Mdot
.92 .46342 Mdot
.92 .46348 Mdot
.92 .46439 Mdot
.92 .46497 Mdot
.92 .46568 Mdot
.92 .4658 Mdot
.92 .46581 Mdot
.92 .46584 Mdot
.92 .46589 Mdot
.92 .46623 Mdot
.92 .46704 Mdot
.92 .46787 Mdot
.92 .46861 Mdot
.92 .46902 Mdot
.92 .46934 Mdot
.92 .46967 Mdot
.92 .46996 Mdot
.92 .47 Mdot
.92 .47004 Mdot
.92 .47016 Mdot
.92 .47069 Mdot
.92 .47169 Mdot
.92 .47263 Mdot
.92 .47452 Mdot
.92 .47511 Mdot
.92 .47528 Mdot
.92 .47528 Mdot
.92 .4761 Mdot
.92 .47627 Mdot
.92 .4765 Mdot
.92 .47697 Mdot
.92 .47767 Mdot
.92 .47823 Mdot
.92 .47869 Mdot
.92 .47876 Mdot
.92 .48019 Mdot
.92 .48021 Mdot
.92 .48049 Mdot
.92 .48121 Mdot
.92 .48182 Mdot
.92 .48214 Mdot
.92 .48249 Mdot
.92 .48269 Mdot
.92 .48362 Mdot
.92 .48458 Mdot
.92 .48466 Mdot
.92 .48483 Mdot
.92 .4858 Mdot
.92 .48601 Mdot
.92 .4861 Mdot
.92 .48703 Mdot
.92 .48731 Mdot
.92 .48812 Mdot
.92 .48883 Mdot
.92 .48902 Mdot
.92 .48967 Mdot
.92 .48992 Mdot
.92 .49053 Mdot
.92 .49109 Mdot
.92 .49177 Mdot
.92 .49208 Mdot
.92 .49344 Mdot
.92 .49534 Mdot
.92 .49552 Mdot
.92 .49571 Mdot
.92 .49577 Mdot
.92 .4966 Mdot
.92 .49692 Mdot
.92 .49719 Mdot
.92 .49813 Mdot
.92 .49828 Mdot
.92 .49877 Mdot
.92 .49896 Mdot
.92 .49933 Mdot
.92 .49958 Mdot
.92 .49971 Mdot
.92 .50009 Mdot
.92 .50013 Mdot
.92 .50015 Mdot
.92 .50039 Mdot
.92 .50039 Mdot
.92 .50072 Mdot
.92 .50098 Mdot
.92 .50226 Mdot
.92 .50252 Mdot
.92 .50262 Mdot
.92 .50286 Mdot
.92 .50314 Mdot
.92 .5032 Mdot
.92 .5033 Mdot
.92 .50335 Mdot
.92 .50342 Mdot
.92 .50373 Mdot
.92 .50445 Mdot
.92 .50448 Mdot
.92 .50453 Mdot
.92 .50458 Mdot
.92 .50483 Mdot
.92 .5054 Mdot
.92 .50642 Mdot
.92 .50685 Mdot
.92 .50689 Mdot
.92 .507 Mdot
.92 .50735 Mdot
.92 .50792 Mdot
.92 .50804 Mdot
.92 .5084 Mdot
.92 .50856 Mdot
.92 .5086 Mdot
.92 .50896 Mdot
.92 .50917 Mdot
.92 .50918 Mdot
.92 .50919 Mdot
.92 .50927 Mdot
.92 .50934 Mdot
.92 .50955 Mdot
.92 .50956 Mdot
.92 .5096 Mdot
.92 .50984 Mdot
.92 .51004 Mdot
.92 .5101 Mdot
.92 .51033 Mdot
.92 .51033 Mdot
.92 .51034 Mdot
.92 .51036 Mdot
.92 .5104 Mdot
.92 .51054 Mdot
.92 .51056 Mdot
.92 .51059 Mdot
.92 .51073 Mdot
.92 .51078 Mdot
.92 .51081 Mdot
.92 .51101 Mdot
.92 .51151 Mdot
.92 .51162 Mdot
.92 .51167 Mdot
.92 .51234 Mdot
.92 .51256 Mdot
.92 .51273 Mdot
.92 .51316 Mdot
.92 .5132 Mdot
.92 .51363 Mdot
.92 .51374 Mdot
.92 .51395 Mdot
.92 .51398 Mdot
.92 .5142 Mdot
.92 .51424 Mdot
.92 .51425 Mdot
.92 .51444 Mdot
.92 .51454 Mdot
.92 .51454 Mdot
.92 .51459 Mdot
.92 .51463 Mdot
.92 .51496 Mdot
.92 .51504 Mdot
.92 .51506 Mdot
.92 .51521 Mdot
.92 .51558 Mdot
.92 .51618 Mdot
.92 .51679 Mdot
.92 .51683 Mdot
.92 .5172 Mdot
.92 .51733 Mdot
.92 .51765 Mdot
.92 .51775 Mdot
.92 .51863 Mdot
.92 .51882 Mdot
.92 .51923 Mdot
.92 .51926 Mdot
.92 .51949 Mdot
.92 .51961 Mdot
.92 .51968 Mdot
.92 .52023 Mdot
.92 .52027 Mdot
.92 .52049 Mdot
.92 .52052 Mdot
.92 .52053 Mdot
.92 .52053 Mdot
.92 .52058 Mdot
.92 .52069 Mdot
.92 .52096 Mdot
.92 .521 Mdot
.92 .52114 Mdot
.92 .52115 Mdot
.92 .52122 Mdot
.92 .5213 Mdot
.92 .52144 Mdot
.92 .52187 Mdot
.92 .52223 Mdot
.92 .5225 Mdot
.92 .52257 Mdot
.92 .52282 Mdot
.92 .52304 Mdot
.92 .52319 Mdot
.92 .5232 Mdot
.92 .52373 Mdot
.92 .52393 Mdot
.92 .52407 Mdot
.92 .52428 Mdot
.92 .52449 Mdot
.92 .52468 Mdot
.92 .52471 Mdot
.92 .52483 Mdot
.92 .52496 Mdot
.92 .52504 Mdot
.92 .52505 Mdot
.92 .52516 Mdot
.92 .5253 Mdot
.92 .52583 Mdot
.92 .52603 Mdot
.92 .5261 Mdot
.92 .52616 Mdot
.92 .52622 Mdot
.92 .52624 Mdot
.92 .52624 Mdot
.92 .52625 Mdot
.92 .52632 Mdot
.92 .5264 Mdot
.92 .5265 Mdot
.92 .52659 Mdot
.92 .52661 Mdot
.92 .52662 Mdot
.92 .52662 Mdot
.92 .52686 Mdot
.92 .52698 Mdot
.92 .52734 Mdot
.92 .52798 Mdot
.92 .52831 Mdot
.92 .52847 Mdot
.92 .52865 Mdot
.92 .52875 Mdot
.92 .52921 Mdot
.92 .52931 Mdot
.92 .52931 Mdot
.92 .52938 Mdot
.92 .52938 Mdot
.92 .52962 Mdot
.92 .53031 Mdot
.92 .53065 Mdot
.92 .53076 Mdot
.92 .53253 Mdot
.92 .53272 Mdot
.92 .53294 Mdot
.92 .53363 Mdot
.92 .5339 Mdot
.92 .53428 Mdot
.92 .53469 Mdot
.92 .53477 Mdot
.92 .53602 Mdot
.92 .5372 Mdot
.92 .53757 Mdot
.92 .53794 Mdot
.92 .53822 Mdot
.92 .53825 Mdot
.92 .53841 Mdot
.92 .53854 Mdot
.92 .53882 Mdot
.92 .53882 Mdot
.92 .53903 Mdot
.92 .5391 Mdot
.92 .53919 Mdot
.92 .53919 Mdot
.92 .53937 Mdot
.92 .53972 Mdot
.92 .53974 Mdot
.92 .53983 Mdot
.92 .54014 Mdot
.92 .54022 Mdot
.92 .54027 Mdot
.92 .5404 Mdot
.92 .54065 Mdot
.92 .54076 Mdot
.92 .54083 Mdot
.92 .54147 Mdot
.92 .54158 Mdot
.92 .54165 Mdot
.92 .54238 Mdot
.92 .54252 Mdot
.92 .54266 Mdot
.92 .54302 Mdot
.92 .54333 Mdot
.92 .54398 Mdot
.92 .54407 Mdot
.92 .54409 Mdot
.92 .54416 Mdot
.92 .54432 Mdot
.92 .54509 Mdot
.92 .54537 Mdot
.92 .54542 Mdot
.92 .54549 Mdot
.92 .54571 Mdot
.92 .54574 Mdot
.92 .54577 Mdot
.92 .54597 Mdot
.92 .54598 Mdot
.92 .546 Mdot
.92 .54603 Mdot
.92 .54605 Mdot
.92 .54607 Mdot
.92 .54607 Mdot
.92 .54636 Mdot
.92 .5464 Mdot
.92 .54648 Mdot
.92 .54675 Mdot
.92 .54709 Mdot
.92 .54714 Mdot
.92 .54714 Mdot
.92 .54725 Mdot
.92 .54743 Mdot
.92 .54752 Mdot
.92 .54762 Mdot
.92 .54764 Mdot
.92 .54765 Mdot
.92 .54792 Mdot
.92 .54797 Mdot
.92 .54834 Mdot
.92 .54838 Mdot
.92 .54842 Mdot
.92 .54862 Mdot
.92 .54873 Mdot
.92 .54896 Mdot
.92 .54905 Mdot
.92 .5492 Mdot
.92 .54985 Mdot
.92 .54993 Mdot
.92 .55023 Mdot
.92 .55035 Mdot
.92 .55039 Mdot
.92 .55084 Mdot
.92 .55088 Mdot
.92 .55095 Mdot
.92 .55112 Mdot
.92 .55183 Mdot
.92 .55198 Mdot
.92 .55215 Mdot
.92 .55222 Mdot
.92 .55234 Mdot
.92 .55256 Mdot
.92 .5526 Mdot
.92 .55264 Mdot
.92 .55267 Mdot
.92 .55296 Mdot
.92 .55316 Mdot
.92 .55323 Mdot
.92 .55347 Mdot
.92 .55352 Mdot
.92 .55355 Mdot
.92 .55362 Mdot
.92 .55367 Mdot
.92 .55373 Mdot
.92 .55386 Mdot
.92 .55402 Mdot
.92 .55409 Mdot
.92 .55417 Mdot
.92 .55425 Mdot
.92 .55428 Mdot
.92 .55465 Mdot
.92 .55477 Mdot
.92 .55496 Mdot
.92 .55507 Mdot
.92 .55508 Mdot
.92 .55523 Mdot
.92 .55523 Mdot
.92 .55531 Mdot
.92 .55533 Mdot
.92 .55534 Mdot
.92 .55536 Mdot
.92 .55551 Mdot
.92 .55555 Mdot
.92 .55557 Mdot
.92 .55564 Mdot
.92 .55567 Mdot
.92 .55576 Mdot
.92 .55582 Mdot
.92 .55594 Mdot
.92 .55598 Mdot
.92 .55602 Mdot
.92 .55615 Mdot
.92 .55618 Mdot
.92 .55621 Mdot
.92 .55625 Mdot
.92 .55625 Mdot
.92 .55625 Mdot
.92 .55625 Mdot
.922 .14639 Mdot
.922 .1464 Mdot
.922 .14643 Mdot
.922 .14644 Mdot
.922 .14645 Mdot
.922 .14648 Mdot
.922 .14652 Mdot
.922 .14655 Mdot
.922 .14661 Mdot
.922 .14665 Mdot
.922 .14665 Mdot
.922 .14668 Mdot
.922 .1467 Mdot
.922 .14677 Mdot
.922 .14688 Mdot
.922 .14693 Mdot
.922 .14695 Mdot
.922 .14697 Mdot
.922 .14704 Mdot
.922 .14709 Mdot
.922 .14717 Mdot
.922 .14724 Mdot
.922 .14727 Mdot
.922 .1473 Mdot
.922 .14749 Mdot
.922 .14758 Mdot
.922 .1476 Mdot
.922 .14764 Mdot
.922 .14773 Mdot
.922 .14776 Mdot
.922 .14783 Mdot
.922 .14785 Mdot
.922 .14787 Mdot
.922 .14805 Mdot
.922 .14812 Mdot
.922 .14882 Mdot
.922 .14883 Mdot
.922 .14885 Mdot
.922 .14885 Mdot
.922 .14895 Mdot
.922 .14896 Mdot
.922 .14902 Mdot
.922 .14911 Mdot
.922 .14914 Mdot
.922 .14946 Mdot
.922 .14962 Mdot
.922 .14968 Mdot
.922 .14979 Mdot
.922 .14986 Mdot
.922 .14987 Mdot
.922 .14992 Mdot
.922 .15017 Mdot
.922 .15026 Mdot
.922 .15031 Mdot
.922 .15035 Mdot
.922 .15047 Mdot
.922 .15053 Mdot
.922 .15084 Mdot
.922 .15089 Mdot
.922 .151 Mdot
.922 .15127 Mdot
.922 .15149 Mdot
.922 .15159 Mdot
.922 .15172 Mdot
.922 .15198 Mdot
.922 .15203 Mdot
.922 .15221 Mdot
.922 .15226 Mdot
.922 .15268 Mdot
.922 .15278 Mdot
.922 .15298 Mdot
.922 .15325 Mdot
.922 .15348 Mdot
.922 .1539 Mdot
.922 .15421 Mdot
.922 .15427 Mdot
.922 .15487 Mdot
.922 .15555 Mdot
.922 .15652 Mdot
.922 .15827 Mdot
.922 .15888 Mdot
.922 .15916 Mdot
.922 .15927 Mdot
.922 .15934 Mdot
.922 .15942 Mdot
.922 .15982 Mdot
.922 .15984 Mdot
.922 .1605 Mdot
.922 .16053 Mdot
.922 .16056 Mdot
.922 .16104 Mdot
.922 .16161 Mdot
.922 .16188 Mdot
.922 .16289 Mdot
.922 .16295 Mdot
.922 .16477 Mdot
.922 .16482 Mdot
.922 .16566 Mdot
.922 .16651 Mdot
.922 .16847 Mdot
.922 .16894 Mdot
.922 .169 Mdot
.922 .16914 Mdot
.922 .16988 Mdot
.922 .17194 Mdot
.922 .17289 Mdot
.922 .17542 Mdot
.922 .17709 Mdot
.922 .17876 Mdot
.922 .17953 Mdot
.922 .18043 Mdot
.922 .18185 Mdot
.922 .18396 Mdot
.922 .18415 Mdot
.922 .18495 Mdot
.922 .18498 Mdot
.922 .18556 Mdot
.922 .18564 Mdot
.922 .18762 Mdot
.922 .18909 Mdot
.922 .19027 Mdot
.922 .19088 Mdot
.922 .19113 Mdot
.922 .19176 Mdot
.922 .1928 Mdot
.922 .19351 Mdot
.922 .19353 Mdot
.922 .19356 Mdot
.922 .19379 Mdot
.922 .19619 Mdot
.922 .19805 Mdot
.922 .19929 Mdot
.922 .19991 Mdot
.922 .20108 Mdot
.922 .20112 Mdot
.922 .20192 Mdot
.922 .20339 Mdot
.922 .20391 Mdot
.922 .20496 Mdot
.922 .20549 Mdot
.922 .2059 Mdot
.922 .20927 Mdot
.922 .21128 Mdot
.922 .21166 Mdot
.922 .21276 Mdot
.922 .21378 Mdot
.922 .21382 Mdot
.922 .21399 Mdot
.922 .21401 Mdot
.922 .21411 Mdot
.922 .21422 Mdot
.922 .21442 Mdot
.922 .21461 Mdot
.922 .21481 Mdot
.922 .21492 Mdot
.922 .21513 Mdot
.922 .21513 Mdot
.922 .21523 Mdot
.922 .21527 Mdot
.922 .21536 Mdot
.922 .21575 Mdot
.922 .21575 Mdot
.922 .21631 Mdot
.922 .21649 Mdot
.922 .21654 Mdot
.922 .21666 Mdot
.922 .2168 Mdot
.922 .21699 Mdot
.922 .21714 Mdot
.922 .21729 Mdot
.922 .21742 Mdot
.922 .21781 Mdot
.922 .21821 Mdot
.922 .21833 Mdot
.922 .2185 Mdot
.922 .21869 Mdot
.922 .21875 Mdot
.922 .21948 Mdot
.922 .21999 Mdot
.922 .22008 Mdot
.922 .22029 Mdot
.922 .22075 Mdot
.922 .22096 Mdot
.922 .22128 Mdot
.922 .22142 Mdot
.922 .22153 Mdot
.922 .22155 Mdot
.922 .22246 Mdot
.922 .22287 Mdot
.922 .22295 Mdot
.922 .22309 Mdot
.922 .22317 Mdot
.922 .22352 Mdot
.922 .22653 Mdot
.922 .22666 Mdot
.922 .22668 Mdot
.922 .2267 Mdot
.922 .22682 Mdot
.922 .22683 Mdot
.922 .22735 Mdot
.922 .22742 Mdot
.922 .22772 Mdot
.922 .22822 Mdot
.922 .22844 Mdot
.922 .22913 Mdot
.922 .22994 Mdot
.922 .23015 Mdot
.922 .23081 Mdot
.922 .23106 Mdot
.922 .2314 Mdot
.922 .23202 Mdot
.922 .23243 Mdot
.922 .23246 Mdot
.922 .23262 Mdot
.922 .23273 Mdot
.922 .23338 Mdot
.922 .23375 Mdot
.922 .23405 Mdot
.922 .23417 Mdot
.922 .23464 Mdot
.922 .23495 Mdot
.922 .23516 Mdot
.922 .23584 Mdot
.922 .23618 Mdot
.922 .2371 Mdot
.922 .23733 Mdot
.922 .23778 Mdot
.922 .23797 Mdot
.922 .23824 Mdot
.922 .23888 Mdot
.922 .23939 Mdot
.922 .2394 Mdot
.922 .24046 Mdot
.922 .24099 Mdot
.922 .2417 Mdot
.922 .2423 Mdot
.922 .2429 Mdot
.922 .24308 Mdot
.922 .24433 Mdot
.922 .24458 Mdot
.922 .24488 Mdot
.922 .24558 Mdot
.922 .24592 Mdot
.922 .24624 Mdot
.922 .24723 Mdot
.922 .24727 Mdot
.922 .24867 Mdot
.922 .24872 Mdot
.922 .2493 Mdot
.922 .25046 Mdot
.922 .25048 Mdot
.922 .25107 Mdot
.922 .2512 Mdot
.922 .25172 Mdot
.922 .25212 Mdot
.922 .25301 Mdot
.922 .25349 Mdot
.922 .25366 Mdot
.922 .25455 Mdot
.922 .25607 Mdot
.922 .25625 Mdot
.922 .25722 Mdot
.922 .25791 Mdot
.922 .25831 Mdot
.922 .25917 Mdot
.922 .25976 Mdot
.922 .26068 Mdot
.922 .262 Mdot
.922 .26203 Mdot
.922 .26239 Mdot
.922 .26325 Mdot
.922 .26432 Mdot
.922 .2662 Mdot
.922 .26624 Mdot
.922 .26658 Mdot
.922 .26703 Mdot
.922 .26714 Mdot
.922 .26835 Mdot
.922 .26972 Mdot
.922 .27019 Mdot
.922 .27121 Mdot
.922 .27194 Mdot
.922 .27227 Mdot
.922 .27392 Mdot
.922 .27457 Mdot
.922 .27701 Mdot
.922 .27848 Mdot
.922 .27913 Mdot
.922 .27979 Mdot
.922 .28132 Mdot
.922 .28138 Mdot
.922 .28223 Mdot
.922 .28248 Mdot
.922 .28346 Mdot
.922 .28407 Mdot
.922 .28409 Mdot
.922 .28446 Mdot
.922 .28454 Mdot
.922 .28461 Mdot
.922 .28498 Mdot
.922 .28738 Mdot
.922 .28922 Mdot
.922 .28994 Mdot
.922 .29039 Mdot
.922 .29092 Mdot
.922 .29352 Mdot
.922 .29368 Mdot
.922 .29443 Mdot
.922 .29468 Mdot
.922 .2952 Mdot
.922 .2955 Mdot
.922 .29556 Mdot
.922 .2958 Mdot
.922 .29625 Mdot
.922 .29649 Mdot
.922 .29774 Mdot
.922 .29782 Mdot
.922 .298 Mdot
.922 .29812 Mdot
.922 .29815 Mdot
.922 .29835 Mdot
.922 .29835 Mdot
.922 .30073 Mdot
.922 .30079 Mdot
.922 .30115 Mdot
.922 .30153 Mdot
.922 .30158 Mdot
.922 .30263 Mdot
.922 .30271 Mdot
.922 .30329 Mdot
.922 .304 Mdot
.922 .30477 Mdot
.922 .3053 Mdot
.922 .30547 Mdot
.922 .30547 Mdot
.922 .30574 Mdot
.922 .3062 Mdot
.922 .30715 Mdot
.922 .30739 Mdot
.922 .30978 Mdot
.922 .30999 Mdot
.922 .3106 Mdot
.922 .31116 Mdot
.922 .31155 Mdot
.922 .31287 Mdot
.922 .31384 Mdot
.922 .31415 Mdot
.922 .31428 Mdot
.922 .31455 Mdot
.922 .31506 Mdot
.922 .31555 Mdot
.922 .31618 Mdot
.922 .31665 Mdot
.922 .31702 Mdot
.922 .3172 Mdot
.922 .31779 Mdot
.922 .318 Mdot
.922 .31965 Mdot
.922 .31966 Mdot
.922 .32094 Mdot
.922 .32125 Mdot
.922 .32137 Mdot
.922 .3217 Mdot
.922 .32172 Mdot
.922 .3224 Mdot
.922 .32276 Mdot
.922 .32345 Mdot
.922 .32406 Mdot
.922 .32473 Mdot
.922 .32511 Mdot
.922 .32518 Mdot
.922 .32543 Mdot
.922 .32551 Mdot
.922 .32609 Mdot
.922 .32622 Mdot
.922 .32648 Mdot
.922 .32684 Mdot
.922 .32804 Mdot
.922 .32961 Mdot
.922 .33248 Mdot
.922 .33335 Mdot
.922 .33462 Mdot
.922 .33464 Mdot
.922 .33508 Mdot
.922 .33822 Mdot
.922 .34144 Mdot
.922 .34153 Mdot
.922 .34207 Mdot
.922 .34887 Mdot
.922 .35149 Mdot
.922 .35295 Mdot
.922 .35436 Mdot
.922 .35468 Mdot
.922 .35513 Mdot
.922 .35604 Mdot
.922 .35618 Mdot
.922 .35919 Mdot
.922 .35977 Mdot
.922 .36108 Mdot
.922 .36156 Mdot
.922 .36549 Mdot
.922 .36551 Mdot
.922 .36558 Mdot
.922 .36559 Mdot
.922 .36563 Mdot
.922 .36568 Mdot
.922 .36577 Mdot
.922 .36585 Mdot
.922 .36598 Mdot
.922 .36607 Mdot
.922 .36607 Mdot
.922 .36611 Mdot
.922 .36613 Mdot
.922 .36617 Mdot
.922 .36633 Mdot
.922 .36657 Mdot
.922 .36665 Mdot
.922 .36667 Mdot
.922 .36672 Mdot
.922 .36678 Mdot
.922 .36692 Mdot
.922 .36704 Mdot
.922 .3672 Mdot
.922 .36737 Mdot
.922 .36742 Mdot
.922 .3675 Mdot
.922 .36791 Mdot
.922 .36812 Mdot
.922 .36815 Mdot
.922 .36824 Mdot
.922 .36843 Mdot
.922 .36852 Mdot
.922 .36865 Mdot
.922 .36871 Mdot
.922 .36875 Mdot
.922 .36913 Mdot
.922 .3693 Mdot
.922 .36942 Mdot
.922 .36957 Mdot
.922 .37084 Mdot
.922 .37085 Mdot
.922 .3709 Mdot
.922 .3709 Mdot
.922 .37111 Mdot
.922 .37114 Mdot
.922 .37126 Mdot
.922 .37145 Mdot
.922 .37154 Mdot
.922 .37222 Mdot
.922 .37257 Mdot
.922 .3727 Mdot
.922 .37295 Mdot
.922 .3731 Mdot
.922 .37312 Mdot
.922 .37322 Mdot
.922 .37362 Mdot
.922 .37378 Mdot
.922 .37396 Mdot
.922 .37408 Mdot
.922 .37416 Mdot
.922 .37442 Mdot
.922 .37455 Mdot
.922 .3749 Mdot
.922 .37523 Mdot
.922 .37533 Mdot
.922 .37557 Mdot
.922 .37577 Mdot
.922 .37616 Mdot
.922 .37662 Mdot
.922 .37685 Mdot
.922 .37713 Mdot
.922 .37769 Mdot
.922 .3778 Mdot
.922 .37806 Mdot
.922 .37818 Mdot
.922 .3783 Mdot
.922 .3792 Mdot
.922 .3794 Mdot
.922 .37983 Mdot
.922 .38004 Mdot
.922 .38042 Mdot
.922 .3809 Mdot
.922 .38128 Mdot
.922 .38181 Mdot
.922 .38246 Mdot
.922 .3826 Mdot
.922 .38387 Mdot
.922 .38531 Mdot
.922 .3865 Mdot
.922 .38735 Mdot
.922 .38941 Mdot
.922 .39035 Mdot
.922 .39103 Mdot
.922 .39229 Mdot
.922 .39288 Mdot
.922 .39311 Mdot
.922 .39325 Mdot
.922 .39343 Mdot
.922 .39425 Mdot
.922 .3943 Mdot
.922 .39462 Mdot
.922 .39478 Mdot
.922 .39487 Mdot
.922 .39558 Mdot
.922 .39566 Mdot
.922 .3957 Mdot
.922 .3957 Mdot
.922 .39577 Mdot
.922 .39577 Mdot
.922 .39676 Mdot
.922 .39713 Mdot
.922 .39753 Mdot
.922 .39793 Mdot
.922 .39798 Mdot
.922 .39821 Mdot
.922 .3985 Mdot
.922 .40055 Mdot
.922 .40068 Mdot
.922 .40181 Mdot
.922 .40397 Mdot
.922 .40436 Mdot
.922 .40447 Mdot
.922 .40483 Mdot
.922 .40615 Mdot
.922 .40679 Mdot
.922 .40692 Mdot
.922 .40785 Mdot
.922 .40882 Mdot
.922 .40898 Mdot
.922 .41097 Mdot
.922 .41174 Mdot
.922 .41266 Mdot
.922 .4128 Mdot
.922 .41306 Mdot
.922 .41398 Mdot
.922 .41452 Mdot
.922 .41598 Mdot
.922 .41852 Mdot
.922 .41943 Mdot
.922 .42036 Mdot
.922 .42271 Mdot
.922 .42299 Mdot
.922 .42422 Mdot
.922 .42429 Mdot
.922 .42494 Mdot
.922 .42506 Mdot
.922 .42519 Mdot
.922 .42775 Mdot
.922 .42834 Mdot
.922 .42839 Mdot
.922 .42985 Mdot
.922 .43145 Mdot
.922 .43286 Mdot
.922 .43288 Mdot
.922 .43453 Mdot
.922 .43543 Mdot
.922 .43714 Mdot
.922 .43854 Mdot
.922 .44016 Mdot
.922 .44094 Mdot
.922 .44128 Mdot
.922 .44271 Mdot
.922 .44277 Mdot
.922 .44311 Mdot
.922 .44315 Mdot
.922 .4438 Mdot
.922 .44394 Mdot
.922 .44565 Mdot
.922 .44743 Mdot
.922 .44846 Mdot
.922 .44998 Mdot
.922 .45098 Mdot
.922 .45106 Mdot
.922 .45202 Mdot
.922 .45208 Mdot
.922 .45306 Mdot
.922 .45348 Mdot
.922 .45455 Mdot
.922 .45632 Mdot
.922 .45643 Mdot
.922 .45665 Mdot
.922 .45684 Mdot
.922 .4575 Mdot
.922 .45754 Mdot
.922 .45759 Mdot
.922 .45794 Mdot
.922 .45798 Mdot
.922 .45806 Mdot
.922 .46011 Mdot
.922 .46056 Mdot
.922 .46194 Mdot
.922 .4644 Mdot
.922 .46498 Mdot
.922 .46591 Mdot
.922 .46697 Mdot
.922 .46737 Mdot
.922 .46796 Mdot
.922 .46981 Mdot
.922 .46988 Mdot
.922 .47114 Mdot
.922 .47139 Mdot
.922 .47344 Mdot
.922 .47365 Mdot
.922 .47424 Mdot
.922 .4745 Mdot
.922 .47584 Mdot
.922 .4759 Mdot
.922 .4763 Mdot
.922 .47651 Mdot
.922 .47665 Mdot
.922 .47727 Mdot
.922 .47791 Mdot
.922 .47906 Mdot
.922 .48203 Mdot
.922 .48226 Mdot
.922 .4823 Mdot
.922 .48369 Mdot
.922 .48504 Mdot
.922 .48522 Mdot
.922 .48523 Mdot
.922 .48577 Mdot
.922 .48614 Mdot
.922 .48736 Mdot
.922 .48803 Mdot
.922 .48853 Mdot
.922 .48869 Mdot
.922 .4888 Mdot
.922 .48885 Mdot
.922 .4891 Mdot
.922 .48913 Mdot
.922 .48923 Mdot
.922 .48926 Mdot
.922 .48942 Mdot
.922 .48971 Mdot
.922 .48996 Mdot
.922 .49025 Mdot
.922 .4904 Mdot
.922 .49069 Mdot
.922 .49069 Mdot
.922 .49083 Mdot
.922 .49088 Mdot
.922 .49101 Mdot
.922 .49155 Mdot
.922 .49155 Mdot
.922 .49224 Mdot
.922 .49233 Mdot
.922 .49257 Mdot
.922 .49265 Mdot
.922 .4928 Mdot
.922 .493 Mdot
.922 .49326 Mdot
.922 .49346 Mdot
.922 .49367 Mdot
.922 .49379 Mdot
.922 .49384 Mdot
.922 .49396 Mdot
.922 .49437 Mdot
.922 .49491 Mdot
.922 .49507 Mdot
.922 .4953 Mdot
.922 .49556 Mdot
.922 .49564 Mdot
.922 .49662 Mdot
.922 .49672 Mdot
.922 .49711 Mdot
.922 .4973 Mdot
.922 .49741 Mdot
.922 .49741 Mdot
.922 .49748 Mdot
.922 .4977 Mdot
.922 .49801 Mdot
.922 .4983 Mdot
.922 .49853 Mdot
.922 .49857 Mdot
.922 .499 Mdot
.922 .49902 Mdot
.922 .49917 Mdot
.922 .49932 Mdot
.922 .49934 Mdot
.922 .5003 Mdot
.922 .50031 Mdot
.922 .50039 Mdot
.922 .5004 Mdot
.922 .50045 Mdot
.922 .50052 Mdot
.922 .50055 Mdot
.922 .50106 Mdot
.922 .50115 Mdot
.922 .50134 Mdot
.922 .50143 Mdot
.922 .50146 Mdot
.922 .50158 Mdot
.922 .50179 Mdot
.922 .50189 Mdot
.922 .50219 Mdot
.922 .50225 Mdot
.922 .5033 Mdot
.922 .50351 Mdot
.922 .50369 Mdot
.922 .50398 Mdot
.922 .50472 Mdot
.922 .50567 Mdot
.922 .50582 Mdot
.922 .50585 Mdot
.922 .50588 Mdot
.922 .50603 Mdot
.922 .50604 Mdot
.922 .50628 Mdot
.922 .50667 Mdot
.922 .50676 Mdot
.922 .50711 Mdot
.922 .50713 Mdot
.922 .50773 Mdot
.922 .50799 Mdot
.922 .50825 Mdot
.922 .50883 Mdot
.922 .50979 Mdot
.922 .51005 Mdot
.922 .5107 Mdot
.922 .51083 Mdot
.922 .51111 Mdot
.922 .51151 Mdot
.922 .51169 Mdot
.922 .51223 Mdot
.922 .5127 Mdot
.922 .51274 Mdot
.922 .51292 Mdot
.922 .51305 Mdot
.922 .51307 Mdot
.922 .5138 Mdot
.922 .51422 Mdot
.922 .51455 Mdot
.922 .51469 Mdot
.922 .5147 Mdot
.922 .51521 Mdot
.922 .51557 Mdot
.922 .5158 Mdot
.922 .51613 Mdot
.922 .51628 Mdot
.922 .51655 Mdot
.922 .51692 Mdot
.922 .517 Mdot
.922 .51758 Mdot
.922 .51792 Mdot
.922 .51799 Mdot
.922 .51817 Mdot
.922 .51851 Mdot
.922 .51867 Mdot
.922 .51887 Mdot
.922 .51892 Mdot
.922 .51914 Mdot
.922 .51915 Mdot
.922 .51959 Mdot
.922 .51981 Mdot
.922 .51984 Mdot
.922 .52037 Mdot
.922 .52039 Mdot
.922 .52076 Mdot
.922 .52088 Mdot
.922 .52101 Mdot
.922 .52128 Mdot
.922 .5214 Mdot
.922 .52149 Mdot
.922 .52197 Mdot
.922 .52204 Mdot
.922 .52227 Mdot
.922 .52249 Mdot
.922 .52276 Mdot
.922 .52296 Mdot
.922 .52337 Mdot
.922 .52337 Mdot
.922 .52356 Mdot
.922 .52381 Mdot
.922 .52391 Mdot
.922 .52398 Mdot
.922 .52415 Mdot
.922 .52424 Mdot
.922 .52459 Mdot
.922 .52471 Mdot
.922 .52497 Mdot
.922 .52505 Mdot
.922 .52517 Mdot
.922 .52534 Mdot
.922 .52539 Mdot
.922 .5255 Mdot
.922 .52564 Mdot
.922 .52589 Mdot
.922 .52593 Mdot
.922 .52599 Mdot
.922 .526 Mdot
.922 .52616 Mdot
.922 .52639 Mdot
.922 .52652 Mdot
.922 .52661 Mdot
.922 .52686 Mdot
.922 .52694 Mdot
.922 .52724 Mdot
.922 .5275 Mdot
.922 .52759 Mdot
.922 .52777 Mdot
.922 .52788 Mdot
.922 .52791 Mdot
.922 .52811 Mdot
.922 .52811 Mdot
.922 .52815 Mdot
.922 .52816 Mdot
.922 .52817 Mdot
.922 .52822 Mdot
.922 .52935 Mdot
.922 .52948 Mdot
.922 .52951 Mdot
.922 .52956 Mdot
.922 .52959 Mdot
.922 .52974 Mdot
.922 .53008 Mdot
.922 .53009 Mdot
.922 .53013 Mdot
.922 .53018 Mdot
.922 .5303 Mdot
.922 .53038 Mdot
.922 .53055 Mdot
.922 .53063 Mdot
.922 .53066 Mdot
.922 .53085 Mdot
.922 .53113 Mdot
.922 .53115 Mdot
.922 .53122 Mdot
.922 .53128 Mdot
.922 .53133 Mdot
.922 .53148 Mdot
.922 .53162 Mdot
.922 .53167 Mdot
.922 .53173 Mdot
.922 .53178 Mdot
.922 .53185 Mdot
.922 .53191 Mdot
.922 .53195 Mdot
.922 .53197 Mdot
.922 .53204 Mdot
.922 .53224 Mdot
.922 .53224 Mdot
.922 .53239 Mdot
.922 .53242 Mdot
.922 .53244 Mdot
.922 .53247 Mdot
.922 .53248 Mdot
.922 .53255 Mdot
.922 .53259 Mdot
.922 .53267 Mdot
.922 .53274 Mdot
.922 .53281 Mdot
.922 .53285 Mdot
.922 .53289 Mdot
.922 .5329 Mdot
.922 .53296 Mdot
.922 .53298 Mdot
.922 .53335 Mdot
.922 .53376 Mdot
.922 .5339 Mdot
.922 .53465 Mdot
.922 .53589 Mdot
.922 .53604 Mdot
.922 .53624 Mdot
.922 .53662 Mdot
.922 .53681 Mdot
.922 .53736 Mdot
.922 .53765 Mdot
.922 .53767 Mdot
.922 .5381 Mdot
.922 .53832 Mdot
.922 .53878 Mdot
.922 .53946 Mdot
.922 .54034 Mdot
.922 .54042 Mdot
.922 .54043 Mdot
.922 .54044 Mdot
.922 .5407 Mdot
.922 .54108 Mdot
.922 .54131 Mdot
.922 .5414 Mdot
.922 .54162 Mdot
.922 .54206 Mdot
.922 .54259 Mdot
.922 .54331 Mdot
.922 .54334 Mdot
.922 .54355 Mdot
.922 .54356 Mdot
.922 .54385 Mdot
.922 .54392 Mdot
.922 .54469 Mdot
.922 .5452 Mdot
.922 .54553 Mdot
.922 .54581 Mdot
.922 .54641 Mdot
.922 .54702 Mdot
.922 .54793 Mdot
.922 .54827 Mdot
.922 .54901 Mdot
.922 .54928 Mdot
.922 .54933 Mdot
.922 .54936 Mdot
.922 .54953 Mdot
.922 .55023 Mdot
.922 .55054 Mdot
.922 .55084 Mdot
.922 .55085 Mdot
.922 .55151 Mdot
.922 .55153 Mdot
.922 .55189 Mdot
.922 .55199 Mdot
.922 .55219 Mdot
.922 .55237 Mdot
.922 .55238 Mdot
.922 .55239 Mdot
.922 .55262 Mdot
.922 .55263 Mdot
.922 .55277 Mdot
.922 .5528 Mdot
.922 .55283 Mdot
.922 .55287 Mdot
.922 .55297 Mdot
.922 .55318 Mdot
.922 .55381 Mdot
.922 .55416 Mdot
.922 .5544 Mdot
.922 .55461 Mdot
.922 .55464 Mdot
.922 .55475 Mdot
.922 .5549 Mdot
.922 .55498 Mdot
.922 .55508 Mdot
.922 .55515 Mdot
.922 .55518 Mdot
.922 .55533 Mdot
.922 .55535 Mdot
.922 .55541 Mdot
.922 .55543 Mdot
.922 .55552 Mdot
.922 .55557 Mdot
.922 .55561 Mdot
.922 .55569 Mdot
.922 .55578 Mdot
.922 .55582 Mdot
.922 .55584 Mdot
.922 .55595 Mdot
.922 .55597 Mdot
.922 .55602 Mdot
.922 .55603 Mdot
.922 .55605 Mdot
.922 .55608 Mdot
.922 .55617 Mdot
.922 .55619 Mdot
.922 .55619 Mdot
.922 .55621 Mdot
.922 .55625 Mdot
.922 .55628 Mdot
.922 .55633 Mdot
.922 .55644 Mdot
.922 .55646 Mdot
.922 .55649 Mdot
.922 .55651 Mdot
.922 .55651 Mdot
.922 .55655 Mdot
.922 .55655 Mdot
.922 .55656 Mdot
.922 .55656 Mdot
.922 .55681 Mdot
.922 .55684 Mdot
.922 .5569 Mdot
.922 .55691 Mdot
.922 .55691 Mdot
.922 .55694 Mdot
.922 .55695 Mdot
.922 .55698 Mdot
.922 .557 Mdot
.922 .557 Mdot
.922 .55703 Mdot
.922 .5571 Mdot
.922 .55711 Mdot
.922 .55712 Mdot
.922 .55715 Mdot
.922 .55718 Mdot
.922 .55719 Mdot
.922 .55722 Mdot
.922 .55723 Mdot
.922 .55723 Mdot
.922 .55725 Mdot
.922 .55729 Mdot
.922 .55732 Mdot
.922 .55732 Mdot
.922 .55733 Mdot
.922 .55733 Mdot
.922 .55735 Mdot
.922 .55737 Mdot
.922 .55738 Mdot
.922 .55739 Mdot
.922 .5574 Mdot
.922 .55741 Mdot
.922 .55741 Mdot
.922 .55742 Mdot
.922 .55743 Mdot
.924 .14335 Mdot
.924 .14335 Mdot
.924 .14336 Mdot
.924 .14336 Mdot
.924 .14336 Mdot
.924 .14336 Mdot
.924 .14336 Mdot
.924 .1434 Mdot
.924 .14346 Mdot
.924 .14352 Mdot
.924 .14352 Mdot
.924 .14358 Mdot
.924 .14372 Mdot
.924 .14372 Mdot
.924 .14373 Mdot
.924 .14385 Mdot
.924 .14392 Mdot
.924 .1441 Mdot
.924 .14418 Mdot
.924 .14423 Mdot
.924 .14428 Mdot
.924 .1447 Mdot
.924 .14564 Mdot
.924 .146 Mdot
.924 .14612 Mdot
.924 .14618 Mdot
.924 .1465 Mdot
.924 .14652 Mdot
.924 .14697 Mdot
.924 .14726 Mdot
.924 .1474 Mdot
.924 .14747 Mdot
.924 .14758 Mdot
.924 .148 Mdot
.924 .14817 Mdot
.924 .14826 Mdot
.924 .14834 Mdot
.924 .14877 Mdot
.924 .14883 Mdot
.924 .14904 Mdot
.924 .14919 Mdot
.924 .14951 Mdot
.924 .15052 Mdot
.924 .15062 Mdot
.924 .15083 Mdot
.924 .15086 Mdot
.924 .15111 Mdot
.924 .15162 Mdot
.924 .15171 Mdot
.924 .15173 Mdot
.924 .15193 Mdot
.924 .15262 Mdot
.924 .15281 Mdot
.924 .15297 Mdot
.924 .15312 Mdot
.924 .15338 Mdot
.924 .15343 Mdot
.924 .15372 Mdot
.924 .15429 Mdot
.924 .1548 Mdot
.924 .15503 Mdot
.924 .15578 Mdot
.924 .15682 Mdot
.924 .15693 Mdot
.924 .15708 Mdot
.924 .15755 Mdot
.924 .15821 Mdot
.924 .15908 Mdot
.924 .16012 Mdot
.924 .16112 Mdot
.924 .16128 Mdot
.924 .16142 Mdot
.924 .16191 Mdot
.924 .16266 Mdot
.924 .16301 Mdot
.924 .16436 Mdot
.924 .16473 Mdot
.924 .16508 Mdot
.924 .16633 Mdot
.924 .16682 Mdot
.924 .16707 Mdot
.924 .16788 Mdot
.924 .16822 Mdot
.924 .16879 Mdot
.924 .16919 Mdot
.924 .16923 Mdot
.924 .17142 Mdot
.924 .17201 Mdot
.924 .17247 Mdot
.924 .17261 Mdot
.924 .17332 Mdot
.924 .17482 Mdot
.924 .17622 Mdot
.924 .17634 Mdot
.924 .17761 Mdot
.924 .17793 Mdot
.924 .17946 Mdot
.924 .17996 Mdot
.924 .18022 Mdot
.924 .18175 Mdot
.924 .18205 Mdot
.924 .18254 Mdot
.924 .18254 Mdot
.924 .18334 Mdot
.924 .18479 Mdot
.924 .18702 Mdot
.924 .18872 Mdot
.924 .18898 Mdot
.924 .18967 Mdot
.924 .19164 Mdot
.924 .19213 Mdot
.924 .19234 Mdot
.924 .19257 Mdot
.924 .1937 Mdot
.924 .19446 Mdot
.924 .19499 Mdot
.924 .1963 Mdot
.924 .19778 Mdot
.924 .19779 Mdot
.924 .19782 Mdot
.924 .19784 Mdot
.924 .19784 Mdot
.924 .19786 Mdot
.924 .19787 Mdot
.924 .19798 Mdot
.924 .19802 Mdot
.924 .19812 Mdot
.924 .19832 Mdot
.924 .19859 Mdot
.924 .19862 Mdot
.924 .19888 Mdot
.924 .19954 Mdot
.924 .19958 Mdot
.924 .19961 Mdot
.924 .20021 Mdot
.924 .20055 Mdot
.924 .20138 Mdot
.924 .2018 Mdot
.924 .20201 Mdot
.924 .2023 Mdot
.924 .20355 Mdot
.924 .20433 Mdot
.924 .20512 Mdot
.924 .20581 Mdot
.924 .20589 Mdot
.924 .20751 Mdot
.924 .20816 Mdot
.924 .209 Mdot
.924 .20908 Mdot
.924 .20982 Mdot
.924 .20986 Mdot
.924 .21061 Mdot
.924 .21091 Mdot
.924 .21095 Mdot
.924 .21149 Mdot
.924 .21156 Mdot
.924 .21171 Mdot
.924 .21188 Mdot
.924 .21212 Mdot
.924 .21253 Mdot
.924 .21275 Mdot
.924 .21356 Mdot
.924 .21365 Mdot
.924 .21422 Mdot
.924 .21427 Mdot
.924 .21497 Mdot
.924 .21501 Mdot
.924 .21603 Mdot
.924 .21648 Mdot
.924 .21716 Mdot
.924 .21755 Mdot
.924 .2183 Mdot
.924 .21849 Mdot
.924 .21865 Mdot
.924 .21869 Mdot
.924 .21887 Mdot
.924 .2191 Mdot
.924 .21927 Mdot
.924 .22154 Mdot
.924 .22178 Mdot
.924 .22209 Mdot
.924 .22251 Mdot
.924 .22298 Mdot
.924 .22302 Mdot
.924 .22306 Mdot
.924 .22344 Mdot
.924 .22358 Mdot
.924 .224 Mdot
.924 .22442 Mdot
.924 .22445 Mdot
.924 .22485 Mdot
.924 .22505 Mdot
.924 .22506 Mdot
.924 .22582 Mdot
.924 .22613 Mdot
.924 .22733 Mdot
.924 .22781 Mdot
.924 .22814 Mdot
.924 .22878 Mdot
.924 .22896 Mdot
.924 .22986 Mdot
.924 .22996 Mdot
.924 .23044 Mdot
.924 .23073 Mdot
.924 .23106 Mdot
.924 .23136 Mdot
.924 .2315 Mdot
.924 .23235 Mdot
.924 .23363 Mdot
.924 .23549 Mdot
.924 .23574 Mdot
.924 .23584 Mdot
.924 .23633 Mdot
.924 .23663 Mdot
.924 .23711 Mdot
.924 .23722 Mdot
.924 .23755 Mdot
.924 .23776 Mdot
.924 .23847 Mdot
.924 .2392 Mdot
.924 .23956 Mdot
.924 .23987 Mdot
.924 .24053 Mdot
.924 .24173 Mdot
.924 .2422 Mdot
.924 .24242 Mdot
.924 .24271 Mdot
.924 .24285 Mdot
.924 .24355 Mdot
.924 .24403 Mdot
.924 .24436 Mdot
.924 .24441 Mdot
.924 .24533 Mdot
.924 .24541 Mdot
.924 .24578 Mdot
.924 .24687 Mdot
.924 .24694 Mdot
.924 .2471 Mdot
.924 .24711 Mdot
.924 .24728 Mdot
.924 .24745 Mdot
.924 .24766 Mdot
.924 .24767 Mdot
.924 .24817 Mdot
.924 .24925 Mdot
.924 .24935 Mdot
.924 .24944 Mdot
.924 .25005 Mdot
.924 .25033 Mdot
.924 .25096 Mdot
.924 .25125 Mdot
.924 .25128 Mdot
.924 .25189 Mdot
.924 .25234 Mdot
.924 .25266 Mdot
.924 .25281 Mdot
.924 .25314 Mdot
.924 .2535 Mdot
.924 .25487 Mdot
.924 .25491 Mdot
.924 .25522 Mdot
.924 .25593 Mdot
.924 .25843 Mdot
.924 .26056 Mdot
.924 .26112 Mdot
.924 .26134 Mdot
.924 .26159 Mdot
.924 .26258 Mdot
.924 .26307 Mdot
.924 .26514 Mdot
.924 .26593 Mdot
.924 .26767 Mdot
.924 .26782 Mdot
.924 .2681 Mdot
.924 .26899 Mdot
.924 .27001 Mdot
.924 .27086 Mdot
.924 .27232 Mdot
.924 .27262 Mdot
.924 .27445 Mdot
.924 .27514 Mdot
.924 .27537 Mdot
.924 .27594 Mdot
.924 .27612 Mdot
.924 .2779 Mdot
.924 .27892 Mdot
.924 .2792 Mdot
.924 .28041 Mdot
.924 .28212 Mdot
.924 .28347 Mdot
.924 .28414 Mdot
.924 .28512 Mdot
.924 .2875 Mdot
.924 .28756 Mdot
.924 .28818 Mdot
.924 .28918 Mdot
.924 .28944 Mdot
.924 .28954 Mdot
.924 .29045 Mdot
.924 .29089 Mdot
.924 .29221 Mdot
.924 .29266 Mdot
.924 .29389 Mdot
.924 .29402 Mdot
.924 .29415 Mdot
.924 .29443 Mdot
.924 .29564 Mdot
.924 .29614 Mdot
.924 .29696 Mdot
.924 .297 Mdot
.924 .29801 Mdot
.924 .29878 Mdot
.924 .30283 Mdot
.924 .30317 Mdot
.924 .30388 Mdot
.924 .30484 Mdot
.924 .30576 Mdot
.924 .30617 Mdot
.924 .30672 Mdot
.924 .30748 Mdot
.924 .30809 Mdot
.924 .30813 Mdot
.924 .30822 Mdot
.924 .30823 Mdot
.924 .30873 Mdot
.924 .30936 Mdot
.924 .30972 Mdot
.924 .31184 Mdot
.924 .31314 Mdot
.924 .31319 Mdot
.924 .31386 Mdot
.924 .31538 Mdot
.924 .31559 Mdot
.924 .3169 Mdot
.924 .32031 Mdot
.924 .32043 Mdot
.924 .32266 Mdot
.924 .32278 Mdot
.924 .32296 Mdot
.924 .3248 Mdot
.924 .32489 Mdot
.924 .32519 Mdot
.924 .3273 Mdot
.924 .32756 Mdot
.924 .32791 Mdot
.924 .32864 Mdot
.924 .32966 Mdot
.924 .33006 Mdot
.924 .33022 Mdot
.924 .33085 Mdot
.924 .33145 Mdot
.924 .33197 Mdot
.924 .3322 Mdot
.924 .33402 Mdot
.924 .33416 Mdot
.924 .33518 Mdot
.924 .33682 Mdot
.924 .33777 Mdot
.924 .33789 Mdot
.924 .33827 Mdot
.924 .34043 Mdot
.924 .34069 Mdot
.924 .3416 Mdot
.924 .34331 Mdot
.924 .34358 Mdot
.924 .34505 Mdot
.924 .34582 Mdot
.924 .34627 Mdot
.924 .34812 Mdot
.924 .34888 Mdot
.924 .35125 Mdot
.924 .35142 Mdot
.924 .35169 Mdot
.924 .35169 Mdot
.924 .3541 Mdot
.924 .35512 Mdot
.924 .35682 Mdot
.924 .35787 Mdot
.924 .35812 Mdot
.924 .35876 Mdot
.924 .35946 Mdot
.924 .35946 Mdot
.924 .35948 Mdot
.924 .35949 Mdot
.924 .35949 Mdot
.924 .3595 Mdot
.924 .3595 Mdot
.924 .35956 Mdot
.924 .35958 Mdot
.924 .35972 Mdot
.924 .35985 Mdot
.924 .35986 Mdot
.924 .35998 Mdot
.924 .36029 Mdot
.924 .36031 Mdot
.924 .36032 Mdot
.924 .3606 Mdot
.924 .36076 Mdot
.924 .36114 Mdot
.924 .36134 Mdot
.924 .36143 Mdot
.924 .36156 Mdot
.924 .36249 Mdot
.924 .3639 Mdot
.924 .36419 Mdot
.924 .36459 Mdot
.924 .36491 Mdot
.924 .36538 Mdot
.924 .36562 Mdot
.924 .36565 Mdot
.924 .36579 Mdot
.924 .36589 Mdot
.924 .36607 Mdot
.924 .3665 Mdot
.924 .36654 Mdot
.924 .36711 Mdot
.924 .36754 Mdot
.924 .36817 Mdot
.924 .36848 Mdot
.924 .36856 Mdot
.924 .36864 Mdot
.924 .36887 Mdot
.924 .36979 Mdot
.924 .37002 Mdot
.924 .37018 Mdot
.924 .37037 Mdot
.924 .37056 Mdot
.924 .3712 Mdot
.924 .3715 Mdot
.924 .37162 Mdot
.924 .37209 Mdot
.924 .37241 Mdot
.924 .37307 Mdot
.924 .37311 Mdot
.924 .3733 Mdot
.924 .3734 Mdot
.924 .37353 Mdot
.924 .3753 Mdot
.924 .37553 Mdot
.924 .37582 Mdot
.924 .37598 Mdot
.924 .37606 Mdot
.924 .37659 Mdot
.924 .37673 Mdot
.924 .37684 Mdot
.924 .37708 Mdot
.924 .37769 Mdot
.924 .37777 Mdot
.924 .37788 Mdot
.924 .37793 Mdot
.924 .37836 Mdot
.924 .37848 Mdot
.924 .37883 Mdot
.924 .37899 Mdot
.924 .37938 Mdot
.924 .37941 Mdot
.924 .37946 Mdot
.924 .37947 Mdot
.924 .37953 Mdot
.924 .37966 Mdot
.924 .37967 Mdot
.924 .37984 Mdot
.924 .38023 Mdot
.924 .38026 Mdot
.924 .38061 Mdot
.924 .38094 Mdot
.924 .38116 Mdot
.924 .38148 Mdot
.924 .3816 Mdot
.924 .3822 Mdot
.924 .38343 Mdot
.924 .38416 Mdot
.924 .38435 Mdot
.924 .38451 Mdot
.924 .38485 Mdot
.924 .38501 Mdot
.924 .38597 Mdot
.924 .3866 Mdot
.924 .3888 Mdot
.924 .38902 Mdot
.924 .38934 Mdot
.924 .39034 Mdot
.924 .39128 Mdot
.924 .39171 Mdot
.924 .39352 Mdot
.924 .39392 Mdot
.924 .39517 Mdot
.924 .3957 Mdot
.924 .39596 Mdot
.924 .39777 Mdot
.924 .39787 Mdot
.924 .39809 Mdot
.924 .39838 Mdot
.924 .39866 Mdot
.924 .39938 Mdot
.924 .39941 Mdot
.924 .39987 Mdot
.924 .40092 Mdot
.924 .40112 Mdot
.924 .40164 Mdot
.924 .40375 Mdot
.924 .40439 Mdot
.924 .40513 Mdot
.924 .4052 Mdot
.924 .40582 Mdot
.924 .40599 Mdot
.924 .40793 Mdot
.924 .40835 Mdot
.924 .40932 Mdot
.924 .40982 Mdot
.924 .41032 Mdot
.924 .41068 Mdot
.924 .41121 Mdot
.924 .41143 Mdot
.924 .41212 Mdot
.924 .41224 Mdot
.924 .41323 Mdot
.924 .41402 Mdot
.924 .4141 Mdot
.924 .41428 Mdot
.924 .41584 Mdot
.924 .41633 Mdot
.924 .41638 Mdot
.924 .41709 Mdot
.924 .41839 Mdot
.924 .41954 Mdot
.924 .42044 Mdot
.924 .4207 Mdot
.924 .42156 Mdot
.924 .42161 Mdot
.924 .42208 Mdot
.924 .42471 Mdot
.924 .42494 Mdot
.924 .42606 Mdot
.924 .42718 Mdot
.924 .4276 Mdot
.924 .42782 Mdot
.924 .42918 Mdot
.924 .42963 Mdot
.924 .43022 Mdot
.924 .43068 Mdot
.924 .43082 Mdot
.924 .43083 Mdot
.924 .43234 Mdot
.924 .43236 Mdot
.924 .43366 Mdot
.924 .43399 Mdot
.924 .43458 Mdot
.924 .43502 Mdot
.924 .43507 Mdot
.924 .43786 Mdot
.924 .43842 Mdot
.924 .4393 Mdot
.924 .43931 Mdot
.924 .44012 Mdot
.924 .4402 Mdot
.924 .44076 Mdot
.924 .441 Mdot
.924 .44206 Mdot
.924 .44265 Mdot
.924 .44336 Mdot
.924 .44498 Mdot
.924 .445 Mdot
.924 .44731 Mdot
.924 .44767 Mdot
.924 .4477 Mdot
.924 .44795 Mdot
.924 .44874 Mdot
.924 .44977 Mdot
.924 .45029 Mdot
.924 .45056 Mdot
.924 .45074 Mdot
.924 .45194 Mdot
.924 .4529 Mdot
.924 .45329 Mdot
.924 .45401 Mdot
.924 .4553 Mdot
.924 .45591 Mdot
.924 .45613 Mdot
.924 .4565 Mdot
.924 .45688 Mdot
.924 .45781 Mdot
.924 .45819 Mdot
.924 .45879 Mdot
.924 .46006 Mdot
.924 .46257 Mdot
.924 .4631 Mdot
.924 .46334 Mdot
.924 .46343 Mdot
.924 .46483 Mdot
.924 .46526 Mdot
.924 .46552 Mdot
.924 .46553 Mdot
.924 .46559 Mdot
.924 .46562 Mdot
.924 .46562 Mdot
.924 .46565 Mdot
.924 .46566 Mdot
.924 .46584 Mdot
.924 .46591 Mdot
.924 .46608 Mdot
.924 .4664 Mdot
.924 .46672 Mdot
.924 .46683 Mdot
.924 .46689 Mdot
.924 .4673 Mdot
.924 .46835 Mdot
.924 .46841 Mdot
.924 .46846 Mdot
.924 .46857 Mdot
.924 .46942 Mdot
.924 .46996 Mdot
.924 .47062 Mdot
.924 .47128 Mdot
.924 .47175 Mdot
.924 .47183 Mdot
.924 .47195 Mdot
.924 .47227 Mdot
.924 .4726 Mdot
.924 .47273 Mdot
.924 .47467 Mdot
.924 .47503 Mdot
.924 .47531 Mdot
.924 .47542 Mdot
.924 .47588 Mdot
.924 .47664 Mdot
.924 .47709 Mdot
.924 .47815 Mdot
.924 .47815 Mdot
.924 .47827 Mdot
.924 .47834 Mdot
.924 .47938 Mdot
.924 .47971 Mdot
.924 .48051 Mdot
.924 .48071 Mdot
.924 .48104 Mdot
.924 .48168 Mdot
.924 .4818 Mdot
.924 .48254 Mdot
.924 .48293 Mdot
.924 .48304 Mdot
.924 .48396 Mdot
.924 .48413 Mdot
.924 .48418 Mdot
.924 .48459 Mdot
.924 .48529 Mdot
.924 .48572 Mdot
.924 .48578 Mdot
.924 .48655 Mdot
.924 .48665 Mdot
.924 .48687 Mdot
.924 .48713 Mdot
.924 .48739 Mdot
.924 .48746 Mdot
.924 .48763 Mdot
.924 .48806 Mdot
.924 .48837 Mdot
.924 .48852 Mdot
.924 .48863 Mdot
.924 .48951 Mdot
.924 .48964 Mdot
.924 .48967 Mdot
.924 .49045 Mdot
.924 .49052 Mdot
.924 .49057 Mdot
.924 .4915 Mdot
.924 .49155 Mdot
.924 .49297 Mdot
.924 .49351 Mdot
.924 .4936 Mdot
.924 .49423 Mdot
.924 .4945 Mdot
.924 .49452 Mdot
.924 .49506 Mdot
.924 .49593 Mdot
.924 .49608 Mdot
.924 .49633 Mdot
.924 .49654 Mdot
.924 .49654 Mdot
.924 .49658 Mdot
.924 .4966 Mdot
.924 .49685 Mdot
.924 .49715 Mdot
.924 .49738 Mdot
.924 .49755 Mdot
.924 .49792 Mdot
.924 .49831 Mdot
.924 .4986 Mdot
.924 .49874 Mdot
.924 .50038 Mdot
.924 .50069 Mdot
.924 .5011 Mdot
.924 .50111 Mdot
.924 .50145 Mdot
.924 .50165 Mdot
.924 .50213 Mdot
.924 .50225 Mdot
.924 .5023 Mdot
.924 .50235 Mdot
.924 .50284 Mdot
.924 .50302 Mdot
.924 .50355 Mdot
.924 .50373 Mdot
.924 .50409 Mdot
.924 .50413 Mdot
.924 .50423 Mdot
.924 .50463 Mdot
.924 .50488 Mdot
.924 .5049 Mdot
.924 .50585 Mdot
.924 .50624 Mdot
.924 .50651 Mdot
.924 .50704 Mdot
.924 .50771 Mdot
.924 .50819 Mdot
.924 .5083 Mdot
.924 .50871 Mdot
.924 .50941 Mdot
.924 .50948 Mdot
.924 .5097 Mdot
.924 .50979 Mdot
.924 .51006 Mdot
.924 .51078 Mdot
.924 .51089 Mdot
.924 .51147 Mdot
.924 .5118 Mdot
.924 .51219 Mdot
.924 .51254 Mdot
.924 .51265 Mdot
.924 .51271 Mdot
.924 .51339 Mdot
.924 .51369 Mdot
.924 .51449 Mdot
.924 .51468 Mdot
.924 .51507 Mdot
.924 .51516 Mdot
.924 .51525 Mdot
.924 .51546 Mdot
.924 .51629 Mdot
.924 .51725 Mdot
.924 .51752 Mdot
.924 .51764 Mdot
.924 .51765 Mdot
.924 .51818 Mdot
.924 .51832 Mdot
.924 .51845 Mdot
.924 .5185 Mdot
.924 .51863 Mdot
.924 .5188 Mdot
.924 .51903 Mdot
.924 .51904 Mdot
.924 .51915 Mdot
.924 .5194 Mdot
.924 .5195 Mdot
.924 .51974 Mdot
.924 .51977 Mdot
.924 .51981 Mdot
.924 .52022 Mdot
.924 .52041 Mdot
.924 .52042 Mdot
.924 .5205 Mdot
.924 .52056 Mdot
.924 .52062 Mdot
.924 .52063 Mdot
.924 .52069 Mdot
.924 .52072 Mdot
.924 .52113 Mdot
.924 .52127 Mdot
.924 .5213 Mdot
.924 .52165 Mdot
.924 .52167 Mdot
.924 .52179 Mdot
.924 .52198 Mdot
.924 .52225 Mdot
.924 .5223 Mdot
.924 .52241 Mdot
.924 .52249 Mdot
.924 .52267 Mdot
.924 .52312 Mdot
.924 .52337 Mdot
.924 .52349 Mdot
.924 .52363 Mdot
.924 .5239 Mdot
.924 .52417 Mdot
.924 .52425 Mdot
.924 .52437 Mdot
.924 .52441 Mdot
.924 .5246 Mdot
.924 .52471 Mdot
.924 .52489 Mdot
.924 .52493 Mdot
.924 .52503 Mdot
.924 .52573 Mdot
.924 .52621 Mdot
.924 .52653 Mdot
.924 .52658 Mdot
.924 .52669 Mdot
.924 .52682 Mdot
.924 .52692 Mdot
.924 .52711 Mdot
.924 .52714 Mdot
.924 .52748 Mdot
.924 .52755 Mdot
.924 .52779 Mdot
.924 .52791 Mdot
.924 .52809 Mdot
.924 .52854 Mdot
.924 .52866 Mdot
.924 .52894 Mdot
.924 .52895 Mdot
.924 .52902 Mdot
.924 .52917 Mdot
.924 .52918 Mdot
.924 .52934 Mdot
.924 .52949 Mdot
.924 .52955 Mdot
.924 .52969 Mdot
.924 .5297 Mdot
.924 .52972 Mdot
.924 .52989 Mdot
.924 .53005 Mdot
.924 .53017 Mdot
.924 .53025 Mdot
.924 .5311 Mdot
.924 .53116 Mdot
.924 .53125 Mdot
.924 .53132 Mdot
.924 .53133 Mdot
.924 .53139 Mdot
.924 .53146 Mdot
.924 .53174 Mdot
.924 .53188 Mdot
.924 .53213 Mdot
.924 .5323 Mdot
.924 .53268 Mdot
.924 .53269 Mdot
.924 .53295 Mdot
.924 .53297 Mdot
.924 .53318 Mdot
.924 .53322 Mdot
.924 .53352 Mdot
.924 .5336 Mdot
.924 .53375 Mdot
.924 .53384 Mdot
.924 .5339 Mdot
.924 .53396 Mdot
.924 .53398 Mdot
.924 .53418 Mdot
.924 .5342 Mdot
.924 .53431 Mdot
.924 .53459 Mdot
.924 .5346 Mdot
.924 .53487 Mdot
.924 .5349 Mdot
.924 .53521 Mdot
.924 .53545 Mdot
.924 .53605 Mdot
.924 .53607 Mdot
.924 .53633 Mdot
.924 .53662 Mdot
.924 .53691 Mdot
.924 .53737 Mdot
.924 .53747 Mdot
.924 .53755 Mdot
.924 .5377 Mdot
.924 .53801 Mdot
.924 .53813 Mdot
.924 .53835 Mdot
.924 .53837 Mdot
.924 .53838 Mdot
.924 .53862 Mdot
.924 .53871 Mdot
.924 .53873 Mdot
.924 .53882 Mdot
.924 .5389 Mdot
.924 .53893 Mdot
.924 .53895 Mdot
.924 .53899 Mdot
.924 .53899 Mdot
.924 .539 Mdot
.924 .539 Mdot
.924 .53901 Mdot
.924 .53902 Mdot
.924 .53902 Mdot
.924 .53956 Mdot
.924 .54004 Mdot
.924 .54024 Mdot
.924 .54051 Mdot
.924 .54093 Mdot
.924 .54101 Mdot
.924 .54109 Mdot
.924 .54127 Mdot
.924 .54198 Mdot
.924 .54223 Mdot
.924 .54233 Mdot
.924 .54295 Mdot
.924 .54375 Mdot
.924 .54428 Mdot
.924 .54457 Mdot
.924 .54457 Mdot
.924 .54475 Mdot
.924 .54486 Mdot
.924 .54541 Mdot
.924 .5455 Mdot
.924 .54568 Mdot
.924 .54624 Mdot
.924 .54635 Mdot
.924 .54681 Mdot
.924 .54685 Mdot
.924 .54736 Mdot
.924 .5479 Mdot
.924 .54815 Mdot
.924 .5482 Mdot
.924 .54837 Mdot
.924 .54858 Mdot
.924 .54937 Mdot
.924 .54939 Mdot
.924 .54953 Mdot
.924 .54973 Mdot
.924 .54986 Mdot
.924 .55015 Mdot
.924 .55024 Mdot
.924 .55041 Mdot
.924 .55086 Mdot
.924 .55099 Mdot
.924 .55112 Mdot
.924 .5516 Mdot
.924 .55173 Mdot
.924 .55199 Mdot
.924 .55217 Mdot
.924 .55222 Mdot
.924 .55228 Mdot
.924 .55263 Mdot
.924 .55301 Mdot
.924 .55332 Mdot
.924 .55355 Mdot
.924 .55372 Mdot
.924 .55378 Mdot
.924 .55381 Mdot
.924 .55418 Mdot
.924 .55445 Mdot
.924 .55454 Mdot
.924 .55472 Mdot
.924 .55492 Mdot
.924 .55502 Mdot
.924 .55504 Mdot
.924 .55513 Mdot
.924 .55519 Mdot
.924 .55524 Mdot
.924 .55531 Mdot
.924 .55556 Mdot
.924 .55563 Mdot
.924 .55564 Mdot
.924 .55567 Mdot
.924 .55585 Mdot
.924 .55594 Mdot
.924 .55595 Mdot
.924 .55602 Mdot
.924 .55606 Mdot
.924 .55642 Mdot
.924 .55653 Mdot
.924 .55658 Mdot
.924 .55666 Mdot
.924 .55668 Mdot
.924 .55683 Mdot
.924 .55686 Mdot
.924 .55689 Mdot
.924 .55696 Mdot
.924 .5571 Mdot
.924 .55714 Mdot
.924 .55717 Mdot
.924 .55722 Mdot
.924 .55732 Mdot
.924 .55748 Mdot
.924 .55749 Mdot
.924 .5576 Mdot
.924 .55762 Mdot
.924 .55767 Mdot
.924 .55779 Mdot
.924 .55813 Mdot
.924 .55827 Mdot
.924 .55829 Mdot
.924 .55831 Mdot
.924 .55834 Mdot
.924 .5584 Mdot
.924 .55843 Mdot
.924 .55847 Mdot
.924 .55847 Mdot
.924 .55848 Mdot
.924 .55852 Mdot
.924 .55854 Mdot
.924 .55855 Mdot
.924 .55857 Mdot
.924 .55859 Mdot
.924 .5586 Mdot
.924 .5586 Mdot
.924 .5586 Mdot
.924 .5586 Mdot
.924 .5586 Mdot
.924 .55861 Mdot
.924 .55861 Mdot
.926 .14029 Mdot
.926 .1403 Mdot
.926 .14031 Mdot
.926 .14032 Mdot
.926 .14033 Mdot
.926 .14033 Mdot
.926 .14043 Mdot
.926 .14045 Mdot
.926 .1405 Mdot
.926 .14054 Mdot
.926 .1406 Mdot
.926 .14065 Mdot
.926 .14093 Mdot
.926 .14094 Mdot
.926 .141 Mdot
.926 .1411 Mdot
.926 .14112 Mdot
.926 .14114 Mdot
.926 .14121 Mdot
.926 .14154 Mdot
.926 .14195 Mdot
.926 .142 Mdot
.926 .14216 Mdot
.926 .14226 Mdot
.926 .14239 Mdot
.926 .1428 Mdot
.926 .14292 Mdot
.926 .14318 Mdot
.926 .14412 Mdot
.926 .14425 Mdot
.926 .1444 Mdot
.926 .14519 Mdot
.926 .14529 Mdot
.926 .14534 Mdot
.926 .14571 Mdot
.926 .14581 Mdot
.926 .14601 Mdot
.926 .14621 Mdot
.926 .14626 Mdot
.926 .14636 Mdot
.926 .14641 Mdot
.926 .14643 Mdot
.926 .1469 Mdot
.926 .14729 Mdot
.926 .14775 Mdot
.926 .14804 Mdot
.926 .14819 Mdot
.926 .14874 Mdot
.926 .15042 Mdot
.926 .15056 Mdot
.926 .1513 Mdot
.926 .15165 Mdot
.926 .15197 Mdot
.926 .15268 Mdot
.926 .15291 Mdot
.926 .15306 Mdot
.926 .15358 Mdot
.926 .15435 Mdot
.926 .15448 Mdot
.926 .15468 Mdot
.926 .15473 Mdot
.926 .15507 Mdot
.926 .15751 Mdot
.926 .15872 Mdot
.926 .15946 Mdot
.926 .15961 Mdot
.926 .16063 Mdot
.926 .16065 Mdot
.926 .16147 Mdot
.926 .162 Mdot
.926 .16211 Mdot
.926 .16271 Mdot
.926 .1628 Mdot
.926 .16286 Mdot
.926 .16411 Mdot
.926 .16433 Mdot
.926 .16467 Mdot
.926 .16649 Mdot
.926 .16656 Mdot
.926 .16726 Mdot
.926 .16806 Mdot
.926 .16869 Mdot
.926 .16956 Mdot
.926 .16998 Mdot
.926 .1702 Mdot
.926 .17039 Mdot
.926 .17108 Mdot
.926 .17183 Mdot
.926 .17215 Mdot
.926 .1735 Mdot
.926 .17406 Mdot
.926 .17443 Mdot
.926 .17482 Mdot
.926 .17517 Mdot
.926 .17531 Mdot
.926 .17658 Mdot
.926 .17663 Mdot
.926 .17861 Mdot
.926 .17948 Mdot
.926 .18137 Mdot
.926 .18224 Mdot
.926 .1827 Mdot
.926 .1827 Mdot
.926 .18273 Mdot
.926 .18279 Mdot
.926 .1828 Mdot
.926 .18284 Mdot
.926 .18287 Mdot
.926 .18327 Mdot
.926 .18339 Mdot
.926 .18361 Mdot
.926 .18375 Mdot
.926 .18404 Mdot
.926 .18425 Mdot
.926 .18527 Mdot
.926 .18549 Mdot
.926 .1855 Mdot
.926 .18575 Mdot
.926 .18578 Mdot
.926 .18621 Mdot
.926 .1863 Mdot
.926 .1864 Mdot
.926 .18671 Mdot
.926 .18774 Mdot
.926 .18789 Mdot
.926 .18806 Mdot
.926 .18821 Mdot
.926 .18842 Mdot
.926 .18949 Mdot
.926 .18954 Mdot
.926 .19006 Mdot
.926 .1901 Mdot
.926 .19023 Mdot
.926 .19029 Mdot
.926 .1906 Mdot
.926 .19104 Mdot
.926 .19148 Mdot
.926 .1921 Mdot
.926 .19271 Mdot
.926 .19403 Mdot
.926 .19412 Mdot
.926 .1944 Mdot
.926 .1945 Mdot
.926 .19463 Mdot
.926 .19509 Mdot
.926 .19577 Mdot
.926 .19585 Mdot
.926 .20038 Mdot
.926 .20047 Mdot
.926 .20053 Mdot
.926 .20113 Mdot
.926 .20156 Mdot
.926 .20172 Mdot
.926 .20188 Mdot
.926 .20305 Mdot
.926 .20324 Mdot
.926 .20491 Mdot
.926 .20511 Mdot
.926 .20587 Mdot
.926 .20616 Mdot
.926 .20639 Mdot
.926 .20662 Mdot
.926 .20693 Mdot
.926 .20696 Mdot
.926 .20708 Mdot
.926 .20736 Mdot
.926 .20751 Mdot
.926 .20856 Mdot
.926 .20867 Mdot
.926 .20885 Mdot
.926 .20911 Mdot
.926 .21016 Mdot
.926 .21074 Mdot
.926 .2111 Mdot
.926 .2112 Mdot
.926 .21147 Mdot
.926 .21201 Mdot
.926 .21226 Mdot
.926 .21236 Mdot
.926 .21287 Mdot
.926 .21339 Mdot
.926 .21383 Mdot
.926 .21491 Mdot
.926 .21508 Mdot
.926 .21621 Mdot
.926 .2167 Mdot
.926 .21701 Mdot
.926 .21745 Mdot
.926 .21856 Mdot
.926 .21904 Mdot
.926 .21953 Mdot
.926 .22114 Mdot
.926 .22198 Mdot
.926 .22283 Mdot
.926 .22512 Mdot
.926 .22565 Mdot
.926 .22571 Mdot
.926 .22572 Mdot
.926 .22859 Mdot
.926 .2297 Mdot
.926 .23013 Mdot
.926 .23035 Mdot
.926 .23265 Mdot
.926 .2348 Mdot
.926 .23483 Mdot
.926 .23561 Mdot
.926 .23561 Mdot
.926 .23887 Mdot
.926 .23961 Mdot
.926 .24003 Mdot
.926 .24069 Mdot
.926 .24189 Mdot
.926 .24218 Mdot
.926 .24299 Mdot
.926 .24385 Mdot
.926 .24393 Mdot
.926 .2441 Mdot
.926 .24564 Mdot
.926 .24843 Mdot
.926 .24984 Mdot
.926 .25075 Mdot
.926 .25244 Mdot
.926 .25251 Mdot
.926 .25308 Mdot
.926 .25325 Mdot
.926 .25326 Mdot
.926 .25405 Mdot
.926 .25554 Mdot
.926 .25562 Mdot
.926 .25886 Mdot
.926 .25972 Mdot
.926 .26092 Mdot
.926 .26098 Mdot
.926 .26126 Mdot
.926 .26128 Mdot
.926 .262 Mdot
.926 .26208 Mdot
.926 .26342 Mdot
.926 .2681 Mdot
.926 .26894 Mdot
.926 .26937 Mdot
.926 .26959 Mdot
.926 .27093 Mdot
.926 .27291 Mdot
.926 .27429 Mdot
.926 .27434 Mdot
.926 .27582 Mdot
.926 .27686 Mdot
.926 .27928 Mdot
.926 .27998 Mdot
.926 .28096 Mdot
.926 .28333 Mdot
.926 .28338 Mdot
.926 .28356 Mdot
.926 .28488 Mdot
.926 .28524 Mdot
.926 .28738 Mdot
.926 .29233 Mdot
.926 .2926 Mdot
.926 .29288 Mdot
.926 .29332 Mdot
.926 .29534 Mdot
.926 .29582 Mdot
.926 .29808 Mdot
.926 .29958 Mdot
.926 .30022 Mdot
.926 .30035 Mdot
.926 .30149 Mdot
.926 .3029 Mdot
.926 .30336 Mdot
.926 .30498 Mdot
.926 .30593 Mdot
.926 .30657 Mdot
.926 .30805 Mdot
.926 .30923 Mdot
.926 .30961 Mdot
.926 .31007 Mdot
.926 .31026 Mdot
.926 .31036 Mdot
.926 .31174 Mdot
.926 .31236 Mdot
.926 .31279 Mdot
.926 .31443 Mdot
.926 .31445 Mdot
.926 .31508 Mdot
.926 .31523 Mdot
.926 .31548 Mdot
.926 .31825 Mdot
.926 .31879 Mdot
.926 .31971 Mdot
.926 .32049 Mdot
.926 .32246 Mdot
.926 .32397 Mdot
.926 .32412 Mdot
.926 .32419 Mdot
.926 .32489 Mdot
.926 .32552 Mdot
.926 .32566 Mdot
.926 .32575 Mdot
.926 .32639 Mdot
.926 .32689 Mdot
.926 .32747 Mdot
.926 .32782 Mdot
.926 .32801 Mdot
.926 .32867 Mdot
.926 .33053 Mdot
.926 .33145 Mdot
.926 .33181 Mdot
.926 .33213 Mdot
.926 .33304 Mdot
.926 .33368 Mdot
.926 .33438 Mdot
.926 .33502 Mdot
.926 .33866 Mdot
.926 .33956 Mdot
.926 .33957 Mdot
.926 .34018 Mdot
.926 .34058 Mdot
.926 .34066 Mdot
.926 .34109 Mdot
.926 .34116 Mdot
.926 .34209 Mdot
.926 .34422 Mdot
.926 .34475 Mdot
.926 .34571 Mdot
.926 .34597 Mdot
.926 .34612 Mdot
.926 .34623 Mdot
.926 .34666 Mdot
.926 .34732 Mdot
.926 .34813 Mdot
.926 .34891 Mdot
.926 .3492 Mdot
.926 .34993 Mdot
.926 .35107 Mdot
.926 .35156 Mdot
.926 .35258 Mdot
.926 .35305 Mdot
.926 .35329 Mdot
.926 .3533 Mdot
.926 .35331 Mdot
.926 .35334 Mdot
.926 .35335 Mdot
.926 .35337 Mdot
.926 .35338 Mdot
.926 .3536 Mdot
.926 .35366 Mdot
.926 .35377 Mdot
.926 .35385 Mdot
.926 .354 Mdot
.926 .35411 Mdot
.926 .35475 Mdot
.926 .35476 Mdot
.926 .35489 Mdot
.926 .3549 Mdot
.926 .35512 Mdot
.926 .35517 Mdot
.926 .35522 Mdot
.926 .35538 Mdot
.926 .3559 Mdot
.926 .35614 Mdot
.926 .35624 Mdot
.926 .35705 Mdot
.926 .35716 Mdot
.926 .35732 Mdot
.926 .35753 Mdot
.926 .35775 Mdot
.926 .35805 Mdot
.926 .35897 Mdot
.926 .35901 Mdot
.926 .35915 Mdot
.926 .35926 Mdot
.926 .35947 Mdot
.926 .35979 Mdot
.926 .35983 Mdot
.926 .36191 Mdot
.926 .36195 Mdot
.926 .36198 Mdot
.926 .36225 Mdot
.926 .36258 Mdot
.926 .36311 Mdot
.926 .36319 Mdot
.926 .36392 Mdot
.926 .36434 Mdot
.926 .36447 Mdot
.926 .36456 Mdot
.926 .36466 Mdot
.926 .36486 Mdot
.926 .36505 Mdot
.926 .36549 Mdot
.926 .36573 Mdot
.926 .36618 Mdot
.926 .36642 Mdot
.926 .36657 Mdot
.926 .36661 Mdot
.926 .36672 Mdot
.926 .36695 Mdot
.926 .36705 Mdot
.926 .3671 Mdot
.926 .36752 Mdot
.926 .3677 Mdot
.926 .36815 Mdot
.926 .36868 Mdot
.926 .36888 Mdot
.926 .369 Mdot
.926 .36918 Mdot
.926 .36982 Mdot
.926 .37001 Mdot
.926 .37065 Mdot
.926 .37098 Mdot
.926 .37132 Mdot
.926 .37221 Mdot
.926 .37244 Mdot
.926 .37244 Mdot
.926 .37354 Mdot
.926 .37587 Mdot
.926 .37617 Mdot
.926 .37763 Mdot
.926 .37779 Mdot
.926 .37856 Mdot
.926 .37885 Mdot
.926 .37915 Mdot
.926 .37924 Mdot
.926 .37979 Mdot
.926 .38077 Mdot
.926 .38127 Mdot
.926 .38158 Mdot
.926 .38216 Mdot
.926 .38219 Mdot
.926 .38238 Mdot
.926 .38272 Mdot
.926 .38436 Mdot
.926 .38465 Mdot
.926 .38505 Mdot
.926 .38507 Mdot
.926 .38516 Mdot
.926 .38517 Mdot
.926 .38544 Mdot
.926 .38589 Mdot
.926 .38743 Mdot
.926 .38785 Mdot
.926 .389 Mdot
.926 .38945 Mdot
.926 .38994 Mdot
.926 .39028 Mdot
.926 .39105 Mdot
.926 .39127 Mdot
.926 .39158 Mdot
.926 .39282 Mdot
.926 .39361 Mdot
.926 .39515 Mdot
.926 .39532 Mdot
.926 .39545 Mdot
.926 .39622 Mdot
.926 .39737 Mdot
.926 .39757 Mdot
.926 .39761 Mdot
.926 .39796 Mdot
.926 .39839 Mdot
.926 .3993 Mdot
.926 .39994 Mdot
.926 .40029 Mdot
.926 .40041 Mdot
.926 .40055 Mdot
.926 .40063 Mdot
.926 .40123 Mdot
.926 .40185 Mdot
.926 .40204 Mdot
.926 .40209 Mdot
.926 .40216 Mdot
.926 .40341 Mdot
.926 .40364 Mdot
.926 .40471 Mdot
.926 .40473 Mdot
.926 .40494 Mdot
.926 .40512 Mdot
.926 .40517 Mdot
.926 .40538 Mdot
.926 .40552 Mdot
.926 .40585 Mdot
.926 .40705 Mdot
.926 .40733 Mdot
.926 .4075 Mdot
.926 .40771 Mdot
.926 .40921 Mdot
.926 .40952 Mdot
.926 .40965 Mdot
.926 .40967 Mdot
.926 .40994 Mdot
.926 .41105 Mdot
.926 .41125 Mdot
.926 .41198 Mdot
.926 .41252 Mdot
.926 .41265 Mdot
.926 .41308 Mdot
.926 .41361 Mdot
.926 .4139 Mdot
.926 .41399 Mdot
.926 .4143 Mdot
.926 .41478 Mdot
.926 .41491 Mdot
.926 .41561 Mdot
.926 .41563 Mdot
.926 .41595 Mdot
.926 .41597 Mdot
.926 .41645 Mdot
.926 .41689 Mdot
.926 .4172 Mdot
.926 .41725 Mdot
.926 .41786 Mdot
.926 .41828 Mdot
.926 .4186 Mdot
.926 .4186 Mdot
.926 .41891 Mdot
.926 .42007 Mdot
.926 .42042 Mdot
.926 .4205 Mdot
.926 .42068 Mdot
.926 .42136 Mdot
.926 .42136 Mdot
.926 .42142 Mdot
.926 .42218 Mdot
.926 .42285 Mdot
.926 .4233 Mdot
.926 .42438 Mdot
.926 .42509 Mdot
.926 .42567 Mdot
.926 .42584 Mdot
.926 .42641 Mdot
.926 .42651 Mdot
.926 .42677 Mdot
.926 .4274 Mdot
.926 .42788 Mdot
.926 .42844 Mdot
.926 .42862 Mdot
.926 .42905 Mdot
.926 .42918 Mdot
.926 .42926 Mdot
.926 .43043 Mdot
.926 .43051 Mdot
.926 .43065 Mdot
.926 .43069 Mdot
.926 .43089 Mdot
.926 .43099 Mdot
.926 .431 Mdot
.926 .43154 Mdot
.926 .43255 Mdot
.926 .43298 Mdot
.926 .43461 Mdot
.926 .43552 Mdot
.926 .43808 Mdot
.926 .43968 Mdot
.926 .44022 Mdot
.926 .44051 Mdot
.926 .44051 Mdot
.926 .44057 Mdot
.926 .44067 Mdot
.926 .44069 Mdot
.926 .44077 Mdot
.926 .44081 Mdot
.926 .44154 Mdot
.926 .44177 Mdot
.926 .44187 Mdot
.926 .44216 Mdot
.926 .44242 Mdot
.926 .44294 Mdot
.926 .44332 Mdot
.926 .44479 Mdot
.926 .44514 Mdot
.926 .44553 Mdot
.926 .44556 Mdot
.926 .44556 Mdot
.926 .446 Mdot
.926 .44605 Mdot
.926 .44682 Mdot
.926 .44698 Mdot
.926 .44714 Mdot
.926 .44736 Mdot
.926 .44769 Mdot
.926 .44832 Mdot
.926 .44833 Mdot
.926 .44851 Mdot
.926 .44886 Mdot
.926 .44892 Mdot
.926 .44917 Mdot
.926 .44932 Mdot
.926 .44952 Mdot
.926 .44978 Mdot
.926 .45007 Mdot
.926 .45034 Mdot
.926 .4507 Mdot
.926 .45136 Mdot
.926 .4515 Mdot
.926 .45172 Mdot
.926 .45247 Mdot
.926 .45257 Mdot
.926 .45266 Mdot
.926 .45279 Mdot
.926 .45355 Mdot
.926 .45362 Mdot
.926 .45375 Mdot
.926 .45384 Mdot
.926 .45394 Mdot
.926 .45447 Mdot
.926 .45459 Mdot
.926 .45524 Mdot
.926 .45565 Mdot
.926 .45599 Mdot
.926 .45611 Mdot
.926 .45628 Mdot
.926 .45704 Mdot
.926 .45724 Mdot
.926 .45752 Mdot
.926 .45808 Mdot
.926 .45851 Mdot
.926 .45971 Mdot
.926 .4603 Mdot
.926 .46045 Mdot
.926 .46092 Mdot
.926 .46108 Mdot
.926 .46131 Mdot
.926 .46152 Mdot
.926 .46207 Mdot
.926 .46226 Mdot
.926 .4632 Mdot
.926 .46333 Mdot
.926 .46338 Mdot
.926 .46463 Mdot
.926 .46472 Mdot
.926 .46473 Mdot
.926 .46583 Mdot
.926 .46613 Mdot
.926 .46627 Mdot
.926 .46683 Mdot
.926 .46871 Mdot
.926 .46921 Mdot
.926 .46921 Mdot
.926 .46972 Mdot
.926 .4704 Mdot
.926 .47069 Mdot
.926 .47083 Mdot
.926 .47092 Mdot
.926 .47136 Mdot
.926 .47144 Mdot
.926 .47187 Mdot
.926 .47193 Mdot
.926 .47255 Mdot
.926 .47263 Mdot
.926 .47281 Mdot
.926 .47306 Mdot
.926 .47338 Mdot
.926 .47342 Mdot
.926 .47392 Mdot
.926 .47395 Mdot
.926 .4749 Mdot
.926 .47504 Mdot
.926 .47518 Mdot
.926 .47524 Mdot
.926 .47599 Mdot
.926 .47647 Mdot
.926 .47662 Mdot
.926 .47706 Mdot
.926 .47776 Mdot
.926 .47787 Mdot
.926 .47808 Mdot
.926 .47853 Mdot
.926 .47874 Mdot
.926 .47924 Mdot
.926 .47955 Mdot
.926 .47968 Mdot
.926 .48002 Mdot
.926 .48037 Mdot
.926 .48066 Mdot
.926 .48084 Mdot
.926 .48089 Mdot
.926 .48095 Mdot
.926 .48107 Mdot
.926 .48148 Mdot
.926 .48171 Mdot
.926 .48263 Mdot
.926 .48303 Mdot
.926 .48306 Mdot
.926 .48324 Mdot
.926 .48328 Mdot
.926 .48345 Mdot
.926 .48371 Mdot
.926 .48372 Mdot
.926 .4841 Mdot
.926 .48565 Mdot
.926 .48592 Mdot
.926 .48622 Mdot
.926 .48647 Mdot
.926 .48649 Mdot
.926 .48688 Mdot
.926 .48701 Mdot
.926 .48716 Mdot
.926 .48755 Mdot
.926 .48834 Mdot
.926 .48861 Mdot
.926 .48869 Mdot
.926 .48884 Mdot
.926 .48908 Mdot
.926 .48929 Mdot
.926 .48956 Mdot
.926 .4896 Mdot
.926 .48965 Mdot
.926 .48992 Mdot
.926 .49021 Mdot
.926 .49024 Mdot
.926 .4903 Mdot
.926 .49093 Mdot
.926 .49175 Mdot
.926 .49208 Mdot
.926 .49246 Mdot
.926 .49268 Mdot
.926 .49382 Mdot
.926 .49393 Mdot
.926 .49399 Mdot
.926 .49425 Mdot
.926 .49426 Mdot
.926 .49493 Mdot
.926 .49511 Mdot
.926 .49536 Mdot
.926 .49593 Mdot
.926 .49597 Mdot
.926 .49605 Mdot
.926 .49623 Mdot
.926 .49639 Mdot
.926 .49687 Mdot
.926 .49747 Mdot
.926 .49774 Mdot
.926 .49812 Mdot
.926 .49878 Mdot
.926 .49896 Mdot
.926 .49954 Mdot
.926 .5 Mdot
.926 .50005 Mdot
.926 .50031 Mdot
.926 .50091 Mdot
.926 .50182 Mdot
.926 .50201 Mdot
.926 .50282 Mdot
.926 .503 Mdot
.926 .50311 Mdot
.926 .50322 Mdot
.926 .50519 Mdot
.926 .50604 Mdot
.926 .50618 Mdot
.926 .5067 Mdot
.926 .50677 Mdot
.926 .50679 Mdot
.926 .50773 Mdot
.926 .50811 Mdot
.926 .50839 Mdot
.926 .50934 Mdot
.926 .50975 Mdot
.926 .51032 Mdot
.926 .51034 Mdot
.926 .51088 Mdot
.926 .51165 Mdot
.926 .51217 Mdot
.926 .51226 Mdot
.926 .51243 Mdot
.926 .51275 Mdot
.926 .51457 Mdot
.926 .51508 Mdot
.926 .51511 Mdot
.926 .51539 Mdot
.926 .5154 Mdot
.926 .51551 Mdot
.926 .51553 Mdot
.926 .51599 Mdot
.926 .51632 Mdot
.926 .51757 Mdot
.926 .5176 Mdot
.926 .51817 Mdot
.926 .51847 Mdot
.926 .51848 Mdot
.926 .51854 Mdot
.926 .51876 Mdot
.926 .51878 Mdot
.926 .51943 Mdot
.926 .51977 Mdot
.926 .52031 Mdot
.926 .52137 Mdot
.926 .52196 Mdot
.926 .52202 Mdot
.926 .52205 Mdot
.926 .52238 Mdot
.926 .52269 Mdot
.926 .5228 Mdot
.926 .52325 Mdot
.926 .52349 Mdot
.926 .52366 Mdot
.926 .52393 Mdot
.926 .52516 Mdot
.926 .52516 Mdot
.926 .52546 Mdot
.926 .52547 Mdot
.926 .52627 Mdot
.926 .52714 Mdot
.926 .52722 Mdot
.926 .52738 Mdot
.926 .52779 Mdot
.926 .52886 Mdot
.926 .52887 Mdot
.926 .52889 Mdot
.926 .52909 Mdot
.926 .52994 Mdot
.926 .53026 Mdot
.926 .53057 Mdot
.926 .53116 Mdot
.926 .53135 Mdot
.926 .53153 Mdot
.926 .53194 Mdot
.926 .5321 Mdot
.926 .53222 Mdot
.926 .5324 Mdot
.926 .53282 Mdot
.926 .53288 Mdot
.926 .53327 Mdot
.926 .53344 Mdot
.926 .53363 Mdot
.926 .53382 Mdot
.926 .53386 Mdot
.926 .53395 Mdot
.926 .53415 Mdot
.926 .53425 Mdot
.926 .53428 Mdot
.926 .53442 Mdot
.926 .53463 Mdot
.926 .53502 Mdot
.926 .53511 Mdot
.926 .53518 Mdot
.926 .53522 Mdot
.926 .5356 Mdot
.926 .53566 Mdot
.926 .53576 Mdot
.926 .5358 Mdot
.926 .53582 Mdot
.926 .53593 Mdot
.926 .53602 Mdot
.926 .5361 Mdot
.926 .53621 Mdot
.926 .53649 Mdot
.926 .53656 Mdot
.926 .53717 Mdot
.926 .53724 Mdot
.926 .53767 Mdot
.926 .53773 Mdot
.926 .53779 Mdot
.926 .53794 Mdot
.926 .53816 Mdot
.926 .53818 Mdot
.926 .53822 Mdot
.926 .53987 Mdot
.926 .5399 Mdot
.926 .54015 Mdot
.926 .54031 Mdot
.926 .54036 Mdot
.926 .5404 Mdot
.926 .5405 Mdot
.926 .54053 Mdot
.926 .54101 Mdot
.926 .54124 Mdot
.926 .54146 Mdot
.926 .54162 Mdot
.926 .54178 Mdot
.926 .5419 Mdot
.926 .54192 Mdot
.926 .54196 Mdot
.926 .54198 Mdot
.926 .54216 Mdot
.926 .54218 Mdot
.926 .54257 Mdot
.926 .54265 Mdot
.926 .5427 Mdot
.926 .54276 Mdot
.926 .54282 Mdot
.926 .54319 Mdot
.926 .54331 Mdot
.926 .54334 Mdot
.926 .54337 Mdot
.926 .54353 Mdot
.926 .54354 Mdot
.926 .54363 Mdot
.926 .54363 Mdot
.926 .54371 Mdot
.926 .54408 Mdot
.926 .54416 Mdot
.926 .54426 Mdot
.926 .54431 Mdot
.926 .54439 Mdot
.926 .54444 Mdot
.926 .54458 Mdot
.926 .54459 Mdot
.926 .54461 Mdot
.926 .54461 Mdot
.926 .54463 Mdot
.926 .54464 Mdot
.926 .54464 Mdot
.926 .54481 Mdot
.926 .54512 Mdot
.926 .5458 Mdot
.926 .54612 Mdot
.926 .54683 Mdot
.926 .54685 Mdot
.926 .54731 Mdot
.926 .54736 Mdot
.926 .54748 Mdot
.926 .54762 Mdot
.926 .54776 Mdot
.926 .54796 Mdot
.926 .54844 Mdot
.926 .54856 Mdot
.926 .54883 Mdot
.926 .54907 Mdot
.926 .54914 Mdot
.926 .54922 Mdot
.926 .54937 Mdot
.926 .54969 Mdot
.926 .54991 Mdot
.926 .5502 Mdot
.926 .55045 Mdot
.926 .55047 Mdot
.926 .55124 Mdot
.926 .55132 Mdot
.926 .55177 Mdot
.926 .55179 Mdot
.926 .55182 Mdot
.926 .55204 Mdot
.926 .55208 Mdot
.926 .55227 Mdot
.926 .55256 Mdot
.926 .55257 Mdot
.926 .55293 Mdot
.926 .55298 Mdot
.926 .55325 Mdot
.926 .55368 Mdot
.926 .55455 Mdot
.926 .55467 Mdot
.926 .55468 Mdot
.926 .55475 Mdot
.926 .5548 Mdot
.926 .55507 Mdot
.926 .55526 Mdot
.926 .55531 Mdot
.926 .5554 Mdot
.926 .55565 Mdot
.926 .55576 Mdot
.926 .55589 Mdot
.926 .55615 Mdot
.926 .5562 Mdot
.926 .55679 Mdot
.926 .55699 Mdot
.926 .55704 Mdot
.926 .55715 Mdot
.926 .55731 Mdot
.926 .55745 Mdot
.926 .55761 Mdot
.926 .55762 Mdot
.926 .55764 Mdot
.926 .55767 Mdot
.926 .55769 Mdot
.926 .55776 Mdot
.926 .55783 Mdot
.926 .55787 Mdot
.926 .558 Mdot
.926 .55802 Mdot
.926 .55805 Mdot
.926 .55833 Mdot
.926 .55838 Mdot
.926 .55843 Mdot
.926 .55876 Mdot
.926 .55885 Mdot
.926 .5589 Mdot
.926 .55904 Mdot
.926 .55909 Mdot
.926 .55912 Mdot
.926 .55918 Mdot
.926 .5592 Mdot
.926 .55934 Mdot
.926 .55946 Mdot
.926 .55949 Mdot
.926 .55949 Mdot
.926 .5595 Mdot
.926 .55953 Mdot
.926 .55956 Mdot
.926 .55956 Mdot
.926 .55966 Mdot
.926 .55967 Mdot
.926 .5597 Mdot
.926 .55971 Mdot
.926 .55973 Mdot
.926 .55974 Mdot
.926 .55977 Mdot
.926 .55977 Mdot
.926 .55978 Mdot
.926 .55978 Mdot
.926 .55978 Mdot
.926 .55978 Mdot
.928 .13724 Mdot
.928 .13725 Mdot
.928 .13737 Mdot
.928 .13739 Mdot
.928 .13739 Mdot
.928 .1376 Mdot
.928 .13761 Mdot
.928 .13781 Mdot
.928 .13786 Mdot
.928 .13791 Mdot
.928 .13814 Mdot
.928 .13846 Mdot
.928 .13882 Mdot
.928 .13886 Mdot
.928 .139 Mdot
.928 .13911 Mdot
.928 .13969 Mdot
.928 .14023 Mdot
.928 .14069 Mdot
.928 .14072 Mdot
.928 .1409 Mdot
.928 .14112 Mdot
.928 .14159 Mdot
.928 .14166 Mdot
.928 .14213 Mdot
.928 .1423 Mdot
.928 .14291 Mdot
.928 .14325 Mdot
.928 .14336 Mdot
.928 .14366 Mdot
.928 .1437 Mdot
.928 .14406 Mdot
.928 .1443 Mdot
.928 .14436 Mdot
.928 .14438 Mdot
.928 .14448 Mdot
.928 .14508 Mdot
.928 .14525 Mdot
.928 .14527 Mdot
.928 .14583 Mdot
.928 .14612 Mdot
.928 .14759 Mdot
.928 .14801 Mdot
.928 .14867 Mdot
.928 .14877 Mdot
.928 .14963 Mdot
.928 .15001 Mdot
.928 .15034 Mdot
.928 .15052 Mdot
.928 .15056 Mdot
.928 .15107 Mdot
.928 .1523 Mdot
.928 .15291 Mdot
.928 .15346 Mdot
.928 .15355 Mdot
.928 .1545 Mdot
.928 .15517 Mdot
.928 .15518 Mdot
.928 .15569 Mdot
.928 .15782 Mdot
.928 .15847 Mdot
.928 .15939 Mdot
.928 .15963 Mdot
.928 .15987 Mdot
.928 .16219 Mdot
.928 .16364 Mdot
.928 .16726 Mdot
.928 .16819 Mdot
.928 .16873 Mdot
.928 .16878 Mdot
.928 .169 Mdot
.928 .16926 Mdot
.928 .16934 Mdot
.928 .16934 Mdot
.928 .1694 Mdot
.928 .16953 Mdot
.928 .16983 Mdot
.928 .17013 Mdot
.928 .17017 Mdot
.928 .17043 Mdot
.928 .17094 Mdot
.928 .17115 Mdot
.928 .17136 Mdot
.928 .17198 Mdot
.928 .17225 Mdot
.928 .17306 Mdot
.928 .17353 Mdot
.928 .17386 Mdot
.928 .17456 Mdot
.928 .17458 Mdot
.928 .17472 Mdot
.928 .17499 Mdot
.928 .17518 Mdot
.928 .17523 Mdot
.928 .17573 Mdot
.928 .17574 Mdot
.928 .17621 Mdot
.928 .1771 Mdot
.928 .17865 Mdot
.928 .17966 Mdot
.928 .18002 Mdot
.928 .18037 Mdot
.928 .18073 Mdot
.928 .18082 Mdot
.928 .18084 Mdot
.928 .181 Mdot
.928 .1811 Mdot
.928 .18141 Mdot
.928 .18304 Mdot
.928 .18305 Mdot
.928 .18319 Mdot
.928 .18399 Mdot
.928 .18428 Mdot
.928 .1849 Mdot
.928 .18496 Mdot
.928 .18594 Mdot
.928 .18713 Mdot
.928 .18747 Mdot
.928 .18769 Mdot
.928 .18804 Mdot
.928 .18873 Mdot
.928 .18942 Mdot
.928 .1895 Mdot
.928 .18966 Mdot
.928 .19037 Mdot
.928 .19046 Mdot
.928 .19085 Mdot
.928 .19143 Mdot
.928 .19207 Mdot
.928 .19228 Mdot
.928 .19254 Mdot
.928 .1926 Mdot
.928 .19342 Mdot
.928 .19439 Mdot
.928 .19511 Mdot
.928 .19519 Mdot
.928 .19565 Mdot
.928 .19671 Mdot
.928 .19712 Mdot
.928 .19732 Mdot
.928 .19743 Mdot
.928 .19786 Mdot
.928 .19789 Mdot
.928 .19869 Mdot
.928 .19877 Mdot
.928 .19912 Mdot
.928 .20035 Mdot
.928 .20065 Mdot
.928 .20078 Mdot
.928 .20084 Mdot
.928 .20112 Mdot
.928 .20121 Mdot
.928 .20127 Mdot
.928 .2016 Mdot
.928 .20298 Mdot
.928 .20335 Mdot
.928 .20382 Mdot
.928 .20424 Mdot
.928 .20432 Mdot
.928 .20439 Mdot
.928 .2051 Mdot
.928 .20526 Mdot
.928 .2054 Mdot
.928 .2057 Mdot
.928 .20596 Mdot
.928 .20745 Mdot
.928 .20791 Mdot
.928 .20796 Mdot
.928 .20834 Mdot
.928 .20908 Mdot
.928 .20993 Mdot
.928 .21078 Mdot
.928 .21091 Mdot
.928 .21147 Mdot
.928 .21167 Mdot
.928 .21254 Mdot
.928 .21355 Mdot
.928 .21601 Mdot
.928 .21803 Mdot
.928 .22042 Mdot
.928 .22151 Mdot
.928 .22228 Mdot
.928 .22256 Mdot
.928 .22272 Mdot
.928 .22419 Mdot
.928 .22456 Mdot
.928 .22472 Mdot
.928 .22521 Mdot
.928 .22596 Mdot
.928 .22676 Mdot
.928 .22883 Mdot
.928 .2291 Mdot
.928 .22915 Mdot
.928 .22977 Mdot
.928 .2305 Mdot
.928 .232 Mdot
.928 .23279 Mdot
.928 .23305 Mdot
.928 .23399 Mdot
.928 .23437 Mdot
.928 .23442 Mdot
.928 .23468 Mdot
.928 .23506 Mdot
.928 .23534 Mdot
.928 .23823 Mdot
.928 .2384 Mdot
.928 .2389 Mdot
.928 .24005 Mdot
.928 .24144 Mdot
.928 .24202 Mdot
.928 .24286 Mdot
.928 .24336 Mdot
.928 .24509 Mdot
.928 .24597 Mdot
.928 .24626 Mdot
.928 .24982 Mdot
.928 .25048 Mdot
.928 .25172 Mdot
.928 .25254 Mdot
.928 .25327 Mdot
.928 .25366 Mdot
.928 .25381 Mdot
.928 .25441 Mdot
.928 .25458 Mdot
.928 .2557 Mdot
.928 .25626 Mdot
.928 .25727 Mdot
.928 .2585 Mdot
.928 .25871 Mdot
.928 .25929 Mdot
.928 .25993 Mdot
.928 .26167 Mdot
.928 .26219 Mdot
.928 .26313 Mdot
.928 .26427 Mdot
.928 .26432 Mdot
.928 .26625 Mdot
.928 .26728 Mdot
.928 .26765 Mdot
.928 .26851 Mdot
.928 .27041 Mdot
.928 .27059 Mdot
.928 .27091 Mdot
.928 .2714 Mdot
.928 .2743 Mdot
.928 .27724 Mdot
.928 .27791 Mdot
.928 .28045 Mdot
.928 .28178 Mdot
.928 .28185 Mdot
.928 .28231 Mdot
.928 .28285 Mdot
.928 .28441 Mdot
.928 .28445 Mdot
.928 .28493 Mdot
.928 .28613 Mdot
.928 .28623 Mdot
.928 .29015 Mdot
.928 .29089 Mdot
.928 .29121 Mdot
.928 .29143 Mdot
.928 .29194 Mdot
.928 .29234 Mdot
.928 .29249 Mdot
.928 .29386 Mdot
.928 .29412 Mdot
.928 .29485 Mdot
.928 .29497 Mdot
.928 .29575 Mdot
.928 .29649 Mdot
.928 .29736 Mdot
.928 .29846 Mdot
.928 .29979 Mdot
.928 .30007 Mdot
.928 .30054 Mdot
.928 .30365 Mdot
.928 .3049 Mdot
.928 .30641 Mdot
.928 .30979 Mdot
.928 .3101 Mdot
.928 .31181 Mdot
.928 .31182 Mdot
.928 .31321 Mdot
.928 .31418 Mdot
.928 .31463 Mdot
.928 .31547 Mdot
.928 .31651 Mdot
.928 .31764 Mdot
.928 .32162 Mdot
.928 .32194 Mdot
.928 .32509 Mdot
.928 .32617 Mdot
.928 .32694 Mdot
.928 .32702 Mdot
.928 .32705 Mdot
.928 .32811 Mdot
.928 .32814 Mdot
.928 .32879 Mdot
.928 .32912 Mdot
.928 .33073 Mdot
.928 .33116 Mdot
.928 .33277 Mdot
.928 .33344 Mdot
.928 .33412 Mdot
.928 .33707 Mdot
.928 .33762 Mdot
.928 .33802 Mdot
.928 .33966 Mdot
.928 .34099 Mdot
.928 .34116 Mdot
.928 .34278 Mdot
.928 .34609 Mdot
.928 .34699 Mdot
.928 .34702 Mdot
.928 .34731 Mdot
.928 .34736 Mdot
.928 .34736 Mdot
.928 .34739 Mdot
.928 .34783 Mdot
.928 .34786 Mdot
.928 .34801 Mdot
.928 .34832 Mdot
.928 .34844 Mdot
.928 .34856 Mdot
.928 .34892 Mdot
.928 .34908 Mdot
.928 .34981 Mdot
.928 .35 Mdot
.928 .3504 Mdot
.928 .35049 Mdot
.928 .35064 Mdot
.928 .35074 Mdot
.928 .35105 Mdot
.928 .35105 Mdot
.928 .35131 Mdot
.928 .35264 Mdot
.928 .35318 Mdot
.928 .35337 Mdot
.928 .35355 Mdot
.928 .35379 Mdot
.928 .35388 Mdot
.928 .35393 Mdot
.928 .35409 Mdot
.928 .35494 Mdot
.928 .35501 Mdot
.928 .35541 Mdot
.928 .35556 Mdot
.928 .3559 Mdot
.928 .35697 Mdot
.928 .35714 Mdot
.928 .35725 Mdot
.928 .35742 Mdot
.928 .35775 Mdot
.928 .35809 Mdot
.928 .3582 Mdot
.928 .35854 Mdot
.928 .35858 Mdot
.928 .35904 Mdot
.928 .35944 Mdot
.928 .35959 Mdot
.928 .35997 Mdot
.928 .36042 Mdot
.928 .36075 Mdot
.928 .361 Mdot
.928 .36147 Mdot
.928 .36166 Mdot
.928 .36175 Mdot
.928 .36199 Mdot
.928 .36201 Mdot
.928 .3624 Mdot
.928 .36255 Mdot
.928 .3631 Mdot
.928 .36323 Mdot
.928 .36329 Mdot
.928 .36331 Mdot
.928 .36343 Mdot
.928 .3635 Mdot
.928 .36461 Mdot
.928 .36482 Mdot
.928 .36485 Mdot
.928 .36515 Mdot
.928 .36522 Mdot
.928 .36528 Mdot
.928 .36541 Mdot
.928 .36614 Mdot
.928 .36636 Mdot
.928 .36652 Mdot
.928 .36682 Mdot
.928 .36718 Mdot
.928 .36753 Mdot
.928 .36781 Mdot
.928 .36789 Mdot
.928 .36865 Mdot
.928 .36964 Mdot
.928 .37044 Mdot
.928 .37137 Mdot
.928 .3722 Mdot
.928 .37226 Mdot
.928 .37282 Mdot
.928 .37303 Mdot
.928 .37321 Mdot
.928 .3735 Mdot
.928 .3738 Mdot
.928 .37458 Mdot
.928 .37467 Mdot
.928 .37492 Mdot
.928 .37575 Mdot
.928 .37614 Mdot
.928 .37648 Mdot
.928 .37664 Mdot
.928 .37673 Mdot
.928 .37687 Mdot
.928 .37697 Mdot
.928 .37807 Mdot
.928 .37825 Mdot
.928 .37866 Mdot
.928 .37936 Mdot
.928 .38044 Mdot
.928 .38074 Mdot
.928 .38084 Mdot
.928 .38207 Mdot
.928 .3823 Mdot
.928 .38325 Mdot
.928 .38343 Mdot
.928 .38425 Mdot
.928 .3846 Mdot
.928 .38508 Mdot
.928 .38548 Mdot
.928 .38623 Mdot
.928 .38654 Mdot
.928 .38691 Mdot
.928 .38693 Mdot
.928 .38789 Mdot
.928 .38801 Mdot
.928 .38907 Mdot
.928 .39015 Mdot
.928 .39108 Mdot
.928 .39251 Mdot
.928 .39254 Mdot
.928 .39268 Mdot
.928 .39335 Mdot
.928 .3939 Mdot
.928 .39511 Mdot
.928 .39543 Mdot
.928 .39566 Mdot
.928 .39583 Mdot
.928 .39625 Mdot
.928 .39632 Mdot
.928 .39658 Mdot
.928 .39682 Mdot
.928 .39704 Mdot
.928 .39731 Mdot
.928 .39804 Mdot
.928 .39813 Mdot
.928 .39827 Mdot
.928 .3992 Mdot
.928 .39958 Mdot
.928 .40103 Mdot
.928 .40112 Mdot
.928 .40163 Mdot
.928 .40163 Mdot
.928 .40233 Mdot
.928 .40246 Mdot
.928 .40271 Mdot
.928 .40301 Mdot
.928 .40335 Mdot
.928 .4046 Mdot
.928 .40583 Mdot
.928 .40606 Mdot
.928 .40608 Mdot
.928 .40609 Mdot
.928 .4064 Mdot
.928 .40669 Mdot
.928 .40774 Mdot
.928 .40793 Mdot
.928 .40913 Mdot
.928 .40925 Mdot
.928 .41155 Mdot
.928 .41192 Mdot
.928 .41277 Mdot
.928 .41356 Mdot
.928 .41361 Mdot
.928 .41377 Mdot
.928 .41476 Mdot
.928 .41485 Mdot
.928 .41495 Mdot
.928 .41522 Mdot
.928 .41537 Mdot
.928 .41561 Mdot
.928 .4159 Mdot
.928 .41605 Mdot
.928 .41605 Mdot
.928 .41616 Mdot
.928 .41642 Mdot
.928 .41701 Mdot
.928 .41761 Mdot
.928 .41769 Mdot
.928 .41792 Mdot
.928 .4182 Mdot
.928 .41892 Mdot
.928 .41921 Mdot
.928 .41959 Mdot
.928 .41962 Mdot
.928 .42003 Mdot
.928 .42124 Mdot
.928 .42176 Mdot
.928 .42231 Mdot
.928 .42254 Mdot
.928 .42333 Mdot
.928 .42397 Mdot
.928 .42423 Mdot
.928 .42468 Mdot
.928 .42487 Mdot
.928 .42536 Mdot
.928 .42568 Mdot
.928 .42591 Mdot
.928 .42619 Mdot
.928 .42621 Mdot
.928 .42625 Mdot
.928 .42652 Mdot
.928 .42704 Mdot
.928 .42706 Mdot
.928 .4274 Mdot
.928 .42744 Mdot
.928 .42751 Mdot
.928 .42846 Mdot
.928 .42846 Mdot
.928 .42847 Mdot
.928 .42893 Mdot
.928 .42899 Mdot
.928 .42936 Mdot
.928 .4306 Mdot
.928 .43106 Mdot
.928 .43117 Mdot
.928 .43184 Mdot
.928 .43231 Mdot
.928 .43357 Mdot
.928 .43397 Mdot
.928 .43413 Mdot
.928 .43421 Mdot
.928 .43446 Mdot
.928 .43457 Mdot
.928 .43549 Mdot
.928 .43565 Mdot
.928 .43585 Mdot
.928 .43599 Mdot
.928 .43635 Mdot
.928 .43652 Mdot
.928 .43654 Mdot
.928 .43661 Mdot
.928 .43691 Mdot
.928 .43717 Mdot
.928 .43782 Mdot
.928 .43798 Mdot
.928 .43802 Mdot
.928 .43812 Mdot
.928 .43832 Mdot
.928 .4385 Mdot
.928 .43859 Mdot
.928 .43908 Mdot
.928 .43914 Mdot
.928 .43928 Mdot
.928 .43932 Mdot
.928 .43962 Mdot
.928 .44029 Mdot
.928 .44054 Mdot
.928 .44089 Mdot
.928 .4412 Mdot
.928 .44205 Mdot
.928 .44208 Mdot
.928 .44233 Mdot
.928 .44286 Mdot
.928 .44306 Mdot
.928 .44351 Mdot
.928 .44366 Mdot
.928 .44378 Mdot
.928 .44394 Mdot
.928 .4443 Mdot
.928 .44467 Mdot
.928 .44541 Mdot
.928 .44552 Mdot
.928 .44692 Mdot
.928 .44726 Mdot
.928 .44777 Mdot
.928 .44894 Mdot
.928 .44914 Mdot
.928 .44937 Mdot
.928 .44995 Mdot
.928 .44997 Mdot
.928 .45037 Mdot
.928 .45098 Mdot
.928 .45213 Mdot
.928 .45218 Mdot
.928 .45278 Mdot
.928 .45287 Mdot
.928 .45339 Mdot
.928 .45353 Mdot
.928 .45369 Mdot
.928 .45369 Mdot
.928 .4537 Mdot
.928 .45381 Mdot
.928 .45503 Mdot
.928 .45519 Mdot
.928 .45534 Mdot
.928 .45546 Mdot
.928 .45553 Mdot
.928 .45587 Mdot
.928 .45611 Mdot
.928 .45616 Mdot
.928 .45686 Mdot
.928 .45704 Mdot
.928 .45749 Mdot
.928 .45756 Mdot
.928 .4576 Mdot
.928 .45795 Mdot
.928 .45808 Mdot
.928 .4583 Mdot
.928 .45846 Mdot
.928 .45874 Mdot
.928 .45885 Mdot
.928 .45901 Mdot
.928 .45985 Mdot
.928 .46016 Mdot
.928 .46024 Mdot
.928 .46092 Mdot
.928 .46136 Mdot
.928 .46188 Mdot
.928 .46243 Mdot
.928 .46306 Mdot
.928 .46321 Mdot
.928 .46374 Mdot
.928 .46397 Mdot
.928 .46413 Mdot
.928 .46504 Mdot
.928 .46571 Mdot
.928 .4659 Mdot
.928 .4664 Mdot
.928 .46672 Mdot
.928 .46691 Mdot
.928 .4676 Mdot
.928 .46765 Mdot
.928 .46788 Mdot
.928 .46854 Mdot
.928 .46859 Mdot
.928 .46894 Mdot
.928 .46908 Mdot
.928 .46921 Mdot
.928 .46964 Mdot
.928 .46967 Mdot
.928 .47083 Mdot
.928 .47127 Mdot
.928 .47162 Mdot
.928 .47165 Mdot
.928 .47178 Mdot
.928 .47209 Mdot
.928 .4723 Mdot
.928 .4724 Mdot
.928 .47273 Mdot
.928 .47284 Mdot
.928 .47299 Mdot
.928 .47309 Mdot
.928 .47361 Mdot
.928 .47366 Mdot
.928 .47407 Mdot
.928 .47424 Mdot
.928 .47425 Mdot
.928 .47448 Mdot
.928 .47495 Mdot
.928 .47532 Mdot
.928 .47556 Mdot
.928 .47578 Mdot
.928 .47598 Mdot
.928 .47613 Mdot
.928 .47627 Mdot
.928 .47635 Mdot
.928 .47709 Mdot
.928 .47773 Mdot
.928 .47781 Mdot
.928 .47787 Mdot
.928 .47797 Mdot
.928 .47805 Mdot
.928 .47814 Mdot
.928 .47906 Mdot
.928 .47931 Mdot
.928 .47935 Mdot
.928 .47952 Mdot
.928 .47999 Mdot
.928 .48038 Mdot
.928 .48065 Mdot
.928 .48121 Mdot
.928 .48263 Mdot
.928 .48333 Mdot
.928 .4834 Mdot
.928 .48397 Mdot
.928 .48467 Mdot
.928 .48484 Mdot
.928 .48507 Mdot
.928 .48633 Mdot
.928 .48661 Mdot
.928 .4869 Mdot
.928 .48757 Mdot
.928 .48776 Mdot
.928 .48843 Mdot
.928 .48857 Mdot
.928 .48884 Mdot
.928 .48886 Mdot
.928 .4893 Mdot
.928 .48931 Mdot
.928 .48934 Mdot
.928 .48967 Mdot
.928 .49012 Mdot
.928 .49143 Mdot
.928 .49156 Mdot
.928 .4932 Mdot
.928 .49367 Mdot
.928 .4941 Mdot
.928 .49444 Mdot
.928 .49463 Mdot
.928 .49502 Mdot
.928 .49559 Mdot
.928 .4956 Mdot
.928 .49629 Mdot
.928 .49642 Mdot
.928 .4978 Mdot
.928 .49841 Mdot
.928 .49891 Mdot
.928 .50017 Mdot
.928 .50036 Mdot
.928 .50047 Mdot
.928 .501 Mdot
.928 .50145 Mdot
.928 .50179 Mdot
.928 .50209 Mdot
.928 .5024 Mdot
.928 .50245 Mdot
.928 .50274 Mdot
.928 .50284 Mdot
.928 .50339 Mdot
.928 .50345 Mdot
.928 .50361 Mdot
.928 .50381 Mdot
.928 .5039 Mdot
.928 .50403 Mdot
.928 .50432 Mdot
.928 .50588 Mdot
.928 .50591 Mdot
.928 .50639 Mdot
.928 .50658 Mdot
.928 .50659 Mdot
.928 .50721 Mdot
.928 .50742 Mdot
.928 .5076 Mdot
.928 .50763 Mdot
.928 .50815 Mdot
.928 .50915 Mdot
.928 .50941 Mdot
.928 .51056 Mdot
.928 .51169 Mdot
.928 .51188 Mdot
.928 .512 Mdot
.928 .51207 Mdot
.928 .51281 Mdot
.928 .51314 Mdot
.928 .51328 Mdot
.928 .51368 Mdot
.928 .51443 Mdot
.928 .51444 Mdot
.928 .51489 Mdot
.928 .51525 Mdot
.928 .51545 Mdot
.928 .51611 Mdot
.928 .51636 Mdot
.928 .51658 Mdot
.928 .51667 Mdot
.928 .51713 Mdot
.928 .51752 Mdot
.928 .51774 Mdot
.928 .51816 Mdot
.928 .51823 Mdot
.928 .51846 Mdot
.928 .51852 Mdot
.928 .51866 Mdot
.928 .51894 Mdot
.928 .51925 Mdot
.928 .51973 Mdot
.928 .51998 Mdot
.928 .52133 Mdot
.928 .52144 Mdot
.928 .52177 Mdot
.928 .52242 Mdot
.928 .52261 Mdot
.928 .52293 Mdot
.928 .52315 Mdot
.928 .52367 Mdot
.928 .5241 Mdot
.928 .52429 Mdot
.928 .52436 Mdot
.928 .52544 Mdot
.928 .52555 Mdot
.928 .52569 Mdot
.928 .52579 Mdot
.928 .52581 Mdot
.928 .52595 Mdot
.928 .5263 Mdot
.928 .5264 Mdot
.928 .52669 Mdot
.928 .52725 Mdot
.928 .52753 Mdot
.928 .52776 Mdot
.928 .52778 Mdot
.928 .52787 Mdot
.928 .52865 Mdot
.928 .52894 Mdot
.928 .52922 Mdot
.928 .5294 Mdot
.928 .52946 Mdot
.928 .5296 Mdot
.928 .53015 Mdot
.928 .53021 Mdot
.928 .53031 Mdot
.928 .5306 Mdot
.928 .531 Mdot
.928 .53188 Mdot
.928 .53263 Mdot
.928 .53354 Mdot
.928 .53391 Mdot
.928 .53423 Mdot
.928 .5343 Mdot
.928 .53451 Mdot
.928 .53456 Mdot
.928 .53487 Mdot
.928 .53518 Mdot
.928 .53545 Mdot
.928 .53559 Mdot
.928 .53561 Mdot
.928 .53578 Mdot
.928 .53632 Mdot
.928 .53642 Mdot
.928 .53653 Mdot
.928 .53658 Mdot
.928 .53664 Mdot
.928 .5369 Mdot
.928 .53692 Mdot
.928 .53695 Mdot
.928 .53711 Mdot
.928 .53728 Mdot
.928 .53741 Mdot
.928 .53792 Mdot
.928 .53804 Mdot
.928 .53806 Mdot
.928 .53809 Mdot
.928 .5382 Mdot
.928 .53822 Mdot
.928 .53827 Mdot
.928 .53838 Mdot
.928 .53882 Mdot
.928 .53895 Mdot
.928 .53898 Mdot
.928 .53927 Mdot
.928 .53928 Mdot
.928 .53944 Mdot
.928 .53948 Mdot
.928 .53955 Mdot
.928 .5397 Mdot
.928 .54009 Mdot
.928 .54025 Mdot
.928 .54028 Mdot
.928 .54054 Mdot
.928 .54089 Mdot
.928 .54119 Mdot
.928 .54122 Mdot
.928 .54131 Mdot
.928 .54138 Mdot
.928 .54162 Mdot
.928 .54183 Mdot
.928 .54197 Mdot
.928 .542 Mdot
.928 .54226 Mdot
.928 .54232 Mdot
.928 .54235 Mdot
.928 .5426 Mdot
.928 .54284 Mdot
.928 .54297 Mdot
.928 .54305 Mdot
.928 .54318 Mdot
.928 .54361 Mdot
.928 .54396 Mdot
.928 .54398 Mdot
.928 .5442 Mdot
.928 .54431 Mdot
.928 .5446 Mdot
.928 .54465 Mdot
.928 .54465 Mdot
.928 .54524 Mdot
.928 .54535 Mdot
.928 .54539 Mdot
.928 .54544 Mdot
.928 .54545 Mdot
.928 .54548 Mdot
.928 .54561 Mdot
.928 .54574 Mdot
.928 .54587 Mdot
.928 .54623 Mdot
.928 .54679 Mdot
.928 .54711 Mdot
.928 .54728 Mdot
.928 .54728 Mdot
.928 .54746 Mdot
.928 .54748 Mdot
.928 .54755 Mdot
.928 .54764 Mdot
.928 .54769 Mdot
.928 .5477 Mdot
.928 .54795 Mdot
.928 .54807 Mdot
.928 .54824 Mdot
.928 .54853 Mdot
.928 .54863 Mdot
.928 .54885 Mdot
.928 .54892 Mdot
.928 .549 Mdot
.928 .54918 Mdot
.928 .54927 Mdot
.928 .54929 Mdot
.928 .5494 Mdot
.928 .5495 Mdot
.928 .54955 Mdot
.928 .54957 Mdot
.928 .54957 Mdot
.928 .5496 Mdot
.928 .54969 Mdot
.928 .54977 Mdot
.928 .54979 Mdot
.928 .54998 Mdot
.928 .55031 Mdot
.928 .5516 Mdot
.928 .55212 Mdot
.928 .55295 Mdot
.928 .55303 Mdot
.928 .55312 Mdot
.928 .55345 Mdot
.928 .55368 Mdot
.928 .55443 Mdot
.928 .55462 Mdot
.928 .55462 Mdot
.928 .55486 Mdot
.928 .55519 Mdot
.928 .55522 Mdot
.928 .55542 Mdot
.928 .55564 Mdot
.928 .55607 Mdot
.928 .55625 Mdot
.928 .55627 Mdot
.928 .55633 Mdot
.928 .55645 Mdot
.928 .55658 Mdot
.928 .55689 Mdot
.928 .55692 Mdot
.928 .55715 Mdot
.928 .5573 Mdot
.928 .55782 Mdot
.928 .55793 Mdot
.928 .55812 Mdot
.928 .55813 Mdot
.928 .55819 Mdot
.928 .5584 Mdot
.928 .55844 Mdot
.928 .55845 Mdot
.928 .55847 Mdot
.928 .55855 Mdot
.928 .55868 Mdot
.928 .55869 Mdot
.928 .5588 Mdot
.928 .55884 Mdot
.928 .55896 Mdot
.928 .55917 Mdot
.928 .55923 Mdot
.928 .5594 Mdot
.928 .55942 Mdot
.928 .55959 Mdot
.928 .55967 Mdot
.928 .55973 Mdot
.928 .55974 Mdot
.928 .5599 Mdot
.928 .56009 Mdot
.928 .5603 Mdot
.928 .56034 Mdot
.928 .56038 Mdot
.928 .5604 Mdot
.928 .56053 Mdot
.928 .56064 Mdot
.928 .56072 Mdot
.928 .56074 Mdot
.928 .56076 Mdot
.928 .56083 Mdot
.928 .56083 Mdot
.928 .5609 Mdot
.928 .5609 Mdot
.928 .56091 Mdot
.928 .56095 Mdot
.928 .56096 Mdot
.93 .13414 Mdot
.93 .13415 Mdot
.93 .13415 Mdot
.93 .13418 Mdot
.93 .13422 Mdot
.93 .13423 Mdot
.93 .13426 Mdot
.93 .13432 Mdot
.93 .1344 Mdot
.93 .13467 Mdot
.93 .13469 Mdot
.93 .13478 Mdot
.93 .13498 Mdot
.93 .13502 Mdot
.93 .13514 Mdot
.93 .13555 Mdot
.93 .13561 Mdot
.93 .13572 Mdot
.93 .13586 Mdot
.93 .13612 Mdot
.93 .13612 Mdot
.93 .13614 Mdot
.93 .13617 Mdot
.93 .13623 Mdot
.93 .13639 Mdot
.93 .13644 Mdot
.93 .13671 Mdot
.93 .13671 Mdot
.93 .13681 Mdot
.93 .13687 Mdot
.93 .13691 Mdot
.93 .1371 Mdot
.93 .13822 Mdot
.93 .13824 Mdot
.93 .13883 Mdot
.93 .13915 Mdot
.93 .13952 Mdot
.93 .14011 Mdot
.93 .14014 Mdot
.93 .14077 Mdot
.93 .14104 Mdot
.93 .14159 Mdot
.93 .14179 Mdot
.93 .14231 Mdot
.93 .14274 Mdot
.93 .14287 Mdot
.93 .14326 Mdot
.93 .14405 Mdot
.93 .14432 Mdot
.93 .14499 Mdot
.93 .1459 Mdot
.93 .14593 Mdot
.93 .14626 Mdot
.93 .14636 Mdot
.93 .14651 Mdot
.93 .14658 Mdot
.93 .14752 Mdot
.93 .14772 Mdot
.93 .14795 Mdot
.93 .14804 Mdot
.93 .14876 Mdot
.93 .14885 Mdot
.93 .14906 Mdot
.93 .14943 Mdot
.93 .14998 Mdot
.93 .15016 Mdot
.93 .15016 Mdot
.93 .1507 Mdot
.93 .15072 Mdot
.93 .15151 Mdot
.93 .15151 Mdot
.93 .15231 Mdot
.93 .15294 Mdot
.93 .15351 Mdot
.93 .15383 Mdot
.93 .15458 Mdot
.93 .15502 Mdot
.93 .15598 Mdot
.93 .156 Mdot
.93 .15602 Mdot
.93 .1561 Mdot
.93 .15624 Mdot
.93 .15625 Mdot
.93 .15635 Mdot
.93 .15656 Mdot
.93 .15683 Mdot
.93 .15687 Mdot
.93 .15739 Mdot
.93 .15772 Mdot
.93 .15779 Mdot
.93 .15795 Mdot
.93 .1581 Mdot
.93 .15835 Mdot
.93 .15876 Mdot
.93 .15884 Mdot
.93 .15891 Mdot
.93 .15932 Mdot
.93 .15973 Mdot
.93 .1603 Mdot
.93 .16032 Mdot
.93 .16076 Mdot
.93 .16096 Mdot
.93 .16137 Mdot
.93 .16155 Mdot
.93 .16187 Mdot
.93 .16216 Mdot
.93 .1628 Mdot
.93 .16282 Mdot
.93 .16286 Mdot
.93 .16301 Mdot
.93 .16304 Mdot
.93 .16309 Mdot
.93 .16322 Mdot
.93 .16372 Mdot
.93 .16379 Mdot
.93 .16399 Mdot
.93 .16479 Mdot
.93 .16492 Mdot
.93 .16496 Mdot
.93 .165 Mdot
.93 .16501 Mdot
.93 .16537 Mdot
.93 .16552 Mdot
.93 .16561 Mdot
.93 .16577 Mdot
.93 .16624 Mdot
.93 .16651 Mdot
.93 .16652 Mdot
.93 .16741 Mdot
.93 .16765 Mdot
.93 .16786 Mdot
.93 .16979 Mdot
.93 .16997 Mdot
.93 .17071 Mdot
.93 .17096 Mdot
.93 .17105 Mdot
.93 .17176 Mdot
.93 .17232 Mdot
.93 .17351 Mdot
.93 .17388 Mdot
.93 .17486 Mdot
.93 .17644 Mdot
.93 .17667 Mdot
.93 .17905 Mdot
.93 .17908 Mdot
.93 .17919 Mdot
.93 .17953 Mdot
.93 .17993 Mdot
.93 .18103 Mdot
.93 .18204 Mdot
.93 .18235 Mdot
.93 .18328 Mdot
.93 .18414 Mdot
.93 .1846 Mdot
.93 .18589 Mdot
.93 .18683 Mdot
.93 .18829 Mdot
.93 .18934 Mdot
.93 .19145 Mdot
.93 .1915 Mdot
.93 .19174 Mdot
.93 .19208 Mdot
.93 .19214 Mdot
.93 .19404 Mdot
.93 .19523 Mdot
.93 .19602 Mdot
.93 .19612 Mdot
.93 .19673 Mdot
.93 .1968 Mdot
.93 .19731 Mdot
.93 .19739 Mdot
.93 .19808 Mdot
.93 .19947 Mdot
.93 .19992 Mdot
.93 .20071 Mdot
.93 .20083 Mdot
.93 .2014 Mdot
.93 .20247 Mdot
.93 .20302 Mdot
.93 .20474 Mdot
.93 .20644 Mdot
.93 .20792 Mdot
.93 .20809 Mdot
.93 .20919 Mdot
.93 .20926 Mdot
.93 .20947 Mdot
.93 .20958 Mdot
.93 .20989 Mdot
.93 .21048 Mdot
.93 .2113 Mdot
.93 .21167 Mdot
.93 .21332 Mdot
.93 .21488 Mdot
.93 .2151 Mdot
.93 .21599 Mdot
.93 .21649 Mdot
.93 .21698 Mdot
.93 .21816 Mdot
.93 .21867 Mdot
.93 .2193 Mdot
.93 .21949 Mdot
.93 .21988 Mdot
.93 .21998 Mdot
.93 .22301 Mdot
.93 .22421 Mdot
.93 .22473 Mdot
.93 .22597 Mdot
.93 .22639 Mdot
.93 .22663 Mdot
.93 .22769 Mdot
.93 .22818 Mdot
.93 .22933 Mdot
.93 .23149 Mdot
.93 .23255 Mdot
.93 .23259 Mdot
.93 .23311 Mdot
.93 .23334 Mdot
.93 .23342 Mdot
.93 .2339 Mdot
.93 .23447 Mdot
.93 .23585 Mdot
.93 .236 Mdot
.93 .23636 Mdot
.93 .23838 Mdot
.93 .23913 Mdot
.93 .23984 Mdot
.93 .24051 Mdot
.93 .24089 Mdot
.93 .24092 Mdot
.93 .24337 Mdot
.93 .24591 Mdot
.93 .24613 Mdot
.93 .24637 Mdot
.93 .24721 Mdot
.93 .24741 Mdot
.93 .24775 Mdot
.93 .24784 Mdot
.93 .24995 Mdot
.93 .25194 Mdot
.93 .25358 Mdot
.93 .25364 Mdot
.93 .25397 Mdot
.93 .25507 Mdot
.93 .25511 Mdot
.93 .25533 Mdot
.93 .25563 Mdot
.93 .25568 Mdot
.93 .25602 Mdot
.93 .2576 Mdot
.93 .25771 Mdot
.93 .26096 Mdot
.93 .26348 Mdot
.93 .26762 Mdot
.93 .26873 Mdot
.93 .26985 Mdot
.93 .26998 Mdot
.93 .27012 Mdot
.93 .27065 Mdot
.93 .27125 Mdot
.93 .27159 Mdot
.93 .27162 Mdot
.93 .2717 Mdot
.93 .27236 Mdot
.93 .27279 Mdot
.93 .27375 Mdot
.93 .27555 Mdot
.93 .27589 Mdot
.93 .27616 Mdot
.93 .27692 Mdot
.93 .27827 Mdot
.93 .27941 Mdot
.93 .28099 Mdot
.93 .28166 Mdot
.93 .28211 Mdot
.93 .28211 Mdot
.93 .28226 Mdot
.93 .28324 Mdot
.93 .28396 Mdot
.93 .28425 Mdot
.93 .28598 Mdot
.93 .28787 Mdot
.93 .28874 Mdot
.93 .28918 Mdot
.93 .28932 Mdot
.93 .28982 Mdot
.93 .29069 Mdot
.93 .29139 Mdot
.93 .29261 Mdot
.93 .29542 Mdot
.93 .29546 Mdot
.93 .29793 Mdot
.93 .29825 Mdot
.93 .29826 Mdot
.93 .29884 Mdot
.93 .29944 Mdot
.93 .29956 Mdot
.93 .29958 Mdot
.93 .3002 Mdot
.93 .3023 Mdot
.93 .3027 Mdot
.93 .30401 Mdot
.93 .3041 Mdot
.93 .30696 Mdot
.93 .30702 Mdot
.93 .30803 Mdot
.93 .30819 Mdot
.93 .3097 Mdot
.93 .31048 Mdot
.93 .3114 Mdot
.93 .31194 Mdot
.93 .31251 Mdot
.93 .31445 Mdot
.93 .31519 Mdot
.93 .31703 Mdot
.93 .31718 Mdot
.93 .31749 Mdot
.93 .31852 Mdot
.93 .31875 Mdot
.93 .3191 Mdot
.93 .32 Mdot
.93 .32022 Mdot
.93 .3206 Mdot
.93 .32358 Mdot
.93 .32407 Mdot
.93 .32461 Mdot
.93 .32548 Mdot
.93 .32632 Mdot
.93 .32761 Mdot
.93 .33047 Mdot
.93 .33117 Mdot
.93 .33211 Mdot
.93 .33243 Mdot
.93 .33253 Mdot
.93 .33267 Mdot
.93 .33274 Mdot
.93 .33362 Mdot
.93 .33402 Mdot
.93 .33474 Mdot
.93 .335 Mdot
.93 .33533 Mdot
.93 .33642 Mdot
.93 .33707 Mdot
.93 .33771 Mdot
.93 .33821 Mdot
.93 .33889 Mdot
.93 .33946 Mdot
.93 .34049 Mdot
.93 .3405 Mdot
.93 .34052 Mdot
.93 .34058 Mdot
.93 .34068 Mdot
.93 .34069 Mdot
.93 .34076 Mdot
.93 .34091 Mdot
.93 .3411 Mdot
.93 .3415 Mdot
.93 .34173 Mdot
.93 .34178 Mdot
.93 .342 Mdot
.93 .34245 Mdot
.93 .34255 Mdot
.93 .34283 Mdot
.93 .3431 Mdot
.93 .34349 Mdot
.93 .3435 Mdot
.93 .34379 Mdot
.93 .34393 Mdot
.93 .34419 Mdot
.93 .34452 Mdot
.93 .3447 Mdot
.93 .34511 Mdot
.93 .34512 Mdot
.93 .34515 Mdot
.93 .34524 Mdot
.93 .3453 Mdot
.93 .34538 Mdot
.93 .34574 Mdot
.93 .34586 Mdot
.93 .34649 Mdot
.93 .34649 Mdot
.93 .34671 Mdot
.93 .34686 Mdot
.93 .34696 Mdot
.93 .34724 Mdot
.93 .3474 Mdot
.93 .34942 Mdot
.93 .34985 Mdot
.93 .34999 Mdot
.93 .35004 Mdot
.93 .35075 Mdot
.93 .3514 Mdot
.93 .3516 Mdot
.93 .35213 Mdot
.93 .35298 Mdot
.93 .35309 Mdot
.93 .35433 Mdot
.93 .35435 Mdot
.93 .3544 Mdot
.93 .35478 Mdot
.93 .35534 Mdot
.93 .35584 Mdot
.93 .35599 Mdot
.93 .35645 Mdot
.93 .35688 Mdot
.93 .35772 Mdot
.93 .35817 Mdot
.93 .35886 Mdot
.93 .35935 Mdot
.93 .36033 Mdot
.93 .36062 Mdot
.93 .36064 Mdot
.93 .3615 Mdot
.93 .3627 Mdot
.93 .36329 Mdot
.93 .36389 Mdot
.93 .36471 Mdot
.93 .36517 Mdot
.93 .3654 Mdot
.93 .36683 Mdot
.93 .36743 Mdot
.93 .3675 Mdot
.93 .36795 Mdot
.93 .36798 Mdot
.93 .36806 Mdot
.93 .36823 Mdot
.93 .36847 Mdot
.93 .3688 Mdot
.93 .36895 Mdot
.93 .3696 Mdot
.93 .37104 Mdot
.93 .37149 Mdot
.93 .372 Mdot
.93 .37219 Mdot
.93 .37334 Mdot
.93 .37379 Mdot
.93 .37399 Mdot
.93 .37445 Mdot
.93 .3746 Mdot
.93 .37508 Mdot
.93 .37526 Mdot
.93 .37569 Mdot
.93 .37647 Mdot
.93 .37686 Mdot
.93 .37687 Mdot
.93 .37705 Mdot
.93 .37734 Mdot
.93 .37804 Mdot
.93 .37809 Mdot
.93 .37919 Mdot
.93 .37944 Mdot
.93 .37981 Mdot
.93 .37982 Mdot
.93 .38067 Mdot
.93 .38154 Mdot
.93 .38162 Mdot
.93 .38199 Mdot
.93 .38217 Mdot
.93 .38292 Mdot
.93 .38414 Mdot
.93 .38427 Mdot
.93 .38465 Mdot
.93 .38482 Mdot
.93 .38483 Mdot
.93 .38645 Mdot
.93 .38739 Mdot
.93 .38908 Mdot
.93 .38944 Mdot
.93 .38948 Mdot
.93 .38952 Mdot
.93 .38969 Mdot
.93 .38999 Mdot
.93 .39 Mdot
.93 .39002 Mdot
.93 .39023 Mdot
.93 .39067 Mdot
.93 .39124 Mdot
.93 .39134 Mdot
.93 .39244 Mdot
.93 .39293 Mdot
.93 .39314 Mdot
.93 .39328 Mdot
.93 .39362 Mdot
.93 .39394 Mdot
.93 .39447 Mdot
.93 .39531 Mdot
.93 .39544 Mdot
.93 .39549 Mdot
.93 .39564 Mdot
.93 .3959 Mdot
.93 .39611 Mdot
.93 .39648 Mdot
.93 .39733 Mdot
.93 .39734 Mdot
.93 .39818 Mdot
.93 .39835 Mdot
.93 .39853 Mdot
.93 .39858 Mdot
.93 .3995 Mdot
.93 .39992 Mdot
.93 .40076 Mdot
.93 .40078 Mdot
.93 .40113 Mdot
.93 .4018 Mdot
.93 .40223 Mdot
.93 .40239 Mdot
.93 .40371 Mdot
.93 .40375 Mdot
.93 .40384 Mdot
.93 .40414 Mdot
.93 .40421 Mdot
.93 .40431 Mdot
.93 .40457 Mdot
.93 .40463 Mdot
.93 .4056 Mdot
.93 .40574 Mdot
.93 .4059 Mdot
.93 .40615 Mdot
.93 .40778 Mdot
.93 .40804 Mdot
.93 .40814 Mdot
.93 .40821 Mdot
.93 .40822 Mdot
.93 .40896 Mdot
.93 .40927 Mdot
.93 .40946 Mdot
.93 .40964 Mdot
.93 .40978 Mdot
.93 .41071 Mdot
.93 .41116 Mdot
.93 .41127 Mdot
.93 .41128 Mdot
.93 .41178 Mdot
.93 .41233 Mdot
.93 .41294 Mdot
.93 .41306 Mdot
.93 .41356 Mdot
.93 .41398 Mdot
.93 .41432 Mdot
.93 .41445 Mdot
.93 .4146 Mdot
.93 .41479 Mdot
.93 .41609 Mdot
.93 .41782 Mdot
.93 .41813 Mdot
.93 .41816 Mdot
.93 .41963 Mdot
.93 .42012 Mdot
.93 .42028 Mdot
.93 .42167 Mdot
.93 .42209 Mdot
.93 .42267 Mdot
.93 .42278 Mdot
.93 .42427 Mdot
.93 .42509 Mdot
.93 .42579 Mdot
.93 .42728 Mdot
.93 .42769 Mdot
.93 .42836 Mdot
.93 .4302 Mdot
.93 .43037 Mdot
.93 .43053 Mdot
.93 .4307 Mdot
.93 .43109 Mdot
.93 .43113 Mdot
.93 .43117 Mdot
.93 .43159 Mdot
.93 .4333 Mdot
.93 .43509 Mdot
.93 .43562 Mdot
.93 .43567 Mdot
.93 .43587 Mdot
.93 .4359 Mdot
.93 .43651 Mdot
.93 .43726 Mdot
.93 .43886 Mdot
.93 .43929 Mdot
.93 .44024 Mdot
.93 .44115 Mdot
.93 .44137 Mdot
.93 .44141 Mdot
.93 .44171 Mdot
.93 .44179 Mdot
.93 .44188 Mdot
.93 .44284 Mdot
.93 .44341 Mdot
.93 .44497 Mdot
.93 .44579 Mdot
.93 .44609 Mdot
.93 .44811 Mdot
.93 .44914 Mdot
.93 .44979 Mdot
.93 .44988 Mdot
.93 .44996 Mdot
.93 .45002 Mdot
.93 .45071 Mdot
.93 .45102 Mdot
.93 .45129 Mdot
.93 .4516 Mdot
.93 .45235 Mdot
.93 .45419 Mdot
.93 .45481 Mdot
.93 .45598 Mdot
.93 .45668 Mdot
.93 .45785 Mdot
.93 .45793 Mdot
.93 .45834 Mdot
.93 .45892 Mdot
.93 .45902 Mdot
.93 .45924 Mdot
.93 .46043 Mdot
.93 .46182 Mdot
.93 .46225 Mdot
.93 .46424 Mdot
.93 .46432 Mdot
.93 .46449 Mdot
.93 .46546 Mdot
.93 .46555 Mdot
.93 .46572 Mdot
.93 .46615 Mdot
.93 .46672 Mdot
.93 .46683 Mdot
.93 .46768 Mdot
.93 .46781 Mdot
.93 .46844 Mdot
.93 .46871 Mdot
.93 .46893 Mdot
.93 .4695 Mdot
.93 .47119 Mdot
.93 .47188 Mdot
.93 .47192 Mdot
.93 .47193 Mdot
.93 .47243 Mdot
.93 .47317 Mdot
.93 .47337 Mdot
.93 .47427 Mdot
.93 .47518 Mdot
.93 .47596 Mdot
.93 .47684 Mdot
.93 .47722 Mdot
.93 .47751 Mdot
.93 .47775 Mdot
.93 .47795 Mdot
.93 .47849 Mdot
.93 .47914 Mdot
.93 .47951 Mdot
.93 .4799 Mdot
.93 .48008 Mdot
.93 .48103 Mdot
.93 .48186 Mdot
.93 .48212 Mdot
.93 .48263 Mdot
.93 .48264 Mdot
.93 .4828 Mdot
.93 .48348 Mdot
.93 .48435 Mdot
.93 .4846 Mdot
.93 .48489 Mdot
.93 .4851 Mdot
.93 .48537 Mdot
.93 .48564 Mdot
.93 .48611 Mdot
.93 .48624 Mdot
.93 .48635 Mdot
.93 .48666 Mdot
.93 .48683 Mdot
.93 .4872 Mdot
.93 .48722 Mdot
.93 .48728 Mdot
.93 .48733 Mdot
.93 .48746 Mdot
.93 .48786 Mdot
.93 .48815 Mdot
.93 .48934 Mdot
.93 .48988 Mdot
.93 .49023 Mdot
.93 .49059 Mdot
.93 .49082 Mdot
.93 .49102 Mdot
.93 .49225 Mdot
.93 .49241 Mdot
.93 .4925 Mdot
.93 .49287 Mdot
.93 .49302 Mdot
.93 .49311 Mdot
.93 .49353 Mdot
.93 .49366 Mdot
.93 .49372 Mdot
.93 .49448 Mdot
.93 .49478 Mdot
.93 .49557 Mdot
.93 .4958 Mdot
.93 .49602 Mdot
.93 .4964 Mdot
.93 .49672 Mdot
.93 .49733 Mdot
.93 .4974 Mdot
.93 .4978 Mdot
.93 .49783 Mdot
.93 .49898 Mdot
.93 .49902 Mdot
.93 .49955 Mdot
.93 .49971 Mdot
.93 .50055 Mdot
.93 .5008 Mdot
.93 .50081 Mdot
.93 .50086 Mdot
.93 .5011 Mdot
.93 .50133 Mdot
.93 .50133 Mdot
.93 .50146 Mdot
.93 .50245 Mdot
.93 .50246 Mdot
.93 .50358 Mdot
.93 .50407 Mdot
.93 .50434 Mdot
.93 .50469 Mdot
.93 .50488 Mdot
.93 .50494 Mdot
.93 .50512 Mdot
.93 .50546 Mdot
.93 .5062 Mdot
.93 .50689 Mdot
.93 .507 Mdot
.93 .50728 Mdot
.93 .50767 Mdot
.93 .50772 Mdot
.93 .50773 Mdot
.93 .5079 Mdot
.93 .50817 Mdot
.93 .50878 Mdot
.93 .50923 Mdot
.93 .50975 Mdot
.93 .51005 Mdot
.93 .51016 Mdot
.93 .51029 Mdot
.93 .51099 Mdot
.93 .51136 Mdot
.93 .51153 Mdot
.93 .51178 Mdot
.93 .51181 Mdot
.93 .51183 Mdot
.93 .51196 Mdot
.93 .51219 Mdot
.93 .5124 Mdot
.93 .51245 Mdot
.93 .5125 Mdot
.93 .51293 Mdot
.93 .51336 Mdot
.93 .51496 Mdot
.93 .51592 Mdot
.93 .51607 Mdot
.93 .51717 Mdot
.93 .51721 Mdot
.93 .51781 Mdot
.93 .51794 Mdot
.93 .51796 Mdot
.93 .51807 Mdot
.93 .51816 Mdot
.93 .51817 Mdot
.93 .51859 Mdot
.93 .51872 Mdot
.93 .51874 Mdot
.93 .51937 Mdot
.93 .52012 Mdot
.93 .52092 Mdot
.93 .52095 Mdot
.93 .52108 Mdot
.93 .52116 Mdot
.93 .52148 Mdot
.93 .52157 Mdot
.93 .52165 Mdot
.93 .52261 Mdot
.93 .52353 Mdot
.93 .52354 Mdot
.93 .52368 Mdot
.93 .52393 Mdot
.93 .5242 Mdot
.93 .52448 Mdot
.93 .52524 Mdot
.93 .52537 Mdot
.93 .52543 Mdot
.93 .52594 Mdot
.93 .52616 Mdot
.93 .52634 Mdot
.93 .52637 Mdot
.93 .52645 Mdot
.93 .52665 Mdot
.93 .52666 Mdot
.93 .52706 Mdot
.93 .52786 Mdot
.93 .52829 Mdot
.93 .52847 Mdot
.93 .52887 Mdot
.93 .52895 Mdot
.93 .52911 Mdot
.93 .52957 Mdot
.93 .52976 Mdot
.93 .53021 Mdot
.93 .53133 Mdot
.93 .53137 Mdot
.93 .53151 Mdot
.93 .53158 Mdot
.93 .53181 Mdot
.93 .532 Mdot
.93 .53243 Mdot
.93 .53261 Mdot
.93 .5328 Mdot
.93 .53312 Mdot
.93 .5332 Mdot
.93 .53378 Mdot
.93 .53439 Mdot
.93 .53452 Mdot
.93 .53482 Mdot
.93 .53504 Mdot
.93 .53515 Mdot
.93 .53519 Mdot
.93 .53527 Mdot
.93 .53529 Mdot
.93 .5357 Mdot
.93 .53576 Mdot
.93 .5363 Mdot
.93 .53692 Mdot
.93 .53755 Mdot
.93 .53775 Mdot
.93 .53814 Mdot
.93 .53834 Mdot
.93 .53839 Mdot
.93 .53868 Mdot
.93 .53884 Mdot
.93 .53935 Mdot
.93 .5396 Mdot
.93 .53962 Mdot
.93 .53981 Mdot
.93 .53984 Mdot
.93 .54006 Mdot
.93 .54009 Mdot
.93 .54038 Mdot
.93 .54081 Mdot
.93 .5415 Mdot
.93 .54152 Mdot
.93 .54164 Mdot
.93 .54173 Mdot
.93 .54175 Mdot
.93 .54251 Mdot
.93 .54289 Mdot
.93 .54342 Mdot
.93 .54376 Mdot
.93 .54422 Mdot
.93 .54439 Mdot
.93 .5447 Mdot
.93 .54503 Mdot
.93 .54514 Mdot
.93 .5455 Mdot
.93 .5459 Mdot
.93 .54604 Mdot
.93 .54617 Mdot
.93 .54621 Mdot
.93 .54621 Mdot
.93 .54707 Mdot
.93 .54715 Mdot
.93 .54772 Mdot
.93 .54807 Mdot
.93 .5482 Mdot
.93 .54862 Mdot
.93 .54883 Mdot
.93 .54908 Mdot
.93 .54911 Mdot
.93 .5492 Mdot
.93 .54947 Mdot
.93 .54953 Mdot
.93 .55022 Mdot
.93 .55029 Mdot
.93 .55038 Mdot
.93 .5507 Mdot
.93 .5507 Mdot
.93 .5508 Mdot
.93 .55096 Mdot
.93 .55102 Mdot
.93 .55105 Mdot
.93 .5511 Mdot
.93 .55123 Mdot
.93 .55124 Mdot
.93 .55125 Mdot
.93 .55126 Mdot
.93 .55131 Mdot
.93 .5516 Mdot
.93 .55167 Mdot
.93 .55169 Mdot
.93 .55187 Mdot
.93 .55192 Mdot
.93 .55193 Mdot
.93 .55194 Mdot
.93 .552 Mdot
.93 .55201 Mdot
.93 .55202 Mdot
.93 .55225 Mdot
.93 .55235 Mdot
.93 .55246 Mdot
.93 .55253 Mdot
.93 .55267 Mdot
.93 .55274 Mdot
.93 .5529 Mdot
.93 .55291 Mdot
.93 .55311 Mdot
.93 .55326 Mdot
.93 .5534 Mdot
.93 .55342 Mdot
.93 .55345 Mdot
.93 .5536 Mdot
.93 .55369 Mdot
.93 .55374 Mdot
.93 .5538 Mdot
.93 .55382 Mdot
.93 .55394 Mdot
.93 .55412 Mdot
.93 .55414 Mdot
.93 .55423 Mdot
.93 .55431 Mdot
.93 .55434 Mdot
.93 .55435 Mdot
.93 .5544 Mdot
.93 .55443 Mdot
.93 .55443 Mdot
.93 .55444 Mdot
.93 .55478 Mdot
.93 .55493 Mdot
.93 .5552 Mdot
.93 .55531 Mdot
.93 .55551 Mdot
.93 .55574 Mdot
.93 .55602 Mdot
.93 .55602 Mdot
.93 .5563 Mdot
.93 .55631 Mdot
.93 .5565 Mdot
.93 .5565 Mdot
.93 .55656 Mdot
.93 .55676 Mdot
.93 .55689 Mdot
.93 .55696 Mdot
.93 .55699 Mdot
.93 .55725 Mdot
.93 .55728 Mdot
.93 .55736 Mdot
.93 .55743 Mdot
.93 .55776 Mdot
.93 .55779 Mdot
.93 .55784 Mdot
.93 .55788 Mdot
.93 .55799 Mdot
.93 .558 Mdot
.93 .55832 Mdot
.93 .55856 Mdot
.93 .55865 Mdot
.93 .55893 Mdot
.93 .55907 Mdot
.93 .55911 Mdot
.93 .55927 Mdot
.93 .55945 Mdot
.93 .55952 Mdot
.93 .55971 Mdot
.93 .55981 Mdot
.93 .56003 Mdot
.93 .56004 Mdot
.93 .56025 Mdot
.93 .56038 Mdot
.93 .56049 Mdot
.93 .5607 Mdot
.93 .5607 Mdot
.93 .5611 Mdot
.93 .56116 Mdot
.93 .56118 Mdot
.93 .5612 Mdot
.93 .56123 Mdot
.93 .56123 Mdot
.93 .56133 Mdot
.93 .56135 Mdot
.93 .5614 Mdot
.93 .56142 Mdot
.93 .56144 Mdot
.93 .56144 Mdot
.93 .56144 Mdot
.93 .56153 Mdot
.93 .56158 Mdot
.93 .56162 Mdot
.93 .56164 Mdot
.93 .56179 Mdot
.93 .56183 Mdot
.93 .56184 Mdot
.93 .56191 Mdot
.93 .56194 Mdot
.93 .56195 Mdot
.93 .56204 Mdot
.93 .56207 Mdot
.93 .56209 Mdot
.93 .56211 Mdot
.93 .56211 Mdot
.93 .56212 Mdot
.93 .56213 Mdot
.93 .56213 Mdot
.93 .56214 Mdot
.932 .13103 Mdot
.932 .13104 Mdot
.932 .13105 Mdot
.932 .13106 Mdot
.932 .13107 Mdot
.932 .13111 Mdot
.932 .13118 Mdot
.932 .1312 Mdot
.932 .13123 Mdot
.932 .13132 Mdot
.932 .13158 Mdot
.932 .1317 Mdot
.932 .13198 Mdot
.932 .13206 Mdot
.932 .13216 Mdot
.932 .13236 Mdot
.932 .13256 Mdot
.932 .13262 Mdot
.932 .13262 Mdot
.932 .13292 Mdot
.932 .13357 Mdot
.932 .13373 Mdot
.932 .13452 Mdot
.932 .13475 Mdot
.932 .13481 Mdot
.932 .13483 Mdot
.932 .13484 Mdot
.932 .13499 Mdot
.932 .13512 Mdot
.932 .13523 Mdot
.932 .13536 Mdot
.932 .13541 Mdot
.932 .13586 Mdot
.932 .13621 Mdot
.932 .13636 Mdot
.932 .13682 Mdot
.932 .13705 Mdot
.932 .13744 Mdot
.932 .1375 Mdot
.932 .13819 Mdot
.932 .13864 Mdot
.932 .13882 Mdot
.932 .13914 Mdot
.932 .13993 Mdot
.932 .1403 Mdot
.932 .1413 Mdot
.932 .14186 Mdot
.932 .14197 Mdot
.932 .14258 Mdot
.932 .14259 Mdot
.932 .14313 Mdot
.932 .14325 Mdot
.932 .14455 Mdot
.932 .14472 Mdot
.932 .14472 Mdot
.932 .14476 Mdot
.932 .14479 Mdot
.932 .14479 Mdot
.932 .14481 Mdot
.932 .14484 Mdot
.932 .14491 Mdot
.932 .14511 Mdot
.932 .14516 Mdot
.932 .14523 Mdot
.932 .14548 Mdot
.932 .14586 Mdot
.932 .14607 Mdot
.932 .14617 Mdot
.932 .14652 Mdot
.932 .1468 Mdot
.932 .14682 Mdot
.932 .14685 Mdot
.932 .14705 Mdot
.932 .14729 Mdot
.932 .14754 Mdot
.932 .14781 Mdot
.932 .14829 Mdot
.932 .1484 Mdot
.932 .14855 Mdot
.932 .14871 Mdot
.932 .14872 Mdot
.932 .14881 Mdot
.932 .14898 Mdot
.932 .14902 Mdot
.932 .14916 Mdot
.932 .14917 Mdot
.932 .15008 Mdot
.932 .15037 Mdot
.932 .15093 Mdot
.932 .15174 Mdot
.932 .15209 Mdot
.932 .15216 Mdot
.932 .15262 Mdot
.932 .15367 Mdot
.932 .1542 Mdot
.932 .15473 Mdot
.932 .15525 Mdot
.932 .15527 Mdot
.932 .15541 Mdot
.932 .15598 Mdot
.932 .15604 Mdot
.932 .15607 Mdot
.932 .15622 Mdot
.932 .15627 Mdot
.932 .15631 Mdot
.932 .15637 Mdot
.932 .15688 Mdot
.932 .15734 Mdot
.932 .15773 Mdot
.932 .15787 Mdot
.932 .158 Mdot
.932 .15822 Mdot
.932 .1584 Mdot
.932 .15865 Mdot
.932 .1597 Mdot
.932 .15999 Mdot
.932 .16003 Mdot
.932 .16035 Mdot
.932 .16062 Mdot
.932 .16114 Mdot
.932 .16126 Mdot
.932 .16133 Mdot
.932 .16144 Mdot
.932 .16164 Mdot
.932 .16169 Mdot
.932 .16191 Mdot
.932 .16335 Mdot
.932 .16366 Mdot
.932 .16369 Mdot
.932 .16432 Mdot
.932 .1646 Mdot
.932 .16546 Mdot
.932 .16613 Mdot
.932 .16614 Mdot
.932 .16638 Mdot
.932 .16741 Mdot
.932 .16822 Mdot
.932 .16926 Mdot
.932 .17053 Mdot
.932 .17117 Mdot
.932 .1712 Mdot
.932 .17192 Mdot
.932 .17303 Mdot
.932 .17331 Mdot
.932 .17332 Mdot
.932 .17509 Mdot
.932 .17683 Mdot
.932 .17791 Mdot
.932 .17847 Mdot
.932 .17852 Mdot
.932 .17988 Mdot
.932 .18013 Mdot
.932 .18201 Mdot
.932 .18324 Mdot
.932 .18594 Mdot
.932 .18647 Mdot
.932 .1876 Mdot
.932 .18832 Mdot
.932 .1887 Mdot
.932 .18951 Mdot
.932 .18956 Mdot
.932 .19121 Mdot
.932 .19134 Mdot
.932 .19233 Mdot
.932 .19243 Mdot
.932 .19292 Mdot
.932 .19313 Mdot
.932 .19321 Mdot
.932 .19353 Mdot
.932 .19475 Mdot
.932 .19545 Mdot
.932 .19575 Mdot
.932 .19645 Mdot
.932 .19674 Mdot
.932 .19865 Mdot
.932 .19931 Mdot
.932 .19936 Mdot
.932 .19976 Mdot
.932 .20035 Mdot
.932 .20065 Mdot
.932 .20069 Mdot
.932 .20089 Mdot
.932 .20104 Mdot
.932 .20108 Mdot
.932 .20117 Mdot
.932 .20131 Mdot
.932 .20132 Mdot
.932 .20168 Mdot
.932 .20279 Mdot
.932 .20306 Mdot
.932 .20346 Mdot
.932 .20449 Mdot
.932 .20482 Mdot
.932 .20578 Mdot
.932 .20692 Mdot
.932 .20742 Mdot
.932 .20808 Mdot
.932 .20811 Mdot
.932 .20851 Mdot
.932 .20869 Mdot
.932 .21065 Mdot
.932 .21149 Mdot
.932 .21223 Mdot
.932 .21229 Mdot
.932 .21236 Mdot
.932 .21252 Mdot
.932 .21368 Mdot
.932 .21453 Mdot
.932 .21468 Mdot
.932 .21507 Mdot
.932 .21651 Mdot
.932 .21812 Mdot
.932 .21991 Mdot
.932 .22096 Mdot
.932 .22114 Mdot
.932 .22158 Mdot
.932 .22164 Mdot
.932 .22247 Mdot
.932 .22287 Mdot
.932 .22303 Mdot
.932 .22344 Mdot
.932 .2235 Mdot
.932 .22404 Mdot
.932 .22505 Mdot
.932 .22533 Mdot
.932 .22616 Mdot
.932 .22621 Mdot
.932 .22731 Mdot
.932 .22801 Mdot
.932 .23179 Mdot
.932 .23345 Mdot
.932 .23358 Mdot
.932 .23419 Mdot
.932 .23495 Mdot
.932 .23641 Mdot
.932 .23705 Mdot
.932 .24194 Mdot
.932 .24219 Mdot
.932 .24376 Mdot
.932 .24382 Mdot
.932 .24446 Mdot
.932 .24492 Mdot
.932 .24696 Mdot
.932 .24783 Mdot
.932 .24814 Mdot
.932 .24976 Mdot
.932 .25041 Mdot
.932 .25225 Mdot
.932 .25265 Mdot
.932 .2546 Mdot
.932 .25473 Mdot
.932 .25772 Mdot
.932 .25823 Mdot
.932 .26176 Mdot
.932 .26523 Mdot
.932 .26537 Mdot
.932 .26635 Mdot
.932 .26844 Mdot
.932 .26956 Mdot
.932 .27023 Mdot
.932 .27062 Mdot
.932 .2708 Mdot
.932 .27181 Mdot
.932 .27184 Mdot
.932 .27207 Mdot
.932 .27214 Mdot
.932 .27247 Mdot
.932 .27286 Mdot
.932 .27305 Mdot
.932 .27372 Mdot
.932 .27422 Mdot
.932 .27532 Mdot
.932 .27542 Mdot
.932 .27548 Mdot
.932 .27634 Mdot
.932 .27817 Mdot
.932 .2791 Mdot
.932 .27952 Mdot
.932 .28057 Mdot
.932 .28074 Mdot
.932 .28116 Mdot
.932 .28219 Mdot
.932 .28238 Mdot
.932 .2824 Mdot
.932 .28321 Mdot
.932 .28412 Mdot
.932 .28416 Mdot
.932 .28438 Mdot
.932 .2856 Mdot
.932 .28571 Mdot
.932 .28624 Mdot
.932 .28687 Mdot
.932 .28755 Mdot
.932 .28863 Mdot
.932 .29033 Mdot
.932 .29054 Mdot
.932 .292 Mdot
.932 .29207 Mdot
.932 .29259 Mdot
.932 .29431 Mdot
.932 .296 Mdot
.932 .29611 Mdot
.932 .29802 Mdot
.932 .29836 Mdot
.932 .30058 Mdot
.932 .30074 Mdot
.932 .3022 Mdot
.932 .3025 Mdot
.932 .306 Mdot
.932 .3062 Mdot
.932 .30711 Mdot
.932 .30758 Mdot
.932 .30769 Mdot
.932 .30835 Mdot
.932 .30978 Mdot
.932 .31013 Mdot
.932 .3117 Mdot
.932 .31268 Mdot
.932 .31401 Mdot
.932 .31454 Mdot
.932 .31616 Mdot
.932 .31677 Mdot
.932 .31749 Mdot
.932 .31825 Mdot
.932 .32154 Mdot
.932 .32208 Mdot
.932 .32211 Mdot
.932 .32236 Mdot
.932 .32257 Mdot
.932 .32275 Mdot
.932 .32297 Mdot
.932 .32305 Mdot
.932 .32427 Mdot
.932 .32449 Mdot
.932 .32515 Mdot
.932 .32696 Mdot
.932 .32811 Mdot
.932 .32901 Mdot
.932 .33108 Mdot
.932 .3318 Mdot
.932 .33383 Mdot
.932 .33384 Mdot
.932 .33387 Mdot
.932 .3339 Mdot
.932 .33392 Mdot
.932 .334 Mdot
.932 .33419 Mdot
.932 .33423 Mdot
.932 .3343 Mdot
.932 .33451 Mdot
.932 .33503 Mdot
.932 .33512 Mdot
.932 .33542 Mdot
.932 .3357 Mdot
.932 .33607 Mdot
.932 .33628 Mdot
.932 .33651 Mdot
.932 .33698 Mdot
.932 .33711 Mdot
.932 .33724 Mdot
.932 .33724 Mdot
.932 .33745 Mdot
.932 .3376 Mdot
.932 .3376 Mdot
.932 .33832 Mdot
.932 .33957 Mdot
.932 .33983 Mdot
.932 .34021 Mdot
.932 .34097 Mdot
.932 .34135 Mdot
.932 .34207 Mdot
.932 .34209 Mdot
.932 .34219 Mdot
.932 .34262 Mdot
.932 .34277 Mdot
.932 .3428 Mdot
.932 .34284 Mdot
.932 .34318 Mdot
.932 .34349 Mdot
.932 .34374 Mdot
.932 .34392 Mdot
.932 .34406 Mdot
.932 .34418 Mdot
.932 .34522 Mdot
.932 .34542 Mdot
.932 .34603 Mdot
.932 .3461 Mdot
.932 .34639 Mdot
.932 .34746 Mdot
.932 .348 Mdot
.932 .34889 Mdot
.932 .34889 Mdot
.932 .34903 Mdot
.932 .35007 Mdot
.932 .35065 Mdot
.932 .35135 Mdot
.932 .35169 Mdot
.932 .35209 Mdot
.932 .35283 Mdot
.932 .35376 Mdot
.932 .35465 Mdot
.932 .35519 Mdot
.932 .35547 Mdot
.932 .3555 Mdot
.932 .35617 Mdot
.932 .3572 Mdot
.932 .35779 Mdot
.932 .35906 Mdot
.932 .35931 Mdot
.932 .36016 Mdot
.932 .3607 Mdot
.932 .36073 Mdot
.932 .36147 Mdot
.932 .36152 Mdot
.932 .36196 Mdot
.932 .36201 Mdot
.932 .36222 Mdot
.932 .36231 Mdot
.932 .36235 Mdot
.932 .36249 Mdot
.932 .36303 Mdot
.932 .36376 Mdot
.932 .36388 Mdot
.932 .36469 Mdot
.932 .36497 Mdot
.932 .36499 Mdot
.932 .36516 Mdot
.932 .36554 Mdot
.932 .36555 Mdot
.932 .36564 Mdot
.932 .3657 Mdot
.932 .36571 Mdot
.932 .36575 Mdot
.932 .36582 Mdot
.932 .36597 Mdot
.932 .36642 Mdot
.932 .36653 Mdot
.932 .3667 Mdot
.932 .36712 Mdot
.932 .36725 Mdot
.932 .3681 Mdot
.932 .36856 Mdot
.932 .36858 Mdot
.932 .36874 Mdot
.932 .36881 Mdot
.932 .36958 Mdot
.932 .3702 Mdot
.932 .37025 Mdot
.932 .37032 Mdot
.932 .37077 Mdot
.932 .37115 Mdot
.932 .3713 Mdot
.932 .37185 Mdot
.932 .37246 Mdot
.932 .37353 Mdot
.932 .37376 Mdot
.932 .37378 Mdot
.932 .37409 Mdot
.932 .37445 Mdot
.932 .37447 Mdot
.932 .37467 Mdot
.932 .37504 Mdot
.932 .37514 Mdot
.932 .37545 Mdot
.932 .37547 Mdot
.932 .37747 Mdot
.932 .37806 Mdot
.932 .37811 Mdot
.932 .37832 Mdot
.932 .37859 Mdot
.932 .3791 Mdot
.932 .37932 Mdot
.932 .3811 Mdot
.932 .38163 Mdot
.932 .38187 Mdot
.932 .38202 Mdot
.932 .38271 Mdot
.932 .383 Mdot
.932 .38365 Mdot
.932 .38525 Mdot
.932 .38529 Mdot
.932 .38643 Mdot
.932 .38757 Mdot
.932 .38868 Mdot
.932 .38872 Mdot
.932 .38903 Mdot
.932 .38969 Mdot
.932 .39025 Mdot
.932 .39038 Mdot
.932 .39043 Mdot
.932 .39076 Mdot
.932 .39083 Mdot
.932 .39086 Mdot
.932 .39096 Mdot
.932 .39108 Mdot
.932 .39114 Mdot
.932 .39135 Mdot
.932 .3915 Mdot
.932 .39188 Mdot
.932 .39216 Mdot
.932 .39314 Mdot
.932 .39346 Mdot
.932 .39351 Mdot
.932 .39364 Mdot
.932 .39395 Mdot
.932 .39402 Mdot
.932 .39427 Mdot
.932 .39454 Mdot
.932 .39499 Mdot
.932 .39538 Mdot
.932 .39591 Mdot
.932 .39694 Mdot
.932 .39761 Mdot
.932 .39811 Mdot
.932 .39871 Mdot
.932 .39881 Mdot
.932 .39946 Mdot
.932 .39951 Mdot
.932 .40003 Mdot
.932 .40111 Mdot
.932 .40138 Mdot
.932 .40151 Mdot
.932 .40174 Mdot
.932 .40215 Mdot
.932 .40225 Mdot
.932 .40271 Mdot
.932 .404 Mdot
.932 .40417 Mdot
.932 .4046 Mdot
.932 .40569 Mdot
.932 .40588 Mdot
.932 .40595 Mdot
.932 .40597 Mdot
.932 .40632 Mdot
.932 .40638 Mdot
.932 .40708 Mdot
.932 .40766 Mdot
.932 .40825 Mdot
.932 .40845 Mdot
.932 .40999 Mdot
.932 .41103 Mdot
.932 .41134 Mdot
.932 .41137 Mdot
.932 .41186 Mdot
.932 .41246 Mdot
.932 .41393 Mdot
.932 .41507 Mdot
.932 .41555 Mdot
.932 .41697 Mdot
.932 .41763 Mdot
.932 .41771 Mdot
.932 .42014 Mdot
.932 .42139 Mdot
.932 .42147 Mdot
.932 .42286 Mdot
.932 .42499 Mdot
.932 .42503 Mdot
.932 .42557 Mdot
.932 .42559 Mdot
.932 .42654 Mdot
.932 .42725 Mdot
.932 .42866 Mdot
.932 .42902 Mdot
.932 .42904 Mdot
.932 .42904 Mdot
.932 .43086 Mdot
.932 .43233 Mdot
.932 .43438 Mdot
.932 .43502 Mdot
.932 .43543 Mdot
.932 .43553 Mdot
.932 .43553 Mdot
.932 .43724 Mdot
.932 .43739 Mdot
.932 .43788 Mdot
.932 .43807 Mdot
.932 .43828 Mdot
.932 .43854 Mdot
.932 .43862 Mdot
.932 .43953 Mdot
.932 .43981 Mdot
.932 .442 Mdot
.932 .44295 Mdot
.932 .44295 Mdot
.932 .44315 Mdot
.932 .44388 Mdot
.932 .44425 Mdot
.932 .44505 Mdot
.932 .44875 Mdot
.932 .44913 Mdot
.932 .45008 Mdot
.932 .45138 Mdot
.932 .45208 Mdot
.932 .45335 Mdot
.932 .45403 Mdot
.932 .45457 Mdot
.932 .45458 Mdot
.932 .45461 Mdot
.932 .45524 Mdot
.932 .45544 Mdot
.932 .45553 Mdot
.932 .45769 Mdot
.932 .45838 Mdot
.932 .4586 Mdot
.932 .45892 Mdot
.932 .4603 Mdot
.932 .46048 Mdot
.932 .46054 Mdot
.932 .46057 Mdot
.932 .46131 Mdot
.932 .46149 Mdot
.932 .46156 Mdot
.932 .46166 Mdot
.932 .4618 Mdot
.932 .46234 Mdot
.932 .46441 Mdot
.932 .46515 Mdot
.932 .46558 Mdot
.932 .46607 Mdot
.932 .46723 Mdot
.932 .46747 Mdot
.932 .46759 Mdot
.932 .46771 Mdot
.932 .46965 Mdot
.932 .47083 Mdot
.932 .47192 Mdot
.932 .47199 Mdot
.932 .47264 Mdot
.932 .47358 Mdot
.932 .47359 Mdot
.932 .47372 Mdot
.932 .47408 Mdot
.932 .47413 Mdot
.932 .47446 Mdot
.932 .47469 Mdot
.932 .47475 Mdot
.932 .47477 Mdot
.932 .4749 Mdot
.932 .47512 Mdot
.932 .47514 Mdot
.932 .47572 Mdot
.932 .47702 Mdot
.932 .47747 Mdot
.932 .47777 Mdot
.932 .47789 Mdot
.932 .47852 Mdot
.932 .47956 Mdot
.932 .48011 Mdot
.932 .48062 Mdot
.932 .48182 Mdot
.932 .48211 Mdot
.932 .48275 Mdot
.932 .48349 Mdot
.932 .48353 Mdot
.932 .48385 Mdot
.932 .48401 Mdot
.932 .4846 Mdot
.932 .48559 Mdot
.932 .48559 Mdot
.932 .48565 Mdot
.932 .48624 Mdot
.932 .48652 Mdot
.932 .48787 Mdot
.932 .48818 Mdot
.932 .48904 Mdot
.932 .48942 Mdot
.932 .48989 Mdot
.932 .49065 Mdot
.932 .49092 Mdot
.932 .49101 Mdot
.932 .49151 Mdot
.932 .49155 Mdot
.932 .49164 Mdot
.932 .49171 Mdot
.932 .4918 Mdot
.932 .4919 Mdot
.932 .49191 Mdot
.932 .49214 Mdot
.932 .49349 Mdot
.932 .4938 Mdot
.932 .4941 Mdot
.932 .49434 Mdot
.932 .495 Mdot
.932 .49522 Mdot
.932 .49576 Mdot
.932 .49616 Mdot
.932 .4968 Mdot
.932 .49694 Mdot
.932 .49752 Mdot
.932 .49779 Mdot
.932 .49783 Mdot
.932 .49802 Mdot
.932 .49839 Mdot
.932 .49988 Mdot
.932 .49999 Mdot
.932 .50058 Mdot
.932 .50065 Mdot
.932 .50153 Mdot
.932 .50167 Mdot
.932 .50243 Mdot
.932 .50247 Mdot
.932 .50314 Mdot
.932 .50383 Mdot
.932 .50403 Mdot
.932 .50406 Mdot
.932 .50464 Mdot
.932 .50472 Mdot
.932 .50539 Mdot
.932 .50581 Mdot
.932 .50608 Mdot
.932 .50633 Mdot
.932 .50654 Mdot
.932 .50658 Mdot
.932 .50706 Mdot
.932 .50715 Mdot
.932 .50717 Mdot
.932 .50752 Mdot
.932 .50784 Mdot
.932 .50784 Mdot
.932 .50792 Mdot
.932 .50832 Mdot
.932 .50849 Mdot
.932 .50855 Mdot
.932 .50896 Mdot
.932 .50913 Mdot
.932 .50949 Mdot
.932 .5102 Mdot
.932 .51053 Mdot
.932 .51056 Mdot
.932 .5106 Mdot
.932 .51102 Mdot
.932 .51122 Mdot
.932 .51148 Mdot
.932 .51155 Mdot
.932 .5117 Mdot
.932 .51183 Mdot
.932 .51186 Mdot
.932 .51195 Mdot
.932 .51196 Mdot
.932 .51235 Mdot
.932 .51242 Mdot
.932 .51257 Mdot
.932 .51282 Mdot
.932 .51326 Mdot
.932 .51406 Mdot
.932 .51443 Mdot
.932 .51449 Mdot
.932 .51582 Mdot
.932 .51717 Mdot
.932 .51736 Mdot
.932 .5185 Mdot
.932 .51855 Mdot
.932 .51929 Mdot
.932 .51944 Mdot
.932 .52014 Mdot
.932 .52038 Mdot
.932 .52099 Mdot
.932 .52111 Mdot
.932 .52144 Mdot
.932 .52221 Mdot
.932 .52238 Mdot
.932 .52262 Mdot
.932 .52264 Mdot
.932 .52323 Mdot
.932 .52333 Mdot
.932 .52516 Mdot
.932 .5254 Mdot
.932 .52594 Mdot
.932 .52622 Mdot
.932 .52645 Mdot
.932 .5265 Mdot
.932 .52712 Mdot
.932 .52852 Mdot
.932 .52878 Mdot
.932 .52919 Mdot
.932 .52921 Mdot
.932 .52951 Mdot
.932 .52962 Mdot
.932 .52999 Mdot
.932 .53019 Mdot
.932 .53022 Mdot
.932 .53036 Mdot
.932 .53042 Mdot
.932 .53057 Mdot
.932 .53088 Mdot
.932 .5309 Mdot
.932 .53106 Mdot
.932 .53113 Mdot
.932 .53151 Mdot
.932 .53218 Mdot
.932 .53276 Mdot
.932 .5333 Mdot
.932 .53344 Mdot
.932 .53349 Mdot
.932 .5338 Mdot
.932 .53423 Mdot
.932 .53429 Mdot
.932 .53431 Mdot
.932 .53434 Mdot
.932 .53461 Mdot
.932 .53491 Mdot
.932 .53563 Mdot
.932 .5357 Mdot
.932 .53584 Mdot
.932 .53585 Mdot
.932 .53609 Mdot
.932 .53627 Mdot
.932 .53669 Mdot
.932 .53704 Mdot
.932 .53716 Mdot
.932 .53754 Mdot
.932 .53768 Mdot
.932 .53778 Mdot
.932 .53818 Mdot
.932 .53831 Mdot
.932 .53832 Mdot
.932 .53837 Mdot
.932 .5384 Mdot
.932 .53841 Mdot
.932 .53847 Mdot
.932 .53854 Mdot
.932 .53855 Mdot
.932 .53866 Mdot
.932 .53888 Mdot
.932 .53902 Mdot
.932 .53904 Mdot
.932 .53928 Mdot
.932 .53997 Mdot
.932 .54008 Mdot
.932 .54033 Mdot
.932 .54044 Mdot
.932 .54069 Mdot
.932 .54114 Mdot
.932 .54125 Mdot
.932 .54128 Mdot
.932 .54135 Mdot
.932 .54153 Mdot
.932 .54157 Mdot
.932 .54193 Mdot
.932 .54197 Mdot
.932 .54257 Mdot
.932 .54258 Mdot
.932 .54288 Mdot
.932 .54301 Mdot
.932 .54327 Mdot
.932 .54368 Mdot
.932 .54387 Mdot
.932 .54484 Mdot
.932 .54528 Mdot
.932 .54595 Mdot
.932 .54605 Mdot
.932 .54653 Mdot
.932 .54655 Mdot
.932 .54675 Mdot
.932 .54714 Mdot
.932 .54776 Mdot
.932 .54839 Mdot
.932 .54839 Mdot
.932 .54849 Mdot
.932 .54889 Mdot
.932 .54914 Mdot
.932 .54916 Mdot
.932 .54938 Mdot
.932 .54984 Mdot
.932 .55021 Mdot
.932 .55049 Mdot
.932 .55086 Mdot
.932 .55095 Mdot
.932 .55095 Mdot
.932 .55119 Mdot
.932 .55149 Mdot
.932 .55159 Mdot
.932 .55182 Mdot
.932 .55183 Mdot
.932 .55193 Mdot
.932 .55245 Mdot
.932 .55253 Mdot
.932 .55254 Mdot
.932 .55261 Mdot
.932 .55265 Mdot
.932 .55268 Mdot
.932 .55272 Mdot
.932 .55291 Mdot
.932 .553 Mdot
.932 .55311 Mdot
.932 .55313 Mdot
.932 .55323 Mdot
.932 .5536 Mdot
.932 .55369 Mdot
.932 .55376 Mdot
.932 .55383 Mdot
.932 .55388 Mdot
.932 .55393 Mdot
.932 .55407 Mdot
.932 .55423 Mdot
.932 .55441 Mdot
.932 .55443 Mdot
.932 .55445 Mdot
.932 .55446 Mdot
.932 .55452 Mdot
.932 .55452 Mdot
.932 .55454 Mdot
.932 .55475 Mdot
.932 .5548 Mdot
.932 .55481 Mdot
.932 .55499 Mdot
.932 .55518 Mdot
.932 .55536 Mdot
.932 .55573 Mdot
.932 .55589 Mdot
.932 .55592 Mdot
.932 .55604 Mdot
.932 .55633 Mdot
.932 .55653 Mdot
.932 .55663 Mdot
.932 .55695 Mdot
.932 .55695 Mdot
.932 .557 Mdot
.932 .55702 Mdot
.932 .55708 Mdot
.932 .55711 Mdot
.932 .55711 Mdot
.932 .55717 Mdot
.932 .55722 Mdot
.932 .55726 Mdot
.932 .55743 Mdot
.932 .55752 Mdot
.932 .55761 Mdot
.932 .5577 Mdot
.932 .55777 Mdot
.932 .55778 Mdot
.932 .55778 Mdot
.932 .55788 Mdot
.932 .558 Mdot
.932 .55804 Mdot
.932 .55812 Mdot
.932 .55825 Mdot
.932 .55834 Mdot
.932 .55836 Mdot
.932 .55838 Mdot
.932 .55845 Mdot
.932 .55847 Mdot
.932 .55848 Mdot
.932 .55849 Mdot
.932 .55849 Mdot
.932 .5585 Mdot
.932 .55851 Mdot
.932 .55852 Mdot
.932 .55858 Mdot
.932 .55903 Mdot
.932 .55907 Mdot
.932 .55926 Mdot
.932 .55927 Mdot
.932 .55948 Mdot
.932 .55952 Mdot
.932 .55972 Mdot
.932 .56007 Mdot
.932 .5602 Mdot
.932 .56047 Mdot
.932 .56059 Mdot
.932 .56065 Mdot
.932 .56081 Mdot
.932 .56105 Mdot
.932 .56107 Mdot
.932 .56121 Mdot
.932 .56129 Mdot
.932 .56145 Mdot
.932 .5615 Mdot
.932 .56162 Mdot
.932 .56178 Mdot
.932 .5618 Mdot
.932 .56185 Mdot
.932 .56188 Mdot
.932 .56193 Mdot
.932 .56198 Mdot
.932 .56199 Mdot
.932 .56199 Mdot
.932 .56201 Mdot
.932 .56209 Mdot
.932 .56237 Mdot
.932 .56243 Mdot
.932 .56265 Mdot
.932 .56276 Mdot
.932 .56276 Mdot
.932 .56278 Mdot
.932 .56285 Mdot
.932 .56292 Mdot
.932 .56295 Mdot
.932 .56298 Mdot
.932 .56308 Mdot
.932 .56312 Mdot
.932 .56321 Mdot
.932 .56324 Mdot
.932 .56325 Mdot
.932 .56326 Mdot
.932 .56329 Mdot
.932 .5633 Mdot
.932 .5633 Mdot
.932 .56331 Mdot
.932 .56331 Mdot
.932 .56331 Mdot
.934 .12796 Mdot
.934 .12804 Mdot
.934 .1281 Mdot
.934 .12815 Mdot
.934 .12822 Mdot
.934 .12827 Mdot
.934 .1283 Mdot
.934 .12836 Mdot
.934 .1285 Mdot
.934 .12872 Mdot
.934 .12873 Mdot
.934 .12933 Mdot
.934 .12964 Mdot
.934 .12974 Mdot
.934 .12974 Mdot
.934 .12981 Mdot
.934 .1299 Mdot
.934 .13018 Mdot
.934 .13143 Mdot
.934 .13157 Mdot
.934 .13171 Mdot
.934 .13185 Mdot
.934 .13238 Mdot
.934 .13361 Mdot
.934 .13362 Mdot
.934 .13474 Mdot
.934 .13478 Mdot
.934 .13488 Mdot
.934 .13526 Mdot
.934 .13533 Mdot
.934 .13542 Mdot
.934 .13553 Mdot
.934 .13562 Mdot
.934 .13576 Mdot
.934 .13586 Mdot
.934 .13593 Mdot
.934 .13606 Mdot
.934 .13635 Mdot
.934 .13637 Mdot
.934 .13659 Mdot
.934 .13681 Mdot
.934 .13684 Mdot
.934 .13741 Mdot
.934 .13774 Mdot
.934 .13777 Mdot
.934 .13784 Mdot
.934 .13787 Mdot
.934 .13817 Mdot
.934 .13827 Mdot
.934 .1389 Mdot
.934 .13913 Mdot
.934 .13913 Mdot
.934 .13929 Mdot
.934 .13946 Mdot
.934 .13951 Mdot
.934 .13991 Mdot
.934 .14021 Mdot
.934 .14093 Mdot
.934 .14095 Mdot
.934 .14114 Mdot
.934 .1423 Mdot
.934 .14233 Mdot
.934 .14241 Mdot
.934 .14352 Mdot
.934 .14392 Mdot
.934 .14432 Mdot
.934 .14472 Mdot
.934 .14482 Mdot
.934 .14491 Mdot
.934 .14631 Mdot
.934 .14646 Mdot
.934 .14709 Mdot
.934 .14791 Mdot
.934 .14952 Mdot
.934 .15 Mdot
.934 .1502 Mdot
.934 .15024 Mdot
.934 .15038 Mdot
.934 .1504 Mdot
.934 .15148 Mdot
.934 .15176 Mdot
.934 .15409 Mdot
.934 .15422 Mdot
.934 .15445 Mdot
.934 .15459 Mdot
.934 .15496 Mdot
.934 .15497 Mdot
.934 .15597 Mdot
.934 .15608 Mdot
.934 .15622 Mdot
.934 .1564 Mdot
.934 .15655 Mdot
.934 .15695 Mdot
.934 .15699 Mdot
.934 .15721 Mdot
.934 .1573 Mdot
.934 .15754 Mdot
.934 .15784 Mdot
.934 .15803 Mdot
.934 .15823 Mdot
.934 .15848 Mdot
.934 .15887 Mdot
.934 .15896 Mdot
.934 .15959 Mdot
.934 .15963 Mdot
.934 .16009 Mdot
.934 .16012 Mdot
.934 .16018 Mdot
.934 .16056 Mdot
.934 .16094 Mdot
.934 .16104 Mdot
.934 .16193 Mdot
.934 .16203 Mdot
.934 .1636 Mdot
.934 .1638 Mdot
.934 .16436 Mdot
.934 .16576 Mdot
.934 .16586 Mdot
.934 .16618 Mdot
.934 .16631 Mdot
.934 .16636 Mdot
.934 .1664 Mdot
.934 .16662 Mdot
.934 .16756 Mdot
.934 .16767 Mdot
.934 .16799 Mdot
.934 .16857 Mdot
.934 .16905 Mdot
.934 .17077 Mdot
.934 .17098 Mdot
.934 .17103 Mdot
.934 .17144 Mdot
.934 .17178 Mdot
.934 .1723 Mdot
.934 .17252 Mdot
.934 .17261 Mdot
.934 .17329 Mdot
.934 .17349 Mdot
.934 .17358 Mdot
.934 .17365 Mdot
.934 .17406 Mdot
.934 .17423 Mdot
.934 .17514 Mdot
.934 .17534 Mdot
.934 .1766 Mdot
.934 .17674 Mdot
.934 .17734 Mdot
.934 .17742 Mdot
.934 .17875 Mdot
.934 .17892 Mdot
.934 .17902 Mdot
.934 .18019 Mdot
.934 .18028 Mdot
.934 .18073 Mdot
.934 .18119 Mdot
.934 .18416 Mdot
.934 .18488 Mdot
.934 .18558 Mdot
.934 .18573 Mdot
.934 .18609 Mdot
.934 .18696 Mdot
.934 .18712 Mdot
.934 .18752 Mdot
.934 .18814 Mdot
.934 .18856 Mdot
.934 .18895 Mdot
.934 .18926 Mdot
.934 .18933 Mdot
.934 .18991 Mdot
.934 .19067 Mdot
.934 .19135 Mdot
.934 .19318 Mdot
.934 .19331 Mdot
.934 .19433 Mdot
.934 .19546 Mdot
.934 .19618 Mdot
.934 .19631 Mdot
.934 .19678 Mdot
.934 .19759 Mdot
.934 .19801 Mdot
.934 .19901 Mdot
.934 .19933 Mdot
.934 .19979 Mdot
.934 .20034 Mdot
.934 .20064 Mdot
.934 .20085 Mdot
.934 .2009 Mdot
.934 .20126 Mdot
.934 .20211 Mdot
.934 .20302 Mdot
.934 .2032 Mdot
.934 .20348 Mdot
.934 .20384 Mdot
.934 .20479 Mdot
.934 .20495 Mdot
.934 .20743 Mdot
.934 .20873 Mdot
.934 .20901 Mdot
.934 .20959 Mdot
.934 .21179 Mdot
.934 .21328 Mdot
.934 .2144 Mdot
.934 .21819 Mdot
.934 .21849 Mdot
.934 .22301 Mdot
.934 .22475 Mdot
.934 .22665 Mdot
.934 .22751 Mdot
.934 .22799 Mdot
.934 .22877 Mdot
.934 .22925 Mdot
.934 .22978 Mdot
.934 .23102 Mdot
.934 .23154 Mdot
.934 .23182 Mdot
.934 .23223 Mdot
.934 .23249 Mdot
.934 .23291 Mdot
.934 .23309 Mdot
.934 .2334 Mdot
.934 .23351 Mdot
.934 .23418 Mdot
.934 .23698 Mdot
.934 .23791 Mdot
.934 .2397 Mdot
.934 .24041 Mdot
.934 .2406 Mdot
.934 .24122 Mdot
.934 .2422 Mdot
.934 .24283 Mdot
.934 .24808 Mdot
.934 .24974 Mdot
.934 .25012 Mdot
.934 .25026 Mdot
.934 .25045 Mdot
.934 .25141 Mdot
.934 .25195 Mdot
.934 .25301 Mdot
.934 .25326 Mdot
.934 .25404 Mdot
.934 .25532 Mdot
.934 .25595 Mdot
.934 .2562 Mdot
.934 .25765 Mdot
.934 .25781 Mdot
.934 .25852 Mdot
.934 .26012 Mdot
.934 .26106 Mdot
.934 .2617 Mdot
.934 .26174 Mdot
.934 .2621 Mdot
.934 .26337 Mdot
.934 .26357 Mdot
.934 .26361 Mdot
.934 .2647 Mdot
.934 .26491 Mdot
.934 .26621 Mdot
.934 .26669 Mdot
.934 .26738 Mdot
.934 .26741 Mdot
.934 .26883 Mdot
.934 .26895 Mdot
.934 .27049 Mdot
.934 .27127 Mdot
.934 .27173 Mdot
.934 .27224 Mdot
.934 .27346 Mdot
.934 .27451 Mdot
.934 .27729 Mdot
.934 .27756 Mdot
.934 .27791 Mdot
.934 .27909 Mdot
.934 .27972 Mdot
.934 .28145 Mdot
.934 .28357 Mdot
.934 .28366 Mdot
.934 .28471 Mdot
.934 .2849 Mdot
.934 .2863 Mdot
.934 .28804 Mdot
.934 .28807 Mdot
.934 .28934 Mdot
.934 .29082 Mdot
.934 .29138 Mdot
.934 .29151 Mdot
.934 .29305 Mdot
.934 .296 Mdot
.934 .29624 Mdot
.934 .29649 Mdot
.934 .29894 Mdot
.934 .29959 Mdot
.934 .2998 Mdot
.934 .29997 Mdot
.934 .3002 Mdot
.934 .30292 Mdot
.934 .30297 Mdot
.934 .30569 Mdot
.934 .30601 Mdot
.934 .30644 Mdot
.934 .30725 Mdot
.934 .31282 Mdot
.934 .31311 Mdot
.934 .31327 Mdot
.934 .31359 Mdot
.934 .31424 Mdot
.934 .31702 Mdot
.934 .31809 Mdot
.934 .3223 Mdot
.934 .32317 Mdot
.934 .32499 Mdot
.934 .3265 Mdot
.934 .32715 Mdot
.934 .32734 Mdot
.934 .32747 Mdot
.934 .32759 Mdot
.934 .32776 Mdot
.934 .32788 Mdot
.934 .32796 Mdot
.934 .32811 Mdot
.934 .32845 Mdot
.934 .32847 Mdot
.934 .32897 Mdot
.934 .329 Mdot
.934 .32963 Mdot
.934 .3301 Mdot
.934 .33013 Mdot
.934 .33044 Mdot
.934 .33054 Mdot
.934 .33119 Mdot
.934 .33142 Mdot
.934 .33142 Mdot
.934 .33158 Mdot
.934 .3318 Mdot
.934 .33219 Mdot
.934 .33248 Mdot
.934 .33318 Mdot
.934 .33442 Mdot
.934 .33545 Mdot
.934 .33579 Mdot
.934 .33612 Mdot
.934 .33646 Mdot
.934 .33654 Mdot
.934 .33773 Mdot
.934 .33784 Mdot
.934 .34064 Mdot
.934 .34066 Mdot
.934 .34078 Mdot
.934 .34154 Mdot
.934 .34173 Mdot
.934 .3433 Mdot
.934 .34339 Mdot
.934 .34364 Mdot
.934 .34388 Mdot
.934 .34388 Mdot
.934 .34452 Mdot
.934 .34469 Mdot
.934 .3448 Mdot
.934 .34489 Mdot
.934 .34514 Mdot
.934 .34517 Mdot
.934 .34531 Mdot
.934 .34536 Mdot
.934 .34551 Mdot
.934 .3457 Mdot
.934 .34594 Mdot
.934 .34609 Mdot
.934 .34639 Mdot
.934 .34677 Mdot
.934 .34707 Mdot
.934 .34709 Mdot
.934 .34712 Mdot
.934 .34735 Mdot
.934 .34763 Mdot
.934 .34815 Mdot
.934 .34821 Mdot
.934 .34954 Mdot
.934 .35032 Mdot
.934 .35038 Mdot
.934 .35055 Mdot
.934 .35062 Mdot
.934 .35079 Mdot
.934 .35131 Mdot
.934 .35154 Mdot
.934 .35211 Mdot
.934 .35301 Mdot
.934 .35312 Mdot
.934 .35353 Mdot
.934 .3538 Mdot
.934 .35391 Mdot
.934 .35396 Mdot
.934 .35431 Mdot
.934 .3544 Mdot
.934 .35478 Mdot
.934 .35523 Mdot
.934 .35533 Mdot
.934 .35602 Mdot
.934 .35708 Mdot
.934 .35713 Mdot
.934 .35768 Mdot
.934 .35773 Mdot
.934 .35816 Mdot
.934 .35986 Mdot
.934 .36018 Mdot
.934 .3608 Mdot
.934 .36088 Mdot
.934 .36106 Mdot
.934 .36133 Mdot
.934 .36152 Mdot
.934 .36169 Mdot
.934 .36182 Mdot
.934 .36244 Mdot
.934 .36353 Mdot
.934 .36358 Mdot
.934 .3645 Mdot
.934 .36485 Mdot
.934 .36539 Mdot
.934 .36556 Mdot
.934 .36598 Mdot
.934 .3663 Mdot
.934 .36652 Mdot
.934 .36673 Mdot
.934 .36675 Mdot
.934 .3669 Mdot
.934 .36724 Mdot
.934 .36838 Mdot
.934 .36936 Mdot
.934 .36987 Mdot
.934 .3702 Mdot
.934 .37105 Mdot
.934 .37162 Mdot
.934 .37204 Mdot
.934 .37346 Mdot
.934 .37357 Mdot
.934 .37653 Mdot
.934 .37701 Mdot
.934 .37729 Mdot
.934 .37808 Mdot
.934 .37826 Mdot
.934 .37851 Mdot
.934 .37859 Mdot
.934 .37874 Mdot
.934 .3788 Mdot
.934 .37891 Mdot
.934 .37895 Mdot
.934 .37918 Mdot
.934 .38047 Mdot
.934 .38132 Mdot
.934 .38138 Mdot
.934 .38159 Mdot
.934 .38192 Mdot
.934 .38213 Mdot
.934 .38442 Mdot
.934 .3846 Mdot
.934 .38549 Mdot
.934 .38644 Mdot
.934 .38699 Mdot
.934 .38727 Mdot
.934 .38778 Mdot
.934 .38808 Mdot
.934 .38829 Mdot
.934 .38841 Mdot
.934 .38887 Mdot
.934 .38888 Mdot
.934 .38922 Mdot
.934 .3897 Mdot
.934 .38985 Mdot
.934 .39006 Mdot
.934 .39051 Mdot
.934 .39103 Mdot
.934 .39127 Mdot
.934 .39157 Mdot
.934 .39195 Mdot
.934 .39227 Mdot
.934 .39312 Mdot
.934 .3932 Mdot
.934 .39367 Mdot
.934 .39386 Mdot
.934 .39438 Mdot
.934 .39502 Mdot
.934 .39536 Mdot
.934 .39542 Mdot
.934 .39584 Mdot
.934 .39636 Mdot
.934 .39636 Mdot
.934 .39674 Mdot
.934 .39718 Mdot
.934 .39735 Mdot
.934 .39739 Mdot
.934 .39784 Mdot
.934 .39871 Mdot
.934 .39878 Mdot
.934 .39885 Mdot
.934 .39976 Mdot
.934 .39982 Mdot
.934 .39994 Mdot
.934 .40073 Mdot
.934 .40074 Mdot
.934 .40153 Mdot
.934 .40162 Mdot
.934 .40175 Mdot
.934 .40198 Mdot
.934 .40358 Mdot
.934 .40371 Mdot
.934 .4038 Mdot
.934 .40399 Mdot
.934 .40508 Mdot
.934 .40652 Mdot
.934 .40703 Mdot
.934 .40746 Mdot
.934 .40801 Mdot
.934 .40833 Mdot
.934 .40847 Mdot
.934 .40859 Mdot
.934 .40968 Mdot
.934 .41027 Mdot
.934 .41144 Mdot
.934 .41165 Mdot
.934 .41171 Mdot
.934 .4123 Mdot
.934 .4123 Mdot
.934 .41256 Mdot
.934 .41266 Mdot
.934 .4127 Mdot
.934 .41276 Mdot
.934 .41319 Mdot
.934 .41509 Mdot
.934 .41531 Mdot
.934 .41544 Mdot
.934 .41596 Mdot
.934 .41671 Mdot
.934 .41711 Mdot
.934 .41725 Mdot
.934 .41808 Mdot
.934 .41839 Mdot
.934 .4186 Mdot
.934 .41864 Mdot
.934 .41931 Mdot
.934 .41977 Mdot
.934 .42148 Mdot
.934 .4219 Mdot
.934 .422 Mdot
.934 .42235 Mdot
.934 .42266 Mdot
.934 .42281 Mdot
.934 .42343 Mdot
.934 .42348 Mdot
.934 .42399 Mdot
.934 .42449 Mdot
.934 .42452 Mdot
.934 .42492 Mdot
.934 .42498 Mdot
.934 .4251 Mdot
.934 .42643 Mdot
.934 .42681 Mdot
.934 .42698 Mdot
.934 .42711 Mdot
.934 .42791 Mdot
.934 .42825 Mdot
.934 .43 Mdot
.934 .43004 Mdot
.934 .43037 Mdot
.934 .43121 Mdot
.934 .43279 Mdot
.934 .43285 Mdot
.934 .43286 Mdot
.934 .43305 Mdot
.934 .43399 Mdot
.934 .4342 Mdot
.934 .43436 Mdot
.934 .43451 Mdot
.934 .43464 Mdot
.934 .43606 Mdot
.934 .4364 Mdot
.934 .43686 Mdot
.934 .43718 Mdot
.934 .43737 Mdot
.934 .43956 Mdot
.934 .43973 Mdot
.934 .44049 Mdot
.934 .44055 Mdot
.934 .44083 Mdot
.934 .44142 Mdot
.934 .44143 Mdot
.934 .44229 Mdot
.934 .4429 Mdot
.934 .44551 Mdot
.934 .44574 Mdot
.934 .44602 Mdot
.934 .4463 Mdot
.934 .44669 Mdot
.934 .44685 Mdot
.934 .44815 Mdot
.934 .44839 Mdot
.934 .44872 Mdot
.934 .44874 Mdot
.934 .44885 Mdot
.934 .44942 Mdot
.934 .44969 Mdot
.934 .45032 Mdot
.934 .45168 Mdot
.934 .45188 Mdot
.934 .45217 Mdot
.934 .45288 Mdot
.934 .45317 Mdot
.934 .45376 Mdot
.934 .45382 Mdot
.934 .45398 Mdot
.934 .45471 Mdot
.934 .45541 Mdot
.934 .45594 Mdot
.934 .45607 Mdot
.934 .4569 Mdot
.934 .45707 Mdot
.934 .4575 Mdot
.934 .4584 Mdot
.934 .45888 Mdot
.934 .45911 Mdot
.934 .4594 Mdot
.934 .45958 Mdot
.934 .46005 Mdot
.934 .46233 Mdot
.934 .46254 Mdot
.934 .46264 Mdot
.934 .46271 Mdot
.934 .46293 Mdot
.934 .46331 Mdot
.934 .46336 Mdot
.934 .46422 Mdot
.934 .46466 Mdot
.934 .46507 Mdot
.934 .46515 Mdot
.934 .46621 Mdot
.934 .46645 Mdot
.934 .46655 Mdot
.934 .46697 Mdot
.934 .46755 Mdot
.934 .46773 Mdot
.934 .46775 Mdot
.934 .46797 Mdot
.934 .46841 Mdot
.934 .46875 Mdot
.934 .47009 Mdot
.934 .47078 Mdot
.934 .47123 Mdot
.934 .47198 Mdot
.934 .47241 Mdot
.934 .47292 Mdot
.934 .47307 Mdot
.934 .47314 Mdot
.934 .47348 Mdot
.934 .47366 Mdot
.934 .47398 Mdot
.934 .47456 Mdot
.934 .47504 Mdot
.934 .47531 Mdot
.934 .47537 Mdot
.934 .47545 Mdot
.934 .47553 Mdot
.934 .47603 Mdot
.934 .47617 Mdot
.934 .47737 Mdot
.934 .47739 Mdot
.934 .47819 Mdot
.934 .47839 Mdot
.934 .47875 Mdot
.934 .47881 Mdot
.934 .47911 Mdot
.934 .47955 Mdot
.934 .48011 Mdot
.934 .48159 Mdot
.934 .48171 Mdot
.934 .48184 Mdot
.934 .48237 Mdot
.934 .48246 Mdot
.934 .48252 Mdot
.934 .48268 Mdot
.934 .48307 Mdot
.934 .48307 Mdot
.934 .48398 Mdot
.934 .48407 Mdot
.934 .48439 Mdot
.934 .48563 Mdot
.934 .48618 Mdot
.934 .48706 Mdot
.934 .48759 Mdot
.934 .488 Mdot
.934 .48868 Mdot
.934 .48886 Mdot
.934 .48887 Mdot
.934 .48906 Mdot
.934 .48955 Mdot
.934 .49036 Mdot
.934 .49099 Mdot
.934 .49174 Mdot
.934 .4921 Mdot
.934 .49382 Mdot
.934 .49426 Mdot
.934 .49539 Mdot
.934 .49565 Mdot
.934 .49578 Mdot
.934 .49585 Mdot
.934 .49597 Mdot
.934 .49822 Mdot
.934 .49854 Mdot
.934 .49871 Mdot
.934 .49885 Mdot
.934 .49993 Mdot
.934 .49995 Mdot
.934 .50104 Mdot
.934 .50113 Mdot
.934 .5012 Mdot
.934 .50128 Mdot
.934 .50154 Mdot
.934 .50252 Mdot
.934 .50262 Mdot
.934 .50271 Mdot
.934 .50388 Mdot
.934 .50449 Mdot
.934 .50454 Mdot
.934 .50476 Mdot
.934 .50534 Mdot
.934 .50584 Mdot
.934 .50585 Mdot
.934 .50653 Mdot
.934 .50708 Mdot
.934 .50716 Mdot
.934 .50757 Mdot
.934 .50761 Mdot
.934 .50843 Mdot
.934 .5091 Mdot
.934 .50935 Mdot
.934 .50981 Mdot
.934 .50994 Mdot
.934 .51005 Mdot
.934 .51112 Mdot
.934 .51153 Mdot
.934 .512 Mdot
.934 .5122 Mdot
.934 .51238 Mdot
.934 .51268 Mdot
.934 .51327 Mdot
.934 .51332 Mdot
.934 .51386 Mdot
.934 .51387 Mdot
.934 .51414 Mdot
.934 .51432 Mdot
.934 .51482 Mdot
.934 .5149 Mdot
.934 .51532 Mdot
.934 .51533 Mdot
.934 .51541 Mdot
.934 .51589 Mdot
.934 .51603 Mdot
.934 .51604 Mdot
.934 .51629 Mdot
.934 .51665 Mdot
.934 .51725 Mdot
.934 .51753 Mdot
.934 .51759 Mdot
.934 .51814 Mdot
.934 .51823 Mdot
.934 .51847 Mdot
.934 .51896 Mdot
.934 .51925 Mdot
.934 .51935 Mdot
.934 .51975 Mdot
.934 .51995 Mdot
.934 .52031 Mdot
.934 .52038 Mdot
.934 .52044 Mdot
.934 .52058 Mdot
.934 .5212 Mdot
.934 .52318 Mdot
.934 .52341 Mdot
.934 .52378 Mdot
.934 .52401 Mdot
.934 .52408 Mdot
.934 .52435 Mdot
.934 .52502 Mdot
.934 .52536 Mdot
.934 .5264 Mdot
.934 .52665 Mdot
.934 .52669 Mdot
.934 .52681 Mdot
.934 .52688 Mdot
.934 .52703 Mdot
.934 .52713 Mdot
.934 .52728 Mdot
.934 .52739 Mdot
.934 .52758 Mdot
.934 .52804 Mdot
.934 .52823 Mdot
.934 .52841 Mdot
.934 .5287 Mdot
.934 .52888 Mdot
.934 .5292 Mdot
.934 .5299 Mdot
.934 .53054 Mdot
.934 .5322 Mdot
.934 .53231 Mdot
.934 .5337 Mdot
.934 .53411 Mdot
.934 .53465 Mdot
.934 .53545 Mdot
.934 .53567 Mdot
.934 .53577 Mdot
.934 .53624 Mdot
.934 .53714 Mdot
.934 .5372 Mdot
.934 .53754 Mdot
.934 .53767 Mdot
.934 .53784 Mdot
.934 .53817 Mdot
.934 .53848 Mdot
.934 .53861 Mdot
.934 .53863 Mdot
.934 .5387 Mdot
.934 .53881 Mdot
.934 .53901 Mdot
.934 .53918 Mdot
.934 .53929 Mdot
.934 .53965 Mdot
.934 .53981 Mdot
.934 .5401 Mdot
.934 .54027 Mdot
.934 .54032 Mdot
.934 .54058 Mdot
.934 .54098 Mdot
.934 .54135 Mdot
.934 .5414 Mdot
.934 .54206 Mdot
.934 .5423 Mdot
.934 .54258 Mdot
.934 .54278 Mdot
.934 .54281 Mdot
.934 .54292 Mdot
.934 .54306 Mdot
.934 .54321 Mdot
.934 .54343 Mdot
.934 .54358 Mdot
.934 .54364 Mdot
.934 .54395 Mdot
.934 .54408 Mdot
.934 .54413 Mdot
.934 .54438 Mdot
.934 .54464 Mdot
.934 .5457 Mdot
.934 .54587 Mdot
.934 .54603 Mdot
.934 .54606 Mdot
.934 .54648 Mdot
.934 .54651 Mdot
.934 .54658 Mdot
.934 .54705 Mdot
.934 .54708 Mdot
.934 .54729 Mdot
.934 .54734 Mdot
.934 .54779 Mdot
.934 .54786 Mdot
.934 .54819 Mdot
.934 .54825 Mdot
.934 .54839 Mdot
.934 .54842 Mdot
.934 .54845 Mdot
.934 .54852 Mdot
.934 .54876 Mdot
.934 .5488 Mdot
.934 .54887 Mdot
.934 .54906 Mdot
.934 .54918 Mdot
.934 .54932 Mdot
.934 .54934 Mdot
.934 .54942 Mdot
.934 .55003 Mdot
.934 .5502 Mdot
.934 .5504 Mdot
.934 .55052 Mdot
.934 .55056 Mdot
.934 .55089 Mdot
.934 .55097 Mdot
.934 .55098 Mdot
.934 .551 Mdot
.934 .55105 Mdot
.934 .55116 Mdot
.934 .5512 Mdot
.934 .55169 Mdot
.934 .55189 Mdot
.934 .55196 Mdot
.934 .55252 Mdot
.934 .55255 Mdot
.934 .55286 Mdot
.934 .5529 Mdot
.934 .55303 Mdot
.934 .55317 Mdot
.934 .55319 Mdot
.934 .5532 Mdot
.934 .55337 Mdot
.934 .55338 Mdot
.934 .5536 Mdot
.934 .55363 Mdot
.934 .55377 Mdot
.934 .55386 Mdot
.934 .55393 Mdot
.934 .554 Mdot
.934 .5541 Mdot
.934 .55419 Mdot
.934 .55422 Mdot
.934 .5543 Mdot
.934 .55431 Mdot
.934 .55445 Mdot
.934 .55451 Mdot
.934 .55457 Mdot
.934 .55462 Mdot
.934 .55466 Mdot
.934 .55501 Mdot
.934 .55501 Mdot
.934 .55514 Mdot
.934 .55519 Mdot
.934 .55527 Mdot
.934 .55532 Mdot
.934 .55614 Mdot
.934 .55624 Mdot
.934 .55662 Mdot
.934 .55662 Mdot
.934 .55668 Mdot
.934 .55669 Mdot
.934 .55676 Mdot
.934 .55693 Mdot
.934 .55749 Mdot
.934 .55778 Mdot
.934 .558 Mdot
.934 .55806 Mdot
.934 .55855 Mdot
.934 .55858 Mdot
.934 .55861 Mdot
.934 .55875 Mdot
.934 .55889 Mdot
.934 .55903 Mdot
.934 .55942 Mdot
.934 .55945 Mdot
.934 .55946 Mdot
.934 .55987 Mdot
.934 .55993 Mdot
.934 .55994 Mdot
.934 .56019 Mdot
.934 .5603 Mdot
.934 .56044 Mdot
.934 .56045 Mdot
.934 .56051 Mdot
.934 .56057 Mdot
.934 .56057 Mdot
.934 .56065 Mdot
.934 .56087 Mdot
.934 .56091 Mdot
.934 .56101 Mdot
.934 .56102 Mdot
.934 .56105 Mdot
.934 .56106 Mdot
.934 .56117 Mdot
.934 .56137 Mdot
.934 .56138 Mdot
.934 .56146 Mdot
.934 .56154 Mdot
.934 .56154 Mdot
.934 .56165 Mdot
.934 .56169 Mdot
.934 .56171 Mdot
.934 .56175 Mdot
.934 .5618 Mdot
.934 .56183 Mdot
.934 .56187 Mdot
.934 .5619 Mdot
.934 .56192 Mdot
.934 .56206 Mdot
.934 .56209 Mdot
.934 .56211 Mdot
.934 .5625 Mdot
.934 .5625 Mdot
.934 .56293 Mdot
.934 .56312 Mdot
.934 .56316 Mdot
.934 .56321 Mdot
.934 .56326 Mdot
.934 .5637 Mdot
.934 .5638 Mdot
.934 .56383 Mdot
.934 .56385 Mdot
.934 .56385 Mdot
.934 .56388 Mdot
.934 .56399 Mdot
.934 .5642 Mdot
.934 .56421 Mdot
.934 .56428 Mdot
.934 .56433 Mdot
.934 .56435 Mdot
.934 .56436 Mdot
.934 .56438 Mdot
.934 .56441 Mdot
.934 .56442 Mdot
.934 .56444 Mdot
.934 .56447 Mdot
.936 .12475 Mdot
.936 .12475 Mdot
.936 .12477 Mdot
.936 .12478 Mdot
.936 .1248 Mdot
.936 .1251 Mdot
.936 .12521 Mdot
.936 .12524 Mdot
.936 .12535 Mdot
.936 .12536 Mdot
.936 .12539 Mdot
.936 .12545 Mdot
.936 .12562 Mdot
.936 .12562 Mdot
.936 .126 Mdot
.936 .12601 Mdot
.936 .12673 Mdot
.936 .12721 Mdot
.936 .12747 Mdot
.936 .12747 Mdot
.936 .12749 Mdot
.936 .12751 Mdot
.936 .12753 Mdot
.936 .12769 Mdot
.936 .1279 Mdot
.936 .12805 Mdot
.936 .12809 Mdot
.936 .12823 Mdot
.936 .12826 Mdot
.936 .12829 Mdot
.936 .12837 Mdot
.936 .12851 Mdot
.936 .12862 Mdot
.936 .12862 Mdot
.936 .12895 Mdot
.936 .12919 Mdot
.936 .12921 Mdot
.936 .12948 Mdot
.936 .1297 Mdot
.936 .12988 Mdot
.936 .13008 Mdot
.936 .13038 Mdot
.936 .13075 Mdot
.936 .13085 Mdot
.936 .13124 Mdot
.936 .13172 Mdot
.936 .13173 Mdot
.936 .13177 Mdot
.936 .1318 Mdot
.936 .13184 Mdot
.936 .13216 Mdot
.936 .13259 Mdot
.936 .13267 Mdot
.936 .13289 Mdot
.936 .13297 Mdot
.936 .13319 Mdot
.936 .13327 Mdot
.936 .13332 Mdot
.936 .13338 Mdot
.936 .13356 Mdot
.936 .13387 Mdot
.936 .1341 Mdot
.936 .13411 Mdot
.936 .13425 Mdot
.936 .13484 Mdot
.936 .13521 Mdot
.936 .1354 Mdot
.936 .13544 Mdot
.936 .13582 Mdot
.936 .13597 Mdot
.936 .13609 Mdot
.936 .13617 Mdot
.936 .13641 Mdot
.936 .13663 Mdot
.936 .13703 Mdot
.936 .13708 Mdot
.936 .13754 Mdot
.936 .13759 Mdot
.936 .13813 Mdot
.936 .13838 Mdot
.936 .13868 Mdot
.936 .13907 Mdot
.936 .13938 Mdot
.936 .13941 Mdot
.936 .13966 Mdot
.936 .1405 Mdot
.936 .14075 Mdot
.936 .14108 Mdot
.936 .14215 Mdot
.936 .14216 Mdot
.936 .1423 Mdot
.936 .14238 Mdot
.936 .14249 Mdot
.936 .143 Mdot
.936 .14327 Mdot
.936 .14348 Mdot
.936 .14481 Mdot
.936 .14507 Mdot
.936 .14576 Mdot
.936 .14577 Mdot
.936 .14582 Mdot
.936 .14587 Mdot
.936 .14604 Mdot
.936 .14627 Mdot
.936 .14675 Mdot
.936 .14679 Mdot
.936 .14703 Mdot
.936 .14718 Mdot
.936 .14723 Mdot
.936 .1474 Mdot
.936 .14774 Mdot
.936 .14777 Mdot
.936 .14783 Mdot
.936 .14797 Mdot
.936 .14801 Mdot
.936 .14867 Mdot
.936 .14907 Mdot
.936 .14986 Mdot
.936 .14991 Mdot
.936 .15015 Mdot
.936 .1502 Mdot
.936 .15041 Mdot
.936 .15072 Mdot
.936 .15079 Mdot
.936 .15253 Mdot
.936 .15254 Mdot
.936 .15391 Mdot
.936 .15407 Mdot
.936 .15418 Mdot
.936 .15439 Mdot
.936 .15445 Mdot
.936 .15465 Mdot
.936 .15479 Mdot
.936 .15565 Mdot
.936 .15625 Mdot
.936 .15655 Mdot
.936 .15682 Mdot
.936 .15684 Mdot
.936 .15684 Mdot
.936 .1573 Mdot
.936 .15733 Mdot
.936 .15762 Mdot
.936 .1583 Mdot
.936 .15861 Mdot
.936 .1595 Mdot
.936 .16112 Mdot
.936 .16119 Mdot
.936 .16134 Mdot
.936 .16328 Mdot
.936 .16348 Mdot
.936 .16405 Mdot
.936 .16583 Mdot
.936 .16637 Mdot
.936 .16695 Mdot
.936 .1679 Mdot
.936 .1683 Mdot
.936 .17007 Mdot
.936 .17149 Mdot
.936 .17153 Mdot
.936 .17164 Mdot
.936 .17252 Mdot
.936 .17281 Mdot
.936 .17388 Mdot
.936 .17463 Mdot
.936 .17631 Mdot
.936 .17682 Mdot
.936 .17749 Mdot
.936 .17802 Mdot
.936 .17806 Mdot
.936 .17841 Mdot
.936 .17965 Mdot
.936 .17993 Mdot
.936 .18004 Mdot
.936 .18142 Mdot
.936 .18205 Mdot
.936 .18216 Mdot
.936 .18307 Mdot
.936 .18458 Mdot
.936 .18509 Mdot
.936 .18514 Mdot
.936 .18554 Mdot
.936 .18585 Mdot
.936 .18625 Mdot
.936 .18631 Mdot
.936 .18686 Mdot
.936 .1875 Mdot
.936 .18794 Mdot
.936 .18804 Mdot
.936 .18956 Mdot
.936 .18957 Mdot
.936 .191 Mdot
.936 .19166 Mdot
.936 .19211 Mdot
.936 .19325 Mdot
.936 .19485 Mdot
.936 .195 Mdot
.936 .19571 Mdot
.936 .19606 Mdot
.936 .19943 Mdot
.936 .20028 Mdot
.936 .20094 Mdot
.936 .20487 Mdot
.936 .20491 Mdot
.936 .2052 Mdot
.936 .20551 Mdot
.936 .2059 Mdot
.936 .20606 Mdot
.936 .20618 Mdot
.936 .20647 Mdot
.936 .20786 Mdot
.936 .20818 Mdot
.936 .20847 Mdot
.936 .2087 Mdot
.936 .21069 Mdot
.936 .21093 Mdot
.936 .21236 Mdot
.936 .21325 Mdot
.936 .21355 Mdot
.936 .21457 Mdot
.936 .2166 Mdot
.936 .21679 Mdot
.936 .21714 Mdot
.936 .21715 Mdot
.936 .21801 Mdot
.936 .21829 Mdot
.936 .22223 Mdot
.936 .22234 Mdot
.936 .22486 Mdot
.936 .22592 Mdot
.936 .22613 Mdot
.936 .22778 Mdot
.936 .22896 Mdot
.936 .22985 Mdot
.936 .23018 Mdot
.936 .23076 Mdot
.936 .23149 Mdot
.936 .2317 Mdot
.936 .23203 Mdot
.936 .23208 Mdot
.936 .23334 Mdot
.936 .23533 Mdot
.936 .23579 Mdot
.936 .2392 Mdot
.936 .24081 Mdot
.936 .24088 Mdot
.936 .24219 Mdot
.936 .24718 Mdot
.936 .24727 Mdot
.936 .24738 Mdot
.936 .2482 Mdot
.936 .24826 Mdot
.936 .25047 Mdot
.936 .25218 Mdot
.936 .25232 Mdot
.936 .25334 Mdot
.936 .254 Mdot
.936 .2563 Mdot
.936 .25664 Mdot
.936 .25774 Mdot
.936 .25815 Mdot
.936 .25849 Mdot
.936 .25912 Mdot
.936 .25917 Mdot
.936 .25988 Mdot
.936 .26031 Mdot
.936 .26167 Mdot
.936 .26204 Mdot
.936 .2627 Mdot
.936 .26319 Mdot
.936 .26505 Mdot
.936 .26583 Mdot
.936 .26865 Mdot
.936 .27087 Mdot
.936 .27118 Mdot
.936 .27188 Mdot
.936 .27265 Mdot
.936 .27285 Mdot
.936 .275 Mdot
.936 .27537 Mdot
.936 .27687 Mdot
.936 .27701 Mdot
.936 .27703 Mdot
.936 .2777 Mdot
.936 .27807 Mdot
.936 .28032 Mdot
.936 .28053 Mdot
.936 .28208 Mdot
.936 .28257 Mdot
.936 .2838 Mdot
.936 .28415 Mdot
.936 .28627 Mdot
.936 .28748 Mdot
.936 .28968 Mdot
.936 .29611 Mdot
.936 .29761 Mdot
.936 .29858 Mdot
.936 .30154 Mdot
.936 .30157 Mdot
.936 .3028 Mdot
.936 .30346 Mdot
.936 .30381 Mdot
.936 .30435 Mdot
.936 .30449 Mdot
.936 .30507 Mdot
.936 .30793 Mdot
.936 .30844 Mdot
.936 .30956 Mdot
.936 .31033 Mdot
.936 .31059 Mdot
.936 .31419 Mdot
.936 .31435 Mdot
.936 .31524 Mdot
.936 .3184 Mdot
.936 .32 Mdot
.936 .32001 Mdot
.936 .32005 Mdot
.936 .32008 Mdot
.936 .32012 Mdot
.936 .32085 Mdot
.936 .32112 Mdot
.936 .3212 Mdot
.936 .32146 Mdot
.936 .32149 Mdot
.936 .32155 Mdot
.936 .3217 Mdot
.936 .32212 Mdot
.936 .32213 Mdot
.936 .32267 Mdot
.936 .32306 Mdot
.936 .32308 Mdot
.936 .3235 Mdot
.936 .32384 Mdot
.936 .3241 Mdot
.936 .32439 Mdot
.936 .32483 Mdot
.936 .32534 Mdot
.936 .32548 Mdot
.936 .32599 Mdot
.936 .32661 Mdot
.936 .32662 Mdot
.936 .32668 Mdot
.936 .32671 Mdot
.936 .32676 Mdot
.936 .32716 Mdot
.936 .32767 Mdot
.936 .32777 Mdot
.936 .32803 Mdot
.936 .32812 Mdot
.936 .32847 Mdot
.936 .32852 Mdot
.936 .3286 Mdot
.936 .3288 Mdot
.936 .32915 Mdot
.936 .3294 Mdot
.936 .32941 Mdot
.936 .32956 Mdot
.936 .33019 Mdot
.936 .33077 Mdot
.936 .33081 Mdot
.936 .3312 Mdot
.936 .33135 Mdot
.936 .33146 Mdot
.936 .33154 Mdot
.936 .332 Mdot
.936 .33238 Mdot
.936 .33243 Mdot
.936 .33286 Mdot
.936 .33291 Mdot
.936 .33341 Mdot
.936 .33364 Mdot
.936 .33453 Mdot
.936 .33456 Mdot
.936 .33477 Mdot
.936 .3357 Mdot
.936 .33685 Mdot
.936 .33686 Mdot
.936 .33697 Mdot
.936 .33703 Mdot
.936 .33712 Mdot
.936 .3379 Mdot
.936 .33891 Mdot
.936 .33911 Mdot
.936 .33961 Mdot
.936 .33962 Mdot
.936 .33966 Mdot
.936 .33969 Mdot
.936 .33982 Mdot
.936 .34033 Mdot
.936 .34053 Mdot
.936 .34064 Mdot
.936 .34067 Mdot
.936 .34079 Mdot
.936 .34109 Mdot
.936 .34122 Mdot
.936 .34168 Mdot
.936 .34195 Mdot
.936 .34249 Mdot
.936 .34252 Mdot
.936 .34272 Mdot
.936 .34285 Mdot
.936 .3431 Mdot
.936 .34424 Mdot
.936 .34425 Mdot
.936 .34511 Mdot
.936 .34528 Mdot
.936 .34544 Mdot
.936 .34557 Mdot
.936 .34566 Mdot
.936 .34654 Mdot
.936 .34672 Mdot
.936 .34689 Mdot
.936 .3469 Mdot
.936 .34717 Mdot
.936 .34736 Mdot
.936 .34776 Mdot
.936 .34794 Mdot
.936 .34845 Mdot
.936 .34937 Mdot
.936 .3495 Mdot
.936 .35057 Mdot
.936 .35068 Mdot
.936 .35099 Mdot
.936 .35194 Mdot
.936 .35253 Mdot
.936 .35302 Mdot
.936 .35323 Mdot
.936 .35413 Mdot
.936 .35484 Mdot
.936 .35492 Mdot
.936 .3555 Mdot
.936 .35719 Mdot
.936 .35743 Mdot
.936 .358 Mdot
.936 .35802 Mdot
.936 .35876 Mdot
.936 .35986 Mdot
.936 .36099 Mdot
.936 .36122 Mdot
.936 .36124 Mdot
.936 .36155 Mdot
.936 .36173 Mdot
.936 .36199 Mdot
.936 .36227 Mdot
.936 .36246 Mdot
.936 .36251 Mdot
.936 .36316 Mdot
.936 .36316 Mdot
.936 .36377 Mdot
.936 .36424 Mdot
.936 .36538 Mdot
.936 .36545 Mdot
.936 .36725 Mdot
.936 .36785 Mdot
.936 .3694 Mdot
.936 .36942 Mdot
.936 .36953 Mdot
.936 .36965 Mdot
.936 .36991 Mdot
.936 .37002 Mdot
.936 .37056 Mdot
.936 .37163 Mdot
.936 .37172 Mdot
.936 .37226 Mdot
.936 .37259 Mdot
.936 .3727 Mdot
.936 .37308 Mdot
.936 .37383 Mdot
.936 .3739 Mdot
.936 .37403 Mdot
.936 .37403 Mdot
.936 .37434 Mdot
.936 .37444 Mdot
.936 .3759 Mdot
.936 .3768 Mdot
.936 .37783 Mdot
.936 .37824 Mdot
.936 .37855 Mdot
.936 .37866 Mdot
.936 .37911 Mdot
.936 .37919 Mdot
.936 .3793 Mdot
.936 .37931 Mdot
.936 .37975 Mdot
.936 .38043 Mdot
.936 .38058 Mdot
.936 .38173 Mdot
.936 .38229 Mdot
.936 .38437 Mdot
.936 .3844 Mdot
.936 .38443 Mdot
.936 .3847 Mdot
.936 .38543 Mdot
.936 .38741 Mdot
.936 .38775 Mdot
.936 .38799 Mdot
.936 .38819 Mdot
.936 .38843 Mdot
.936 .38856 Mdot
.936 .38899 Mdot
.936 .38931 Mdot
.936 .38946 Mdot
.936 .39004 Mdot
.936 .39115 Mdot
.936 .39183 Mdot
.936 .39237 Mdot
.936 .39243 Mdot
.936 .39309 Mdot
.936 .39365 Mdot
.936 .39369 Mdot
.936 .3937 Mdot
.936 .3939 Mdot
.936 .39401 Mdot
.936 .39469 Mdot
.936 .39475 Mdot
.936 .39521 Mdot
.936 .39536 Mdot
.936 .39645 Mdot
.936 .39681 Mdot
.936 .39746 Mdot
.936 .39934 Mdot
.936 .40155 Mdot
.936 .40171 Mdot
.936 .40175 Mdot
.936 .40192 Mdot
.936 .40273 Mdot
.936 .40288 Mdot
.936 .4032 Mdot
.936 .40342 Mdot
.936 .40455 Mdot
.936 .40689 Mdot
.936 .40722 Mdot
.936 .40729 Mdot
.936 .40764 Mdot
.936 .40768 Mdot
.936 .40831 Mdot
.936 .40881 Mdot
.936 .40926 Mdot
.936 .40931 Mdot
.936 .40973 Mdot
.936 .4116 Mdot
.936 .41161 Mdot
.936 .41244 Mdot
.936 .41354 Mdot
.936 .41359 Mdot
.936 .41382 Mdot
.936 .41471 Mdot
.936 .41526 Mdot
.936 .4164 Mdot
.936 .41662 Mdot
.936 .41743 Mdot
.936 .41783 Mdot
.936 .41784 Mdot
.936 .41802 Mdot
.936 .41864 Mdot
.936 .41985 Mdot
.936 .42097 Mdot
.936 .42211 Mdot
.936 .4224 Mdot
.936 .42377 Mdot
.936 .42386 Mdot
.936 .42406 Mdot
.936 .42531 Mdot
.936 .4258 Mdot
.936 .42636 Mdot
.936 .42672 Mdot
.936 .42845 Mdot
.936 .42855 Mdot
.936 .42896 Mdot
.936 .42927 Mdot
.936 .42991 Mdot
.936 .4303 Mdot
.936 .43057 Mdot
.936 .43068 Mdot
.936 .4312 Mdot
.936 .43292 Mdot
.936 .43314 Mdot
.936 .4341 Mdot
.936 .43418 Mdot
.936 .43538 Mdot
.936 .43609 Mdot
.936 .43638 Mdot
.936 .43646 Mdot
.936 .43649 Mdot
.936 .43712 Mdot
.936 .43747 Mdot
.936 .43946 Mdot
.936 .43998 Mdot
.936 .44019 Mdot
.936 .4412 Mdot
.936 .44186 Mdot
.936 .44275 Mdot
.936 .44302 Mdot
.936 .44308 Mdot
.936 .44322 Mdot
.936 .44376 Mdot
.936 .44392 Mdot
.936 .44413 Mdot
.936 .44507 Mdot
.936 .44579 Mdot
.936 .44726 Mdot
.936 .44741 Mdot
.936 .44855 Mdot
.936 .44915 Mdot
.936 .44946 Mdot
.936 .44955 Mdot
.936 .44956 Mdot
.936 .45027 Mdot
.936 .45084 Mdot
.936 .45155 Mdot
.936 .45166 Mdot
.936 .45264 Mdot
.936 .45264 Mdot
.936 .45356 Mdot
.936 .45376 Mdot
.936 .45378 Mdot
.936 .45425 Mdot
.936 .45456 Mdot
.936 .45474 Mdot
.936 .45494 Mdot
.936 .45606 Mdot
.936 .45661 Mdot
.936 .45733 Mdot
.936 .45741 Mdot
.936 .45743 Mdot
.936 .4575 Mdot
.936 .45992 Mdot
.936 .46051 Mdot
.936 .46107 Mdot
.936 .46112 Mdot
.936 .46184 Mdot
.936 .46209 Mdot
.936 .46292 Mdot
.936 .46319 Mdot
.936 .46378 Mdot
.936 .46505 Mdot
.936 .46539 Mdot
.936 .46554 Mdot
.936 .46649 Mdot
.936 .46675 Mdot
.936 .46785 Mdot
.936 .46794 Mdot
.936 .46834 Mdot
.936 .46852 Mdot
.936 .47023 Mdot
.936 .47207 Mdot
.936 .47405 Mdot
.936 .47408 Mdot
.936 .47505 Mdot
.936 .47534 Mdot
.936 .47536 Mdot
.936 .47544 Mdot
.936 .476 Mdot
.936 .4765 Mdot
.936 .4773 Mdot
.936 .47766 Mdot
.936 .47946 Mdot
.936 .48034 Mdot
.936 .48172 Mdot
.936 .48209 Mdot
.936 .48216 Mdot
.936 .48271 Mdot
.936 .48278 Mdot
.936 .48322 Mdot
.936 .4837 Mdot
.936 .48386 Mdot
.936 .4843 Mdot
.936 .48455 Mdot
.936 .48473 Mdot
.936 .48514 Mdot
.936 .48516 Mdot
.936 .48517 Mdot
.936 .48729 Mdot
.936 .48777 Mdot
.936 .488 Mdot
.936 .4882 Mdot
.936 .48855 Mdot
.936 .48863 Mdot
.936 .48869 Mdot
.936 .48937 Mdot
.936 .49011 Mdot
.936 .49106 Mdot
.936 .49112 Mdot
.936 .49151 Mdot
.936 .49162 Mdot
.936 .49173 Mdot
.936 .49187 Mdot
.936 .49222 Mdot
.936 .49396 Mdot
.936 .49524 Mdot
.936 .49561 Mdot
.936 .49567 Mdot
.936 .49713 Mdot
.936 .49723 Mdot
.936 .49754 Mdot
.936 .49799 Mdot
.936 .4982 Mdot
.936 .49934 Mdot
.936 .49957 Mdot
.936 .49963 Mdot
.936 .49985 Mdot
.936 .49998 Mdot
.936 .50025 Mdot
.936 .50074 Mdot
.936 .50075 Mdot
.936 .50193 Mdot
.936 .50231 Mdot
.936 .5029 Mdot
.936 .50544 Mdot
.936 .5063 Mdot
.936 .50677 Mdot
.936 .5076 Mdot
.936 .50774 Mdot
.936 .50822 Mdot
.936 .50841 Mdot
.936 .50901 Mdot
.936 .50909 Mdot
.936 .50996 Mdot
.936 .51011 Mdot
.936 .51037 Mdot
.936 .51038 Mdot
.936 .51043 Mdot
.936 .51101 Mdot
.936 .51115 Mdot
.936 .51198 Mdot
.936 .51206 Mdot
.936 .51235 Mdot
.936 .51262 Mdot
.936 .51274 Mdot
.936 .51359 Mdot
.936 .51467 Mdot
.936 .51497 Mdot
.936 .51568 Mdot
.936 .51587 Mdot
.936 .51612 Mdot
.936 .51626 Mdot
.936 .51678 Mdot
.936 .51694 Mdot
.936 .51721 Mdot
.936 .51723 Mdot
.936 .51747 Mdot
.936 .51759 Mdot
.936 .51775 Mdot
.936 .51817 Mdot
.936 .51829 Mdot
.936 .51916 Mdot
.936 .51941 Mdot
.936 .5198 Mdot
.936 .51985 Mdot
.936 .5205 Mdot
.936 .52133 Mdot
.936 .52135 Mdot
.936 .52166 Mdot
.936 .5217 Mdot
.936 .52173 Mdot
.936 .5236 Mdot
.936 .52409 Mdot
.936 .52411 Mdot
.936 .52471 Mdot
.936 .52598 Mdot
.936 .52615 Mdot
.936 .52689 Mdot
.936 .52736 Mdot
.936 .52737 Mdot
.936 .5275 Mdot
.936 .52757 Mdot
.936 .52785 Mdot
.936 .52806 Mdot
.936 .52818 Mdot
.936 .52851 Mdot
.936 .52895 Mdot
.936 .52955 Mdot
.936 .52963 Mdot
.936 .53002 Mdot
.936 .53095 Mdot
.936 .53099 Mdot
.936 .53243 Mdot
.936 .53254 Mdot
.936 .53285 Mdot
.936 .53285 Mdot
.936 .53298 Mdot
.936 .53305 Mdot
.936 .53379 Mdot
.936 .53416 Mdot
.936 .53427 Mdot
.936 .5346 Mdot
.936 .53512 Mdot
.936 .53521 Mdot
.936 .53593 Mdot
.936 .53601 Mdot
.936 .53612 Mdot
.936 .53623 Mdot
.936 .53674 Mdot
.936 .53684 Mdot
.936 .53689 Mdot
.936 .53694 Mdot
.936 .53709 Mdot
.936 .5372 Mdot
.936 .5373 Mdot
.936 .53732 Mdot
.936 .53874 Mdot
.936 .53898 Mdot
.936 .53928 Mdot
.936 .5405 Mdot
.936 .54063 Mdot
.936 .54088 Mdot
.936 .54094 Mdot
.936 .54151 Mdot
.936 .54192 Mdot
.936 .54208 Mdot
.936 .54232 Mdot
.936 .54283 Mdot
.936 .54284 Mdot
.936 .54338 Mdot
.936 .54342 Mdot
.936 .54357 Mdot
.936 .5438 Mdot
.936 .544 Mdot
.936 .54402 Mdot
.936 .54416 Mdot
.936 .54428 Mdot
.936 .54442 Mdot
.936 .54444 Mdot
.936 .54462 Mdot
.936 .54516 Mdot
.936 .54548 Mdot
.936 .54552 Mdot
.936 .54575 Mdot
.936 .54624 Mdot
.936 .54628 Mdot
.936 .54638 Mdot
.936 .54682 Mdot
.936 .54695 Mdot
.936 .54696 Mdot
.936 .54715 Mdot
.936 .54739 Mdot
.936 .54757 Mdot
.936 .54817 Mdot
.936 .54843 Mdot
.936 .54881 Mdot
.936 .54891 Mdot
.936 .54923 Mdot
.936 .54926 Mdot
.936 .54928 Mdot
.936 .54978 Mdot
.936 .55041 Mdot
.936 .55055 Mdot
.936 .55056 Mdot
.936 .55089 Mdot
.936 .55109 Mdot
.936 .55129 Mdot
.936 .55191 Mdot
.936 .55211 Mdot
.936 .55219 Mdot
.936 .55287 Mdot
.936 .55292 Mdot
.936 .55295 Mdot
.936 .55352 Mdot
.936 .55383 Mdot
.936 .55394 Mdot
.936 .55418 Mdot
.936 .55428 Mdot
.936 .55429 Mdot
.936 .55446 Mdot
.936 .55446 Mdot
.936 .55446 Mdot
.936 .55456 Mdot
.936 .55467 Mdot
.936 .55488 Mdot
.936 .55518 Mdot
.936 .55523 Mdot
.936 .5553 Mdot
.936 .55532 Mdot
.936 .55539 Mdot
.936 .55543 Mdot
.936 .55549 Mdot
.936 .55597 Mdot
.936 .55597 Mdot
.936 .55658 Mdot
.936 .55661 Mdot
.936 .55672 Mdot
.936 .55679 Mdot
.936 .55681 Mdot
.936 .55689 Mdot
.936 .55691 Mdot
.936 .55719 Mdot
.936 .55733 Mdot
.936 .55756 Mdot
.936 .55757 Mdot
.936 .55762 Mdot
.936 .55764 Mdot
.936 .55765 Mdot
.936 .55777 Mdot
.936 .55783 Mdot
.936 .55785 Mdot
.936 .5579 Mdot
.936 .55798 Mdot
.936 .558 Mdot
.936 .55817 Mdot
.936 .55825 Mdot
.936 .55831 Mdot
.936 .55833 Mdot
.936 .55834 Mdot
.936 .55835 Mdot
.936 .55859 Mdot
.936 .55868 Mdot
.936 .55914 Mdot
.936 .55922 Mdot
.936 .55931 Mdot
.936 .55949 Mdot
.936 .55953 Mdot
.936 .55956 Mdot
.936 .55961 Mdot
.936 .55961 Mdot
.936 .55998 Mdot
.936 .5601 Mdot
.936 .56019 Mdot
.936 .56048 Mdot
.936 .56057 Mdot
.936 .56058 Mdot
.936 .56068 Mdot
.936 .56082 Mdot
.936 .56093 Mdot
.936 .56101 Mdot
.936 .5612 Mdot
.936 .56122 Mdot
.936 .56138 Mdot
.936 .5614 Mdot
.936 .56154 Mdot
.936 .56161 Mdot
.936 .5617 Mdot
.936 .56173 Mdot
.936 .56177 Mdot
.936 .56182 Mdot
.936 .56195 Mdot
.936 .56196 Mdot
.936 .56203 Mdot
.936 .56216 Mdot
.936 .56237 Mdot
.936 .56241 Mdot
.936 .56242 Mdot
.936 .5625 Mdot
.936 .56261 Mdot
.936 .56267 Mdot
.936 .56269 Mdot
.936 .56271 Mdot
.936 .56274 Mdot
.936 .56281 Mdot
.936 .56284 Mdot
.936 .56292 Mdot
.936 .56295 Mdot
.936 .56309 Mdot
.936 .56321 Mdot
.936 .56322 Mdot
.936 .56323 Mdot
.936 .56324 Mdot
.936 .56325 Mdot
.936 .56341 Mdot
.936 .56355 Mdot
.936 .56358 Mdot
.936 .56371 Mdot
.936 .56382 Mdot
.936 .56389 Mdot
.936 .56395 Mdot
.936 .56403 Mdot
.936 .56412 Mdot
.936 .56413 Mdot
.936 .56421 Mdot
.936 .56432 Mdot
.936 .56433 Mdot
.936 .56436 Mdot
.936 .56441 Mdot
.936 .56444 Mdot
.936 .56445 Mdot
.936 .56446 Mdot
.936 .56451 Mdot
.936 .56452 Mdot
.936 .56457 Mdot
.936 .56465 Mdot
.936 .56471 Mdot
.936 .56471 Mdot
.936 .56472 Mdot
.936 .56473 Mdot
.936 .56473 Mdot
.936 .56481 Mdot
.936 .56498 Mdot
.936 .56523 Mdot
.936 .56523 Mdot
.936 .56537 Mdot
.936 .56537 Mdot
.936 .56543 Mdot
.936 .56545 Mdot
.936 .56546 Mdot
.936 .56546 Mdot
.936 .5655 Mdot
.936 .56551 Mdot
.936 .56555 Mdot
.936 .56565 Mdot
.936 .56566 Mdot
.936 .56566 Mdot
.936 .56567 Mdot
.936 .56567 Mdot
.938 .12227 Mdot
.938 .31454 Mdot
.938 .56661 Mdot
.94 .1186 Mdot
.94 .30602 Mdot
.94 .56795 Mdot
.942 .11653 Mdot
.942 .3014 Mdot
.942 .56874 Mdot
.944 .11202 Mdot
.944 .11989 Mdot
.944 .29049 Mdot
.944 .31051 Mdot
.944 .56766 Mdot
.944 .57036 Mdot
.946 .10873 Mdot
.946 .10873 Mdot
.946 .10874 Mdot
.946 .10874 Mdot
.946 .10874 Mdot
.946 .10874 Mdot
.946 .10874 Mdot
.946 .10875 Mdot
.946 .10876 Mdot
.946 .10876 Mdot
.946 .10877 Mdot
.946 .10877 Mdot
.946 .10877 Mdot
.946 .10879 Mdot
.946 .10883 Mdot
.946 .10884 Mdot
.946 .10885 Mdot
.946 .10885 Mdot
.946 .10886 Mdot
.946 .10886 Mdot
.946 .10886 Mdot
.946 .10888 Mdot
.946 .10894 Mdot
.946 .10896 Mdot
.946 .10897 Mdot
.946 .10901 Mdot
.946 .10901 Mdot
.946 .10902 Mdot
.946 .10902 Mdot
.946 .10904 Mdot
.946 .10906 Mdot
.946 .10908 Mdot
.946 .10911 Mdot
.946 .10911 Mdot
.946 .10916 Mdot
.946 .10917 Mdot
.946 .10918 Mdot
.946 .10922 Mdot
.946 .10925 Mdot
.946 .10926 Mdot
.946 .10926 Mdot
.946 .10931 Mdot
.946 .10936 Mdot
.946 .10947 Mdot
.946 .10948 Mdot
.946 .10949 Mdot
.946 .10955 Mdot
.946 .10967 Mdot
.946 .10967 Mdot
.946 .10974 Mdot
.946 .10985 Mdot
.946 .10985 Mdot
.946 .10991 Mdot
.946 .11004 Mdot
.946 .11008 Mdot
.946 .11008 Mdot
.946 .11008 Mdot
.946 .11013 Mdot
.946 .11019 Mdot
.946 .11026 Mdot
.946 .11027 Mdot
.946 .11031 Mdot
.946 .11031 Mdot
.946 .11034 Mdot
.946 .11041 Mdot
.946 .11043 Mdot
.946 .11043 Mdot
.946 .11045 Mdot
.946 .11055 Mdot
.946 .11058 Mdot
.946 .11062 Mdot
.946 .11062 Mdot
.946 .11066 Mdot
.946 .11067 Mdot
.946 .1107 Mdot
.946 .1107 Mdot
.946 .11071 Mdot
.946 .11072 Mdot
.946 .11074 Mdot
.946 .11091 Mdot
.946 .11101 Mdot
.946 .11102 Mdot
.946 .11114 Mdot
.946 .11114 Mdot
.946 .11117 Mdot
.946 .11118 Mdot
.946 .11136 Mdot
.946 .11138 Mdot
.946 .11139 Mdot
.946 .11141 Mdot
.946 .11143 Mdot
.946 .11146 Mdot
.946 .11151 Mdot
.946 .11151 Mdot
.946 .11156 Mdot
.946 .11166 Mdot
.946 .11173 Mdot
.946 .11174 Mdot
.946 .11175 Mdot
.946 .11197 Mdot
.946 .11197 Mdot
.946 .11207 Mdot
.946 .11209 Mdot
.946 .11212 Mdot
.946 .11215 Mdot
.946 .11219 Mdot
.946 .11219 Mdot
.946 .11221 Mdot
.946 .11221 Mdot
.946 .11222 Mdot
.946 .11227 Mdot
.946 .11227 Mdot
.946 .11228 Mdot
.946 .11232 Mdot
.946 .11235 Mdot
.946 .11238 Mdot
.946 .11239 Mdot
.946 .11239 Mdot
.946 .1124 Mdot
.946 .1124 Mdot
.946 .11241 Mdot
.946 .11249 Mdot
.946 .11253 Mdot
.946 .11258 Mdot
.946 .11259 Mdot
.946 .1126 Mdot
.946 .1127 Mdot
.946 .1127 Mdot
.946 .11271 Mdot
.946 .11273 Mdot
.946 .11275 Mdot
.946 .11283 Mdot
.946 .11295 Mdot
.946 .11297 Mdot
.946 .11298 Mdot
.946 .113 Mdot
.946 .11301 Mdot
.946 .11301 Mdot
.946 .11301 Mdot
.946 .11303 Mdot
.946 .11303 Mdot
.946 .11307 Mdot
.946 .11307 Mdot
.946 .11308 Mdot
.946 .11308 Mdot
.946 .11311 Mdot
.946 .11313 Mdot
.946 .11314 Mdot
.946 .11318 Mdot
.946 .11319 Mdot
.946 .1132 Mdot
.946 .11321 Mdot
.946 .11323 Mdot
.946 .1133 Mdot
.946 .1133 Mdot
.946 .11332 Mdot
.946 .11336 Mdot
.946 .11342 Mdot
.946 .11344 Mdot
.946 .11345 Mdot
.946 .11345 Mdot
.946 .11346 Mdot
.946 .11347 Mdot
.946 .11351 Mdot
.946 .11353 Mdot
.946 .11354 Mdot
.946 .11354 Mdot
.946 .1136 Mdot
.946 .11361 Mdot
.946 .11361 Mdot
.946 .11368 Mdot
.946 .11368 Mdot
.946 .11369 Mdot
.946 .11371 Mdot
.946 .11371 Mdot
.946 .11372 Mdot
.946 .11372 Mdot
.946 .11372 Mdot
.946 .11374 Mdot
.946 .11374 Mdot
.946 .11375 Mdot
.946 .11383 Mdot
.946 .11388 Mdot
.946 .11389 Mdot
.946 .1139 Mdot
.946 .11392 Mdot
.946 .11399 Mdot
.946 .11402 Mdot
.946 .11405 Mdot
.946 .1141 Mdot
.946 .11411 Mdot
.946 .11412 Mdot
.946 .11412 Mdot
.946 .1142 Mdot
.946 .1142 Mdot
.946 .11423 Mdot
.946 .11424 Mdot
.946 .11424 Mdot
.946 .11425 Mdot
.946 .11428 Mdot
.946 .1143 Mdot
.946 .11433 Mdot
.946 .11457 Mdot
.946 .11471 Mdot
.946 .11475 Mdot
.946 .11479 Mdot
.946 .11481 Mdot
.946 .11483 Mdot
.946 .11501 Mdot
.946 .11504 Mdot
.946 .11505 Mdot
.946 .11515 Mdot
.946 .11524 Mdot
.946 .11539 Mdot
.946 .1154 Mdot
.946 .11541 Mdot
.946 .11543 Mdot
.946 .11543 Mdot
.946 .11545 Mdot
.946 .1155 Mdot
.946 .11557 Mdot
.946 .11567 Mdot
.946 .11568 Mdot
.946 .11568 Mdot
.946 .11578 Mdot
.946 .1158 Mdot
.946 .1158 Mdot
.946 .11584 Mdot
.946 .11585 Mdot
.946 .11593 Mdot
.946 .11599 Mdot
.946 .11605 Mdot
.946 .11609 Mdot
.946 .11631 Mdot
.946 .11632 Mdot
.946 .11679 Mdot
.946 .11681 Mdot
.946 .11683 Mdot
.946 .117 Mdot
.946 .11723 Mdot
.946 .11734 Mdot
.946 .11735 Mdot
.946 .11746 Mdot
.946 .11752 Mdot
.946 .11757 Mdot
.946 .11762 Mdot
.946 .11764 Mdot
.946 .11767 Mdot
.946 .11813 Mdot
.946 .11814 Mdot
.946 .1182 Mdot
.946 .11822 Mdot
.946 .11851 Mdot
.946 .11852 Mdot
.946 .11877 Mdot
.946 .11921 Mdot
.946 .11924 Mdot
.946 .11927 Mdot
.946 .11931 Mdot
.946 .11931 Mdot
.946 .11938 Mdot
.946 .1194 Mdot
.946 .11951 Mdot
.946 .11952 Mdot
.946 .11961 Mdot
.946 .11969 Mdot
.946 .11996 Mdot
.946 .12001 Mdot
.946 .12001 Mdot
.946 .12007 Mdot
.946 .12026 Mdot
.946 .12032 Mdot
.946 .12033 Mdot
.946 .12043 Mdot
.946 .12046 Mdot
.946 .12066 Mdot
.946 .12082 Mdot
.946 .12095 Mdot
.946 .12095 Mdot
.946 .12096 Mdot
.946 .12105 Mdot
.946 .12143 Mdot
.946 .12159 Mdot
.946 .1216 Mdot
.946 .12189 Mdot
.946 .12209 Mdot
.946 .1221 Mdot
.946 .12244 Mdot
.946 .12262 Mdot
.946 .12265 Mdot
.946 .1227 Mdot
.946 .12301 Mdot
.946 .12315 Mdot
.946 .12331 Mdot
.946 .12332 Mdot
.946 .12333 Mdot
.946 .12342 Mdot
.946 .12354 Mdot
.946 .1236 Mdot
.946 .12361 Mdot
.946 .12378 Mdot
.946 .12378 Mdot
.946 .12387 Mdot
.946 .12393 Mdot
.946 .124 Mdot
.946 .12403 Mdot
.946 .12405 Mdot
.946 .12407 Mdot
.946 .12408 Mdot
.946 .12421 Mdot
.946 .12422 Mdot
.946 .12429 Mdot
.946 .12448 Mdot
.946 .12453 Mdot
.946 .12453 Mdot
.946 .12455 Mdot
.946 .12456 Mdot
.946 .12457 Mdot
.946 .12461 Mdot
.946 .12463 Mdot
.946 .12477 Mdot
.946 .12481 Mdot
.946 .12482 Mdot
.946 .12482 Mdot
.946 .12486 Mdot
.946 .12486 Mdot
.946 .1249 Mdot
.946 .12491 Mdot
.946 .12492 Mdot
.946 .12493 Mdot
.946 .12493 Mdot
.946 .12494 Mdot
.946 .12494 Mdot
.946 .12495 Mdot
.946 .28255 Mdot
.946 .28255 Mdot
.946 .28256 Mdot
.946 .28256 Mdot
.946 .28257 Mdot
.946 .28257 Mdot
.946 .28258 Mdot
.946 .28259 Mdot
.946 .28262 Mdot
.946 .28262 Mdot
.946 .28265 Mdot
.946 .28265 Mdot
.946 .28266 Mdot
.946 .2827 Mdot
.946 .28281 Mdot
.946 .28282 Mdot
.946 .28286 Mdot
.946 .28287 Mdot
.946 .28288 Mdot
.946 .28289 Mdot
.946 .28289 Mdot
.946 .28293 Mdot
.946 .28309 Mdot
.946 .28315 Mdot
.946 .28316 Mdot
.946 .28327 Mdot
.946 .28328 Mdot
.946 .28329 Mdot
.946 .28331 Mdot
.946 .28334 Mdot
.946 .28339 Mdot
.946 .28345 Mdot
.946 .28353 Mdot
.946 .28353 Mdot
.946 .28367 Mdot
.946 .28368 Mdot
.946 .28373 Mdot
.946 .28383 Mdot
.946 .28391 Mdot
.946 .28392 Mdot
.946 .28393 Mdot
.946 .28407 Mdot
.946 .28418 Mdot
.946 .28446 Mdot
.946 .2845 Mdot
.946 .28453 Mdot
.946 .28469 Mdot
.946 .285 Mdot
.946 .285 Mdot
.946 .28518 Mdot
.946 .28545 Mdot
.946 .28546 Mdot
.946 .28561 Mdot
.946 .28596 Mdot
.946 .28605 Mdot
.946 .28605 Mdot
.946 .28606 Mdot
.946 .28618 Mdot
.946 .28633 Mdot
.946 .28653 Mdot
.946 .28655 Mdot
.946 .28665 Mdot
.946 .28666 Mdot
.946 .28672 Mdot
.946 .2869 Mdot
.946 .28696 Mdot
.946 .28696 Mdot
.946 .28701 Mdot
.946 .28727 Mdot
.946 .28736 Mdot
.946 .28745 Mdot
.946 .28745 Mdot
.946 .28757 Mdot
.946 .28759 Mdot
.946 .28766 Mdot
.946 .28766 Mdot
.946 .2877 Mdot
.946 .28772 Mdot
.946 .28776 Mdot
.946 .28821 Mdot
.946 .28847 Mdot
.946 .28848 Mdot
.946 .28879 Mdot
.946 .28881 Mdot
.946 .28888 Mdot
.946 .28889 Mdot
.946 .28938 Mdot
.946 .28942 Mdot
.946 .28944 Mdot
.946 .2895 Mdot
.946 .28955 Mdot
.946 .28962 Mdot
.946 .28975 Mdot
.946 .28975 Mdot
.946 .28988 Mdot
.946 .29014 Mdot
.946 .29034 Mdot
.946 .29036 Mdot
.946 .29038 Mdot
.946 .29094 Mdot
.946 .29094 Mdot
.946 .29121 Mdot
.946 .29126 Mdot
.946 .29133 Mdot
.946 .2914 Mdot
.946 .2915 Mdot
.946 .29151 Mdot
.946 .29156 Mdot
.946 .29157 Mdot
.946 .2916 Mdot
.946 .29171 Mdot
.946 .29171 Mdot
.946 .29173 Mdot
.946 .29186 Mdot
.946 .29194 Mdot
.946 .292 Mdot
.946 .29204 Mdot
.946 .29204 Mdot
.946 .29205 Mdot
.946 .29206 Mdot
.946 .29208 Mdot
.946 .29228 Mdot
.946 .29239 Mdot
.946 .29252 Mdot
.946 .29253 Mdot
.946 .29257 Mdot
.946 .29282 Mdot
.946 .29284 Mdot
.946 .29287 Mdot
.946 .29292 Mdot
.946 .29297 Mdot
.946 .29317 Mdot
.946 .29348 Mdot
.946 .29353 Mdot
.946 .29356 Mdot
.946 .2936 Mdot
.946 .29362 Mdot
.946 .29362 Mdot
.946 .29363 Mdot
.946 .29367 Mdot
.946 .29367 Mdot
.946 .29379 Mdot
.946 .29379 Mdot
.946 .2938 Mdot
.946 .29381 Mdot
.946 .29388 Mdot
.946 .29392 Mdot
.946 .29397 Mdot
.946 .29407 Mdot
.946 .29409 Mdot
.946 .29411 Mdot
.946 .29413 Mdot
.946 .2942 Mdot
.946 .29436 Mdot
.946 .29438 Mdot
.946 .29442 Mdot
.946 .29452 Mdot
.946 .29468 Mdot
.946 .29473 Mdot
.946 .29475 Mdot
.946 .29477 Mdot
.946 .29478 Mdot
.946 .29481 Mdot
.946 .2949 Mdot
.946 .29496 Mdot
.946 .29499 Mdot
.946 .295 Mdot
.946 .29515 Mdot
.946 .29516 Mdot
.946 .29517 Mdot
.946 .29534 Mdot
.946 .29534 Mdot
.946 .29542 Mdot
.946 .29542 Mdot
.946 .29544 Mdot
.946 .29545 Mdot
.946 .29545 Mdot
.946 .29549 Mdot
.946 .29551 Mdot
.946 .29553 Mdot
.946 .29573 Mdot
.946 .29586 Mdot
.946 .29589 Mdot
.946 .29592 Mdot
.946 .29596 Mdot
.946 .29614 Mdot
.946 .29623 Mdot
.946 .29631 Mdot
.946 .29643 Mdot
.946 .29645 Mdot
.946 .29646 Mdot
.946 .29647 Mdot
.946 .29668 Mdot
.946 .29668 Mdot
.946 .29676 Mdot
.946 .29678 Mdot
.946 .29678 Mdot
.946 .29682 Mdot
.946 .29689 Mdot
.946 .29694 Mdot
.946 .29703 Mdot
.946 .29762 Mdot
.946 .29799 Mdot
.946 .29809 Mdot
.946 .29819 Mdot
.946 .29824 Mdot
.946 .29828 Mdot
.946 .29876 Mdot
.946 .29883 Mdot
.946 .29885 Mdot
.946 .2991 Mdot
.946 .29934 Mdot
.946 .29972 Mdot
.946 .29976 Mdot
.946 .29978 Mdot
.946 .29982 Mdot
.946 .29982 Mdot
.946 .29988 Mdot
.946 .30001 Mdot
.946 .30017 Mdot
.946 .30043 Mdot
.946 .30047 Mdot
.946 .30048 Mdot
.946 .30071 Mdot
.946 .30077 Mdot
.946 .30078 Mdot
.946 .30088 Mdot
.946 .30091 Mdot
.946 .30111 Mdot
.946 .30126 Mdot
.946 .30141 Mdot
.946 .30151 Mdot
.946 .30208 Mdot
.946 .30208 Mdot
.946 .30329 Mdot
.946 .30334 Mdot
.946 .30339 Mdot
.946 .30382 Mdot
.946 .30441 Mdot
.946 .30469 Mdot
.946 .30471 Mdot
.946 .30499 Mdot
.946 .30515 Mdot
.946 .30527 Mdot
.946 .30539 Mdot
.946 .30546 Mdot
.946 .30554 Mdot
.946 .30668 Mdot
.946 .30671 Mdot
.946 .30686 Mdot
.946 .30692 Mdot
.946 .30766 Mdot
.946 .30767 Mdot
.946 .30832 Mdot
.946 .30941 Mdot
.946 .30951 Mdot
.946 .30956 Mdot
.946 .30966 Mdot
.946 .30966 Mdot
.946 .30984 Mdot
.946 .3099 Mdot
.946 .31018 Mdot
.946 .31019 Mdot
.946 .31043 Mdot
.946 .31064 Mdot
.946 .31131 Mdot
.946 .31143 Mdot
.946 .31144 Mdot
.946 .31158 Mdot
.946 .31205 Mdot
.946 .31221 Mdot
.946 .31223 Mdot
.946 .31249 Mdot
.946 .31256 Mdot
.946 .31307 Mdot
.946 .31346 Mdot
.946 .31379 Mdot
.946 .3138 Mdot
.946 .31382 Mdot
.946 .31405 Mdot
.946 .31499 Mdot
.946 .31541 Mdot
.946 .31541 Mdot
.946 .31616 Mdot
.946 .31665 Mdot
.946 .31666 Mdot
.946 .31753 Mdot
.946 .31796 Mdot
.946 .31805 Mdot
.946 .31815 Mdot
.946 .31895 Mdot
.946 .31928 Mdot
.946 .31968 Mdot
.946 .31971 Mdot
.946 .31973 Mdot
.946 .31997 Mdot
.946 .32026 Mdot
.946 .32041 Mdot
.946 .32042 Mdot
.946 .32084 Mdot
.946 .32084 Mdot
.946 .32106 Mdot
.946 .32123 Mdot
.946 .32139 Mdot
.946 .32147 Mdot
.946 .32153 Mdot
.946 .32157 Mdot
.946 .32161 Mdot
.946 .32192 Mdot
.946 .32194 Mdot
.946 .32212 Mdot
.946 .32259 Mdot
.946 .32271 Mdot
.946 .32272 Mdot
.946 .32277 Mdot
.946 .32279 Mdot
.946 .32282 Mdot
.946 .32292 Mdot
.946 .32296 Mdot
.946 .3233 Mdot
.946 .32341 Mdot
.946 .32343 Mdot
.946 .32343 Mdot
.946 .32352 Mdot
.946 .32353 Mdot
.946 .32363 Mdot
.946 .32365 Mdot
.946 .32368 Mdot
.946 .3237 Mdot
.946 .3237 Mdot
.946 .32372 Mdot
.946 .32373 Mdot
.946 .32374 Mdot
.946 .56601 Mdot
.946 .56601 Mdot
.946 .56601 Mdot
.946 .56601 Mdot
.946 .56601 Mdot
.946 .56601 Mdot
.946 .56602 Mdot
.946 .56602 Mdot
.946 .56604 Mdot
.946 .56604 Mdot
.946 .56605 Mdot
.946 .56605 Mdot
.946 .56605 Mdot
.946 .56607 Mdot
.946 .56611 Mdot
.946 .56612 Mdot
.946 .56613 Mdot
.946 .56614 Mdot
.946 .56614 Mdot
.946 .56615 Mdot
.946 .56615 Mdot
.946 .56616 Mdot
.946 .56623 Mdot
.946 .56626 Mdot
.946 .56626 Mdot
.946 .5663 Mdot
.946 .56631 Mdot
.946 .56631 Mdot
.946 .56632 Mdot
.946 .56633 Mdot
.946 .56635 Mdot
.946 .56638 Mdot
.946 .56641 Mdot
.946 .56641 Mdot
.946 .56646 Mdot
.946 .56647 Mdot
.946 .56649 Mdot
.946 .56653 Mdot
.946 .56656 Mdot
.946 .56656 Mdot
.946 .56657 Mdot
.946 .56662 Mdot
.946 .56667 Mdot
.946 .56678 Mdot
.946 .56679 Mdot
.946 .5668 Mdot
.946 .56686 Mdot
.946 .56698 Mdot
.946 .56698 Mdot
.946 .56705 Mdot
.946 .56716 Mdot
.946 .56716 Mdot
.946 .56721 Mdot
.946 .56734 Mdot
.946 .56737 Mdot
.946 .56738 Mdot
.946 .56738 Mdot
.946 .56742 Mdot
.946 .56748 Mdot
.946 .56755 Mdot
.946 .56755 Mdot
.946 .56759 Mdot
.946 .56759 Mdot
.946 .56761 Mdot
.946 .56768 Mdot
.946 .5677 Mdot
.946 .5677 Mdot
.946 .56771 Mdot
.946 .56781 Mdot
.946 .56784 Mdot
.946 .56787 Mdot
.946 .56787 Mdot
.946 .56791 Mdot
.946 .56791 Mdot
.946 .56794 Mdot
.946 .56794 Mdot
.946 .56795 Mdot
.946 .56796 Mdot
.946 .56797 Mdot
.946 .56812 Mdot
.946 .56821 Mdot
.946 .56821 Mdot
.946 .56831 Mdot
.946 .56832 Mdot
.946 .56834 Mdot
.946 .56834 Mdot
.946 .5685 Mdot
.946 .56851 Mdot
.946 .56852 Mdot
.946 .56853 Mdot
.946 .56855 Mdot
.946 .56857 Mdot
.946 .56861 Mdot
.946 .56861 Mdot
.946 .56865 Mdot
.946 .56873 Mdot
.946 .56879 Mdot
.946 .5688 Mdot
.946 .5688 Mdot
.946 .56896 Mdot
.946 .56896 Mdot
.946 .56904 Mdot
.946 .56905 Mdot
.946 .56907 Mdot
.946 .56909 Mdot
.946 .56912 Mdot
.946 .56913 Mdot
.946 .56914 Mdot
.946 .56914 Mdot
.946 .56915 Mdot
.946 .56918 Mdot
.946 .56918 Mdot
.946 .56919 Mdot
.946 .56922 Mdot
.946 .56924 Mdot
.946 .56926 Mdot
.946 .56927 Mdot
.946 .56927 Mdot
.946 .56927 Mdot
.946 .56928 Mdot
.946 .56928 Mdot
.946 .56933 Mdot
.946 .56936 Mdot
.946 .5694 Mdot
.946 .5694 Mdot
.946 .56941 Mdot
.946 .56947 Mdot
.946 .56948 Mdot
.946 .56949 Mdot
.946 .5695 Mdot
.946 .56951 Mdot
.946 .56956 Mdot
.946 .56964 Mdot
.946 .56965 Mdot
.946 .56966 Mdot
.946 .56967 Mdot
.946 .56967 Mdot
.946 .56967 Mdot
.946 .56968 Mdot
.946 .56969 Mdot
.946 .56969 Mdot
.946 .56972 Mdot
.946 .56972 Mdot
.946 .56972 Mdot
.946 .56972 Mdot
.946 .56974 Mdot
.946 .56975 Mdot
.946 .56976 Mdot
.946 .56978 Mdot
.946 .56979 Mdot
.946 .56979 Mdot
.946 .5698 Mdot
.946 .56981 Mdot
.946 .56984 Mdot
.946 .56984 Mdot
.946 .56985 Mdot
.946 .56985 Mdot
.946 .56985 Mdot
.946 .56985 Mdot
.946 .56986 Mdot
.946 .56986 Mdot
.946 .56986 Mdot
.946 .56987 Mdot
.946 .56987 Mdot
.946 .56989 Mdot
.946 .56989 Mdot
.946 .56989 Mdot
.946 .56991 Mdot
.946 .56991 Mdot
.946 .56992 Mdot
.946 .56992 Mdot
.946 .56994 Mdot
.946 .56994 Mdot
.946 .56994 Mdot
.946 .56994 Mdot
.946 .56995 Mdot
.946 .56995 Mdot
.946 .56998 Mdot
.946 .56999 Mdot
.946 .56999 Mdot
.946 .57 Mdot
.946 .57002 Mdot
.946 .57003 Mdot
.946 .57003 Mdot
.946 .57003 Mdot
.946 .57003 Mdot
.946 .57005 Mdot
.946 .57005 Mdot
.946 .57006 Mdot
.946 .57007 Mdot
.946 .57007 Mdot
.946 .57007 Mdot
.946 .57007 Mdot
.946 .57009 Mdot
.946 .57009 Mdot
.946 .57009 Mdot
.946 .5701 Mdot
.946 .5701 Mdot
.946 .5701 Mdot
.946 .5701 Mdot
.946 .57011 Mdot
.946 .57011 Mdot
.946 .57016 Mdot
.946 .57018 Mdot
.946 .57019 Mdot
.946 .5702 Mdot
.946 .5702 Mdot
.946 .5702 Mdot
.946 .57023 Mdot
.946 .57024 Mdot
.946 .57024 Mdot
.946 .57026 Mdot
.946 .57027 Mdot
.946 .5703 Mdot
.946 .5703 Mdot
.946 .5703 Mdot
.946 .57031 Mdot
.946 .57031 Mdot
.946 .57031 Mdot
.946 .57032 Mdot
.946 .57033 Mdot
.946 .57035 Mdot
.946 .57035 Mdot
.946 .57035 Mdot
.946 .57036 Mdot
.946 .57037 Mdot
.946 .57037 Mdot
.946 .57037 Mdot
.946 .57038 Mdot
.946 .57039 Mdot
.946 .5704 Mdot
.946 .57041 Mdot
.946 .57041 Mdot
.946 .57045 Mdot
.946 .57045 Mdot
.946 .57052 Mdot
.946 .57053 Mdot
.946 .57053 Mdot
.946 .57056 Mdot
.946 .57059 Mdot
.946 .57061 Mdot
.946 .57061 Mdot
.946 .57063 Mdot
.946 .57063 Mdot
.946 .57064 Mdot
.946 .57065 Mdot
.946 .57065 Mdot
.946 .57066 Mdot
.946 .57072 Mdot
.946 .57072 Mdot
.946 .57073 Mdot
.946 .57073 Mdot
.946 .57078 Mdot
.946 .57078 Mdot
.946 .57081 Mdot
.946 .57087 Mdot
.946 .57088 Mdot
.946 .57088 Mdot
.946 .57088 Mdot
.946 .57088 Mdot
.946 .57089 Mdot
.946 .5709 Mdot
.946 .57091 Mdot
.946 .57091 Mdot
.946 .57092 Mdot
.946 .57094 Mdot
.946 .57097 Mdot
.946 .57098 Mdot
.946 .57098 Mdot
.946 .57098 Mdot
.946 .57101 Mdot
.946 .57102 Mdot
.946 .57102 Mdot
.946 .57103 Mdot
.946 .57103 Mdot
.946 .57106 Mdot
.946 .57108 Mdot
.946 .5711 Mdot
.946 .5711 Mdot
.946 .5711 Mdot
.946 .57111 Mdot
.946 .57115 Mdot
.946 .57117 Mdot
.946 .57117 Mdot
.946 .57121 Mdot
.946 .57123 Mdot
.946 .57123 Mdot
.946 .57128 Mdot
.946 .5713 Mdot
.946 .5713 Mdot
.946 .5713 Mdot
.946 .57134 Mdot
.946 .57136 Mdot
.946 .57138 Mdot
.946 .57138 Mdot
.946 .57138 Mdot
.946 .57139 Mdot
.946 .5714 Mdot
.946 .57141 Mdot
.946 .57141 Mdot
.946 .57143 Mdot
.946 .57143 Mdot
.946 .57144 Mdot
.946 .57144 Mdot
.946 .57145 Mdot
.946 .57146 Mdot
.946 .57146 Mdot
.946 .57146 Mdot
.946 .57146 Mdot
.946 .57148 Mdot
.946 .57148 Mdot
.946 .57148 Mdot
.946 .57151 Mdot
.946 .57151 Mdot
.946 .57151 Mdot
.946 .57151 Mdot
.946 .57151 Mdot
.946 .57152 Mdot
.946 .57152 Mdot
.946 .57152 Mdot
.946 .57154 Mdot
.946 .57154 Mdot
.946 .57154 Mdot
.946 .57154 Mdot
.946 .57155 Mdot
.946 .57155 Mdot
.946 .57155 Mdot
.946 .57155 Mdot
.946 .57155 Mdot
.946 .57155 Mdot
.946 .57155 Mdot
.946 .57155 Mdot
.946 .57156 Mdot
.946 .57156 Mdot
.948 .10547 Mdot
.948 .10547 Mdot
.948 .10547 Mdot
.948 .10548 Mdot
.948 .10548 Mdot
.948 .10548 Mdot
.948 .1055 Mdot
.948 .1055 Mdot
.948 .10551 Mdot
.948 .10553 Mdot
.948 .10554 Mdot
.948 .10554 Mdot
.948 .10554 Mdot
.948 .10557 Mdot
.948 .10559 Mdot
.948 .10562 Mdot
.948 .10563 Mdot
.948 .10573 Mdot
.948 .10574 Mdot
.948 .10581 Mdot
.948 .10582 Mdot
.948 .10583 Mdot
.948 .10588 Mdot
.948 .10592 Mdot
.948 .10596 Mdot
.948 .10599 Mdot
.948 .10601 Mdot
.948 .10609 Mdot
.948 .1061 Mdot
.948 .10612 Mdot
.948 .10613 Mdot
.948 .10616 Mdot
.948 .10619 Mdot
.948 .10626 Mdot
.948 .10626 Mdot
.948 .10637 Mdot
.948 .10641 Mdot
.948 .10652 Mdot
.948 .10653 Mdot
.948 .10657 Mdot
.948 .10659 Mdot
.948 .1066 Mdot
.948 .10678 Mdot
.948 .10683 Mdot
.948 .10684 Mdot
.948 .10696 Mdot
.948 .10713 Mdot
.948 .10715 Mdot
.948 .10725 Mdot
.948 .10762 Mdot
.948 .10763 Mdot
.948 .10766 Mdot
.948 .10779 Mdot
.948 .1078 Mdot
.948 .10797 Mdot
.948 .10801 Mdot
.948 .10806 Mdot
.948 .10814 Mdot
.948 .10815 Mdot
.948 .10824 Mdot
.948 .10839 Mdot
.948 .10861 Mdot
.948 .10866 Mdot
.948 .10877 Mdot
.948 .1088 Mdot
.948 .10898 Mdot
.948 .10904 Mdot
.948 .10904 Mdot
.948 .10946 Mdot
.948 .10949 Mdot
.948 .10958 Mdot
.948 .10965 Mdot
.948 .10971 Mdot
.948 .10973 Mdot
.948 .10978 Mdot
.948 .11004 Mdot
.948 .11015 Mdot
.948 .11017 Mdot
.948 .11024 Mdot
.948 .11037 Mdot
.948 .11046 Mdot
.948 .11049 Mdot
.948 .11057 Mdot
.948 .1106 Mdot
.948 .11065 Mdot
.948 .11076 Mdot
.948 .1109 Mdot
.948 .11155 Mdot
.948 .11178 Mdot
.948 .11238 Mdot
.948 .11302 Mdot
.948 .11307 Mdot
.948 .11321 Mdot
.948 .11333 Mdot
.948 .11351 Mdot
.948 .11367 Mdot
.948 .11396 Mdot
.948 .11414 Mdot
.948 .11453 Mdot
.948 .1146 Mdot
.948 .11504 Mdot
.948 .11538 Mdot
.948 .1155 Mdot
.948 .11566 Mdot
.948 .1158 Mdot
.948 .11581 Mdot
.948 .11586 Mdot
.948 .11608 Mdot
.948 .11616 Mdot
.948 .11637 Mdot
.948 .11662 Mdot
.948 .11672 Mdot
.948 .11674 Mdot
.948 .11692 Mdot
.948 .11696 Mdot
.948 .11701 Mdot
.948 .11708 Mdot
.948 .11715 Mdot
.948 .11725 Mdot
.948 .11798 Mdot
.948 .11811 Mdot
.948 .11811 Mdot
.948 .11819 Mdot
.948 .11835 Mdot
.948 .11854 Mdot
.948 .11882 Mdot
.948 .11884 Mdot
.948 .11889 Mdot
.948 .11903 Mdot
.948 .11908 Mdot
.948 .11927 Mdot
.948 .11932 Mdot
.948 .11951 Mdot
.948 .11972 Mdot
.948 .11982 Mdot
.948 .11985 Mdot
.948 .12014 Mdot
.948 .12015 Mdot
.948 .12032 Mdot
.948 .12034 Mdot
.948 .12087 Mdot
.948 .12096 Mdot
.948 .12112 Mdot
.948 .12132 Mdot
.948 .12148 Mdot
.948 .12153 Mdot
.948 .12156 Mdot
.948 .12218 Mdot
.948 .12266 Mdot
.948 .12278 Mdot
.948 .12279 Mdot
.948 .12293 Mdot
.948 .12296 Mdot
.948 .123 Mdot
.948 .12307 Mdot
.948 .12326 Mdot
.948 .12343 Mdot
.948 .12347 Mdot
.948 .12357 Mdot
.948 .12369 Mdot
.948 .1241 Mdot
.948 .12415 Mdot
.948 .12418 Mdot
.948 .12423 Mdot
.948 .12446 Mdot
.948 .1246 Mdot
.948 .12465 Mdot
.948 .12473 Mdot
.948 .12476 Mdot
.948 .12482 Mdot
.948 .1249 Mdot
.948 .12526 Mdot
.948 .12569 Mdot
.948 .12603 Mdot
.948 .1261 Mdot
.948 .12616 Mdot
.948 .12632 Mdot
.948 .12645 Mdot
.948 .12654 Mdot
.948 .12674 Mdot
.948 .12713 Mdot
.948 .12726 Mdot
.948 .12759 Mdot
.948 .12763 Mdot
.948 .12774 Mdot
.948 .12777 Mdot
.948 .1278 Mdot
.948 .12817 Mdot
.948 .12844 Mdot
.948 .12851 Mdot
.948 .12853 Mdot
.948 .1286 Mdot
.948 .12862 Mdot
.948 .12868 Mdot
.948 .12876 Mdot
.948 .12879 Mdot
.948 .1288 Mdot
.948 .12925 Mdot
.948 .1294 Mdot
.948 .1298 Mdot
.948 .1298 Mdot
.948 .12985 Mdot
.948 .12989 Mdot
.948 .13002 Mdot
.948 .13009 Mdot
.948 .13022 Mdot
.948 .13026 Mdot
.948 .13034 Mdot
.948 .13038 Mdot
.948 .13045 Mdot
.948 .13047 Mdot
.948 .13058 Mdot
.948 .13082 Mdot
.948 .1309 Mdot
.948 .13103 Mdot
.948 .13118 Mdot
.948 .13132 Mdot
.948 .13133 Mdot
.948 .13144 Mdot
.948 .13152 Mdot
.948 .13156 Mdot
.948 .13159 Mdot
.948 .13162 Mdot
.948 .13191 Mdot
.948 .13193 Mdot
.948 .13203 Mdot
.948 .13232 Mdot
.948 .13235 Mdot
.948 .13238 Mdot
.948 .13251 Mdot
.948 .13258 Mdot
.948 .13271 Mdot
.948 .13271 Mdot
.948 .13272 Mdot
.948 .13278 Mdot
.948 .1328 Mdot
.948 .1328 Mdot
.948 .13282 Mdot
.948 .13285 Mdot
.948 .13287 Mdot
.948 .13288 Mdot
.948 .13289 Mdot
.948 .13297 Mdot
.948 .13297 Mdot
.948 .13299 Mdot
.948 .13301 Mdot
.948 .13302 Mdot
.948 .13302 Mdot
.948 .13304 Mdot
.948 .13307 Mdot
.948 .13313 Mdot
.948 .13313 Mdot
.948 .1332 Mdot
.948 .13334 Mdot
.948 .13341 Mdot
.948 .13346 Mdot
.948 .13347 Mdot
.948 .13379 Mdot
.948 .1338 Mdot
.948 .13385 Mdot
.948 .13396 Mdot
.948 .13397 Mdot
.948 .13397 Mdot
.948 .13408 Mdot
.948 .13417 Mdot
.948 .1344 Mdot
.948 .13442 Mdot
.948 .13525 Mdot
.948 .1355 Mdot
.948 .13571 Mdot
.948 .13576 Mdot
.948 .13706 Mdot
.948 .13708 Mdot
.948 .13729 Mdot
.948 .13772 Mdot
.948 .13778 Mdot
.948 .13778 Mdot
.948 .13821 Mdot
.948 .1386 Mdot
.948 .13954 Mdot
.948 .13966 Mdot
.948 .14323 Mdot
.948 .14431 Mdot
.948 .14526 Mdot
.948 .14548 Mdot
.948 .14557 Mdot
.948 .1461 Mdot
.948 .15002 Mdot
.948 .15154 Mdot
.948 .15164 Mdot
.948 .15269 Mdot
.948 .15389 Mdot
.948 .1548 Mdot
.948 .15506 Mdot
.948 .1551 Mdot
.948 .15664 Mdot
.948 .15723 Mdot
.948 .15865 Mdot
.948 .15888 Mdot
.948 .15923 Mdot
.948 .16414 Mdot
.948 .16476 Mdot
.948 .16477 Mdot
.948 .17106 Mdot
.948 .18514 Mdot
.948 .18691 Mdot
.948 .19178 Mdot
.948 .19779 Mdot
.948 .19917 Mdot
.948 .19919 Mdot
.948 .19977 Mdot
.948 .20322 Mdot
.948 .20831 Mdot
.948 .2104 Mdot
.948 .22079 Mdot
.948 .22992 Mdot
.948 .23742 Mdot
.948 .24086 Mdot
.948 .24157 Mdot
.948 .24476 Mdot
.948 .24924 Mdot
.948 .25821 Mdot
.948 .26188 Mdot
.948 .26508 Mdot
.948 .26708 Mdot
.948 .26736 Mdot
.948 .27456 Mdot
.948 .27456 Mdot
.948 .27456 Mdot
.948 .27458 Mdot
.948 .27459 Mdot
.948 .27459 Mdot
.948 .27464 Mdot
.948 .27464 Mdot
.948 .27466 Mdot
.948 .27471 Mdot
.948 .27475 Mdot
.948 .27475 Mdot
.948 .27475 Mdot
.948 .27483 Mdot
.948 .27488 Mdot
.948 .27496 Mdot
.948 .27498 Mdot
.948 .27525 Mdot
.948 .27526 Mdot
.948 .27545 Mdot
.948 .27547 Mdot
.948 .27552 Mdot
.948 .27564 Mdot
.948 .27574 Mdot
.948 .27584 Mdot
.948 .27592 Mdot
.948 .27597 Mdot
.948 .27613 Mdot
.948 .2762 Mdot
.948 .27622 Mdot
.948 .27626 Mdot
.948 .27629 Mdot
.948 .27637 Mdot
.948 .27645 Mdot
.948 .27665 Mdot
.948 .27665 Mdot
.948 .27692 Mdot
.948 .27702 Mdot
.948 .27733 Mdot
.948 .27735 Mdot
.948 .27745 Mdot
.948 .27751 Mdot
.948 .27752 Mdot
.948 .27802 Mdot
.948 .27813 Mdot
.948 .27816 Mdot
.948 .27849 Mdot
.948 .27891 Mdot
.948 .27897 Mdot
.948 .27919 Mdot
.948 .27923 Mdot
.948 .28022 Mdot
.948 .28024 Mdot
.948 .2803 Mdot
.948 .28065 Mdot
.948 .28068 Mdot
.948 .28112 Mdot
.948 .28123 Mdot
.948 .28136 Mdot
.948 .28157 Mdot
.948 .2816 Mdot
.948 .28184 Mdot
.948 .28222 Mdot
.948 .2828 Mdot
.948 .28292 Mdot
.948 .28322 Mdot
.948 .2833 Mdot
.948 .28375 Mdot
.948 .28377 Mdot
.948 .28391 Mdot
.948 .28392 Mdot
.948 .28502 Mdot
.948 .28508 Mdot
.948 .28533 Mdot
.948 .28551 Mdot
.948 .28565 Mdot
.948 .28573 Mdot
.948 .28585 Mdot
.948 .28653 Mdot
.948 .28682 Mdot
.948 .28686 Mdot
.948 .28705 Mdot
.948 .28739 Mdot
.948 .28761 Mdot
.948 .28769 Mdot
.948 .28791 Mdot
.948 .28797 Mdot
.948 .28811 Mdot
.948 .2884 Mdot
.948 .28876 Mdot
.948 .29045 Mdot
.948 .29103 Mdot
.948 .29258 Mdot
.948 .29424 Mdot
.948 .29436 Mdot
.948 .29473 Mdot
.948 .29484 Mdot
.948 .29503 Mdot
.948 .29551 Mdot
.948 .29591 Mdot
.948 .29666 Mdot
.948 .29666 Mdot
.948 .29713 Mdot
.948 .29813 Mdot
.948 .29831 Mdot
.948 .2994 Mdot
.948 .29942 Mdot
.948 .30031 Mdot
.948 .30061 Mdot
.948 .30103 Mdot
.948 .30137 Mdot
.948 .3014 Mdot
.948 .30153 Mdot
.948 .30208 Mdot
.948 .30228 Mdot
.948 .30283 Mdot
.948 .3032 Mdot
.948 .30348 Mdot
.948 .30372 Mdot
.948 .30376 Mdot
.948 .30423 Mdot
.948 .30433 Mdot
.948 .30447 Mdot
.948 .30465 Mdot
.948 .30483 Mdot
.948 .30508 Mdot
.948 .30692 Mdot
.948 .30726 Mdot
.948 .30726 Mdot
.948 .30745 Mdot
.948 .30786 Mdot
.948 .30835 Mdot
.948 .30905 Mdot
.948 .3091 Mdot
.948 .30923 Mdot
.948 .30959 Mdot
.948 .30972 Mdot
.948 .31018 Mdot
.948 .31032 Mdot
.948 .31079 Mdot
.948 .31132 Mdot
.948 .31159 Mdot
.948 .31165 Mdot
.948 .31239 Mdot
.948 .31241 Mdot
.948 .31283 Mdot
.948 .31288 Mdot
.948 .3142 Mdot
.948 .31422 Mdot
.948 .31445 Mdot
.948 .31486 Mdot
.948 .31536 Mdot
.948 .31574 Mdot
.948 .31589 Mdot
.948 .31596 Mdot
.948 .31751 Mdot
.948 .31871 Mdot
.948 .319 Mdot
.948 .31902 Mdot
.948 .31938 Mdot
.948 .31946 Mdot
.948 .31957 Mdot
.948 .31972 Mdot
.948 .32021 Mdot
.948 .32063 Mdot
.948 .32072 Mdot
.948 .32098 Mdot
.948 .32129 Mdot
.948 .32211 Mdot
.948 .3223 Mdot
.948 .32241 Mdot
.948 .3225 Mdot
.948 .32262 Mdot
.948 .3232 Mdot
.948 .32353 Mdot
.948 .32365 Mdot
.948 .32386 Mdot
.948 .32393 Mdot
.948 .32409 Mdot
.948 .32429 Mdot
.948 .32518 Mdot
.948 .32624 Mdot
.948 .32708 Mdot
.948 .32725 Mdot
.948 .32739 Mdot
.948 .32778 Mdot
.948 .32812 Mdot
.948 .32832 Mdot
.948 .32875 Mdot
.948 .32883 Mdot
.948 .32978 Mdot
.948 .3301 Mdot
.948 .33091 Mdot
.948 .33102 Mdot
.948 .33129 Mdot
.948 .33136 Mdot
.948 .33143 Mdot
.948 .33233 Mdot
.948 .333 Mdot
.948 .33317 Mdot
.948 .33321 Mdot
.948 .33338 Mdot
.948 .33343 Mdot
.948 .33359 Mdot
.948 .33377 Mdot
.948 .33386 Mdot
.948 .33389 Mdot
.948 .33497 Mdot
.948 .33531 Mdot
.948 .33533 Mdot
.948 .33631 Mdot
.948 .33632 Mdot
.948 .33643 Mdot
.948 .33654 Mdot
.948 .33685 Mdot
.948 .33703 Mdot
.948 .33734 Mdot
.948 .33744 Mdot
.948 .33762 Mdot
.948 .33772 Mdot
.948 .33789 Mdot
.948 .33795 Mdot
.948 .33822 Mdot
.948 .33853 Mdot
.948 .33878 Mdot
.948 .33899 Mdot
.948 .33929 Mdot
.948 .33966 Mdot
.948 .34 Mdot
.948 .34002 Mdot
.948 .3403 Mdot
.948 .34049 Mdot
.948 .34059 Mdot
.948 .34065 Mdot
.948 .34074 Mdot
.948 .34144 Mdot
.948 .34147 Mdot
.948 .34156 Mdot
.948 .34172 Mdot
.948 .34242 Mdot
.948 .34249 Mdot
.948 .34257 Mdot
.948 .34287 Mdot
.948 .34306 Mdot
.948 .34336 Mdot
.948 .34336 Mdot
.948 .34337 Mdot
.948 .34341 Mdot
.948 .34352 Mdot
.948 .34353 Mdot
.948 .34357 Mdot
.948 .34357 Mdot
.948 .34362 Mdot
.948 .34371 Mdot
.948 .34374 Mdot
.948 .34378 Mdot
.948 .34379 Mdot
.948 .34399 Mdot
.948 .34399 Mdot
.948 .34402 Mdot
.948 .34409 Mdot
.948 .3441 Mdot
.948 .3441 Mdot
.948 .34416 Mdot
.948 .34422 Mdot
.948 .34436 Mdot
.948 .34438 Mdot
.948 .34454 Mdot
.948 .34488 Mdot
.948 .34503 Mdot
.948 .34516 Mdot
.948 .34519 Mdot
.948 .34596 Mdot
.948 .34598 Mdot
.948 .3461 Mdot
.948 .34635 Mdot
.948 .34639 Mdot
.948 .34639 Mdot
.948 .34664 Mdot
.948 .34686 Mdot
.948 .3474 Mdot
.948 .34747 Mdot
.948 .34945 Mdot
.948 .35003 Mdot
.948 .35053 Mdot
.948 .35065 Mdot
.948 .35373 Mdot
.948 .35378 Mdot
.948 .35429 Mdot
.948 .35487 Mdot
.948 .35531 Mdot
.948 .35543 Mdot
.948 .35545 Mdot
.948 .35645 Mdot
.948 .35711 Mdot
.948 .35722 Mdot
.948 .35737 Mdot
.948 .35958 Mdot
.948 .35985 Mdot
.948 .36254 Mdot
.948 .36815 Mdot
.948 .37063 Mdot
.948 .37281 Mdot
.948 .37331 Mdot
.948 .37352 Mdot
.948 .37473 Mdot
.948 .38356 Mdot
.948 .3859 Mdot
.948 .38696 Mdot
.948 .38718 Mdot
.948 .38949 Mdot
.948 .39213 Mdot
.948 .3932 Mdot
.948 .39412 Mdot
.948 .3947 Mdot
.948 .39478 Mdot
.948 .39812 Mdot
.948 .3994 Mdot
.948 .40244 Mdot
.948 .40294 Mdot
.948 .40368 Mdot
.948 .40471 Mdot
.948 .4115 Mdot
.948 .41405 Mdot
.948 .41532 Mdot
.948 .41535 Mdot
.948 .42817 Mdot
.948 .45514 Mdot
.948 .45835 Mdot
.948 .46368 Mdot
.948 .46699 Mdot
.948 .47725 Mdot
.948 .47952 Mdot
.948 .47957 Mdot
.948 .48052 Mdot
.948 .48528 Mdot
.948 .48533 Mdot
.948 .4861 Mdot
.948 .48735 Mdot
.948 .49135 Mdot
.948 .49403 Mdot
.948 .4972 Mdot
.948 .50154 Mdot
.948 .50303 Mdot
.948 .5041 Mdot
.948 .50481 Mdot
.948 .50908 Mdot
.948 .51083 Mdot
.948 .51199 Mdot
.948 .51531 Mdot
.948 .51541 Mdot
.948 .51617 Mdot
.948 .51737 Mdot
.948 .51874 Mdot
.948 .52207 Mdot
.948 .52373 Mdot
.948 .5249 Mdot
.948 .52516 Mdot
.948 .52642 Mdot
.948 .52916 Mdot
.948 .53247 Mdot
.948 .53621 Mdot
.948 .53696 Mdot
.948 .53878 Mdot
.948 .54001 Mdot
.948 .54021 Mdot
.948 .54022 Mdot
.948 .54071 Mdot
.948 .54285 Mdot
.948 .54457 Mdot
.948 .54519 Mdot
.948 .55013 Mdot
.948 .55233 Mdot
.948 .55234 Mdot
.948 .55255 Mdot
.948 .55426 Mdot
.948 .55438 Mdot
.948 .55446 Mdot
.948 .55495 Mdot
.948 .55516 Mdot
.948 .55569 Mdot
.948 .55571 Mdot
.948 .5558 Mdot
.948 .55611 Mdot
.948 .55653 Mdot
.948 .55689 Mdot
.948 .55693 Mdot
.948 .55745 Mdot
.948 .55881 Mdot
.948 .55899 Mdot
.948 .55902 Mdot
.948 .5591 Mdot
.948 .55943 Mdot
.948 .5598 Mdot
.948 .56103 Mdot
.948 .56107 Mdot
.948 .5614 Mdot
.948 .56153 Mdot
.948 .56168 Mdot
.948 .56168 Mdot
.948 .5617 Mdot
.948 .56185 Mdot
.948 .56192 Mdot
.948 .56193 Mdot
.948 .56237 Mdot
.948 .56239 Mdot
.948 .56246 Mdot
.948 .56255 Mdot
.948 .56283 Mdot
.948 .56284 Mdot
.948 .56292 Mdot
.948 .56295 Mdot
.948 .56299 Mdot
.948 .56299 Mdot
.948 .56299 Mdot
.948 .56303 Mdot
.948 .56305 Mdot
.948 .56305 Mdot
.948 .56316 Mdot
.948 .56316 Mdot
.948 .56318 Mdot
.948 .5632 Mdot
.948 .56325 Mdot
.948 .56328 Mdot
.948 .56328 Mdot
.948 .5633 Mdot
.948 .56331 Mdot
.948 .56332 Mdot
.948 .56332 Mdot
.948 .56332 Mdot
.948 .56333 Mdot
.948 .56333 Mdot
.948 .56333 Mdot
.948 .56336 Mdot
.948 .56336 Mdot
.948 .56337 Mdot
.948 .56337 Mdot
.948 .56339 Mdot
.948 .56339 Mdot
.948 .56339 Mdot
.948 .5634 Mdot
.948 .56342 Mdot
.948 .56342 Mdot
.948 .56342 Mdot
.948 .56347 Mdot
.948 .56349 Mdot
.948 .56353 Mdot
.948 .56355 Mdot
.948 .56356 Mdot
.948 .56366 Mdot
.948 .56369 Mdot
.948 .5637 Mdot
.948 .5638 Mdot
.948 .56381 Mdot
.948 .56382 Mdot
.948 .56383 Mdot
.948 .56386 Mdot
.948 .5639 Mdot
.948 .5639 Mdot
.948 .56395 Mdot
.948 .564 Mdot
.948 .56404 Mdot
.948 .56407 Mdot
.948 .56415 Mdot
.948 .56419 Mdot
.948 .5642 Mdot
.948 .56422 Mdot
.948 .56424 Mdot
.948 .56426 Mdot
.948 .56428 Mdot
.948 .56432 Mdot
.948 .56435 Mdot
.948 .56439 Mdot
.948 .5644 Mdot
.948 .56442 Mdot
.948 .56442 Mdot
.948 .56456 Mdot
.948 .56461 Mdot
.948 .56476 Mdot
.948 .56477 Mdot
.948 .56478 Mdot
.948 .5648 Mdot
.948 .56483 Mdot
.948 .56483 Mdot
.948 .56486 Mdot
.948 .56486 Mdot
.948 .56489 Mdot
.948 .56498 Mdot
.948 .56511 Mdot
.948 .56512 Mdot
.948 .56513 Mdot
.948 .56516 Mdot
.948 .56518 Mdot
.948 .56529 Mdot
.948 .56534 Mdot
.948 .56547 Mdot
.948 .56554 Mdot
.948 .56557 Mdot
.948 .56562 Mdot
.948 .56567 Mdot
.948 .56569 Mdot
.948 .56571 Mdot
.948 .56583 Mdot
.948 .56598 Mdot
.948 .5661 Mdot
.948 .56613 Mdot
.948 .56615 Mdot
.948 .56616 Mdot
.948 .56619 Mdot
.948 .56621 Mdot
.948 .56625 Mdot
.948 .56633 Mdot
.948 .56635 Mdot
.948 .56636 Mdot
.948 .56637 Mdot
.948 .56651 Mdot
.948 .56656 Mdot
.948 .56659 Mdot
.948 .5666 Mdot
.948 .56666 Mdot
.948 .56673 Mdot
.948 .56675 Mdot
.948 .56676 Mdot
.948 .56678 Mdot
.948 .56683 Mdot
.948 .56683 Mdot
.948 .56687 Mdot
.948 .56703 Mdot
.948 .56724 Mdot
.948 .56725 Mdot
.948 .56727 Mdot
.948 .56733 Mdot
.948 .56739 Mdot
.948 .56745 Mdot
.948 .56748 Mdot
.948 .56766 Mdot
.948 .56767 Mdot
.948 .56773 Mdot
.948 .56773 Mdot
.948 .56783 Mdot
.948 .56784 Mdot
.948 .56788 Mdot
.948 .56795 Mdot
.948 .56801 Mdot
.948 .56803 Mdot
.948 .56809 Mdot
.948 .56811 Mdot
.948 .56816 Mdot
.948 .56818 Mdot
.948 .56818 Mdot
.948 .56828 Mdot
.948 .56834 Mdot
.948 .5684 Mdot
.948 .56842 Mdot
.948 .56842 Mdot
.948 .56847 Mdot
.948 .56872 Mdot
.948 .56875 Mdot
.948 .56877 Mdot
.948 .5688 Mdot
.948 .56882 Mdot
.948 .56883 Mdot
.948 .56889 Mdot
.948 .5689 Mdot
.948 .56893 Mdot
.948 .56902 Mdot
.948 .56909 Mdot
.948 .56912 Mdot
.948 .56919 Mdot
.948 .56921 Mdot
.948 .56921 Mdot
.948 .56926 Mdot
.948 .56932 Mdot
.948 .56936 Mdot
.948 .56947 Mdot
.948 .56962 Mdot
.948 .56965 Mdot
.948 .56978 Mdot
.948 .56984 Mdot
.948 .56994 Mdot
.948 .56999 Mdot
.948 .57006 Mdot
.948 .5701 Mdot
.948 .57015 Mdot
.948 .57016 Mdot
.948 .57038 Mdot
.948 .57059 Mdot
.948 .57066 Mdot
.948 .57088 Mdot
.948 .57093 Mdot
.948 .57097 Mdot
.948 .57099 Mdot
.948 .571 Mdot
.948 .57103 Mdot
.948 .57104 Mdot
.948 .57106 Mdot
.948 .57111 Mdot
.948 .57113 Mdot
.948 .57114 Mdot
.948 .57118 Mdot
.948 .57127 Mdot
.948 .57128 Mdot
.948 .57129 Mdot
.948 .57131 Mdot
.948 .57133 Mdot
.948 .57137 Mdot
.948 .57138 Mdot
.948 .57152 Mdot
.948 .57152 Mdot
.948 .57154 Mdot
.948 .5716 Mdot
.948 .57161 Mdot
.948 .57165 Mdot
.948 .57167 Mdot
.948 .57174 Mdot
.948 .57179 Mdot
.948 .57182 Mdot
.948 .57183 Mdot
.948 .57185 Mdot
.948 .57187 Mdot
.948 .57188 Mdot
.948 .57194 Mdot
.948 .57194 Mdot
.948 .57199 Mdot
.948 .572 Mdot
.948 .572 Mdot
.948 .57213 Mdot
.948 .57216 Mdot
.948 .57217 Mdot
.948 .57223 Mdot
.948 .57227 Mdot
.948 .57227 Mdot
.948 .57229 Mdot
.948 .57235 Mdot
.948 .57235 Mdot
.948 .57236 Mdot
.948 .57237 Mdot
.948 .57238 Mdot
.948 .57242 Mdot
.948 .57243 Mdot
.948 .57246 Mdot
.948 .57246 Mdot
.948 .57249 Mdot
.948 .5725 Mdot
.948 .57251 Mdot
.948 .57251 Mdot
.948 .57252 Mdot
.948 .57252 Mdot
.948 .57255 Mdot
.948 .57256 Mdot
.948 .57257 Mdot
.948 .57258 Mdot
.948 .57259 Mdot
.948 .57261 Mdot
.948 .57262 Mdot
.948 .57262 Mdot
.948 .57264 Mdot
.948 .57264 Mdot
.948 .57268 Mdot
.948 .57268 Mdot
.948 .57269 Mdot
.948 .5727 Mdot
.948 .57271 Mdot
.948 .57271 Mdot
.948 .57271 Mdot
.948 .57271 Mdot
.948 .57272 Mdot
.948 .57272 Mdot
.948 .57272 Mdot
.948 .57273 Mdot
.948 .57273 Mdot
.948 .57273 Mdot
.948 .57273 Mdot
.948 .57273 Mdot
.948 .57273 Mdot
.95 .10219 Mdot
.95 .1022 Mdot
.95 .1022 Mdot
.95 .10221 Mdot
.95 .10221 Mdot
.95 .10221 Mdot
.95 .10222 Mdot
.95 .10225 Mdot
.95 .1023 Mdot
.95 .10232 Mdot
.95 .10233 Mdot
.95 .10236 Mdot
.95 .10244 Mdot
.95 .10257 Mdot
.95 .10258 Mdot
.95 .10263 Mdot
.95 .10264 Mdot
.95 .10266 Mdot
.95 .10268 Mdot
.95 .10269 Mdot
.95 .10274 Mdot
.95 .10277 Mdot
.95 .10278 Mdot
.95 .10285 Mdot
.95 .10287 Mdot
.95 .10298 Mdot
.95 .10301 Mdot
.95 .10339 Mdot
.95 .10339 Mdot
.95 .1035 Mdot
.95 .1036 Mdot
.95 .10379 Mdot
.95 .10401 Mdot
.95 .10403 Mdot
.95 .10422 Mdot
.95 .10422 Mdot
.95 .10441 Mdot
.95 .10444 Mdot
.95 .10449 Mdot
.95 .10458 Mdot
.95 .10476 Mdot
.95 .10493 Mdot
.95 .10503 Mdot
.95 .10528 Mdot
.95 .10562 Mdot
.95 .10576 Mdot
.95 .10588 Mdot
.95 .10619 Mdot
.95 .10644 Mdot
.95 .10647 Mdot
.95 .10655 Mdot
.95 .10667 Mdot
.95 .10673 Mdot
.95 .10705 Mdot
.95 .10767 Mdot
.95 .10775 Mdot
.95 .10777 Mdot
.95 .10779 Mdot
.95 .10798 Mdot
.95 .10834 Mdot
.95 .10841 Mdot
.95 .10857 Mdot
.95 .1086 Mdot
.95 .1086 Mdot
.95 .10871 Mdot
.95 .10891 Mdot
.95 .10893 Mdot
.95 .10921 Mdot
.95 .10967 Mdot
.95 .11058 Mdot
.95 .11195 Mdot
.95 .11206 Mdot
.95 .11243 Mdot
.95 .11346 Mdot
.95 .11426 Mdot
.95 .11447 Mdot
.95 .11461 Mdot
.95 .11476 Mdot
.95 .11512 Mdot
.95 .11533 Mdot
.95 .11564 Mdot
.95 .11577 Mdot
.95 .11629 Mdot
.95 .1166 Mdot
.95 .11667 Mdot
.95 .11697 Mdot
.95 .1173 Mdot
.95 .11762 Mdot
.95 .11763 Mdot
.95 .11773 Mdot
.95 .11815 Mdot
.95 .11823 Mdot
.95 .11832 Mdot
.95 .11843 Mdot
.95 .11847 Mdot
.95 .11963 Mdot
.95 .12015 Mdot
.95 .12028 Mdot
.95 .12033 Mdot
.95 .12039 Mdot
.95 .12052 Mdot
.95 .12066 Mdot
.95 .12069 Mdot
.95 .12225 Mdot
.95 .12249 Mdot
.95 .12286 Mdot
.95 .12355 Mdot
.95 .12406 Mdot
.95 .1241 Mdot
.95 .12429 Mdot
.95 .12465 Mdot
.95 .12472 Mdot
.95 .12501 Mdot
.95 .12505 Mdot
.95 .12514 Mdot
.95 .12515 Mdot
.95 .12531 Mdot
.95 .12547 Mdot
.95 .12569 Mdot
.95 .12612 Mdot
.95 .12734 Mdot
.95 .12779 Mdot
.95 .12784 Mdot
.95 .12817 Mdot
.95 .1284 Mdot
.95 .12864 Mdot
.95 .12914 Mdot
.95 .12982 Mdot
.95 .12986 Mdot
.95 .1309 Mdot
.95 .13119 Mdot
.95 .13124 Mdot
.95 .13129 Mdot
.95 .13135 Mdot
.95 .13203 Mdot
.95 .13228 Mdot
.95 .13283 Mdot
.95 .13286 Mdot
.95 .13309 Mdot
.95 .13323 Mdot
.95 .13347 Mdot
.95 .13361 Mdot
.95 .1338 Mdot
.95 .13439 Mdot
.95 .13445 Mdot
.95 .13447 Mdot
.95 .1352 Mdot
.95 .13532 Mdot
.95 .13542 Mdot
.95 .13644 Mdot
.95 .13694 Mdot
.95 .13732 Mdot
.95 .13766 Mdot
.95 .13781 Mdot
.95 .13792 Mdot
.95 .13802 Mdot
.95 .13832 Mdot
.95 .13837 Mdot
.95 .14023 Mdot
.95 .14033 Mdot
.95 .14088 Mdot
.95 .14098 Mdot
.95 .14123 Mdot
.95 .14134 Mdot
.95 .1414 Mdot
.95 .14157 Mdot
.95 .14178 Mdot
.95 .14181 Mdot
.95 .14185 Mdot
.95 .14194 Mdot
.95 .14207 Mdot
.95 .14209 Mdot
.95 .14225 Mdot
.95 .14235 Mdot
.95 .14241 Mdot
.95 .14309 Mdot
.95 .14347 Mdot
.95 .14365 Mdot
.95 .14367 Mdot
.95 .14381 Mdot
.95 .14407 Mdot
.95 .14421 Mdot
.95 .14426 Mdot
.95 .14427 Mdot
.95 .14428 Mdot
.95 .1443 Mdot
.95 .14433 Mdot
.95 .14434 Mdot
.95 .14531 Mdot
.95 .1463 Mdot
.95 .14701 Mdot
.95 .14943 Mdot
.95 .14951 Mdot
.95 .15131 Mdot
.95 .15156 Mdot
.95 .153 Mdot
.95 .15338 Mdot
.95 .15378 Mdot
.95 .15433 Mdot
.95 .15484 Mdot
.95 .1564 Mdot
.95 .15662 Mdot
.95 .15862 Mdot
.95 .16283 Mdot
.95 .16289 Mdot
.95 .16447 Mdot
.95 .16481 Mdot
.95 .16665 Mdot
.95 .16724 Mdot
.95 .16742 Mdot
.95 .16981 Mdot
.95 .17004 Mdot
.95 .17037 Mdot
.95 .17095 Mdot
.95 .17234 Mdot
.95 .173 Mdot
.95 .17335 Mdot
.95 .17416 Mdot
.95 .17431 Mdot
.95 .17557 Mdot
.95 .17574 Mdot
.95 .17599 Mdot
.95 .17651 Mdot
.95 .17728 Mdot
.95 .17732 Mdot
.95 .1774 Mdot
.95 .17786 Mdot
.95 .17838 Mdot
.95 .17897 Mdot
.95 .17932 Mdot
.95 .18346 Mdot
.95 .18577 Mdot
.95 .18692 Mdot
.95 .18701 Mdot
.95 .18713 Mdot
.95 .18789 Mdot
.95 .18847 Mdot
.95 .18956 Mdot
.95 .19046 Mdot
.95 .19075 Mdot
.95 .19082 Mdot
.95 .19089 Mdot
.95 .19101 Mdot
.95 .19122 Mdot
.95 .19127 Mdot
.95 .19178 Mdot
.95 .19748 Mdot
.95 .19927 Mdot
.95 .20207 Mdot
.95 .20402 Mdot
.95 .20443 Mdot
.95 .20692 Mdot
.95 .20824 Mdot
.95 .20881 Mdot
.95 .20893 Mdot
.95 .20921 Mdot
.95 .20937 Mdot
.95 .21166 Mdot
.95 .21247 Mdot
.95 .21737 Mdot
.95 .21944 Mdot
.95 .22318 Mdot
.95 .22562 Mdot
.95 .22622 Mdot
.95 .23048 Mdot
.95 .23052 Mdot
.95 .23353 Mdot
.95 .23702 Mdot
.95 .23769 Mdot
.95 .23929 Mdot
.95 .23955 Mdot
.95 .24031 Mdot
.95 .24037 Mdot
.95 .24046 Mdot
.95 .24114 Mdot
.95 .24198 Mdot
.95 .24279 Mdot
.95 .24376 Mdot
.95 .24762 Mdot
.95 .24811 Mdot
.95 .25183 Mdot
.95 .25474 Mdot
.95 .25484 Mdot
.95 .25692 Mdot
.95 .25774 Mdot
.95 .25962 Mdot
.95 .262 Mdot
.95 .26384 Mdot
.95 .26542 Mdot
.95 .26592 Mdot
.95 .26641 Mdot
.95 .26642 Mdot
.95 .26644 Mdot
.95 .26645 Mdot
.95 .26645 Mdot
.95 .26646 Mdot
.95 .26648 Mdot
.95 .26655 Mdot
.95 .26669 Mdot
.95 .26676 Mdot
.95 .26677 Mdot
.95 .26687 Mdot
.95 .26706 Mdot
.95 .26742 Mdot
.95 .26745 Mdot
.95 .26758 Mdot
.95 .26759 Mdot
.95 .26766 Mdot
.95 .26771 Mdot
.95 .26775 Mdot
.95 .26786 Mdot
.95 .26795 Mdot
.95 .26798 Mdot
.95 .26817 Mdot
.95 .26822 Mdot
.95 .26852 Mdot
.95 .26857 Mdot
.95 .26959 Mdot
.95 .26961 Mdot
.95 .26989 Mdot
.95 .27016 Mdot
.95 .27066 Mdot
.95 .27124 Mdot
.95 .2713 Mdot
.95 .27179 Mdot
.95 .27181 Mdot
.95 .2723 Mdot
.95 .27238 Mdot
.95 .27252 Mdot
.95 .27276 Mdot
.95 .27324 Mdot
.95 .27369 Mdot
.95 .27393 Mdot
.95 .27457 Mdot
.95 .2746 Mdot
.95 .2755 Mdot
.95 .27586 Mdot
.95 .2759 Mdot
.95 .27619 Mdot
.95 .27701 Mdot
.95 .27766 Mdot
.95 .27773 Mdot
.95 .27776 Mdot
.95 .27797 Mdot
.95 .27801 Mdot
.95 .27826 Mdot
.95 .27843 Mdot
.95 .27879 Mdot
.95 .27928 Mdot
.95 .27972 Mdot
.95 .28089 Mdot
.95 .28112 Mdot
.95 .28117 Mdot
.95 .28121 Mdot
.95 .28172 Mdot
.95 .28264 Mdot
.95 .28277 Mdot
.95 .28284 Mdot
.95 .28325 Mdot
.95 .28333 Mdot
.95 .28334 Mdot
.95 .28361 Mdot
.95 .28415 Mdot
.95 .28421 Mdot
.95 .28494 Mdot
.95 .28553 Mdot
.95 .28613 Mdot
.95 .28632 Mdot
.95 .2885 Mdot
.95 .29207 Mdot
.95 .29236 Mdot
.95 .29332 Mdot
.95 .2936 Mdot
.95 .29363 Mdot
.95 .29539 Mdot
.95 .29557 Mdot
.95 .29597 Mdot
.95 .2967 Mdot
.95 .29804 Mdot
.95 .29856 Mdot
.95 .29894 Mdot
.95 .29931 Mdot
.95 .30023 Mdot
.95 .30078 Mdot
.95 .30156 Mdot
.95 .3019 Mdot
.95 .30315 Mdot
.95 .30322 Mdot
.95 .30402 Mdot
.95 .30421 Mdot
.95 .30447 Mdot
.95 .30496 Mdot
.95 .30581 Mdot
.95 .30663 Mdot
.95 .30666 Mdot
.95 .30692 Mdot
.95 .30752 Mdot
.95 .30798 Mdot
.95 .30817 Mdot
.95 .3084 Mdot
.95 .30867 Mdot
.95 .30879 Mdot
.95 .30983 Mdot
.95 .31172 Mdot
.95 .31304 Mdot
.95 .31336 Mdot
.95 .31338 Mdot
.95 .3135 Mdot
.95 .31365 Mdot
.95 .31399 Mdot
.95 .31433 Mdot
.95 .31441 Mdot
.95 .31619 Mdot
.95 .31678 Mdot
.95 .31788 Mdot
.95 .31832 Mdot
.95 .31833 Mdot
.95 .31881 Mdot
.95 .31893 Mdot
.95 .31984 Mdot
.95 .3205 Mdot
.95 .32112 Mdot
.95 .32157 Mdot
.95 .32253 Mdot
.95 .32284 Mdot
.95 .32294 Mdot
.95 .32343 Mdot
.95 .32431 Mdot
.95 .32448 Mdot
.95 .32522 Mdot
.95 .32532 Mdot
.95 .32552 Mdot
.95 .32556 Mdot
.95 .32557 Mdot
.95 .32596 Mdot
.95 .32634 Mdot
.95 .32689 Mdot
.95 .32795 Mdot
.95 .32944 Mdot
.95 .32994 Mdot
.95 .33097 Mdot
.95 .33207 Mdot
.95 .3322 Mdot
.95 .33272 Mdot
.95 .333 Mdot
.95 .33357 Mdot
.95 .33416 Mdot
.95 .33515 Mdot
.95 .33538 Mdot
.95 .33675 Mdot
.95 .33704 Mdot
.95 .33714 Mdot
.95 .33851 Mdot
.95 .33966 Mdot
.95 .34038 Mdot
.95 .3405 Mdot
.95 .34061 Mdot
.95 .34076 Mdot
.95 .3424 Mdot
.95 .34271 Mdot
.95 .34303 Mdot
.95 .34431 Mdot
.95 .34434 Mdot
.95 .3444 Mdot
.95 .34497 Mdot
.95 .34531 Mdot
.95 .34546 Mdot
.95 .34588 Mdot
.95 .34622 Mdot
.95 .34669 Mdot
.95 .34768 Mdot
.95 .34808 Mdot
.95 .34823 Mdot
.95 .34828 Mdot
.95 .35002 Mdot
.95 .35033 Mdot
.95 .35056 Mdot
.95 .35299 Mdot
.95 .35417 Mdot
.95 .35508 Mdot
.95 .3552 Mdot
.95 .35587 Mdot
.95 .35624 Mdot
.95 .3565 Mdot
.95 .35673 Mdot
.95 .35744 Mdot
.95 .35754 Mdot
.95 .36029 Mdot
.95 .36099 Mdot
.95 .36191 Mdot
.95 .36216 Mdot
.95 .36223 Mdot
.95 .36345 Mdot
.95 .36368 Mdot
.95 .36425 Mdot
.95 .36451 Mdot
.95 .36465 Mdot
.95 .36498 Mdot
.95 .36504 Mdot
.95 .36553 Mdot
.95 .3656 Mdot
.95 .3657 Mdot
.95 .3659 Mdot
.95 .36621 Mdot
.95 .36625 Mdot
.95 .36643 Mdot
.95 .36663 Mdot
.95 .36686 Mdot
.95 .367 Mdot
.95 .36858 Mdot
.95 .36944 Mdot
.95 .36987 Mdot
.95 .3699 Mdot
.95 .37023 Mdot
.95 .37084 Mdot
.95 .37116 Mdot
.95 .37127 Mdot
.95 .3713 Mdot
.95 .37132 Mdot
.95 .37136 Mdot
.95 .37144 Mdot
.95 .37146 Mdot
.95 .37164 Mdot
.95 .37367 Mdot
.95 .37594 Mdot
.95 .37736 Mdot
.95 .37756 Mdot
.95 .38224 Mdot
.95 .38301 Mdot
.95 .3832 Mdot
.95 .38454 Mdot
.95 .38547 Mdot
.95 .38654 Mdot
.95 .38674 Mdot
.95 .38723 Mdot
.95 .38731 Mdot
.95 .38755 Mdot
.95 .38779 Mdot
.95 .38804 Mdot
.95 .38828 Mdot
.95 .38857 Mdot
.95 .38972 Mdot
.95 .38986 Mdot
.95 .39096 Mdot
.95 .39181 Mdot
.95 .39268 Mdot
.95 .39322 Mdot
.95 .3939 Mdot
.95 .39443 Mdot
.95 .39502 Mdot
.95 .39745 Mdot
.95 .39782 Mdot
.95 .39834 Mdot
.95 .39841 Mdot
.95 .39888 Mdot
.95 .39972 Mdot
.95 .40048 Mdot
.95 .40267 Mdot
.95 .40268 Mdot
.95 .40316 Mdot
.95 .4032 Mdot
.95 .40351 Mdot
.95 .40523 Mdot
.95 .40701 Mdot
.95 .40794 Mdot
.95 .40938 Mdot
.95 .40998 Mdot
.95 .41035 Mdot
.95 .41215 Mdot
.95 .41228 Mdot
.95 .413 Mdot
.95 .4145 Mdot
.95 .41558 Mdot
.95 .41628 Mdot
.95 .41686 Mdot
.95 .42009 Mdot
.95 .42027 Mdot
.95 .42128 Mdot
.95 .42166 Mdot
.95 .42299 Mdot
.95 .42445 Mdot
.95 .42569 Mdot
.95 .42652 Mdot
.95 .42699 Mdot
.95 .42764 Mdot
.95 .42881 Mdot
.95 .42968 Mdot
.95 .42981 Mdot
.95 .43036 Mdot
.95 .43093 Mdot
.95 .43159 Mdot
.95 .43204 Mdot
.95 .43265 Mdot
.95 .43281 Mdot
.95 .43291 Mdot
.95 .43359 Mdot
.95 .43398 Mdot
.95 .43519 Mdot
.95 .43548 Mdot
.95 .43619 Mdot
.95 .43658 Mdot
.95 .4369 Mdot
.95 .43795 Mdot
.95 .43799 Mdot
.95 .43813 Mdot
.95 .43828 Mdot
.95 .43858 Mdot
.95 .43878 Mdot
.95 .43978 Mdot
.95 .43987 Mdot
.95 .44015 Mdot
.95 .44031 Mdot
.95 .44127 Mdot
.95 .44135 Mdot
.95 .4415 Mdot
.95 .44217 Mdot
.95 .4424 Mdot
.95 .44247 Mdot
.95 .44303 Mdot
.95 .44319 Mdot
.95 .44339 Mdot
.95 .44451 Mdot
.95 .4451 Mdot
.95 .44518 Mdot
.95 .44549 Mdot
.95 .44605 Mdot
.95 .44633 Mdot
.95 .44661 Mdot
.95 .44668 Mdot
.95 .44866 Mdot
.95 .44927 Mdot
.95 .44999 Mdot
.95 .45132 Mdot
.95 .45185 Mdot
.95 .45297 Mdot
.95 .4541 Mdot
.95 .45482 Mdot
.95 .45608 Mdot
.95 .45626 Mdot
.95 .45654 Mdot
.95 .45722 Mdot
.95 .45766 Mdot
.95 .45849 Mdot
.95 .4593 Mdot
.95 .45946 Mdot
.95 .45968 Mdot
.95 .45969 Mdot
.95 .4607 Mdot
.95 .46105 Mdot
.95 .46169 Mdot
.95 .46193 Mdot
.95 .4621 Mdot
.95 .46349 Mdot
.95 .46404 Mdot
.95 .46556 Mdot
.95 .46562 Mdot
.95 .46614 Mdot
.95 .46627 Mdot
.95 .46638 Mdot
.95 .4666 Mdot
.95 .46671 Mdot
.95 .46696 Mdot
.95 .46705 Mdot
.95 .46753 Mdot
.95 .46795 Mdot
.95 .46897 Mdot
.95 .47113 Mdot
.95 .47363 Mdot
.95 .47589 Mdot
.95 .47652 Mdot
.95 .4777 Mdot
.95 .47822 Mdot
.95 .47852 Mdot
.95 .48068 Mdot
.95 .48384 Mdot
.95 .48477 Mdot
.95 .48524 Mdot
.95 .4859 Mdot
.95 .48764 Mdot
.95 .48836 Mdot
.95 .48901 Mdot
.95 .49 Mdot
.95 .49113 Mdot
.95 .49134 Mdot
.95 .4929 Mdot
.95 .49413 Mdot
.95 .49469 Mdot
.95 .49494 Mdot
.95 .49561 Mdot
.95 .49581 Mdot
.95 .49598 Mdot
.95 .49642 Mdot
.95 .49666 Mdot
.95 .49778 Mdot
.95 .49918 Mdot
.95 .50009 Mdot
.95 .50128 Mdot
.95 .5018 Mdot
.95 .50431 Mdot
.95 .50475 Mdot
.95 .50482 Mdot
.95 .5055 Mdot
.95 .50551 Mdot
.95 .50832 Mdot
.95 .50862 Mdot
.95 .50968 Mdot
.95 .51084 Mdot
.95 .51119 Mdot
.95 .51149 Mdot
.95 .51158 Mdot
.95 .51229 Mdot
.95 .51279 Mdot
.95 .51605 Mdot
.95 .51624 Mdot
.95 .51683 Mdot
.95 .51752 Mdot
.95 .51841 Mdot
.95 .5191 Mdot
.95 .51941 Mdot
.95 .52018 Mdot
.95 .52022 Mdot
.95 .5213 Mdot
.95 .52267 Mdot
.95 .52285 Mdot
.95 .52427 Mdot
.95 .52463 Mdot
.95 .52492 Mdot
.95 .52523 Mdot
.95 .52548 Mdot
.95 .52552 Mdot
.95 .52554 Mdot
.95 .52581 Mdot
.95 .52591 Mdot
.95 .5265 Mdot
.95 .52674 Mdot
.95 .52801 Mdot
.95 .52911 Mdot
.95 .52912 Mdot
.95 .53067 Mdot
.95 .53088 Mdot
.95 .53177 Mdot
.95 .53312 Mdot
.95 .53386 Mdot
.95 .53562 Mdot
.95 .53591 Mdot
.95 .53673 Mdot
.95 .53678 Mdot
.95 .53688 Mdot
.95 .53693 Mdot
.95 .53713 Mdot
.95 .5376 Mdot
.95 .53849 Mdot
.95 .53864 Mdot
.95 .53933 Mdot
.95 .54032 Mdot
.95 .54096 Mdot
.95 .54298 Mdot
.95 .54316 Mdot
.95 .54317 Mdot
.95 .54325 Mdot
.95 .54329 Mdot
.95 .54331 Mdot
.95 .54334 Mdot
.95 .54344 Mdot
.95 .54376 Mdot
.95 .54414 Mdot
.95 .54435 Mdot
.95 .54462 Mdot
.95 .54466 Mdot
.95 .54469 Mdot
.95 .54509 Mdot
.95 .54591 Mdot
.95 .54736 Mdot
.95 .54748 Mdot
.95 .54769 Mdot
.95 .54787 Mdot
.95 .54803 Mdot
.95 .54806 Mdot
.95 .54807 Mdot
.95 .54835 Mdot
.95 .54853 Mdot
.95 .54861 Mdot
.95 .54867 Mdot
.95 .54911 Mdot
.95 .54917 Mdot
.95 .54945 Mdot
.95 .54957 Mdot
.95 .5498 Mdot
.95 .55029 Mdot
.95 .55049 Mdot
.95 .55061 Mdot
.95 .55069 Mdot
.95 .55152 Mdot
.95 .55158 Mdot
.95 .55179 Mdot
.95 .55243 Mdot
.95 .55254 Mdot
.95 .55309 Mdot
.95 .55311 Mdot
.95 .55458 Mdot
.95 .55527 Mdot
.95 .55535 Mdot
.95 .55589 Mdot
.95 .55606 Mdot
.95 .55625 Mdot
.95 .55639 Mdot
.95 .55652 Mdot
.95 .55702 Mdot
.95 .55711 Mdot
.95 .55773 Mdot
.95 .55776 Mdot
.95 .55859 Mdot
.95 .55884 Mdot
.95 .55918 Mdot
.95 .55951 Mdot
.95 .55951 Mdot
.95 .55952 Mdot
.95 .55953 Mdot
.95 .55953 Mdot
.95 .55954 Mdot
.95 .55955 Mdot
.95 .5596 Mdot
.95 .55969 Mdot
.95 .55974 Mdot
.95 .55975 Mdot
.95 .55981 Mdot
.95 .55994 Mdot
.95 .56018 Mdot
.95 .5602 Mdot
.95 .56023 Mdot
.95 .56029 Mdot
.95 .56029 Mdot
.95 .56034 Mdot
.95 .56037 Mdot
.95 .56038 Mdot
.95 .56039 Mdot
.95 .56047 Mdot
.95 .56052 Mdot
.95 .56054 Mdot
.95 .56058 Mdot
.95 .56067 Mdot
.95 .5607 Mdot
.95 .56089 Mdot
.95 .56093 Mdot
.95 .56157 Mdot
.95 .56158 Mdot
.95 .56168 Mdot
.95 .56172 Mdot
.95 .56176 Mdot
.95 .56181 Mdot
.95 .56192 Mdot
.95 .56206 Mdot
.95 .56223 Mdot
.95 .56258 Mdot
.95 .56261 Mdot
.95 .56266 Mdot
.95 .5629 Mdot
.95 .56291 Mdot
.95 .56293 Mdot
.95 .56313 Mdot
.95 .5632 Mdot
.95 .56325 Mdot
.95 .56333 Mdot
.95 .56338 Mdot
.95 .56346 Mdot
.95 .56347 Mdot
.95 .56365 Mdot
.95 .56374 Mdot
.95 .56397 Mdot
.95 .564 Mdot
.95 .56401 Mdot
.95 .56403 Mdot
.95 .56413 Mdot
.95 .56448 Mdot
.95 .5645 Mdot
.95 .56473 Mdot
.95 .5649 Mdot
.95 .56498 Mdot
.95 .56506 Mdot
.95 .56517 Mdot
.95 .56519 Mdot
.95 .56535 Mdot
.95 .56577 Mdot
.95 .56591 Mdot
.95 .56599 Mdot
.95 .56604 Mdot
.95 .56609 Mdot
.95 .5661 Mdot
.95 .56613 Mdot
.95 .56614 Mdot
.95 .56624 Mdot
.95 .56627 Mdot
.95 .56639 Mdot
.95 .56646 Mdot
.95 .56647 Mdot
.95 .56664 Mdot
.95 .56688 Mdot
.95 .567 Mdot
.95 .56709 Mdot
.95 .56762 Mdot
.95 .56763 Mdot
.95 .56767 Mdot
.95 .56772 Mdot
.95 .56774 Mdot
.95 .56776 Mdot
.95 .5678 Mdot
.95 .56798 Mdot
.95 .56838 Mdot
.95 .56839 Mdot
.95 .56843 Mdot
.95 .56846 Mdot
.95 .56848 Mdot
.95 .56863 Mdot
.95 .56866 Mdot
.95 .56866 Mdot
.95 .56877 Mdot
.95 .56889 Mdot
.95 .56899 Mdot
.95 .56901 Mdot
.95 .56912 Mdot
.95 .5693 Mdot
.95 .56934 Mdot
.95 .56945 Mdot
.95 .56952 Mdot
.95 .56964 Mdot
.95 .56969 Mdot
.95 .56974 Mdot
.95 .56981 Mdot
.95 .57008 Mdot
.95 .57043 Mdot
.95 .57056 Mdot
.95 .5706 Mdot
.95 .57106 Mdot
.95 .57137 Mdot
.95 .57153 Mdot
.95 .57162 Mdot
.95 .57163 Mdot
.95 .5717 Mdot
.95 .57173 Mdot
.95 .57174 Mdot
.95 .57175 Mdot
.95 .5718 Mdot
.95 .57183 Mdot
.95 .57195 Mdot
.95 .57201 Mdot
.95 .57202 Mdot
.95 .57202 Mdot
.95 .57205 Mdot
.95 .57226 Mdot
.95 .57237 Mdot
.95 .57239 Mdot
.95 .57243 Mdot
.95 .57246 Mdot
.95 .57247 Mdot
.95 .57255 Mdot
.95 .57266 Mdot
.95 .5727 Mdot
.95 .57275 Mdot
.95 .57286 Mdot
.95 .57295 Mdot
.95 .57298 Mdot
.95 .57304 Mdot
.95 .5731 Mdot
.95 .57313 Mdot
.95 .57315 Mdot
.95 .57316 Mdot
.95 .57322 Mdot
.95 .57322 Mdot
.95 .57329 Mdot
.95 .57329 Mdot
.95 .57337 Mdot
.95 .57343 Mdot
.95 .57347 Mdot
.95 .5735 Mdot
.95 .57351 Mdot
.95 .57364 Mdot
.95 .57364 Mdot
.95 .57368 Mdot
.95 .57369 Mdot
.95 .57371 Mdot
.95 .57372 Mdot
.95 .57373 Mdot
.95 .57374 Mdot
.95 .57375 Mdot
.95 .57375 Mdot
.95 .57376 Mdot
.95 .57376 Mdot
.95 .57378 Mdot
.95 .57378 Mdot
.95 .57383 Mdot
.95 .57385 Mdot
.95 .57387 Mdot
.95 .57387 Mdot
.95 .57388 Mdot
.95 .57389 Mdot
.95 .5739 Mdot
.95 .57391 Mdot
.95 .57391 Mdot
.95 .57391 Mdot
.95 .57391 Mdot
.95 .57391 Mdot
.952 .0989 Mdot
.952 .09891 Mdot
.952 .09892 Mdot
.952 .09896 Mdot
.952 .09896 Mdot
.952 .09898 Mdot
.952 .09898 Mdot
.952 .09899 Mdot
.952 .09922 Mdot
.952 .09922 Mdot
.952 .09925 Mdot
.952 .09937 Mdot
.952 .09947 Mdot
.952 .09951 Mdot
.952 .09962 Mdot
.952 .09963 Mdot
.952 .09984 Mdot
.952 .0999 Mdot
.952 .09993 Mdot
.952 .10019 Mdot
.952 .10037 Mdot
.952 .1004 Mdot
.952 .10043 Mdot
.952 .10044 Mdot
.952 .10069 Mdot
.952 .10097 Mdot
.952 .10099 Mdot
.952 .10103 Mdot
.952 .10148 Mdot
.952 .1016 Mdot
.952 .10174 Mdot
.952 .10176 Mdot
.952 .10207 Mdot
.952 .10224 Mdot
.952 .10269 Mdot
.952 .10272 Mdot
.952 .10282 Mdot
.952 .10285 Mdot
.952 .10285 Mdot
.952 .10285 Mdot
.952 .10296 Mdot
.952 .10299 Mdot
.952 .10301 Mdot
.952 .10302 Mdot
.952 .10308 Mdot
.952 .10315 Mdot
.952 .10317 Mdot
.952 .10321 Mdot
.952 .10337 Mdot
.952 .10347 Mdot
.952 .10363 Mdot
.952 .10385 Mdot
.952 .10429 Mdot
.952 .10464 Mdot
.952 .10494 Mdot
.952 .10537 Mdot
.952 .10564 Mdot
.952 .10636 Mdot
.952 .10642 Mdot
.952 .10704 Mdot
.952 .10797 Mdot
.952 .10815 Mdot
.952 .10872 Mdot
.952 .10875 Mdot
.952 .10879 Mdot
.952 .10881 Mdot
.952 .1091 Mdot
.952 .11025 Mdot
.952 .11063 Mdot
.952 .11225 Mdot
.952 .1128 Mdot
.952 .11309 Mdot
.952 .11317 Mdot
.952 .11317 Mdot
.952 .11328 Mdot
.952 .1133 Mdot
.952 .11338 Mdot
.952 .11424 Mdot
.952 .11516 Mdot
.952 .11517 Mdot
.952 .11574 Mdot
.952 .11658 Mdot
.952 .1168 Mdot
.952 .11687 Mdot
.952 .11865 Mdot
.952 .11895 Mdot
.952 .11907 Mdot
.952 .11909 Mdot
.952 .12033 Mdot
.952 .12052 Mdot
.952 .1209 Mdot
.952 .12125 Mdot
.952 .12147 Mdot
.952 .12266 Mdot
.952 .12345 Mdot
.952 .12368 Mdot
.952 .12378 Mdot
.952 .12433 Mdot
.952 .1254 Mdot
.952 .12543 Mdot
.952 .12572 Mdot
.952 .12614 Mdot
.952 .12647 Mdot
.952 .12649 Mdot
.952 .12723 Mdot
.952 .12854 Mdot
.952 .13007 Mdot
.952 .13008 Mdot
.952 .13044 Mdot
.952 .13061 Mdot
.952 .13141 Mdot
.952 .13213 Mdot
.952 .13303 Mdot
.952 .13312 Mdot
.952 .13336 Mdot
.952 .13374 Mdot
.952 .13382 Mdot
.952 .1339 Mdot
.952 .13437 Mdot
.952 .13515 Mdot
.952 .13535 Mdot
.952 .13543 Mdot
.952 .13569 Mdot
.952 .13575 Mdot
.952 .13579 Mdot
.952 .13608 Mdot
.952 .1361 Mdot
.952 .13624 Mdot
.952 .13637 Mdot
.952 .13681 Mdot
.952 .13691 Mdot
.952 .13692 Mdot
.952 .13693 Mdot
.952 .13708 Mdot
.952 .13718 Mdot
.952 .13757 Mdot
.952 .13773 Mdot
.952 .13927 Mdot
.952 .13958 Mdot
.952 .14002 Mdot
.952 .14019 Mdot
.952 .14057 Mdot
.952 .14087 Mdot
.952 .14181 Mdot
.952 .14207 Mdot
.952 .14229 Mdot
.952 .14253 Mdot
.952 .14265 Mdot
.952 .14307 Mdot
.952 .1434 Mdot
.952 .14366 Mdot
.952 .14367 Mdot
.952 .14404 Mdot
.952 .14443 Mdot
.952 .14484 Mdot
.952 .14504 Mdot
.952 .1463 Mdot
.952 .14652 Mdot
.952 .14671 Mdot
.952 .14685 Mdot
.952 .1472 Mdot
.952 .14775 Mdot
.952 .14776 Mdot
.952 .14785 Mdot
.952 .14839 Mdot
.952 .14858 Mdot
.952 .14907 Mdot
.952 .14938 Mdot
.952 .14975 Mdot
.952 .14982 Mdot
.952 .14987 Mdot
.952 .14995 Mdot
.952 .15009 Mdot
.952 .15024 Mdot
.952 .15109 Mdot
.952 .15126 Mdot
.952 .15191 Mdot
.952 .15253 Mdot
.952 .15284 Mdot
.952 .15298 Mdot
.952 .15333 Mdot
.952 .15461 Mdot
.952 .15468 Mdot
.952 .15534 Mdot
.952 .15557 Mdot
.952 .1562 Mdot
.952 .15639 Mdot
.952 .15656 Mdot
.952 .1569 Mdot
.952 .15709 Mdot
.952 .15711 Mdot
.952 .15715 Mdot
.952 .1585 Mdot
.952 .15853 Mdot
.952 .15856 Mdot
.952 .15859 Mdot
.952 .15869 Mdot
.952 .15873 Mdot
.952 .15899 Mdot
.952 .159 Mdot
.952 .15908 Mdot
.952 .16012 Mdot
.952 .16186 Mdot
.952 .16266 Mdot
.952 .16427 Mdot
.952 .16433 Mdot
.952 .16527 Mdot
.952 .16722 Mdot
.952 .16744 Mdot
.952 .16919 Mdot
.952 .17059 Mdot
.952 .17387 Mdot
.952 .17473 Mdot
.952 .17475 Mdot
.952 .17559 Mdot
.952 .17636 Mdot
.952 .17669 Mdot
.952 .17766 Mdot
.952 .17911 Mdot
.952 .17987 Mdot
.952 .18029 Mdot
.952 .18246 Mdot
.952 .18301 Mdot
.952 .18427 Mdot
.952 .18457 Mdot
.952 .18617 Mdot
.952 .18627 Mdot
.952 .18795 Mdot
.952 .18864 Mdot
.952 .18888 Mdot
.952 .19112 Mdot
.952 .19294 Mdot
.952 .19384 Mdot
.952 .19513 Mdot
.952 .19604 Mdot
.952 .19645 Mdot
.952 .19872 Mdot
.952 .20238 Mdot
.952 .20359 Mdot
.952 .20504 Mdot
.952 .20634 Mdot
.952 .20732 Mdot
.952 .2093 Mdot
.952 .20945 Mdot
.952 .20977 Mdot
.952 .21051 Mdot
.952 .21241 Mdot
.952 .21356 Mdot
.952 .21365 Mdot
.952 .21426 Mdot
.952 .21457 Mdot
.952 .21513 Mdot
.952 .21806 Mdot
.952 .21813 Mdot
.952 .21945 Mdot
.952 .21995 Mdot
.952 .2216 Mdot
.952 .22296 Mdot
.952 .22436 Mdot
.952 .22523 Mdot
.952 .22787 Mdot
.952 .22839 Mdot
.952 .22875 Mdot
.952 .22935 Mdot
.952 .23034 Mdot
.952 .2306 Mdot
.952 .23148 Mdot
.952 .23207 Mdot
.952 .23271 Mdot
.952 .23464 Mdot
.952 .23756 Mdot
.952 .23774 Mdot
.952 .23844 Mdot
.952 .23906 Mdot
.952 .24176 Mdot
.952 .24379 Mdot
.952 .24393 Mdot
.952 .24501 Mdot
.952 .24646 Mdot
.952 .24679 Mdot
.952 .24859 Mdot
.952 .25097 Mdot
.952 .25206 Mdot
.952 .25471 Mdot
.952 .25592 Mdot
.952 .25659 Mdot
.952 .25811 Mdot
.952 .25815 Mdot
.952 .25815 Mdot
.952 .25826 Mdot
.952 .25828 Mdot
.952 .25832 Mdot
.952 .25833 Mdot
.952 .25835 Mdot
.952 .25836 Mdot
.952 .25895 Mdot
.952 .25897 Mdot
.952 .25897 Mdot
.952 .25906 Mdot
.952 .25921 Mdot
.952 .25928 Mdot
.952 .25936 Mdot
.952 .25964 Mdot
.952 .25975 Mdot
.952 .26004 Mdot
.952 .26007 Mdot
.952 .26065 Mdot
.952 .2608 Mdot
.952 .26087 Mdot
.952 .26159 Mdot
.952 .26206 Mdot
.952 .26213 Mdot
.952 .2622 Mdot
.952 .26223 Mdot
.952 .26226 Mdot
.952 .26293 Mdot
.952 .26366 Mdot
.952 .26373 Mdot
.952 .26382 Mdot
.952 .26392 Mdot
.952 .26463 Mdot
.952 .26503 Mdot
.952 .26521 Mdot
.952 .26535 Mdot
.952 .26551 Mdot
.952 .26572 Mdot
.952 .26578 Mdot
.952 .26662 Mdot
.952 .26706 Mdot
.952 .26826 Mdot
.952 .26834 Mdot
.952 .26855 Mdot
.952 .2686 Mdot
.952 .26868 Mdot
.952 .26869 Mdot
.952 .26869 Mdot
.952 .26875 Mdot
.952 .26899 Mdot
.952 .26906 Mdot
.952 .26913 Mdot
.952 .26914 Mdot
.952 .2693 Mdot
.952 .2695 Mdot
.952 .26954 Mdot
.952 .26965 Mdot
.952 .27008 Mdot
.952 .27034 Mdot
.952 .27039 Mdot
.952 .27078 Mdot
.952 .27134 Mdot
.952 .27222 Mdot
.952 .27254 Mdot
.952 .27346 Mdot
.952 .27426 Mdot
.952 .27472 Mdot
.952 .2752 Mdot
.952 .27539 Mdot
.952 .2761 Mdot
.952 .27652 Mdot
.952 .2772 Mdot
.952 .27801 Mdot
.952 .27817 Mdot
.952 .27868 Mdot
.952 .27981 Mdot
.952 .28003 Mdot
.952 .28137 Mdot
.952 .2816 Mdot
.952 .28226 Mdot
.952 .28272 Mdot
.952 .28273 Mdot
.952 .28421 Mdot
.952 .28428 Mdot
.952 .2843 Mdot
.952 .28439 Mdot
.952 .28439 Mdot
.952 .28446 Mdot
.952 .28471 Mdot
.952 .28521 Mdot
.952 .28821 Mdot
.952 .2892 Mdot
.952 .29246 Mdot
.952 .29342 Mdot
.952 .29454 Mdot
.952 .29486 Mdot
.952 .29557 Mdot
.952 .2956 Mdot
.952 .29572 Mdot
.952 .29581 Mdot
.952 .29581 Mdot
.952 .29586 Mdot
.952 .29608 Mdot
.952 .29608 Mdot
.952 .29614 Mdot
.952 .2963 Mdot
.952 .29635 Mdot
.952 .29713 Mdot
.952 .29742 Mdot
.952 .29801 Mdot
.952 .29833 Mdot
.952 .29857 Mdot
.952 .29953 Mdot
.952 .2996 Mdot
.952 .29966 Mdot
.952 .3003 Mdot
.952 .30093 Mdot
.952 .30096 Mdot
.952 .30113 Mdot
.952 .30243 Mdot
.952 .3027 Mdot
.952 .30457 Mdot
.952 .30515 Mdot
.952 .30534 Mdot
.952 .30717 Mdot
.952 .30871 Mdot
.952 .30986 Mdot
.952 .3099 Mdot
.952 .31062 Mdot
.952 .31069 Mdot
.952 .31094 Mdot
.952 .31099 Mdot
.952 .31273 Mdot
.952 .31395 Mdot
.952 .31412 Mdot
.952 .31455 Mdot
.952 .3146 Mdot
.952 .31555 Mdot
.952 .31644 Mdot
.952 .317 Mdot
.952 .32 Mdot
.952 .32197 Mdot
.952 .32216 Mdot
.952 .32255 Mdot
.952 .3228 Mdot
.952 .32295 Mdot
.952 .32416 Mdot
.952 .32504 Mdot
.952 .32594 Mdot
.952 .32683 Mdot
.952 .3269 Mdot
.952 .32763 Mdot
.952 .32866 Mdot
.952 .32945 Mdot
.952 .32949 Mdot
.952 .32952 Mdot
.952 .32955 Mdot
.952 .33099 Mdot
.952 .33136 Mdot
.952 .33457 Mdot
.952 .33663 Mdot
.952 .33834 Mdot
.952 .33836 Mdot
.952 .33924 Mdot
.952 .33964 Mdot
.952 .34138 Mdot
.952 .3416 Mdot
.952 .34265 Mdot
.952 .34312 Mdot
.952 .34333 Mdot
.952 .34552 Mdot
.952 .34574 Mdot
.952 .3463 Mdot
.952 .34723 Mdot
.952 .34741 Mdot
.952 .34763 Mdot
.952 .3487 Mdot
.952 .34874 Mdot
.952 .35061 Mdot
.952 .35077 Mdot
.952 .35109 Mdot
.952 .35128 Mdot
.952 .35191 Mdot
.952 .35205 Mdot
.952 .35216 Mdot
.952 .35284 Mdot
.952 .35322 Mdot
.952 .35352 Mdot
.952 .35457 Mdot
.952 .35482 Mdot
.952 .35483 Mdot
.952 .35487 Mdot
.952 .35522 Mdot
.952 .35545 Mdot
.952 .3556 Mdot
.952 .35577 Mdot
.952 .35639 Mdot
.952 .35677 Mdot
.952 .35705 Mdot
.952 .36039 Mdot
.952 .36114 Mdot
.952 .36217 Mdot
.952 .36255 Mdot
.952 .36344 Mdot
.952 .36415 Mdot
.952 .36471 Mdot
.952 .36633 Mdot
.952 .36634 Mdot
.952 .36666 Mdot
.952 .36696 Mdot
.952 .36746 Mdot
.952 .36801 Mdot
.952 .36829 Mdot
.952 .36845 Mdot
.952 .36926 Mdot
.952 .36993 Mdot
.952 .37004 Mdot
.952 .37062 Mdot
.952 .37066 Mdot
.952 .37152 Mdot
.952 .3724 Mdot
.952 .37336 Mdot
.952 .37381 Mdot
.952 .37505 Mdot
.952 .37671 Mdot
.952 .37719 Mdot
.952 .37763 Mdot
.952 .37795 Mdot
.952 .3786 Mdot
.952 .37876 Mdot
.952 .37999 Mdot
.952 .38002 Mdot
.952 .38022 Mdot
.952 .38144 Mdot
.952 .38146 Mdot
.952 .38188 Mdot
.952 .38203 Mdot
.952 .38256 Mdot
.952 .38298 Mdot
.952 .38369 Mdot
.952 .38451 Mdot
.952 .38467 Mdot
.952 .38478 Mdot
.952 .38496 Mdot
.952 .38527 Mdot
.952 .38562 Mdot
.952 .38579 Mdot
.952 .38751 Mdot
.952 .3879 Mdot
.952 .38935 Mdot
.952 .39009 Mdot
.952 .39071 Mdot
.952 .3914 Mdot
.952 .39172 Mdot
.952 .39248 Mdot
.952 .39302 Mdot
.952 .39353 Mdot
.952 .39377 Mdot
.952 .39379 Mdot
.952 .39461 Mdot
.952 .3953 Mdot
.952 .39546 Mdot
.952 .39555 Mdot
.952 .3964 Mdot
.952 .39691 Mdot
.952 .39742 Mdot
.952 .39824 Mdot
.952 .39879 Mdot
.952 .3992 Mdot
.952 .39957 Mdot
.952 .4003 Mdot
.952 .40072 Mdot
.952 .40075 Mdot
.952 .40084 Mdot
.952 .40376 Mdot
.952 .40384 Mdot
.952 .4039 Mdot
.952 .40395 Mdot
.952 .40417 Mdot
.952 .40425 Mdot
.952 .40481 Mdot
.952 .40483 Mdot
.952 .40485 Mdot
.952 .40502 Mdot
.952 .40524 Mdot
.952 .40683 Mdot
.952 .40723 Mdot
.952 .40775 Mdot
.952 .41094 Mdot
.952 .41148 Mdot
.952 .41262 Mdot
.952 .41265 Mdot
.952 .416 Mdot
.952 .41612 Mdot
.952 .41754 Mdot
.952 .41807 Mdot
.952 .41929 Mdot
.952 .41966 Mdot
.952 .4221 Mdot
.952 .42255 Mdot
.952 .42584 Mdot
.952 .42599 Mdot
.952 .42612 Mdot
.952 .42803 Mdot
.952 .42878 Mdot
.952 .4289 Mdot
.952 .42897 Mdot
.952 .42897 Mdot
.952 .42963 Mdot
.952 .4323 Mdot
.952 .43253 Mdot
.952 .4355 Mdot
.952 .4372 Mdot
.952 .43724 Mdot
.952 .43797 Mdot
.952 .438 Mdot
.952 .43802 Mdot
.952 .43889 Mdot
.952 .44038 Mdot
.952 .44039 Mdot
.952 .44102 Mdot
.952 .4417 Mdot
.952 .44291 Mdot
.952 .44292 Mdot
.952 .44294 Mdot
.952 .44569 Mdot
.952 .4458 Mdot
.952 .44713 Mdot
.952 .44746 Mdot
.952 .4475 Mdot
.952 .44756 Mdot
.952 .44793 Mdot
.952 .44894 Mdot
.952 .44901 Mdot
.952 .45202 Mdot
.952 .4522 Mdot
.952 .45305 Mdot
.952 .45539 Mdot
.952 .45594 Mdot
.952 .4577 Mdot
.952 .45813 Mdot
.952 .45887 Mdot
.952 .45905 Mdot
.952 .46211 Mdot
.952 .46295 Mdot
.952 .46334 Mdot
.952 .46376 Mdot
.952 .46414 Mdot
.952 .46415 Mdot
.952 .46426 Mdot
.952 .46449 Mdot
.952 .46581 Mdot
.952 .46774 Mdot
.952 .46918 Mdot
.952 .46941 Mdot
.952 .46966 Mdot
.952 .47092 Mdot
.952 .47248 Mdot
.952 .4747 Mdot
.952 .47534 Mdot
.952 .47611 Mdot
.952 .47625 Mdot
.952 .47695 Mdot
.952 .48021 Mdot
.952 .48075 Mdot
.952 .48082 Mdot
.952 .48284 Mdot
.952 .4837 Mdot
.952 .48602 Mdot
.952 .48621 Mdot
.952 .48674 Mdot
.952 .48868 Mdot
.952 .49098 Mdot
.952 .49156 Mdot
.952 .4916 Mdot
.952 .49302 Mdot
.952 .49338 Mdot
.952 .49421 Mdot
.952 .49453 Mdot
.952 .49756 Mdot
.952 .4978 Mdot
.952 .49828 Mdot
.952 .49908 Mdot
.952 .4994 Mdot
.952 .49986 Mdot
.952 .50047 Mdot
.952 .50221 Mdot
.952 .50283 Mdot
.952 .50315 Mdot
.952 .5034 Mdot
.952 .50342 Mdot
.952 .50345 Mdot
.952 .50391 Mdot
.952 .50403 Mdot
.952 .50426 Mdot
.952 .50438 Mdot
.952 .5047 Mdot
.952 .50478 Mdot
.952 .50487 Mdot
.952 .50492 Mdot
.952 .50498 Mdot
.952 .50538 Mdot
.952 .50618 Mdot
.952 .50915 Mdot
.952 .50927 Mdot
.952 .50931 Mdot
.952 .50991 Mdot
.952 .51033 Mdot
.952 .51042 Mdot
.952 .51093 Mdot
.952 .51144 Mdot
.952 .512 Mdot
.952 .51226 Mdot
.952 .51276 Mdot
.952 .51294 Mdot
.952 .51388 Mdot
.952 .51457 Mdot
.952 .51519 Mdot
.952 .51526 Mdot
.952 .5164 Mdot
.952 .51651 Mdot
.952 .51673 Mdot
.952 .51699 Mdot
.952 .51764 Mdot
.952 .51872 Mdot
.952 .51875 Mdot
.952 .51885 Mdot
.952 .51906 Mdot
.952 .51972 Mdot
.952 .51997 Mdot
.952 .52042 Mdot
.952 .5214 Mdot
.952 .5218 Mdot
.952 .52267 Mdot
.952 .52334 Mdot
.952 .52346 Mdot
.952 .52399 Mdot
.952 .52439 Mdot
.952 .52444 Mdot
.952 .52518 Mdot
.952 .52617 Mdot
.952 .52639 Mdot
.952 .52665 Mdot
.952 .52671 Mdot
.952 .52778 Mdot
.952 .52848 Mdot
.952 .52871 Mdot
.952 .52892 Mdot
.952 .52924 Mdot
.952 .52934 Mdot
.952 .52969 Mdot
.952 .52991 Mdot
.952 .53004 Mdot
.952 .53023 Mdot
.952 .53118 Mdot
.952 .5315 Mdot
.952 .532 Mdot
.952 .53249 Mdot
.952 .53309 Mdot
.952 .53326 Mdot
.952 .53374 Mdot
.952 .53376 Mdot
.952 .53481 Mdot
.952 .53501 Mdot
.952 .53513 Mdot
.952 .53534 Mdot
.952 .53538 Mdot
.952 .53579 Mdot
.952 .53647 Mdot
.952 .53673 Mdot
.952 .5369 Mdot
.952 .5376 Mdot
.952 .53795 Mdot
.952 .53841 Mdot
.952 .53893 Mdot
.952 .53936 Mdot
.952 .54066 Mdot
.952 .54146 Mdot
.952 .5416 Mdot
.952 .54192 Mdot
.952 .54238 Mdot
.952 .5427 Mdot
.952 .54334 Mdot
.952 .54413 Mdot
.952 .54421 Mdot
.952 .54445 Mdot
.952 .54505 Mdot
.952 .54508 Mdot
.952 .54564 Mdot
.952 .54575 Mdot
.952 .54619 Mdot
.952 .54638 Mdot
.952 .54714 Mdot
.952 .54729 Mdot
.952 .54756 Mdot
.952 .54806 Mdot
.952 .5484 Mdot
.952 .54852 Mdot
.952 .54878 Mdot
.952 .54908 Mdot
.952 .54908 Mdot
.952 .54939 Mdot
.952 .55053 Mdot
.952 .55102 Mdot
.952 .55162 Mdot
.952 .5517 Mdot
.952 .55238 Mdot
.952 .5527 Mdot
.952 .55272 Mdot
.952 .55328 Mdot
.952 .55356 Mdot
.952 .55416 Mdot
.952 .55452 Mdot
.952 .55455 Mdot
.952 .55455 Mdot
.952 .55464 Mdot
.952 .55466 Mdot
.952 .55469 Mdot
.952 .5547 Mdot
.952 .55471 Mdot
.952 .55472 Mdot
.952 .55519 Mdot
.952 .55521 Mdot
.952 .55521 Mdot
.952 .55528 Mdot
.952 .55539 Mdot
.952 .55545 Mdot
.952 .55552 Mdot
.952 .55573 Mdot
.952 .55582 Mdot
.952 .55604 Mdot
.952 .55607 Mdot
.952 .55651 Mdot
.952 .55663 Mdot
.952 .55668 Mdot
.952 .55679 Mdot
.952 .557 Mdot
.952 .55722 Mdot
.952 .55728 Mdot
.952 .55757 Mdot
.952 .55763 Mdot
.952 .55767 Mdot
.952 .5577 Mdot
.952 .55772 Mdot
.952 .55774 Mdot
.952 .55787 Mdot
.952 .55798 Mdot
.952 .55815 Mdot
.952 .55821 Mdot
.952 .5584 Mdot
.952 .55843 Mdot
.952 .55843 Mdot
.952 .55862 Mdot
.952 .55874 Mdot
.952 .55879 Mdot
.952 .55886 Mdot
.952 .55893 Mdot
.952 .55936 Mdot
.952 .55943 Mdot
.952 .55958 Mdot
.952 .55971 Mdot
.952 .55984 Mdot
.952 .55984 Mdot
.952 .55993 Mdot
.952 .56004 Mdot
.952 .56019 Mdot
.952 .56023 Mdot
.952 .56031 Mdot
.952 .56038 Mdot
.952 .56047 Mdot
.952 .5608 Mdot
.952 .5609 Mdot
.952 .56103 Mdot
.952 .56109 Mdot
.952 .56124 Mdot
.952 .56135 Mdot
.952 .56187 Mdot
.952 .56193 Mdot
.952 .56206 Mdot
.952 .5621 Mdot
.952 .56215 Mdot
.952 .56215 Mdot
.952 .56215 Mdot
.952 .56219 Mdot
.952 .56234 Mdot
.952 .56238 Mdot
.952 .56243 Mdot
.952 .56244 Mdot
.952 .56254 Mdot
.952 .56255 Mdot
.952 .56257 Mdot
.952 .56266 Mdot
.952 .56269 Mdot
.952 .56276 Mdot
.952 .56303 Mdot
.952 .56318 Mdot
.952 .56321 Mdot
.952 .56324 Mdot
.952 .56337 Mdot
.952 .56345 Mdot
.952 .56348 Mdot
.952 .56379 Mdot
.952 .56404 Mdot
.952 .56431 Mdot
.952 .56437 Mdot
.952 .56449 Mdot
.952 .56449 Mdot
.952 .56502 Mdot
.952 .56547 Mdot
.952 .56572 Mdot
.952 .56572 Mdot
.952 .56584 Mdot
.952 .56598 Mdot
.952 .56608 Mdot
.952 .56609 Mdot
.952 .56646 Mdot
.952 .56664 Mdot
.952 .56667 Mdot
.952 .56675 Mdot
.952 .56702 Mdot
.952 .56743 Mdot
.952 .5675 Mdot
.952 .56762 Mdot
.952 .56775 Mdot
.952 .56782 Mdot
.952 .56824 Mdot
.952 .56824 Mdot
.952 .56829 Mdot
.952 .56839 Mdot
.952 .56899 Mdot
.952 .56902 Mdot
.952 .56909 Mdot
.952 .56938 Mdot
.952 .56957 Mdot
.952 .56958 Mdot
.952 .56989 Mdot
.952 .57018 Mdot
.952 .57021 Mdot
.952 .57022 Mdot
.952 .57025 Mdot
.952 .57025 Mdot
.952 .57028 Mdot
.952 .57038 Mdot
.952 .57056 Mdot
.952 .57112 Mdot
.952 .57124 Mdot
.952 .57163 Mdot
.952 .57173 Mdot
.952 .57174 Mdot
.952 .57175 Mdot
.952 .57176 Mdot
.952 .57195 Mdot
.952 .57201 Mdot
.952 .57233 Mdot
.952 .57254 Mdot
.952 .57256 Mdot
.952 .57281 Mdot
.952 .5729 Mdot
.952 .57304 Mdot
.952 .57314 Mdot
.952 .57326 Mdot
.952 .57341 Mdot
.952 .57349 Mdot
.952 .57354 Mdot
.952 .57357 Mdot
.952 .57363 Mdot
.952 .57364 Mdot
.952 .57365 Mdot
.952 .57367 Mdot
.952 .57369 Mdot
.952 .5737 Mdot
.952 .57371 Mdot
.952 .57371 Mdot
.952 .57375 Mdot
.952 .57375 Mdot
.952 .57375 Mdot
.952 .57376 Mdot
.952 .5738 Mdot
.952 .57381 Mdot
.952 .57396 Mdot
.952 .57401 Mdot
.952 .57412 Mdot
.952 .57413 Mdot
.952 .57418 Mdot
.952 .57422 Mdot
.952 .57437 Mdot
.952 .57438 Mdot
.952 .57439 Mdot
.952 .57448 Mdot
.952 .57457 Mdot
.952 .57457 Mdot
.952 .57458 Mdot
.952 .57459 Mdot
.952 .57465 Mdot
.952 .57474 Mdot
.952 .57475 Mdot
.952 .57477 Mdot
.952 .57484 Mdot
.952 .57485 Mdot
.952 .57488 Mdot
.952 .5749 Mdot
.952 .57493 Mdot
.952 .57497 Mdot
.952 .57498 Mdot
.952 .57498 Mdot
.952 .57506 Mdot
.952 .57506 Mdot
.952 .57506 Mdot
.952 .57507 Mdot
.952 .57507 Mdot
.952 .57508 Mdot
.952 .57508 Mdot
.952 .57509 Mdot
.954 .09559 Mdot
.954 .09563 Mdot
.954 .09564 Mdot
.954 .09566 Mdot
.954 .09567 Mdot
.954 .0957 Mdot
.954 .09571 Mdot
.954 .09574 Mdot
.954 .09574 Mdot
.954 .0959 Mdot
.954 .09594 Mdot
.954 .09594 Mdot
.954 .09598 Mdot
.954 .09606 Mdot
.954 .09609 Mdot
.954 .09617 Mdot
.954 .09623 Mdot
.954 .09624 Mdot
.954 .0967 Mdot
.954 .09674 Mdot
.954 .09674 Mdot
.954 .09681 Mdot
.954 .09693 Mdot
.954 .09703 Mdot
.954 .09705 Mdot
.954 .09717 Mdot
.954 .09724 Mdot
.954 .09764 Mdot
.954 .09768 Mdot
.954 .09782 Mdot
.954 .09802 Mdot
.954 .09806 Mdot
.954 .09846 Mdot
.954 .09933 Mdot
.954 .09935 Mdot
.954 .09972 Mdot
.954 .10019 Mdot
.954 .10093 Mdot
.954 .10096 Mdot
.954 .10118 Mdot
.954 .1012 Mdot
.954 .1016 Mdot
.954 .10179 Mdot
.954 .10179 Mdot
.954 .10228 Mdot
.954 .10243 Mdot
.954 .10354 Mdot
.954 .10356 Mdot
.954 .1042 Mdot
.954 .10427 Mdot
.954 .10528 Mdot
.954 .10539 Mdot
.954 .10543 Mdot
.954 .10581 Mdot
.954 .10602 Mdot
.954 .10607 Mdot
.954 .10647 Mdot
.954 .10703 Mdot
.954 .10756 Mdot
.954 .10788 Mdot
.954 .10958 Mdot
.954 .10979 Mdot
.954 .11004 Mdot
.954 .11019 Mdot
.954 .1102 Mdot
.954 .11098 Mdot
.954 .11156 Mdot
.954 .11211 Mdot
.954 .11211 Mdot
.954 .11223 Mdot
.954 .11318 Mdot
.954 .1141 Mdot
.954 .11445 Mdot
.954 .11482 Mdot
.954 .11501 Mdot
.954 .11535 Mdot
.954 .11614 Mdot
.954 .11634 Mdot
.954 .11707 Mdot
.954 .11708 Mdot
.954 .11862 Mdot
.954 .11879 Mdot
.954 .11893 Mdot
.954 .1195 Mdot
.954 .1196 Mdot
.954 .12077 Mdot
.954 .12091 Mdot
.954 .12115 Mdot
.954 .1213 Mdot
.954 .12178 Mdot
.954 .12243 Mdot
.954 .12305 Mdot
.954 .1233 Mdot
.954 .12612 Mdot
.954 .12642 Mdot
.954 .12937 Mdot
.954 .12948 Mdot
.954 .13482 Mdot
.954 .13489 Mdot
.954 .13566 Mdot
.954 .13601 Mdot
.954 .13635 Mdot
.954 .13669 Mdot
.954 .13752 Mdot
.954 .13824 Mdot
.954 .13824 Mdot
.954 .13926 Mdot
.954 .13999 Mdot
.954 .14 Mdot
.954 .14014 Mdot
.954 .1404 Mdot
.954 .14097 Mdot
.954 .14144 Mdot
.954 .14151 Mdot
.954 .1417 Mdot
.954 .14273 Mdot
.954 .14292 Mdot
.954 .14336 Mdot
.954 .1451 Mdot
.954 .14621 Mdot
.954 .14714 Mdot
.954 .14751 Mdot
.954 .14757 Mdot
.954 .14934 Mdot
.954 .1499 Mdot
.954 .15135 Mdot
.954 .15212 Mdot
.954 .15224 Mdot
.954 .15225 Mdot
.954 .15308 Mdot
.954 .1532 Mdot
.954 .1532 Mdot
.954 .15464 Mdot
.954 .156 Mdot
.954 .15647 Mdot
.954 .15768 Mdot
.954 .15883 Mdot
.954 .16025 Mdot
.954 .16051 Mdot
.954 .16183 Mdot
.954 .16277 Mdot
.954 .16296 Mdot
.954 .16298 Mdot
.954 .16302 Mdot
.954 .16302 Mdot
.954 .1636 Mdot
.954 .16382 Mdot
.954 .1653 Mdot
.954 .16533 Mdot
.954 .16563 Mdot
.954 .16571 Mdot
.954 .16571 Mdot
.954 .16592 Mdot
.954 .16617 Mdot
.954 .16699 Mdot
.954 .16717 Mdot
.954 .16733 Mdot
.954 .16771 Mdot
.954 .16772 Mdot
.954 .16784 Mdot
.954 .16802 Mdot
.954 .1687 Mdot
.954 .16912 Mdot
.954 .16915 Mdot
.954 .16919 Mdot
.954 .16945 Mdot
.954 .17095 Mdot
.954 .17155 Mdot
.954 .17196 Mdot
.954 .1721 Mdot
.954 .17265 Mdot
.954 .17269 Mdot
.954 .17278 Mdot
.954 .17313 Mdot
.954 .17316 Mdot
.954 .17371 Mdot
.954 .17395 Mdot
.954 .17447 Mdot
.954 .17478 Mdot
.954 .17479 Mdot
.954 .1751 Mdot
.954 .17585 Mdot
.954 .17621 Mdot
.954 .17623 Mdot
.954 .17644 Mdot
.954 .17655 Mdot
.954 .17671 Mdot
.954 .17672 Mdot
.954 .1768 Mdot
.954 .17698 Mdot
.954 .17704 Mdot
.954 .17736 Mdot
.954 .17784 Mdot
.954 .17869 Mdot
.954 .17953 Mdot
.954 .17955 Mdot
.954 .18015 Mdot
.954 .18074 Mdot
.954 .18201 Mdot
.954 .18351 Mdot
.954 .18511 Mdot
.954 .18536 Mdot
.954 .18804 Mdot
.954 .18895 Mdot
.954 .18906 Mdot
.954 .19195 Mdot
.954 .19291 Mdot
.954 .19493 Mdot
.954 .19606 Mdot
.954 .20249 Mdot
.954 .20266 Mdot
.954 .20341 Mdot
.954 .20367 Mdot
.954 .20444 Mdot
.954 .20531 Mdot
.954 .20903 Mdot
.954 .21159 Mdot
.954 .21204 Mdot
.954 .21287 Mdot
.954 .21447 Mdot
.954 .21675 Mdot
.954 .22376 Mdot
.954 .22475 Mdot
.954 .22482 Mdot
.954 .22578 Mdot
.954 .22619 Mdot
.954 .22796 Mdot
.954 .22902 Mdot
.954 .23274 Mdot
.954 .23328 Mdot
.954 .23988 Mdot
.954 .24042 Mdot
.954 .24406 Mdot
.954 .24576 Mdot
.954 .24671 Mdot
.954 .2468 Mdot
.954 .24792 Mdot
.954 .24914 Mdot
.954 .24963 Mdot
.954 .24975 Mdot
.954 .24978 Mdot
.954 .24984 Mdot
.954 .24987 Mdot
.954 .24993 Mdot
.954 .24998 Mdot
.954 .25006 Mdot
.954 .25006 Mdot
.954 .2502 Mdot
.954 .25048 Mdot
.954 .2506 Mdot
.954 .2506 Mdot
.954 .25072 Mdot
.954 .25092 Mdot
.954 .25101 Mdot
.954 .25122 Mdot
.954 .2514 Mdot
.954 .25141 Mdot
.954 .25163 Mdot
.954 .25265 Mdot
.954 .25275 Mdot
.954 .25277 Mdot
.954 .25278 Mdot
.954 .25296 Mdot
.954 .25322 Mdot
.954 .25328 Mdot
.954 .25349 Mdot
.954 .25355 Mdot
.954 .25362 Mdot
.954 .25395 Mdot
.954 .25405 Mdot
.954 .25413 Mdot
.954 .25413 Mdot
.954 .25416 Mdot
.954 .2543 Mdot
.954 .25498 Mdot
.954 .25522 Mdot
.954 .25524 Mdot
.954 .25532 Mdot
.954 .2557 Mdot
.954 .25625 Mdot
.954 .25636 Mdot
.954 .25744 Mdot
.954 .25795 Mdot
.954 .25874 Mdot
.954 .25978 Mdot
.954 .25984 Mdot
.954 .26083 Mdot
.954 .26209 Mdot
.954 .26408 Mdot
.954 .26417 Mdot
.954 .26477 Mdot
.954 .2648 Mdot
.954 .26544 Mdot
.954 .26551 Mdot
.954 .26588 Mdot
.954 .26639 Mdot
.954 .26639 Mdot
.954 .26676 Mdot
.954 .26718 Mdot
.954 .26771 Mdot
.954 .26812 Mdot
.954 .26816 Mdot
.954 .27106 Mdot
.954 .27113 Mdot
.954 .27283 Mdot
.954 .27302 Mdot
.954 .27489 Mdot
.954 .27528 Mdot
.954 .27569 Mdot
.954 .276 Mdot
.954 .2761 Mdot
.954 .27634 Mdot
.954 .27711 Mdot
.954 .27766 Mdot
.954 .27778 Mdot
.954 .27885 Mdot
.954 .28009 Mdot
.954 .28034 Mdot
.954 .28174 Mdot
.954 .28258 Mdot
.954 .28258 Mdot
.954 .2843 Mdot
.954 .28703 Mdot
.954 .28758 Mdot
.954 .28824 Mdot
.954 .28863 Mdot
.954 .28867 Mdot
.954 .28987 Mdot
.954 .2907 Mdot
.954 .29221 Mdot
.954 .29284 Mdot
.954 .29284 Mdot
.954 .29364 Mdot
.954 .29366 Mdot
.954 .29396 Mdot
.954 .29642 Mdot
.954 .2988 Mdot
.954 .29889 Mdot
.954 .29932 Mdot
.954 .29971 Mdot
.954 .30067 Mdot
.954 .30116 Mdot
.954 .30204 Mdot
.954 .30205 Mdot
.954 .30377 Mdot
.954 .30407 Mdot
.954 .30456 Mdot
.954 .30516 Mdot
.954 .30644 Mdot
.954 .30647 Mdot
.954 .30672 Mdot
.954 .30921 Mdot
.954 .3104 Mdot
.954 .31053 Mdot
.954 .31084 Mdot
.954 .31096 Mdot
.954 .31119 Mdot
.954 .31266 Mdot
.954 .31291 Mdot
.954 .31314 Mdot
.954 .31365 Mdot
.954 .31426 Mdot
.954 .31587 Mdot
.954 .31622 Mdot
.954 .31656 Mdot
.954 .31683 Mdot
.954 .31722 Mdot
.954 .31843 Mdot
.954 .32005 Mdot
.954 .3216 Mdot
.954 .32224 Mdot
.954 .32297 Mdot
.954 .32405 Mdot
.954 .32496 Mdot
.954 .32604 Mdot
.954 .32738 Mdot
.954 .32811 Mdot
.954 .32926 Mdot
.954 .33003 Mdot
.954 .33008 Mdot
.954 .33153 Mdot
.954 .33183 Mdot
.954 .33336 Mdot
.954 .33354 Mdot
.954 .33388 Mdot
.954 .3339 Mdot
.954 .33455 Mdot
.954 .33503 Mdot
.954 .33557 Mdot
.954 .33703 Mdot
.954 .3373 Mdot
.954 .33757 Mdot
.954 .33854 Mdot
.954 .33868 Mdot
.954 .3392 Mdot
.954 .34049 Mdot
.954 .34088 Mdot
.954 .3418 Mdot
.954 .34333 Mdot
.954 .35053 Mdot
.954 .3507 Mdot
.954 .35255 Mdot
.954 .35275 Mdot
.954 .35303 Mdot
.954 .35339 Mdot
.954 .35419 Mdot
.954 .35501 Mdot
.954 .35553 Mdot
.954 .35613 Mdot
.954 .35616 Mdot
.954 .35697 Mdot
.954 .35787 Mdot
.954 .35827 Mdot
.954 .35864 Mdot
.954 .35869 Mdot
.954 .35869 Mdot
.954 .35991 Mdot
.954 .36111 Mdot
.954 .36282 Mdot
.954 .36284 Mdot
.954 .36316 Mdot
.954 .36377 Mdot
.954 .36472 Mdot
.954 .36472 Mdot
.954 .36511 Mdot
.954 .36599 Mdot
.954 .36622 Mdot
.954 .36638 Mdot
.954 .36669 Mdot
.954 .36683 Mdot
.954 .36818 Mdot
.954 .3686 Mdot
.954 .36923 Mdot
.954 .36924 Mdot
.954 .36946 Mdot
.954 .36967 Mdot
.954 .37068 Mdot
.954 .37262 Mdot
.954 .37266 Mdot
.954 .37367 Mdot
.954 .3747 Mdot
.954 .37508 Mdot
.954 .37724 Mdot
.954 .3773 Mdot
.954 .37755 Mdot
.954 .37789 Mdot
.954 .37938 Mdot
.954 .38021 Mdot
.954 .38035 Mdot
.954 .38062 Mdot
.954 .38113 Mdot
.954 .38185 Mdot
.954 .38403 Mdot
.954 .38433 Mdot
.954 .38436 Mdot
.954 .38465 Mdot
.954 .38564 Mdot
.954 .38676 Mdot
.954 .38692 Mdot
.954 .38888 Mdot
.954 .39059 Mdot
.954 .39087 Mdot
.954 .39089 Mdot
.954 .39122 Mdot
.954 .39157 Mdot
.954 .3926 Mdot
.954 .39273 Mdot
.954 .39281 Mdot
.954 .39297 Mdot
.954 .39299 Mdot
.954 .393 Mdot
.954 .39304 Mdot
.954 .39407 Mdot
.954 .39617 Mdot
.954 .39619 Mdot
.954 .39653 Mdot
.954 .39665 Mdot
.954 .39692 Mdot
.954 .39877 Mdot
.954 .39887 Mdot
.954 .39916 Mdot
.954 .40018 Mdot
.954 .40085 Mdot
.954 .4028 Mdot
.954 .40359 Mdot
.954 .4053 Mdot
.954 .40683 Mdot
.954 .40723 Mdot
.954 .40788 Mdot
.954 .40822 Mdot
.954 .40833 Mdot
.954 .4089 Mdot
.954 .40919 Mdot
.954 .40978 Mdot
.954 .41143 Mdot
.954 .41171 Mdot
.954 .41194 Mdot
.954 .41221 Mdot
.954 .41256 Mdot
.954 .41325 Mdot
.954 .41369 Mdot
.954 .41408 Mdot
.954 .41413 Mdot
.954 .41422 Mdot
.954 .41422 Mdot
.954 .41451 Mdot
.954 .41501 Mdot
.954 .41543 Mdot
.954 .41589 Mdot
.954 .41599 Mdot
.954 .41622 Mdot
.954 .41661 Mdot
.954 .41898 Mdot
.954 .41905 Mdot
.954 .41969 Mdot
.954 .41984 Mdot
.954 .41984 Mdot
.954 .42027 Mdot
.954 .42037 Mdot
.954 .42047 Mdot
.954 .42079 Mdot
.954 .422 Mdot
.954 .42231 Mdot
.954 .42249 Mdot
.954 .42286 Mdot
.954 .42297 Mdot
.954 .42318 Mdot
.954 .42398 Mdot
.954 .42399 Mdot
.954 .42424 Mdot
.954 .42459 Mdot
.954 .42521 Mdot
.954 .4253 Mdot
.954 .42598 Mdot
.954 .42629 Mdot
.954 .42684 Mdot
.954 .42692 Mdot
.954 .427 Mdot
.954 .42753 Mdot
.954 .42757 Mdot
.954 .42865 Mdot
.954 .42874 Mdot
.954 .42905 Mdot
.954 .42909 Mdot
.954 .42937 Mdot
.954 .4299 Mdot
.954 .42999 Mdot
.954 .43009 Mdot
.954 .43055 Mdot
.954 .43058 Mdot
.954 .43108 Mdot
.954 .43177 Mdot
.954 .43259 Mdot
.954 .43286 Mdot
.954 .43319 Mdot
.954 .43334 Mdot
.954 .43376 Mdot
.954 .43389 Mdot
.954 .43396 Mdot
.954 .43405 Mdot
.954 .43423 Mdot
.954 .43468 Mdot
.954 .43493 Mdot
.954 .43499 Mdot
.954 .43509 Mdot
.954 .43607 Mdot
.954 .43647 Mdot
.954 .43655 Mdot
.954 .43672 Mdot
.954 .4373 Mdot
.954 .43757 Mdot
.954 .43818 Mdot
.954 .43821 Mdot
.954 .4383 Mdot
.954 .43837 Mdot
.954 .43856 Mdot
.954 .43868 Mdot
.954 .43881 Mdot
.954 .4394 Mdot
.954 .43951 Mdot
.954 .43955 Mdot
.954 .43975 Mdot
.954 .43986 Mdot
.954 .44028 Mdot
.954 .44044 Mdot
.954 .44072 Mdot
.954 .44077 Mdot
.954 .4408 Mdot
.954 .44099 Mdot
.954 .44103 Mdot
.954 .44111 Mdot
.954 .44136 Mdot
.954 .44144 Mdot
.954 .44166 Mdot
.954 .44178 Mdot
.954 .44194 Mdot
.954 .44196 Mdot
.954 .44199 Mdot
.954 .44213 Mdot
.954 .44242 Mdot
.954 .44248 Mdot
.954 .44258 Mdot
.954 .4426 Mdot
.954 .44266 Mdot
.954 .44302 Mdot
.954 .44309 Mdot
.954 .44318 Mdot
.954 .44322 Mdot
.954 .44373 Mdot
.954 .44402 Mdot
.954 .44415 Mdot
.954 .44484 Mdot
.954 .44505 Mdot
.954 .44544 Mdot
.954 .44551 Mdot
.954 .44572 Mdot
.954 .44579 Mdot
.954 .44685 Mdot
.954 .4471 Mdot
.954 .44734 Mdot
.954 .44739 Mdot
.954 .44743 Mdot
.954 .4477 Mdot
.954 .44783 Mdot
.954 .44785 Mdot
.954 .44801 Mdot
.954 .44805 Mdot
.954 .44859 Mdot
.954 .44921 Mdot
.954 .4497 Mdot
.954 .44974 Mdot
.954 .45083 Mdot
.954 .45115 Mdot
.954 .45131 Mdot
.954 .45205 Mdot
.954 .45209 Mdot
.954 .4539 Mdot
.954 .45408 Mdot
.954 .45419 Mdot
.954 .45466 Mdot
.954 .4549 Mdot
.954 .4555 Mdot
.954 .45582 Mdot
.954 .45599 Mdot
.954 .45612 Mdot
.954 .45636 Mdot
.954 .45713 Mdot
.954 .45741 Mdot
.954 .45786 Mdot
.954 .45802 Mdot
.954 .45832 Mdot
.954 .45851 Mdot
.954 .46002 Mdot
.954 .46128 Mdot
.954 .46219 Mdot
.954 .46224 Mdot
.954 .46308 Mdot
.954 .4632 Mdot
.954 .46325 Mdot
.954 .46341 Mdot
.954 .46437 Mdot
.954 .46484 Mdot
.954 .46487 Mdot
.954 .46494 Mdot
.954 .46504 Mdot
.954 .4655 Mdot
.954 .46566 Mdot
.954 .46758 Mdot
.954 .46765 Mdot
.954 .46859 Mdot
.954 .46873 Mdot
.954 .46887 Mdot
.954 .46983 Mdot
.954 .47015 Mdot
.954 .47037 Mdot
.954 .47157 Mdot
.954 .47172 Mdot
.954 .47183 Mdot
.954 .47279 Mdot
.954 .47341 Mdot
.954 .47385 Mdot
.954 .47386 Mdot
.954 .47523 Mdot
.954 .47532 Mdot
.954 .4756 Mdot
.954 .47578 Mdot
.954 .47641 Mdot
.954 .47672 Mdot
.954 .47726 Mdot
.954 .47726 Mdot
.954 .4793 Mdot
.954 .47984 Mdot
.954 .47999 Mdot
.954 .48016 Mdot
.954 .48088 Mdot
.954 .48089 Mdot
.954 .48115 Mdot
.954 .4822 Mdot
.954 .48231 Mdot
.954 .48622 Mdot
.954 .48684 Mdot
.954 .48722 Mdot
.954 .48738 Mdot
.954 .48791 Mdot
.954 .48812 Mdot
.954 .48818 Mdot
.954 .4888 Mdot
.954 .48939 Mdot
.954 .48961 Mdot
.954 .4898 Mdot
.954 .49007 Mdot
.954 .49008 Mdot
.954 .49022 Mdot
.954 .49029 Mdot
.954 .49091 Mdot
.954 .49103 Mdot
.954 .49162 Mdot
.954 .49241 Mdot
.954 .4927 Mdot
.954 .49324 Mdot
.954 .49367 Mdot
.954 .49404 Mdot
.954 .49447 Mdot
.954 .49701 Mdot
.954 .49792 Mdot
.954 .49816 Mdot
.954 .49837 Mdot
.954 .49922 Mdot
.954 .49939 Mdot
.954 .49991 Mdot
.954 .50088 Mdot
.954 .50149 Mdot
.954 .50203 Mdot
.954 .5027 Mdot
.954 .50376 Mdot
.954 .50393 Mdot
.954 .50626 Mdot
.954 .50626 Mdot
.954 .5074 Mdot
.954 .50952 Mdot
.954 .51018 Mdot
.954 .51112 Mdot
.954 .51254 Mdot
.954 .51294 Mdot
.954 .51308 Mdot
.954 .51561 Mdot
.954 .51597 Mdot
.954 .51613 Mdot
.954 .5166 Mdot
.954 .51662 Mdot
.954 .51911 Mdot
.954 .51941 Mdot
.954 .52041 Mdot
.954 .5205 Mdot
.954 .52076 Mdot
.954 .52081 Mdot
.954 .52082 Mdot
.954 .52085 Mdot
.954 .52105 Mdot
.954 .52115 Mdot
.954 .52132 Mdot
.954 .52174 Mdot
.954 .52226 Mdot
.954 .52265 Mdot
.954 .5231 Mdot
.954 .52351 Mdot
.954 .52355 Mdot
.954 .52389 Mdot
.954 .52452 Mdot
.954 .52584 Mdot
.954 .52604 Mdot
.954 .52844 Mdot
.954 .52863 Mdot
.954 .52998 Mdot
.954 .53036 Mdot
.954 .531 Mdot
.954 .53115 Mdot
.954 .53149 Mdot
.954 .53152 Mdot
.954 .53187 Mdot
.954 .53439 Mdot
.954 .5352 Mdot
.954 .53577 Mdot
.954 .53607 Mdot
.954 .53623 Mdot
.954 .53714 Mdot
.954 .53846 Mdot
.954 .53877 Mdot
.954 .53904 Mdot
.954 .53913 Mdot
.954 .5394 Mdot
.954 .53946 Mdot
.954 .54173 Mdot
.954 .54213 Mdot
.954 .54284 Mdot
.954 .54318 Mdot
.954 .54419 Mdot
.954 .54423 Mdot
.954 .54455 Mdot
.954 .54549 Mdot
.954 .54558 Mdot
.954 .54614 Mdot
.954 .54666 Mdot
.954 .54711 Mdot
.954 .54731 Mdot
.954 .54752 Mdot
.954 .54753 Mdot
.954 .54782 Mdot
.954 .54812 Mdot
.954 .54829 Mdot
.954 .5484 Mdot
.954 .54842 Mdot
.954 .54848 Mdot
.954 .54851 Mdot
.954 .54851 Mdot
.954 .54857 Mdot
.954 .54861 Mdot
.954 .54868 Mdot
.954 .54869 Mdot
.954 .54881 Mdot
.954 .54907 Mdot
.954 .54918 Mdot
.954 .54918 Mdot
.954 .54929 Mdot
.954 .54947 Mdot
.954 .54956 Mdot
.954 .54975 Mdot
.954 .54976 Mdot
.954 .54988 Mdot
.954 .54991 Mdot
.954 .54993 Mdot
.954 .55012 Mdot
.954 .55016 Mdot
.954 .55031 Mdot
.954 .55052 Mdot
.954 .55104 Mdot
.954 .55113 Mdot
.954 .55114 Mdot
.954 .55115 Mdot
.954 .5513 Mdot
.954 .55154 Mdot
.954 .5516 Mdot
.954 .55164 Mdot
.954 .55164 Mdot
.954 .55177 Mdot
.954 .55183 Mdot
.954 .55189 Mdot
.954 .55218 Mdot
.954 .55226 Mdot
.954 .55233 Mdot
.954 .55234 Mdot
.954 .55236 Mdot
.954 .55247 Mdot
.954 .55248 Mdot
.954 .55299 Mdot
.954 .55307 Mdot
.954 .55327 Mdot
.954 .55327 Mdot
.954 .55328 Mdot
.954 .55329 Mdot
.954 .55335 Mdot
.954 .55368 Mdot
.954 .55413 Mdot
.954 .55422 Mdot
.954 .55471 Mdot
.954 .55511 Mdot
.954 .55553 Mdot
.954 .55569 Mdot
.954 .55616 Mdot
.954 .55665 Mdot
.954 .55665 Mdot
.954 .5567 Mdot
.954 .55698 Mdot
.954 .55698 Mdot
.954 .55703 Mdot
.954 .55729 Mdot
.954 .55779 Mdot
.954 .55798 Mdot
.954 .55859 Mdot
.954 .55861 Mdot
.954 .55874 Mdot
.954 .55906 Mdot
.954 .55944 Mdot
.954 .56004 Mdot
.954 .56018 Mdot
.954 .56025 Mdot
.954 .5606 Mdot
.954 .56067 Mdot
.954 .56069 Mdot
.954 .56085 Mdot
.954 .56105 Mdot
.954 .56114 Mdot
.954 .56119 Mdot
.954 .56119 Mdot
.954 .56144 Mdot
.954 .56179 Mdot
.954 .56179 Mdot
.954 .56204 Mdot
.954 .56232 Mdot
.954 .56243 Mdot
.954 .56255 Mdot
.954 .56267 Mdot
.954 .56293 Mdot
.954 .56296 Mdot
.954 .56478 Mdot
.954 .56482 Mdot
.954 .56582 Mdot
.954 .56592 Mdot
.954 .56688 Mdot
.954 .56697 Mdot
.954 .56718 Mdot
.954 .5674 Mdot
.954 .56756 Mdot
.954 .56761 Mdot
.954 .5677 Mdot
.954 .56774 Mdot
.954 .56814 Mdot
.954 .56817 Mdot
.954 .56837 Mdot
.954 .56842 Mdot
.954 .56847 Mdot
.954 .569 Mdot
.954 .569 Mdot
.954 .56925 Mdot
.954 .56931 Mdot
.954 .56958 Mdot
.954 .5697 Mdot
.954 .56976 Mdot
.954 .56989 Mdot
.954 .57001 Mdot
.954 .57032 Mdot
.954 .57064 Mdot
.954 .57068 Mdot
.954 .57068 Mdot
.954 .57087 Mdot
.954 .57106 Mdot
.954 .57133 Mdot
.954 .57133 Mdot
.954 .57138 Mdot
.954 .57147 Mdot
.954 .57154 Mdot
.954 .57211 Mdot
.954 .57222 Mdot
.954 .5724 Mdot
.954 .57259 Mdot
.954 .57273 Mdot
.954 .57274 Mdot
.954 .57281 Mdot
.954 .57294 Mdot
.954 .57295 Mdot
.954 .57299 Mdot
.954 .57333 Mdot
.954 .57336 Mdot
.954 .57357 Mdot
.954 .57358 Mdot
.954 .57395 Mdot
.954 .57401 Mdot
.954 .57417 Mdot
.954 .57417 Mdot
.954 .57424 Mdot
.954 .57437 Mdot
.954 .57438 Mdot
.954 .57445 Mdot
.954 .57446 Mdot
.954 .57471 Mdot
.954 .57487 Mdot
.954 .57499 Mdot
.954 .575 Mdot
.954 .5753 Mdot
.954 .57543 Mdot
.954 .57544 Mdot
.954 .57551 Mdot
.954 .57556 Mdot
.954 .57557 Mdot
.954 .57571 Mdot
.954 .57573 Mdot
.954 .57577 Mdot
.954 .57578 Mdot
.954 .57581 Mdot
.954 .57585 Mdot
.954 .57587 Mdot
.954 .57588 Mdot
.954 .57589 Mdot
.954 .57604 Mdot
.954 .57605 Mdot
.954 .57607 Mdot
.954 .5761 Mdot
.954 .57611 Mdot
.954 .57613 Mdot
.954 .57615 Mdot
.954 .57615 Mdot
.954 .57616 Mdot
.954 .57621 Mdot
.954 .57621 Mdot
.954 .57622 Mdot
.954 .57623 Mdot
.954 .57624 Mdot
.954 .57624 Mdot
.954 .57625 Mdot
.954 .57625 Mdot
.954 .57627 Mdot
.956 .09225 Mdot
.956 .09226 Mdot
.956 .09226 Mdot
.956 .09238 Mdot
.956 .09238 Mdot
.956 .09241 Mdot
.956 .09245 Mdot
.956 .09246 Mdot
.956 .09247 Mdot
.956 .09249 Mdot
.956 .09255 Mdot
.956 .09268 Mdot
.956 .09269 Mdot
.956 .09275 Mdot
.956 .09276 Mdot
.956 .09303 Mdot
.956 .09323 Mdot
.956 .09327 Mdot
.956 .09342 Mdot
.956 .09347 Mdot
.956 .09374 Mdot
.956 .09398 Mdot
.956 .09401 Mdot
.956 .09402 Mdot
.956 .0945 Mdot
.956 .0946 Mdot
.956 .09518 Mdot
.956 .09528 Mdot
.956 .09555 Mdot
.956 .09558 Mdot
.956 .09569 Mdot
.956 .0958 Mdot
.956 .09586 Mdot
.956 .0959 Mdot
.956 .09653 Mdot
.956 .09693 Mdot
.956 .09737 Mdot
.956 .09756 Mdot
.956 .09793 Mdot
.956 .09799 Mdot
.956 .09828 Mdot
.956 .09833 Mdot
.956 .09849 Mdot
.956 .09879 Mdot
.956 .09893 Mdot
.956 .09911 Mdot
.956 .09955 Mdot
.956 .0998 Mdot
.956 .09998 Mdot
.956 .10005 Mdot
.956 .10006 Mdot
.956 .10027 Mdot
.956 .10037 Mdot
.956 .10074 Mdot
.956 .10136 Mdot
.956 .10189 Mdot
.956 .10207 Mdot
.956 .10226 Mdot
.956 .1023 Mdot
.956 .10263 Mdot
.956 .10285 Mdot
.956 .10308 Mdot
.956 .10334 Mdot
.956 .10375 Mdot
.956 .10498 Mdot
.956 .10566 Mdot
.956 .10593 Mdot
.956 .10635 Mdot
.956 .10644 Mdot
.956 .10659 Mdot
.956 .10665 Mdot
.956 .10675 Mdot
.956 .10951 Mdot
.956 .10991 Mdot
.956 .10992 Mdot
.956 .11007 Mdot
.956 .11071 Mdot
.956 .11075 Mdot
.956 .11084 Mdot
.956 .11088 Mdot
.956 .11186 Mdot
.956 .11206 Mdot
.956 .11216 Mdot
.956 .11241 Mdot
.956 .11265 Mdot
.956 .11307 Mdot
.956 .11318 Mdot
.956 .11347 Mdot
.956 .11354 Mdot
.956 .11451 Mdot
.956 .11511 Mdot
.956 .11562 Mdot
.956 .11618 Mdot
.956 .11646 Mdot
.956 .11765 Mdot
.956 .11875 Mdot
.956 .11899 Mdot
.956 .11907 Mdot
.956 .11964 Mdot
.956 .1204 Mdot
.956 .12122 Mdot
.956 .12165 Mdot
.956 .12271 Mdot
.956 .12438 Mdot
.956 .12445 Mdot
.956 .12488 Mdot
.956 .12499 Mdot
.956 .12588 Mdot
.956 .12611 Mdot
.956 .12629 Mdot
.956 .12656 Mdot
.956 .12754 Mdot
.956 .12765 Mdot
.956 .12856 Mdot
.956 .12869 Mdot
.956 .12895 Mdot
.956 .12898 Mdot
.956 .12976 Mdot
.956 .13121 Mdot
.956 .13144 Mdot
.956 .13163 Mdot
.956 .13194 Mdot
.956 .13262 Mdot
.956 .13301 Mdot
.956 .13312 Mdot
.956 .13337 Mdot
.956 .13358 Mdot
.956 .13366 Mdot
.956 .13619 Mdot
.956 .13638 Mdot
.956 .13897 Mdot
.956 .13983 Mdot
.956 .14057 Mdot
.956 .14072 Mdot
.956 .14078 Mdot
.956 .141 Mdot
.956 .14145 Mdot
.956 .14153 Mdot
.956 .14174 Mdot
.956 .14179 Mdot
.956 .14192 Mdot
.956 .14193 Mdot
.956 .14248 Mdot
.956 .14369 Mdot
.956 .14379 Mdot
.956 .14397 Mdot
.956 .14417 Mdot
.956 .14566 Mdot
.956 .14578 Mdot
.956 .14641 Mdot
.956 .14673 Mdot
.956 .14728 Mdot
.956 .14843 Mdot
.956 .14942 Mdot
.956 .14951 Mdot
.956 .15023 Mdot
.956 .15051 Mdot
.956 .1514 Mdot
.956 .15329 Mdot
.956 .15428 Mdot
.956 .15429 Mdot
.956 .15461 Mdot
.956 .1559 Mdot
.956 .15637 Mdot
.956 .15656 Mdot
.956 .1569 Mdot
.956 .15708 Mdot
.956 .15845 Mdot
.956 .15936 Mdot
.956 .15984 Mdot
.956 .16064 Mdot
.956 .16089 Mdot
.956 .16177 Mdot
.956 .16178 Mdot
.956 .16273 Mdot
.956 .16362 Mdot
.956 .1643 Mdot
.956 .16437 Mdot
.956 .16519 Mdot
.956 .16528 Mdot
.956 .16529 Mdot
.956 .16615 Mdot
.956 .16638 Mdot
.956 .16654 Mdot
.956 .16788 Mdot
.956 .17064 Mdot
.956 .1709 Mdot
.956 .17093 Mdot
.956 .17106 Mdot
.956 .17109 Mdot
.956 .17118 Mdot
.956 .17149 Mdot
.956 .17161 Mdot
.956 .17219 Mdot
.956 .17239 Mdot
.956 .17243 Mdot
.956 .17277 Mdot
.956 .17318 Mdot
.956 .17339 Mdot
.956 .17357 Mdot
.956 .17364 Mdot
.956 .17539 Mdot
.956 .17611 Mdot
.956 .17707 Mdot
.956 .17876 Mdot
.956 .18053 Mdot
.956 .1813 Mdot
.956 .18263 Mdot
.956 .18493 Mdot
.956 .18495 Mdot
.956 .18497 Mdot
.956 .18508 Mdot
.956 .18525 Mdot
.956 .18558 Mdot
.956 .1868 Mdot
.956 .18716 Mdot
.956 .1881 Mdot
.956 .18928 Mdot
.956 .18967 Mdot
.956 .19093 Mdot
.956 .19119 Mdot
.956 .19283 Mdot
.956 .19402 Mdot
.956 .19504 Mdot
.956 .19507 Mdot
.956 .19509 Mdot
.956 .19563 Mdot
.956 .19572 Mdot
.956 .19588 Mdot
.956 .19652 Mdot
.956 .19674 Mdot
.956 .19725 Mdot
.956 .19737 Mdot
.956 .1975 Mdot
.956 .1976 Mdot
.956 .19787 Mdot
.956 .19812 Mdot
.956 .19816 Mdot
.956 .19825 Mdot
.956 .19912 Mdot
.956 .19916 Mdot
.956 .19919 Mdot
.956 .1992 Mdot
.956 .20085 Mdot
.956 .20352 Mdot
.956 .20575 Mdot
.956 .20969 Mdot
.956 .2105 Mdot
.956 .21412 Mdot
.956 .21701 Mdot
.956 .2181 Mdot
.956 .22044 Mdot
.956 .22238 Mdot
.956 .22542 Mdot
.956 .22611 Mdot
.956 .22953 Mdot
.956 .2315 Mdot
.956 .23366 Mdot
.956 .23621 Mdot
.956 .23735 Mdot
.956 .24046 Mdot
.956 .241 Mdot
.956 .24101 Mdot
.956 .24102 Mdot
.956 .24134 Mdot
.956 .24136 Mdot
.956 .24144 Mdot
.956 .24153 Mdot
.956 .24157 Mdot
.956 .24161 Mdot
.956 .24165 Mdot
.956 .24182 Mdot
.956 .24216 Mdot
.956 .24219 Mdot
.956 .24238 Mdot
.956 .24239 Mdot
.956 .24273 Mdot
.956 .24313 Mdot
.956 .24369 Mdot
.956 .24378 Mdot
.956 .24422 Mdot
.956 .24435 Mdot
.956 .24508 Mdot
.956 .24575 Mdot
.956 .24581 Mdot
.956 .24585 Mdot
.956 .24586 Mdot
.956 .24715 Mdot
.956 .24743 Mdot
.956 .24806 Mdot
.956 .24903 Mdot
.956 .2493 Mdot
.956 .25004 Mdot
.956 .25012 Mdot
.956 .25042 Mdot
.956 .25049 Mdot
.956 .25071 Mdot
.956 .25087 Mdot
.956 .25098 Mdot
.956 .25271 Mdot
.956 .25379 Mdot
.956 .25498 Mdot
.956 .25531 Mdot
.956 .2555 Mdot
.956 .25651 Mdot
.956 .25665 Mdot
.956 .25747 Mdot
.956 .2576 Mdot
.956 .25803 Mdot
.956 .25884 Mdot
.956 .25922 Mdot
.956 .25935 Mdot
.956 .2597 Mdot
.956 .26089 Mdot
.956 .26138 Mdot
.956 .26155 Mdot
.956 .26206 Mdot
.956 .26223 Mdot
.956 .26227 Mdot
.956 .26284 Mdot
.956 .2631 Mdot
.956 .26318 Mdot
.956 .26328 Mdot
.956 .26409 Mdot
.956 .26577 Mdot
.956 .26586 Mdot
.956 .26718 Mdot
.956 .26767 Mdot
.956 .26819 Mdot
.956 .26829 Mdot
.956 .26841 Mdot
.956 .26918 Mdot
.956 .26976 Mdot
.956 .27039 Mdot
.956 .27108 Mdot
.956 .27182 Mdot
.956 .27217 Mdot
.956 .27316 Mdot
.956 .27544 Mdot
.956 .27629 Mdot
.956 .27707 Mdot
.956 .27726 Mdot
.956 .27798 Mdot
.956 .2784 Mdot
.956 .27908 Mdot
.956 .27933 Mdot
.956 .27941 Mdot
.956 .27971 Mdot
.956 .27988 Mdot
.956 .28006 Mdot
.956 .28014 Mdot
.956 .28028 Mdot
.956 .28115 Mdot
.956 .28163 Mdot
.956 .28176 Mdot
.956 .28441 Mdot
.956 .28447 Mdot
.956 .28528 Mdot
.956 .2859 Mdot
.956 .28743 Mdot
.956 .28792 Mdot
.956 .28848 Mdot
.956 .28851 Mdot
.956 .2889 Mdot
.956 .28946 Mdot
.956 .29015 Mdot
.956 .29056 Mdot
.956 .29067 Mdot
.956 .29091 Mdot
.956 .29101 Mdot
.956 .29206 Mdot
.956 .29359 Mdot
.956 .2941 Mdot
.956 .29437 Mdot
.956 .29501 Mdot
.956 .29562 Mdot
.956 .29673 Mdot
.956 .29683 Mdot
.956 .29702 Mdot
.956 .29721 Mdot
.956 .29726 Mdot
.956 .29776 Mdot
.956 .29794 Mdot
.956 .30045 Mdot
.956 .30113 Mdot
.956 .30188 Mdot
.956 .30202 Mdot
.956 .30332 Mdot
.956 .30445 Mdot
.956 .30477 Mdot
.956 .30482 Mdot
.956 .3055 Mdot
.956 .30598 Mdot
.956 .30618 Mdot
.956 .30644 Mdot
.956 .30674 Mdot
.956 .30854 Mdot
.956 .30876 Mdot
.956 .30912 Mdot
.956 .31136 Mdot
.956 .31197 Mdot
.956 .31217 Mdot
.956 .31363 Mdot
.956 .31544 Mdot
.956 .31555 Mdot
.956 .31755 Mdot
.956 .31764 Mdot
.956 .31873 Mdot
.956 .31895 Mdot
.956 .3214 Mdot
.956 .32454 Mdot
.956 .32494 Mdot
.956 .32501 Mdot
.956 .32522 Mdot
.956 .3256 Mdot
.956 .32578 Mdot
.956 .32654 Mdot
.956 .32683 Mdot
.956 .32713 Mdot
.956 .32934 Mdot
.956 .32992 Mdot
.956 .33037 Mdot
.956 .33102 Mdot
.956 .33302 Mdot
.956 .33338 Mdot
.956 .33346 Mdot
.956 .33373 Mdot
.956 .33599 Mdot
.956 .33631 Mdot
.956 .33694 Mdot
.956 .33701 Mdot
.956 .33704 Mdot
.956 .33893 Mdot
.956 .34042 Mdot
.956 .34247 Mdot
.956 .34267 Mdot
.956 .34303 Mdot
.956 .3435 Mdot
.956 .34401 Mdot
.956 .34427 Mdot
.956 .34592 Mdot
.956 .34617 Mdot
.956 .34674 Mdot
.956 .34687 Mdot
.956 .34712 Mdot
.956 .34773 Mdot
.956 .34823 Mdot
.956 .34844 Mdot
.956 .34845 Mdot
.956 .35003 Mdot
.956 .35059 Mdot
.956 .35064 Mdot
.956 .35077 Mdot
.956 .35092 Mdot
.956 .35356 Mdot
.956 .35432 Mdot
.956 .35439 Mdot
.956 .35442 Mdot
.956 .35453 Mdot
.956 .35474 Mdot
.956 .3549 Mdot
.956 .35497 Mdot
.956 .35591 Mdot
.956 .35674 Mdot
.956 .35702 Mdot
.956 .35741 Mdot
.956 .35793 Mdot
.956 .3584 Mdot
.956 .36045 Mdot
.956 .36113 Mdot
.956 .36132 Mdot
.956 .36162 Mdot
.956 .36218 Mdot
.956 .36318 Mdot
.956 .36353 Mdot
.956 .36353 Mdot
.956 .36391 Mdot
.956 .36454 Mdot
.956 .36456 Mdot
.956 .36488 Mdot
.956 .36492 Mdot
.956 .36492 Mdot
.956 .36526 Mdot
.956 .36541 Mdot
.956 .36593 Mdot
.956 .36699 Mdot
.956 .36709 Mdot
.956 .36714 Mdot
.956 .36715 Mdot
.956 .3673 Mdot
.956 .36766 Mdot
.956 .36778 Mdot
.956 .36808 Mdot
.956 .36811 Mdot
.956 .36938 Mdot
.956 .37138 Mdot
.956 .3722 Mdot
.956 .37242 Mdot
.956 .37285 Mdot
.956 .3733 Mdot
.956 .37569 Mdot
.956 .37595 Mdot
.956 .37617 Mdot
.956 .37674 Mdot
.956 .37703 Mdot
.956 .37847 Mdot
.956 .37919 Mdot
.956 .38045 Mdot
.956 .38275 Mdot
.956 .38309 Mdot
.956 .38381 Mdot
.956 .38532 Mdot
.956 .38553 Mdot
.956 .38714 Mdot
.956 .38778 Mdot
.956 .38886 Mdot
.956 .38977 Mdot
.956 .39042 Mdot
.956 .39132 Mdot
.956 .39399 Mdot
.956 .39512 Mdot
.956 .39618 Mdot
.956 .39621 Mdot
.956 .39692 Mdot
.956 .39854 Mdot
.956 .3989 Mdot
.956 .39975 Mdot
.956 .40031 Mdot
.956 .40058 Mdot
.956 .40076 Mdot
.956 .40082 Mdot
.956 .40118 Mdot
.956 .40192 Mdot
.956 .40193 Mdot
.956 .40215 Mdot
.956 .40231 Mdot
.956 .40285 Mdot
.956 .40325 Mdot
.956 .40344 Mdot
.956 .40519 Mdot
.956 .40529 Mdot
.956 .4053 Mdot
.956 .40631 Mdot
.956 .4065 Mdot
.956 .40716 Mdot
.956 .40726 Mdot
.956 .40761 Mdot
.956 .40768 Mdot
.956 .40776 Mdot
.956 .40828 Mdot
.956 .40999 Mdot
.956 .41053 Mdot
.956 .41089 Mdot
.956 .41241 Mdot
.956 .41243 Mdot
.956 .41248 Mdot
.956 .41281 Mdot
.956 .41445 Mdot
.956 .41546 Mdot
.956 .41631 Mdot
.956 .41688 Mdot
.956 .41775 Mdot
.956 .41789 Mdot
.956 .41832 Mdot
.956 .41872 Mdot
.956 .4196 Mdot
.956 .41979 Mdot
.956 .41981 Mdot
.956 .42039 Mdot
.956 .42161 Mdot
.956 .42175 Mdot
.956 .42208 Mdot
.956 .42208 Mdot
.956 .42233 Mdot
.956 .42242 Mdot
.956 .42511 Mdot
.956 .42517 Mdot
.956 .42901 Mdot
.956 .43081 Mdot
.956 .43132 Mdot
.956 .43138 Mdot
.956 .43166 Mdot
.956 .43172 Mdot
.956 .43189 Mdot
.956 .43199 Mdot
.956 .43204 Mdot
.956 .43251 Mdot
.956 .43276 Mdot
.956 .43391 Mdot
.956 .43432 Mdot
.956 .4344 Mdot
.956 .43507 Mdot
.956 .4358 Mdot
.956 .4359 Mdot
.956 .43632 Mdot
.956 .43667 Mdot
.956 .43682 Mdot
.956 .43853 Mdot
.956 .43931 Mdot
.956 .44028 Mdot
.956 .44119 Mdot
.956 .44168 Mdot
.956 .4422 Mdot
.956 .44316 Mdot
.956 .44355 Mdot
.956 .44493 Mdot
.956 .44681 Mdot
.956 .44683 Mdot
.956 .4483 Mdot
.956 .45021 Mdot
.956 .45156 Mdot
.956 .45168 Mdot
.956 .45184 Mdot
.956 .45249 Mdot
.956 .45329 Mdot
.956 .45348 Mdot
.956 .45417 Mdot
.956 .45484 Mdot
.956 .4561 Mdot
.956 .45625 Mdot
.956 .457 Mdot
.956 .45846 Mdot
.956 .4585 Mdot
.956 .45853 Mdot
.956 .45874 Mdot
.956 .45905 Mdot
.956 .45914 Mdot
.956 .4596 Mdot
.956 .45966 Mdot
.956 .46046 Mdot
.956 .46055 Mdot
.956 .46073 Mdot
.956 .46106 Mdot
.956 .46116 Mdot
.956 .46167 Mdot
.956 .46177 Mdot
.956 .4619 Mdot
.956 .46254 Mdot
.956 .4627 Mdot
.956 .46426 Mdot
.956 .46597 Mdot
.956 .46637 Mdot
.956 .46706 Mdot
.956 .46931 Mdot
.956 .46977 Mdot
.956 .47265 Mdot
.956 .47274 Mdot
.956 .47286 Mdot
.956 .47472 Mdot
.956 .47647 Mdot
.956 .47654 Mdot
.956 .47656 Mdot
.956 .47749 Mdot
.956 .4775 Mdot
.956 .47764 Mdot
.956 .47765 Mdot
.956 .47791 Mdot
.956 .47807 Mdot
.956 .47808 Mdot
.956 .47865 Mdot
.956 .47888 Mdot
.956 .47901 Mdot
.956 .47938 Mdot
.956 .48024 Mdot
.956 .48044 Mdot
.956 .48066 Mdot
.956 .48082 Mdot
.956 .48094 Mdot
.956 .48129 Mdot
.956 .48171 Mdot
.956 .48178 Mdot
.956 .48191 Mdot
.956 .48192 Mdot
.956 .48195 Mdot
.956 .48227 Mdot
.956 .48337 Mdot
.956 .48343 Mdot
.956 .48348 Mdot
.956 .48351 Mdot
.956 .48374 Mdot
.956 .48439 Mdot
.956 .4851 Mdot
.956 .48533 Mdot
.956 .48622 Mdot
.956 .48677 Mdot
.956 .48769 Mdot
.956 .48907 Mdot
.956 .49055 Mdot
.956 .4907 Mdot
.956 .4933 Mdot
.956 .49383 Mdot
.956 .49391 Mdot
.956 .49394 Mdot
.956 .4941 Mdot
.956 .49632 Mdot
.956 .49687 Mdot
.956 .4977 Mdot
.956 .50018 Mdot
.956 .50033 Mdot
.956 .50111 Mdot
.956 .50123 Mdot
.956 .50133 Mdot
.956 .50141 Mdot
.956 .50186 Mdot
.956 .502 Mdot
.956 .503 Mdot
.956 .50329 Mdot
.956 .50478 Mdot
.956 .5048 Mdot
.956 .50495 Mdot
.956 .50678 Mdot
.956 .50751 Mdot
.956 .50777 Mdot
.956 .50836 Mdot
.956 .50913 Mdot
.956 .50937 Mdot
.956 .50967 Mdot
.956 .50969 Mdot
.956 .51075 Mdot
.956 .51093 Mdot
.956 .51126 Mdot
.956 .51134 Mdot
.956 .51159 Mdot
.956 .51197 Mdot
.956 .51247 Mdot
.956 .51276 Mdot
.956 .51394 Mdot
.956 .51444 Mdot
.956 .51571 Mdot
.956 .51666 Mdot
.956 .51762 Mdot
.956 .51766 Mdot
.956 .51833 Mdot
.956 .51908 Mdot
.956 .52057 Mdot
.956 .52234 Mdot
.956 .52323 Mdot
.956 .52403 Mdot
.956 .52517 Mdot
.956 .526 Mdot
.956 .52713 Mdot
.956 .52754 Mdot
.956 .52847 Mdot
.956 .52924 Mdot
.956 .52996 Mdot
.956 .53119 Mdot
.956 .53143 Mdot
.956 .53253 Mdot
.956 .53322 Mdot
.956 .53406 Mdot
.956 .53444 Mdot
.956 .53547 Mdot
.956 .53676 Mdot
.956 .53705 Mdot
.956 .53845 Mdot
.956 .53924 Mdot
.956 .54018 Mdot
.956 .54076 Mdot
.956 .54076 Mdot
.956 .54077 Mdot
.956 .54079 Mdot
.956 .54109 Mdot
.956 .54112 Mdot
.956 .54114 Mdot
.956 .54123 Mdot
.956 .54132 Mdot
.956 .54136 Mdot
.956 .5414 Mdot
.956 .54145 Mdot
.956 .54163 Mdot
.956 .5417 Mdot
.956 .54193 Mdot
.956 .54199 Mdot
.956 .54202 Mdot
.956 .54221 Mdot
.956 .54221 Mdot
.956 .54223 Mdot
.956 .54258 Mdot
.956 .543 Mdot
.956 .54357 Mdot
.956 .54367 Mdot
.956 .54411 Mdot
.956 .54425 Mdot
.956 .54466 Mdot
.956 .54499 Mdot
.956 .54511 Mdot
.956 .54554 Mdot
.956 .54565 Mdot
.956 .54571 Mdot
.956 .54575 Mdot
.956 .54576 Mdot
.956 .54577 Mdot
.956 .54657 Mdot
.956 .54703 Mdot
.956 .5473 Mdot
.956 .54792 Mdot
.956 .54851 Mdot
.956 .54884 Mdot
.956 .54909 Mdot
.956 .5497 Mdot
.956 .54972 Mdot
.956 .54978 Mdot
.956 .54986 Mdot
.956 .55 Mdot
.956 .55012 Mdot
.956 .55013 Mdot
.956 .5502 Mdot
.956 .5504 Mdot
.956 .55044 Mdot
.956 .55055 Mdot
.956 .55058 Mdot
.956 .55059 Mdot
.956 .55064 Mdot
.956 .55065 Mdot
.956 .55074 Mdot
.956 .55169 Mdot
.956 .55216 Mdot
.956 .55221 Mdot
.956 .55229 Mdot
.956 .55259 Mdot
.956 .55259 Mdot
.956 .55263 Mdot
.956 .55291 Mdot
.956 .55293 Mdot
.956 .55317 Mdot
.956 .55347 Mdot
.956 .5538 Mdot
.956 .5538 Mdot
.956 .55411 Mdot
.956 .5542 Mdot
.956 .55447 Mdot
.956 .55463 Mdot
.956 .55495 Mdot
.956 .55542 Mdot
.956 .55548 Mdot
.956 .5556 Mdot
.956 .55567 Mdot
.956 .55582 Mdot
.956 .55627 Mdot
.956 .55638 Mdot
.956 .55638 Mdot
.956 .55672 Mdot
.956 .55737 Mdot
.956 .55768 Mdot
.956 .55777 Mdot
.956 .55802 Mdot
.956 .55805 Mdot
.956 .55839 Mdot
.956 .55879 Mdot
.956 .55898 Mdot
.956 .55908 Mdot
.956 .5593 Mdot
.956 .55934 Mdot
.956 .55948 Mdot
.956 .55985 Mdot
.956 .55992 Mdot
.956 .55998 Mdot
.956 .56001 Mdot
.956 .56043 Mdot
.956 .56061 Mdot
.956 .56062 Mdot
.956 .56066 Mdot
.956 .56068 Mdot
.956 .56075 Mdot
.956 .56078 Mdot
.956 .56093 Mdot
.956 .56101 Mdot
.956 .56103 Mdot
.956 .56108 Mdot
.956 .56133 Mdot
.956 .56163 Mdot
.956 .56251 Mdot
.956 .56257 Mdot
.956 .56344 Mdot
.956 .56347 Mdot
.956 .56354 Mdot
.956 .56362 Mdot
.956 .56366 Mdot
.956 .56379 Mdot
.956 .56402 Mdot
.956 .56413 Mdot
.956 .56419 Mdot
.956 .56427 Mdot
.956 .56477 Mdot
.956 .56503 Mdot
.956 .56504 Mdot
.956 .56513 Mdot
.956 .56517 Mdot
.956 .56548 Mdot
.956 .56552 Mdot
.956 .56585 Mdot
.956 .56594 Mdot
.956 .566 Mdot
.956 .56608 Mdot
.956 .56639 Mdot
.956 .56643 Mdot
.956 .56657 Mdot
.956 .56659 Mdot
.956 .56716 Mdot
.956 .56752 Mdot
.956 .56767 Mdot
.956 .56795 Mdot
.956 .5682 Mdot
.956 .5684 Mdot
.956 .56842 Mdot
.956 .5685 Mdot
.956 .56888 Mdot
.956 .56928 Mdot
.956 .56937 Mdot
.956 .56956 Mdot
.956 .56973 Mdot
.956 .56994 Mdot
.956 .57027 Mdot
.956 .57029 Mdot
.956 .57039 Mdot
.956 .57043 Mdot
.956 .57057 Mdot
.956 .57065 Mdot
.956 .57073 Mdot
.956 .57077 Mdot
.956 .57083 Mdot
.956 .57117 Mdot
.956 .57118 Mdot
.956 .57121 Mdot
.956 .57122 Mdot
.956 .57144 Mdot
.956 .57149 Mdot
.956 .57149 Mdot
.956 .57163 Mdot
.956 .57256 Mdot
.956 .57259 Mdot
.956 .57262 Mdot
.956 .57266 Mdot
.956 .5727 Mdot
.956 .57284 Mdot
.956 .57293 Mdot
.956 .57316 Mdot
.956 .57357 Mdot
.956 .57371 Mdot
.956 .5738 Mdot
.956 .57388 Mdot
.956 .57395 Mdot
.956 .57406 Mdot
.956 .57407 Mdot
.956 .57414 Mdot
.956 .5742 Mdot
.956 .57438 Mdot
.956 .57459 Mdot
.956 .57471 Mdot
.956 .57474 Mdot
.956 .57482 Mdot
.956 .57482 Mdot
.956 .57484 Mdot
.956 .5749 Mdot
.956 .57499 Mdot
.956 .57514 Mdot
.956 .5752 Mdot
.956 .57524 Mdot
.956 .57534 Mdot
.956 .5754 Mdot
.956 .57541 Mdot
.956 .57551 Mdot
.956 .57553 Mdot
.956 .57566 Mdot
.956 .57572 Mdot
.956 .57587 Mdot
.956 .576 Mdot
.956 .57622 Mdot
.956 .57623 Mdot
.956 .57625 Mdot
.956 .57629 Mdot
.956 .57632 Mdot
.956 .57633 Mdot
.956 .57643 Mdot
.956 .57646 Mdot
.956 .57666 Mdot
.956 .57669 Mdot
.956 .57685 Mdot
.956 .57685 Mdot
.956 .57686 Mdot
.956 .57694 Mdot
.956 .57703 Mdot
.956 .57705 Mdot
.956 .5771 Mdot
.956 .57711 Mdot
.956 .57718 Mdot
.956 .57727 Mdot
.956 .57727 Mdot
.956 .5773 Mdot
.956 .5773 Mdot
.956 .57734 Mdot
.956 .57736 Mdot
.956 .57737 Mdot
.956 .57737 Mdot
.956 .57738 Mdot
.956 .57739 Mdot
.956 .5774 Mdot
.956 .5774 Mdot
.956 .57744 Mdot
.956 .57744 Mdot
.956 .57744 Mdot
.958 .08891 Mdot
.958 .08891 Mdot
.958 .08891 Mdot
.958 .08891 Mdot
.958 .08892 Mdot
.958 .08892 Mdot
.958 .08893 Mdot
.958 .08896 Mdot
.958 .08898 Mdot
.958 .089 Mdot
.958 .08901 Mdot
.958 .08904 Mdot
.958 .08909 Mdot
.958 .08919 Mdot
.958 .08922 Mdot
.958 .08926 Mdot
.958 .08926 Mdot
.958 .08926 Mdot
.958 .08939 Mdot
.958 .08941 Mdot
.958 .08969 Mdot
.958 .08997 Mdot
.958 .09005 Mdot
.958 .09014 Mdot
.958 .09026 Mdot
.958 .09034 Mdot
.958 .09038 Mdot
.958 .0904 Mdot
.958 .09047 Mdot
.958 .09059 Mdot
.958 .09084 Mdot
.958 .09119 Mdot
.958 .09176 Mdot
.958 .09203 Mdot
.958 .0922 Mdot
.958 .09235 Mdot
.958 .09274 Mdot
.958 .09286 Mdot
.958 .09297 Mdot
.958 .09302 Mdot
.958 .09309 Mdot
.958 .09325 Mdot
.958 .09329 Mdot
.958 .09337 Mdot
.958 .09347 Mdot
.958 .09384 Mdot
.958 .09415 Mdot
.958 .09425 Mdot
.958 .09493 Mdot
.958 .0964 Mdot
.958 .098 Mdot
.958 .09874 Mdot
.958 .09885 Mdot
.958 .09886 Mdot
.958 .10026 Mdot
.958 .10049 Mdot
.958 .10138 Mdot
.958 .10146 Mdot
.958 .102 Mdot
.958 .1022 Mdot
.958 .10242 Mdot
.958 .10312 Mdot
.958 .10367 Mdot
.958 .10405 Mdot
.958 .10445 Mdot
.958 .10469 Mdot
.958 .10476 Mdot
.958 .1056 Mdot
.958 .10628 Mdot
.958 .1067 Mdot
.958 .10781 Mdot
.958 .10794 Mdot
.958 .10806 Mdot
.958 .10823 Mdot
.958 .10846 Mdot
.958 .10882 Mdot
.958 .10975 Mdot
.958 .11237 Mdot
.958 .11239 Mdot
.958 .11256 Mdot
.958 .11537 Mdot
.958 .11581 Mdot
.958 .1161 Mdot
.958 .1168 Mdot
.958 .11691 Mdot
.958 .11717 Mdot
.958 .1173 Mdot
.958 .11738 Mdot
.958 .1174 Mdot
.958 .11791 Mdot
.958 .11819 Mdot
.958 .11841 Mdot
.958 .11894 Mdot
.958 .1191 Mdot
.958 .1202 Mdot
.958 .12063 Mdot
.958 .12142 Mdot
.958 .1228 Mdot
.958 .12324 Mdot
.958 .12667 Mdot
.958 .12686 Mdot
.958 .12781 Mdot
.958 .12877 Mdot
.958 .12881 Mdot
.958 .12908 Mdot
.958 .13014 Mdot
.958 .13128 Mdot
.958 .1314 Mdot
.958 .13165 Mdot
.958 .13208 Mdot
.958 .13585 Mdot
.958 .13702 Mdot
.958 .13702 Mdot
.958 .13768 Mdot
.958 .13836 Mdot
.958 .13899 Mdot
.958 .13913 Mdot
.958 .13913 Mdot
.958 .13939 Mdot
.958 .14072 Mdot
.958 .14246 Mdot
.958 .14248 Mdot
.958 .14322 Mdot
.958 .14378 Mdot
.958 .14381 Mdot
.958 .14446 Mdot
.958 .14458 Mdot
.958 .14629 Mdot
.958 .14677 Mdot
.958 .1468 Mdot
.958 .14737 Mdot
.958 .14753 Mdot
.958 .15105 Mdot
.958 .15117 Mdot
.958 .15222 Mdot
.958 .15248 Mdot
.958 .15478 Mdot
.958 .15558 Mdot
.958 .15563 Mdot
.958 .1565 Mdot
.958 .15713 Mdot
.958 .15887 Mdot
.958 .15926 Mdot
.958 .15971 Mdot
.958 .16005 Mdot
.958 .16135 Mdot
.958 .16147 Mdot
.958 .16306 Mdot
.958 .1631 Mdot
.958 .16408 Mdot
.958 .16472 Mdot
.958 .16516 Mdot
.958 .16538 Mdot
.958 .16652 Mdot
.958 .16662 Mdot
.958 .16667 Mdot
.958 .16723 Mdot
.958 .1673 Mdot
.958 .16761 Mdot
.958 .16762 Mdot
.958 .16785 Mdot
.958 .16885 Mdot
.958 .17013 Mdot
.958 .17117 Mdot
.958 .17247 Mdot
.958 .17373 Mdot
.958 .17381 Mdot
.958 .17382 Mdot
.958 .17402 Mdot
.958 .17427 Mdot
.958 .17614 Mdot
.958 .17626 Mdot
.958 .17837 Mdot
.958 .17901 Mdot
.958 .17974 Mdot
.958 .18114 Mdot
.958 .18216 Mdot
.958 .18307 Mdot
.958 .18487 Mdot
.958 .18487 Mdot
.958 .18506 Mdot
.958 .18513 Mdot
.958 .18588 Mdot
.958 .18652 Mdot
.958 .18664 Mdot
.958 .18682 Mdot
.958 .18727 Mdot
.958 .18811 Mdot
.958 .18868 Mdot
.958 .18911 Mdot
.958 .18951 Mdot
.958 .19003 Mdot
.958 .19029 Mdot
.958 .19102 Mdot
.958 .19129 Mdot
.958 .19234 Mdot
.958 .19242 Mdot
.958 .19267 Mdot
.958 .19418 Mdot
.958 .19442 Mdot
.958 .19533 Mdot
.958 .19547 Mdot
.958 .19687 Mdot
.958 .19861 Mdot
.958 .19918 Mdot
.958 .20026 Mdot
.958 .20053 Mdot
.958 .20233 Mdot
.958 .20272 Mdot
.958 .20408 Mdot
.958 .20574 Mdot
.958 .20588 Mdot
.958 .20595 Mdot
.958 .206 Mdot
.958 .20707 Mdot
.958 .2086 Mdot
.958 .20929 Mdot
.958 .21012 Mdot
.958 .21035 Mdot
.958 .21097 Mdot
.958 .21113 Mdot
.958 .21127 Mdot
.958 .21151 Mdot
.958 .21213 Mdot
.958 .21221 Mdot
.958 .21328 Mdot
.958 .21416 Mdot
.958 .21423 Mdot
.958 .21489 Mdot
.958 .21736 Mdot
.958 .21992 Mdot
.958 .22011 Mdot
.958 .22103 Mdot
.958 .22128 Mdot
.958 .2213 Mdot
.958 .22134 Mdot
.958 .22172 Mdot
.958 .22172 Mdot
.958 .22196 Mdot
.958 .22291 Mdot
.958 .22336 Mdot
.958 .22363 Mdot
.958 .22367 Mdot
.958 .2239 Mdot
.958 .22408 Mdot
.958 .22419 Mdot
.958 .22433 Mdot
.958 .22445 Mdot
.958 .22446 Mdot
.958 .22453 Mdot
.958 .22454 Mdot
.958 .22457 Mdot
.958 .22457 Mdot
.958 .22459 Mdot
.958 .2252 Mdot
.958 .22526 Mdot
.958 .23221 Mdot
.958 .23222 Mdot
.958 .23223 Mdot
.958 .23223 Mdot
.958 .23225 Mdot
.958 .23225 Mdot
.958 .23229 Mdot
.958 .23233 Mdot
.958 .23236 Mdot
.958 .23242 Mdot
.958 .23249 Mdot
.958 .2325 Mdot
.958 .23258 Mdot
.958 .23272 Mdot
.958 .233 Mdot
.958 .23307 Mdot
.958 .23319 Mdot
.958 .2332 Mdot
.958 .2332 Mdot
.958 .23356 Mdot
.958 .23361 Mdot
.958 .23439 Mdot
.958 .23515 Mdot
.958 .23538 Mdot
.958 .23565 Mdot
.958 .23598 Mdot
.958 .2362 Mdot
.958 .23631 Mdot
.958 .23636 Mdot
.958 .23656 Mdot
.958 .23689 Mdot
.958 .23758 Mdot
.958 .23794 Mdot
.958 .23796 Mdot
.958 .23853 Mdot
.958 .23897 Mdot
.958 .24011 Mdot
.958 .24086 Mdot
.958 .24133 Mdot
.958 .24175 Mdot
.958 .24281 Mdot
.958 .24314 Mdot
.958 .24345 Mdot
.958 .2436 Mdot
.958 .24379 Mdot
.958 .24407 Mdot
.958 .24423 Mdot
.958 .24433 Mdot
.958 .24455 Mdot
.958 .24481 Mdot
.958 .24584 Mdot
.958 .24669 Mdot
.958 .24695 Mdot
.958 .24718 Mdot
.958 .24865 Mdot
.958 .24874 Mdot
.958 .24882 Mdot
.958 .24885 Mdot
.958 .24931 Mdot
.958 .25102 Mdot
.958 .25111 Mdot
.958 .25112 Mdot
.958 .25123 Mdot
.958 .25126 Mdot
.958 .25149 Mdot
.958 .25153 Mdot
.958 .25196 Mdot
.958 .25222 Mdot
.958 .25246 Mdot
.958 .25284 Mdot
.958 .25285 Mdot
.958 .25352 Mdot
.958 .25417 Mdot
.958 .25434 Mdot
.958 .2545 Mdot
.958 .25545 Mdot
.958 .2571 Mdot
.958 .25721 Mdot
.958 .2592 Mdot
.958 .25951 Mdot
.958 .25953 Mdot
.958 .26054 Mdot
.958 .26143 Mdot
.958 .26144 Mdot
.958 .26222 Mdot
.958 .26284 Mdot
.958 .26296 Mdot
.958 .26303 Mdot
.958 .26332 Mdot
.958 .26395 Mdot
.958 .26395 Mdot
.958 .26451 Mdot
.958 .26636 Mdot
.958 .26657 Mdot
.958 .26734 Mdot
.958 .26789 Mdot
.958 .26802 Mdot
.958 .26804 Mdot
.958 .26854 Mdot
.958 .26915 Mdot
.958 .27102 Mdot
.958 .27127 Mdot
.958 .27251 Mdot
.958 .2735 Mdot
.958 .27395 Mdot
.958 .27444 Mdot
.958 .27457 Mdot
.958 .27479 Mdot
.958 .27523 Mdot
.958 .27541 Mdot
.958 .27569 Mdot
.958 .27764 Mdot
.958 .27765 Mdot
.958 .27946 Mdot
.958 .28056 Mdot
.958 .28204 Mdot
.958 .28352 Mdot
.958 .28385 Mdot
.958 .28416 Mdot
.958 .28463 Mdot
.958 .28524 Mdot
.958 .28544 Mdot
.958 .28618 Mdot
.958 .28701 Mdot
.958 .28723 Mdot
.958 .28863 Mdot
.958 .28952 Mdot
.958 .2898 Mdot
.958 .29133 Mdot
.958 .29317 Mdot
.958 .29409 Mdot
.958 .29549 Mdot
.958 .29555 Mdot
.958 .296 Mdot
.958 .29703 Mdot
.958 .2973 Mdot
.958 .2976 Mdot
.958 .29811 Mdot
.958 .30003 Mdot
.958 .30094 Mdot
.958 .30112 Mdot
.958 .30117 Mdot
.958 .3015 Mdot
.958 .30184 Mdot
.958 .30213 Mdot
.958 .3033 Mdot
.958 .30443 Mdot
.958 .30453 Mdot
.958 .30516 Mdot
.958 .30518 Mdot
.958 .30543 Mdot
.958 .30699 Mdot
.958 .30726 Mdot
.958 .30794 Mdot
.958 .30826 Mdot
.958 .30848 Mdot
.958 .30851 Mdot
.958 .30868 Mdot
.958 .30893 Mdot
.958 .30983 Mdot
.958 .31054 Mdot
.958 .31112 Mdot
.958 .31138 Mdot
.958 .31178 Mdot
.958 .31247 Mdot
.958 .31286 Mdot
.958 .31568 Mdot
.958 .31678 Mdot
.958 .31742 Mdot
.958 .31879 Mdot
.958 .32168 Mdot
.958 .32188 Mdot
.958 .32215 Mdot
.958 .32226 Mdot
.958 .32269 Mdot
.958 .32283 Mdot
.958 .32339 Mdot
.958 .32383 Mdot
.958 .32931 Mdot
.958 .32943 Mdot
.958 .33196 Mdot
.958 .33244 Mdot
.958 .33475 Mdot
.958 .3348 Mdot
.958 .33548 Mdot
.958 .33633 Mdot
.958 .33718 Mdot
.958 .33727 Mdot
.958 .33736 Mdot
.958 .33766 Mdot
.958 .33792 Mdot
.958 .34054 Mdot
.958 .34333 Mdot
.958 .34357 Mdot
.958 .34363 Mdot
.958 .34394 Mdot
.958 .34424 Mdot
.958 .34465 Mdot
.958 .3453 Mdot
.958 .34601 Mdot
.958 .34901 Mdot
.958 .3513 Mdot
.958 .35136 Mdot
.958 .35442 Mdot
.958 .3551 Mdot
.958 .35696 Mdot
.958 .35721 Mdot
.958 .35723 Mdot
.958 .35757 Mdot
.958 .35832 Mdot
.958 .35879 Mdot
.958 .36036 Mdot
.958 .36041 Mdot
.958 .36191 Mdot
.958 .36224 Mdot
.958 .36225 Mdot
.958 .36286 Mdot
.958 .36403 Mdot
.958 .36458 Mdot
.958 .36601 Mdot
.958 .36659 Mdot
.958 .36741 Mdot
.958 .36788 Mdot
.958 .36827 Mdot
.958 .36924 Mdot
.958 .37008 Mdot
.958 .37013 Mdot
.958 .37186 Mdot
.958 .37254 Mdot
.958 .37316 Mdot
.958 .37316 Mdot
.958 .37322 Mdot
.958 .37474 Mdot
.958 .37501 Mdot
.958 .37534 Mdot
.958 .37569 Mdot
.958 .37572 Mdot
.958 .37581 Mdot
.958 .37638 Mdot
.958 .37669 Mdot
.958 .37776 Mdot
.958 .3783 Mdot
.958 .37838 Mdot
.958 .37896 Mdot
.958 .38005 Mdot
.958 .38013 Mdot
.958 .38096 Mdot
.958 .38143 Mdot
.958 .38179 Mdot
.958 .38206 Mdot
.958 .3827 Mdot
.958 .38478 Mdot
.958 .38498 Mdot
.958 .38584 Mdot
.958 .38603 Mdot
.958 .38604 Mdot
.958 .38813 Mdot
.958 .38976 Mdot
.958 .38976 Mdot
.958 .39005 Mdot
.958 .39151 Mdot
.958 .39239 Mdot
.958 .39283 Mdot
.958 .39298 Mdot
.958 .3938 Mdot
.958 .39434 Mdot
.958 .39655 Mdot
.958 .39718 Mdot
.958 .39809 Mdot
.958 .399 Mdot
.958 .39972 Mdot
.958 .39985 Mdot
.958 .39994 Mdot
.958 .40018 Mdot
.958 .40187 Mdot
.958 .40276 Mdot
.958 .40323 Mdot
.958 .4043 Mdot
.958 .40502 Mdot
.958 .40578 Mdot
.958 .40606 Mdot
.958 .40683 Mdot
.958 .40684 Mdot
.958 .40702 Mdot
.958 .40787 Mdot
.958 .40883 Mdot
.958 .40956 Mdot
.958 .41235 Mdot
.958 .4126 Mdot
.958 .41401 Mdot
.958 .41552 Mdot
.958 .41599 Mdot
.958 .41606 Mdot
.958 .41762 Mdot
.958 .41814 Mdot
.958 .41946 Mdot
.958 .42039 Mdot
.958 .42085 Mdot
.958 .421 Mdot
.958 .42169 Mdot
.958 .42322 Mdot
.958 .42343 Mdot
.958 .42354 Mdot
.958 .42469 Mdot
.958 .42485 Mdot
.958 .42547 Mdot
.958 .42548 Mdot
.958 .4255 Mdot
.958 .42598 Mdot
.958 .42611 Mdot
.958 .42614 Mdot
.958 .4272 Mdot
.958 .42771 Mdot
.958 .42798 Mdot
.958 .42803 Mdot
.958 .42971 Mdot
.958 .43008 Mdot
.958 .43063 Mdot
.958 .43256 Mdot
.958 .43274 Mdot
.958 .43537 Mdot
.958 .43675 Mdot
.958 .43788 Mdot
.958 .43804 Mdot
.958 .43805 Mdot
.958 .43845 Mdot
.958 .43852 Mdot
.958 .43896 Mdot
.958 .44076 Mdot
.958 .44122 Mdot
.958 .44264 Mdot
.958 .44287 Mdot
.958 .44401 Mdot
.958 .4449 Mdot
.958 .44698 Mdot
.958 .4482 Mdot
.958 .44839 Mdot
.958 .44923 Mdot
.958 .44936 Mdot
.958 .44961 Mdot
.958 .45013 Mdot
.958 .45014 Mdot
.958 .45045 Mdot
.958 .45228 Mdot
.958 .45261 Mdot
.958 .45422 Mdot
.958 .45522 Mdot
.958 .45593 Mdot
.958 .45927 Mdot
.958 .45927 Mdot
.958 .45963 Mdot
.958 .45976 Mdot
.958 .46011 Mdot
.958 .46044 Mdot
.958 .46115 Mdot
.958 .46232 Mdot
.958 .46253 Mdot
.958 .46286 Mdot
.958 .46369 Mdot
.958 .46397 Mdot
.958 .46497 Mdot
.958 .46521 Mdot
.958 .46565 Mdot
.958 .46623 Mdot
.958 .46702 Mdot
.958 .46774 Mdot
.958 .46866 Mdot
.958 .46867 Mdot
.958 .46875 Mdot
.958 .46913 Mdot
.958 .46922 Mdot
.958 .47013 Mdot
.958 .47041 Mdot
.958 .4709 Mdot
.958 .47202 Mdot
.958 .47205 Mdot
.958 .47229 Mdot
.958 .47275 Mdot
.958 .47288 Mdot
.958 .47313 Mdot
.958 .47317 Mdot
.958 .47318 Mdot
.958 .47334 Mdot
.958 .47428 Mdot
.958 .47454 Mdot
.958 .47596 Mdot
.958 .47637 Mdot
.958 .47654 Mdot
.958 .47674 Mdot
.958 .47709 Mdot
.958 .47794 Mdot
.958 .47817 Mdot
.958 .47972 Mdot
.958 .48058 Mdot
.958 .48089 Mdot
.958 .48114 Mdot
.958 .48192 Mdot
.958 .48348 Mdot
.958 .4835 Mdot
.958 .48445 Mdot
.958 .48568 Mdot
.958 .48624 Mdot
.958 .48653 Mdot
.958 .48668 Mdot
.958 .48909 Mdot
.958 .48921 Mdot
.958 .48963 Mdot
.958 .48997 Mdot
.958 .49027 Mdot
.958 .4924 Mdot
.958 .49245 Mdot
.958 .49464 Mdot
.958 .49503 Mdot
.958 .49509 Mdot
.958 .49531 Mdot
.958 .49541 Mdot
.958 .49549 Mdot
.958 .49717 Mdot
.958 .49939 Mdot
.958 .49954 Mdot
.958 .5005 Mdot
.958 .50059 Mdot
.958 .50186 Mdot
.958 .50196 Mdot
.958 .50221 Mdot
.958 .50314 Mdot
.958 .50325 Mdot
.958 .50338 Mdot
.958 .50351 Mdot
.958 .50353 Mdot
.958 .50359 Mdot
.958 .50395 Mdot
.958 .50468 Mdot
.958 .50488 Mdot
.958 .505 Mdot
.958 .5051 Mdot
.958 .50623 Mdot
.958 .50658 Mdot
.958 .50728 Mdot
.958 .50786 Mdot
.958 .50797 Mdot
.958 .50884 Mdot
.958 .50892 Mdot
.958 .50952 Mdot
.958 .5108 Mdot
.958 .51246 Mdot
.958 .51319 Mdot
.958 .51353 Mdot
.958 .51366 Mdot
.958 .51384 Mdot
.958 .51484 Mdot
.958 .51605 Mdot
.958 .51611 Mdot
.958 .51631 Mdot
.958 .51736 Mdot
.958 .51756 Mdot
.958 .51791 Mdot
.958 .51793 Mdot
.958 .51798 Mdot
.958 .5182 Mdot
.958 .5185 Mdot
.958 .5185 Mdot
.958 .51883 Mdot
.958 .5201 Mdot
.958 .5207 Mdot
.958 .52105 Mdot
.958 .52111 Mdot
.958 .52117 Mdot
.958 .52141 Mdot
.958 .52165 Mdot
.958 .5218 Mdot
.958 .52189 Mdot
.958 .52198 Mdot
.958 .52214 Mdot
.958 .52215 Mdot
.958 .52224 Mdot
.958 .52225 Mdot
.958 .52229 Mdot
.958 .52229 Mdot
.958 .52232 Mdot
.958 .52295 Mdot
.958 .52312 Mdot
.958 .52316 Mdot
.958 .52319 Mdot
.958 .52373 Mdot
.958 .52486 Mdot
.958 .52671 Mdot
.958 .52708 Mdot
.958 .52708 Mdot
.958 .52911 Mdot
.958 .53165 Mdot
.958 .53167 Mdot
.958 .53189 Mdot
.958 .5319 Mdot
.958 .5319 Mdot
.958 .53191 Mdot
.958 .53191 Mdot
.958 .53193 Mdot
.958 .53194 Mdot
.958 .53198 Mdot
.958 .53203 Mdot
.958 .53207 Mdot
.958 .53214 Mdot
.958 .53222 Mdot
.958 .53223 Mdot
.958 .53233 Mdot
.958 .53249 Mdot
.958 .53283 Mdot
.958 .53292 Mdot
.958 .53292 Mdot
.958 .53305 Mdot
.958 .53306 Mdot
.958 .53307 Mdot
.958 .53316 Mdot
.958 .53349 Mdot
.958 .53356 Mdot
.958 .53447 Mdot
.958 .53535 Mdot
.958 .53558 Mdot
.958 .53561 Mdot
.958 .53592 Mdot
.958 .5363 Mdot
.958 .53633 Mdot
.958 .53655 Mdot
.958 .53663 Mdot
.958 .53668 Mdot
.958 .53674 Mdot
.958 .53696 Mdot
.958 .53704 Mdot
.958 .53734 Mdot
.958 .53758 Mdot
.958 .53812 Mdot
.958 .5385 Mdot
.958 .53852 Mdot
.958 .53854 Mdot
.958 .53859 Mdot
.958 .53918 Mdot
.958 .53965 Mdot
.958 .53979 Mdot
.958 .54043 Mdot
.958 .54052 Mdot
.958 .5409 Mdot
.958 .5411 Mdot
.958 .54171 Mdot
.958 .54221 Mdot
.958 .54225 Mdot
.958 .54257 Mdot
.958 .54266 Mdot
.958 .54319 Mdot
.958 .54328 Mdot
.958 .5433 Mdot
.958 .54367 Mdot
.958 .54377 Mdot
.958 .54402 Mdot
.958 .54411 Mdot
.958 .54429 Mdot
.958 .54443 Mdot
.958 .54458 Mdot
.958 .54478 Mdot
.958 .54507 Mdot
.958 .54523 Mdot
.958 .54533 Mdot
.958 .54556 Mdot
.958 .54582 Mdot
.958 .54584 Mdot
.958 .54591 Mdot
.958 .54591 Mdot
.958 .54654 Mdot
.958 .54685 Mdot
.958 .54721 Mdot
.958 .5477 Mdot
.958 .54795 Mdot
.958 .54817 Mdot
.958 .5489 Mdot
.958 .54895 Mdot
.958 .54959 Mdot
.958 .54968 Mdot
.958 .54975 Mdot
.958 .54975 Mdot
.958 .54978 Mdot
.958 .55022 Mdot
.958 .55067 Mdot
.958 .55103 Mdot
.958 .55147 Mdot
.958 .55181 Mdot
.958 .55189 Mdot
.958 .5519 Mdot
.958 .552 Mdot
.958 .55203 Mdot
.958 .55222 Mdot
.958 .55224 Mdot
.958 .55227 Mdot
.958 .55267 Mdot
.958 .55274 Mdot
.958 .5529 Mdot
.958 .55311 Mdot
.958 .55345 Mdot
.958 .55346 Mdot
.958 .55401 Mdot
.958 .55405 Mdot
.958 .5545 Mdot
.958 .55462 Mdot
.958 .55477 Mdot
.958 .55491 Mdot
.958 .55551 Mdot
.958 .55572 Mdot
.958 .55602 Mdot
.958 .55604 Mdot
.958 .55631 Mdot
.958 .5571 Mdot
.958 .55719 Mdot
.958 .55755 Mdot
.958 .55759 Mdot
.958 .5588 Mdot
.958 .55885 Mdot
.958 .55904 Mdot
.958 .55905 Mdot
.958 .55922 Mdot
.958 .5598 Mdot
.958 .55984 Mdot
.958 .56007 Mdot
.958 .56008 Mdot
.958 .56027 Mdot
.958 .56052 Mdot
.958 .56053 Mdot
.958 .56112 Mdot
.958 .56157 Mdot
.958 .56166 Mdot
.958 .56166 Mdot
.958 .56171 Mdot
.958 .56192 Mdot
.958 .56216 Mdot
.958 .56238 Mdot
.958 .56238 Mdot
.958 .56278 Mdot
.958 .56406 Mdot
.958 .56421 Mdot
.958 .56429 Mdot
.958 .56433 Mdot
.958 .56472 Mdot
.958 .56508 Mdot
.958 .56517 Mdot
.958 .56518 Mdot
.958 .56551 Mdot
.958 .56583 Mdot
.958 .5659 Mdot
.958 .56706 Mdot
.958 .56721 Mdot
.958 .56767 Mdot
.958 .56794 Mdot
.958 .56809 Mdot
.958 .56846 Mdot
.958 .56851 Mdot
.958 .56869 Mdot
.958 .56877 Mdot
.958 .56886 Mdot
.958 .56903 Mdot
.958 .56904 Mdot
.958 .56907 Mdot
.958 .56911 Mdot
.958 .5692 Mdot
.958 .56923 Mdot
.958 .56947 Mdot
.958 .56957 Mdot
.958 .56972 Mdot
.958 .57067 Mdot
.958 .57072 Mdot
.958 .57073 Mdot
.958 .57161 Mdot
.958 .57193 Mdot
.958 .57205 Mdot
.958 .57213 Mdot
.958 .57219 Mdot
.958 .57223 Mdot
.958 .57227 Mdot
.958 .57264 Mdot
.958 .57278 Mdot
.958 .57301 Mdot
.958 .57329 Mdot
.958 .57332 Mdot
.958 .5734 Mdot
.958 .57354 Mdot
.958 .57366 Mdot
.958 .57385 Mdot
.958 .57408 Mdot
.958 .57416 Mdot
.958 .57422 Mdot
.958 .5744 Mdot
.958 .57443 Mdot
.958 .57473 Mdot
.958 .57481 Mdot
.958 .57528 Mdot
.958 .57528 Mdot
.958 .57532 Mdot
.958 .57557 Mdot
.958 .57611 Mdot
.958 .5766 Mdot
.958 .57683 Mdot
.958 .57686 Mdot
.958 .57697 Mdot
.958 .57709 Mdot
.958 .57712 Mdot
.958 .57715 Mdot
.958 .57716 Mdot
.958 .57722 Mdot
.958 .57724 Mdot
.958 .57726 Mdot
.958 .57729 Mdot
.958 .57734 Mdot
.958 .57746 Mdot
.958 .57752 Mdot
.958 .57757 Mdot
.958 .57766 Mdot
.958 .57786 Mdot
.958 .57797 Mdot
.958 .57805 Mdot
.958 .57809 Mdot
.958 .57812 Mdot
.958 .57812 Mdot
.958 .57814 Mdot
.958 .57817 Mdot
.958 .57821 Mdot
.958 .57824 Mdot
.958 .57827 Mdot
.958 .57836 Mdot
.958 .57845 Mdot
.958 .57846 Mdot
.958 .5785 Mdot
.958 .5785 Mdot
.958 .5785 Mdot
.958 .57852 Mdot
.958 .57853 Mdot
.958 .57856 Mdot
.958 .57858 Mdot
.958 .57859 Mdot
.958 .57859 Mdot
.958 .5786 Mdot
.958 .5786 Mdot
.958 .57861 Mdot
.958 .57862 Mdot
.958 .57862 Mdot
.958 .57862 Mdot
.958 .57862 Mdot
.958 .57862 Mdot
.958 .57862 Mdot
.96 .08555 Mdot
.96 .08555 Mdot
.96 .08556 Mdot
.96 .0856 Mdot
.96 .08567 Mdot
.96 .08579 Mdot
.96 .08587 Mdot
.96 .08589 Mdot
.96 .08602 Mdot
.96 .08608 Mdot
.96 .0861 Mdot
.96 .08614 Mdot
.96 .08623 Mdot
.96 .08624 Mdot
.96 .08649 Mdot
.96 .0865 Mdot
.96 .08651 Mdot
.96 .08662 Mdot
.96 .08674 Mdot
.96 .08696 Mdot
.96 .08752 Mdot
.96 .08769 Mdot
.96 .08788 Mdot
.96 .08817 Mdot
.96 .0883 Mdot
.96 .08907 Mdot
.96 .08921 Mdot
.96 .08936 Mdot
.96 .08941 Mdot
.96 .08956 Mdot
.96 .08966 Mdot
.96 .08973 Mdot
.96 .08976 Mdot
.96 .09017 Mdot
.96 .09041 Mdot
.96 .09064 Mdot
.96 .09076 Mdot
.96 .09083 Mdot
.96 .09128 Mdot
.96 .09173 Mdot
.96 .09176 Mdot
.96 .09197 Mdot
.96 .09202 Mdot
.96 .09204 Mdot
.96 .09244 Mdot
.96 .0928 Mdot
.96 .09292 Mdot
.96 .09309 Mdot
.96 .09324 Mdot
.96 .09344 Mdot
.96 .09366 Mdot
.96 .09418 Mdot
.96 .09482 Mdot
.96 .09487 Mdot
.96 .09509 Mdot
.96 .09523 Mdot
.96 .09535 Mdot
.96 .096 Mdot
.96 .09654 Mdot
.96 .09657 Mdot
.96 .09754 Mdot
.96 .09776 Mdot
.96 .09797 Mdot
.96 .09827 Mdot
.96 .09922 Mdot
.96 .09984 Mdot
.96 .09997 Mdot
.96 .10055 Mdot
.96 .10096 Mdot
.96 .1023 Mdot
.96 .10241 Mdot
.96 .10275 Mdot
.96 .1038 Mdot
.96 .10403 Mdot
.96 .10403 Mdot
.96 .10454 Mdot
.96 .10456 Mdot
.96 .10506 Mdot
.96 .10554 Mdot
.96 .10588 Mdot
.96 .10633 Mdot
.96 .10646 Mdot
.96 .10712 Mdot
.96 .10722 Mdot
.96 .10802 Mdot
.96 .10822 Mdot
.96 .10854 Mdot
.96 .10915 Mdot
.96 .10961 Mdot
.96 .1103 Mdot
.96 .11048 Mdot
.96 .11055 Mdot
.96 .11104 Mdot
.96 .11232 Mdot
.96 .1126 Mdot
.96 .11269 Mdot
.96 .11463 Mdot
.96 .1149 Mdot
.96 .11491 Mdot
.96 .11592 Mdot
.96 .11676 Mdot
.96 .11712 Mdot
.96 .11923 Mdot
.96 .1193 Mdot
.96 .11946 Mdot
.96 .11997 Mdot
.96 .1209 Mdot
.96 .12145 Mdot
.96 .12255 Mdot
.96 .1228 Mdot
.96 .12294 Mdot
.96 .12313 Mdot
.96 .12425 Mdot
.96 .1252 Mdot
.96 .13019 Mdot
.96 .13238 Mdot
.96 .13249 Mdot
.96 .13316 Mdot
.96 .13365 Mdot
.96 .13528 Mdot
.96 .13569 Mdot
.96 .13581 Mdot
.96 .13588 Mdot
.96 .13623 Mdot
.96 .13656 Mdot
.96 .13662 Mdot
.96 .13806 Mdot
.96 .13814 Mdot
.96 .14018 Mdot
.96 .14031 Mdot
.96 .14267 Mdot
.96 .14275 Mdot
.96 .14626 Mdot
.96 .14817 Mdot
.96 .1482 Mdot
.96 .14859 Mdot
.96 .14956 Mdot
.96 .15104 Mdot
.96 .15287 Mdot
.96 .15374 Mdot
.96 .15407 Mdot
.96 .15513 Mdot
.96 .1563 Mdot
.96 .15765 Mdot
.96 .15783 Mdot
.96 .15809 Mdot
.96 .15884 Mdot
.96 .15895 Mdot
.96 .15905 Mdot
.96 .16002 Mdot
.96 .16013 Mdot
.96 .16073 Mdot
.96 .16127 Mdot
.96 .16155 Mdot
.96 .16169 Mdot
.96 .16207 Mdot
.96 .1653 Mdot
.96 .16644 Mdot
.96 .16707 Mdot
.96 .16732 Mdot
.96 .16751 Mdot
.96 .16757 Mdot
.96 .16794 Mdot
.96 .16838 Mdot
.96 .16999 Mdot
.96 .17036 Mdot
.96 .17171 Mdot
.96 .17323 Mdot
.96 .17381 Mdot
.96 .17494 Mdot
.96 .17529 Mdot
.96 .17613 Mdot
.96 .17614 Mdot
.96 .1767 Mdot
.96 .17724 Mdot
.96 .17753 Mdot
.96 .17794 Mdot
.96 .17816 Mdot
.96 .17933 Mdot
.96 .18111 Mdot
.96 .18208 Mdot
.96 .18256 Mdot
.96 .18272 Mdot
.96 .18389 Mdot
.96 .18462 Mdot
.96 .18504 Mdot
.96 .18526 Mdot
.96 .18555 Mdot
.96 .18573 Mdot
.96 .1859 Mdot
.96 .18625 Mdot
.96 .18679 Mdot
.96 .18742 Mdot
.96 .18834 Mdot
.96 .1889 Mdot
.96 .18923 Mdot
.96 .19134 Mdot
.96 .19178 Mdot
.96 .19254 Mdot
.96 .19263 Mdot
.96 .1928 Mdot
.96 .19318 Mdot
.96 .19335 Mdot
.96 .19468 Mdot
.96 .19498 Mdot
.96 .19516 Mdot
.96 .19527 Mdot
.96 .19906 Mdot
.96 .19935 Mdot
.96 .20069 Mdot
.96 .20133 Mdot
.96 .20177 Mdot
.96 .20257 Mdot
.96 .20301 Mdot
.96 .20367 Mdot
.96 .20467 Mdot
.96 .20468 Mdot
.96 .20677 Mdot
.96 .20889 Mdot
.96 .21263 Mdot
.96 .21286 Mdot
.96 .21353 Mdot
.96 .21446 Mdot
.96 .2151 Mdot
.96 .21578 Mdot
.96 .21592 Mdot
.96 .21618 Mdot
.96 .21626 Mdot
.96 .21657 Mdot
.96 .21685 Mdot
.96 .2171 Mdot
.96 .21769 Mdot
.96 .21808 Mdot
.96 .21892 Mdot
.96 .21912 Mdot
.96 .22093 Mdot
.96 .22264 Mdot
.96 .22329 Mdot
.96 .2233 Mdot
.96 .22331 Mdot
.96 .22343 Mdot
.96 .22363 Mdot
.96 .22397 Mdot
.96 .22419 Mdot
.96 .22424 Mdot
.96 .22462 Mdot
.96 .22477 Mdot
.96 .22483 Mdot
.96 .22494 Mdot
.96 .22506 Mdot
.96 .22519 Mdot
.96 .22523 Mdot
.96 .22591 Mdot
.96 .22596 Mdot
.96 .226 Mdot
.96 .22614 Mdot
.96 .22628 Mdot
.96 .22655 Mdot
.96 .22662 Mdot
.96 .22724 Mdot
.96 .22742 Mdot
.96 .22881 Mdot
.96 .22889 Mdot
.96 .22914 Mdot
.96 .22928 Mdot
.96 .22981 Mdot
.96 .23019 Mdot
.96 .23062 Mdot
.96 .23099 Mdot
.96 .23202 Mdot
.96 .23253 Mdot
.96 .23313 Mdot
.96 .23338 Mdot
.96 .2335 Mdot
.96 .23368 Mdot
.96 .23375 Mdot
.96 .23393 Mdot
.96 .23408 Mdot
.96 .23447 Mdot
.96 .23476 Mdot
.96 .23496 Mdot
.96 .23503 Mdot
.96 .23618 Mdot
.96 .23684 Mdot
.96 .23749 Mdot
.96 .2378 Mdot
.96 .23801 Mdot
.96 .23815 Mdot
.96 .23854 Mdot
.96 .23917 Mdot
.96 .23927 Mdot
.96 .24049 Mdot
.96 .24058 Mdot
.96 .24117 Mdot
.96 .24129 Mdot
.96 .24135 Mdot
.96 .24138 Mdot
.96 .24163 Mdot
.96 .24177 Mdot
.96 .24247 Mdot
.96 .24258 Mdot
.96 .24307 Mdot
.96 .24347 Mdot
.96 .24358 Mdot
.96 .2437 Mdot
.96 .2438 Mdot
.96 .24387 Mdot
.96 .24426 Mdot
.96 .24466 Mdot
.96 .24522 Mdot
.96 .24583 Mdot
.96 .24632 Mdot
.96 .24646 Mdot
.96 .24695 Mdot
.96 .24725 Mdot
.96 .24737 Mdot
.96 .24778 Mdot
.96 .24798 Mdot
.96 .24853 Mdot
.96 .24902 Mdot
.96 .24915 Mdot
.96 .24974 Mdot
.96 .2499 Mdot
.96 .25006 Mdot
.96 .25013 Mdot
.96 .25046 Mdot
.96 .25088 Mdot
.96 .2521 Mdot
.96 .25224 Mdot
.96 .25284 Mdot
.96 .25288 Mdot
.96 .25326 Mdot
.96 .2533 Mdot
.96 .25334 Mdot
.96 .25373 Mdot
.96 .2538 Mdot
.96 .25522 Mdot
.96 .2557 Mdot
.96 .25645 Mdot
.96 .25706 Mdot
.96 .25762 Mdot
.96 .25844 Mdot
.96 .25998 Mdot
.96 .26102 Mdot
.96 .262 Mdot
.96 .26269 Mdot
.96 .26271 Mdot
.96 .26306 Mdot
.96 .26407 Mdot
.96 .26462 Mdot
.96 .26468 Mdot
.96 .26574 Mdot
.96 .26876 Mdot
.96 .26934 Mdot
.96 .26952 Mdot
.96 .26966 Mdot
.96 .27055 Mdot
.96 .27148 Mdot
.96 .27268 Mdot
.96 .27289 Mdot
.96 .27339 Mdot
.96 .27399 Mdot
.96 .274 Mdot
.96 .27416 Mdot
.96 .27535 Mdot
.96 .2754 Mdot
.96 .27558 Mdot
.96 .27639 Mdot
.96 .27675 Mdot
.96 .27733 Mdot
.96 .27804 Mdot
.96 .27826 Mdot
.96 .2784 Mdot
.96 .27895 Mdot
.96 .27958 Mdot
.96 .2799 Mdot
.96 .28014 Mdot
.96 .2805 Mdot
.96 .28087 Mdot
.96 .28088 Mdot
.96 .28126 Mdot
.96 .28143 Mdot
.96 .28225 Mdot
.96 .28251 Mdot
.96 .2826 Mdot
.96 .28368 Mdot
.96 .28402 Mdot
.96 .28462 Mdot
.96 .28516 Mdot
.96 .28601 Mdot
.96 .28647 Mdot
.96 .28763 Mdot
.96 .28816 Mdot
.96 .28883 Mdot
.96 .29007 Mdot
.96 .29065 Mdot
.96 .29113 Mdot
.96 .2913 Mdot
.96 .29165 Mdot
.96 .29259 Mdot
.96 .29262 Mdot
.96 .29267 Mdot
.96 .29357 Mdot
.96 .2942 Mdot
.96 .29583 Mdot
.96 .29595 Mdot
.96 .29611 Mdot
.96 .29634 Mdot
.96 .29669 Mdot
.96 .29691 Mdot
.96 .29831 Mdot
.96 .30198 Mdot
.96 .30266 Mdot
.96 .3027 Mdot
.96 .30276 Mdot
.96 .30368 Mdot
.96 .30455 Mdot
.96 .30532 Mdot
.96 .30748 Mdot
.96 .30829 Mdot
.96 .30841 Mdot
.96 .30987 Mdot
.96 .31136 Mdot
.96 .31225 Mdot
.96 .31283 Mdot
.96 .31375 Mdot
.96 .31384 Mdot
.96 .31401 Mdot
.96 .31443 Mdot
.96 .31572 Mdot
.96 .31671 Mdot
.96 .3181 Mdot
.96 .31849 Mdot
.96 .31889 Mdot
.96 .31949 Mdot
.96 .32163 Mdot
.96 .32227 Mdot
.96 .3229 Mdot
.96 .32325 Mdot
.96 .32359 Mdot
.96 .32376 Mdot
.96 .32507 Mdot
.96 .32511 Mdot
.96 .32597 Mdot
.96 .32656 Mdot
.96 .32716 Mdot
.96 .32873 Mdot
.96 .32896 Mdot
.96 .32911 Mdot
.96 .33046 Mdot
.96 .33138 Mdot
.96 .33178 Mdot
.96 .33355 Mdot
.96 .3368 Mdot
.96 .33858 Mdot
.96 .33904 Mdot
.96 .34043 Mdot
.96 .34118 Mdot
.96 .34135 Mdot
.96 .34662 Mdot
.96 .34671 Mdot
.96 .34699 Mdot
.96 .34781 Mdot
.96 .34861 Mdot
.96 .3498 Mdot
.96 .35375 Mdot
.96 .35475 Mdot
.96 .35494 Mdot
.96 .35503 Mdot
.96 .35519 Mdot
.96 .35603 Mdot
.96 .35684 Mdot
.96 .35698 Mdot
.96 .35811 Mdot
.96 .36043 Mdot
.96 .3606 Mdot
.96 .36271 Mdot
.96 .36326 Mdot
.96 .36373 Mdot
.96 .36443 Mdot
.96 .36545 Mdot
.96 .36566 Mdot
.96 .36576 Mdot
.96 .36783 Mdot
.96 .36802 Mdot
.96 .37111 Mdot
.96 .37131 Mdot
.96 .3715 Mdot
.96 .37182 Mdot
.96 .37318 Mdot
.96 .37334 Mdot
.96 .37404 Mdot
.96 .37442 Mdot
.96 .37477 Mdot
.96 .37529 Mdot
.96 .37695 Mdot
.96 .37738 Mdot
.96 .37753 Mdot
.96 .37931 Mdot
.96 .37965 Mdot
.96 .38057 Mdot
.96 .38378 Mdot
.96 .38403 Mdot
.96 .3841 Mdot
.96 .38422 Mdot
.96 .38499 Mdot
.96 .38675 Mdot
.96 .38718 Mdot
.96 .38794 Mdot
.96 .38927 Mdot
.96 .39053 Mdot
.96 .39155 Mdot
.96 .39464 Mdot
.96 .39528 Mdot
.96 .39658 Mdot
.96 .39731 Mdot
.96 .39768 Mdot
.96 .39785 Mdot
.96 .39966 Mdot
.96 .40004 Mdot
.96 .40075 Mdot
.96 .40145 Mdot
.96 .40214 Mdot
.96 .40224 Mdot
.96 .40259 Mdot
.96 .40287 Mdot
.96 .40403 Mdot
.96 .40493 Mdot
.96 .40518 Mdot
.96 .40559 Mdot
.96 .406 Mdot
.96 .40608 Mdot
.96 .40614 Mdot
.96 .40664 Mdot
.96 .40777 Mdot
.96 .40801 Mdot
.96 .40823 Mdot
.96 .40957 Mdot
.96 .40995 Mdot
.96 .41017 Mdot
.96 .41032 Mdot
.96 .41055 Mdot
.96 .41174 Mdot
.96 .41184 Mdot
.96 .41252 Mdot
.96 .41301 Mdot
.96 .4136 Mdot
.96 .4139 Mdot
.96 .41429 Mdot
.96 .41472 Mdot
.96 .41495 Mdot
.96 .41684 Mdot
.96 .41718 Mdot
.96 .42075 Mdot
.96 .42153 Mdot
.96 .42265 Mdot
.96 .42391 Mdot
.96 .42395 Mdot
.96 .42521 Mdot
.96 .42561 Mdot
.96 .42573 Mdot
.96 .42614 Mdot
.96 .42624 Mdot
.96 .42702 Mdot
.96 .42781 Mdot
.96 .42792 Mdot
.96 .42854 Mdot
.96 .43123 Mdot
.96 .43198 Mdot
.96 .43244 Mdot
.96 .43328 Mdot
.96 .4333 Mdot
.96 .43426 Mdot
.96 .43431 Mdot
.96 .4347 Mdot
.96 .4349 Mdot
.96 .43606 Mdot
.96 .43743 Mdot
.96 .43776 Mdot
.96 .43817 Mdot
.96 .43891 Mdot
.96 .44011 Mdot
.96 .44036 Mdot
.96 .44038 Mdot
.96 .44117 Mdot
.96 .44186 Mdot
.96 .44352 Mdot
.96 .44352 Mdot
.96 .44365 Mdot
.96 .44462 Mdot
.96 .44499 Mdot
.96 .44568 Mdot
.96 .44625 Mdot
.96 .44654 Mdot
.96 .44657 Mdot
.96 .44705 Mdot
.96 .44705 Mdot
.96 .44747 Mdot
.96 .44938 Mdot
.96 .44973 Mdot
.96 .4508 Mdot
.96 .4516 Mdot
.96 .45222 Mdot
.96 .45313 Mdot
.96 .45482 Mdot
.96 .45499 Mdot
.96 .45588 Mdot
.96 .45619 Mdot
.96 .45701 Mdot
.96 .45738 Mdot
.96 .45811 Mdot
.96 .45821 Mdot
.96 .45838 Mdot
.96 .45974 Mdot
.96 .46 Mdot
.96 .46003 Mdot
.96 .46052 Mdot
.96 .46094 Mdot
.96 .46147 Mdot
.96 .4616 Mdot
.96 .4618 Mdot
.96 .46211 Mdot
.96 .46243 Mdot
.96 .46275 Mdot
.96 .46375 Mdot
.96 .46382 Mdot
.96 .4649 Mdot
.96 .46657 Mdot
.96 .46758 Mdot
.96 .46817 Mdot
.96 .46869 Mdot
.96 .4698 Mdot
.96 .47 Mdot
.96 .4714 Mdot
.96 .47194 Mdot
.96 .47271 Mdot
.96 .47278 Mdot
.96 .47297 Mdot
.96 .47368 Mdot
.96 .4739 Mdot
.96 .47406 Mdot
.96 .47422 Mdot
.96 .47452 Mdot
.96 .47459 Mdot
.96 .47517 Mdot
.96 .47548 Mdot
.96 .47679 Mdot
.96 .47687 Mdot
.96 .47779 Mdot
.96 .47831 Mdot
.96 .47861 Mdot
.96 .4788 Mdot
.96 .47904 Mdot
.96 .48096 Mdot
.96 .48228 Mdot
.96 .48523 Mdot
.96 .48572 Mdot
.96 .48793 Mdot
.96 .48824 Mdot
.96 .4888 Mdot
.96 .48899 Mdot
.96 .48971 Mdot
.96 .49102 Mdot
.96 .49173 Mdot
.96 .49189 Mdot
.96 .49226 Mdot
.96 .4928 Mdot
.96 .49294 Mdot
.96 .49357 Mdot
.96 .49404 Mdot
.96 .49439 Mdot
.96 .4944 Mdot
.96 .49499 Mdot
.96 .49576 Mdot
.96 .49684 Mdot
.96 .497 Mdot
.96 .4977 Mdot
.96 .49886 Mdot
.96 .49922 Mdot
.96 .49944 Mdot
.96 .49979 Mdot
.96 .50037 Mdot
.96 .50099 Mdot
.96 .50243 Mdot
.96 .50277 Mdot
.96 .50312 Mdot
.96 .50483 Mdot
.96 .50559 Mdot
.96 .50568 Mdot
.96 .50578 Mdot
.96 .50641 Mdot
.96 .50665 Mdot
.96 .50699 Mdot
.96 .50701 Mdot
.96 .50738 Mdot
.96 .50798 Mdot
.96 .5087 Mdot
.96 .50934 Mdot
.96 .51027 Mdot
.96 .5104 Mdot
.96 .5108 Mdot
.96 .51124 Mdot
.96 .51131 Mdot
.96 .51145 Mdot
.96 .51145 Mdot
.96 .51182 Mdot
.96 .51194 Mdot
.96 .51238 Mdot
.96 .51243 Mdot
.96 .51278 Mdot
.96 .51313 Mdot
.96 .51344 Mdot
.96 .51397 Mdot
.96 .51444 Mdot
.96 .51452 Mdot
.96 .51497 Mdot
.96 .51569 Mdot
.96 .51598 Mdot
.96 .51749 Mdot
.96 .51771 Mdot
.96 .51822 Mdot
.96 .51848 Mdot
.96 .51922 Mdot
.96 .52079 Mdot
.96 .52097 Mdot
.96 .52166 Mdot
.96 .52167 Mdot
.96 .52169 Mdot
.96 .52183 Mdot
.96 .52184 Mdot
.96 .52211 Mdot
.96 .52256 Mdot
.96 .52286 Mdot
.96 .52291 Mdot
.96 .52341 Mdot
.96 .52361 Mdot
.96 .52369 Mdot
.96 .52384 Mdot
.96 .52399 Mdot
.96 .52417 Mdot
.96 .52422 Mdot
.96 .52511 Mdot
.96 .52517 Mdot
.96 .52521 Mdot
.96 .5254 Mdot
.96 .52558 Mdot
.96 .52587 Mdot
.96 .52592 Mdot
.96 .52601 Mdot
.96 .52681 Mdot
.96 .52704 Mdot
.96 .52718 Mdot
.96 .52876 Mdot
.96 .52879 Mdot
.96 .52889 Mdot
.96 .5292 Mdot
.96 .52938 Mdot
.96 .53004 Mdot
.96 .53042 Mdot
.96 .53051 Mdot
.96 .53103 Mdot
.96 .53135 Mdot
.96 .53149 Mdot
.96 .53188 Mdot
.96 .53274 Mdot
.96 .53335 Mdot
.96 .53399 Mdot
.96 .53407 Mdot
.96 .53437 Mdot
.96 .5345 Mdot
.96 .53471 Mdot
.96 .5348 Mdot
.96 .5349 Mdot
.96 .53501 Mdot
.96 .53504 Mdot
.96 .53513 Mdot
.96 .53518 Mdot
.96 .53542 Mdot
.96 .53565 Mdot
.96 .53598 Mdot
.96 .53622 Mdot
.96 .5363 Mdot
.96 .53762 Mdot
.96 .53837 Mdot
.96 .5391 Mdot
.96 .53911 Mdot
.96 .53946 Mdot
.96 .53969 Mdot
.96 .53985 Mdot
.96 .54013 Mdot
.96 .54028 Mdot
.96 .54051 Mdot
.96 .54098 Mdot
.96 .54108 Mdot
.96 .54241 Mdot
.96 .54245 Mdot
.96 .54251 Mdot
.96 .54261 Mdot
.96 .54308 Mdot
.96 .54314 Mdot
.96 .54327 Mdot
.96 .54333 Mdot
.96 .54336 Mdot
.96 .54363 Mdot
.96 .54378 Mdot
.96 .54452 Mdot
.96 .54463 Mdot
.96 .54483 Mdot
.96 .54515 Mdot
.96 .54537 Mdot
.96 .54555 Mdot
.96 .54568 Mdot
.96 .54573 Mdot
.96 .5458 Mdot
.96 .5459 Mdot
.96 .54597 Mdot
.96 .54612 Mdot
.96 .54637 Mdot
.96 .54678 Mdot
.96 .54684 Mdot
.96 .547 Mdot
.96 .54734 Mdot
.96 .54796 Mdot
.96 .54836 Mdot
.96 .54844 Mdot
.96 .54858 Mdot
.96 .54868 Mdot
.96 .54887 Mdot
.96 .54906 Mdot
.96 .54907 Mdot
.96 .54936 Mdot
.96 .54948 Mdot
.96 .54987 Mdot
.96 .55007 Mdot
.96 .55059 Mdot
.96 .55106 Mdot
.96 .55119 Mdot
.96 .55174 Mdot
.96 .55189 Mdot
.96 .55202 Mdot
.96 .55204 Mdot
.96 .55211 Mdot
.96 .55219 Mdot
.96 .55241 Mdot
.96 .5528 Mdot
.96 .55391 Mdot
.96 .55404 Mdot
.96 .55409 Mdot
.96 .55419 Mdot
.96 .55437 Mdot
.96 .55458 Mdot
.96 .55462 Mdot
.96 .55495 Mdot
.96 .55498 Mdot
.96 .55502 Mdot
.96 .55528 Mdot
.96 .55537 Mdot
.96 .55543 Mdot
.96 .55589 Mdot
.96 .55629 Mdot
.96 .55665 Mdot
.96 .55677 Mdot
.96 .55706 Mdot
.96 .55769 Mdot
.96 .5582 Mdot
.96 .55853 Mdot
.96 .55866 Mdot
.96 .55867 Mdot
.96 .55932 Mdot
.96 .56052 Mdot
.96 .56055 Mdot
.96 .56135 Mdot
.96 .56139 Mdot
.96 .5615 Mdot
.96 .56209 Mdot
.96 .56211 Mdot
.96 .5626 Mdot
.96 .56262 Mdot
.96 .56274 Mdot
.96 .56285 Mdot
.96 .56288 Mdot
.96 .56292 Mdot
.96 .56306 Mdot
.96 .56361 Mdot
.96 .56378 Mdot
.96 .564 Mdot
.96 .56404 Mdot
.96 .56478 Mdot
.96 .56647 Mdot
.96 .56679 Mdot
.96 .56717 Mdot
.96 .56724 Mdot
.96 .56728 Mdot
.96 .56737 Mdot
.96 .56774 Mdot
.96 .56792 Mdot
.96 .56824 Mdot
.96 .56841 Mdot
.96 .56846 Mdot
.96 .56849 Mdot
.96 .5692 Mdot
.96 .56932 Mdot
.96 .5696 Mdot
.96 .56994 Mdot
.96 .56995 Mdot
.96 .57004 Mdot
.96 .57069 Mdot
.96 .57072 Mdot
.96 .57082 Mdot
.96 .57125 Mdot
.96 .57141 Mdot
.96 .57143 Mdot
.96 .5715 Mdot
.96 .57173 Mdot
.96 .57188 Mdot
.96 .57209 Mdot
.96 .5722 Mdot
.96 .57226 Mdot
.96 .57253 Mdot
.96 .57256 Mdot
.96 .57279 Mdot
.96 .57283 Mdot
.96 .57298 Mdot
.96 .5731 Mdot
.96 .57326 Mdot
.96 .57343 Mdot
.96 .57343 Mdot
.96 .5736 Mdot
.96 .5736 Mdot
.96 .57368 Mdot
.96 .57403 Mdot
.96 .57415 Mdot
.96 .57419 Mdot
.96 .57463 Mdot
.96 .57477 Mdot
.96 .57497 Mdot
.96 .57501 Mdot
.96 .57522 Mdot
.96 .57554 Mdot
.96 .57564 Mdot
.96 .57571 Mdot
.96 .57578 Mdot
.96 .57611 Mdot
.96 .57612 Mdot
.96 .5763 Mdot
.96 .57652 Mdot
.96 .57656 Mdot
.96 .5766 Mdot
.96 .57668 Mdot
.96 .57691 Mdot
.96 .57708 Mdot
.96 .57715 Mdot
.96 .57722 Mdot
.96 .57727 Mdot
.96 .57733 Mdot
.96 .57737 Mdot
.96 .57749 Mdot
.96 .57762 Mdot
.96 .57763 Mdot
.96 .57765 Mdot
.96 .57772 Mdot
.96 .57773 Mdot
.96 .57788 Mdot
.96 .57803 Mdot
.96 .57805 Mdot
.96 .57809 Mdot
.96 .57817 Mdot
.96 .57825 Mdot
.96 .57839 Mdot
.96 .5784 Mdot
.96 .57842 Mdot
.96 .57845 Mdot
.96 .5785 Mdot
.96 .57852 Mdot
.96 .57857 Mdot
.96 .57862 Mdot
.96 .57887 Mdot
.96 .57892 Mdot
.96 .57901 Mdot
.96 .57908 Mdot
.96 .57914 Mdot
.96 .57932 Mdot
.96 .5794 Mdot
.96 .57944 Mdot
.96 .57947 Mdot
.96 .57948 Mdot
.96 .57948 Mdot
.96 .57956 Mdot
.96 .57957 Mdot
.96 .5796 Mdot
.96 .57961 Mdot
.96 .57962 Mdot
.96 .57964 Mdot
.96 .57968 Mdot
.96 .57969 Mdot
.96 .57971 Mdot
.96 .57975 Mdot
.96 .57978 Mdot
.96 .57979 Mdot
.96 .57979 Mdot
.96 .57979 Mdot
.962 .08216 Mdot
.962 .08216 Mdot
.962 .08219 Mdot
.962 .0822 Mdot
.962 .08221 Mdot
.962 .08221 Mdot
.962 .08223 Mdot
.962 .08226 Mdot
.962 .08228 Mdot
.962 .08239 Mdot
.962 .08251 Mdot
.962 .08279 Mdot
.962 .08287 Mdot
.962 .08291 Mdot
.962 .08302 Mdot
.962 .08305 Mdot
.962 .08321 Mdot
.962 .08337 Mdot
.962 .08344 Mdot
.962 .0837 Mdot
.962 .08412 Mdot
.962 .08427 Mdot
.962 .08456 Mdot
.962 .0846 Mdot
.962 .0847 Mdot
.962 .08476 Mdot
.962 .08487 Mdot
.962 .08494 Mdot
.962 .08516 Mdot
.962 .08544 Mdot
.962 .08577 Mdot
.962 .08589 Mdot
.962 .08646 Mdot
.962 .08701 Mdot
.962 .08703 Mdot
.962 .08719 Mdot
.962 .08761 Mdot
.962 .08766 Mdot
.962 .08806 Mdot
.962 .08821 Mdot
.962 .09066 Mdot
.962 .09068 Mdot
.962 .09198 Mdot
.962 .09261 Mdot
.962 .09343 Mdot
.962 .09365 Mdot
.962 .09365 Mdot
.962 .09387 Mdot
.962 .09416 Mdot
.962 .09455 Mdot
.962 .09466 Mdot
.962 .09504 Mdot
.962 .09535 Mdot
.962 .09563 Mdot
.962 .09572 Mdot
.962 .09583 Mdot
.962 .09586 Mdot
.962 .09593 Mdot
.962 .09595 Mdot
.962 .09602 Mdot
.962 .0961 Mdot
.962 .0961 Mdot
.962 .0962 Mdot
.962 .09626 Mdot
.962 .09654 Mdot
.962 .09685 Mdot
.962 .09703 Mdot
.962 .09712 Mdot
.962 .09859 Mdot
.962 .09933 Mdot
.962 .09937 Mdot
.962 .09994 Mdot
.962 .10036 Mdot
.962 .10049 Mdot
.962 .10066 Mdot
.962 .10079 Mdot
.962 .10109 Mdot
.962 .10124 Mdot
.962 .10177 Mdot
.962 .10184 Mdot
.962 .10223 Mdot
.962 .10249 Mdot
.962 .10256 Mdot
.962 .10308 Mdot
.962 .10315 Mdot
.962 .10331 Mdot
.962 .10347 Mdot
.962 .10352 Mdot
.962 .10456 Mdot
.962 .10468 Mdot
.962 .10505 Mdot
.962 .10509 Mdot
.962 .1051 Mdot
.962 .10512 Mdot
.962 .10591 Mdot
.962 .10604 Mdot
.962 .10613 Mdot
.962 .10624 Mdot
.962 .10626 Mdot
.962 .10645 Mdot
.962 .10657 Mdot
.962 .10661 Mdot
.962 .10677 Mdot
.962 .10794 Mdot
.962 .10797 Mdot
.962 .10819 Mdot
.962 .10843 Mdot
.962 .10846 Mdot
.962 .1086 Mdot
.962 .10878 Mdot
.962 .10886 Mdot
.962 .11105 Mdot
.962 .11136 Mdot
.962 .11158 Mdot
.962 .11168 Mdot
.962 .11304 Mdot
.962 .11328 Mdot
.962 .11352 Mdot
.962 .11404 Mdot
.962 .11457 Mdot
.962 .11478 Mdot
.962 .11481 Mdot
.962 .11514 Mdot
.962 .11592 Mdot
.962 .11668 Mdot
.962 .1169 Mdot
.962 .11765 Mdot
.962 .118 Mdot
.962 .1193 Mdot
.962 .12112 Mdot
.962 .12131 Mdot
.962 .12167 Mdot
.962 .12197 Mdot
.962 .12324 Mdot
.962 .12448 Mdot
.962 .12529 Mdot
.962 .12578 Mdot
.962 .1269 Mdot
.962 .12764 Mdot
.962 .12766 Mdot
.962 .12859 Mdot
.962 .12933 Mdot
.962 .12933 Mdot
.962 .13015 Mdot
.962 .13087 Mdot
.962 .13176 Mdot
.962 .13219 Mdot
.962 .13362 Mdot
.962 .13485 Mdot
.962 .13515 Mdot
.962 .13541 Mdot
.962 .13717 Mdot
.962 .13993 Mdot
.962 .14053 Mdot
.962 .14139 Mdot
.962 .1416 Mdot
.962 .14177 Mdot
.962 .14253 Mdot
.962 .1438 Mdot
.962 .14532 Mdot
.962 .14575 Mdot
.962 .14822 Mdot
.962 .14886 Mdot
.962 .14957 Mdot
.962 .15013 Mdot
.962 .15023 Mdot
.962 .15097 Mdot
.962 .15142 Mdot
.962 .15241 Mdot
.962 .1532 Mdot
.962 .15356 Mdot
.962 .15554 Mdot
.962 .15571 Mdot
.962 .15583 Mdot
.962 .15586 Mdot
.962 .15599 Mdot
.962 .15666 Mdot
.962 .15667 Mdot
.962 .15674 Mdot
.962 .15725 Mdot
.962 .15778 Mdot
.962 .15788 Mdot
.962 .15814 Mdot
.962 .15826 Mdot
.962 .15838 Mdot
.962 .15861 Mdot
.962 .15922 Mdot
.962 .15939 Mdot
.962 .16006 Mdot
.962 .16194 Mdot
.962 .16217 Mdot
.962 .16284 Mdot
.962 .16345 Mdot
.962 .16445 Mdot
.962 .16589 Mdot
.962 .16731 Mdot
.962 .16742 Mdot
.962 .16746 Mdot
.962 .16818 Mdot
.962 .16882 Mdot
.962 .16993 Mdot
.962 .17114 Mdot
.962 .17263 Mdot
.962 .17282 Mdot
.962 .1734 Mdot
.962 .17504 Mdot
.962 .17515 Mdot
.962 .17516 Mdot
.962 .17634 Mdot
.962 .17693 Mdot
.962 .18151 Mdot
.962 .18363 Mdot
.962 .18377 Mdot
.962 .18886 Mdot
.962 .18921 Mdot
.962 .1897 Mdot
.962 .19003 Mdot
.962 .19148 Mdot
.962 .19161 Mdot
.962 .19163 Mdot
.962 .19389 Mdot
.962 .19453 Mdot
.962 .19453 Mdot
.962 .19551 Mdot
.962 .1977 Mdot
.962 .19882 Mdot
.962 .20012 Mdot
.962 .2003 Mdot
.962 .20058 Mdot
.962 .20228 Mdot
.962 .20768 Mdot
.962 .2108 Mdot
.962 .21127 Mdot
.962 .212 Mdot
.962 .2133 Mdot
.962 .21417 Mdot
.962 .21418 Mdot
.962 .21425 Mdot
.962 .21429 Mdot
.962 .21431 Mdot
.962 .21432 Mdot
.962 .21439 Mdot
.962 .21445 Mdot
.962 .21451 Mdot
.962 .21482 Mdot
.962 .21518 Mdot
.962 .21526 Mdot
.962 .21534 Mdot
.962 .21577 Mdot
.962 .21596 Mdot
.962 .21619 Mdot
.962 .21622 Mdot
.962 .21631 Mdot
.962 .21662 Mdot
.962 .21668 Mdot
.962 .21709 Mdot
.962 .21714 Mdot
.962 .21742 Mdot
.962 .21758 Mdot
.962 .21778 Mdot
.962 .21852 Mdot
.962 .21971 Mdot
.962 .22014 Mdot
.962 .22029 Mdot
.962 .22096 Mdot
.962 .22105 Mdot
.962 .22119 Mdot
.962 .22133 Mdot
.962 .2215 Mdot
.962 .22182 Mdot
.962 .22203 Mdot
.962 .22212 Mdot
.962 .22236 Mdot
.962 .22262 Mdot
.962 .22289 Mdot
.962 .22299 Mdot
.962 .22342 Mdot
.962 .22432 Mdot
.962 .22434 Mdot
.962 .22468 Mdot
.962 .2263 Mdot
.962 .22674 Mdot
.962 .22704 Mdot
.962 .22782 Mdot
.962 .22788 Mdot
.962 .2282 Mdot
.962 .22834 Mdot
.962 .22875 Mdot
.962 .22949 Mdot
.962 .22965 Mdot
.962 .23077 Mdot
.962 .23116 Mdot
.962 .23119 Mdot
.962 .23134 Mdot
.962 .23195 Mdot
.962 .2328 Mdot
.962 .23329 Mdot
.962 .23403 Mdot
.962 .23442 Mdot
.962 .23464 Mdot
.962 .23739 Mdot
.962 .23792 Mdot
.962 .23801 Mdot
.962 .23806 Mdot
.962 .23847 Mdot
.962 .24004 Mdot
.962 .24155 Mdot
.962 .24167 Mdot
.962 .2434 Mdot
.962 .24567 Mdot
.962 .24587 Mdot
.962 .24628 Mdot
.962 .24629 Mdot
.962 .2469 Mdot
.962 .2471 Mdot
.962 .24716 Mdot
.962 .24769 Mdot
.962 .24875 Mdot
.962 .24906 Mdot
.962 .24958 Mdot
.962 .2501 Mdot
.962 .25047 Mdot
.962 .25095 Mdot
.962 .25174 Mdot
.962 .25199 Mdot
.962 .25205 Mdot
.962 .25228 Mdot
.962 .25237 Mdot
.962 .25241 Mdot
.962 .25256 Mdot
.962 .2526 Mdot
.962 .2528 Mdot
.962 .25302 Mdot
.962 .25303 Mdot
.962 .25329 Mdot
.962 .25339 Mdot
.962 .25346 Mdot
.962 .25423 Mdot
.962 .25437 Mdot
.962 .25507 Mdot
.962 .25525 Mdot
.962 .25555 Mdot
.962 .25559 Mdot
.962 .25581 Mdot
.962 .2561 Mdot
.962 .25636 Mdot
.962 .25755 Mdot
.962 .25818 Mdot
.962 .25872 Mdot
.962 .25911 Mdot
.962 .2592 Mdot
.962 .25957 Mdot
.962 .25983 Mdot
.962 .26182 Mdot
.962 .26194 Mdot
.962 .26207 Mdot
.962 .26264 Mdot
.962 .26349 Mdot
.962 .26425 Mdot
.962 .26464 Mdot
.962 .26499 Mdot
.962 .26545 Mdot
.962 .26581 Mdot
.962 .2666 Mdot
.962 .26701 Mdot
.962 .26828 Mdot
.962 .26844 Mdot
.962 .26863 Mdot
.962 .26873 Mdot
.962 .26969 Mdot
.962 .27039 Mdot
.962 .27058 Mdot
.962 .27153 Mdot
.962 .27197 Mdot
.962 .27216 Mdot
.962 .2723 Mdot
.962 .2726 Mdot
.962 .2729 Mdot
.962 .27304 Mdot
.962 .27318 Mdot
.962 .27398 Mdot
.962 .27418 Mdot
.962 .27571 Mdot
.962 .27576 Mdot
.962 .27596 Mdot
.962 .27599 Mdot
.962 .27628 Mdot
.962 .27715 Mdot
.962 .27718 Mdot
.962 .27726 Mdot
.962 .27739 Mdot
.962 .2774 Mdot
.962 .27747 Mdot
.962 .27753 Mdot
.962 .27762 Mdot
.962 .27816 Mdot
.962 .27845 Mdot
.962 .27853 Mdot
.962 .27924 Mdot
.962 .27951 Mdot
.962 .27956 Mdot
.962 .27993 Mdot
.962 .28017 Mdot
.962 .28045 Mdot
.962 .2805 Mdot
.962 .28089 Mdot
.962 .281 Mdot
.962 .28122 Mdot
.962 .28132 Mdot
.962 .28145 Mdot
.962 .28155 Mdot
.962 .28187 Mdot
.962 .28292 Mdot
.962 .28412 Mdot
.962 .28435 Mdot
.962 .28461 Mdot
.962 .28485 Mdot
.962 .2849 Mdot
.962 .28498 Mdot
.962 .28499 Mdot
.962 .28506 Mdot
.962 .28513 Mdot
.962 .28519 Mdot
.962 .28532 Mdot
.962 .2854 Mdot
.962 .28565 Mdot
.962 .28592 Mdot
.962 .28627 Mdot
.962 .28637 Mdot
.962 .28673 Mdot
.962 .28721 Mdot
.962 .28742 Mdot
.962 .28886 Mdot
.962 .29024 Mdot
.962 .2932 Mdot
.962 .29393 Mdot
.962 .29401 Mdot
.962 .29459 Mdot
.962 .29483 Mdot
.962 .29486 Mdot
.962 .29568 Mdot
.962 .29681 Mdot
.962 .29789 Mdot
.962 .29843 Mdot
.962 .29866 Mdot
.962 .29898 Mdot
.962 .29905 Mdot
.962 .29967 Mdot
.962 .30002 Mdot
.962 .30104 Mdot
.962 .30195 Mdot
.962 .30243 Mdot
.962 .30296 Mdot
.962 .30303 Mdot
.962 .3039 Mdot
.962 .30518 Mdot
.962 .30592 Mdot
.962 .30721 Mdot
.962 .30748 Mdot
.962 .30755 Mdot
.962 .30788 Mdot
.962 .30845 Mdot
.962 .30875 Mdot
.962 .3104 Mdot
.962 .3111 Mdot
.962 .31129 Mdot
.962 .31448 Mdot
.962 .31463 Mdot
.962 .31631 Mdot
.962 .31928 Mdot
.962 .31977 Mdot
.962 .32068 Mdot
.962 .32145 Mdot
.962 .32466 Mdot
.962 .32779 Mdot
.962 .32983 Mdot
.962 .33085 Mdot
.962 .33106 Mdot
.962 .33284 Mdot
.962 .33294 Mdot
.962 .33386 Mdot
.962 .33572 Mdot
.962 .33575 Mdot
.962 .33808 Mdot
.962 .33866 Mdot
.962 .33878 Mdot
.962 .33986 Mdot
.962 .33989 Mdot
.962 .33991 Mdot
.962 .34101 Mdot
.962 .34176 Mdot
.962 .34192 Mdot
.962 .34218 Mdot
.962 .34369 Mdot
.962 .34401 Mdot
.962 .34588 Mdot
.962 .34694 Mdot
.962 .34707 Mdot
.962 .35043 Mdot
.962 .3517 Mdot
.962 .35262 Mdot
.962 .35342 Mdot
.962 .35415 Mdot
.962 .35477 Mdot
.962 .35702 Mdot
.962 .35902 Mdot
.962 .36069 Mdot
.962 .36338 Mdot
.962 .36471 Mdot
.962 .36472 Mdot
.962 .36506 Mdot
.962 .3656 Mdot
.962 .36703 Mdot
.962 .36736 Mdot
.962 .36904 Mdot
.962 .36905 Mdot
.962 .36954 Mdot
.962 .36994 Mdot
.962 .37174 Mdot
.962 .37395 Mdot
.962 .37471 Mdot
.962 .37666 Mdot
.962 .37677 Mdot
.962 .37724 Mdot
.962 .37728 Mdot
.962 .37729 Mdot
.962 .37822 Mdot
.962 .37823 Mdot
.962 .37854 Mdot
.962 .37923 Mdot
.962 .38233 Mdot
.962 .38328 Mdot
.962 .38462 Mdot
.962 .38464 Mdot
.962 .3849 Mdot
.962 .38637 Mdot
.962 .38664 Mdot
.962 .38799 Mdot
.962 .38807 Mdot
.962 .38926 Mdot
.962 .38948 Mdot
.962 .39007 Mdot
.962 .39117 Mdot
.962 .39218 Mdot
.962 .3944 Mdot
.962 .39617 Mdot
.962 .39698 Mdot
.962 .39942 Mdot
.962 .40137 Mdot
.962 .40174 Mdot
.962 .40201 Mdot
.962 .40208 Mdot
.962 .40236 Mdot
.962 .40382 Mdot
.962 .40385 Mdot
.962 .40401 Mdot
.962 .40512 Mdot
.962 .40628 Mdot
.962 .4065 Mdot
.962 .40706 Mdot
.962 .40734 Mdot
.962 .4076 Mdot
.962 .40809 Mdot
.962 .4089 Mdot
.962 .40941 Mdot
.962 .40947 Mdot
.962 .40949 Mdot
.962 .40979 Mdot
.962 .41122 Mdot
.962 .41168 Mdot
.962 .41527 Mdot
.962 .41575 Mdot
.962 .41718 Mdot
.962 .41721 Mdot
.962 .41804 Mdot
.962 .41849 Mdot
.962 .42059 Mdot
.962 .42166 Mdot
.962 .4232 Mdot
.962 .42361 Mdot
.962 .42457 Mdot
.962 .42577 Mdot
.962 .42657 Mdot
.962 .42658 Mdot
.962 .4268 Mdot
.962 .42688 Mdot
.962 .4278 Mdot
.962 .42836 Mdot
.962 .42968 Mdot
.962 .43197 Mdot
.962 .43444 Mdot
.962 .43497 Mdot
.962 .43634 Mdot
.962 .43745 Mdot
.962 .43783 Mdot
.962 .43817 Mdot
.962 .43847 Mdot
.962 .43867 Mdot
.962 .43898 Mdot
.962 .44078 Mdot
.962 .44159 Mdot
.962 .44167 Mdot
.962 .44226 Mdot
.962 .44246 Mdot
.962 .44248 Mdot
.962 .44331 Mdot
.962 .44335 Mdot
.962 .44376 Mdot
.962 .44481 Mdot
.962 .44491 Mdot
.962 .44506 Mdot
.962 .44597 Mdot
.962 .44665 Mdot
.962 .45015 Mdot
.962 .45075 Mdot
.962 .45114 Mdot
.962 .45171 Mdot
.962 .45237 Mdot
.962 .4531 Mdot
.962 .45481 Mdot
.962 .45521 Mdot
.962 .45779 Mdot
.962 .4588 Mdot
.962 .45881 Mdot
.962 .45908 Mdot
.962 .4634 Mdot
.962 .46757 Mdot
.962 .46845 Mdot
.962 .46908 Mdot
.962 .46995 Mdot
.962 .46996 Mdot
.962 .47055 Mdot
.962 .47096 Mdot
.962 .47261 Mdot
.962 .47274 Mdot
.962 .47314 Mdot
.962 .47315 Mdot
.962 .47316 Mdot
.962 .47337 Mdot
.962 .47341 Mdot
.962 .47458 Mdot
.962 .47667 Mdot
.962 .47738 Mdot
.962 .47835 Mdot
.962 .47849 Mdot
.962 .4785 Mdot
.962 .47906 Mdot
.962 .48019 Mdot
.962 .48172 Mdot
.962 .48354 Mdot
.962 .48392 Mdot
.962 .48582 Mdot
.962 .48706 Mdot
.962 .48781 Mdot
.962 .48797 Mdot
.962 .48828 Mdot
.962 .48874 Mdot
.962 .48918 Mdot
.962 .48923 Mdot
.962 .49153 Mdot
.962 .49157 Mdot
.962 .49236 Mdot
.962 .4981 Mdot
.962 .49882 Mdot
.962 .50013 Mdot
.962 .50105 Mdot
.962 .50151 Mdot
.962 .50153 Mdot
.962 .50164 Mdot
.962 .50242 Mdot
.962 .50367 Mdot
.962 .50441 Mdot
.962 .5048 Mdot
.962 .50493 Mdot
.962 .50522 Mdot
.962 .50563 Mdot
.962 .50607 Mdot
.962 .50639 Mdot
.962 .50673 Mdot
.962 .50813 Mdot
.962 .50865 Mdot
.962 .50976 Mdot
.962 .50996 Mdot
.962 .50999 Mdot
.962 .51004 Mdot
.962 .51006 Mdot
.962 .51012 Mdot
.962 .51015 Mdot
.962 .51017 Mdot
.962 .51026 Mdot
.962 .51036 Mdot
.962 .51044 Mdot
.962 .51089 Mdot
.962 .51141 Mdot
.962 .51153 Mdot
.962 .51165 Mdot
.962 .51217 Mdot
.962 .51227 Mdot
.962 .51254 Mdot
.962 .51257 Mdot
.962 .51268 Mdot
.962 .51288 Mdot
.962 .51291 Mdot
.962 .51304 Mdot
.962 .51305 Mdot
.962 .51349 Mdot
.962 .51357 Mdot
.962 .51359 Mdot
.962 .51416 Mdot
.962 .51423 Mdot
.962 .51464 Mdot
.962 .51486 Mdot
.962 .51514 Mdot
.962 .51619 Mdot
.962 .51635 Mdot
.962 .51784 Mdot
.962 .51843 Mdot
.962 .51864 Mdot
.962 .51956 Mdot
.962 .51969 Mdot
.962 .51973 Mdot
.962 .51987 Mdot
.962 .52007 Mdot
.962 .5203 Mdot
.962 .52074 Mdot
.962 .52083 Mdot
.962 .52102 Mdot
.962 .52114 Mdot
.962 .52146 Mdot
.962 .52182 Mdot
.962 .52218 Mdot
.962 .52231 Mdot
.962 .52289 Mdot
.962 .52321 Mdot
.962 .52409 Mdot
.962 .52411 Mdot
.962 .52455 Mdot
.962 .52612 Mdot
.962 .52666 Mdot
.962 .52723 Mdot
.962 .52743 Mdot
.962 .52762 Mdot
.962 .52861 Mdot
.962 .52869 Mdot
.962 .52883 Mdot
.962 .52909 Mdot
.962 .52927 Mdot
.962 .52957 Mdot
.962 .52979 Mdot
.962 .52985 Mdot
.962 .53072 Mdot
.962 .53091 Mdot
.962 .53133 Mdot
.962 .53144 Mdot
.962 .5323 Mdot
.962 .53277 Mdot
.962 .53281 Mdot
.962 .533 Mdot
.962 .53308 Mdot
.962 .53341 Mdot
.962 .53373 Mdot
.962 .53475 Mdot
.962 .53518 Mdot
.962 .53533 Mdot
.962 .53548 Mdot
.962 .53551 Mdot
.962 .53621 Mdot
.962 .53667 Mdot
.962 .53692 Mdot
.962 .53709 Mdot
.962 .53819 Mdot
.962 .54009 Mdot
.962 .54068 Mdot
.962 .54078 Mdot
.962 .54084 Mdot
.962 .5413 Mdot
.962 .54169 Mdot
.962 .54245 Mdot
.962 .5428 Mdot
.962 .5428 Mdot
.962 .54302 Mdot
.962 .54381 Mdot
.962 .54382 Mdot
.962 .54386 Mdot
.962 .54437 Mdot
.962 .54448 Mdot
.962 .54465 Mdot
.962 .54477 Mdot
.962 .54654 Mdot
.962 .54659 Mdot
.962 .54732 Mdot
.962 .54891 Mdot
.962 .54911 Mdot
.962 .54952 Mdot
.962 .54952 Mdot
.962 .54956 Mdot
.962 .55012 Mdot
.962 .55032 Mdot
.962 .55039 Mdot
.962 .5509 Mdot
.962 .55132 Mdot
.962 .5517 Mdot
.962 .55192 Mdot
.962 .55217 Mdot
.962 .55218 Mdot
.962 .55222 Mdot
.962 .55271 Mdot
.962 .5532 Mdot
.962 .55354 Mdot
.962 .55375 Mdot
.962 .55398 Mdot
.962 .55406 Mdot
.962 .55471 Mdot
.962 .55493 Mdot
.962 .55499 Mdot
.962 .5552 Mdot
.962 .55528 Mdot
.962 .55532 Mdot
.962 .55536 Mdot
.962 .55545 Mdot
.962 .55549 Mdot
.962 .55567 Mdot
.962 .55584 Mdot
.962 .55587 Mdot
.962 .55587 Mdot
.962 .5561 Mdot
.962 .55614 Mdot
.962 .55615 Mdot
.962 .55619 Mdot
.962 .55625 Mdot
.962 .55693 Mdot
.962 .55705 Mdot
.962 .55732 Mdot
.962 .55766 Mdot
.962 .55781 Mdot
.962 .55806 Mdot
.962 .5581 Mdot
.962 .55829 Mdot
.962 .55853 Mdot
.962 .55875 Mdot
.962 .55959 Mdot
.962 .55974 Mdot
.962 .56025 Mdot
.962 .56068 Mdot
.962 .56094 Mdot
.962 .561 Mdot
.962 .56107 Mdot
.962 .56136 Mdot
.962 .56157 Mdot
.962 .5625 Mdot
.962 .5631 Mdot
.962 .56319 Mdot
.962 .56329 Mdot
.962 .5637 Mdot
.962 .56419 Mdot
.962 .56433 Mdot
.962 .56464 Mdot
.962 .56488 Mdot
.962 .56515 Mdot
.962 .56516 Mdot
.962 .5654 Mdot
.962 .56572 Mdot
.962 .56572 Mdot
.962 .56598 Mdot
.962 .56635 Mdot
.962 .56652 Mdot
.962 .56679 Mdot
.962 .56721 Mdot
.962 .56764 Mdot
.962 .56774 Mdot
.962 .56786 Mdot
.962 .56793 Mdot
.962 .56854 Mdot
.962 .56898 Mdot
.962 .56909 Mdot
.962 .56935 Mdot
.962 .56942 Mdot
.962 .56967 Mdot
.962 .56994 Mdot
.962 .57005 Mdot
.962 .57006 Mdot
.962 .57013 Mdot
.962 .57031 Mdot
.962 .57048 Mdot
.962 .57056 Mdot
.962 .57064 Mdot
.962 .5711 Mdot
.962 .57113 Mdot
.962 .57121 Mdot
.962 .57131 Mdot
.962 .57205 Mdot
.962 .57207 Mdot
.962 .57213 Mdot
.962 .57218 Mdot
.962 .57219 Mdot
.962 .57227 Mdot
.962 .57235 Mdot
.962 .57235 Mdot
.962 .57275 Mdot
.962 .5728 Mdot
.962 .57282 Mdot
.962 .57286 Mdot
.962 .57292 Mdot
.962 .57293 Mdot
.962 .57296 Mdot
.962 .57299 Mdot
.962 .57304 Mdot
.962 .5733 Mdot
.962 .57331 Mdot
.962 .57331 Mdot
.962 .57333 Mdot
.962 .57345 Mdot
.962 .57349 Mdot
.962 .57384 Mdot
.962 .57385 Mdot
.962 .57391 Mdot
.962 .57396 Mdot
.962 .57399 Mdot
.962 .57416 Mdot
.962 .57418 Mdot
.962 .57427 Mdot
.962 .5744 Mdot
.962 .57442 Mdot
.962 .5746 Mdot
.962 .57465 Mdot
.962 .57475 Mdot
.962 .57479 Mdot
.962 .57485 Mdot
.962 .57489 Mdot
.962 .57504 Mdot
.962 .57523 Mdot
.962 .57524 Mdot
.962 .57549 Mdot
.962 .57598 Mdot
.962 .57601 Mdot
.962 .57607 Mdot
.962 .57617 Mdot
.962 .57627 Mdot
.962 .57629 Mdot
.962 .57632 Mdot
.962 .57632 Mdot
.962 .57635 Mdot
.962 .57637 Mdot
.962 .57638 Mdot
.962 .5764 Mdot
.962 .57641 Mdot
.962 .57645 Mdot
.962 .57648 Mdot
.962 .57657 Mdot
.962 .57667 Mdot
.962 .5768 Mdot
.962 .57684 Mdot
.962 .57697 Mdot
.962 .57706 Mdot
.962 .57714 Mdot
.962 .57714 Mdot
.962 .57721 Mdot
.962 .57749 Mdot
.962 .5777 Mdot
.962 .57813 Mdot
.962 .57814 Mdot
.962 .57895 Mdot
.962 .579 Mdot
.962 .57914 Mdot
.962 .57916 Mdot
.962 .57929 Mdot
.962 .57935 Mdot
.962 .57936 Mdot
.962 .57954 Mdot
.962 .57973 Mdot
.962 .57977 Mdot
.962 .57988 Mdot
.962 .57997 Mdot
.962 .58005 Mdot
.962 .58007 Mdot
.962 .58011 Mdot
.962 .58013 Mdot
.962 .58016 Mdot
.962 .58017 Mdot
.962 .58027 Mdot
.962 .58032 Mdot
.962 .58046 Mdot
.962 .58055 Mdot
.962 .58057 Mdot
.962 .58062 Mdot
.962 .58068 Mdot
.962 .58068 Mdot
.962 .58072 Mdot
.962 .58074 Mdot
.962 .58076 Mdot
.962 .58086 Mdot
.962 .5809 Mdot
.962 .58093 Mdot
.962 .58094 Mdot
.962 .58095 Mdot
.962 .58096 Mdot
.962 .58096 Mdot
.962 .58096 Mdot
.962 .58096 Mdot
.962 .58097 Mdot
.962 .58097 Mdot
.964 .07875 Mdot
.964 .07875 Mdot
.964 .07876 Mdot
.964 .07876 Mdot
.964 .07876 Mdot
.964 .07877 Mdot
.964 .07879 Mdot
.964 .07882 Mdot
.964 .07882 Mdot
.964 .07883 Mdot
.964 .07887 Mdot
.964 .07887 Mdot
.964 .07889 Mdot
.964 .0789 Mdot
.964 .07891 Mdot
.964 .07903 Mdot
.964 .07903 Mdot
.964 .07911 Mdot
.964 .07913 Mdot
.964 .07914 Mdot
.964 .07917 Mdot
.964 .07917 Mdot
.964 .07959 Mdot
.964 .07959 Mdot
.964 .07971 Mdot
.964 .07977 Mdot
.964 .0798 Mdot
.964 .07989 Mdot
.964 .07993 Mdot
.964 .07994 Mdot
.964 .07995 Mdot
.964 .08003 Mdot
.964 .08007 Mdot
.964 .08009 Mdot
.964 .0801 Mdot
.964 .08034 Mdot
.964 .08034 Mdot
.964 .08049 Mdot
.964 .08059 Mdot
.964 .08095 Mdot
.964 .08103 Mdot
.964 .08108 Mdot
.964 .08108 Mdot
.964 .08116 Mdot
.964 .08118 Mdot
.964 .08121 Mdot
.964 .08143 Mdot
.964 .08144 Mdot
.964 .08145 Mdot
.964 .08167 Mdot
.964 .08179 Mdot
.964 .08185 Mdot
.964 .08186 Mdot
.964 .08186 Mdot
.964 .08188 Mdot
.964 .08188 Mdot
.964 .08192 Mdot
.964 .08291 Mdot
.964 .08342 Mdot
.964 .08357 Mdot
.964 .08373 Mdot
.964 .08406 Mdot
.964 .0842 Mdot
.964 .08448 Mdot
.964 .08449 Mdot
.964 .08458 Mdot
.964 .08458 Mdot
.964 .08463 Mdot
.964 .08515 Mdot
.964 .08524 Mdot
.964 .08537 Mdot
.964 .08553 Mdot
.964 .08557 Mdot
.964 .08654 Mdot
.964 .08695 Mdot
.964 .08726 Mdot
.964 .08778 Mdot
.964 .08791 Mdot
.964 .088 Mdot
.964 .08802 Mdot
.964 .08823 Mdot
.964 .09041 Mdot
.964 .09053 Mdot
.964 .09089 Mdot
.964 .09174 Mdot
.964 .09177 Mdot
.964 .09187 Mdot
.964 .09214 Mdot
.964 .09272 Mdot
.964 .09275 Mdot
.964 .09275 Mdot
.964 .09285 Mdot
.964 .09301 Mdot
.964 .09305 Mdot
.964 .09354 Mdot
.964 .09357 Mdot
.964 .09363 Mdot
.964 .09468 Mdot
.964 .09516 Mdot
.964 .09649 Mdot
.964 .09686 Mdot
.964 .09744 Mdot
.964 .09758 Mdot
.964 .09934 Mdot
.964 .10298 Mdot
.964 .10371 Mdot
.964 .10383 Mdot
.964 .1041 Mdot
.964 .10633 Mdot
.964 .10749 Mdot
.964 .10806 Mdot
.964 .10807 Mdot
.964 .10836 Mdot
.964 .10943 Mdot
.964 .10974 Mdot
.964 .1114 Mdot
.964 .11463 Mdot
.964 .11463 Mdot
.964 .11558 Mdot
.964 .11684 Mdot
.964 .11931 Mdot
.964 .11977 Mdot
.964 .12133 Mdot
.964 .12292 Mdot
.964 .12293 Mdot
.964 .12295 Mdot
.964 .12407 Mdot
.964 .12659 Mdot
.964 .12695 Mdot
.964 .12959 Mdot
.964 .13073 Mdot
.964 .13105 Mdot
.964 .13415 Mdot
.964 .13778 Mdot
.964 .13998 Mdot
.964 .14041 Mdot
.964 .14079 Mdot
.964 .14116 Mdot
.964 .1412 Mdot
.964 .14218 Mdot
.964 .14313 Mdot
.964 .14391 Mdot
.964 .14467 Mdot
.964 .14498 Mdot
.964 .14502 Mdot
.964 .14625 Mdot
.964 .14708 Mdot
.964 .14736 Mdot
.964 .14739 Mdot
.964 .14892 Mdot
.964 .14963 Mdot
.964 .1497 Mdot
.964 .15035 Mdot
.964 .15395 Mdot
.964 .15454 Mdot
.964 .15607 Mdot
.964 .15629 Mdot
.964 .15741 Mdot
.964 .15923 Mdot
.964 .16012 Mdot
.964 .16178 Mdot
.964 .16259 Mdot
.964 .16288 Mdot
.964 .16324 Mdot
.964 .16505 Mdot
.964 .16533 Mdot
.964 .16576 Mdot
.964 .16675 Mdot
.964 .1698 Mdot
.964 .17084 Mdot
.964 .17103 Mdot
.964 .17149 Mdot
.964 .17177 Mdot
.964 .17192 Mdot
.964 .1746 Mdot
.964 .17567 Mdot
.964 .17573 Mdot
.964 .17607 Mdot
.964 .17735 Mdot
.964 .17815 Mdot
.964 .1782 Mdot
.964 .17831 Mdot
.964 .17841 Mdot
.964 .17846 Mdot
.964 .17922 Mdot
.964 .17949 Mdot
.964 .18034 Mdot
.964 .18168 Mdot
.964 .18327 Mdot
.964 .18392 Mdot
.964 .18557 Mdot
.964 .18639 Mdot
.964 .18668 Mdot
.964 .18945 Mdot
.964 .18972 Mdot
.964 .19169 Mdot
.964 .19196 Mdot
.964 .194 Mdot
.964 .19405 Mdot
.964 .19725 Mdot
.964 .19828 Mdot
.964 .19984 Mdot
.964 .20107 Mdot
.964 .20423 Mdot
.964 .2049 Mdot
.964 .20491 Mdot
.964 .20491 Mdot
.964 .20491 Mdot
.964 .20492 Mdot
.964 .20495 Mdot
.964 .205 Mdot
.964 .2051 Mdot
.964 .2051 Mdot
.964 .20511 Mdot
.964 .20523 Mdot
.964 .20525 Mdot
.964 .20528 Mdot
.964 .20531 Mdot
.964 .20535 Mdot
.964 .2057 Mdot
.964 .2057 Mdot
.964 .20591 Mdot
.964 .20597 Mdot
.964 .20601 Mdot
.964 .20608 Mdot
.964 .2061 Mdot
.964 .20671 Mdot
.964 .20728 Mdot
.964 .20728 Mdot
.964 .20741 Mdot
.964 .20761 Mdot
.964 .20765 Mdot
.964 .2078 Mdot
.964 .20789 Mdot
.964 .20813 Mdot
.964 .20825 Mdot
.964 .20828 Mdot
.964 .2083 Mdot
.964 .20854 Mdot
.964 .20864 Mdot
.964 .20872 Mdot
.964 .20873 Mdot
.964 .20943 Mdot
.964 .20943 Mdot
.964 .20953 Mdot
.964 .2098 Mdot
.964 .20986 Mdot
.964 .21013 Mdot
.964 .21116 Mdot
.964 .21139 Mdot
.964 .21144 Mdot
.964 .21153 Mdot
.964 .21153 Mdot
.964 .21175 Mdot
.964 .21182 Mdot
.964 .21187 Mdot
.964 .21188 Mdot
.964 .21252 Mdot
.964 .21256 Mdot
.964 .21258 Mdot
.964 .21319 Mdot
.964 .21353 Mdot
.964 .21359 Mdot
.964 .21372 Mdot
.964 .21373 Mdot
.964 .21375 Mdot
.964 .21378 Mdot
.964 .21379 Mdot
.964 .21392 Mdot
.964 .21671 Mdot
.964 .21817 Mdot
.964 .21838 Mdot
.964 .21858 Mdot
.964 .21859 Mdot
.964 .21904 Mdot
.964 .21909 Mdot
.964 .21995 Mdot
.964 .22037 Mdot
.964 .22062 Mdot
.964 .2207 Mdot
.964 .22075 Mdot
.964 .22075 Mdot
.964 .22116 Mdot
.964 .22117 Mdot
.964 .22142 Mdot
.964 .22144 Mdot
.964 .22158 Mdot
.964 .22166 Mdot
.964 .22173 Mdot
.964 .22289 Mdot
.964 .22303 Mdot
.964 .22328 Mdot
.964 .22366 Mdot
.964 .22376 Mdot
.964 .22412 Mdot
.964 .22422 Mdot
.964 .22637 Mdot
.964 .22695 Mdot
.964 .22738 Mdot
.964 .22792 Mdot
.964 .22798 Mdot
.964 .22811 Mdot
.964 .22898 Mdot
.964 .22944 Mdot
.964 .23044 Mdot
.964 .23079 Mdot
.964 .23105 Mdot
.964 .23107 Mdot
.964 .23109 Mdot
.964 .23154 Mdot
.964 .23168 Mdot
.964 .23174 Mdot
.964 .23315 Mdot
.964 .23366 Mdot
.964 .2352 Mdot
.964 .23595 Mdot
.964 .2373 Mdot
.964 .23778 Mdot
.964 .2381 Mdot
.964 .2391 Mdot
.964 .23912 Mdot
.964 .24048 Mdot
.964 .24146 Mdot
.964 .24156 Mdot
.964 .24182 Mdot
.964 .24257 Mdot
.964 .24419 Mdot
.964 .24426 Mdot
.964 .24428 Mdot
.964 .24455 Mdot
.964 .24498 Mdot
.964 .24509 Mdot
.964 .24511 Mdot
.964 .24548 Mdot
.964 .24645 Mdot
.964 .24655 Mdot
.964 .24671 Mdot
.964 .24677 Mdot
.964 .24714 Mdot
.964 .24856 Mdot
.964 .24947 Mdot
.964 .2496 Mdot
.964 .25 Mdot
.964 .25093 Mdot
.964 .25203 Mdot
.964 .2543 Mdot
.964 .25456 Mdot
.964 .25458 Mdot
.964 .25486 Mdot
.964 .25547 Mdot
.964 .25548 Mdot
.964 .25559 Mdot
.964 .25642 Mdot
.964 .25643 Mdot
.964 .25656 Mdot
.964 .25719 Mdot
.964 .25758 Mdot
.964 .25798 Mdot
.964 .258 Mdot
.964 .25816 Mdot
.964 .25849 Mdot
.964 .25942 Mdot
.964 .261 Mdot
.964 .26238 Mdot
.964 .26304 Mdot
.964 .26427 Mdot
.964 .26444 Mdot
.964 .26619 Mdot
.964 .2662 Mdot
.964 .26699 Mdot
.964 .26777 Mdot
.964 .26801 Mdot
.964 .26929 Mdot
.964 .26996 Mdot
.964 .27047 Mdot
.964 .27226 Mdot
.964 .2734 Mdot
.964 .2742 Mdot
.964 .27455 Mdot
.964 .27525 Mdot
.964 .28115 Mdot
.964 .28126 Mdot
.964 .28301 Mdot
.964 .28426 Mdot
.964 .28433 Mdot
.964 .28474 Mdot
.964 .28479 Mdot
.964 .28492 Mdot
.964 .285 Mdot
.964 .28503 Mdot
.964 .28554 Mdot
.964 .28578 Mdot
.964 .28586 Mdot
.964 .28589 Mdot
.964 .28666 Mdot
.964 .28711 Mdot
.964 .28927 Mdot
.964 .28949 Mdot
.964 .28951 Mdot
.964 .28961 Mdot
.964 .28974 Mdot
.964 .29031 Mdot
.964 .29228 Mdot
.964 .29232 Mdot
.964 .29252 Mdot
.964 .29269 Mdot
.964 .2928 Mdot
.964 .29367 Mdot
.964 .29367 Mdot
.964 .29405 Mdot
.964 .29426 Mdot
.964 .29471 Mdot
.964 .29516 Mdot
.964 .29595 Mdot
.964 .29924 Mdot
.964 .30034 Mdot
.964 .30057 Mdot
.964 .30168 Mdot
.964 .30205 Mdot
.964 .30208 Mdot
.964 .30317 Mdot
.964 .30318 Mdot
.964 .30487 Mdot
.964 .30492 Mdot
.964 .30511 Mdot
.964 .30522 Mdot
.964 .30563 Mdot
.964 .30563 Mdot
.964 .30648 Mdot
.964 .3066 Mdot
.964 .30668 Mdot
.964 .30681 Mdot
.964 .3073 Mdot
.964 .30825 Mdot
.964 .30861 Mdot
.964 .30862 Mdot
.964 .30891 Mdot
.964 .30922 Mdot
.964 .30937 Mdot
.964 .31021 Mdot
.964 .31072 Mdot
.964 .31074 Mdot
.964 .31121 Mdot
.964 .31303 Mdot
.964 .31528 Mdot
.964 .3155 Mdot
.964 .3156 Mdot
.964 .31585 Mdot
.964 .31603 Mdot
.964 .31628 Mdot
.964 .31645 Mdot
.964 .31646 Mdot
.964 .31711 Mdot
.964 .31712 Mdot
.964 .31854 Mdot
.964 .31871 Mdot
.964 .31882 Mdot
.964 .31898 Mdot
.964 .31903 Mdot
.964 .31907 Mdot
.964 .31953 Mdot
.964 .31955 Mdot
.964 .31957 Mdot
.964 .31998 Mdot
.964 .3202 Mdot
.964 .32032 Mdot
.964 .32033 Mdot
.964 .32034 Mdot
.964 .32036 Mdot
.964 .32037 Mdot
.964 .32045 Mdot
.964 .32311 Mdot
.964 .32451 Mdot
.964 .32452 Mdot
.964 .32459 Mdot
.964 .32694 Mdot
.964 .32741 Mdot
.964 .33106 Mdot
.964 .33305 Mdot
.964 .33375 Mdot
.964 .33466 Mdot
.964 .33608 Mdot
.964 .33636 Mdot
.964 .33819 Mdot
.964 .34067 Mdot
.964 .34115 Mdot
.964 .34123 Mdot
.964 .3414 Mdot
.964 .34386 Mdot
.964 .34403 Mdot
.964 .34484 Mdot
.964 .34759 Mdot
.964 .35186 Mdot
.964 .35241 Mdot
.964 .35553 Mdot
.964 .35974 Mdot
.964 .36119 Mdot
.964 .36213 Mdot
.964 .36515 Mdot
.964 .36537 Mdot
.964 .36595 Mdot
.964 .36645 Mdot
.964 .36745 Mdot
.964 .36836 Mdot
.964 .36924 Mdot
.964 .36934 Mdot
.964 .36985 Mdot
.964 .37166 Mdot
.964 .37384 Mdot
.964 .37389 Mdot
.964 .37414 Mdot
.964 .37423 Mdot
.964 .37451 Mdot
.964 .37496 Mdot
.964 .3757 Mdot
.964 .37749 Mdot
.964 .37821 Mdot
.964 .37829 Mdot
.964 .38114 Mdot
.964 .38307 Mdot
.964 .38314 Mdot
.964 .3837 Mdot
.964 .38378 Mdot
.964 .38427 Mdot
.964 .387 Mdot
.964 .38729 Mdot
.964 .38787 Mdot
.964 .38891 Mdot
.964 .38906 Mdot
.964 .38949 Mdot
.964 .39053 Mdot
.964 .39132 Mdot
.964 .39219 Mdot
.964 .39257 Mdot
.964 .39572 Mdot
.964 .39664 Mdot
.964 .39693 Mdot
.964 .39865 Mdot
.964 .39995 Mdot
.964 .40028 Mdot
.964 .40046 Mdot
.964 .40059 Mdot
.964 .40335 Mdot
.964 .40382 Mdot
.964 .40541 Mdot
.964 .40628 Mdot
.964 .4071 Mdot
.964 .40939 Mdot
.964 .40973 Mdot
.964 .41026 Mdot
.964 .4109 Mdot
.964 .41219 Mdot
.964 .41476 Mdot
.964 .41577 Mdot
.964 .41625 Mdot
.964 .41706 Mdot
.964 .4175 Mdot
.964 .4181 Mdot
.964 .41828 Mdot
.964 .41887 Mdot
.964 .42169 Mdot
.964 .42271 Mdot
.964 .42328 Mdot
.964 .4242 Mdot
.964 .42514 Mdot
.964 .42617 Mdot
.964 .42619 Mdot
.964 .42626 Mdot
.964 .42927 Mdot
.964 .42948 Mdot
.964 .42987 Mdot
.964 .43031 Mdot
.964 .43052 Mdot
.964 .43062 Mdot
.964 .4316 Mdot
.964 .43253 Mdot
.964 .43256 Mdot
.964 .43373 Mdot
.964 .4347 Mdot
.964 .43507 Mdot
.964 .43602 Mdot
.964 .43658 Mdot
.964 .43688 Mdot
.964 .43883 Mdot
.964 .43993 Mdot
.964 .44018 Mdot
.964 .44041 Mdot
.964 .44227 Mdot
.964 .44439 Mdot
.964 .4445 Mdot
.964 .44462 Mdot
.964 .44517 Mdot
.964 .44769 Mdot
.964 .44828 Mdot
.964 .44873 Mdot
.964 .44921 Mdot
.964 .44925 Mdot
.964 .44935 Mdot
.964 .44957 Mdot
.964 .44976 Mdot
.964 .44986 Mdot
.964 .45134 Mdot
.964 .45135 Mdot
.964 .45185 Mdot
.964 .45349 Mdot
.964 .4551 Mdot
.964 .45567 Mdot
.964 .45605 Mdot
.964 .45674 Mdot
.964 .45853 Mdot
.964 .45907 Mdot
.964 .45923 Mdot
.964 .46028 Mdot
.964 .46105 Mdot
.964 .46323 Mdot
.964 .46329 Mdot
.964 .46337 Mdot
.964 .46487 Mdot
.964 .465 Mdot
.964 .46541 Mdot
.964 .46681 Mdot
.964 .46698 Mdot
.964 .46736 Mdot
.964 .46817 Mdot
.964 .46888 Mdot
.964 .46926 Mdot
.964 .47045 Mdot
.964 .47094 Mdot
.964 .47447 Mdot
.964 .47466 Mdot
.964 .47478 Mdot
.964 .47482 Mdot
.964 .47495 Mdot
.964 .47664 Mdot
.964 .47829 Mdot
.964 .47853 Mdot
.964 .47862 Mdot
.964 .47988 Mdot
.964 .48088 Mdot
.964 .48263 Mdot
.964 .48414 Mdot
.964 .48588 Mdot
.964 .4874 Mdot
.964 .4884 Mdot
.964 .4885 Mdot
.964 .48869 Mdot
.964 .48969 Mdot
.964 .49042 Mdot
.964 .49053 Mdot
.964 .49175 Mdot
.964 .49254 Mdot
.964 .49418 Mdot
.964 .49568 Mdot
.964 .49676 Mdot
.964 .49676 Mdot
.964 .49677 Mdot
.964 .49678 Mdot
.964 .49678 Mdot
.964 .49683 Mdot
.964 .49691 Mdot
.964 .49708 Mdot
.964 .49708 Mdot
.964 .49709 Mdot
.964 .49729 Mdot
.964 .49731 Mdot
.964 .49737 Mdot
.964 .49741 Mdot
.964 .49748 Mdot
.964 .49803 Mdot
.964 .49804 Mdot
.964 .49829 Mdot
.964 .49836 Mdot
.964 .49846 Mdot
.964 .49853 Mdot
.964 .49863 Mdot
.964 .49866 Mdot
.964 .49962 Mdot
.964 .50033 Mdot
.964 .50051 Mdot
.964 .50052 Mdot
.964 .50072 Mdot
.964 .50104 Mdot
.964 .5011 Mdot
.964 .50133 Mdot
.964 .50134 Mdot
.964 .50148 Mdot
.964 .50184 Mdot
.964 .50203 Mdot
.964 .50208 Mdot
.964 .50211 Mdot
.964 .50216 Mdot
.964 .50248 Mdot
.964 .50264 Mdot
.964 .50268 Mdot
.964 .50276 Mdot
.964 .50277 Mdot
.964 .50385 Mdot
.964 .50386 Mdot
.964 .504 Mdot
.964 .50442 Mdot
.964 .50451 Mdot
.964 .50493 Mdot
.964 .50618 Mdot
.964 .50648 Mdot
.964 .50683 Mdot
.964 .5069 Mdot
.964 .50705 Mdot
.964 .50705 Mdot
.964 .50738 Mdot
.964 .50742 Mdot
.964 .50748 Mdot
.964 .50756 Mdot
.964 .50758 Mdot
.964 .50854 Mdot
.964 .50859 Mdot
.964 .50862 Mdot
.964 .50871 Mdot
.964 .50953 Mdot
.964 .51003 Mdot
.964 .51012 Mdot
.964 .51031 Mdot
.964 .51032 Mdot
.964 .51035 Mdot
.964 .5104 Mdot
.964 .51042 Mdot
.964 .5106 Mdot
.964 .51107 Mdot
.964 .51176 Mdot
.964 .51465 Mdot
.964 .51574 Mdot
.964 .51592 Mdot
.964 .51617 Mdot
.964 .51665 Mdot
.964 .51673 Mdot
.964 .51702 Mdot
.964 .51731 Mdot
.964 .51732 Mdot
.964 .51796 Mdot
.964 .51802 Mdot
.964 .51847 Mdot
.964 .51922 Mdot
.964 .5198 Mdot
.964 .52014 Mdot
.964 .52026 Mdot
.964 .52032 Mdot
.964 .52033 Mdot
.964 .52085 Mdot
.964 .52089 Mdot
.964 .5209 Mdot
.964 .52124 Mdot
.964 .52125 Mdot
.964 .52127 Mdot
.964 .52147 Mdot
.964 .52158 Mdot
.964 .52167 Mdot
.964 .5225 Mdot
.964 .52324 Mdot
.964 .52343 Mdot
.964 .52376 Mdot
.964 .52427 Mdot
.964 .5244 Mdot
.964 .52487 Mdot
.964 .52501 Mdot
.964 .52667 Mdot
.964 .52717 Mdot
.964 .52782 Mdot
.964 .5283 Mdot
.964 .52857 Mdot
.964 .52912 Mdot
.964 .52931 Mdot
.964 .52981 Mdot
.964 .52988 Mdot
.964 .53005 Mdot
.964 .53063 Mdot
.964 .53115 Mdot
.964 .53117 Mdot
.964 .53136 Mdot
.964 .53173 Mdot
.964 .53265 Mdot
.964 .53296 Mdot
.964 .53337 Mdot
.964 .5334 Mdot
.964 .53372 Mdot
.964 .53372 Mdot
.964 .53374 Mdot
.964 .53377 Mdot
.964 .53431 Mdot
.964 .53449 Mdot
.964 .53456 Mdot
.964 .53625 Mdot
.964 .53686 Mdot
.964 .53701 Mdot
.964 .53758 Mdot
.964 .53768 Mdot
.964 .53834 Mdot
.964 .53843 Mdot
.964 .53867 Mdot
.964 .53954 Mdot
.964 .54065 Mdot
.964 .54107 Mdot
.964 .54162 Mdot
.964 .54198 Mdot
.964 .54309 Mdot
.964 .54311 Mdot
.964 .54382 Mdot
.964 .54392 Mdot
.964 .5446 Mdot
.964 .54469 Mdot
.964 .54565 Mdot
.964 .54575 Mdot
.964 .54604 Mdot
.964 .54661 Mdot
.964 .54683 Mdot
.964 .54738 Mdot
.964 .54785 Mdot
.964 .54814 Mdot
.964 .54823 Mdot
.964 .54849 Mdot
.964 .54851 Mdot
.964 .54855 Mdot
.964 .54858 Mdot
.964 .5486 Mdot
.964 .54888 Mdot
.964 .54932 Mdot
.964 .54944 Mdot
.964 .54946 Mdot
.964 .54982 Mdot
.964 .55075 Mdot
.964 .5508 Mdot
.964 .55089 Mdot
.964 .55105 Mdot
.964 .55112 Mdot
.964 .55148 Mdot
.964 .55252 Mdot
.964 .55286 Mdot
.964 .55301 Mdot
.964 .5531 Mdot
.964 .55372 Mdot
.964 .55385 Mdot
.964 .55394 Mdot
.964 .55422 Mdot
.964 .55479 Mdot
.964 .55509 Mdot
.964 .55572 Mdot
.964 .5561 Mdot
.964 .55617 Mdot
.964 .55669 Mdot
.964 .55689 Mdot
.964 .55812 Mdot
.964 .55834 Mdot
.964 .55836 Mdot
.964 .5586 Mdot
.964 .55912 Mdot
.964 .55914 Mdot
.964 .55923 Mdot
.964 .55951 Mdot
.964 .55993 Mdot
.964 .55994 Mdot
.964 .56005 Mdot
.964 .56031 Mdot
.964 .56057 Mdot
.964 .56089 Mdot
.964 .56122 Mdot
.964 .56124 Mdot
.964 .56136 Mdot
.964 .56149 Mdot
.964 .56164 Mdot
.964 .56238 Mdot
.964 .56361 Mdot
.964 .56465 Mdot
.964 .56476 Mdot
.964 .56515 Mdot
.964 .56604 Mdot
.964 .56616 Mdot
.964 .56701 Mdot
.964 .56738 Mdot
.964 .56739 Mdot
.964 .56739 Mdot
.964 .56793 Mdot
.964 .56845 Mdot
.964 .56861 Mdot
.964 .56944 Mdot
.964 .56986 Mdot
.964 .57018 Mdot
.964 .57018 Mdot
.964 .57126 Mdot
.964 .57182 Mdot
.964 .57192 Mdot
.964 .57228 Mdot
.964 .57238 Mdot
.964 .57238 Mdot
.964 .57257 Mdot
.964 .57296 Mdot
.964 .57371 Mdot
.964 .57379 Mdot
.964 .57384 Mdot
.964 .57408 Mdot
.964 .5753 Mdot
.964 .57588 Mdot
.964 .57593 Mdot
.964 .57612 Mdot
.964 .57625 Mdot
.964 .57669 Mdot
.964 .57685 Mdot
.964 .5772 Mdot
.964 .57722 Mdot
.964 .57723 Mdot
.964 .57739 Mdot
.964 .57741 Mdot
.964 .57746 Mdot
.964 .57749 Mdot
.964 .5775 Mdot
.964 .5775 Mdot
.964 .5777 Mdot
.964 .57779 Mdot
.964 .57782 Mdot
.964 .57783 Mdot
.964 .57811 Mdot
.964 .57823 Mdot
.964 .57827 Mdot
.964 .579 Mdot
.964 .57907 Mdot
.964 .57908 Mdot
.964 .57911 Mdot
.964 .57915 Mdot
.964 .57932 Mdot
.964 .57943 Mdot
.964 .57956 Mdot
.964 .57989 Mdot
.964 .5799 Mdot
.964 .57995 Mdot
.964 .58 Mdot
.964 .58003 Mdot
.964 .5802 Mdot
.964 .58021 Mdot
.964 .58022 Mdot
.964 .58025 Mdot
.964 .58025 Mdot
.964 .58034 Mdot
.964 .58039 Mdot
.964 .5805 Mdot
.964 .58055 Mdot
.964 .5806 Mdot
.964 .58077 Mdot
.964 .5811 Mdot
.964 .58111 Mdot
.964 .58111 Mdot
.964 .58112 Mdot
.964 .58112 Mdot
.964 .58112 Mdot
.964 .58114 Mdot
.964 .58118 Mdot
.964 .58125 Mdot
.964 .58126 Mdot
.964 .58126 Mdot
.964 .58134 Mdot
.964 .58134 Mdot
.964 .58135 Mdot
.964 .58138 Mdot
.964 .58138 Mdot
.964 .5814 Mdot
.964 .58142 Mdot
.964 .58154 Mdot
.964 .58157 Mdot
.964 .58162 Mdot
.964 .58162 Mdot
.964 .58171 Mdot
.964 .58171 Mdot
.964 .58172 Mdot
.964 .58173 Mdot
.964 .58176 Mdot
.964 .58176 Mdot
.964 .58176 Mdot
.964 .58178 Mdot
.964 .5818 Mdot
.964 .58181 Mdot
.964 .58184 Mdot
.964 .58187 Mdot
.964 .58188 Mdot
.964 .58201 Mdot
.964 .58202 Mdot
.964 .58202 Mdot
.964 .58203 Mdot
.964 .58203 Mdot
.964 .58206 Mdot
.964 .58206 Mdot
.964 .5821 Mdot
.964 .5821 Mdot
.964 .58211 Mdot
.964 .58211 Mdot
.964 .58211 Mdot
.964 .58213 Mdot
.964 .58213 Mdot
.964 .58213 Mdot
.964 .58214 Mdot
.964 .58215 Mdot
.964 .58215 Mdot
.964 .58215 Mdot
.964 .58215 Mdot
.964 .58215 Mdot
.964 .58215 Mdot
.966 .07534 Mdot
.966 .07534 Mdot
.966 .07534 Mdot
.966 .07536 Mdot
.966 .07542 Mdot
.966 .07543 Mdot
.966 .07544 Mdot
.966 .07551 Mdot
.966 .07553 Mdot
.966 .07554 Mdot
.966 .07554 Mdot
.966 .07558 Mdot
.966 .07559 Mdot
.966 .07562 Mdot
.966 .07569 Mdot
.966 .07572 Mdot
.966 .07572 Mdot
.966 .07574 Mdot
.966 .07581 Mdot
.966 .07581 Mdot
.966 .07581 Mdot
.966 .07583 Mdot
.966 .07597 Mdot
.966 .07597 Mdot
.966 .07603 Mdot
.966 .07606 Mdot
.966 .07613 Mdot
.966 .07615 Mdot
.966 .07617 Mdot
.966 .07635 Mdot
.966 .07636 Mdot
.966 .07654 Mdot
.966 .07674 Mdot
.966 .07675 Mdot
.966 .07681 Mdot
.966 .07682 Mdot
.966 .07683 Mdot
.966 .07719 Mdot
.966 .07744 Mdot
.966 .07746 Mdot
.966 .07761 Mdot
.966 .07814 Mdot
.966 .07838 Mdot
.966 .0784 Mdot
.966 .07847 Mdot
.966 .07877 Mdot
.966 .07882 Mdot
.966 .07897 Mdot
.966 .07907 Mdot
.966 .07908 Mdot
.966 .07915 Mdot
.966 .07934 Mdot
.966 .07943 Mdot
.966 .07967 Mdot
.966 .0797 Mdot
.966 .0798 Mdot
.966 .07986 Mdot
.966 .08022 Mdot
.966 .08053 Mdot
.966 .08082 Mdot
.966 .08088 Mdot
.966 .08111 Mdot
.966 .08169 Mdot
.966 .0822 Mdot
.966 .08227 Mdot
.966 .08227 Mdot
.966 .08307 Mdot
.966 .08336 Mdot
.966 .08401 Mdot
.966 .08418 Mdot
.966 .08452 Mdot
.966 .08454 Mdot
.966 .08465 Mdot
.966 .08494 Mdot
.966 .08526 Mdot
.966 .08623 Mdot
.966 .08639 Mdot
.966 .08689 Mdot
.966 .087 Mdot
.966 .08731 Mdot
.966 .08743 Mdot
.966 .08793 Mdot
.966 .08837 Mdot
.966 .08849 Mdot
.966 .08863 Mdot
.966 .0887 Mdot
.966 .08994 Mdot
.966 .09024 Mdot
.966 .09043 Mdot
.966 .0905 Mdot
.966 .09101 Mdot
.966 .0911 Mdot
.966 .09139 Mdot
.966 .09144 Mdot
.966 .09156 Mdot
.966 .09168 Mdot
.966 .09182 Mdot
.966 .09223 Mdot
.966 .09394 Mdot
.966 .09429 Mdot
.966 .09447 Mdot
.966 .09749 Mdot
.966 .098 Mdot
.966 .09826 Mdot
.966 .09836 Mdot
.966 .09873 Mdot
.966 .09935 Mdot
.966 .0996 Mdot
.966 .09974 Mdot
.966 .09977 Mdot
.966 .10018 Mdot
.966 .10066 Mdot
.966 .10091 Mdot
.966 .10091 Mdot
.966 .10143 Mdot
.966 .10182 Mdot
.966 .10222 Mdot
.966 .10305 Mdot
.966 .10356 Mdot
.966 .10457 Mdot
.966 .10523 Mdot
.966 .10683 Mdot
.966 .1069 Mdot
.966 .10718 Mdot
.966 .1072 Mdot
.966 .10736 Mdot
.966 .10783 Mdot
.966 .10921 Mdot
.966 .10974 Mdot
.966 .11093 Mdot
.966 .11125 Mdot
.966 .1117 Mdot
.966 .11192 Mdot
.966 .11211 Mdot
.966 .11232 Mdot
.966 .11236 Mdot
.966 .11296 Mdot
.966 .11367 Mdot
.966 .11443 Mdot
.966 .11446 Mdot
.966 .11495 Mdot
.966 .11564 Mdot
.966 .11587 Mdot
.966 .11591 Mdot
.966 .11661 Mdot
.966 .11775 Mdot
.966 .11776 Mdot
.966 .11812 Mdot
.966 .11891 Mdot
.966 .11914 Mdot
.966 .11915 Mdot
.966 .11959 Mdot
.966 .11967 Mdot
.966 .11968 Mdot
.966 .12002 Mdot
.966 .1215 Mdot
.966 .12182 Mdot
.966 .12184 Mdot
.966 .12194 Mdot
.966 .12232 Mdot
.966 .12263 Mdot
.966 .12321 Mdot
.966 .12321 Mdot
.966 .12422 Mdot
.966 .12439 Mdot
.966 .1252 Mdot
.966 .12531 Mdot
.966 .12553 Mdot
.966 .12633 Mdot
.966 .12658 Mdot
.966 .12661 Mdot
.966 .1267 Mdot
.966 .12676 Mdot
.966 .12749 Mdot
.966 .12765 Mdot
.966 .12935 Mdot
.966 .12955 Mdot
.966 .12965 Mdot
.966 .12975 Mdot
.966 .13048 Mdot
.966 .13086 Mdot
.966 .13153 Mdot
.966 .13201 Mdot
.966 .13209 Mdot
.966 .1321 Mdot
.966 .1328 Mdot
.966 .13347 Mdot
.966 .13414 Mdot
.966 .13515 Mdot
.966 .13633 Mdot
.966 .13753 Mdot
.966 .13845 Mdot
.966 .13849 Mdot
.966 .1393 Mdot
.966 .14111 Mdot
.966 .14113 Mdot
.966 .14385 Mdot
.966 .14641 Mdot
.966 .14668 Mdot
.966 .14693 Mdot
.966 .14869 Mdot
.966 .15201 Mdot
.966 .15314 Mdot
.966 .15326 Mdot
.966 .15371 Mdot
.966 .15556 Mdot
.966 .15697 Mdot
.966 .15855 Mdot
.966 .16018 Mdot
.966 .16158 Mdot
.966 .16385 Mdot
.966 .16396 Mdot
.966 .16429 Mdot
.966 .16555 Mdot
.966 .16671 Mdot
.966 .17089 Mdot
.966 .17533 Mdot
.966 .17818 Mdot
.966 .18166 Mdot
.966 .18282 Mdot
.966 .18292 Mdot
.966 .18297 Mdot
.966 .18392 Mdot
.966 .18498 Mdot
.966 .18542 Mdot
.966 .18796 Mdot
.966 .18873 Mdot
.966 .19326 Mdot
.966 .19388 Mdot
.966 .19409 Mdot
.966 .19549 Mdot
.966 .19549 Mdot
.966 .1955 Mdot
.966 .19555 Mdot
.966 .19562 Mdot
.966 .19574 Mdot
.966 .19575 Mdot
.966 .19578 Mdot
.966 .19598 Mdot
.966 .19606 Mdot
.966 .19608 Mdot
.966 .19608 Mdot
.966 .19619 Mdot
.966 .19622 Mdot
.966 .19632 Mdot
.966 .19652 Mdot
.966 .1966 Mdot
.966 .19661 Mdot
.966 .19665 Mdot
.966 .19686 Mdot
.966 .19686 Mdot
.966 .19687 Mdot
.966 .19692 Mdot
.966 .19731 Mdot
.966 .19731 Mdot
.966 .19748 Mdot
.966 .19758 Mdot
.966 .19778 Mdot
.966 .19783 Mdot
.966 .19789 Mdot
.966 .19835 Mdot
.966 .19841 Mdot
.966 .19843 Mdot
.966 .19895 Mdot
.966 .19952 Mdot
.966 .19954 Mdot
.966 .19974 Mdot
.966 .19976 Mdot
.966 .1998 Mdot
.966 .20081 Mdot
.966 .20153 Mdot
.966 .20158 Mdot
.966 .20202 Mdot
.966 .20206 Mdot
.966 .20353 Mdot
.966 .20418 Mdot
.966 .20423 Mdot
.966 .20429 Mdot
.966 .20448 Mdot
.966 .20535 Mdot
.966 .20549 Mdot
.966 .2059 Mdot
.966 .2061 Mdot
.966 .20621 Mdot
.966 .20623 Mdot
.966 .20623 Mdot
.966 .20643 Mdot
.966 .20698 Mdot
.966 .20711 Mdot
.966 .20724 Mdot
.966 .20791 Mdot
.966 .20799 Mdot
.966 .20829 Mdot
.966 .20845 Mdot
.966 .20949 Mdot
.966 .20985 Mdot
.966 .21037 Mdot
.966 .21055 Mdot
.966 .2112 Mdot
.966 .21136 Mdot
.966 .21188 Mdot
.966 .21202 Mdot
.966 .21273 Mdot
.966 .21302 Mdot
.966 .21368 Mdot
.966 .21415 Mdot
.966 .21495 Mdot
.966 .21512 Mdot
.966 .21531 Mdot
.966 .21531 Mdot
.966 .21729 Mdot
.966 .21758 Mdot
.966 .21841 Mdot
.966 .21993 Mdot
.966 .22006 Mdot
.966 .22025 Mdot
.966 .22074 Mdot
.966 .22168 Mdot
.966 .22174 Mdot
.966 .22206 Mdot
.966 .22222 Mdot
.966 .22288 Mdot
.966 .22338 Mdot
.966 .22378 Mdot
.966 .22542 Mdot
.966 .22643 Mdot
.966 .22651 Mdot
.966 .22696 Mdot
.966 .22755 Mdot
.966 .22838 Mdot
.966 .22869 Mdot
.966 .22955 Mdot
.966 .22989 Mdot
.966 .2305 Mdot
.966 .2313 Mdot
.966 .23253 Mdot
.966 .23262 Mdot
.966 .23287 Mdot
.966 .23326 Mdot
.966 .23346 Mdot
.966 .23427 Mdot
.966 .23454 Mdot
.966 .23691 Mdot
.966 .23775 Mdot
.966 .23822 Mdot
.966 .23829 Mdot
.966 .23848 Mdot
.966 .2399 Mdot
.966 .24015 Mdot
.966 .24096 Mdot
.966 .2411 Mdot
.966 .24144 Mdot
.966 .24176 Mdot
.966 .24217 Mdot
.966 .24331 Mdot
.966 .24425 Mdot
.966 .24575 Mdot
.966 .24719 Mdot
.966 .2476 Mdot
.966 .24804 Mdot
.966 .249 Mdot
.966 .2495 Mdot
.966 .25009 Mdot
.966 .25066 Mdot
.966 .25187 Mdot
.966 .25208 Mdot
.966 .25566 Mdot
.966 .25675 Mdot
.966 .25749 Mdot
.966 .25783 Mdot
.966 .25784 Mdot
.966 .25822 Mdot
.966 .25872 Mdot
.966 .25922 Mdot
.966 .25994 Mdot
.966 .26022 Mdot
.966 .26123 Mdot
.966 .26164 Mdot
.966 .26292 Mdot
.966 .26361 Mdot
.966 .26398 Mdot
.966 .26406 Mdot
.966 .26453 Mdot
.966 .26453 Mdot
.966 .26518 Mdot
.966 .26649 Mdot
.966 .26717 Mdot
.966 .26718 Mdot
.966 .26775 Mdot
.966 .26859 Mdot
.966 .26886 Mdot
.966 .26964 Mdot
.966 .27072 Mdot
.966 .27166 Mdot
.966 .27281 Mdot
.966 .27297 Mdot
.966 .27434 Mdot
.966 .27526 Mdot
.966 .27659 Mdot
.966 .27659 Mdot
.966 .27706 Mdot
.966 .27733 Mdot
.966 .2776 Mdot
.966 .27801 Mdot
.966 .27885 Mdot
.966 .28113 Mdot
.966 .28301 Mdot
.966 .28313 Mdot
.966 .28332 Mdot
.966 .28408 Mdot
.966 .28414 Mdot
.966 .28455 Mdot
.966 .28561 Mdot
.966 .2858 Mdot
.966 .28676 Mdot
.966 .28886 Mdot
.966 .28949 Mdot
.966 .28961 Mdot
.966 .28999 Mdot
.966 .29017 Mdot
.966 .29089 Mdot
.966 .29226 Mdot
.966 .29289 Mdot
.966 .29404 Mdot
.966 .29488 Mdot
.966 .29551 Mdot
.966 .29607 Mdot
.966 .29622 Mdot
.966 .29666 Mdot
.966 .29717 Mdot
.966 .29771 Mdot
.966 .29783 Mdot
.966 .29832 Mdot
.966 .29938 Mdot
.966 .29975 Mdot
.966 .30125 Mdot
.966 .30326 Mdot
.966 .30332 Mdot
.966 .30394 Mdot
.966 .30395 Mdot
.966 .30461 Mdot
.966 .30462 Mdot
.966 .30462 Mdot
.966 .30561 Mdot
.966 .30582 Mdot
.966 .30615 Mdot
.966 .30639 Mdot
.966 .307 Mdot
.966 .30711 Mdot
.966 .30715 Mdot
.966 .30887 Mdot
.966 .30893 Mdot
.966 .30942 Mdot
.966 .30996 Mdot
.966 .31187 Mdot
.966 .31192 Mdot
.966 .31219 Mdot
.966 .31285 Mdot
.966 .31299 Mdot
.966 .31301 Mdot
.966 .31308 Mdot
.966 .31353 Mdot
.966 .31435 Mdot
.966 .31448 Mdot
.966 .31487 Mdot
.966 .31547 Mdot
.966 .3155 Mdot
.966 .31604 Mdot
.966 .31661 Mdot
.966 .31663 Mdot
.966 .31682 Mdot
.966 .31686 Mdot
.966 .31773 Mdot
.966 .31835 Mdot
.966 .32019 Mdot
.966 .32098 Mdot
.966 .32122 Mdot
.966 .32141 Mdot
.966 .32153 Mdot
.966 .32235 Mdot
.966 .3224 Mdot
.966 .32264 Mdot
.966 .32362 Mdot
.966 .3241 Mdot
.966 .32441 Mdot
.966 .32588 Mdot
.966 .32588 Mdot
.966 .32683 Mdot
.966 .32843 Mdot
.966 .32887 Mdot
.966 .33016 Mdot
.966 .33032 Mdot
.966 .3308 Mdot
.966 .3309 Mdot
.966 .33119 Mdot
.966 .33176 Mdot
.966 .33216 Mdot
.966 .33238 Mdot
.966 .33376 Mdot
.966 .33439 Mdot
.966 .33446 Mdot
.966 .3347 Mdot
.966 .33484 Mdot
.966 .33537 Mdot
.966 .33667 Mdot
.966 .33706 Mdot
.966 .33955 Mdot
.966 .33973 Mdot
.966 .3398 Mdot
.966 .34062 Mdot
.966 .34071 Mdot
.966 .3413 Mdot
.966 .3418 Mdot
.966 .34204 Mdot
.966 .34229 Mdot
.966 .34311 Mdot
.966 .34412 Mdot
.966 .34505 Mdot
.966 .34526 Mdot
.966 .34535 Mdot
.966 .34562 Mdot
.966 .34669 Mdot
.966 .34751 Mdot
.966 .34775 Mdot
.966 .34787 Mdot
.966 .34798 Mdot
.966 .34808 Mdot
.966 .34811 Mdot
.966 .3488 Mdot
.966 .34921 Mdot
.966 .34982 Mdot
.966 .34993 Mdot
.966 .34996 Mdot
.966 .35107 Mdot
.966 .35145 Mdot
.966 .35157 Mdot
.966 .35179 Mdot
.966 .35183 Mdot
.966 .35183 Mdot
.966 .352 Mdot
.966 .35271 Mdot
.966 .35287 Mdot
.966 .35292 Mdot
.966 .3531 Mdot
.966 .35325 Mdot
.966 .35409 Mdot
.966 .3545 Mdot
.966 .3546 Mdot
.966 .35497 Mdot
.966 .35508 Mdot
.966 .3551 Mdot
.966 .35516 Mdot
.966 .35549 Mdot
.966 .35557 Mdot
.966 .35633 Mdot
.966 .35646 Mdot
.966 .3565 Mdot
.966 .35699 Mdot
.966 .35728 Mdot
.966 .35749 Mdot
.966 .35753 Mdot
.966 .35753 Mdot
.966 .35841 Mdot
.966 .36131 Mdot
.966 .36341 Mdot
.966 .36351 Mdot
.966 .36361 Mdot
.966 .36429 Mdot
.966 .36555 Mdot
.966 .36602 Mdot
.966 .36687 Mdot
.966 .36987 Mdot
.966 .3699 Mdot
.966 .37627 Mdot
.966 .37632 Mdot
.966 .38227 Mdot
.966 .38291 Mdot
.966 .38348 Mdot
.966 .38585 Mdot
.966 .38608 Mdot
.966 .38752 Mdot
.966 .38908 Mdot
.966 .39507 Mdot
.966 .39761 Mdot
.966 .3979 Mdot
.966 .39889 Mdot
.966 .39965 Mdot
.966 .40149 Mdot
.966 .40241 Mdot
.966 .40301 Mdot
.966 .40585 Mdot
.966 .40613 Mdot
.966 .4096 Mdot
.966 .40977 Mdot
.966 .41001 Mdot
.966 .41039 Mdot
.966 .41219 Mdot
.966 .41313 Mdot
.966 .41519 Mdot
.966 .41615 Mdot
.966 .42102 Mdot
.966 .42124 Mdot
.966 .42195 Mdot
.966 .42459 Mdot
.966 .42704 Mdot
.966 .42938 Mdot
.966 .4333 Mdot
.966 .43567 Mdot
.966 .44085 Mdot
.966 .44461 Mdot
.966 .44832 Mdot
.966 .45022 Mdot
.966 .45693 Mdot
.966 .45832 Mdot
.966 .45914 Mdot
.966 .45932 Mdot
.966 .45943 Mdot
.966 .46121 Mdot
.966 .46277 Mdot
.966 .46319 Mdot
.966 .46401 Mdot
.966 .46869 Mdot
.966 .47 Mdot
.966 .4701 Mdot
.966 .47423 Mdot
.966 .4782 Mdot
.966 .47856 Mdot
.966 .47929 Mdot
.966 .47965 Mdot
.966 .48209 Mdot
.966 .48209 Mdot
.966 .48211 Mdot
.966 .4822 Mdot
.966 .48232 Mdot
.966 .48252 Mdot
.966 .48254 Mdot
.966 .48259 Mdot
.966 .48293 Mdot
.966 .48307 Mdot
.966 .4831 Mdot
.966 .4831 Mdot
.966 .48315 Mdot
.966 .4833 Mdot
.966 .48334 Mdot
.966 .48351 Mdot
.966 .48385 Mdot
.966 .48399 Mdot
.966 .48401 Mdot
.966 .48408 Mdot
.966 .48437 Mdot
.966 .48444 Mdot
.966 .48444 Mdot
.966 .48445 Mdot
.966 .48454 Mdot
.966 .48475 Mdot
.966 .4852 Mdot
.966 .48521 Mdot
.966 .48551 Mdot
.966 .48567 Mdot
.966 .48601 Mdot
.966 .4861 Mdot
.966 .4862 Mdot
.966 .48697 Mdot
.966 .48707 Mdot
.966 .48711 Mdot
.966 .48798 Mdot
.966 .48895 Mdot
.966 .48898 Mdot
.966 .48931 Mdot
.966 .48934 Mdot
.966 .48941 Mdot
.966 .49109 Mdot
.966 .49228 Mdot
.966 .49237 Mdot
.966 .4929 Mdot
.966 .49309 Mdot
.966 .49316 Mdot
.966 .49447 Mdot
.966 .49555 Mdot
.966 .4966 Mdot
.966 .49668 Mdot
.966 .49677 Mdot
.966 .49708 Mdot
.966 .4978 Mdot
.966 .49848 Mdot
.966 .4987 Mdot
.966 .4993 Mdot
.966 .49935 Mdot
.966 .49967 Mdot
.966 .49984 Mdot
.966 .49987 Mdot
.966 .49988 Mdot
.966 .50019 Mdot
.966 .50105 Mdot
.966 .50126 Mdot
.966 .50147 Mdot
.966 .50213 Mdot
.966 .50252 Mdot
.966 .50264 Mdot
.966 .50272 Mdot
.966 .5031 Mdot
.966 .5031 Mdot
.966 .50336 Mdot
.966 .50336 Mdot
.966 .50496 Mdot
.966 .5055 Mdot
.966 .5063 Mdot
.966 .50657 Mdot
.966 .50756 Mdot
.966 .5078 Mdot
.966 .50859 Mdot
.966 .50866 Mdot
.966 .5088 Mdot
.966 .50908 Mdot
.966 .50987 Mdot
.966 .5103 Mdot
.966 .51127 Mdot
.966 .51198 Mdot
.966 .51314 Mdot
.966 .51329 Mdot
.966 .51339 Mdot
.966 .51367 Mdot
.966 .51367 Mdot
.966 .51416 Mdot
.966 .51549 Mdot
.966 .51652 Mdot
.966 .51693 Mdot
.966 .51812 Mdot
.966 .51812 Mdot
.966 .51917 Mdot
.966 .52024 Mdot
.966 .52042 Mdot
.966 .52056 Mdot
.966 .52069 Mdot
.966 .52096 Mdot
.966 .52136 Mdot
.966 .52266 Mdot
.966 .52273 Mdot
.966 .52317 Mdot
.966 .52338 Mdot
.966 .52428 Mdot
.966 .52443 Mdot
.966 .52495 Mdot
.966 .52549 Mdot
.966 .52765 Mdot
.966 .52897 Mdot
.966 .52906 Mdot
.966 .52966 Mdot
.966 .53041 Mdot
.966 .53146 Mdot
.966 .53186 Mdot
.966 .53222 Mdot
.966 .53294 Mdot
.966 .53335 Mdot
.966 .53411 Mdot
.966 .53416 Mdot
.966 .53509 Mdot
.966 .53592 Mdot
.966 .5362 Mdot
.966 .53659 Mdot
.966 .5367 Mdot
.966 .537 Mdot
.966 .53747 Mdot
.966 .53771 Mdot
.966 .53867 Mdot
.966 .53898 Mdot
.966 .53902 Mdot
.966 .53969 Mdot
.966 .54043 Mdot
.966 .54173 Mdot
.966 .54268 Mdot
.966 .54321 Mdot
.966 .54328 Mdot
.966 .5435 Mdot
.966 .54507 Mdot
.966 .54534 Mdot
.966 .54621 Mdot
.966 .54637 Mdot
.966 .54673 Mdot
.966 .54706 Mdot
.966 .54708 Mdot
.966 .54711 Mdot
.966 .54751 Mdot
.966 .54871 Mdot
.966 .54969 Mdot
.966 .55121 Mdot
.966 .55264 Mdot
.966 .55304 Mdot
.966 .55347 Mdot
.966 .55358 Mdot
.966 .55362 Mdot
.966 .5544 Mdot
.966 .55487 Mdot
.966 .55543 Mdot
.966 .55596 Mdot
.966 .55645 Mdot
.966 .55707 Mdot
.966 .55722 Mdot
.966 .55727 Mdot
.966 .55765 Mdot
.966 .55878 Mdot
.966 .55937 Mdot
.966 .55946 Mdot
.966 .55955 Mdot
.966 .56042 Mdot
.966 .56134 Mdot
.966 .56134 Mdot
.966 .56195 Mdot
.966 .56223 Mdot
.966 .56224 Mdot
.966 .56255 Mdot
.966 .56296 Mdot
.966 .56335 Mdot
.966 .56369 Mdot
.966 .56392 Mdot
.966 .56415 Mdot
.966 .56438 Mdot
.966 .56438 Mdot
.966 .56441 Mdot
.966 .56458 Mdot
.966 .5648 Mdot
.966 .56493 Mdot
.966 .56518 Mdot
.966 .56521 Mdot
.966 .56524 Mdot
.966 .56531 Mdot
.966 .56588 Mdot
.966 .56593 Mdot
.966 .56618 Mdot
.966 .5662 Mdot
.966 .56623 Mdot
.966 .56624 Mdot
.966 .56632 Mdot
.966 .56659 Mdot
.966 .56667 Mdot
.966 .5667 Mdot
.966 .56697 Mdot
.966 .56703 Mdot
.966 .56737 Mdot
.966 .56737 Mdot
.966 .56757 Mdot
.966 .56767 Mdot
.966 .5678 Mdot
.966 .56783 Mdot
.966 .56784 Mdot
.966 .56794 Mdot
.966 .56844 Mdot
.966 .56856 Mdot
.966 .56856 Mdot
.966 .56859 Mdot
.966 .56873 Mdot
.966 .56874 Mdot
.966 .56881 Mdot
.966 .56908 Mdot
.966 .5692 Mdot
.966 .5692 Mdot
.966 .56958 Mdot
.966 .56982 Mdot
.966 .56983 Mdot
.966 .56991 Mdot
.966 .57014 Mdot
.966 .5703 Mdot
.966 .57031 Mdot
.966 .57057 Mdot
.966 .57081 Mdot
.966 .57101 Mdot
.966 .57102 Mdot
.966 .57109 Mdot
.966 .57115 Mdot
.966 .57123 Mdot
.966 .57138 Mdot
.966 .57149 Mdot
.966 .57188 Mdot
.966 .57206 Mdot
.966 .57252 Mdot
.966 .57268 Mdot
.966 .57273 Mdot
.966 .57274 Mdot
.966 .57283 Mdot
.966 .57286 Mdot
.966 .57339 Mdot
.966 .57361 Mdot
.966 .57395 Mdot
.966 .57412 Mdot
.966 .57439 Mdot
.966 .57453 Mdot
.966 .57466 Mdot
.966 .57483 Mdot
.966 .57483 Mdot
.966 .57491 Mdot
.966 .57507 Mdot
.966 .57521 Mdot
.966 .57522 Mdot
.966 .57527 Mdot
.966 .57535 Mdot
.966 .57556 Mdot
.966 .57568 Mdot
.966 .57571 Mdot
.966 .5758 Mdot
.966 .57597 Mdot
.966 .57698 Mdot
.966 .57704 Mdot
.966 .57715 Mdot
.966 .57772 Mdot
.966 .57786 Mdot
.966 .57791 Mdot
.966 .57794 Mdot
.966 .57798 Mdot
.966 .578 Mdot
.966 .5781 Mdot
.966 .57813 Mdot
.966 .5783 Mdot
.966 .57832 Mdot
.966 .57838 Mdot
.966 .57848 Mdot
.966 .57889 Mdot
.966 .57892 Mdot
.966 .57896 Mdot
.966 .579 Mdot
.966 .57915 Mdot
.966 .57932 Mdot
.966 .57936 Mdot
.966 .57946 Mdot
.966 .5795 Mdot
.966 .57966 Mdot
.966 .57972 Mdot
.966 .58004 Mdot
.966 .58014 Mdot
.966 .58024 Mdot
.966 .58028 Mdot
.966 .58028 Mdot
.966 .58039 Mdot
.966 .58045 Mdot
.966 .58067 Mdot
.966 .58077 Mdot
.966 .58103 Mdot
.966 .58103 Mdot
.966 .58105 Mdot
.966 .58122 Mdot
.966 .58141 Mdot
.966 .58149 Mdot
.966 .58151 Mdot
.966 .58161 Mdot
.966 .58171 Mdot
.966 .58183 Mdot
.966 .58185 Mdot
.966 .58188 Mdot
.966 .58189 Mdot
.966 .58197 Mdot
.966 .582 Mdot
.966 .58206 Mdot
.966 .58209 Mdot
.966 .58209 Mdot
.966 .58213 Mdot
.966 .58217 Mdot
.966 .58219 Mdot
.966 .58229 Mdot
.966 .58231 Mdot
.966 .58232 Mdot
.966 .5824 Mdot
.966 .58258 Mdot
.966 .58263 Mdot
.966 .58263 Mdot
.966 .58272 Mdot
.966 .58283 Mdot
.966 .58284 Mdot
.966 .58284 Mdot
.966 .58286 Mdot
.966 .58286 Mdot
.966 .58293 Mdot
.966 .58299 Mdot
.966 .58299 Mdot
.966 .58305 Mdot
.966 .58306 Mdot
.966 .58307 Mdot
.966 .58309 Mdot
.966 .5831 Mdot
.966 .58312 Mdot
.966 .58312 Mdot
.966 .58317 Mdot
.966 .58317 Mdot
.966 .58317 Mdot
.966 .58317 Mdot
.966 .5832 Mdot
.966 .5832 Mdot
.966 .5832 Mdot
.966 .58321 Mdot
.966 .58323 Mdot
.966 .58325 Mdot
.966 .58325 Mdot
.966 .58326 Mdot
.966 .58326 Mdot
.966 .58326 Mdot
.966 .58327 Mdot
.966 .5833 Mdot
.966 .5833 Mdot
.966 .5833 Mdot
.966 .58332 Mdot
.966 .58333 Mdot
.966 .58333 Mdot
.966 .58333 Mdot
.968 .0719 Mdot
.968 .07195 Mdot
.968 .07196 Mdot
.968 .07202 Mdot
.968 .07214 Mdot
.968 .07217 Mdot
.968 .07225 Mdot
.968 .07228 Mdot
.968 .07233 Mdot
.968 .07235 Mdot
.968 .07237 Mdot
.968 .07242 Mdot
.968 .07242 Mdot
.968 .07292 Mdot
.968 .07299 Mdot
.968 .07299 Mdot
.968 .07304 Mdot
.968 .07338 Mdot
.968 .07352 Mdot
.968 .07378 Mdot
.968 .07395 Mdot
.968 .074 Mdot
.968 .07454 Mdot
.968 .07454 Mdot
.968 .07463 Mdot
.968 .07471 Mdot
.968 .0749 Mdot
.968 .075 Mdot
.968 .07524 Mdot
.968 .07527 Mdot
.968 .07544 Mdot
.968 .07559 Mdot
.968 .07579 Mdot
.968 .07658 Mdot
.968 .0768 Mdot
.968 .07693 Mdot
.968 .07703 Mdot
.968 .07704 Mdot
.968 .07719 Mdot
.968 .07758 Mdot
.968 .0778 Mdot
.968 .07783 Mdot
.968 .07816 Mdot
.968 .07872 Mdot
.968 .07879 Mdot
.968 .07968 Mdot
.968 .08003 Mdot
.968 .08016 Mdot
.968 .08019 Mdot
.968 .08035 Mdot
.968 .0807 Mdot
.968 .08123 Mdot
.968 .08166 Mdot
.968 .08212 Mdot
.968 .0824 Mdot
.968 .08256 Mdot
.968 .08267 Mdot
.968 .08307 Mdot
.968 .08371 Mdot
.968 .08416 Mdot
.968 .08437 Mdot
.968 .08475 Mdot
.968 .08635 Mdot
.968 .08665 Mdot
.968 .08678 Mdot
.968 .08691 Mdot
.968 .08704 Mdot
.968 .08758 Mdot
.968 .08767 Mdot
.968 .08836 Mdot
.968 .08895 Mdot
.968 .09041 Mdot
.968 .0912 Mdot
.968 .09316 Mdot
.968 .09341 Mdot
.968 .0935 Mdot
.968 .09418 Mdot
.968 .09464 Mdot
.968 .09544 Mdot
.968 .09544 Mdot
.968 .09618 Mdot
.968 .09678 Mdot
.968 .09748 Mdot
.968 .09764 Mdot
.968 .09871 Mdot
.968 .10122 Mdot
.968 .10266 Mdot
.968 .10306 Mdot
.968 .10375 Mdot
.968 .10418 Mdot
.968 .10439 Mdot
.968 .10453 Mdot
.968 .10471 Mdot
.968 .1052 Mdot
.968 .10581 Mdot
.968 .10681 Mdot
.968 .11004 Mdot
.968 .11007 Mdot
.968 .11034 Mdot
.968 .11051 Mdot
.968 .11083 Mdot
.968 .11183 Mdot
.968 .11239 Mdot
.968 .11246 Mdot
.968 .11521 Mdot
.968 .11556 Mdot
.968 .1189 Mdot
.968 .11905 Mdot
.968 .12043 Mdot
.968 .12095 Mdot
.968 .12177 Mdot
.968 .12202 Mdot
.968 .12356 Mdot
.968 .12418 Mdot
.968 .12458 Mdot
.968 .12612 Mdot
.968 .1263 Mdot
.968 .12673 Mdot
.968 .12911 Mdot
.968 .13073 Mdot
.968 .1311 Mdot
.968 .13316 Mdot
.968 .13384 Mdot
.968 .13421 Mdot
.968 .13599 Mdot
.968 .13804 Mdot
.968 .13811 Mdot
.968 .13899 Mdot
.968 .13951 Mdot
.968 .14219 Mdot
.968 .14297 Mdot
.968 .14318 Mdot
.968 .14337 Mdot
.968 .14365 Mdot
.968 .14484 Mdot
.968 .14492 Mdot
.968 .14851 Mdot
.968 .14854 Mdot
.968 .14891 Mdot
.968 .14967 Mdot
.968 .15051 Mdot
.968 .15072 Mdot
.968 .1523 Mdot
.968 .15394 Mdot
.968 .15438 Mdot
.968 .15449 Mdot
.968 .15526 Mdot
.968 .15686 Mdot
.968 .15807 Mdot
.968 .15851 Mdot
.968 .15854 Mdot
.968 .15914 Mdot
.968 .15934 Mdot
.968 .15945 Mdot
.968 .16227 Mdot
.968 .16295 Mdot
.968 .16342 Mdot
.968 .16415 Mdot
.968 .16479 Mdot
.968 .1653 Mdot
.968 .16619 Mdot
.968 .16689 Mdot
.968 .16801 Mdot
.968 .16856 Mdot
.968 .17026 Mdot
.968 .1705 Mdot
.968 .17101 Mdot
.968 .17232 Mdot
.968 .17285 Mdot
.968 .17328 Mdot
.968 .17356 Mdot
.968 .17503 Mdot
.968 .17602 Mdot
.968 .17609 Mdot
.968 .17757 Mdot
.968 .17893 Mdot
.968 .17915 Mdot
.968 .18051 Mdot
.968 .181 Mdot
.968 .18276 Mdot
.968 .18314 Mdot
.968 .18584 Mdot
.968 .18593 Mdot
.968 .18608 Mdot
.968 .18612 Mdot
.968 .18629 Mdot
.968 .18664 Mdot
.968 .1867 Mdot
.968 .18694 Mdot
.968 .18702 Mdot
.968 .18719 Mdot
.968 .18723 Mdot
.968 .1873 Mdot
.968 .18743 Mdot
.968 .18743 Mdot
.968 .18865 Mdot
.968 .18888 Mdot
.968 .18908 Mdot
.968 .1891 Mdot
.968 .18924 Mdot
.968 .18975 Mdot
.968 .18986 Mdot
.968 .19022 Mdot
.968 .19043 Mdot
.968 .19063 Mdot
.968 .19073 Mdot
.968 .19136 Mdot
.968 .1916 Mdot
.968 .19186 Mdot
.968 .19201 Mdot
.968 .19207 Mdot
.968 .19233 Mdot
.968 .19357 Mdot
.968 .19358 Mdot
.968 .19382 Mdot
.968 .19407 Mdot
.968 .19461 Mdot
.968 .19489 Mdot
.968 .1954 Mdot
.968 .1956 Mdot
.968 .19567 Mdot
.968 .19583 Mdot
.968 .19618 Mdot
.968 .1966 Mdot
.968 .19719 Mdot
.968 .19785 Mdot
.968 .19938 Mdot
.968 .19945 Mdot
.968 .20009 Mdot
.968 .20047 Mdot
.968 .20075 Mdot
.968 .20078 Mdot
.968 .20119 Mdot
.968 .20132 Mdot
.968 .20156 Mdot
.968 .20179 Mdot
.968 .20232 Mdot
.968 .20296 Mdot
.968 .20304 Mdot
.968 .20325 Mdot
.968 .20389 Mdot
.968 .204 Mdot
.968 .20404 Mdot
.968 .20447 Mdot
.968 .20509 Mdot
.968 .2056 Mdot
.968 .2058 Mdot
.968 .2071 Mdot
.968 .20778 Mdot
.968 .20783 Mdot
.968 .20834 Mdot
.968 .20894 Mdot
.968 .20933 Mdot
.968 .20971 Mdot
.968 .20979 Mdot
.968 .21026 Mdot
.968 .21127 Mdot
.968 .21211 Mdot
.968 .21276 Mdot
.968 .214 Mdot
.968 .2153 Mdot
.968 .21567 Mdot
.968 .21577 Mdot
.968 .21611 Mdot
.968 .21655 Mdot
.968 .21655 Mdot
.968 .21687 Mdot
.968 .21802 Mdot
.968 .21859 Mdot
.968 .21886 Mdot
.968 .21961 Mdot
.968 .21983 Mdot
.968 .22109 Mdot
.968 .22111 Mdot
.968 .2217 Mdot
.968 .22185 Mdot
.968 .22193 Mdot
.968 .22194 Mdot
.968 .22278 Mdot
.968 .22316 Mdot
.968 .2232 Mdot
.968 .22322 Mdot
.968 .22452 Mdot
.968 .22528 Mdot
.968 .22577 Mdot
.968 .22578 Mdot
.968 .22587 Mdot
.968 .22603 Mdot
.968 .22702 Mdot
.968 .22729 Mdot
.968 .22781 Mdot
.968 .22808 Mdot
.968 .22815 Mdot
.968 .2285 Mdot
.968 .22887 Mdot
.968 .22887 Mdot
.968 .22888 Mdot
.968 .22923 Mdot
.968 .22923 Mdot
.968 .22946 Mdot
.968 .22988 Mdot
.968 .23075 Mdot
.968 .23097 Mdot
.968 .231 Mdot
.968 .23202 Mdot
.968 .23294 Mdot
.968 .23328 Mdot
.968 .23348 Mdot
.968 .23407 Mdot
.968 .23438 Mdot
.968 .23443 Mdot
.968 .23461 Mdot
.968 .23505 Mdot
.968 .23623 Mdot
.968 .23684 Mdot
.968 .23697 Mdot
.968 .23799 Mdot
.968 .2387 Mdot
.968 .23905 Mdot
.968 .2409 Mdot
.968 .24305 Mdot
.968 .2434 Mdot
.968 .24388 Mdot
.968 .24397 Mdot
.968 .24412 Mdot
.968 .24555 Mdot
.968 .24612 Mdot
.968 .24636 Mdot
.968 .24666 Mdot
.968 .24705 Mdot
.968 .24731 Mdot
.968 .2487 Mdot
.968 .24874 Mdot
.968 .24902 Mdot
.968 .24903 Mdot
.968 .24919 Mdot
.968 .24962 Mdot
.968 .2502 Mdot
.968 .25047 Mdot
.968 .25051 Mdot
.968 .25185 Mdot
.968 .25193 Mdot
.968 .25267 Mdot
.968 .25268 Mdot
.968 .25471 Mdot
.968 .25637 Mdot
.968 .25672 Mdot
.968 .25758 Mdot
.968 .25831 Mdot
.968 .25874 Mdot
.968 .26046 Mdot
.968 .26149 Mdot
.968 .26168 Mdot
.968 .26372 Mdot
.968 .26434 Mdot
.968 .26821 Mdot
.968 .26825 Mdot
.968 .26853 Mdot
.968 .26921 Mdot
.968 .26944 Mdot
.968 .26946 Mdot
.968 .27119 Mdot
.968 .27235 Mdot
.968 .27245 Mdot
.968 .27253 Mdot
.968 .2729 Mdot
.968 .27352 Mdot
.968 .27437 Mdot
.968 .2759 Mdot
.968 .27657 Mdot
.968 .27712 Mdot
.968 .27751 Mdot
.968 .27799 Mdot
.968 .27931 Mdot
.968 .27954 Mdot
.968 .28094 Mdot
.968 .28365 Mdot
.968 .28448 Mdot
.968 .28707 Mdot
.968 .28833 Mdot
.968 .29008 Mdot
.968 .29046 Mdot
.968 .29227 Mdot
.968 .29235 Mdot
.968 .29305 Mdot
.968 .29352 Mdot
.968 .29435 Mdot
.968 .29455 Mdot
.968 .29489 Mdot
.968 .29643 Mdot
.968 .29677 Mdot
.968 .29701 Mdot
.968 .29832 Mdot
.968 .29849 Mdot
.968 .29866 Mdot
.968 .29989 Mdot
.968 .30029 Mdot
.968 .3009 Mdot
.968 .30126 Mdot
.968 .30237 Mdot
.968 .30444 Mdot
.968 .30465 Mdot
.968 .30483 Mdot
.968 .30512 Mdot
.968 .30589 Mdot
.968 .30679 Mdot
.968 .30742 Mdot
.968 .30899 Mdot
.968 .31048 Mdot
.968 .31232 Mdot
.968 .31279 Mdot
.968 .3133 Mdot
.968 .31361 Mdot
.968 .31547 Mdot
.968 .3157 Mdot
.968 .31585 Mdot
.968 .31828 Mdot
.968 .3194 Mdot
.968 .32009 Mdot
.968 .32026 Mdot
.968 .3207 Mdot
.968 .32074 Mdot
.968 .32284 Mdot
.968 .32335 Mdot
.968 .32349 Mdot
.968 .32424 Mdot
.968 .32458 Mdot
.968 .32684 Mdot
.968 .32723 Mdot
.968 .32738 Mdot
.968 .32742 Mdot
.968 .32853 Mdot
.968 .32898 Mdot
.968 .32945 Mdot
.968 .32999 Mdot
.968 .33038 Mdot
.968 .3314 Mdot
.968 .33159 Mdot
.968 .33193 Mdot
.968 .33332 Mdot
.968 .33368 Mdot
.968 .33379 Mdot
.968 .33389 Mdot
.968 .33434 Mdot
.968 .33496 Mdot
.968 .33543 Mdot
.968 .33654 Mdot
.968 .33869 Mdot
.968 .33922 Mdot
.968 .33953 Mdot
.968 .34006 Mdot
.968 .34139 Mdot
.968 .34476 Mdot
.968 .34541 Mdot
.968 .34598 Mdot
.968 .34632 Mdot
.968 .34875 Mdot
.968 .34901 Mdot
.968 .35122 Mdot
.968 .35139 Mdot
.968 .353 Mdot
.968 .35307 Mdot
.968 .35396 Mdot
.968 .35445 Mdot
.968 .35515 Mdot
.968 .35543 Mdot
.968 .35561 Mdot
.968 .3563 Mdot
.968 .35829 Mdot
.968 .35845 Mdot
.968 .3596 Mdot
.968 .36131 Mdot
.968 .3619 Mdot
.968 .36296 Mdot
.968 .36326 Mdot
.968 .36342 Mdot
.968 .36353 Mdot
.968 .36399 Mdot
.968 .36401 Mdot
.968 .36553 Mdot
.968 .36581 Mdot
.968 .36679 Mdot
.968 .36738 Mdot
.968 .36925 Mdot
.968 .37035 Mdot
.968 .37059 Mdot
.968 .37122 Mdot
.968 .37232 Mdot
.968 .37308 Mdot
.968 .37316 Mdot
.968 .37333 Mdot
.968 .37377 Mdot
.968 .37499 Mdot
.968 .37549 Mdot
.968 .37593 Mdot
.968 .376 Mdot
.968 .37644 Mdot
.968 .3766 Mdot
.968 .37728 Mdot
.968 .37813 Mdot
.968 .37939 Mdot
.968 .37956 Mdot
.968 .37966 Mdot
.968 .37993 Mdot
.968 .38015 Mdot
.968 .38229 Mdot
.968 .38287 Mdot
.968 .38294 Mdot
.968 .38381 Mdot
.968 .38479 Mdot
.968 .38789 Mdot
.968 .38796 Mdot
.968 .38881 Mdot
.968 .38977 Mdot
.968 .3899 Mdot
.968 .38993 Mdot
.968 .39047 Mdot
.968 .39054 Mdot
.968 .39076 Mdot
.968 .39086 Mdot
.968 .39092 Mdot
.968 .39134 Mdot
.968 .39163 Mdot
.968 .39197 Mdot
.968 .39246 Mdot
.968 .39294 Mdot
.968 .39298 Mdot
.968 .39325 Mdot
.968 .39462 Mdot
.968 .39471 Mdot
.968 .39543 Mdot
.968 .39558 Mdot
.968 .39621 Mdot
.968 .39651 Mdot
.968 .3966 Mdot
.968 .4002 Mdot
.968 .4012 Mdot
.968 .40145 Mdot
.968 .40225 Mdot
.968 .40314 Mdot
.968 .40626 Mdot
.968 .40669 Mdot
.968 .40788 Mdot
.968 .40921 Mdot
.968 .40936 Mdot
.968 .40945 Mdot
.968 .41032 Mdot
.968 .41039 Mdot
.968 .41133 Mdot
.968 .4117 Mdot
.968 .41214 Mdot
.968 .41238 Mdot
.968 .41564 Mdot
.968 .41577 Mdot
.968 .41605 Mdot
.968 .41678 Mdot
.968 .4172 Mdot
.968 .41848 Mdot
.968 .4188 Mdot
.968 .41992 Mdot
.968 .42093 Mdot
.968 .4225 Mdot
.968 .42385 Mdot
.968 .42437 Mdot
.968 .42491 Mdot
.968 .42529 Mdot
.968 .42664 Mdot
.968 .4268 Mdot
.968 .42826 Mdot
.968 .43059 Mdot
.968 .43085 Mdot
.968 .43097 Mdot
.968 .43175 Mdot
.968 .43357 Mdot
.968 .43453 Mdot
.968 .43524 Mdot
.968 .43575 Mdot
.968 .43679 Mdot
.968 .43682 Mdot
.968 .43688 Mdot
.968 .43716 Mdot
.968 .43945 Mdot
.968 .44051 Mdot
.968 .44115 Mdot
.968 .44139 Mdot
.968 .44195 Mdot
.968 .44489 Mdot
.968 .44686 Mdot
.968 .447 Mdot
.968 .44703 Mdot
.968 .44815 Mdot
.968 .44861 Mdot
.968 .44987 Mdot
.968 .44993 Mdot
.968 .45194 Mdot
.968 .45258 Mdot
.968 .45302 Mdot
.968 .45563 Mdot
.968 .45638 Mdot
.968 .45657 Mdot
.968 .45691 Mdot
.968 .45704 Mdot
.968 .4571 Mdot
.968 .45909 Mdot
.968 .45995 Mdot
.968 .46006 Mdot
.968 .46066 Mdot
.968 .4614 Mdot
.968 .46321 Mdot
.968 .46572 Mdot
.968 .4659 Mdot
.968 .46617 Mdot
.968 .46624 Mdot
.968 .46656 Mdot
.968 .4666 Mdot
.968 .4672 Mdot
.968 .46732 Mdot
.968 .46776 Mdot
.968 .46791 Mdot
.968 .46804 Mdot
.968 .46822 Mdot
.968 .46825 Mdot
.968 .46829 Mdot
.968 .46842 Mdot
.968 .46866 Mdot
.968 .46867 Mdot
.968 .46873 Mdot
.968 .47089 Mdot
.968 .47132 Mdot
.968 .47169 Mdot
.968 .47172 Mdot
.968 .47197 Mdot
.968 .47289 Mdot
.968 .47298 Mdot
.968 .4731 Mdot
.968 .47375 Mdot
.968 .47411 Mdot
.968 .47447 Mdot
.968 .47466 Mdot
.968 .47561 Mdot
.968 .47579 Mdot
.968 .4759 Mdot
.968 .47622 Mdot
.968 .47668 Mdot
.968 .47695 Mdot
.968 .47705 Mdot
.968 .47751 Mdot
.968 .4783 Mdot
.968 .47895 Mdot
.968 .4797 Mdot
.968 .47971 Mdot
.968 .4799 Mdot
.968 .48014 Mdot
.968 .48058 Mdot
.968 .48082 Mdot
.968 .48153 Mdot
.968 .48201 Mdot
.968 .48289 Mdot
.968 .48318 Mdot
.968 .48325 Mdot
.968 .48336 Mdot
.968 .48365 Mdot
.968 .48425 Mdot
.968 .48497 Mdot
.968 .48587 Mdot
.968 .48597 Mdot
.968 .4871 Mdot
.968 .48759 Mdot
.968 .48948 Mdot
.968 .48969 Mdot
.968 .48982 Mdot
.968 .49003 Mdot
.968 .49089 Mdot
.968 .49151 Mdot
.968 .49198 Mdot
.968 .49202 Mdot
.968 .49216 Mdot
.968 .49271 Mdot
.968 .49285 Mdot
.968 .49293 Mdot
.968 .49333 Mdot
.968 .4937 Mdot
.968 .49406 Mdot
.968 .49451 Mdot
.968 .49457 Mdot
.968 .49472 Mdot
.968 .49561 Mdot
.968 .49574 Mdot
.968 .49609 Mdot
.968 .49713 Mdot
.968 .4973 Mdot
.968 .49737 Mdot
.968 .49807 Mdot
.968 .49907 Mdot
.968 .49988 Mdot
.968 .5 Mdot
.968 .50019 Mdot
.968 .50038 Mdot
.968 .50108 Mdot
.968 .50166 Mdot
.968 .50226 Mdot
.968 .50314 Mdot
.968 .50325 Mdot
.968 .50332 Mdot
.968 .5034 Mdot
.968 .50419 Mdot
.968 .50461 Mdot
.968 .50475 Mdot
.968 .50498 Mdot
.968 .50513 Mdot
.968 .50573 Mdot
.968 .50632 Mdot
.968 .50644 Mdot
.968 .50703 Mdot
.968 .50715 Mdot
.968 .50869 Mdot
.968 .50884 Mdot
.968 .5095 Mdot
.968 .50997 Mdot
.968 .51093 Mdot
.968 .51277 Mdot
.968 .51412 Mdot
.968 .51469 Mdot
.968 .51523 Mdot
.968 .51537 Mdot
.968 .51543 Mdot
.968 .51586 Mdot
.968 .5165 Mdot
.968 .5165 Mdot
.968 .51659 Mdot
.968 .51694 Mdot
.968 .51696 Mdot
.968 .51837 Mdot
.968 .5186 Mdot
.968 .51942 Mdot
.968 .51979 Mdot
.968 .52084 Mdot
.968 .52115 Mdot
.968 .52289 Mdot
.968 .52292 Mdot
.968 .5234 Mdot
.968 .52352 Mdot
.968 .52372 Mdot
.968 .52394 Mdot
.968 .52394 Mdot
.968 .52404 Mdot
.968 .52406 Mdot
.968 .52479 Mdot
.968 .52499 Mdot
.968 .52519 Mdot
.968 .52571 Mdot
.968 .52576 Mdot
.968 .52579 Mdot
.968 .52596 Mdot
.968 .52609 Mdot
.968 .52752 Mdot
.968 .5279 Mdot
.968 .52827 Mdot
.968 .52831 Mdot
.968 .52853 Mdot
.968 .52895 Mdot
.968 .52917 Mdot
.968 .52919 Mdot
.968 .5293 Mdot
.968 .52951 Mdot
.968 .52958 Mdot
.968 .53003 Mdot
.968 .5304 Mdot
.968 .53079 Mdot
.968 .53094 Mdot
.968 .53102 Mdot
.968 .53114 Mdot
.968 .53115 Mdot
.968 .53143 Mdot
.968 .53152 Mdot
.968 .53181 Mdot
.968 .53216 Mdot
.968 .53221 Mdot
.968 .53224 Mdot
.968 .53225 Mdot
.968 .53242 Mdot
.968 .53269 Mdot
.968 .53315 Mdot
.968 .53316 Mdot
.968 .53317 Mdot
.968 .5336 Mdot
.968 .5336 Mdot
.968 .53363 Mdot
.968 .53389 Mdot
.968 .53442 Mdot
.968 .53469 Mdot
.968 .53478 Mdot
.968 .5355 Mdot
.968 .53578 Mdot
.968 .53581 Mdot
.968 .53706 Mdot
.968 .53817 Mdot
.968 .53856 Mdot
.968 .53857 Mdot
.968 .53881 Mdot
.968 .53951 Mdot
.968 .53973 Mdot
.968 .53988 Mdot
.968 .53993 Mdot
.968 .54016 Mdot
.968 .54066 Mdot
.968 .54074 Mdot
.968 .54083 Mdot
.968 .5415 Mdot
.968 .54204 Mdot
.968 .54273 Mdot
.968 .54288 Mdot
.968 .54395 Mdot
.968 .54404 Mdot
.968 .5442 Mdot
.968 .5445 Mdot
.968 .54461 Mdot
.968 .5448 Mdot
.968 .54484 Mdot
.968 .54522 Mdot
.968 .54619 Mdot
.968 .54712 Mdot
.968 .54725 Mdot
.968 .54786 Mdot
.968 .54802 Mdot
.968 .54849 Mdot
.968 .54857 Mdot
.968 .54903 Mdot
.968 .54954 Mdot
.968 .54957 Mdot
.968 .5499 Mdot
.968 .55041 Mdot
.968 .5505 Mdot
.968 .55065 Mdot
.968 .55083 Mdot
.968 .55128 Mdot
.968 .55145 Mdot
.968 .55154 Mdot
.968 .55212 Mdot
.968 .55231 Mdot
.968 .55269 Mdot
.968 .55293 Mdot
.968 .55323 Mdot
.968 .5534 Mdot
.968 .55362 Mdot
.968 .55387 Mdot
.968 .55403 Mdot
.968 .55426 Mdot
.968 .55522 Mdot
.968 .55526 Mdot
.968 .55533 Mdot
.968 .55553 Mdot
.968 .55554 Mdot
.968 .55569 Mdot
.968 .5561 Mdot
.968 .55665 Mdot
.968 .5569 Mdot
.968 .55694 Mdot
.968 .55709 Mdot
.968 .55765 Mdot
.968 .55818 Mdot
.968 .55826 Mdot
.968 .55854 Mdot
.968 .5588 Mdot
.968 .55892 Mdot
.968 .55893 Mdot
.968 .56015 Mdot
.968 .56017 Mdot
.968 .56057 Mdot
.968 .56067 Mdot
.968 .56073 Mdot
.968 .5608 Mdot
.968 .56107 Mdot
.968 .56197 Mdot
.968 .56215 Mdot
.968 .56244 Mdot
.968 .56247 Mdot
.968 .56316 Mdot
.968 .56376 Mdot
.968 .56388 Mdot
.968 .56411 Mdot
.968 .5648 Mdot
.968 .56492 Mdot
.968 .56547 Mdot
.968 .56627 Mdot
.968 .56641 Mdot
.968 .56647 Mdot
.968 .56699 Mdot
.968 .56712 Mdot
.968 .56733 Mdot
.968 .56784 Mdot
.968 .56793 Mdot
.968 .5682 Mdot
.968 .56838 Mdot
.968 .56884 Mdot
.968 .56889 Mdot
.968 .57001 Mdot
.968 .57012 Mdot
.968 .57104 Mdot
.968 .57106 Mdot
.968 .57125 Mdot
.968 .57159 Mdot
.968 .57169 Mdot
.968 .57175 Mdot
.968 .57184 Mdot
.968 .57185 Mdot
.968 .57292 Mdot
.968 .57326 Mdot
.968 .57346 Mdot
.968 .57362 Mdot
.968 .57368 Mdot
.968 .57373 Mdot
.968 .5738 Mdot
.968 .57394 Mdot
.968 .57418 Mdot
.968 .57431 Mdot
.968 .57479 Mdot
.968 .57562 Mdot
.968 .57598 Mdot
.968 .57603 Mdot
.968 .57626 Mdot
.968 .57646 Mdot
.968 .57671 Mdot
.968 .57671 Mdot
.968 .57697 Mdot
.968 .57713 Mdot
.968 .57735 Mdot
.968 .57738 Mdot
.968 .57747 Mdot
.968 .57812 Mdot
.968 .57838 Mdot
.968 .57886 Mdot
.968 .57906 Mdot
.968 .57929 Mdot
.968 .57932 Mdot
.968 .5795 Mdot
.968 .57954 Mdot
.968 .57958 Mdot
.968 .57962 Mdot
.968 .57972 Mdot
.968 .58025 Mdot
.968 .58038 Mdot
.968 .58045 Mdot
.968 .5806 Mdot
.968 .58081 Mdot
.968 .58094 Mdot
.968 .58103 Mdot
.968 .58113 Mdot
.968 .58128 Mdot
.968 .58142 Mdot
.968 .58159 Mdot
.968 .58171 Mdot
.968 .58177 Mdot
.968 .58177 Mdot
.968 .58182 Mdot
.968 .58193 Mdot
.968 .58223 Mdot
.968 .58225 Mdot
.968 .58244 Mdot
.968 .58255 Mdot
.968 .58256 Mdot
.968 .58263 Mdot
.968 .58276 Mdot
.968 .58281 Mdot
.968 .58281 Mdot
.968 .58284 Mdot
.968 .58289 Mdot
.968 .58296 Mdot
.968 .58322 Mdot
.968 .58329 Mdot
.968 .58334 Mdot
.968 .58339 Mdot
.968 .5834 Mdot
.968 .58348 Mdot
.968 .58351 Mdot
.968 .58358 Mdot
.968 .58361 Mdot
.968 .58363 Mdot
.968 .58363 Mdot
.968 .58381 Mdot
.968 .58383 Mdot
.968 .58389 Mdot
.968 .58397 Mdot
.968 .58402 Mdot
.968 .58413 Mdot
.968 .58415 Mdot
.968 .58415 Mdot
.968 .58417 Mdot
.968 .58434 Mdot
.968 .58434 Mdot
.968 .58435 Mdot
.968 .58436 Mdot
.968 .58436 Mdot
.968 .58438 Mdot
.968 .58439 Mdot
.968 .58442 Mdot
.968 .58443 Mdot
.968 .58447 Mdot
.968 .58449 Mdot
.968 .58449 Mdot
.968 .58451 Mdot
.97 .06845 Mdot
.97 .06846 Mdot
.97 .06849 Mdot
.97 .06849 Mdot
.97 .06849 Mdot
.97 .06854 Mdot
.97 .06863 Mdot
.97 .06865 Mdot
.97 .06865 Mdot
.97 .06869 Mdot
.97 .06875 Mdot
.97 .06886 Mdot
.97 .06908 Mdot
.97 .06924 Mdot
.97 .06932 Mdot
.97 .06944 Mdot
.97 .06944 Mdot
.97 .06964 Mdot
.97 .06975 Mdot
.97 .06981 Mdot
.97 .06984 Mdot
.97 .06988 Mdot
.97 .06991 Mdot
.97 .07014 Mdot
.97 .07045 Mdot
.97 .07147 Mdot
.97 .07168 Mdot
.97 .07172 Mdot
.97 .07187 Mdot
.97 .07256 Mdot
.97 .07259 Mdot
.97 .07265 Mdot
.97 .07276 Mdot
.97 .073 Mdot
.97 .07338 Mdot
.97 .07347 Mdot
.97 .07355 Mdot
.97 .07374 Mdot
.97 .07422 Mdot
.97 .07423 Mdot
.97 .07443 Mdot
.97 .07472 Mdot
.97 .07475 Mdot
.97 .0754 Mdot
.97 .07576 Mdot
.97 .0767 Mdot
.97 .07676 Mdot
.97 .0774 Mdot
.97 .07872 Mdot
.97 .07923 Mdot
.97 .08004 Mdot
.97 .08106 Mdot
.97 .08147 Mdot
.97 .0815 Mdot
.97 .08154 Mdot
.97 .08317 Mdot
.97 .08326 Mdot
.97 .08328 Mdot
.97 .08337 Mdot
.97 .0839 Mdot
.97 .08393 Mdot
.97 .08395 Mdot
.97 .08418 Mdot
.97 .08514 Mdot
.97 .08545 Mdot
.97 .08572 Mdot
.97 .08597 Mdot
.97 .08637 Mdot
.97 .08652 Mdot
.97 .08708 Mdot
.97 .08804 Mdot
.97 .08813 Mdot
.97 .08837 Mdot
.97 .08848 Mdot
.97 .0889 Mdot
.97 .08939 Mdot
.97 .09049 Mdot
.97 .09061 Mdot
.97 .09065 Mdot
.97 .09081 Mdot
.97 .09192 Mdot
.97 .09228 Mdot
.97 .09295 Mdot
.97 .09343 Mdot
.97 .09353 Mdot
.97 .09544 Mdot
.97 .0956 Mdot
.97 .09808 Mdot
.97 .09914 Mdot
.97 .09944 Mdot
.97 .09963 Mdot
.97 .10174 Mdot
.97 .10214 Mdot
.97 .10284 Mdot
.97 .10483 Mdot
.97 .10487 Mdot
.97 .10581 Mdot
.97 .10612 Mdot
.97 .10672 Mdot
.97 .10846 Mdot
.97 .10925 Mdot
.97 .11013 Mdot
.97 .11127 Mdot
.97 .1118 Mdot
.97 .11335 Mdot
.97 .11391 Mdot
.97 .11402 Mdot
.97 .11643 Mdot
.97 .11692 Mdot
.97 .11739 Mdot
.97 .11752 Mdot
.97 .11915 Mdot
.97 .11937 Mdot
.97 .1217 Mdot
.97 .12237 Mdot
.97 .12285 Mdot
.97 .1233 Mdot
.97 .1243 Mdot
.97 .12595 Mdot
.97 .12595 Mdot
.97 .12633 Mdot
.97 .1267 Mdot
.97 .12675 Mdot
.97 .12732 Mdot
.97 .12744 Mdot
.97 .12788 Mdot
.97 .12826 Mdot
.97 .13005 Mdot
.97 .13017 Mdot
.97 .13074 Mdot
.97 .1316 Mdot
.97 .13266 Mdot
.97 .13321 Mdot
.97 .13477 Mdot
.97 .13486 Mdot
.97 .13565 Mdot
.97 .13691 Mdot
.97 .13693 Mdot
.97 .13726 Mdot
.97 .13784 Mdot
.97 .14051 Mdot
.97 .14126 Mdot
.97 .14196 Mdot
.97 .14296 Mdot
.97 .14346 Mdot
.97 .14383 Mdot
.97 .14416 Mdot
.97 .14898 Mdot
.97 .15098 Mdot
.97 .15114 Mdot
.97 .15191 Mdot
.97 .15237 Mdot
.97 .15341 Mdot
.97 .15799 Mdot
.97 .15881 Mdot
.97 .15962 Mdot
.97 .15965 Mdot
.97 .15982 Mdot
.97 .16012 Mdot
.97 .16038 Mdot
.97 .16135 Mdot
.97 .16317 Mdot
.97 .16345 Mdot
.97 .16353 Mdot
.97 .16356 Mdot
.97 .16708 Mdot
.97 .1681 Mdot
.97 .16913 Mdot
.97 .16997 Mdot
.97 .1702 Mdot
.97 .1707 Mdot
.97 .17158 Mdot
.97 .17218 Mdot
.97 .1735 Mdot
.97 .17539 Mdot
.97 .17585 Mdot
.97 .17622 Mdot
.97 .17625 Mdot
.97 .17634 Mdot
.97 .17635 Mdot
.97 .17636 Mdot
.97 .17649 Mdot
.97 .17674 Mdot
.97 .1768 Mdot
.97 .17682 Mdot
.97 .17693 Mdot
.97 .17709 Mdot
.97 .17724 Mdot
.97 .17742 Mdot
.97 .17808 Mdot
.97 .17853 Mdot
.97 .17877 Mdot
.97 .17904 Mdot
.97 .17912 Mdot
.97 .17912 Mdot
.97 .17971 Mdot
.97 .18001 Mdot
.97 .18019 Mdot
.97 .18028 Mdot
.97 .18029 Mdot
.97 .1804 Mdot
.97 .1805 Mdot
.97 .18059 Mdot
.97 .18116 Mdot
.97 .18183 Mdot
.97 .18183 Mdot
.97 .18207 Mdot
.97 .18333 Mdot
.97 .18361 Mdot
.97 .1843 Mdot
.97 .18452 Mdot
.97 .1847 Mdot
.97 .18504 Mdot
.97 .18564 Mdot
.97 .18577 Mdot
.97 .18619 Mdot
.97 .18821 Mdot
.97 .1883 Mdot
.97 .18834 Mdot
.97 .18845 Mdot
.97 .18878 Mdot
.97 .18949 Mdot
.97 .19059 Mdot
.97 .19074 Mdot
.97 .19084 Mdot
.97 .19108 Mdot
.97 .19136 Mdot
.97 .19162 Mdot
.97 .19302 Mdot
.97 .19305 Mdot
.97 .19361 Mdot
.97 .19414 Mdot
.97 .19423 Mdot
.97 .19447 Mdot
.97 .19455 Mdot
.97 .19487 Mdot
.97 .19642 Mdot
.97 .19746 Mdot
.97 .19795 Mdot
.97 .19831 Mdot
.97 .19949 Mdot
.97 .20019 Mdot
.97 .20035 Mdot
.97 .20167 Mdot
.97 .20221 Mdot
.97 .20256 Mdot
.97 .20278 Mdot
.97 .20306 Mdot
.97 .20348 Mdot
.97 .20455 Mdot
.97 .2047 Mdot
.97 .20525 Mdot
.97 .20656 Mdot
.97 .20687 Mdot
.97 .20745 Mdot
.97 .20776 Mdot
.97 .20978 Mdot
.97 .21221 Mdot
.97 .2127 Mdot
.97 .21385 Mdot
.97 .21396 Mdot
.97 .21406 Mdot
.97 .21584 Mdot
.97 .21728 Mdot
.97 .21871 Mdot
.97 .21897 Mdot
.97 .21903 Mdot
.97 .21928 Mdot
.97 .22079 Mdot
.97 .22088 Mdot
.97 .22092 Mdot
.97 .22159 Mdot
.97 .22161 Mdot
.97 .22257 Mdot
.97 .22301 Mdot
.97 .2243 Mdot
.97 .22453 Mdot
.97 .22483 Mdot
.97 .2252 Mdot
.97 .22595 Mdot
.97 .22667 Mdot
.97 .22691 Mdot
.97 .2277 Mdot
.97 .22778 Mdot
.97 .2282 Mdot
.97 .22859 Mdot
.97 .2298 Mdot
.97 .23123 Mdot
.97 .2325 Mdot
.97 .23276 Mdot
.97 .23343 Mdot
.97 .23374 Mdot
.97 .23395 Mdot
.97 .23401 Mdot
.97 .23492 Mdot
.97 .23537 Mdot
.97 .23629 Mdot
.97 .23648 Mdot
.97 .23651 Mdot
.97 .23735 Mdot
.97 .23754 Mdot
.97 .23939 Mdot
.97 .23945 Mdot
.97 .23973 Mdot
.97 .23982 Mdot
.97 .24029 Mdot
.97 .24078 Mdot
.97 .24219 Mdot
.97 .24338 Mdot
.97 .24386 Mdot
.97 .2441 Mdot
.97 .24438 Mdot
.97 .24624 Mdot
.97 .24628 Mdot
.97 .247 Mdot
.97 .24742 Mdot
.97 .24753 Mdot
.97 .24758 Mdot
.97 .24759 Mdot
.97 .24787 Mdot
.97 .25015 Mdot
.97 .25031 Mdot
.97 .25065 Mdot
.97 .25138 Mdot
.97 .25316 Mdot
.97 .25362 Mdot
.97 .25427 Mdot
.97 .25559 Mdot
.97 .25595 Mdot
.97 .25646 Mdot
.97 .25744 Mdot
.97 .25766 Mdot
.97 .25868 Mdot
.97 .25964 Mdot
.97 .26046 Mdot
.97 .26046 Mdot
.97 .2616 Mdot
.97 .26336 Mdot
.97 .26421 Mdot
.97 .26427 Mdot
.97 .26448 Mdot
.97 .26471 Mdot
.97 .26819 Mdot
.97 .2686 Mdot
.97 .26997 Mdot
.97 .27047 Mdot
.97 .27156 Mdot
.97 .27348 Mdot
.97 .27707 Mdot
.97 .27713 Mdot
.97 .27744 Mdot
.97 .27788 Mdot
.97 .27886 Mdot
.97 .27897 Mdot
.97 .27984 Mdot
.97 .2815 Mdot
.97 .28233 Mdot
.97 .28253 Mdot
.97 .28397 Mdot
.97 .28449 Mdot
.97 .28457 Mdot
.97 .28597 Mdot
.97 .28639 Mdot
.97 .28733 Mdot
.97 .28861 Mdot
.97 .29072 Mdot
.97 .29307 Mdot
.97 .29345 Mdot
.97 .29438 Mdot
.97 .29543 Mdot
.97 .29611 Mdot
.97 .2975 Mdot
.97 .29795 Mdot
.97 .30141 Mdot
.97 .30161 Mdot
.97 .30269 Mdot
.97 .30308 Mdot
.97 .30336 Mdot
.97 .30396 Mdot
.97 .30614 Mdot
.97 .30619 Mdot
.97 .30634 Mdot
.97 .30765 Mdot
.97 .3089 Mdot
.97 .30967 Mdot
.97 .3103 Mdot
.97 .31037 Mdot
.97 .31094 Mdot
.97 .31217 Mdot
.97 .3125 Mdot
.97 .3131 Mdot
.97 .31537 Mdot
.97 .31599 Mdot
.97 .31628 Mdot
.97 .31654 Mdot
.97 .31674 Mdot
.97 .31731 Mdot
.97 .31804 Mdot
.97 .32047 Mdot
.97 .3208 Mdot
.97 .322 Mdot
.97 .32208 Mdot
.97 .32225 Mdot
.97 .32318 Mdot
.97 .3233 Mdot
.97 .32342 Mdot
.97 .32433 Mdot
.97 .32435 Mdot
.97 .32502 Mdot
.97 .32582 Mdot
.97 .32625 Mdot
.97 .3274 Mdot
.97 .3281 Mdot
.97 .32995 Mdot
.97 .33203 Mdot
.97 .33206 Mdot
.97 .33358 Mdot
.97 .33366 Mdot
.97 .33412 Mdot
.97 .33413 Mdot
.97 .33432 Mdot
.97 .33508 Mdot
.97 .33533 Mdot
.97 .33603 Mdot
.97 .33614 Mdot
.97 .33726 Mdot
.97 .33733 Mdot
.97 .3375 Mdot
.97 .33758 Mdot
.97 .33788 Mdot
.97 .33898 Mdot
.97 .33907 Mdot
.97 .33994 Mdot
.97 .34219 Mdot
.97 .34229 Mdot
.97 .34379 Mdot
.97 .3444 Mdot
.97 .34469 Mdot
.97 .34588 Mdot
.97 .34611 Mdot
.97 .34757 Mdot
.97 .34825 Mdot
.97 .34857 Mdot
.97 .35031 Mdot
.97 .35087 Mdot
.97 .35113 Mdot
.97 .35189 Mdot
.97 .35216 Mdot
.97 .35221 Mdot
.97 .3546 Mdot
.97 .35575 Mdot
.97 .35604 Mdot
.97 .35626 Mdot
.97 .35689 Mdot
.97 .35776 Mdot
.97 .35792 Mdot
.97 .35794 Mdot
.97 .35819 Mdot
.97 .35824 Mdot
.97 .35858 Mdot
.97 .35933 Mdot
.97 .35961 Mdot
.97 .35997 Mdot
.97 .36125 Mdot
.97 .36129 Mdot
.97 .3621 Mdot
.97 .36224 Mdot
.97 .3635 Mdot
.97 .36406 Mdot
.97 .36463 Mdot
.97 .36477 Mdot
.97 .36828 Mdot
.97 .3699 Mdot
.97 .37073 Mdot
.97 .37168 Mdot
.97 .3718 Mdot
.97 .373 Mdot
.97 .37334 Mdot
.97 .37403 Mdot
.97 .37448 Mdot
.97 .37511 Mdot
.97 .37572 Mdot
.97 .37631 Mdot
.97 .37689 Mdot
.97 .37738 Mdot
.97 .37777 Mdot
.97 .37854 Mdot
.97 .37979 Mdot
.97 .38279 Mdot
.97 .38378 Mdot
.97 .38419 Mdot
.97 .38467 Mdot
.97 .38483 Mdot
.97 .38521 Mdot
.97 .38785 Mdot
.97 .38973 Mdot
.97 .39093 Mdot
.97 .39284 Mdot
.97 .39353 Mdot
.97 .39381 Mdot
.97 .39432 Mdot
.97 .39467 Mdot
.97 .39555 Mdot
.97 .39613 Mdot
.97 .39631 Mdot
.97 .39642 Mdot
.97 .39746 Mdot
.97 .39821 Mdot
.97 .39855 Mdot
.97 .39864 Mdot
.97 .39959 Mdot
.97 .3998 Mdot
.97 .4001 Mdot
.97 .40083 Mdot
.97 .40177 Mdot
.97 .40187 Mdot
.97 .40402 Mdot
.97 .40469 Mdot
.97 .40587 Mdot
.97 .40621 Mdot
.97 .40632 Mdot
.97 .40655 Mdot
.97 .40805 Mdot
.97 .40854 Mdot
.97 .40915 Mdot
.97 .40999 Mdot
.97 .41114 Mdot
.97 .41115 Mdot
.97 .4118 Mdot
.97 .41214 Mdot
.97 .41216 Mdot
.97 .41358 Mdot
.97 .41364 Mdot
.97 .414 Mdot
.97 .41466 Mdot
.97 .41494 Mdot
.97 .41496 Mdot
.97 .41522 Mdot
.97 .4155 Mdot
.97 .41733 Mdot
.97 .41733 Mdot
.97 .41769 Mdot
.97 .41811 Mdot
.97 .41858 Mdot
.97 .41862 Mdot
.97 .41899 Mdot
.97 .41973 Mdot
.97 .421 Mdot
.97 .42123 Mdot
.97 .42184 Mdot
.97 .42201 Mdot
.97 .42208 Mdot
.97 .42265 Mdot
.97 .42292 Mdot
.97 .4234 Mdot
.97 .42343 Mdot
.97 .42344 Mdot
.97 .42376 Mdot
.97 .42487 Mdot
.97 .42587 Mdot
.97 .42775 Mdot
.97 .428 Mdot
.97 .42951 Mdot
.97 .43047 Mdot
.97 .43119 Mdot
.97 .43165 Mdot
.97 .43181 Mdot
.97 .43247 Mdot
.97 .43291 Mdot
.97 .43299 Mdot
.97 .43324 Mdot
.97 .43378 Mdot
.97 .43429 Mdot
.97 .43481 Mdot
.97 .43484 Mdot
.97 .43489 Mdot
.97 .43525 Mdot
.97 .43537 Mdot
.97 .43551 Mdot
.97 .43599 Mdot
.97 .43689 Mdot
.97 .43703 Mdot
.97 .43875 Mdot
.97 .43881 Mdot
.97 .43893 Mdot
.97 .44004 Mdot
.97 .44271 Mdot
.97 .44642 Mdot
.97 .44651 Mdot
.97 .44742 Mdot
.97 .44816 Mdot
.97 .44822 Mdot
.97 .44839 Mdot
.97 .44842 Mdot
.97 .44843 Mdot
.97 .44868 Mdot
.97 .44919 Mdot
.97 .44931 Mdot
.97 .44935 Mdot
.97 .44956 Mdot
.97 .44988 Mdot
.97 .45017 Mdot
.97 .45052 Mdot
.97 .4517 Mdot
.97 .45182 Mdot
.97 .45271 Mdot
.97 .45318 Mdot
.97 .4537 Mdot
.97 .45386 Mdot
.97 .45386 Mdot
.97 .45388 Mdot
.97 .4541 Mdot
.97 .45423 Mdot
.97 .455 Mdot
.97 .45559 Mdot
.97 .45593 Mdot
.97 .45611 Mdot
.97 .45613 Mdot
.97 .45635 Mdot
.97 .45654 Mdot
.97 .45671 Mdot
.97 .45755 Mdot
.97 .4578 Mdot
.97 .45781 Mdot
.97 .45909 Mdot
.97 .45909 Mdot
.97 .45955 Mdot
.97 .45955 Mdot
.97 .46045 Mdot
.97 .46073 Mdot
.97 .46095 Mdot
.97 .46163 Mdot
.97 .46174 Mdot
.97 .46178 Mdot
.97 .46194 Mdot
.97 .46247 Mdot
.97 .46277 Mdot
.97 .46373 Mdot
.97 .46377 Mdot
.97 .46419 Mdot
.97 .46452 Mdot
.97 .46475 Mdot
.97 .46517 Mdot
.97 .46521 Mdot
.97 .46536 Mdot
.97 .4662 Mdot
.97 .46628 Mdot
.97 .46653 Mdot
.97 .4673 Mdot
.97 .46742 Mdot
.97 .46772 Mdot
.97 .46856 Mdot
.97 .4699 Mdot
.97 .47104 Mdot
.97 .4712 Mdot
.97 .47127 Mdot
.97 .47148 Mdot
.97 .47165 Mdot
.97 .47208 Mdot
.97 .47337 Mdot
.97 .47439 Mdot
.97 .47484 Mdot
.97 .47535 Mdot
.97 .47562 Mdot
.97 .47581 Mdot
.97 .47625 Mdot
.97 .47675 Mdot
.97 .4772 Mdot
.97 .47822 Mdot
.97 .47969 Mdot
.97 .47975 Mdot
.97 .47998 Mdot
.97 .48074 Mdot
.97 .48167 Mdot
.97 .48182 Mdot
.97 .48194 Mdot
.97 .48224 Mdot
.97 .48239 Mdot
.97 .48251 Mdot
.97 .48252 Mdot
.97 .48258 Mdot
.97 .48294 Mdot
.97 .48341 Mdot
.97 .48388 Mdot
.97 .48487 Mdot
.97 .48498 Mdot
.97 .48529 Mdot
.97 .48562 Mdot
.97 .48633 Mdot
.97 .48673 Mdot
.97 .48741 Mdot
.97 .48825 Mdot
.97 .48885 Mdot
.97 .48889 Mdot
.97 .49014 Mdot
.97 .49077 Mdot
.97 .49084 Mdot
.97 .49086 Mdot
.97 .49163 Mdot
.97 .49203 Mdot
.97 .49229 Mdot
.97 .49232 Mdot
.97 .49292 Mdot
.97 .49294 Mdot
.97 .49448 Mdot
.97 .49537 Mdot
.97 .49595 Mdot
.97 .49596 Mdot
.97 .49631 Mdot
.97 .49641 Mdot
.97 .49677 Mdot
.97 .49684 Mdot
.97 .49687 Mdot
.97 .49733 Mdot
.97 .49746 Mdot
.97 .4984 Mdot
.97 .49898 Mdot
.97 .49908 Mdot
.97 .4992 Mdot
.97 .49944 Mdot
.97 .50031 Mdot
.97 .50136 Mdot
.97 .50139 Mdot
.97 .50192 Mdot
.97 .5024 Mdot
.97 .5029 Mdot
.97 .50296 Mdot
.97 .50298 Mdot
.97 .50381 Mdot
.97 .50429 Mdot
.97 .50478 Mdot
.97 .50609 Mdot
.97 .50704 Mdot
.97 .50744 Mdot
.97 .50778 Mdot
.97 .51008 Mdot
.97 .51043 Mdot
.97 .51059 Mdot
.97 .51111 Mdot
.97 .51114 Mdot
.97 .51187 Mdot
.97 .51287 Mdot
.97 .51359 Mdot
.97 .51375 Mdot
.97 .51387 Mdot
.97 .51389 Mdot
.97 .5165 Mdot
.97 .51701 Mdot
.97 .51715 Mdot
.97 .51851 Mdot
.97 .51859 Mdot
.97 .51956 Mdot
.97 .51998 Mdot
.97 .52028 Mdot
.97 .52062 Mdot
.97 .52099 Mdot
.97 .52107 Mdot
.97 .52143 Mdot
.97 .52161 Mdot
.97 .52174 Mdot
.97 .52222 Mdot
.97 .52327 Mdot
.97 .52353 Mdot
.97 .52365 Mdot
.97 .52371 Mdot
.97 .52463 Mdot
.97 .52465 Mdot
.97 .52469 Mdot
.97 .52484 Mdot
.97 .5251 Mdot
.97 .52588 Mdot
.97 .52597 Mdot
.97 .52657 Mdot
.97 .52707 Mdot
.97 .52754 Mdot
.97 .52823 Mdot
.97 .52829 Mdot
.97 .52859 Mdot
.97 .5286 Mdot
.97 .529 Mdot
.97 .52948 Mdot
.97 .5295 Mdot
.97 .53047 Mdot
.97 .5314 Mdot
.97 .53172 Mdot
.97 .532 Mdot
.97 .53273 Mdot
.97 .53284 Mdot
.97 .53337 Mdot
.97 .53353 Mdot
.97 .53387 Mdot
.97 .53539 Mdot
.97 .5359 Mdot
.97 .53717 Mdot
.97 .53872 Mdot
.97 .53903 Mdot
.97 .53914 Mdot
.97 .5396 Mdot
.97 .53979 Mdot
.97 .53984 Mdot
.97 .54021 Mdot
.97 .54036 Mdot
.97 .54045 Mdot
.97 .54053 Mdot
.97 .54084 Mdot
.97 .5416 Mdot
.97 .54201 Mdot
.97 .54213 Mdot
.97 .5432 Mdot
.97 .54342 Mdot
.97 .54345 Mdot
.97 .54441 Mdot
.97 .54462 Mdot
.97 .54545 Mdot
.97 .5467 Mdot
.97 .54676 Mdot
.97 .54684 Mdot
.97 .54708 Mdot
.97 .54717 Mdot
.97 .54769 Mdot
.97 .54769 Mdot
.97 .54811 Mdot
.97 .54822 Mdot
.97 .54864 Mdot
.97 .54926 Mdot
.97 .54974 Mdot
.97 .54989 Mdot
.97 .55054 Mdot
.97 .55099 Mdot
.97 .5512 Mdot
.97 .55149 Mdot
.97 .55167 Mdot
.97 .55175 Mdot
.97 .55203 Mdot
.97 .55238 Mdot
.97 .55273 Mdot
.97 .55393 Mdot
.97 .55394 Mdot
.97 .55397 Mdot
.97 .55406 Mdot
.97 .55468 Mdot
.97 .55501 Mdot
.97 .5551 Mdot
.97 .5552 Mdot
.97 .55526 Mdot
.97 .55526 Mdot
.97 .55554 Mdot
.97 .55582 Mdot
.97 .55737 Mdot
.97 .55772 Mdot
.97 .55788 Mdot
.97 .55814 Mdot
.97 .55819 Mdot
.97 .55887 Mdot
.97 .56049 Mdot
.97 .5606 Mdot
.97 .56073 Mdot
.97 .5609 Mdot
.97 .56123 Mdot
.97 .56147 Mdot
.97 .56172 Mdot
.97 .56262 Mdot
.97 .56281 Mdot
.97 .56293 Mdot
.97 .56293 Mdot
.97 .56335 Mdot
.97 .56362 Mdot
.97 .56365 Mdot
.97 .56417 Mdot
.97 .56436 Mdot
.97 .56471 Mdot
.97 .565 Mdot
.97 .56519 Mdot
.97 .56523 Mdot
.97 .56583 Mdot
.97 .56596 Mdot
.97 .56611 Mdot
.97 .56615 Mdot
.97 .56634 Mdot
.97 .56635 Mdot
.97 .56648 Mdot
.97 .5666 Mdot
.97 .56661 Mdot
.97 .56716 Mdot
.97 .56749 Mdot
.97 .56764 Mdot
.97 .5678 Mdot
.97 .56803 Mdot
.97 .5688 Mdot
.97 .56888 Mdot
.97 .56942 Mdot
.97 .56947 Mdot
.97 .56962 Mdot
.97 .56979 Mdot
.97 .57059 Mdot
.97 .57062 Mdot
.97 .57081 Mdot
.97 .57133 Mdot
.97 .5715 Mdot
.97 .57188 Mdot
.97 .57218 Mdot
.97 .57244 Mdot
.97 .57302 Mdot
.97 .57322 Mdot
.97 .57332 Mdot
.97 .57363 Mdot
.97 .57365 Mdot
.97 .57431 Mdot
.97 .57454 Mdot
.97 .57467 Mdot
.97 .57537 Mdot
.97 .57544 Mdot
.97 .57554 Mdot
.97 .57589 Mdot
.97 .57671 Mdot
.97 .57676 Mdot
.97 .5774 Mdot
.97 .57743 Mdot
.97 .57759 Mdot
.97 .57781 Mdot
.97 .57793 Mdot
.97 .5783 Mdot
.97 .57835 Mdot
.97 .57836 Mdot
.97 .5784 Mdot
.97 .57877 Mdot
.97 .57893 Mdot
.97 .57907 Mdot
.97 .5791 Mdot
.97 .57918 Mdot
.97 .57921 Mdot
.97 .57953 Mdot
.97 .57972 Mdot
.97 .57977 Mdot
.97 .5799 Mdot
.97 .57998 Mdot
.97 .58007 Mdot
.97 .58017 Mdot
.97 .58049 Mdot
.97 .58057 Mdot
.97 .58057 Mdot
.97 .58058 Mdot
.97 .58076 Mdot
.97 .58079 Mdot
.97 .58079 Mdot
.97 .58082 Mdot
.97 .58136 Mdot
.97 .58138 Mdot
.97 .58139 Mdot
.97 .58152 Mdot
.97 .58186 Mdot
.97 .58213 Mdot
.97 .5823 Mdot
.97 .58273 Mdot
.97 .58294 Mdot
.97 .58296 Mdot
.97 .58327 Mdot
.97 .58339 Mdot
.97 .58361 Mdot
.97 .58361 Mdot
.97 .58371 Mdot
.97 .58378 Mdot
.97 .58378 Mdot
.97 .58394 Mdot
.97 .584 Mdot
.97 .58403 Mdot
.97 .58406 Mdot
.97 .58418 Mdot
.97 .58426 Mdot
.97 .5843 Mdot
.97 .58432 Mdot
.97 .58433 Mdot
.97 .58456 Mdot
.97 .5846 Mdot
.97 .58462 Mdot
.97 .58469 Mdot
.97 .58502 Mdot
.97 .58513 Mdot
.97 .5852 Mdot
.97 .58521 Mdot
.97 .58522 Mdot
.97 .58524 Mdot
.97 .58526 Mdot
.97 .58529 Mdot
.97 .58536 Mdot
.97 .58536 Mdot
.97 .5854 Mdot
.97 .58542 Mdot
.97 .58547 Mdot
.97 .58555 Mdot
.97 .58559 Mdot
.97 .5856 Mdot
.97 .58562 Mdot
.97 .58562 Mdot
.97 .58563 Mdot
.97 .58565 Mdot
.97 .58567 Mdot
.97 .58567 Mdot
.97 .58567 Mdot
.97 .58568 Mdot
.97 .58568 Mdot
.972 .06499 Mdot
.972 .06501 Mdot
.972 .06504 Mdot
.972 .06505 Mdot
.972 .06507 Mdot
.972 .06517 Mdot
.972 .06517 Mdot
.972 .06519 Mdot
.972 .06527 Mdot
.972 .0653 Mdot
.972 .06542 Mdot
.972 .06571 Mdot
.972 .06575 Mdot
.972 .06579 Mdot
.972 .066 Mdot
.972 .06638 Mdot
.972 .0665 Mdot
.972 .06673 Mdot
.972 .06677 Mdot
.972 .06705 Mdot
.972 .06737 Mdot
.972 .06738 Mdot
.972 .06787 Mdot
.972 .06843 Mdot
.972 .06865 Mdot
.972 .06893 Mdot
.972 .06931 Mdot
.972 .06974 Mdot
.972 .07046 Mdot
.972 .07131 Mdot
.972 .07156 Mdot
.972 .07176 Mdot
.972 .07186 Mdot
.972 .07205 Mdot
.972 .07234 Mdot
.972 .07239 Mdot
.972 .07315 Mdot
.972 .07327 Mdot
.972 .07347 Mdot
.972 .07365 Mdot
.972 .07372 Mdot
.972 .07396 Mdot
.972 .07419 Mdot
.972 .07555 Mdot
.972 .07558 Mdot
.972 .0756 Mdot
.972 .0764 Mdot
.972 .07673 Mdot
.972 .0768 Mdot
.972 .07691 Mdot
.972 .07859 Mdot
.972 .07991 Mdot
.972 .08007 Mdot
.972 .08099 Mdot
.972 .08106 Mdot
.972 .0823 Mdot
.972 .08335 Mdot
.972 .08444 Mdot
.972 .08496 Mdot
.972 .08524 Mdot
.972 .08538 Mdot
.972 .08567 Mdot
.972 .08573 Mdot
.972 .08595 Mdot
.972 .08647 Mdot
.972 .08766 Mdot
.972 .08926 Mdot
.972 .08981 Mdot
.972 .0917 Mdot
.972 .09201 Mdot
.972 .09289 Mdot
.972 .0934 Mdot
.972 .09502 Mdot
.972 .09504 Mdot
.972 .09538 Mdot
.972 .09575 Mdot
.972 .09594 Mdot
.972 .09638 Mdot
.972 .09708 Mdot
.972 .09725 Mdot
.972 .1028 Mdot
.972 .10288 Mdot
.972 .10405 Mdot
.972 .10519 Mdot
.972 .1054 Mdot
.972 .10771 Mdot
.972 .10813 Mdot
.972 .11117 Mdot
.972 .11147 Mdot
.972 .11309 Mdot
.972 .11377 Mdot
.972 .11465 Mdot
.972 .11621 Mdot
.972 .11655 Mdot
.972 .11661 Mdot
.972 .11733 Mdot
.972 .11896 Mdot
.972 .1201 Mdot
.972 .12263 Mdot
.972 .12505 Mdot
.972 .12655 Mdot
.972 .12702 Mdot
.972 .12818 Mdot
.972 .1288 Mdot
.972 .13132 Mdot
.972 .13133 Mdot
.972 .133 Mdot
.972 .13337 Mdot
.972 .13395 Mdot
.972 .13445 Mdot
.972 .13551 Mdot
.972 .13615 Mdot
.972 .13657 Mdot
.972 .13699 Mdot
.972 .13707 Mdot
.972 .13748 Mdot
.972 .13863 Mdot
.972 .13892 Mdot
.972 .14016 Mdot
.972 .141 Mdot
.972 .14171 Mdot
.972 .142 Mdot
.972 .14257 Mdot
.972 .1427 Mdot
.972 .14286 Mdot
.972 .14436 Mdot
.972 .14527 Mdot
.972 .14628 Mdot
.972 .1468 Mdot
.972 .14777 Mdot
.972 .14905 Mdot
.972 .14909 Mdot
.972 .1516 Mdot
.972 .15164 Mdot
.972 .15423 Mdot
.972 .1547 Mdot
.972 .1555 Mdot
.972 .15589 Mdot
.972 .15808 Mdot
.972 .15967 Mdot
.972 .16048 Mdot
.972 .16054 Mdot
.972 .16227 Mdot
.972 .16236 Mdot
.972 .16356 Mdot
.972 .16433 Mdot
.972 .16458 Mdot
.972 .16564 Mdot
.972 .16565 Mdot
.972 .1664 Mdot
.972 .16647 Mdot
.972 .16655 Mdot
.972 .16659 Mdot
.972 .16664 Mdot
.972 .16692 Mdot
.972 .16694 Mdot
.972 .16698 Mdot
.972 .16703 Mdot
.972 .16721 Mdot
.972 .16732 Mdot
.972 .16767 Mdot
.972 .16774 Mdot
.972 .16851 Mdot
.972 .16865 Mdot
.972 .16876 Mdot
.972 .16924 Mdot
.972 .16937 Mdot
.972 .16967 Mdot
.972 .1699 Mdot
.972 .17049 Mdot
.972 .17084 Mdot
.972 .1713 Mdot
.972 .17153 Mdot
.972 .17163 Mdot
.972 .17189 Mdot
.972 .17218 Mdot
.972 .17247 Mdot
.972 .17288 Mdot
.972 .17339 Mdot
.972 .17341 Mdot
.972 .17404 Mdot
.972 .17444 Mdot
.972 .17486 Mdot
.972 .17651 Mdot
.972 .17714 Mdot
.972 .17725 Mdot
.972 .17758 Mdot
.972 .17796 Mdot
.972 .17885 Mdot
.972 .17907 Mdot
.972 .18034 Mdot
.972 .18244 Mdot
.972 .18354 Mdot
.972 .18432 Mdot
.972 .18491 Mdot
.972 .18493 Mdot
.972 .18539 Mdot
.972 .18564 Mdot
.972 .18592 Mdot
.972 .18622 Mdot
.972 .18652 Mdot
.972 .18659 Mdot
.972 .18708 Mdot
.972 .1878 Mdot
.972 .18791 Mdot
.972 .18796 Mdot
.972 .18805 Mdot
.972 .18974 Mdot
.972 .19029 Mdot
.972 .19034 Mdot
.972 .19061 Mdot
.972 .1912 Mdot
.972 .19172 Mdot
.972 .19173 Mdot
.972 .19194 Mdot
.972 .19254 Mdot
.972 .19256 Mdot
.972 .19262 Mdot
.972 .19311 Mdot
.972 .19331 Mdot
.972 .19619 Mdot
.972 .19635 Mdot
.972 .19723 Mdot
.972 .19732 Mdot
.972 .19738 Mdot
.972 .19948 Mdot
.972 .19971 Mdot
.972 .20054 Mdot
.972 .20065 Mdot
.972 .20084 Mdot
.972 .20117 Mdot
.972 .20123 Mdot
.972 .20129 Mdot
.972 .20135 Mdot
.972 .20182 Mdot
.972 .20221 Mdot
.972 .2026 Mdot
.972 .2034 Mdot
.972 .20341 Mdot
.972 .20372 Mdot
.972 .20474 Mdot
.972 .20505 Mdot
.972 .20508 Mdot
.972 .20602 Mdot
.972 .2064 Mdot
.972 .20728 Mdot
.972 .20776 Mdot
.972 .20866 Mdot
.972 .20981 Mdot
.972 .21012 Mdot
.972 .21015 Mdot
.972 .21025 Mdot
.972 .211 Mdot
.972 .21168 Mdot
.972 .2127 Mdot
.972 .21289 Mdot
.972 .21309 Mdot
.972 .21391 Mdot
.972 .21423 Mdot
.972 .21592 Mdot
.972 .21597 Mdot
.972 .21665 Mdot
.972 .21928 Mdot
.972 .21966 Mdot
.972 .22129 Mdot
.972 .22274 Mdot
.972 .22285 Mdot
.972 .22334 Mdot
.972 .22357 Mdot
.972 .22373 Mdot
.972 .22424 Mdot
.972 .22463 Mdot
.972 .22464 Mdot
.972 .22502 Mdot
.972 .22513 Mdot
.972 .22542 Mdot
.972 .22559 Mdot
.972 .22626 Mdot
.972 .22643 Mdot
.972 .22691 Mdot
.972 .22704 Mdot
.972 .22753 Mdot
.972 .22796 Mdot
.972 .22851 Mdot
.972 .22944 Mdot
.972 .23 Mdot
.972 .23062 Mdot
.972 .23173 Mdot
.972 .23187 Mdot
.972 .23212 Mdot
.972 .23357 Mdot
.972 .23361 Mdot
.972 .23411 Mdot
.972 .23508 Mdot
.972 .2364 Mdot
.972 .23699 Mdot
.972 .23758 Mdot
.972 .23794 Mdot
.972 .23845 Mdot
.972 .23864 Mdot
.972 .24032 Mdot
.972 .24072 Mdot
.972 .24272 Mdot
.972 .24324 Mdot
.972 .2441 Mdot
.972 .24525 Mdot
.972 .24565 Mdot
.972 .24628 Mdot
.972 .24656 Mdot
.972 .24798 Mdot
.972 .24842 Mdot
.972 .25023 Mdot
.972 .25071 Mdot
.972 .25161 Mdot
.972 .2525 Mdot
.972 .25256 Mdot
.972 .25261 Mdot
.972 .25351 Mdot
.972 .25398 Mdot
.972 .25409 Mdot
.972 .25453 Mdot
.972 .25504 Mdot
.972 .25627 Mdot
.972 .2582 Mdot
.972 .25868 Mdot
.972 .25887 Mdot
.972 .26052 Mdot
.972 .26283 Mdot
.972 .26318 Mdot
.972 .26444 Mdot
.972 .26713 Mdot
.972 .26733 Mdot
.972 .26859 Mdot
.972 .27283 Mdot
.972 .27369 Mdot
.972 .2739 Mdot
.972 .2741 Mdot
.972 .27412 Mdot
.972 .27539 Mdot
.972 .2773 Mdot
.972 .27872 Mdot
.972 .27953 Mdot
.972 .27988 Mdot
.972 .28004 Mdot
.972 .28029 Mdot
.972 .28039 Mdot
.972 .28096 Mdot
.972 .28358 Mdot
.972 .28432 Mdot
.972 .28445 Mdot
.972 .28717 Mdot
.972 .28723 Mdot
.972 .28831 Mdot
.972 .29031 Mdot
.972 .29073 Mdot
.972 .29085 Mdot
.972 .29213 Mdot
.972 .29273 Mdot
.972 .29516 Mdot
.972 .2964 Mdot
.972 .29686 Mdot
.972 .29722 Mdot
.972 .30061 Mdot
.972 .30151 Mdot
.972 .30262 Mdot
.972 .3033 Mdot
.972 .30344 Mdot
.972 .30361 Mdot
.972 .30562 Mdot
.972 .30627 Mdot
.972 .3071 Mdot
.972 .30785 Mdot
.972 .3097 Mdot
.972 .3106 Mdot
.972 .31076 Mdot
.972 .31182 Mdot
.972 .31194 Mdot
.972 .31263 Mdot
.972 .31325 Mdot
.972 .31686 Mdot
.972 .31753 Mdot
.972 .31818 Mdot
.972 .31885 Mdot
.972 .31886 Mdot
.972 .31983 Mdot
.972 .32225 Mdot
.972 .32391 Mdot
.972 .32501 Mdot
.972 .32557 Mdot
.972 .3257 Mdot
.972 .32627 Mdot
.972 .32633 Mdot
.972 .32755 Mdot
.972 .32782 Mdot
.972 .32808 Mdot
.972 .32833 Mdot
.972 .3297 Mdot
.972 .32973 Mdot
.972 .33052 Mdot
.972 .33099 Mdot
.972 .3325 Mdot
.972 .33453 Mdot
.972 .33551 Mdot
.972 .3363 Mdot
.972 .33748 Mdot
.972 .33798 Mdot
.972 .3404 Mdot
.972 .34195 Mdot
.972 .34214 Mdot
.972 .34298 Mdot
.972 .34447 Mdot
.972 .34473 Mdot
.972 .34513 Mdot
.972 .34824 Mdot
.972 .34827 Mdot
.972 .34888 Mdot
.972 .34957 Mdot
.972 .35239 Mdot
.972 .35254 Mdot
.972 .3533 Mdot
.972 .35402 Mdot
.972 .35473 Mdot
.972 .35491 Mdot
.972 .35595 Mdot
.972 .35645 Mdot
.972 .35856 Mdot
.972 .36011 Mdot
.972 .36112 Mdot
.972 .36113 Mdot
.972 .36194 Mdot
.972 .36216 Mdot
.972 .36236 Mdot
.972 .36277 Mdot
.972 .36318 Mdot
.972 .36335 Mdot
.972 .36338 Mdot
.972 .36486 Mdot
.972 .36513 Mdot
.972 .36524 Mdot
.972 .36611 Mdot
.972 .36681 Mdot
.972 .367 Mdot
.972 .36781 Mdot
.972 .36871 Mdot
.972 .36873 Mdot
.972 .3698 Mdot
.972 .37021 Mdot
.972 .37096 Mdot
.972 .3718 Mdot
.972 .37238 Mdot
.972 .37307 Mdot
.972 .37315 Mdot
.972 .3735 Mdot
.972 .3735 Mdot
.972 .37419 Mdot
.972 .37468 Mdot
.972 .37489 Mdot
.972 .37553 Mdot
.972 .37585 Mdot
.972 .37622 Mdot
.972 .37634 Mdot
.972 .37723 Mdot
.972 .37918 Mdot
.972 .37975 Mdot
.972 .37991 Mdot
.972 .38053 Mdot
.972 .38125 Mdot
.972 .3819 Mdot
.972 .38191 Mdot
.972 .38207 Mdot
.972 .38303 Mdot
.972 .38425 Mdot
.972 .38447 Mdot
.972 .38462 Mdot
.972 .38474 Mdot
.972 .38485 Mdot
.972 .38508 Mdot
.972 .38508 Mdot
.972 .38517 Mdot
.972 .38546 Mdot
.972 .38555 Mdot
.972 .38556 Mdot
.972 .38658 Mdot
.972 .38699 Mdot
.972 .387 Mdot
.972 .38724 Mdot
.972 .38772 Mdot
.972 .38815 Mdot
.972 .38863 Mdot
.972 .39066 Mdot
.972 .39073 Mdot
.972 .39077 Mdot
.972 .39101 Mdot
.972 .39128 Mdot
.972 .39192 Mdot
.972 .39232 Mdot
.972 .39357 Mdot
.972 .39477 Mdot
.972 .39584 Mdot
.972 .3965 Mdot
.972 .3966 Mdot
.972 .39732 Mdot
.972 .39779 Mdot
.972 .39791 Mdot
.972 .39815 Mdot
.972 .39875 Mdot
.972 .4 Mdot
.972 .40042 Mdot
.972 .401 Mdot
.972 .40109 Mdot
.972 .40245 Mdot
.972 .40351 Mdot
.972 .40372 Mdot
.972 .40526 Mdot
.972 .40529 Mdot
.972 .40616 Mdot
.972 .40635 Mdot
.972 .40839 Mdot
.972 .40898 Mdot
.972 .41098 Mdot
.972 .41102 Mdot
.972 .41185 Mdot
.972 .41449 Mdot
.972 .41611 Mdot
.972 .41627 Mdot
.972 .41641 Mdot
.972 .41722 Mdot
.972 .41916 Mdot
.972 .42013 Mdot
.972 .42033 Mdot
.972 .42256 Mdot
.972 .42291 Mdot
.972 .42311 Mdot
.972 .42347 Mdot
.972 .42456 Mdot
.972 .42504 Mdot
.972 .42509 Mdot
.972 .42593 Mdot
.972 .42668 Mdot
.972 .42719 Mdot
.972 .42735 Mdot
.972 .42736 Mdot
.972 .42811 Mdot
.972 .42877 Mdot
.972 .42894 Mdot
.972 .42909 Mdot
.972 .42925 Mdot
.972 .42933 Mdot
.972 .42941 Mdot
.972 .42945 Mdot
.972 .42967 Mdot
.972 .43004 Mdot
.972 .43007 Mdot
.972 .43015 Mdot
.972 .43017 Mdot
.972 .43026 Mdot
.972 .4305 Mdot
.972 .4306 Mdot
.972 .4306 Mdot
.972 .43065 Mdot
.972 .43087 Mdot
.972 .4316 Mdot
.972 .43175 Mdot
.972 .43301 Mdot
.972 .43321 Mdot
.972 .43335 Mdot
.972 .43364 Mdot
.972 .43388 Mdot
.972 .4339 Mdot
.972 .43488 Mdot
.972 .43514 Mdot
.972 .43576 Mdot
.972 .43623 Mdot
.972 .43644 Mdot
.972 .43745 Mdot
.972 .43818 Mdot
.972 .43912 Mdot
.972 .43958 Mdot
.972 .4398 Mdot
.972 .43998 Mdot
.972 .44032 Mdot
.972 .44063 Mdot
.972 .4407 Mdot
.972 .4409 Mdot
.972 .44092 Mdot
.972 .4415 Mdot
.972 .44172 Mdot
.972 .44233 Mdot
.972 .44336 Mdot
.972 .44337 Mdot
.972 .44342 Mdot
.972 .44468 Mdot
.972 .44548 Mdot
.972 .44589 Mdot
.972 .44599 Mdot
.972 .44602 Mdot
.972 .44634 Mdot
.972 .44806 Mdot
.972 .44929 Mdot
.972 .44962 Mdot
.972 .44971 Mdot
.972 .45087 Mdot
.972 .45087 Mdot
.972 .45092 Mdot
.972 .45108 Mdot
.972 .45131 Mdot
.972 .45144 Mdot
.972 .45174 Mdot
.972 .45205 Mdot
.972 .45249 Mdot
.972 .45273 Mdot
.972 .45308 Mdot
.972 .4535 Mdot
.972 .45423 Mdot
.972 .4544 Mdot
.972 .45466 Mdot
.972 .45624 Mdot
.972 .45714 Mdot
.972 .45765 Mdot
.972 .4596 Mdot
.972 .45999 Mdot
.972 .4609 Mdot
.972 .46116 Mdot
.972 .46209 Mdot
.972 .46257 Mdot
.972 .46326 Mdot
.972 .46443 Mdot
.972 .46447 Mdot
.972 .46473 Mdot
.972 .46492 Mdot
.972 .46547 Mdot
.972 .46574 Mdot
.972 .46584 Mdot
.972 .46589 Mdot
.972 .4661 Mdot
.972 .46675 Mdot
.972 .46722 Mdot
.972 .46775 Mdot
.972 .46829 Mdot
.972 .46847 Mdot
.972 .46875 Mdot
.972 .46886 Mdot
.972 .46898 Mdot
.972 .46989 Mdot
.972 .4701 Mdot
.972 .47049 Mdot
.972 .4706 Mdot
.972 .4706 Mdot
.972 .47078 Mdot
.972 .47122 Mdot
.972 .47122 Mdot
.972 .47138 Mdot
.972 .47142 Mdot
.972 .47142 Mdot
.972 .47152 Mdot
.972 .47157 Mdot
.972 .47162 Mdot
.972 .47169 Mdot
.972 .4723 Mdot
.972 .47271 Mdot
.972 .47278 Mdot
.972 .47307 Mdot
.972 .47337 Mdot
.972 .47363 Mdot
.972 .47394 Mdot
.972 .47477 Mdot
.972 .47515 Mdot
.972 .47576 Mdot
.972 .47585 Mdot
.972 .47635 Mdot
.972 .47649 Mdot
.972 .47653 Mdot
.972 .47682 Mdot
.972 .47741 Mdot
.972 .47772 Mdot
.972 .47834 Mdot
.972 .47835 Mdot
.972 .47873 Mdot
.972 .47906 Mdot
.972 .47979 Mdot
.972 .47984 Mdot
.972 .47995 Mdot
.972 .48056 Mdot
.972 .48064 Mdot
.972 .48081 Mdot
.972 .48116 Mdot
.972 .48149 Mdot
.972 .48341 Mdot
.972 .48404 Mdot
.972 .4844 Mdot
.972 .485 Mdot
.972 .4862 Mdot
.972 .48648 Mdot
.972 .48799 Mdot
.972 .48815 Mdot
.972 .48825 Mdot
.972 .48885 Mdot
.972 .48919 Mdot
.972 .49084 Mdot
.972 .49182 Mdot
.972 .49221 Mdot
.972 .4936 Mdot
.972 .49379 Mdot
.972 .4941 Mdot
.972 .49411 Mdot
.972 .49465 Mdot
.972 .49474 Mdot
.972 .49484 Mdot
.972 .49495 Mdot
.972 .49545 Mdot
.972 .49567 Mdot
.972 .49572 Mdot
.972 .49594 Mdot
.972 .49637 Mdot
.972 .49702 Mdot
.972 .49833 Mdot
.972 .49833 Mdot
.972 .49859 Mdot
.972 .49884 Mdot
.972 .50049 Mdot
.972 .50099 Mdot
.972 .50104 Mdot
.972 .50256 Mdot
.972 .50284 Mdot
.972 .50316 Mdot
.972 .50417 Mdot
.972 .50423 Mdot
.972 .50455 Mdot
.972 .5053 Mdot
.972 .50672 Mdot
.972 .50736 Mdot
.972 .50827 Mdot
.972 .5085 Mdot
.972 .50897 Mdot
.972 .50902 Mdot
.972 .50918 Mdot
.972 .51033 Mdot
.972 .51136 Mdot
.972 .51141 Mdot
.972 .51168 Mdot
.972 .5129 Mdot
.972 .51299 Mdot
.972 .51305 Mdot
.972 .51318 Mdot
.972 .51348 Mdot
.972 .51471 Mdot
.972 .51518 Mdot
.972 .51533 Mdot
.972 .51565 Mdot
.972 .5172 Mdot
.972 .51766 Mdot
.972 .51774 Mdot
.972 .51871 Mdot
.972 .51917 Mdot
.972 .5193 Mdot
.972 .52014 Mdot
.972 .52074 Mdot
.972 .52246 Mdot
.972 .5225 Mdot
.972 .523 Mdot
.972 .52336 Mdot
.972 .52368 Mdot
.972 .52385 Mdot
.972 .5245 Mdot
.972 .52527 Mdot
.972 .5255 Mdot
.972 .52564 Mdot
.972 .52654 Mdot
.972 .52726 Mdot
.972 .5274 Mdot
.972 .528 Mdot
.972 .52807 Mdot
.972 .52838 Mdot
.972 .52858 Mdot
.972 .52926 Mdot
.972 .52961 Mdot
.972 .52979 Mdot
.972 .5298 Mdot
.972 .53031 Mdot
.972 .53045 Mdot
.972 .53084 Mdot
.972 .53106 Mdot
.972 .53126 Mdot
.972 .53178 Mdot
.972 .53193 Mdot
.972 .53215 Mdot
.972 .53262 Mdot
.972 .53278 Mdot
.972 .53295 Mdot
.972 .53296 Mdot
.972 .53327 Mdot
.972 .53333 Mdot
.972 .53341 Mdot
.972 .53358 Mdot
.972 .53413 Mdot
.972 .53484 Mdot
.972 .53599 Mdot
.972 .53601 Mdot
.972 .5366 Mdot
.972 .53671 Mdot
.972 .53714 Mdot
.972 .53749 Mdot
.972 .53773 Mdot
.972 .53803 Mdot
.972 .53804 Mdot
.972 .53854 Mdot
.972 .53886 Mdot
.972 .53903 Mdot
.972 .53933 Mdot
.972 .53979 Mdot
.972 .5398 Mdot
.972 .53991 Mdot
.972 .54026 Mdot
.972 .54037 Mdot
.972 .54037 Mdot
.972 .54065 Mdot
.972 .54079 Mdot
.972 .54092 Mdot
.972 .54108 Mdot
.972 .54111 Mdot
.972 .54113 Mdot
.972 .54136 Mdot
.972 .54173 Mdot
.972 .54281 Mdot
.972 .54287 Mdot
.972 .54393 Mdot
.972 .54412 Mdot
.972 .54413 Mdot
.972 .54441 Mdot
.972 .54489 Mdot
.972 .54509 Mdot
.972 .5457 Mdot
.972 .54576 Mdot
.972 .54617 Mdot
.972 .5464 Mdot
.972 .54659 Mdot
.972 .54674 Mdot
.972 .54695 Mdot
.972 .54722 Mdot
.972 .54883 Mdot
.972 .54926 Mdot
.972 .54937 Mdot
.972 .55033 Mdot
.972 .55047 Mdot
.972 .55086 Mdot
.972 .5512 Mdot
.972 .5514 Mdot
.972 .55188 Mdot
.972 .55196 Mdot
.972 .5521 Mdot
.972 .55261 Mdot
.972 .55285 Mdot
.972 .55332 Mdot
.972 .55332 Mdot
.972 .55369 Mdot
.972 .55377 Mdot
.972 .55403 Mdot
.972 .55444 Mdot
.972 .55447 Mdot
.972 .55505 Mdot
.972 .55507 Mdot
.972 .55535 Mdot
.972 .55589 Mdot
.972 .55663 Mdot
.972 .55676 Mdot
.972 .55703 Mdot
.972 .55719 Mdot
.972 .55806 Mdot
.972 .55808 Mdot
.972 .55892 Mdot
.972 .55894 Mdot
.972 .55937 Mdot
.972 .55969 Mdot
.972 .55987 Mdot
.972 .56021 Mdot
.972 .56052 Mdot
.972 .56102 Mdot
.972 .56107 Mdot
.972 .56112 Mdot
.972 .56131 Mdot
.972 .5614 Mdot
.972 .56164 Mdot
.972 .56192 Mdot
.972 .56234 Mdot
.972 .56244 Mdot
.972 .56282 Mdot
.972 .56296 Mdot
.972 .56299 Mdot
.972 .56313 Mdot
.972 .56327 Mdot
.972 .56348 Mdot
.972 .56384 Mdot
.972 .56401 Mdot
.972 .5642 Mdot
.972 .56433 Mdot
.972 .56488 Mdot
.972 .56489 Mdot
.972 .56573 Mdot
.972 .56594 Mdot
.972 .56633 Mdot
.972 .56648 Mdot
.972 .56698 Mdot
.972 .56779 Mdot
.972 .56863 Mdot
.972 .56901 Mdot
.972 .56956 Mdot
.972 .56979 Mdot
.972 .56981 Mdot
.972 .56993 Mdot
.972 .57045 Mdot
.972 .57074 Mdot
.972 .57096 Mdot
.972 .5715 Mdot
.972 .57161 Mdot
.972 .57261 Mdot
.972 .57275 Mdot
.972 .57352 Mdot
.972 .57359 Mdot
.972 .57397 Mdot
.972 .57436 Mdot
.972 .57438 Mdot
.972 .57622 Mdot
.972 .57628 Mdot
.972 .57651 Mdot
.972 .57665 Mdot
.972 .57672 Mdot
.972 .57684 Mdot
.972 .57695 Mdot
.972 .57696 Mdot
.972 .57749 Mdot
.972 .57766 Mdot
.972 .57795 Mdot
.972 .57805 Mdot
.972 .57868 Mdot
.972 .57886 Mdot
.972 .57939 Mdot
.972 .57978 Mdot
.972 .57995 Mdot
.972 .58003 Mdot
.972 .58004 Mdot
.972 .58014 Mdot
.972 .58019 Mdot
.972 .58028 Mdot
.972 .58045 Mdot
.972 .58081 Mdot
.972 .58116 Mdot
.972 .58157 Mdot
.972 .58159 Mdot
.972 .58189 Mdot
.972 .58195 Mdot
.972 .58238 Mdot
.972 .58293 Mdot
.972 .58297 Mdot
.972 .58299 Mdot
.972 .5831 Mdot
.972 .58337 Mdot
.972 .58337 Mdot
.972 .58338 Mdot
.972 .58383 Mdot
.972 .58391 Mdot
.972 .58398 Mdot
.972 .58401 Mdot
.972 .58407 Mdot
.972 .58414 Mdot
.972 .58417 Mdot
.972 .58442 Mdot
.972 .58444 Mdot
.972 .58453 Mdot
.972 .5846 Mdot
.972 .58463 Mdot
.972 .5847 Mdot
.972 .58478 Mdot
.972 .58506 Mdot
.972 .58529 Mdot
.972 .58544 Mdot
.972 .58556 Mdot
.972 .58565 Mdot
.972 .58573 Mdot
.972 .58591 Mdot
.972 .58607 Mdot
.972 .58608 Mdot
.972 .58618 Mdot
.972 .58627 Mdot
.972 .58628 Mdot
.972 .58636 Mdot
.972 .5864 Mdot
.972 .58653 Mdot
.972 .58659 Mdot
.972 .58661 Mdot
.972 .58662 Mdot
.972 .58672 Mdot
.972 .58676 Mdot
.972 .58677 Mdot
.972 .58679 Mdot
.972 .5868 Mdot
.972 .5868 Mdot
.972 .58683 Mdot
.972 .58684 Mdot
.972 .58684 Mdot
.972 .58685 Mdot
.972 .58686 Mdot
.974 .0615 Mdot
.974 .0615 Mdot
.974 .0615 Mdot
.974 .06152 Mdot
.974 .06158 Mdot
.974 .06162 Mdot
.974 .06172 Mdot
.974 .06179 Mdot
.974 .06181 Mdot
.974 .06189 Mdot
.974 .06202 Mdot
.974 .06209 Mdot
.974 .0622 Mdot
.974 .06226 Mdot
.974 .0624 Mdot
.974 .06259 Mdot
.974 .06273 Mdot
.974 .0632 Mdot
.974 .06332 Mdot
.974 .06349 Mdot
.974 .06351 Mdot
.974 .06354 Mdot
.974 .06373 Mdot
.974 .06376 Mdot
.974 .06411 Mdot
.974 .06441 Mdot
.974 .06451 Mdot
.974 .06467 Mdot
.974 .06485 Mdot
.974 .06488 Mdot
.974 .0649 Mdot
.974 .06541 Mdot
.974 .06609 Mdot
.974 .06646 Mdot
.974 .06753 Mdot
.974 .06757 Mdot
.974 .06767 Mdot
.974 .06824 Mdot
.974 .06832 Mdot
.974 .06879 Mdot
.974 .06885 Mdot
.974 .06909 Mdot
.974 .06918 Mdot
.974 .06925 Mdot
.974 .06941 Mdot
.974 .06948 Mdot
.974 .07006 Mdot
.974 .07056 Mdot
.974 .0706 Mdot
.974 .07096 Mdot
.974 .07113 Mdot
.974 .07122 Mdot
.974 .07127 Mdot
.974 .07175 Mdot
.974 .07241 Mdot
.974 .0728 Mdot
.974 .07286 Mdot
.974 .07289 Mdot
.974 .07411 Mdot
.974 .07526 Mdot
.974 .07612 Mdot
.974 .07674 Mdot
.974 .07762 Mdot
.974 .0777 Mdot
.974 .07776 Mdot
.974 .07915 Mdot
.974 .0795 Mdot
.974 .07964 Mdot
.974 .08086 Mdot
.974 .08342 Mdot
.974 .08358 Mdot
.974 .08408 Mdot
.974 .08435 Mdot
.974 .08472 Mdot
.974 .08477 Mdot
.974 .08551 Mdot
.974 .08586 Mdot
.974 .08642 Mdot
.974 .08684 Mdot
.974 .08698 Mdot
.974 .08702 Mdot
.974 .08831 Mdot
.974 .09014 Mdot
.974 .09037 Mdot
.974 .09142 Mdot
.974 .09169 Mdot
.974 .09174 Mdot
.974 .09179 Mdot
.974 .09226 Mdot
.974 .09227 Mdot
.974 .0927 Mdot
.974 .09318 Mdot
.974 .09404 Mdot
.974 .09441 Mdot
.974 .09531 Mdot
.974 .09562 Mdot
.974 .09603 Mdot
.974 .09644 Mdot
.974 .09766 Mdot
.974 .09964 Mdot
.974 .10179 Mdot
.974 .10266 Mdot
.974 .10427 Mdot
.974 .10562 Mdot
.974 .10572 Mdot
.974 .10616 Mdot
.974 .1077 Mdot
.974 .11213 Mdot
.974 .11421 Mdot
.974 .11486 Mdot
.974 .11549 Mdot
.974 .11889 Mdot
.974 .11994 Mdot
.974 .12054 Mdot
.974 .12209 Mdot
.974 .12482 Mdot
.974 .12726 Mdot
.974 .12731 Mdot
.974 .12781 Mdot
.974 .12819 Mdot
.974 .12852 Mdot
.974 .12946 Mdot
.974 .13107 Mdot
.974 .13151 Mdot
.974 .134 Mdot
.974 .13527 Mdot
.974 .13633 Mdot
.974 .13648 Mdot
.974 .13681 Mdot
.974 .13851 Mdot
.974 .14065 Mdot
.974 .1425 Mdot
.974 .14306 Mdot
.974 .1447 Mdot
.974 .1457 Mdot
.974 .14597 Mdot
.974 .14974 Mdot
.974 .14985 Mdot
.974 .15288 Mdot
.974 .15288 Mdot
.974 .15521 Mdot
.974 .15638 Mdot
.974 .15639 Mdot
.974 .1564 Mdot
.974 .15645 Mdot
.974 .15662 Mdot
.974 .15674 Mdot
.974 .15684 Mdot
.974 .15706 Mdot
.974 .15726 Mdot
.974 .15726 Mdot
.974 .1573 Mdot
.974 .15754 Mdot
.974 .15792 Mdot
.974 .15814 Mdot
.974 .15832 Mdot
.974 .15847 Mdot
.974 .15848 Mdot
.974 .15864 Mdot
.974 .15889 Mdot
.974 .15904 Mdot
.974 .15954 Mdot
.974 .15962 Mdot
.974 .16004 Mdot
.974 .16041 Mdot
.974 .16051 Mdot
.974 .16142 Mdot
.974 .16178 Mdot
.974 .16227 Mdot
.974 .16233 Mdot
.974 .16243 Mdot
.974 .16298 Mdot
.974 .16308 Mdot
.974 .1641 Mdot
.974 .16448 Mdot
.974 .16498 Mdot
.974 .16499 Mdot
.974 .16531 Mdot
.974 .16535 Mdot
.974 .16578 Mdot
.974 .16581 Mdot
.974 .16608 Mdot
.974 .16631 Mdot
.974 .16638 Mdot
.974 .16646 Mdot
.974 .16762 Mdot
.974 .16771 Mdot
.974 .16796 Mdot
.974 .16895 Mdot
.974 .16936 Mdot
.974 .16959 Mdot
.974 .16994 Mdot
.974 .17075 Mdot
.974 .17106 Mdot
.974 .17111 Mdot
.974 .17168 Mdot
.974 .17181 Mdot
.974 .17194 Mdot
.974 .17264 Mdot
.974 .17269 Mdot
.974 .17418 Mdot
.974 .1743 Mdot
.974 .17459 Mdot
.974 .17504 Mdot
.974 .17528 Mdot
.974 .17627 Mdot
.974 .1765 Mdot
.974 .1771 Mdot
.974 .17788 Mdot
.974 .17806 Mdot
.974 .17841 Mdot
.974 .17878 Mdot
.974 .17904 Mdot
.974 .17917 Mdot
.974 .17923 Mdot
.974 .1797 Mdot
.974 .17993 Mdot
.974 .18025 Mdot
.974 .18162 Mdot
.974 .18308 Mdot
.974 .1832 Mdot
.974 .18425 Mdot
.974 .18474 Mdot
.974 .18499 Mdot
.974 .18501 Mdot
.974 .18515 Mdot
.974 .18654 Mdot
.974 .18741 Mdot
.974 .18774 Mdot
.974 .1878 Mdot
.974 .18847 Mdot
.974 .18963 Mdot
.974 .18974 Mdot
.974 .18976 Mdot
.974 .18979 Mdot
.974 .18989 Mdot
.974 .1922 Mdot
.974 .19343 Mdot
.974 .19468 Mdot
.974 .19573 Mdot
.974 .19658 Mdot
.974 .19678 Mdot
.974 .1973 Mdot
.974 .19792 Mdot
.974 .19819 Mdot
.974 .19871 Mdot
.974 .19926 Mdot
.974 .20024 Mdot
.974 .20049 Mdot
.974 .20068 Mdot
.974 .20105 Mdot
.974 .20315 Mdot
.974 .2036 Mdot
.974 .20384 Mdot
.974 .204 Mdot
.974 .20803 Mdot
.974 .20901 Mdot
.974 .20936 Mdot
.974 .20943 Mdot
.974 .20952 Mdot
.974 .20982 Mdot
.974 .21027 Mdot
.974 .21065 Mdot
.974 .21119 Mdot
.974 .21288 Mdot
.974 .21295 Mdot
.974 .21388 Mdot
.974 .21449 Mdot
.974 .2155 Mdot
.974 .21662 Mdot
.974 .21915 Mdot
.974 .22025 Mdot
.974 .22073 Mdot
.974 .22136 Mdot
.974 .22214 Mdot
.974 .22291 Mdot
.974 .22397 Mdot
.974 .22412 Mdot
.974 .2251 Mdot
.974 .22621 Mdot
.974 .22722 Mdot
.974 .22782 Mdot
.974 .22882 Mdot
.974 .22927 Mdot
.974 .22954 Mdot
.974 .23001 Mdot
.974 .23027 Mdot
.974 .23039 Mdot
.974 .23048 Mdot
.974 .23052 Mdot
.974 .23297 Mdot
.974 .23303 Mdot
.974 .2331 Mdot
.974 .23354 Mdot
.974 .23415 Mdot
.974 .23757 Mdot
.974 .23901 Mdot
.974 .23934 Mdot
.974 .23997 Mdot
.974 .24054 Mdot
.974 .24135 Mdot
.974 .24162 Mdot
.974 .24167 Mdot
.974 .24293 Mdot
.974 .24345 Mdot
.974 .24354 Mdot
.974 .24369 Mdot
.974 .24381 Mdot
.974 .24397 Mdot
.974 .24527 Mdot
.974 .24531 Mdot
.974 .24581 Mdot
.974 .246 Mdot
.974 .2465 Mdot
.974 .24705 Mdot
.974 .24784 Mdot
.974 .24784 Mdot
.974 .25026 Mdot
.974 .2513 Mdot
.974 .25218 Mdot
.974 .25378 Mdot
.974 .25418 Mdot
.974 .25466 Mdot
.974 .25579 Mdot
.974 .25692 Mdot
.974 .25728 Mdot
.974 .25729 Mdot
.974 .2603 Mdot
.974 .26222 Mdot
.974 .26576 Mdot
.974 .26671 Mdot
.974 .27079 Mdot
.974 .27167 Mdot
.974 .27207 Mdot
.974 .27326 Mdot
.974 .27405 Mdot
.974 .27427 Mdot
.974 .27694 Mdot
.974 .27705 Mdot
.974 .27732 Mdot
.974 .27839 Mdot
.974 .27843 Mdot
.974 .2821 Mdot
.974 .28236 Mdot
.974 .28355 Mdot
.974 .28426 Mdot
.974 .2865 Mdot
.974 .2877 Mdot
.974 .28807 Mdot
.974 .2892 Mdot
.974 .28925 Mdot
.974 .28934 Mdot
.974 .28989 Mdot
.974 .28993 Mdot
.974 .29119 Mdot
.974 .29145 Mdot
.974 .29155 Mdot
.974 .29183 Mdot
.974 .29191 Mdot
.974 .29256 Mdot
.974 .29328 Mdot
.974 .29346 Mdot
.974 .29544 Mdot
.974 .29732 Mdot
.974 .29737 Mdot
.974 .29741 Mdot
.974 .29772 Mdot
.974 .29955 Mdot
.974 .29996 Mdot
.974 .30004 Mdot
.974 .30047 Mdot
.974 .30349 Mdot
.974 .30504 Mdot
.974 .30547 Mdot
.974 .30677 Mdot
.974 .30717 Mdot
.974 .30842 Mdot
.974 .30855 Mdot
.974 .30863 Mdot
.974 .31011 Mdot
.974 .31208 Mdot
.974 .3125 Mdot
.974 .31362 Mdot
.974 .31392 Mdot
.974 .31437 Mdot
.974 .31505 Mdot
.974 .31567 Mdot
.974 .31608 Mdot
.974 .31731 Mdot
.974 .31797 Mdot
.974 .31857 Mdot
.974 .31927 Mdot
.974 .31985 Mdot
.974 .32005 Mdot
.974 .32158 Mdot
.974 .32316 Mdot
.974 .32465 Mdot
.974 .32559 Mdot
.974 .32668 Mdot
.974 .32696 Mdot
.974 .32759 Mdot
.974 .32854 Mdot
.974 .32934 Mdot
.974 .33041 Mdot
.974 .33045 Mdot
.974 .33257 Mdot
.974 .33329 Mdot
.974 .33458 Mdot
.974 .33462 Mdot
.974 .33607 Mdot
.974 .33697 Mdot
.974 .33876 Mdot
.974 .33887 Mdot
.974 .3392 Mdot
.974 .33939 Mdot
.974 .34015 Mdot
.974 .34038 Mdot
.974 .34109 Mdot
.974 .34192 Mdot
.974 .34304 Mdot
.974 .34317 Mdot
.974 .34395 Mdot
.974 .34397 Mdot
.974 .34428 Mdot
.974 .34428 Mdot
.974 .34453 Mdot
.974 .34529 Mdot
.974 .3455 Mdot
.974 .34617 Mdot
.974 .34661 Mdot
.974 .34831 Mdot
.974 .34941 Mdot
.974 .34985 Mdot
.974 .35064 Mdot
.974 .3513 Mdot
.974 .35156 Mdot
.974 .35435 Mdot
.974 .35527 Mdot
.974 .35557 Mdot
.974 .35731 Mdot
.974 .35801 Mdot
.974 .35866 Mdot
.974 .35978 Mdot
.974 .36098 Mdot
.974 .36126 Mdot
.974 .36163 Mdot
.974 .36244 Mdot
.974 .36433 Mdot
.974 .36446 Mdot
.974 .36509 Mdot
.974 .36655 Mdot
.974 .36735 Mdot
.974 .3677 Mdot
.974 .36913 Mdot
.974 .36916 Mdot
.974 .3717 Mdot
.974 .3721 Mdot
.974 .37246 Mdot
.974 .3751 Mdot
.974 .37553 Mdot
.974 .37566 Mdot
.974 .37573 Mdot
.974 .3761 Mdot
.974 .37621 Mdot
.974 .37647 Mdot
.974 .37669 Mdot
.974 .37745 Mdot
.974 .37849 Mdot
.974 .37924 Mdot
.974 .38121 Mdot
.974 .38131 Mdot
.974 .38133 Mdot
.974 .38191 Mdot
.974 .38191 Mdot
.974 .38263 Mdot
.974 .38336 Mdot
.974 .38366 Mdot
.974 .38412 Mdot
.974 .38429 Mdot
.974 .38437 Mdot
.974 .38579 Mdot
.974 .3879 Mdot
.974 .38896 Mdot
.974 .38954 Mdot
.974 .39257 Mdot
.974 .39303 Mdot
.974 .39322 Mdot
.974 .39328 Mdot
.974 .39395 Mdot
.974 .39397 Mdot
.974 .39552 Mdot
.974 .39613 Mdot
.974 .3962 Mdot
.974 .39621 Mdot
.974 .39667 Mdot
.974 .39728 Mdot
.974 .3976 Mdot
.974 .39942 Mdot
.974 .4002 Mdot
.974 .4002 Mdot
.974 .40389 Mdot
.974 .40443 Mdot
.974 .40508 Mdot
.974 .40544 Mdot
.974 .40806 Mdot
.974 .40807 Mdot
.974 .4081 Mdot
.974 .40823 Mdot
.974 .4086 Mdot
.974 .40871 Mdot
.974 .40887 Mdot
.974 .40909 Mdot
.974 .40956 Mdot
.974 .41001 Mdot
.974 .41002 Mdot
.974 .41011 Mdot
.974 .41064 Mdot
.974 .41066 Mdot
.974 .41076 Mdot
.974 .41148 Mdot
.974 .41195 Mdot
.974 .41236 Mdot
.974 .41268 Mdot
.974 .4127 Mdot
.974 .41305 Mdot
.974 .41352 Mdot
.974 .41362 Mdot
.974 .41388 Mdot
.974 .41395 Mdot
.974 .41436 Mdot
.974 .41505 Mdot
.974 .41521 Mdot
.974 .41535 Mdot
.974 .41612 Mdot
.974 .41647 Mdot
.974 .41695 Mdot
.974 .41716 Mdot
.974 .41783 Mdot
.974 .41849 Mdot
.974 .41879 Mdot
.974 .41914 Mdot
.974 .41991 Mdot
.974 .42079 Mdot
.974 .42097 Mdot
.974 .42097 Mdot
.974 .42104 Mdot
.974 .4211 Mdot
.974 .42132 Mdot
.974 .42158 Mdot
.974 .42252 Mdot
.974 .42267 Mdot
.974 .42273 Mdot
.974 .42359 Mdot
.974 .42406 Mdot
.974 .42422 Mdot
.974 .42491 Mdot
.974 .42568 Mdot
.974 .42571 Mdot
.974 .42638 Mdot
.974 .42646 Mdot
.974 .42679 Mdot
.974 .4268 Mdot
.974 .42748 Mdot
.974 .42756 Mdot
.974 .42849 Mdot
.974 .42854 Mdot
.974 .42895 Mdot
.974 .42913 Mdot
.974 .42961 Mdot
.974 .42975 Mdot
.974 .42975 Mdot
.974 .42991 Mdot
.974 .43008 Mdot
.974 .43113 Mdot
.974 .43138 Mdot
.974 .43222 Mdot
.974 .43237 Mdot
.974 .43254 Mdot
.974 .43254 Mdot
.974 .43306 Mdot
.974 .43317 Mdot
.974 .43339 Mdot
.974 .43514 Mdot
.974 .43599 Mdot
.974 .43647 Mdot
.974 .43711 Mdot
.974 .4372 Mdot
.974 .43731 Mdot
.974 .43754 Mdot
.974 .43829 Mdot
.974 .43887 Mdot
.974 .4395 Mdot
.974 .43961 Mdot
.974 .44016 Mdot
.974 .44077 Mdot
.974 .44104 Mdot
.974 .44129 Mdot
.974 .44135 Mdot
.974 .44184 Mdot
.974 .44273 Mdot
.974 .44284 Mdot
.974 .44586 Mdot
.974 .44609 Mdot
.974 .44668 Mdot
.974 .44759 Mdot
.974 .44795 Mdot
.974 .44806 Mdot
.974 .44816 Mdot
.974 .44995 Mdot
.974 .45005 Mdot
.974 .45051 Mdot
.974 .4509 Mdot
.974 .45102 Mdot
.974 .45152 Mdot
.974 .45168 Mdot
.974 .45205 Mdot
.974 .45323 Mdot
.974 .45327 Mdot
.974 .4536 Mdot
.974 .45428 Mdot
.974 .45435 Mdot
.974 .45457 Mdot
.974 .455 Mdot
.974 .45551 Mdot
.974 .45576 Mdot
.974 .45579 Mdot
.974 .45588 Mdot
.974 .4568 Mdot
.974 .45694 Mdot
.974 .45724 Mdot
.974 .45786 Mdot
.974 .45838 Mdot
.974 .45883 Mdot
.974 .45905 Mdot
.974 .45921 Mdot
.974 .46046 Mdot
.974 .46051 Mdot
.974 .46138 Mdot
.974 .46301 Mdot
.974 .4633 Mdot
.974 .46354 Mdot
.974 .46552 Mdot
.974 .46632 Mdot
.974 .46646 Mdot
.974 .46673 Mdot
.974 .46693 Mdot
.974 .46694 Mdot
.974 .46697 Mdot
.974 .46723 Mdot
.974 .46791 Mdot
.974 .46792 Mdot
.974 .46824 Mdot
.974 .46852 Mdot
.974 .46983 Mdot
.974 .47008 Mdot
.974 .47054 Mdot
.974 .47145 Mdot
.974 .47205 Mdot
.974 .47216 Mdot
.974 .47249 Mdot
.974 .4728 Mdot
.974 .4731 Mdot
.974 .47311 Mdot
.974 .47335 Mdot
.974 .4734 Mdot
.974 .47424 Mdot
.974 .47455 Mdot
.974 .47531 Mdot
.974 .47541 Mdot
.974 .47552 Mdot
.974 .47572 Mdot
.974 .47575 Mdot
.974 .4758 Mdot
.974 .47598 Mdot
.974 .47709 Mdot
.974 .47724 Mdot
.974 .47846 Mdot
.974 .47848 Mdot
.974 .47907 Mdot
.974 .47922 Mdot
.974 .48015 Mdot
.974 .48041 Mdot
.974 .48046 Mdot
.974 .48184 Mdot
.974 .48233 Mdot
.974 .48306 Mdot
.974 .48334 Mdot
.974 .48417 Mdot
.974 .48455 Mdot
.974 .48568 Mdot
.974 .48578 Mdot
.974 .48605 Mdot
.974 .48637 Mdot
.974 .48767 Mdot
.974 .48785 Mdot
.974 .48811 Mdot
.974 .4882 Mdot
.974 .4885 Mdot
.974 .4886 Mdot
.974 .48872 Mdot
.974 .48873 Mdot
.974 .48904 Mdot
.974 .4891 Mdot
.974 .49015 Mdot
.974 .49055 Mdot
.974 .49062 Mdot
.974 .4915 Mdot
.974 .49186 Mdot
.974 .49243 Mdot
.974 .49245 Mdot
.974 .49295 Mdot
.974 .49407 Mdot
.974 .49408 Mdot
.974 .4945 Mdot
.974 .49481 Mdot
.974 .49519 Mdot
.974 .49543 Mdot
.974 .49554 Mdot
.974 .49633 Mdot
.974 .49691 Mdot
.974 .49819 Mdot
.974 .49841 Mdot
.974 .49868 Mdot
.974 .49891 Mdot
.974 .49964 Mdot
.974 .4998 Mdot
.974 .50004 Mdot
.974 .5003 Mdot
.974 .50047 Mdot
.974 .50058 Mdot
.974 .50101 Mdot
.974 .50117 Mdot
.974 .50193 Mdot
.974 .50249 Mdot
.974 .50252 Mdot
.974 .50304 Mdot
.974 .50369 Mdot
.974 .50444 Mdot
.974 .50558 Mdot
.974 .50574 Mdot
.974 .50577 Mdot
.974 .50661 Mdot
.974 .50673 Mdot
.974 .50675 Mdot
.974 .50676 Mdot
.974 .50747 Mdot
.974 .50821 Mdot
.974 .50828 Mdot
.974 .50855 Mdot
.974 .50879 Mdot
.974 .50882 Mdot
.974 .50893 Mdot
.974 .50896 Mdot
.974 .50906 Mdot
.974 .50953 Mdot
.974 .50955 Mdot
.974 .50975 Mdot
.974 .50978 Mdot
.974 .5098 Mdot
.974 .51022 Mdot
.974 .51081 Mdot
.974 .51164 Mdot
.974 .5138 Mdot
.974 .5142 Mdot
.974 .5143 Mdot
.974 .51434 Mdot
.974 .51532 Mdot
.974 .51569 Mdot
.974 .51612 Mdot
.974 .51659 Mdot
.974 .51808 Mdot
.974 .51971 Mdot
.974 .52149 Mdot
.974 .52149 Mdot
.974 .52261 Mdot
.974 .52333 Mdot
.974 .52488 Mdot
.974 .52517 Mdot
.974 .52554 Mdot
.974 .52561 Mdot
.974 .52642 Mdot
.974 .52645 Mdot
.974 .52709 Mdot
.974 .5271 Mdot
.974 .5272 Mdot
.974 .52749 Mdot
.974 .52803 Mdot
.974 .52854 Mdot
.974 .52997 Mdot
.974 .53012 Mdot
.974 .53015 Mdot
.974 .53017 Mdot
.974 .53105 Mdot
.974 .53112 Mdot
.974 .53138 Mdot
.974 .53148 Mdot
.974 .53199 Mdot
.974 .53294 Mdot
.974 .53425 Mdot
.974 .53503 Mdot
.974 .53591 Mdot
.974 .5363 Mdot
.974 .53666 Mdot
.974 .53687 Mdot
.974 .53722 Mdot
.974 .5378 Mdot
.974 .53799 Mdot
.974 .53813 Mdot
.974 .53828 Mdot
.974 .53839 Mdot
.974 .53844 Mdot
.974 .54059 Mdot
.974 .54145 Mdot
.974 .54151 Mdot
.974 .5416 Mdot
.974 .54213 Mdot
.974 .54231 Mdot
.974 .5424 Mdot
.974 .54261 Mdot
.974 .54286 Mdot
.974 .54316 Mdot
.974 .54352 Mdot
.974 .54437 Mdot
.974 .54521 Mdot
.974 .54521 Mdot
.974 .54588 Mdot
.974 .5459 Mdot
.974 .54601 Mdot
.974 .54684 Mdot
.974 .54846 Mdot
.974 .54883 Mdot
.974 .54909 Mdot
.974 .54954 Mdot
.974 .55016 Mdot
.974 .55024 Mdot
.974 .55104 Mdot
.974 .55106 Mdot
.974 .5513 Mdot
.974 .55134 Mdot
.974 .55138 Mdot
.974 .55158 Mdot
.974 .5517 Mdot
.974 .55209 Mdot
.974 .55217 Mdot
.974 .55231 Mdot
.974 .55273 Mdot
.974 .55276 Mdot
.974 .55328 Mdot
.974 .55337 Mdot
.974 .55353 Mdot
.974 .55365 Mdot
.974 .55383 Mdot
.974 .55517 Mdot
.974 .5552 Mdot
.974 .55549 Mdot
.974 .55571 Mdot
.974 .55586 Mdot
.974 .55591 Mdot
.974 .55626 Mdot
.974 .55641 Mdot
.974 .55696 Mdot
.974 .55774 Mdot
.974 .55774 Mdot
.974 .55876 Mdot
.974 .5588 Mdot
.974 .56006 Mdot
.974 .56015 Mdot
.974 .56049 Mdot
.974 .56104 Mdot
.974 .56123 Mdot
.974 .56185 Mdot
.974 .56256 Mdot
.974 .56313 Mdot
.974 .56324 Mdot
.974 .56329 Mdot
.974 .56365 Mdot
.974 .56407 Mdot
.974 .5649 Mdot
.974 .56505 Mdot
.974 .56559 Mdot
.974 .5659 Mdot
.974 .56601 Mdot
.974 .56614 Mdot
.974 .56631 Mdot
.974 .56632 Mdot
.974 .56713 Mdot
.974 .56804 Mdot
.974 .56856 Mdot
.974 .56876 Mdot
.974 .56911 Mdot
.974 .57024 Mdot
.974 .57045 Mdot
.974 .57066 Mdot
.974 .57135 Mdot
.974 .57282 Mdot
.974 .57333 Mdot
.974 .57348 Mdot
.974 .57351 Mdot
.974 .57396 Mdot
.974 .57449 Mdot
.974 .57478 Mdot
.974 .57549 Mdot
.974 .57614 Mdot
.974 .57654 Mdot
.974 .57668 Mdot
.974 .57681 Mdot
.974 .57692 Mdot
.974 .57721 Mdot
.974 .57734 Mdot
.974 .57762 Mdot
.974 .57778 Mdot
.974 .57792 Mdot
.974 .57792 Mdot
.974 .57808 Mdot
.974 .5781 Mdot
.974 .57811 Mdot
.974 .5782 Mdot
.974 .57855 Mdot
.974 .57862 Mdot
.974 .57923 Mdot
.974 .57965 Mdot
.974 .57966 Mdot
.974 .57971 Mdot
.974 .57985 Mdot
.974 .58003 Mdot
.974 .58015 Mdot
.974 .58039 Mdot
.974 .58041 Mdot
.974 .58053 Mdot
.974 .58062 Mdot
.974 .58078 Mdot
.974 .58084 Mdot
.974 .58168 Mdot
.974 .58208 Mdot
.974 .58213 Mdot
.974 .58224 Mdot
.974 .5827 Mdot
.974 .58272 Mdot
.974 .58274 Mdot
.974 .58303 Mdot
.974 .58324 Mdot
.974 .58352 Mdot
.974 .5839 Mdot
.974 .5843 Mdot
.974 .58431 Mdot
.974 .58433 Mdot
.974 .58446 Mdot
.974 .58467 Mdot
.974 .58483 Mdot
.974 .58485 Mdot
.974 .58488 Mdot
.974 .58493 Mdot
.974 .58505 Mdot
.974 .58506 Mdot
.974 .58523 Mdot
.974 .58542 Mdot
.974 .58544 Mdot
.974 .58549 Mdot
.974 .58552 Mdot
.974 .58554 Mdot
.974 .58563 Mdot
.974 .58565 Mdot
.974 .5858 Mdot
.974 .58583 Mdot
.974 .58601 Mdot
.974 .58605 Mdot
.974 .58606 Mdot
.974 .58641 Mdot
.974 .58653 Mdot
.974 .58675 Mdot
.974 .58692 Mdot
.974 .58693 Mdot
.974 .58694 Mdot
.974 .58699 Mdot
.974 .58705 Mdot
.974 .58708 Mdot
.974 .58718 Mdot
.974 .58729 Mdot
.974 .58731 Mdot
.974 .58737 Mdot
.974 .58738 Mdot
.974 .58739 Mdot
.974 .58744 Mdot
.974 .58748 Mdot
.974 .58763 Mdot
.974 .58768 Mdot
.974 .58774 Mdot
.974 .58779 Mdot
.974 .58781 Mdot
.974 .58784 Mdot
.974 .58787 Mdot
.974 .58791 Mdot
.974 .58794 Mdot
.974 .58794 Mdot
.974 .58796 Mdot
.974 .588 Mdot
.974 .58801 Mdot
.974 .58803 Mdot
.974 .58804 Mdot
.974 .58804 Mdot
.974 .58804 Mdot
.976 .05799 Mdot
.976 .058 Mdot
.976 .05801 Mdot
.976 .05802 Mdot
.976 .05815 Mdot
.976 .05828 Mdot
.976 .05836 Mdot
.976 .05836 Mdot
.976 .05843 Mdot
.976 .0585 Mdot
.976 .05859 Mdot
.976 .0586 Mdot
.976 .05867 Mdot
.976 .05877 Mdot
.976 .05884 Mdot
.976 .05909 Mdot
.976 .05932 Mdot
.976 .05947 Mdot
.976 .05954 Mdot
.976 .05958 Mdot
.976 .05966 Mdot
.976 .05975 Mdot
.976 .05982 Mdot
.976 .05985 Mdot
.976 .06068 Mdot
.976 .0613 Mdot
.976 .06141 Mdot
.976 .06143 Mdot
.976 .06208 Mdot
.976 .06216 Mdot
.976 .06264 Mdot
.976 .06396 Mdot
.976 .0644 Mdot
.976 .0648 Mdot
.976 .06492 Mdot
.976 .06542 Mdot
.976 .06582 Mdot
.976 .06604 Mdot
.976 .06634 Mdot
.976 .06655 Mdot
.976 .06655 Mdot
.976 .0668 Mdot
.976 .06697 Mdot
.976 .06699 Mdot
.976 .06706 Mdot
.976 .06717 Mdot
.976 .0672 Mdot
.976 .06757 Mdot
.976 .06828 Mdot
.976 .06829 Mdot
.976 .06842 Mdot
.976 .06857 Mdot
.976 .06859 Mdot
.976 .0695 Mdot
.976 .0697 Mdot
.976 .07178 Mdot
.976 .07385 Mdot
.976 .07416 Mdot
.976 .07425 Mdot
.976 .07554 Mdot
.976 .07797 Mdot
.976 .07843 Mdot
.976 .07901 Mdot
.976 .07945 Mdot
.976 .0806 Mdot
.976 .08129 Mdot
.976 .08202 Mdot
.976 .08208 Mdot
.976 .08233 Mdot
.976 .08268 Mdot
.976 .08271 Mdot
.976 .08295 Mdot
.976 .08362 Mdot
.976 .08372 Mdot
.976 .08391 Mdot
.976 .08475 Mdot
.976 .08476 Mdot
.976 .08491 Mdot
.976 .0851 Mdot
.976 .08626 Mdot
.976 .08635 Mdot
.976 .08694 Mdot
.976 .09283 Mdot
.976 .09301 Mdot
.976 .09468 Mdot
.976 .09716 Mdot
.976 .0988 Mdot
.976 .09907 Mdot
.976 .09954 Mdot
.976 .10374 Mdot
.976 .10389 Mdot
.976 .1039 Mdot
.976 .10596 Mdot
.976 .10668 Mdot
.976 .10828 Mdot
.976 .10854 Mdot
.976 .10923 Mdot
.976 .10968 Mdot
.976 .11232 Mdot
.976 .11248 Mdot
.976 .11379 Mdot
.976 .11566 Mdot
.976 .11828 Mdot
.976 .11861 Mdot
.976 .11879 Mdot
.976 .11998 Mdot
.976 .12182 Mdot
.976 .12279 Mdot
.976 .12302 Mdot
.976 .12657 Mdot
.976 .12733 Mdot
.976 .12821 Mdot
.976 .12857 Mdot
.976 .12859 Mdot
.976 .13006 Mdot
.976 .1301 Mdot
.976 .13097 Mdot
.976 .1323 Mdot
.976 .13387 Mdot
.976 .13655 Mdot
.976 .13656 Mdot
.976 .13714 Mdot
.976 .13779 Mdot
.976 .13787 Mdot
.976 .13797 Mdot
.976 .13881 Mdot
.976 .13922 Mdot
.976 .13975 Mdot
.976 .14343 Mdot
.976 .14607 Mdot
.976 .14624 Mdot
.976 .14624 Mdot
.976 .14627 Mdot
.976 .14629 Mdot
.976 .14633 Mdot
.976 .14666 Mdot
.976 .1467 Mdot
.976 .1471 Mdot
.976 .14732 Mdot
.976 .14734 Mdot
.976 .14753 Mdot
.976 .14774 Mdot
.976 .14803 Mdot
.976 .14806 Mdot
.976 .14827 Mdot
.976 .14827 Mdot
.976 .14856 Mdot
.976 .14875 Mdot
.976 .1491 Mdot
.976 .14951 Mdot
.976 .1498 Mdot
.976 .15003 Mdot
.976 .1502 Mdot
.976 .15055 Mdot
.976 .15064 Mdot
.976 .15071 Mdot
.976 .15086 Mdot
.976 .15096 Mdot
.976 .1512 Mdot
.976 .15126 Mdot
.976 .15147 Mdot
.976 .15165 Mdot
.976 .15169 Mdot
.976 .15178 Mdot
.976 .15262 Mdot
.976 .15304 Mdot
.976 .15402 Mdot
.976 .15425 Mdot
.976 .15567 Mdot
.976 .15608 Mdot
.976 .15642 Mdot
.976 .15648 Mdot
.976 .15753 Mdot
.976 .15841 Mdot
.976 .15863 Mdot
.976 .16006 Mdot
.976 .16137 Mdot
.976 .16316 Mdot
.976 .16396 Mdot
.976 .16499 Mdot
.976 .16502 Mdot
.976 .16528 Mdot
.976 .16645 Mdot
.976 .16682 Mdot
.976 .1683 Mdot
.976 .16948 Mdot
.976 .16949 Mdot
.976 .1699 Mdot
.976 .17013 Mdot
.976 .17102 Mdot
.976 .17143 Mdot
.976 .17162 Mdot
.976 .17164 Mdot
.976 .1717 Mdot
.976 .17238 Mdot
.976 .17288 Mdot
.976 .17293 Mdot
.976 .17313 Mdot
.976 .17318 Mdot
.976 .17347 Mdot
.976 .17354 Mdot
.976 .17462 Mdot
.976 .17462 Mdot
.976 .17674 Mdot
.976 .17675 Mdot
.976 .17713 Mdot
.976 .17743 Mdot
.976 .17747 Mdot
.976 .17759 Mdot
.976 .17763 Mdot
.976 .17901 Mdot
.976 .17974 Mdot
.976 .18002 Mdot
.976 .1803 Mdot
.976 .18091 Mdot
.976 .18103 Mdot
.976 .18376 Mdot
.976 .18384 Mdot
.976 .18515 Mdot
.976 .18699 Mdot
.976 .18773 Mdot
.976 .1881 Mdot
.976 .18847 Mdot
.976 .18905 Mdot
.976 .1906 Mdot
.976 .19303 Mdot
.976 .19395 Mdot
.976 .19421 Mdot
.976 .19426 Mdot
.976 .19713 Mdot
.976 .19797 Mdot
.976 .19862 Mdot
.976 .19974 Mdot
.976 .20003 Mdot
.976 .20006 Mdot
.976 .20032 Mdot
.976 .20047 Mdot
.976 .20076 Mdot
.976 .20177 Mdot
.976 .2021 Mdot
.976 .20342 Mdot
.976 .20356 Mdot
.976 .20389 Mdot
.976 .20451 Mdot
.976 .205 Mdot
.976 .20594 Mdot
.976 .20634 Mdot
.976 .2068 Mdot
.976 .20723 Mdot
.976 .208 Mdot
.976 .20911 Mdot
.976 .20923 Mdot
.976 .20927 Mdot
.976 .20929 Mdot
.976 .20966 Mdot
.976 .21084 Mdot
.976 .21169 Mdot
.976 .21195 Mdot
.976 .21222 Mdot
.976 .21242 Mdot
.976 .21247 Mdot
.976 .21259 Mdot
.976 .21262 Mdot
.976 .21291 Mdot
.976 .21458 Mdot
.976 .21508 Mdot
.976 .21533 Mdot
.976 .2162 Mdot
.976 .21667 Mdot
.976 .21684 Mdot
.976 .21713 Mdot
.976 .21715 Mdot
.976 .21757 Mdot
.976 .21858 Mdot
.976 .21865 Mdot
.976 .21869 Mdot
.976 .21935 Mdot
.976 .2197 Mdot
.976 .22126 Mdot
.976 .2213 Mdot
.976 .22156 Mdot
.976 .2221 Mdot
.976 .22279 Mdot
.976 .22431 Mdot
.976 .22446 Mdot
.976 .2245 Mdot
.976 .22451 Mdot
.976 .22496 Mdot
.976 .22525 Mdot
.976 .22548 Mdot
.976 .22614 Mdot
.976 .22723 Mdot
.976 .22791 Mdot
.976 .2288 Mdot
.976 .22893 Mdot
.976 .22899 Mdot
.976 .22906 Mdot
.976 .22913 Mdot
.976 .22969 Mdot
.976 .23048 Mdot
.976 .23072 Mdot
.976 .23142 Mdot
.976 .23246 Mdot
.976 .23402 Mdot
.976 .23553 Mdot
.976 .23709 Mdot
.976 .2379 Mdot
.976 .2382 Mdot
.976 .23851 Mdot
.976 .23985 Mdot
.976 .24029 Mdot
.976 .24075 Mdot
.976 .24131 Mdot
.976 .24143 Mdot
.976 .24284 Mdot
.976 .24344 Mdot
.976 .24527 Mdot
.976 .2469 Mdot
.976 .24723 Mdot
.976 .24736 Mdot
.976 .24755 Mdot
.976 .24786 Mdot
.976 .2481 Mdot
.976 .24894 Mdot
.976 .25157 Mdot
.976 .25172 Mdot
.976 .25202 Mdot
.976 .25254 Mdot
.976 .25353 Mdot
.976 .25495 Mdot
.976 .25497 Mdot
.976 .25568 Mdot
.976 .25602 Mdot
.976 .25772 Mdot
.976 .25781 Mdot
.976 .25895 Mdot
.976 .25944 Mdot
.976 .25952 Mdot
.976 .25965 Mdot
.976 .26075 Mdot
.976 .26155 Mdot
.976 .26398 Mdot
.976 .26471 Mdot
.976 .26504 Mdot
.976 .26601 Mdot
.976 .26608 Mdot
.976 .26812 Mdot
.976 .26849 Mdot
.976 .2706 Mdot
.976 .27493 Mdot
.976 .27615 Mdot
.976 .27624 Mdot
.976 .27677 Mdot
.976 .27695 Mdot
.976 .27753 Mdot
.976 .27777 Mdot
.976 .27793 Mdot
.976 .27797 Mdot
.976 .27891 Mdot
.976 .27999 Mdot
.976 .2835 Mdot
.976 .28357 Mdot
.976 .28382 Mdot
.976 .28552 Mdot
.976 .28756 Mdot
.976 .28843 Mdot
.976 .28844 Mdot
.976 .28983 Mdot
.976 .28997 Mdot
.976 .29006 Mdot
.976 .29024 Mdot
.976 .29052 Mdot
.976 .29074 Mdot
.976 .29132 Mdot
.976 .29237 Mdot
.976 .29358 Mdot
.976 .29539 Mdot
.976 .29865 Mdot
.976 .30047 Mdot
.976 .30065 Mdot
.976 .30106 Mdot
.976 .30115 Mdot
.976 .3024 Mdot
.976 .30343 Mdot
.976 .30412 Mdot
.976 .30453 Mdot
.976 .30486 Mdot
.976 .30516 Mdot
.976 .30561 Mdot
.976 .3081 Mdot
.976 .30941 Mdot
.976 .30947 Mdot
.976 .31018 Mdot
.976 .31155 Mdot
.976 .31286 Mdot
.976 .31398 Mdot
.976 .31425 Mdot
.976 .31484 Mdot
.976 .31633 Mdot
.976 .31672 Mdot
.976 .31719 Mdot
.976 .31766 Mdot
.976 .32053 Mdot
.976 .32073 Mdot
.976 .32076 Mdot
.976 .32182 Mdot
.976 .32194 Mdot
.976 .32505 Mdot
.976 .32553 Mdot
.976 .32627 Mdot
.976 .32698 Mdot
.976 .32754 Mdot
.976 .32801 Mdot
.976 .3282 Mdot
.976 .32861 Mdot
.976 .32933 Mdot
.976 .32934 Mdot
.976 .32946 Mdot
.976 .33069 Mdot
.976 .33556 Mdot
.976 .33734 Mdot
.976 .33766 Mdot
.976 .33837 Mdot
.976 .33961 Mdot
.976 .34051 Mdot
.976 .34069 Mdot
.976 .34117 Mdot
.976 .34181 Mdot
.976 .34202 Mdot
.976 .34273 Mdot
.976 .34278 Mdot
.976 .34647 Mdot
.976 .34656 Mdot
.976 .34874 Mdot
.976 .3497 Mdot
.976 .35205 Mdot
.976 .35419 Mdot
.976 .3545 Mdot
.976 .3547 Mdot
.976 .35587 Mdot
.976 .35594 Mdot
.976 .35986 Mdot
.976 .36174 Mdot
.976 .36252 Mdot
.976 .36253 Mdot
.976 .36344 Mdot
.976 .36394 Mdot
.976 .36552 Mdot
.976 .36573 Mdot
.976 .36597 Mdot
.976 .366 Mdot
.976 .36668 Mdot
.976 .36799 Mdot
.976 .36891 Mdot
.976 .36899 Mdot
.976 .36967 Mdot
.976 .37028 Mdot
.976 .37045 Mdot
.976 .3713 Mdot
.976 .37162 Mdot
.976 .37218 Mdot
.976 .37404 Mdot
.976 .3752 Mdot
.976 .37723 Mdot
.976 .37907 Mdot
.976 .37908 Mdot
.976 .37977 Mdot
.976 .381 Mdot
.976 .38138 Mdot
.976 .38214 Mdot
.976 .38225 Mdot
.976 .38236 Mdot
.976 .38298 Mdot
.976 .38486 Mdot
.976 .38528 Mdot
.976 .38568 Mdot
.976 .38569 Mdot
.976 .38576 Mdot
.976 .38581 Mdot
.976 .38589 Mdot
.976 .38617 Mdot
.976 .38627 Mdot
.976 .38668 Mdot
.976 .38677 Mdot
.976 .38694 Mdot
.976 .3877 Mdot
.976 .38822 Mdot
.976 .38825 Mdot
.976 .38826 Mdot
.976 .38869 Mdot
.976 .38914 Mdot
.976 .38918 Mdot
.976 .38985 Mdot
.976 .38992 Mdot
.976 .3904 Mdot
.976 .39041 Mdot
.976 .3911 Mdot
.976 .39152 Mdot
.976 .39233 Mdot
.976 .39237 Mdot
.976 .39328 Mdot
.976 .39396 Mdot
.976 .3942 Mdot
.976 .39447 Mdot
.976 .39488 Mdot
.976 .39567 Mdot
.976 .39588 Mdot
.976 .39604 Mdot
.976 .39639 Mdot
.976 .39662 Mdot
.976 .39715 Mdot
.976 .39731 Mdot
.976 .39777 Mdot
.976 .39819 Mdot
.976 .39827 Mdot
.976 .39849 Mdot
.976 .39986 Mdot
.976 .40022 Mdot
.976 .40022 Mdot
.976 .4004 Mdot
.976 .40136 Mdot
.976 .40166 Mdot
.976 .40357 Mdot
.976 .40409 Mdot
.976 .40729 Mdot
.976 .40819 Mdot
.976 .4084 Mdot
.976 .40895 Mdot
.976 .40909 Mdot
.976 .41142 Mdot
.976 .41196 Mdot
.976 .41229 Mdot
.976 .41237 Mdot
.976 .41247 Mdot
.976 .41336 Mdot
.976 .41387 Mdot
.976 .41443 Mdot
.976 .41507 Mdot
.976 .41601 Mdot
.976 .41626 Mdot
.976 .41701 Mdot
.976 .41746 Mdot
.976 .418 Mdot
.976 .41985 Mdot
.976 .42058 Mdot
.976 .42062 Mdot
.976 .42073 Mdot
.976 .4227 Mdot
.976 .42373 Mdot
.976 .42546 Mdot
.976 .42585 Mdot
.976 .42643 Mdot
.976 .42659 Mdot
.976 .4271 Mdot
.976 .42728 Mdot
.976 .42765 Mdot
.976 .42772 Mdot
.976 .42785 Mdot
.976 .42828 Mdot
.976 .42854 Mdot
.976 .42943 Mdot
.976 .43014 Mdot
.976 .43016 Mdot
.976 .43019 Mdot
.976 .43076 Mdot
.976 .43108 Mdot
.976 .43124 Mdot
.976 .43154 Mdot
.976 .43175 Mdot
.976 .43249 Mdot
.976 .4343 Mdot
.976 .43464 Mdot
.976 .4362 Mdot
.976 .43711 Mdot
.976 .43712 Mdot
.976 .43761 Mdot
.976 .43798 Mdot
.976 .43844 Mdot
.976 .43906 Mdot
.976 .43908 Mdot
.976 .43955 Mdot
.976 .44029 Mdot
.976 .44076 Mdot
.976 .44114 Mdot
.976 .44131 Mdot
.976 .44153 Mdot
.976 .44157 Mdot
.976 .44169 Mdot
.976 .44186 Mdot
.976 .4423 Mdot
.976 .44275 Mdot
.976 .44309 Mdot
.976 .44355 Mdot
.976 .44384 Mdot
.976 .44397 Mdot
.976 .44411 Mdot
.976 .44421 Mdot
.976 .44432 Mdot
.976 .44462 Mdot
.976 .4447 Mdot
.976 .44507 Mdot
.976 .44524 Mdot
.976 .4453 Mdot
.976 .44545 Mdot
.976 .44584 Mdot
.976 .44606 Mdot
.976 .44627 Mdot
.976 .44654 Mdot
.976 .44681 Mdot
.976 .4474 Mdot
.976 .44762 Mdot
.976 .44764 Mdot
.976 .44834 Mdot
.976 .44901 Mdot
.976 .44992 Mdot
.976 .45078 Mdot
.976 .45114 Mdot
.976 .45138 Mdot
.976 .45145 Mdot
.976 .45187 Mdot
.976 .45189 Mdot
.976 .4519 Mdot
.976 .45223 Mdot
.976 .45265 Mdot
.976 .45298 Mdot
.976 .45324 Mdot
.976 .45333 Mdot
.976 .45357 Mdot
.976 .45364 Mdot
.976 .45391 Mdot
.976 .45538 Mdot
.976 .45628 Mdot
.976 .45634 Mdot
.976 .45635 Mdot
.976 .45754 Mdot
.976 .45779 Mdot
.976 .45834 Mdot
.976 .45845 Mdot
.976 .45888 Mdot
.976 .45917 Mdot
.976 .46006 Mdot
.976 .4601 Mdot
.976 .46014 Mdot
.976 .46029 Mdot
.976 .46189 Mdot
.976 .46488 Mdot
.976 .46552 Mdot
.976 .46552 Mdot
.976 .46568 Mdot
.976 .46815 Mdot
.976 .46894 Mdot
.976 .47034 Mdot
.976 .47072 Mdot
.976 .47128 Mdot
.976 .47157 Mdot
.976 .47161 Mdot
.976 .47217 Mdot
.976 .47297 Mdot
.976 .47323 Mdot
.976 .47328 Mdot
.976 .47332 Mdot
.976 .47365 Mdot
.976 .47433 Mdot
.976 .47462 Mdot
.976 .4754 Mdot
.976 .47625 Mdot
.976 .47674 Mdot
.976 .47751 Mdot
.976 .47774 Mdot
.976 .47788 Mdot
.976 .47823 Mdot
.976 .47855 Mdot
.976 .47887 Mdot
.976 .47979 Mdot
.976 .48007 Mdot
.976 .48113 Mdot
.976 .48182 Mdot
.976 .48259 Mdot
.976 .48421 Mdot
.976 .48469 Mdot
.976 .48477 Mdot
.976 .48489 Mdot
.976 .4867 Mdot
.976 .48977 Mdot
.976 .4901 Mdot
.976 .4903 Mdot
.976 .49037 Mdot
.976 .49121 Mdot
.976 .49162 Mdot
.976 .49232 Mdot
.976 .49423 Mdot
.976 .49471 Mdot
.976 .49476 Mdot
.976 .49476 Mdot
.976 .4952 Mdot
.976 .49546 Mdot
.976 .49567 Mdot
.976 .49595 Mdot
.976 .49642 Mdot
.976 .49762 Mdot
.976 .49767 Mdot
.976 .49809 Mdot
.976 .49817 Mdot
.976 .49963 Mdot
.976 .50035 Mdot
.976 .50058 Mdot
.976 .50068 Mdot
.976 .50111 Mdot
.976 .50161 Mdot
.976 .50213 Mdot
.976 .50242 Mdot
.976 .50292 Mdot
.976 .50386 Mdot
.976 .50403 Mdot
.976 .50415 Mdot
.976 .50443 Mdot
.976 .50468 Mdot
.976 .50507 Mdot
.976 .50555 Mdot
.976 .5058 Mdot
.976 .50648 Mdot
.976 .5077 Mdot
.976 .50922 Mdot
.976 .50944 Mdot
.976 .50944 Mdot
.976 .50962 Mdot
.976 .50969 Mdot
.976 .50972 Mdot
.976 .51029 Mdot
.976 .5103 Mdot
.976 .51062 Mdot
.976 .512 Mdot
.976 .51212 Mdot
.976 .51341 Mdot
.976 .51381 Mdot
.976 .51423 Mdot
.976 .51453 Mdot
.976 .5146 Mdot
.976 .51479 Mdot
.976 .51482 Mdot
.976 .51527 Mdot
.976 .51685 Mdot
.976 .51762 Mdot
.976 .51775 Mdot
.976 .51849 Mdot
.976 .51887 Mdot
.976 .52013 Mdot
.976 .52042 Mdot
.976 .52082 Mdot
.976 .52087 Mdot
.976 .52107 Mdot
.976 .52148 Mdot
.976 .52151 Mdot
.976 .52213 Mdot
.976 .52225 Mdot
.976 .5225 Mdot
.976 .52251 Mdot
.976 .52302 Mdot
.976 .52356 Mdot
.976 .52367 Mdot
.976 .52372 Mdot
.976 .52466 Mdot
.976 .52496 Mdot
.976 .52516 Mdot
.976 .52527 Mdot
.976 .52539 Mdot
.976 .52597 Mdot
.976 .52662 Mdot
.976 .52683 Mdot
.976 .52733 Mdot
.976 .52738 Mdot
.976 .52758 Mdot
.976 .52774 Mdot
.976 .5279 Mdot
.976 .52837 Mdot
.976 .52848 Mdot
.976 .52859 Mdot
.976 .52887 Mdot
.976 .52943 Mdot
.976 .52996 Mdot
.976 .53051 Mdot
.976 .53087 Mdot
.976 .5312 Mdot
.976 .53148 Mdot
.976 .53168 Mdot
.976 .53173 Mdot
.976 .53175 Mdot
.976 .53211 Mdot
.976 .53235 Mdot
.976 .53273 Mdot
.976 .53304 Mdot
.976 .53332 Mdot
.976 .53337 Mdot
.976 .5339 Mdot
.976 .53443 Mdot
.976 .53498 Mdot
.976 .53534 Mdot
.976 .53587 Mdot
.976 .53588 Mdot
.976 .5362 Mdot
.976 .53651 Mdot
.976 .53659 Mdot
.976 .53735 Mdot
.976 .53745 Mdot
.976 .5375 Mdot
.976 .53752 Mdot
.976 .53759 Mdot
.976 .53768 Mdot
.976 .53777 Mdot
.976 .53807 Mdot
.976 .53848 Mdot
.976 .53861 Mdot
.976 .53863 Mdot
.976 .53867 Mdot
.976 .53932 Mdot
.976 .53947 Mdot
.976 .53977 Mdot
.976 .54026 Mdot
.976 .54047 Mdot
.976 .54059 Mdot
.976 .54063 Mdot
.976 .54109 Mdot
.976 .5412 Mdot
.976 .54155 Mdot
.976 .54165 Mdot
.976 .54171 Mdot
.976 .5418 Mdot
.976 .54181 Mdot
.976 .5419 Mdot
.976 .54229 Mdot
.976 .5428 Mdot
.976 .54379 Mdot
.976 .54504 Mdot
.976 .54558 Mdot
.976 .54577 Mdot
.976 .5459 Mdot
.976 .54603 Mdot
.976 .54691 Mdot
.976 .54736 Mdot
.976 .54738 Mdot
.976 .54831 Mdot
.976 .54866 Mdot
.976 .54875 Mdot
.976 .549 Mdot
.976 .54952 Mdot
.976 .54954 Mdot
.976 .55049 Mdot
.976 .55098 Mdot
.976 .55148 Mdot
.976 .55158 Mdot
.976 .55209 Mdot
.976 .55223 Mdot
.976 .55374 Mdot
.976 .55376 Mdot
.976 .55437 Mdot
.976 .55498 Mdot
.976 .55627 Mdot
.976 .5569 Mdot
.976 .55745 Mdot
.976 .55778 Mdot
.976 .55792 Mdot
.976 .55825 Mdot
.976 .55838 Mdot
.976 .55856 Mdot
.976 .55862 Mdot
.976 .55879 Mdot
.976 .55887 Mdot
.976 .55911 Mdot
.976 .55938 Mdot
.976 .55992 Mdot
.976 .56005 Mdot
.976 .56012 Mdot
.976 .561 Mdot
.976 .56223 Mdot
.976 .56241 Mdot
.976 .56255 Mdot
.976 .56283 Mdot
.976 .56286 Mdot
.976 .56289 Mdot
.976 .56311 Mdot
.976 .5633 Mdot
.976 .5633 Mdot
.976 .5642 Mdot
.976 .56472 Mdot
.976 .56516 Mdot
.976 .56545 Mdot
.976 .56547 Mdot
.976 .56596 Mdot
.976 .56596 Mdot
.976 .56608 Mdot
.976 .56637 Mdot
.976 .56663 Mdot
.976 .56781 Mdot
.976 .56789 Mdot
.976 .56821 Mdot
.976 .56882 Mdot
.976 .56921 Mdot
.976 .56927 Mdot
.976 .56938 Mdot
.976 .57025 Mdot
.976 .57087 Mdot
.976 .5713 Mdot
.976 .57135 Mdot
.976 .57223 Mdot
.976 .57238 Mdot
.976 .57261 Mdot
.976 .57269 Mdot
.976 .57322 Mdot
.976 .57346 Mdot
.976 .57414 Mdot
.976 .57414 Mdot
.976 .57419 Mdot
.976 .57558 Mdot
.976 .57573 Mdot
.976 .57582 Mdot
.976 .57636 Mdot
.976 .57718 Mdot
.976 .57773 Mdot
.976 .57779 Mdot
.976 .57973 Mdot
.976 .57992 Mdot
.976 .57995 Mdot
.976 .58033 Mdot
.976 .58039 Mdot
.976 .58044 Mdot
.976 .58044 Mdot
.976 .58072 Mdot
.976 .58078 Mdot
.976 .58082 Mdot
.976 .58103 Mdot
.976 .58112 Mdot
.976 .58112 Mdot
.976 .58124 Mdot
.976 .58132 Mdot
.976 .58134 Mdot
.976 .58158 Mdot
.976 .58181 Mdot
.976 .58218 Mdot
.976 .58233 Mdot
.976 .58252 Mdot
.976 .58267 Mdot
.976 .58347 Mdot
.976 .58389 Mdot
.976 .58392 Mdot
.976 .58402 Mdot
.976 .5847 Mdot
.976 .58538 Mdot
.976 .58545 Mdot
.976 .58575 Mdot
.976 .58575 Mdot
.976 .5858 Mdot
.976 .58584 Mdot
.976 .58585 Mdot
.976 .58608 Mdot
.976 .5862 Mdot
.976 .58621 Mdot
.976 .58625 Mdot
.976 .58627 Mdot
.976 .58628 Mdot
.976 .58633 Mdot
.976 .58641 Mdot
.976 .58642 Mdot
.976 .58648 Mdot
.976 .58658 Mdot
.976 .58665 Mdot
.976 .58678 Mdot
.976 .58695 Mdot
.976 .58699 Mdot
.976 .58712 Mdot
.976 .58726 Mdot
.976 .58769 Mdot
.976 .58785 Mdot
.976 .58788 Mdot
.976 .58809 Mdot
.976 .5881 Mdot
.976 .58813 Mdot
.976 .58834 Mdot
.976 .58861 Mdot
.976 .58862 Mdot
.976 .58864 Mdot
.976 .58867 Mdot
.976 .5887 Mdot
.976 .58871 Mdot
.976 .58873 Mdot
.976 .58878 Mdot
.976 .58886 Mdot
.976 .58894 Mdot
.976 .58896 Mdot
.976 .58899 Mdot
.976 .58902 Mdot
.976 .58902 Mdot
.976 .58905 Mdot
.976 .58907 Mdot
.976 .58909 Mdot
.976 .5891 Mdot
.976 .58912 Mdot
.976 .58916 Mdot
.976 .5892 Mdot
.976 .58921 Mdot
.976 .58921 Mdot
.976 .58921 Mdot
.978 .05448 Mdot
.978 .05452 Mdot
.978 .05462 Mdot
.978 .05464 Mdot
.978 .05477 Mdot
.978 .05494 Mdot
.978 .05505 Mdot
.978 .05522 Mdot
.978 .05563 Mdot
.978 .05574 Mdot
.978 .05598 Mdot
.978 .05609 Mdot
.978 .05619 Mdot
.978 .05635 Mdot
.978 .05638 Mdot
.978 .05641 Mdot
.978 .05647 Mdot
.978 .05714 Mdot
.978 .05718 Mdot
.978 .05761 Mdot
.978 .05762 Mdot
.978 .0578 Mdot
.978 .05864 Mdot
.978 .05868 Mdot
.978 .05902 Mdot
.978 .05914 Mdot
.978 .05924 Mdot
.978 .05946 Mdot
.978 .05999 Mdot
.978 .06045 Mdot
.978 .06067 Mdot
.978 .06087 Mdot
.978 .06103 Mdot
.978 .06124 Mdot
.978 .06152 Mdot
.978 .06221 Mdot
.978 .06244 Mdot
.978 .06324 Mdot
.978 .06352 Mdot
.978 .06361 Mdot
.978 .06487 Mdot
.978 .06523 Mdot
.978 .0662 Mdot
.978 .0665 Mdot
.978 .06717 Mdot
.978 .06853 Mdot
.978 .06866 Mdot
.978 .06953 Mdot
.978 .06968 Mdot
.978 .06985 Mdot
.978 .07022 Mdot
.978 .07034 Mdot
.978 .0707 Mdot
.978 .07072 Mdot
.978 .07223 Mdot
.978 .07401 Mdot
.978 .07459 Mdot
.978 .07581 Mdot
.978 .07629 Mdot
.978 .07651 Mdot
.978 .07677 Mdot
.978 .07705 Mdot
.978 .08044 Mdot
.978 .08046 Mdot
.978 .08131 Mdot
.978 .08245 Mdot
.978 .08386 Mdot
.978 .08476 Mdot
.978 .0852 Mdot
.978 .08524 Mdot
.978 .08525 Mdot
.978 .08528 Mdot
.978 .08642 Mdot
.978 .08704 Mdot
.978 .08705 Mdot
.978 .0874 Mdot
.978 .08745 Mdot
.978 .08831 Mdot
.978 .0895 Mdot
.978 .0897 Mdot
.978 .09018 Mdot
.978 .09066 Mdot
.978 .09108 Mdot
.978 .09171 Mdot
.978 .09189 Mdot
.978 .09418 Mdot
.978 .09493 Mdot
.978 .09591 Mdot
.978 .09689 Mdot
.978 .09924 Mdot
.978 .09943 Mdot
.978 .09959 Mdot
.978 .10017 Mdot
.978 .10124 Mdot
.978 .10186 Mdot
.978 .10223 Mdot
.978 .10328 Mdot
.978 .10415 Mdot
.978 .10533 Mdot
.978 .10576 Mdot
.978 .10587 Mdot
.978 .10602 Mdot
.978 .11105 Mdot
.978 .11198 Mdot
.978 .11345 Mdot
.978 .11617 Mdot
.978 .11625 Mdot
.978 .11658 Mdot
.978 .1169 Mdot
.978 .11831 Mdot
.978 .11866 Mdot
.978 .12137 Mdot
.978 .12224 Mdot
.978 .12307 Mdot
.978 .12356 Mdot
.978 .12367 Mdot
.978 .12441 Mdot
.978 .12619 Mdot
.978 .12652 Mdot
.978 .12671 Mdot
.978 .12926 Mdot
.978 .12935 Mdot
.978 .13013 Mdot
.978 .13026 Mdot
.978 .13077 Mdot
.978 .1318 Mdot
.978 .13252 Mdot
.978 .13479 Mdot
.978 .13562 Mdot
.978 .13597 Mdot
.978 .13599 Mdot
.978 .13611 Mdot
.978 .13639 Mdot
.978 .13647 Mdot
.978 .13686 Mdot
.978 .13725 Mdot
.978 .13735 Mdot
.978 .13769 Mdot
.978 .13806 Mdot
.978 .13818 Mdot
.978 .13819 Mdot
.978 .13872 Mdot
.978 .13942 Mdot
.978 .13977 Mdot
.978 .14047 Mdot
.978 .14048 Mdot
.978 .1408 Mdot
.978 .14112 Mdot
.978 .14159 Mdot
.978 .14167 Mdot
.978 .14177 Mdot
.978 .14181 Mdot
.978 .14194 Mdot
.978 .14371 Mdot
.978 .14394 Mdot
.978 .14408 Mdot
.978 .14486 Mdot
.978 .14499 Mdot
.978 .14537 Mdot
.978 .14538 Mdot
.978 .14593 Mdot
.978 .14677 Mdot
.978 .14699 Mdot
.978 .14843 Mdot
.978 .14855 Mdot
.978 .14924 Mdot
.978 .14957 Mdot
.978 .14995 Mdot
.978 .15024 Mdot
.978 .15029 Mdot
.978 .15044 Mdot
.978 .15088 Mdot
.978 .15175 Mdot
.978 .15233 Mdot
.978 .15247 Mdot
.978 .15384 Mdot
.978 .15432 Mdot
.978 .15443 Mdot
.978 .1545 Mdot
.978 .15475 Mdot
.978 .15509 Mdot
.978 .15557 Mdot
.978 .1562 Mdot
.978 .15624 Mdot
.978 .15634 Mdot
.978 .15656 Mdot
.978 .1568 Mdot
.978 .15704 Mdot
.978 .15764 Mdot
.978 .15806 Mdot
.978 .15908 Mdot
.978 .15913 Mdot
.978 .15976 Mdot
.978 .16069 Mdot
.978 .16189 Mdot
.978 .16215 Mdot
.978 .16267 Mdot
.978 .16297 Mdot
.978 .16326 Mdot
.978 .16332 Mdot
.978 .16404 Mdot
.978 .16441 Mdot
.978 .16536 Mdot
.978 .16568 Mdot
.978 .16642 Mdot
.978 .16677 Mdot
.978 .16698 Mdot
.978 .16749 Mdot
.978 .16805 Mdot
.978 .16891 Mdot
.978 .16918 Mdot
.978 .17002 Mdot
.978 .1703 Mdot
.978 .17092 Mdot
.978 .17103 Mdot
.978 .17117 Mdot
.978 .17181 Mdot
.978 .17202 Mdot
.978 .17236 Mdot
.978 .17282 Mdot
.978 .17379 Mdot
.978 .17447 Mdot
.978 .17453 Mdot
.978 .17528 Mdot
.978 .17584 Mdot
.978 .17637 Mdot
.978 .1774 Mdot
.978 .17778 Mdot
.978 .17818 Mdot
.978 .17922 Mdot
.978 .18075 Mdot
.978 .18103 Mdot
.978 .18108 Mdot
.978 .18117 Mdot
.978 .18167 Mdot
.978 .18216 Mdot
.978 .18245 Mdot
.978 .18278 Mdot
.978 .18313 Mdot
.978 .18321 Mdot
.978 .18419 Mdot
.978 .18423 Mdot
.978 .18726 Mdot
.978 .18784 Mdot
.978 .18844 Mdot
.978 .18852 Mdot
.978 .18868 Mdot
.978 .18883 Mdot
.978 .18926 Mdot
.978 .18956 Mdot
.978 .18988 Mdot
.978 .19268 Mdot
.978 .19281 Mdot
.978 .19387 Mdot
.978 .19556 Mdot
.978 .19643 Mdot
.978 .1969 Mdot
.978 .19739 Mdot
.978 .19788 Mdot
.978 .19912 Mdot
.978 .20044 Mdot
.978 .20051 Mdot
.978 .20057 Mdot
.978 .20115 Mdot
.978 .20132 Mdot
.978 .20192 Mdot
.978 .20274 Mdot
.978 .20448 Mdot
.978 .20633 Mdot
.978 .207 Mdot
.978 .21007 Mdot
.978 .21253 Mdot
.978 .21261 Mdot
.978 .21317 Mdot
.978 .21506 Mdot
.978 .21831 Mdot
.978 .21875 Mdot
.978 .21903 Mdot
.978 .21931 Mdot
.978 .21943 Mdot
.978 .2198 Mdot
.978 .21991 Mdot
.978 .22062 Mdot
.978 .22092 Mdot
.978 .22098 Mdot
.978 .22112 Mdot
.978 .22236 Mdot
.978 .22462 Mdot
.978 .22463 Mdot
.978 .22496 Mdot
.978 .22588 Mdot
.978 .22592 Mdot
.978 .22594 Mdot
.978 .2262 Mdot
.978 .22633 Mdot
.978 .22636 Mdot
.978 .22644 Mdot
.978 .22884 Mdot
.978 .22968 Mdot
.978 .23145 Mdot
.978 .23149 Mdot
.978 .2322 Mdot
.978 .23248 Mdot
.978 .23261 Mdot
.978 .23465 Mdot
.978 .23477 Mdot
.978 .23506 Mdot
.978 .23523 Mdot
.978 .23663 Mdot
.978 .23843 Mdot
.978 .23859 Mdot
.978 .23899 Mdot
.978 .23901 Mdot
.978 .2395 Mdot
.978 .23975 Mdot
.978 .24005 Mdot
.978 .24028 Mdot
.978 .24036 Mdot
.978 .24062 Mdot
.978 .24147 Mdot
.978 .2417 Mdot
.978 .2429 Mdot
.978 .24426 Mdot
.978 .24468 Mdot
.978 .24471 Mdot
.978 .24519 Mdot
.978 .24618 Mdot
.978 .24667 Mdot
.978 .24778 Mdot
.978 .2485 Mdot
.978 .2489 Mdot
.978 .25064 Mdot
.978 .25162 Mdot
.978 .2537 Mdot
.978 .25375 Mdot
.978 .25511 Mdot
.978 .25644 Mdot
.978 .25676 Mdot
.978 .25818 Mdot
.978 .25903 Mdot
.978 .25919 Mdot
.978 .26383 Mdot
.978 .26437 Mdot
.978 .26525 Mdot
.978 .26542 Mdot
.978 .26571 Mdot
.978 .26621 Mdot
.978 .26665 Mdot
.978 .26779 Mdot
.978 .26828 Mdot
.978 .27031 Mdot
.978 .27122 Mdot
.978 .27158 Mdot
.978 .27223 Mdot
.978 .27293 Mdot
.978 .27328 Mdot
.978 .27392 Mdot
.978 .27394 Mdot
.978 .27394 Mdot
.978 .27422 Mdot
.978 .27559 Mdot
.978 .27627 Mdot
.978 .2768 Mdot
.978 .27918 Mdot
.978 .27951 Mdot
.978 .28241 Mdot
.978 .28358 Mdot
.978 .28387 Mdot
.978 .28396 Mdot
.978 .28426 Mdot
.978 .2844 Mdot
.978 .28452 Mdot
.978 .28994 Mdot
.978 .29034 Mdot
.978 .29121 Mdot
.978 .29147 Mdot
.978 .29332 Mdot
.978 .2936 Mdot
.978 .29525 Mdot
.978 .29557 Mdot
.978 .29615 Mdot
.978 .29752 Mdot
.978 .29784 Mdot
.978 .29785 Mdot
.978 .29864 Mdot
.978 .30032 Mdot
.978 .30038 Mdot
.978 .30128 Mdot
.978 .30191 Mdot
.978 .30358 Mdot
.978 .30422 Mdot
.978 .30759 Mdot
.978 .30831 Mdot
.978 .31143 Mdot
.978 .31164 Mdot
.978 .3125 Mdot
.978 .31334 Mdot
.978 .31581 Mdot
.978 .31705 Mdot
.978 .31731 Mdot
.978 .31781 Mdot
.978 .31794 Mdot
.978 .31933 Mdot
.978 .32197 Mdot
.978 .32267 Mdot
.978 .32312 Mdot
.978 .32385 Mdot
.978 .32499 Mdot
.978 .32519 Mdot
.978 .32545 Mdot
.978 .32579 Mdot
.978 .32725 Mdot
.978 .32802 Mdot
.978 .32939 Mdot
.978 .32974 Mdot
.978 .33065 Mdot
.978 .33093 Mdot
.978 .33153 Mdot
.978 .3327 Mdot
.978 .33282 Mdot
.978 .33449 Mdot
.978 .33696 Mdot
.978 .33737 Mdot
.978 .33822 Mdot
.978 .3387 Mdot
.978 .33906 Mdot
.978 .34124 Mdot
.978 .34331 Mdot
.978 .34409 Mdot
.978 .34514 Mdot
.978 .34533 Mdot
.978 .34535 Mdot
.978 .34658 Mdot
.978 .34709 Mdot
.978 .34732 Mdot
.978 .34765 Mdot
.978 .34892 Mdot
.978 .34929 Mdot
.978 .35149 Mdot
.978 .35157 Mdot
.978 .35329 Mdot
.978 .35442 Mdot
.978 .35446 Mdot
.978 .35453 Mdot
.978 .35673 Mdot
.978 .35712 Mdot
.978 .35774 Mdot
.978 .3589 Mdot
.978 .35916 Mdot
.978 .35974 Mdot
.978 .36095 Mdot
.978 .36181 Mdot
.978 .36185 Mdot
.978 .36214 Mdot
.978 .36282 Mdot
.978 .36302 Mdot
.978 .36398 Mdot
.978 .36401 Mdot
.978 .36454 Mdot
.978 .36492 Mdot
.978 .36519 Mdot
.978 .36601 Mdot
.978 .36631 Mdot
.978 .3669 Mdot
.978 .36718 Mdot
.978 .36723 Mdot
.978 .36803 Mdot
.978 .3685 Mdot
.978 .3696 Mdot
.978 .37021 Mdot
.978 .37104 Mdot
.978 .37207 Mdot
.978 .37272 Mdot
.978 .37276 Mdot
.978 .37345 Mdot
.978 .37353 Mdot
.978 .37394 Mdot
.978 .37428 Mdot
.978 .37478 Mdot
.978 .37541 Mdot
.978 .37561 Mdot
.978 .37584 Mdot
.978 .37596 Mdot
.978 .37625 Mdot
.978 .37669 Mdot
.978 .37692 Mdot
.978 .37736 Mdot
.978 .37805 Mdot
.978 .37841 Mdot
.978 .3793 Mdot
.978 .37993 Mdot
.978 .38048 Mdot
.978 .38101 Mdot
.978 .38103 Mdot
.978 .38134 Mdot
.978 .38165 Mdot
.978 .38317 Mdot
.978 .3832 Mdot
.978 .3835 Mdot
.978 .38359 Mdot
.978 .38439 Mdot
.978 .38443 Mdot
.978 .38572 Mdot
.978 .38681 Mdot
.978 .38769 Mdot
.978 .3882 Mdot
.978 .39005 Mdot
.978 .39155 Mdot
.978 .39183 Mdot
.978 .39204 Mdot
.978 .3931 Mdot
.978 .39344 Mdot
.978 .3942 Mdot
.978 .39507 Mdot
.978 .39573 Mdot
.978 .39585 Mdot
.978 .39621 Mdot
.978 .39671 Mdot
.978 .39681 Mdot
.978 .397 Mdot
.978 .39722 Mdot
.978 .39921 Mdot
.978 .40052 Mdot
.978 .40086 Mdot
.978 .40127 Mdot
.978 .40162 Mdot
.978 .40182 Mdot
.978 .40313 Mdot
.978 .40335 Mdot
.978 .40339 Mdot
.978 .40397 Mdot
.978 .40458 Mdot
.978 .40504 Mdot
.978 .4053 Mdot
.978 .40546 Mdot
.978 .40585 Mdot
.978 .40602 Mdot
.978 .40679 Mdot
.978 .40786 Mdot
.978 .40796 Mdot
.978 .40927 Mdot
.978 .40937 Mdot
.978 .40958 Mdot
.978 .40964 Mdot
.978 .41007 Mdot
.978 .41014 Mdot
.978 .41053 Mdot
.978 .4106 Mdot
.978 .41074 Mdot
.978 .41114 Mdot
.978 .41132 Mdot
.978 .41194 Mdot
.978 .41209 Mdot
.978 .41248 Mdot
.978 .41341 Mdot
.978 .41567 Mdot
.978 .41578 Mdot
.978 .41701 Mdot
.978 .41718 Mdot
.978 .41813 Mdot
.978 .41853 Mdot
.978 .41921 Mdot
.978 .41962 Mdot
.978 .42181 Mdot
.978 .42209 Mdot
.978 .42238 Mdot
.978 .423 Mdot
.978 .42352 Mdot
.978 .42416 Mdot
.978 .42417 Mdot
.978 .42469 Mdot
.978 .42478 Mdot
.978 .42492 Mdot
.978 .42635 Mdot
.978 .42647 Mdot
.978 .42687 Mdot
.978 .42726 Mdot
.978 .42762 Mdot
.978 .4286 Mdot
.978 .42928 Mdot
.978 .42982 Mdot
.978 .42997 Mdot
.978 .43036 Mdot
.978 .43071 Mdot
.978 .43154 Mdot
.978 .43228 Mdot
.978 .43273 Mdot
.978 .43297 Mdot
.978 .4338 Mdot
.978 .43497 Mdot
.978 .43532 Mdot
.978 .43533 Mdot
.978 .43677 Mdot
.978 .43716 Mdot
.978 .43734 Mdot
.978 .43848 Mdot
.978 .43874 Mdot
.978 .43909 Mdot
.978 .43967 Mdot
.978 .44015 Mdot
.978 .44078 Mdot
.978 .44096 Mdot
.978 .44119 Mdot
.978 .44148 Mdot
.978 .44161 Mdot
.978 .44278 Mdot
.978 .44321 Mdot
.978 .44393 Mdot
.978 .44408 Mdot
.978 .44486 Mdot
.978 .44562 Mdot
.978 .44682 Mdot
.978 .44722 Mdot
.978 .44753 Mdot
.978 .44821 Mdot
.978 .44833 Mdot
.978 .44896 Mdot
.978 .44984 Mdot
.978 .44984 Mdot
.978 .45096 Mdot
.978 .45203 Mdot
.978 .45219 Mdot
.978 .45245 Mdot
.978 .45302 Mdot
.978 .45348 Mdot
.978 .45383 Mdot
.978 .45407 Mdot
.978 .45484 Mdot
.978 .45508 Mdot
.978 .45563 Mdot
.978 .45604 Mdot
.978 .45718 Mdot
.978 .45768 Mdot
.978 .45786 Mdot
.978 .45837 Mdot
.978 .46059 Mdot
.978 .46066 Mdot
.978 .46094 Mdot
.978 .4612 Mdot
.978 .4613 Mdot
.978 .46147 Mdot
.978 .4617 Mdot
.978 .46244 Mdot
.978 .46338 Mdot
.978 .46394 Mdot
.978 .46447 Mdot
.978 .46449 Mdot
.978 .46458 Mdot
.978 .46516 Mdot
.978 .46525 Mdot
.978 .46541 Mdot
.978 .46727 Mdot
.978 .46735 Mdot
.978 .4674 Mdot
.978 .46896 Mdot
.978 .46942 Mdot
.978 .47027 Mdot
.978 .47166 Mdot
.978 .47303 Mdot
.978 .47321 Mdot
.978 .47385 Mdot
.978 .47412 Mdot
.978 .47458 Mdot
.978 .47484 Mdot
.978 .47521 Mdot
.978 .47537 Mdot
.978 .47566 Mdot
.978 .47584 Mdot
.978 .47594 Mdot
.978 .47673 Mdot
.978 .47709 Mdot
.978 .47729 Mdot
.978 .47786 Mdot
.978 .47889 Mdot
.978 .47953 Mdot
.978 .48024 Mdot
.978 .48097 Mdot
.978 .48118 Mdot
.978 .48293 Mdot
.978 .48316 Mdot
.978 .48374 Mdot
.978 .48399 Mdot
.978 .48415 Mdot
.978 .48504 Mdot
.978 .48506 Mdot
.978 .48508 Mdot
.978 .48623 Mdot
.978 .48714 Mdot
.978 .48802 Mdot
.978 .48822 Mdot
.978 .48872 Mdot
.978 .48921 Mdot
.978 .48952 Mdot
.978 .49034 Mdot
.978 .4912 Mdot
.978 .49203 Mdot
.978 .493 Mdot
.978 .49369 Mdot
.978 .49415 Mdot
.978 .49485 Mdot
.978 .49552 Mdot
.978 .49638 Mdot
.978 .49651 Mdot
.978 .49661 Mdot
.978 .49713 Mdot
.978 .49741 Mdot
.978 .49759 Mdot
.978 .49786 Mdot
.978 .49887 Mdot
.978 .49945 Mdot
.978 .49965 Mdot
.978 .50022 Mdot
.978 .50307 Mdot
.978 .50334 Mdot
.978 .50485 Mdot
.978 .50548 Mdot
.978 .50572 Mdot
.978 .50605 Mdot
.978 .5067 Mdot
.978 .507 Mdot
.978 .50713 Mdot
.978 .50763 Mdot
.978 .50785 Mdot
.978 .50797 Mdot
.978 .50859 Mdot
.978 .50869 Mdot
.978 .50938 Mdot
.978 .50947 Mdot
.978 .5098 Mdot
.978 .50994 Mdot
.978 .51195 Mdot
.978 .51199 Mdot
.978 .51215 Mdot
.978 .51379 Mdot
.978 .51497 Mdot
.978 .51522 Mdot
.978 .51572 Mdot
.978 .51582 Mdot
.978 .51583 Mdot
.978 .51607 Mdot
.978 .51645 Mdot
.978 .51668 Mdot
.978 .51714 Mdot
.978 .51806 Mdot
.978 .51892 Mdot
.978 .51898 Mdot
.978 .5193 Mdot
.978 .51949 Mdot
.978 .52122 Mdot
.978 .52153 Mdot
.978 .52204 Mdot
.978 .52263 Mdot
.978 .52311 Mdot
.978 .52423 Mdot
.978 .52485 Mdot
.978 .52499 Mdot
.978 .52525 Mdot
.978 .52564 Mdot
.978 .52581 Mdot
.978 .52634 Mdot
.978 .5265 Mdot
.978 .52748 Mdot
.978 .52779 Mdot
.978 .52791 Mdot
.978 .52799 Mdot
.978 .52809 Mdot
.978 .52818 Mdot
.978 .52836 Mdot
.978 .5285 Mdot
.978 .5292 Mdot
.978 .52969 Mdot
.978 .52985 Mdot
.978 .52989 Mdot
.978 .53075 Mdot
.978 .53193 Mdot
.978 .53295 Mdot
.978 .53296 Mdot
.978 .53297 Mdot
.978 .53341 Mdot
.978 .53341 Mdot
.978 .53464 Mdot
.978 .53468 Mdot
.978 .5347 Mdot
.978 .53481 Mdot
.978 .53505 Mdot
.978 .53509 Mdot
.978 .53522 Mdot
.978 .53527 Mdot
.978 .53536 Mdot
.978 .53546 Mdot
.978 .5374 Mdot
.978 .53847 Mdot
.978 .53953 Mdot
.978 .53977 Mdot
.978 .5404 Mdot
.978 .54149 Mdot
.978 .54175 Mdot
.978 .5418 Mdot
.978 .54267 Mdot
.978 .54284 Mdot
.978 .54301 Mdot
.978 .54317 Mdot
.978 .54441 Mdot
.978 .54445 Mdot
.978 .54541 Mdot
.978 .54552 Mdot
.978 .54562 Mdot
.978 .54577 Mdot
.978 .54588 Mdot
.978 .54591 Mdot
.978 .54611 Mdot
.978 .54631 Mdot
.978 .54769 Mdot
.978 .54795 Mdot
.978 .54805 Mdot
.978 .54841 Mdot
.978 .54843 Mdot
.978 .54904 Mdot
.978 .54966 Mdot
.978 .55001 Mdot
.978 .55019 Mdot
.978 .55038 Mdot
.978 .55064 Mdot
.978 .55066 Mdot
.978 .55121 Mdot
.978 .55137 Mdot
.978 .55149 Mdot
.978 .55177 Mdot
.978 .55182 Mdot
.978 .55207 Mdot
.978 .55216 Mdot
.978 .55245 Mdot
.978 .55254 Mdot
.978 .55302 Mdot
.978 .55326 Mdot
.978 .55338 Mdot
.978 .55363 Mdot
.978 .55374 Mdot
.978 .55405 Mdot
.978 .55418 Mdot
.978 .55442 Mdot
.978 .55464 Mdot
.978 .55491 Mdot
.978 .55531 Mdot
.978 .55583 Mdot
.978 .55619 Mdot
.978 .55633 Mdot
.978 .55662 Mdot
.978 .5567 Mdot
.978 .55677 Mdot
.978 .5568 Mdot
.978 .5573 Mdot
.978 .55741 Mdot
.978 .55745 Mdot
.978 .55812 Mdot
.978 .55831 Mdot
.978 .55875 Mdot
.978 .5588 Mdot
.978 .55915 Mdot
.978 .5599 Mdot
.978 .55998 Mdot
.978 .56057 Mdot
.978 .56062 Mdot
.978 .561 Mdot
.978 .56163 Mdot
.978 .56208 Mdot
.978 .56266 Mdot
.978 .56285 Mdot
.978 .56289 Mdot
.978 .56316 Mdot
.978 .56358 Mdot
.978 .5637 Mdot
.978 .56397 Mdot
.978 .56473 Mdot
.978 .56497 Mdot
.978 .56531 Mdot
.978 .56548 Mdot
.978 .56552 Mdot
.978 .56578 Mdot
.978 .56581 Mdot
.978 .56666 Mdot
.978 .56672 Mdot
.978 .56683 Mdot
.978 .56742 Mdot
.978 .56767 Mdot
.978 .5677 Mdot
.978 .56786 Mdot
.978 .56814 Mdot
.978 .56843 Mdot
.978 .56933 Mdot
.978 .56944 Mdot
.978 .56991 Mdot
.978 .57001 Mdot
.978 .57012 Mdot
.978 .57015 Mdot
.978 .57105 Mdot
.978 .57153 Mdot
.978 .57184 Mdot
.978 .5735 Mdot
.978 .57355 Mdot
.978 .57358 Mdot
.978 .57373 Mdot
.978 .57412 Mdot
.978 .5744 Mdot
.978 .57475 Mdot
.978 .57487 Mdot
.978 .57507 Mdot
.978 .57543 Mdot
.978 .57562 Mdot
.978 .57567 Mdot
.978 .57573 Mdot
.978 .5765 Mdot
.978 .57683 Mdot
.978 .57715 Mdot
.978 .5774 Mdot
.978 .57815 Mdot
.978 .57821 Mdot
.978 .57842 Mdot
.978 .57855 Mdot
.978 .57871 Mdot
.978 .57887 Mdot
.978 .57893 Mdot
.978 .57932 Mdot
.978 .57961 Mdot
.978 .57962 Mdot
.978 .57974 Mdot
.978 .57974 Mdot
.978 .57995 Mdot
.978 .58032 Mdot
.978 .58033 Mdot
.978 .58033 Mdot
.978 .58034 Mdot
.978 .58049 Mdot
.978 .58079 Mdot
.978 .58125 Mdot
.978 .58162 Mdot
.978 .5819 Mdot
.978 .5819 Mdot
.978 .58301 Mdot
.978 .5831 Mdot
.978 .58319 Mdot
.978 .58326 Mdot
.978 .58342 Mdot
.978 .58382 Mdot
.978 .58401 Mdot
.978 .58459 Mdot
.978 .58509 Mdot
.978 .58509 Mdot
.978 .58521 Mdot
.978 .58525 Mdot
.978 .58537 Mdot
.978 .58543 Mdot
.978 .58547 Mdot
.978 .58576 Mdot
.978 .5858 Mdot
.978 .58625 Mdot
.978 .58647 Mdot
.978 .58656 Mdot
.978 .58688 Mdot
.978 .587 Mdot
.978 .58741 Mdot
.978 .58744 Mdot
.978 .58753 Mdot
.978 .58767 Mdot
.978 .58779 Mdot
.978 .58787 Mdot
.978 .58809 Mdot
.978 .58818 Mdot
.978 .58825 Mdot
.978 .5883 Mdot
.978 .58837 Mdot
.978 .58844 Mdot
.978 .58859 Mdot
.978 .58877 Mdot
.978 .58884 Mdot
.978 .58887 Mdot
.978 .58891 Mdot
.978 .58902 Mdot
.978 .58903 Mdot
.978 .58931 Mdot
.978 .58937 Mdot
.978 .58937 Mdot
.978 .58951 Mdot
.978 .58952 Mdot
.978 .58974 Mdot
.978 .58976 Mdot
.978 .58977 Mdot
.978 .58978 Mdot
.978 .58983 Mdot
.978 .58987 Mdot
.978 .5899 Mdot
.978 .58998 Mdot
.978 .59002 Mdot
.978 .59015 Mdot
.978 .5902 Mdot
.978 .59024 Mdot
.978 .59029 Mdot
.978 .59034 Mdot
.978 .59035 Mdot
.978 .59038 Mdot
.978 .59039 Mdot
.98 .05094 Mdot
.98 .05094 Mdot
.98 .05095 Mdot
.98 .05097 Mdot
.98 .05097 Mdot
.98 .05101 Mdot
.98 .05102 Mdot
.98 .05106 Mdot
.98 .05107 Mdot
.98 .05108 Mdot
.98 .05108 Mdot
.98 .05109 Mdot
.98 .0512 Mdot
.98 .05124 Mdot
.98 .05137 Mdot
.98 .05139 Mdot
.98 .05153 Mdot
.98 .05158 Mdot
.98 .05194 Mdot
.98 .05213 Mdot
.98 .05214 Mdot
.98 .05248 Mdot
.98 .05281 Mdot
.98 .05289 Mdot
.98 .05318 Mdot
.98 .0533 Mdot
.98 .05338 Mdot
.98 .05342 Mdot
.98 .05389 Mdot
.98 .05401 Mdot
.98 .05406 Mdot
.98 .05436 Mdot
.98 .05465 Mdot
.98 .05472 Mdot
.98 .05566 Mdot
.98 .05579 Mdot
.98 .05597 Mdot
.98 .05631 Mdot
.98 .05657 Mdot
.98 .05685 Mdot
.98 .05771 Mdot
.98 .05803 Mdot
.98 .05815 Mdot
.98 .05817 Mdot
.98 .05831 Mdot
.98 .05897 Mdot
.98 .05967 Mdot
.98 .06117 Mdot
.98 .06126 Mdot
.98 .0618 Mdot
.98 .06183 Mdot
.98 .06209 Mdot
.98 .06306 Mdot
.98 .06468 Mdot
.98 .06518 Mdot
.98 .0667 Mdot
.98 .06689 Mdot
.98 .06693 Mdot
.98 .06718 Mdot
.98 .0673 Mdot
.98 .06763 Mdot
.98 .06885 Mdot
.98 .06913 Mdot
.98 .06972 Mdot
.98 .06977 Mdot
.98 .06981 Mdot
.98 .06986 Mdot
.98 .07008 Mdot
.98 .07008 Mdot
.98 .07054 Mdot
.98 .07063 Mdot
.98 .07069 Mdot
.98 .07107 Mdot
.98 .0711 Mdot
.98 .07114 Mdot
.98 .07118 Mdot
.98 .07126 Mdot
.98 .07128 Mdot
.98 .0714 Mdot
.98 .07148 Mdot
.98 .07182 Mdot
.98 .07218 Mdot
.98 .07265 Mdot
.98 .07306 Mdot
.98 .07457 Mdot
.98 .07476 Mdot
.98 .07478 Mdot
.98 .07486 Mdot
.98 .07543 Mdot
.98 .07598 Mdot
.98 .07621 Mdot
.98 .07652 Mdot
.98 .07692 Mdot
.98 .07712 Mdot
.98 .07734 Mdot
.98 .07946 Mdot
.98 .07958 Mdot
.98 .08002 Mdot
.98 .08026 Mdot
.98 .08085 Mdot
.98 .08152 Mdot
.98 .08165 Mdot
.98 .0817 Mdot
.98 .08179 Mdot
.98 .08394 Mdot
.98 .08397 Mdot
.98 .08439 Mdot
.98 .08451 Mdot
.98 .08458 Mdot
.98 .0848 Mdot
.98 .08572 Mdot
.98 .08774 Mdot
.98 .08941 Mdot
.98 .08972 Mdot
.98 .08976 Mdot
.98 .09062 Mdot
.98 .09434 Mdot
.98 .09559 Mdot
.98 .09618 Mdot
.98 .09882 Mdot
.98 .09935 Mdot
.98 .10034 Mdot
.98 .10238 Mdot
.98 .1036 Mdot
.98 .10433 Mdot
.98 .10488 Mdot
.98 .10554 Mdot
.98 .10685 Mdot
.98 .11044 Mdot
.98 .11048 Mdot
.98 .1118 Mdot
.98 .11245 Mdot
.98 .11266 Mdot
.98 .11435 Mdot
.98 .1149 Mdot
.98 .11529 Mdot
.98 .11588 Mdot
.98 .11593 Mdot
.98 .11664 Mdot
.98 .11766 Mdot
.98 .12087 Mdot
.98 .12149 Mdot
.98 .1215 Mdot
.98 .12309 Mdot
.98 .12463 Mdot
.98 .12478 Mdot
.98 .12555 Mdot
.98 .12556 Mdot
.98 .12557 Mdot
.98 .12563 Mdot
.98 .12563 Mdot
.98 .12576 Mdot
.98 .12579 Mdot
.98 .1258 Mdot
.98 .12592 Mdot
.98 .12594 Mdot
.98 .12596 Mdot
.98 .12597 Mdot
.98 .126 Mdot
.98 .12634 Mdot
.98 .12645 Mdot
.98 .12684 Mdot
.98 .12691 Mdot
.98 .12725 Mdot
.98 .12733 Mdot
.98 .12748 Mdot
.98 .12855 Mdot
.98 .12857 Mdot
.98 .12915 Mdot
.98 .12918 Mdot
.98 .13021 Mdot
.98 .13027 Mdot
.98 .13119 Mdot
.98 .13143 Mdot
.98 .13231 Mdot
.98 .13268 Mdot
.98 .1329 Mdot
.98 .13303 Mdot
.98 .13408 Mdot
.98 .13444 Mdot
.98 .13472 Mdot
.98 .13481 Mdot
.98 .13497 Mdot
.98 .13586 Mdot
.98 .13674 Mdot
.98 .13694 Mdot
.98 .13785 Mdot
.98 .13878 Mdot
.98 .13976 Mdot
.98 .13977 Mdot
.98 .14017 Mdot
.98 .14019 Mdot
.98 .14072 Mdot
.98 .14127 Mdot
.98 .14172 Mdot
.98 .1425 Mdot
.98 .14334 Mdot
.98 .14594 Mdot
.98 .1469 Mdot
.98 .14725 Mdot
.98 .14732 Mdot
.98 .14737 Mdot
.98 .14772 Mdot
.98 .14832 Mdot
.98 .14842 Mdot
.98 .14971 Mdot
.98 .15007 Mdot
.98 .15092 Mdot
.98 .15106 Mdot
.98 .15133 Mdot
.98 .15138 Mdot
.98 .15147 Mdot
.98 .15179 Mdot
.98 .15233 Mdot
.98 .15484 Mdot
.98 .15543 Mdot
.98 .15628 Mdot
.98 .15654 Mdot
.98 .15817 Mdot
.98 .15823 Mdot
.98 .15841 Mdot
.98 .15903 Mdot
.98 .15918 Mdot
.98 .1596 Mdot
.98 .16155 Mdot
.98 .16181 Mdot
.98 .16191 Mdot
.98 .1629 Mdot
.98 .16312 Mdot
.98 .16318 Mdot
.98 .16645 Mdot
.98 .16673 Mdot
.98 .1682 Mdot
.98 .1692 Mdot
.98 .16948 Mdot
.98 .16987 Mdot
.98 .17271 Mdot
.98 .17279 Mdot
.98 .17329 Mdot
.98 .17339 Mdot
.98 .17359 Mdot
.98 .17413 Mdot
.98 .17451 Mdot
.98 .17475 Mdot
.98 .17546 Mdot
.98 .17584 Mdot
.98 .17908 Mdot
.98 .17989 Mdot
.98 .18164 Mdot
.98 .1818 Mdot
.98 .18182 Mdot
.98 .18192 Mdot
.98 .18206 Mdot
.98 .1827 Mdot
.98 .18271 Mdot
.98 .18405 Mdot
.98 .18432 Mdot
.98 .18448 Mdot
.98 .18561 Mdot
.98 .18571 Mdot
.98 .18583 Mdot
.98 .18593 Mdot
.98 .18616 Mdot
.98 .18623 Mdot
.98 .18657 Mdot
.98 .18682 Mdot
.98 .18727 Mdot
.98 .18781 Mdot
.98 .18862 Mdot
.98 .18886 Mdot
.98 .18912 Mdot
.98 .1894 Mdot
.98 .19025 Mdot
.98 .19146 Mdot
.98 .19255 Mdot
.98 .19588 Mdot
.98 .19608 Mdot
.98 .19644 Mdot
.98 .1965 Mdot
.98 .19671 Mdot
.98 .19738 Mdot
.98 .19795 Mdot
.98 .1984 Mdot
.98 .19908 Mdot
.98 .19923 Mdot
.98 .19999 Mdot
.98 .20066 Mdot
.98 .20128 Mdot
.98 .20156 Mdot
.98 .20272 Mdot
.98 .20289 Mdot
.98 .20331 Mdot
.98 .20396 Mdot
.98 .20438 Mdot
.98 .20459 Mdot
.98 .205 Mdot
.98 .20565 Mdot
.98 .20608 Mdot
.98 .20639 Mdot
.98 .20653 Mdot
.98 .20711 Mdot
.98 .20798 Mdot
.98 .20816 Mdot
.98 .20867 Mdot
.98 .20927 Mdot
.98 .20971 Mdot
.98 .21006 Mdot
.98 .21011 Mdot
.98 .21045 Mdot
.98 .21172 Mdot
.98 .21242 Mdot
.98 .21282 Mdot
.98 .21413 Mdot
.98 .21479 Mdot
.98 .21499 Mdot
.98 .21607 Mdot
.98 .21644 Mdot
.98 .21658 Mdot
.98 .21683 Mdot
.98 .21757 Mdot
.98 .2179 Mdot
.98 .2181 Mdot
.98 .21899 Mdot
.98 .21994 Mdot
.98 .2224 Mdot
.98 .22303 Mdot
.98 .2231 Mdot
.98 .22314 Mdot
.98 .22372 Mdot
.98 .22431 Mdot
.98 .22452 Mdot
.98 .22467 Mdot
.98 .22486 Mdot
.98 .2255 Mdot
.98 .22612 Mdot
.98 .2268 Mdot
.98 .22686 Mdot
.98 .22812 Mdot
.98 .22907 Mdot
.98 .22919 Mdot
.98 .22948 Mdot
.98 .22959 Mdot
.98 .23049 Mdot
.98 .23193 Mdot
.98 .2338 Mdot
.98 .23388 Mdot
.98 .23441 Mdot
.98 .23805 Mdot
.98 .23863 Mdot
.98 .23951 Mdot
.98 .23963 Mdot
.98 .24156 Mdot
.98 .24164 Mdot
.98 .24206 Mdot
.98 .24281 Mdot
.98 .24531 Mdot
.98 .24545 Mdot
.98 .24573 Mdot
.98 .24662 Mdot
.98 .24904 Mdot
.98 .24953 Mdot
.98 .24985 Mdot
.98 .25118 Mdot
.98 .25254 Mdot
.98 .25418 Mdot
.98 .25462 Mdot
.98 .25521 Mdot
.98 .25581 Mdot
.98 .25605 Mdot
.98 .2573 Mdot
.98 .2577 Mdot
.98 .25798 Mdot
.98 .25824 Mdot
.98 .26173 Mdot
.98 .26258 Mdot
.98 .26505 Mdot
.98 .26529 Mdot
.98 .26653 Mdot
.98 .26925 Mdot
.98 .26968 Mdot
.98 .27073 Mdot
.98 .2723 Mdot
.98 .27242 Mdot
.98 .27277 Mdot
.98 .27406 Mdot
.98 .27452 Mdot
.98 .27487 Mdot
.98 .27534 Mdot
.98 .27747 Mdot
.98 .27823 Mdot
.98 .27825 Mdot
.98 .28022 Mdot
.98 .28045 Mdot
.98 .28069 Mdot
.98 .28171 Mdot
.98 .28215 Mdot
.98 .28235 Mdot
.98 .28353 Mdot
.98 .28383 Mdot
.98 .28386 Mdot
.98 .28567 Mdot
.98 .28709 Mdot
.98 .28826 Mdot
.98 .29042 Mdot
.98 .29118 Mdot
.98 .29193 Mdot
.98 .29443 Mdot
.98 .2949 Mdot
.98 .29679 Mdot
.98 .29689 Mdot
.98 .29738 Mdot
.98 .29799 Mdot
.98 .2992 Mdot
.98 .29935 Mdot
.98 .30042 Mdot
.98 .3012 Mdot
.98 .30215 Mdot
.98 .30272 Mdot
.98 .30398 Mdot
.98 .30579 Mdot
.98 .30667 Mdot
.98 .30721 Mdot
.98 .3085 Mdot
.98 .30868 Mdot
.98 .30971 Mdot
.98 .31015 Mdot
.98 .31016 Mdot
.98 .31075 Mdot
.98 .31127 Mdot
.98 .31133 Mdot
.98 .31141 Mdot
.98 .31149 Mdot
.98 .31249 Mdot
.98 .31316 Mdot
.98 .31328 Mdot
.98 .31388 Mdot
.98 .31594 Mdot
.98 .31846 Mdot
.98 .31895 Mdot
.98 .31985 Mdot
.98 .32016 Mdot
.98 .32271 Mdot
.98 .3229 Mdot
.98 .32397 Mdot
.98 .32434 Mdot
.98 .32542 Mdot
.98 .32581 Mdot
.98 .32594 Mdot
.98 .32597 Mdot
.98 .32918 Mdot
.98 .32926 Mdot
.98 .32982 Mdot
.98 .33007 Mdot
.98 .33281 Mdot
.98 .33405 Mdot
.98 .33443 Mdot
.98 .33478 Mdot
.98 .33639 Mdot
.98 .33642 Mdot
.98 .33645 Mdot
.98 .33661 Mdot
.98 .33661 Mdot
.98 .33694 Mdot
.98 .337 Mdot
.98 .33704 Mdot
.98 .33731 Mdot
.98 .33734 Mdot
.98 .33739 Mdot
.98 .33745 Mdot
.98 .33746 Mdot
.98 .33754 Mdot
.98 .33808 Mdot
.98 .33841 Mdot
.98 .33869 Mdot
.98 .33969 Mdot
.98 .33987 Mdot
.98 .34024 Mdot
.98 .34073 Mdot
.98 .34093 Mdot
.98 .34118 Mdot
.98 .3413 Mdot
.98 .34144 Mdot
.98 .34279 Mdot
.98 .34305 Mdot
.98 .34393 Mdot
.98 .34403 Mdot
.98 .34408 Mdot
.98 .3453 Mdot
.98 .34553 Mdot
.98 .3456 Mdot
.98 .34625 Mdot
.98 .34819 Mdot
.98 .34835 Mdot
.98 .35065 Mdot
.98 .35125 Mdot
.98 .35346 Mdot
.98 .35437 Mdot
.98 .35492 Mdot
.98 .35524 Mdot
.98 .35576 Mdot
.98 .35784 Mdot
.98 .35786 Mdot
.98 .3584 Mdot
.98 .35867 Mdot
.98 .35875 Mdot
.98 .35944 Mdot
.98 .35966 Mdot
.98 .36005 Mdot
.98 .36224 Mdot
.98 .36349 Mdot
.98 .36441 Mdot
.98 .36489 Mdot
.98 .36711 Mdot
.98 .36887 Mdot
.98 .36938 Mdot
.98 .37175 Mdot
.98 .37178 Mdot
.98 .37265 Mdot
.98 .37274 Mdot
.98 .37278 Mdot
.98 .37306 Mdot
.98 .37387 Mdot
.98 .37406 Mdot
.98 .37501 Mdot
.98 .37538 Mdot
.98 .37608 Mdot
.98 .37648 Mdot
.98 .37751 Mdot
.98 .37834 Mdot
.98 .37966 Mdot
.98 .38033 Mdot
.98 .38208 Mdot
.98 .38403 Mdot
.98 .38514 Mdot
.98 .38649 Mdot
.98 .38665 Mdot
.98 .38696 Mdot
.98 .387 Mdot
.98 .388 Mdot
.98 .38841 Mdot
.98 .38875 Mdot
.98 .38895 Mdot
.98 .38915 Mdot
.98 .38938 Mdot
.98 .38943 Mdot
.98 .38957 Mdot
.98 .38973 Mdot
.98 .38985 Mdot
.98 .39068 Mdot
.98 .39202 Mdot
.98 .39207 Mdot
.98 .39231 Mdot
.98 .39416 Mdot
.98 .39435 Mdot
.98 .39506 Mdot
.98 .39529 Mdot
.98 .39613 Mdot
.98 .39629 Mdot
.98 .39721 Mdot
.98 .39809 Mdot
.98 .3984 Mdot
.98 .39903 Mdot
.98 .39913 Mdot
.98 .39936 Mdot
.98 .40008 Mdot
.98 .40133 Mdot
.98 .40215 Mdot
.98 .40222 Mdot
.98 .40498 Mdot
.98 .40561 Mdot
.98 .40572 Mdot
.98 .40603 Mdot
.98 .40614 Mdot
.98 .40684 Mdot
.98 .40703 Mdot
.98 .40755 Mdot
.98 .40836 Mdot
.98 .41025 Mdot
.98 .41084 Mdot
.98 .41195 Mdot
.98 .41448 Mdot
.98 .41448 Mdot
.98 .41462 Mdot
.98 .41479 Mdot
.98 .41502 Mdot
.98 .41639 Mdot
.98 .4167 Mdot
.98 .41736 Mdot
.98 .41765 Mdot
.98 .41798 Mdot
.98 .41885 Mdot
.98 .42085 Mdot
.98 .42192 Mdot
.98 .42249 Mdot
.98 .4227 Mdot
.98 .42485 Mdot
.98 .42532 Mdot
.98 .42545 Mdot
.98 .42876 Mdot
.98 .42976 Mdot
.98 .43191 Mdot
.98 .43239 Mdot
.98 .43246 Mdot
.98 .43304 Mdot
.98 .43353 Mdot
.98 .43422 Mdot
.98 .43616 Mdot
.98 .43658 Mdot
.98 .43759 Mdot
.98 .43824 Mdot
.98 .43883 Mdot
.98 .43918 Mdot
.98 .43964 Mdot
.98 .44148 Mdot
.98 .44171 Mdot
.98 .44233 Mdot
.98 .44276 Mdot
.98 .44452 Mdot
.98 .44519 Mdot
.98 .4455 Mdot
.98 .44583 Mdot
.98 .44669 Mdot
.98 .4469 Mdot
.98 .44719 Mdot
.98 .44731 Mdot
.98 .44841 Mdot
.98 .44917 Mdot
.98 .44965 Mdot
.98 .45077 Mdot
.98 .4511 Mdot
.98 .45164 Mdot
.98 .45187 Mdot
.98 .45287 Mdot
.98 .45334 Mdot
.98 .45699 Mdot
.98 .45791 Mdot
.98 .4583 Mdot
.98 .45859 Mdot
.98 .45975 Mdot
.98 .45989 Mdot
.98 .46102 Mdot
.98 .46298 Mdot
.98 .4633 Mdot
.98 .46361 Mdot
.98 .46366 Mdot
.98 .46379 Mdot
.98 .46384 Mdot
.98 .46412 Mdot
.98 .46534 Mdot
.98 .46536 Mdot
.98 .46752 Mdot
.98 .46792 Mdot
.98 .46845 Mdot
.98 .46875 Mdot
.98 .46884 Mdot
.98 .46976 Mdot
.98 .47087 Mdot
.98 .47089 Mdot
.98 .47099 Mdot
.98 .47107 Mdot
.98 .4713 Mdot
.98 .47148 Mdot
.98 .4719 Mdot
.98 .47192 Mdot
.98 .47205 Mdot
.98 .47269 Mdot
.98 .47316 Mdot
.98 .47399 Mdot
.98 .475 Mdot
.98 .47591 Mdot
.98 .4765 Mdot
.98 .47695 Mdot
.98 .47742 Mdot
.98 .47775 Mdot
.98 .47793 Mdot
.98 .47949 Mdot
.98 .48169 Mdot
.98 .48365 Mdot
.98 .48376 Mdot
.98 .48398 Mdot
.98 .48482 Mdot
.98 .48862 Mdot
.98 .489 Mdot
.98 .48954 Mdot
.98 .48989 Mdot
.98 .48999 Mdot
.98 .49053 Mdot
.98 .49063 Mdot
.98 .491 Mdot
.98 .49185 Mdot
.98 .49215 Mdot
.98 .49314 Mdot
.98 .49391 Mdot
.98 .49507 Mdot
.98 .49528 Mdot
.98 .49532 Mdot
.98 .49662 Mdot
.98 .49677 Mdot
.98 .49733 Mdot
.98 .49774 Mdot
.98 .49781 Mdot
.98 .49879 Mdot
.98 .49891 Mdot
.98 .49926 Mdot
.98 .49944 Mdot
.98 .50119 Mdot
.98 .50146 Mdot
.98 .50171 Mdot
.98 .50209 Mdot
.98 .50215 Mdot
.98 .50237 Mdot
.98 .5026 Mdot
.98 .5026 Mdot
.98 .50322 Mdot
.98 .50391 Mdot
.98 .50424 Mdot
.98 .50492 Mdot
.98 .50597 Mdot
.98 .50666 Mdot
.98 .50671 Mdot
.98 .50716 Mdot
.98 .50739 Mdot
.98 .50832 Mdot
.98 .50849 Mdot
.98 .50942 Mdot
.98 .5097 Mdot
.98 .50998 Mdot
.98 .51077 Mdot
.98 .51173 Mdot
.98 .51239 Mdot
.98 .5124 Mdot
.98 .51295 Mdot
.98 .51302 Mdot
.98 .51356 Mdot
.98 .51364 Mdot
.98 .51445 Mdot
.98 .51473 Mdot
.98 .51551 Mdot
.98 .51581 Mdot
.98 .51597 Mdot
.98 .51644 Mdot
.98 .51657 Mdot
.98 .51661 Mdot
.98 .51718 Mdot
.98 .51756 Mdot
.98 .51915 Mdot
.98 .52012 Mdot
.98 .52043 Mdot
.98 .52168 Mdot
.98 .52178 Mdot
.98 .52202 Mdot
.98 .52255 Mdot
.98 .52277 Mdot
.98 .52298 Mdot
.98 .52313 Mdot
.98 .52421 Mdot
.98 .52468 Mdot
.98 .52479 Mdot
.98 .52497 Mdot
.98 .52583 Mdot
.98 .52614 Mdot
.98 .52624 Mdot
.98 .52629 Mdot
.98 .52718 Mdot
.98 .52759 Mdot
.98 .52762 Mdot
.98 .52886 Mdot
.98 .53014 Mdot
.98 .53035 Mdot
.98 .53101 Mdot
.98 .53151 Mdot
.98 .53182 Mdot
.98 .53186 Mdot
.98 .53197 Mdot
.98 .53201 Mdot
.98 .53278 Mdot
.98 .5328 Mdot
.98 .53304 Mdot
.98 .5336 Mdot
.98 .53388 Mdot
.98 .53408 Mdot
.98 .53434 Mdot
.98 .53519 Mdot
.98 .53552 Mdot
.98 .53583 Mdot
.98 .5359 Mdot
.98 .53601 Mdot
.98 .53691 Mdot
.98 .53698 Mdot
.98 .53766 Mdot
.98 .53861 Mdot
.98 .53874 Mdot
.98 .53888 Mdot
.98 .53909 Mdot
.98 .53927 Mdot
.98 .53933 Mdot
.98 .53963 Mdot
.98 .53983 Mdot
.98 .53988 Mdot
.98 .53999 Mdot
.98 .54013 Mdot
.98 .54036 Mdot
.98 .5405 Mdot
.98 .54057 Mdot
.98 .54108 Mdot
.98 .54163 Mdot
.98 .54234 Mdot
.98 .54239 Mdot
.98 .54278 Mdot
.98 .54297 Mdot
.98 .54342 Mdot
.98 .54462 Mdot
.98 .5457 Mdot
.98 .54579 Mdot
.98 .54596 Mdot
.98 .54643 Mdot
.98 .54828 Mdot
.98 .5503 Mdot
.98 .55067 Mdot
.98 .55106 Mdot
.98 .55133 Mdot
.98 .55232 Mdot
.98 .55245 Mdot
.98 .55255 Mdot
.98 .55347 Mdot
.98 .55457 Mdot
.98 .55459 Mdot
.98 .55466 Mdot
.98 .55503 Mdot
.98 .55512 Mdot
.98 .55577 Mdot
.98 .55592 Mdot
.98 .55617 Mdot
.98 .55717 Mdot
.98 .55737 Mdot
.98 .55821 Mdot
.98 .5585 Mdot
.98 .55853 Mdot
.98 .55854 Mdot
.98 .55863 Mdot
.98 .55868 Mdot
.98 .55896 Mdot
.98 .55952 Mdot
.98 .55955 Mdot
.98 .55987 Mdot
.98 .5619 Mdot
.98 .56226 Mdot
.98 .5624 Mdot
.98 .56273 Mdot
.98 .56304 Mdot
.98 .56408 Mdot
.98 .56429 Mdot
.98 .56555 Mdot
.98 .56612 Mdot
.98 .56655 Mdot
.98 .56703 Mdot
.98 .56737 Mdot
.98 .56742 Mdot
.98 .56793 Mdot
.98 .56846 Mdot
.98 .56846 Mdot
.98 .56867 Mdot
.98 .56973 Mdot
.98 .57006 Mdot
.98 .5703 Mdot
.98 .57031 Mdot
.98 .57051 Mdot
.98 .57064 Mdot
.98 .57082 Mdot
.98 .57137 Mdot
.98 .57145 Mdot
.98 .57166 Mdot
.98 .57209 Mdot
.98 .5721 Mdot
.98 .57329 Mdot
.98 .57372 Mdot
.98 .57394 Mdot
.98 .57412 Mdot
.98 .57436 Mdot
.98 .57476 Mdot
.98 .57543 Mdot
.98 .57575 Mdot
.98 .57593 Mdot
.98 .57679 Mdot
.98 .57699 Mdot
.98 .5774 Mdot
.98 .57862 Mdot
.98 .5789 Mdot
.98 .57891 Mdot
.98 .57901 Mdot
.98 .57956 Mdot
.98 .58022 Mdot
.98 .58052 Mdot
.98 .58059 Mdot
.98 .58062 Mdot
.98 .58066 Mdot
.98 .58079 Mdot
.98 .5808 Mdot
.98 .58151 Mdot
.98 .58154 Mdot
.98 .58155 Mdot
.98 .58159 Mdot
.98 .58181 Mdot
.98 .58201 Mdot
.98 .58209 Mdot
.98 .58223 Mdot
.98 .58227 Mdot
.98 .58296 Mdot
.98 .58303 Mdot
.98 .5831 Mdot
.98 .58323 Mdot
.98 .58333 Mdot
.98 .58341 Mdot
.98 .58358 Mdot
.98 .58377 Mdot
.98 .5838 Mdot
.98 .5838 Mdot
.98 .58387 Mdot
.98 .58436 Mdot
.98 .58449 Mdot
.98 .58465 Mdot
.98 .58476 Mdot
.98 .58487 Mdot
.98 .5849 Mdot
.98 .58494 Mdot
.98 .58495 Mdot
.98 .58497 Mdot
.98 .58498 Mdot
.98 .585 Mdot
.98 .58501 Mdot
.98 .58513 Mdot
.98 .58515 Mdot
.98 .58518 Mdot
.98 .58533 Mdot
.98 .58533 Mdot
.98 .5854 Mdot
.98 .58542 Mdot
.98 .58543 Mdot
.98 .58545 Mdot
.98 .58564 Mdot
.98 .58573 Mdot
.98 .58613 Mdot
.98 .58624 Mdot
.98 .58628 Mdot
.98 .58636 Mdot
.98 .58637 Mdot
.98 .58644 Mdot
.98 .58693 Mdot
.98 .58709 Mdot
.98 .58762 Mdot
.98 .58794 Mdot
.98 .58802 Mdot
.98 .58803 Mdot
.98 .58821 Mdot
.98 .58824 Mdot
.98 .58873 Mdot
.98 .58895 Mdot
.98 .58917 Mdot
.98 .58921 Mdot
.98 .58922 Mdot
.98 .58926 Mdot
.98 .58936 Mdot
.98 .58965 Mdot
.98 .58974 Mdot
.98 .58982 Mdot
.98 .58993 Mdot
.98 .58999 Mdot
.98 .59003 Mdot
.98 .59034 Mdot
.98 .59036 Mdot
.98 .59046 Mdot
.98 .59055 Mdot
.98 .59057 Mdot
.98 .59061 Mdot
.98 .59076 Mdot
.98 .59078 Mdot
.98 .5908 Mdot
.98 .59084 Mdot
.98 .59096 Mdot
.98 .59107 Mdot
.98 .59118 Mdot
.98 .59118 Mdot
.98 .59124 Mdot
.98 .59136 Mdot
.98 .59138 Mdot
.98 .59142 Mdot
.98 .59143 Mdot
.98 .59147 Mdot
.98 .59148 Mdot
.98 .59152 Mdot
.98 .59152 Mdot
.98 .59152 Mdot
.98 .59153 Mdot
.98 .59153 Mdot
.98 .59154 Mdot
.98 .59155 Mdot
.98 .59156 Mdot
.98 .59156 Mdot
.98 .59157 Mdot
.98 .59157 Mdot
.98 .59157 Mdot
.982 .04739 Mdot
.982 .11502 Mdot
.982 .30958 Mdot
.982 .59274 Mdot
.984 .04382 Mdot
.984 .04382 Mdot
.984 .04383 Mdot
.984 .04384 Mdot
.984 .04385 Mdot
.984 .04385 Mdot
.984 .04386 Mdot
.984 .04387 Mdot
.984 .04387 Mdot
.984 .04399 Mdot
.984 .04416 Mdot
.984 .04423 Mdot
.984 .04432 Mdot
.984 .04455 Mdot
.984 .0446 Mdot
.984 .04479 Mdot
.984 .04524 Mdot
.984 .04529 Mdot
.984 .04549 Mdot
.984 .04584 Mdot
.984 .04599 Mdot
.984 .04599 Mdot
.984 .04605 Mdot
.984 .04609 Mdot
.984 .04619 Mdot
.984 .04625 Mdot
.984 .04642 Mdot
.984 .04669 Mdot
.984 .04687 Mdot
.984 .04701 Mdot
.984 .04707 Mdot
.984 .04725 Mdot
.984 .04764 Mdot
.984 .04785 Mdot
.984 .04833 Mdot
.984 .0485 Mdot
.984 .04871 Mdot
.984 .04887 Mdot
.984 .04894 Mdot
.984 .04943 Mdot
.984 .04947 Mdot
.984 .04991 Mdot
.984 .05023 Mdot
.984 .05027 Mdot
.984 .05062 Mdot
.984 .05203 Mdot
.984 .05227 Mdot
.984 .05233 Mdot
.984 .05251 Mdot
.984 .05254 Mdot
.984 .05255 Mdot
.984 .05258 Mdot
.984 .05263 Mdot
.984 .05265 Mdot
.984 .05338 Mdot
.984 .05362 Mdot
.984 .05401 Mdot
.984 .05433 Mdot
.984 .05525 Mdot
.984 .05569 Mdot
.984 .05588 Mdot
.984 .0571 Mdot
.984 .0573 Mdot
.984 .05796 Mdot
.984 .0581 Mdot
.984 .05814 Mdot
.984 .05879 Mdot
.984 .05881 Mdot
.984 .05924 Mdot
.984 .05925 Mdot
.984 .05952 Mdot
.984 .0598 Mdot
.984 .06054 Mdot
.984 .06096 Mdot
.984 .06104 Mdot
.984 .06144 Mdot
.984 .06277 Mdot
.984 .06279 Mdot
.984 .06283 Mdot
.984 .06286 Mdot
.984 .06287 Mdot
.984 .06298 Mdot
.984 .06303 Mdot
.984 .06312 Mdot
.984 .06326 Mdot
.984 .06331 Mdot
.984 .06331 Mdot
.984 .06334 Mdot
.984 .06509 Mdot
.984 .06554 Mdot
.984 .06592 Mdot
.984 .06645 Mdot
.984 .06646 Mdot
.984 .06665 Mdot
.984 .06812 Mdot
.984 .06911 Mdot
.984 .07141 Mdot
.984 .07376 Mdot
.984 .07557 Mdot
.984 .07682 Mdot
.984 .08035 Mdot
.984 .08093 Mdot
.984 .08143 Mdot
.984 .08171 Mdot
.984 .08242 Mdot
.984 .08242 Mdot
.984 .08402 Mdot
.984 .08454 Mdot
.984 .08488 Mdot
.984 .08505 Mdot
.984 .08536 Mdot
.984 .08582 Mdot
.984 .08633 Mdot
.984 .08693 Mdot
.984 .08755 Mdot
.984 .08759 Mdot
.984 .08827 Mdot
.984 .0884 Mdot
.984 .08858 Mdot
.984 .08879 Mdot
.984 .08886 Mdot
.984 .08942 Mdot
.984 .09027 Mdot
.984 .09061 Mdot
.984 .091 Mdot
.984 .09193 Mdot
.984 .09197 Mdot
.984 .09202 Mdot
.984 .09425 Mdot
.984 .09527 Mdot
.984 .09595 Mdot
.984 .09616 Mdot
.984 .09678 Mdot
.984 .0975 Mdot
.984 .0979 Mdot
.984 .09873 Mdot
.984 .09975 Mdot
.984 .10192 Mdot
.984 .10316 Mdot
.984 .1035 Mdot
.984 .10368 Mdot
.984 .10377 Mdot
.984 .10389 Mdot
.984 .10434 Mdot
.984 .10434 Mdot
.984 .10435 Mdot
.984 .10439 Mdot
.984 .10441 Mdot
.984 .10442 Mdot
.984 .10445 Mdot
.984 .10447 Mdot
.984 .10448 Mdot
.984 .10484 Mdot
.984 .10538 Mdot
.984 .10559 Mdot
.984 .10579 Mdot
.984 .10584 Mdot
.984 .10604 Mdot
.984 .10657 Mdot
.984 .10671 Mdot
.984 .10703 Mdot
.984 .10729 Mdot
.984 .10769 Mdot
.984 .10781 Mdot
.984 .10866 Mdot
.984 .10882 Mdot
.984 .1093 Mdot
.984 .10942 Mdot
.984 .11037 Mdot
.984 .11041 Mdot
.984 .1105 Mdot
.984 .11093 Mdot
.984 .11096 Mdot
.984 .11114 Mdot
.984 .11125 Mdot
.984 .11155 Mdot
.984 .11174 Mdot
.984 .11179 Mdot
.984 .11227 Mdot
.984 .11307 Mdot
.984 .11362 Mdot
.984 .11404 Mdot
.984 .11414 Mdot
.984 .11417 Mdot
.984 .11423 Mdot
.984 .11439 Mdot
.984 .11478 Mdot
.984 .11512 Mdot
.984 .11597 Mdot
.984 .11661 Mdot
.984 .11807 Mdot
.984 .11812 Mdot
.984 .11815 Mdot
.984 .1186 Mdot
.984 .11922 Mdot
.984 .11972 Mdot
.984 .11992 Mdot
.984 .12079 Mdot
.984 .12141 Mdot
.984 .12153 Mdot
.984 .12162 Mdot
.984 .12166 Mdot
.984 .12195 Mdot
.984 .12288 Mdot
.984 .12329 Mdot
.984 .12362 Mdot
.984 .12385 Mdot
.984 .12398 Mdot
.984 .12437 Mdot
.984 .12504 Mdot
.984 .12518 Mdot
.984 .12932 Mdot
.984 .12962 Mdot
.984 .13004 Mdot
.984 .1302 Mdot
.984 .13039 Mdot
.984 .13063 Mdot
.984 .13076 Mdot
.984 .13086 Mdot
.984 .13087 Mdot
.984 .13098 Mdot
.984 .13114 Mdot
.984 .1312 Mdot
.984 .13216 Mdot
.984 .13339 Mdot
.984 .13413 Mdot
.984 .1353 Mdot
.984 .13628 Mdot
.984 .13657 Mdot
.984 .1384 Mdot
.984 .13905 Mdot
.984 .14016 Mdot
.984 .14036 Mdot
.984 .14045 Mdot
.984 .14062 Mdot
.984 .14095 Mdot
.984 .14095 Mdot
.984 .14136 Mdot
.984 .14253 Mdot
.984 .14463 Mdot
.984 .14524 Mdot
.984 .1458 Mdot
.984 .14697 Mdot
.984 .14723 Mdot
.984 .14765 Mdot
.984 .14775 Mdot
.984 .14816 Mdot
.984 .14845 Mdot
.984 .14914 Mdot
.984 .1497 Mdot
.984 .14973 Mdot
.984 .14978 Mdot
.984 .15107 Mdot
.984 .15108 Mdot
.984 .15127 Mdot
.984 .15189 Mdot
.984 .15196 Mdot
.984 .15261 Mdot
.984 .15275 Mdot
.984 .15328 Mdot
.984 .15495 Mdot
.984 .15571 Mdot
.984 .15586 Mdot
.984 .15586 Mdot
.984 .15623 Mdot
.984 .15646 Mdot
.984 .15768 Mdot
.984 .15909 Mdot
.984 .16165 Mdot
.984 .1617 Mdot
.984 .16182 Mdot
.984 .16193 Mdot
.984 .16196 Mdot
.984 .16227 Mdot
.984 .16244 Mdot
.984 .16269 Mdot
.984 .16312 Mdot
.984 .16326 Mdot
.984 .16326 Mdot
.984 .16336 Mdot
.984 .16371 Mdot
.984 .16523 Mdot
.984 .1676 Mdot
.984 .16767 Mdot
.984 .16854 Mdot
.984 .16857 Mdot
.984 .16913 Mdot
.984 .16977 Mdot
.984 .16992 Mdot
.984 .17105 Mdot
.984 .17182 Mdot
.984 .17261 Mdot
.984 .17265 Mdot
.984 .17307 Mdot
.984 .17322 Mdot
.984 .17363 Mdot
.984 .17475 Mdot
.984 .17489 Mdot
.984 .17757 Mdot
.984 .17766 Mdot
.984 .18053 Mdot
.984 .18178 Mdot
.984 .1821 Mdot
.984 .18438 Mdot
.984 .18608 Mdot
.984 .1873 Mdot
.984 .18855 Mdot
.984 .18964 Mdot
.984 .19129 Mdot
.984 .19141 Mdot
.984 .19237 Mdot
.984 .19424 Mdot
.984 .19482 Mdot
.984 .1962 Mdot
.984 .19955 Mdot
.984 .20029 Mdot
.984 .2032 Mdot
.984 .2052 Mdot
.984 .20652 Mdot
.984 .20854 Mdot
.984 .20864 Mdot
.984 .20885 Mdot
.984 .21048 Mdot
.984 .21165 Mdot
.984 .2126 Mdot
.984 .21262 Mdot
.984 .2135 Mdot
.984 .21357 Mdot
.984 .21419 Mdot
.984 .21518 Mdot
.984 .21654 Mdot
.984 .21662 Mdot
.984 .21726 Mdot
.984 .21743 Mdot
.984 .21949 Mdot
.984 .2195 Mdot
.984 .21989 Mdot
.984 .22001 Mdot
.984 .22412 Mdot
.984 .22561 Mdot
.984 .22627 Mdot
.984 .22658 Mdot
.984 .22706 Mdot
.984 .22709 Mdot
.984 .22796 Mdot
.984 .22927 Mdot
.984 .23075 Mdot
.984 .23141 Mdot
.984 .23167 Mdot
.984 .23216 Mdot
.984 .23246 Mdot
.984 .23426 Mdot
.984 .23435 Mdot
.984 .23631 Mdot
.984 .23635 Mdot
.984 .23667 Mdot
.984 .23683 Mdot
.984 .23719 Mdot
.984 .23779 Mdot
.984 .23798 Mdot
.984 .23841 Mdot
.984 .23843 Mdot
.984 .23959 Mdot
.984 .24202 Mdot
.984 .24298 Mdot
.984 .24407 Mdot
.984 .24429 Mdot
.984 .24438 Mdot
.984 .24513 Mdot
.984 .24619 Mdot
.984 .24671 Mdot
.984 .24681 Mdot
.984 .24687 Mdot
.984 .24697 Mdot
.984 .24755 Mdot
.984 .25018 Mdot
.984 .25053 Mdot
.984 .25209 Mdot
.984 .25277 Mdot
.984 .25325 Mdot
.984 .25338 Mdot
.984 .25615 Mdot
.984 .25616 Mdot
.984 .25804 Mdot
.984 .25863 Mdot
.984 .25894 Mdot
.984 .25934 Mdot
.984 .25944 Mdot
.984 .26027 Mdot
.984 .2603 Mdot
.984 .26038 Mdot
.984 .26103 Mdot
.984 .26238 Mdot
.984 .26292 Mdot
.984 .26323 Mdot
.984 .2635 Mdot
.984 .26536 Mdot
.984 .2654 Mdot
.984 .26583 Mdot
.984 .26695 Mdot
.984 .26704 Mdot
.984 .26829 Mdot
.984 .26866 Mdot
.984 .26917 Mdot
.984 .27105 Mdot
.984 .27363 Mdot
.984 .27466 Mdot
.984 .27605 Mdot
.984 .27808 Mdot
.984 .27904 Mdot
.984 .27952 Mdot
.984 .27977 Mdot
.984 .28008 Mdot
.984 .28132 Mdot
.984 .28132 Mdot
.984 .28136 Mdot
.984 .28146 Mdot
.984 .28152 Mdot
.984 .28156 Mdot
.984 .28164 Mdot
.984 .28164 Mdot
.984 .2817 Mdot
.984 .28171 Mdot
.984 .28269 Mdot
.984 .28299 Mdot
.984 .28305 Mdot
.984 .28395 Mdot
.984 .28417 Mdot
.984 .28439 Mdot
.984 .28475 Mdot
.984 .28529 Mdot
.984 .28544 Mdot
.984 .286 Mdot
.984 .28742 Mdot
.984 .28782 Mdot
.984 .28869 Mdot
.984 .28901 Mdot
.984 .28939 Mdot
.984 .29047 Mdot
.984 .29051 Mdot
.984 .29054 Mdot
.984 .2908 Mdot
.984 .2931 Mdot
.984 .29315 Mdot
.984 .29356 Mdot
.984 .29418 Mdot
.984 .29484 Mdot
.984 .29517 Mdot
.984 .29644 Mdot
.984 .29773 Mdot
.984 .29784 Mdot
.984 .29809 Mdot
.984 .29891 Mdot
.984 .29926 Mdot
.984 .29931 Mdot
.984 .2998 Mdot
.984 .30011 Mdot
.984 .30093 Mdot
.984 .30142 Mdot
.984 .30156 Mdot
.984 .30285 Mdot
.984 .30348 Mdot
.984 .3046 Mdot
.984 .30498 Mdot
.984 .30645 Mdot
.984 .30759 Mdot
.984 .30771 Mdot
.984 .30786 Mdot
.984 .30794 Mdot
.984 .30808 Mdot
.984 .30838 Mdot
.984 .30852 Mdot
.984 .30954 Mdot
.984 .31045 Mdot
.984 .31272 Mdot
.984 .31441 Mdot
.984 .31827 Mdot
.984 .3184 Mdot
.984 .31848 Mdot
.984 .31868 Mdot
.984 .31964 Mdot
.984 .32064 Mdot
.984 .32128 Mdot
.984 .32234 Mdot
.984 .3226 Mdot
.984 .32312 Mdot
.984 .32393 Mdot
.984 .32538 Mdot
.984 .327 Mdot
.984 .32732 Mdot
.984 .32755 Mdot
.984 .32765 Mdot
.984 .32767 Mdot
.984 .32842 Mdot
.984 .33081 Mdot
.984 .33189 Mdot
.984 .33274 Mdot
.984 .33332 Mdot
.984 .33367 Mdot
.984 .33468 Mdot
.984 .33639 Mdot
.984 .33676 Mdot
.984 .33889 Mdot
.984 .3389 Mdot
.984 .3406 Mdot
.984 .34512 Mdot
.984 .34731 Mdot
.984 .34757 Mdot
.984 .34771 Mdot
.984 .34808 Mdot
.984 .34808 Mdot
.984 .34915 Mdot
.984 .34931 Mdot
.984 .34955 Mdot
.984 .35002 Mdot
.984 .35031 Mdot
.984 .35061 Mdot
.984 .35063 Mdot
.984 .35096 Mdot
.984 .3512 Mdot
.984 .35123 Mdot
.984 .3515 Mdot
.984 .3519 Mdot
.984 .35205 Mdot
.984 .35268 Mdot
.984 .35371 Mdot
.984 .35417 Mdot
.984 .35446 Mdot
.984 .35532 Mdot
.984 .35611 Mdot
.984 .35754 Mdot
.984 .35784 Mdot
.984 .35938 Mdot
.984 .36044 Mdot
.984 .36045 Mdot
.984 .36099 Mdot
.984 .36199 Mdot
.984 .36227 Mdot
.984 .3634 Mdot
.984 .36341 Mdot
.984 .36438 Mdot
.984 .3647 Mdot
.984 .36541 Mdot
.984 .36568 Mdot
.984 .36779 Mdot
.984 .3684 Mdot
.984 .3699 Mdot
.984 .37149 Mdot
.984 .3733 Mdot
.984 .37417 Mdot
.984 .37466 Mdot
.984 .37488 Mdot
.984 .37529 Mdot
.984 .37609 Mdot
.984 .37609 Mdot
.984 .37708 Mdot
.984 .37893 Mdot
.984 .3799 Mdot
.984 .38254 Mdot
.984 .38444 Mdot
.984 .38491 Mdot
.984 .38635 Mdot
.984 .38769 Mdot
.984 .39044 Mdot
.984 .39105 Mdot
.984 .39203 Mdot
.984 .39204 Mdot
.984 .39228 Mdot
.984 .39305 Mdot
.984 .39324 Mdot
.984 .39391 Mdot
.984 .39553 Mdot
.984 .39574 Mdot
.984 .39682 Mdot
.984 .39689 Mdot
.984 .39701 Mdot
.984 .4 Mdot
.984 .40002 Mdot
.984 .40021 Mdot
.984 .40046 Mdot
.984 .4019 Mdot
.984 .40206 Mdot
.984 .4022 Mdot
.984 .40354 Mdot
.984 .40363 Mdot
.984 .40366 Mdot
.984 .40386 Mdot
.984 .40404 Mdot
.984 .40506 Mdot
.984 .40507 Mdot
.984 .40576 Mdot
.984 .40596 Mdot
.984 .40888 Mdot
.984 .40919 Mdot
.984 .41058 Mdot
.984 .41093 Mdot
.984 .41094 Mdot
.984 .41177 Mdot
.984 .41229 Mdot
.984 .41389 Mdot
.984 .41415 Mdot
.984 .41501 Mdot
.984 .41733 Mdot
.984 .41815 Mdot
.984 .41935 Mdot
.984 .42186 Mdot
.984 .42224 Mdot
.984 .42379 Mdot
.984 .4239 Mdot
.984 .42418 Mdot
.984 .4244 Mdot
.984 .42446 Mdot
.984 .42492 Mdot
.984 .42515 Mdot
.984 .42525 Mdot
.984 .42551 Mdot
.984 .42607 Mdot
.984 .42665 Mdot
.984 .42699 Mdot
.984 .4273 Mdot
.984 .42731 Mdot
.984 .42752 Mdot
.984 .42781 Mdot
.984 .42828 Mdot
.984 .43156 Mdot
.984 .4339 Mdot
.984 .4345 Mdot
.984 .43551 Mdot
.984 .43628 Mdot
.984 .43637 Mdot
.984 .4366 Mdot
.984 .43675 Mdot
.984 .4368 Mdot
.984 .43859 Mdot
.984 .43865 Mdot
.984 .43937 Mdot
.984 .43983 Mdot
.984 .4411 Mdot
.984 .44118 Mdot
.984 .4415 Mdot
.984 .44176 Mdot
.984 .44354 Mdot
.984 .44372 Mdot
.984 .44373 Mdot
.984 .44384 Mdot
.984 .44545 Mdot
.984 .44706 Mdot
.984 .44707 Mdot
.984 .44715 Mdot
.984 .44801 Mdot
.984 .44832 Mdot
.984 .44915 Mdot
.984 .45037 Mdot
.984 .45057 Mdot
.984 .45061 Mdot
.984 .45098 Mdot
.984 .45145 Mdot
.984 .45173 Mdot
.984 .45456 Mdot
.984 .4551 Mdot
.984 .45574 Mdot
.984 .45589 Mdot
.984 .45712 Mdot
.984 .45729 Mdot
.984 .45843 Mdot
.984 .45934 Mdot
.984 .46076 Mdot
.984 .46088 Mdot
.984 .46297 Mdot
.984 .46439 Mdot
.984 .46448 Mdot
.984 .46478 Mdot
.984 .46523 Mdot
.984 .4654 Mdot
.984 .46541 Mdot
.984 .46603 Mdot
.984 .4669 Mdot
.984 .46883 Mdot
.984 .46998 Mdot
.984 .47041 Mdot
.984 .47363 Mdot
.984 .47442 Mdot
.984 .47593 Mdot
.984 .47826 Mdot
.984 .48027 Mdot
.984 .48052 Mdot
.984 .48138 Mdot
.984 .48191 Mdot
.984 .4823 Mdot
.984 .4823 Mdot
.984 .48287 Mdot
.984 .48328 Mdot
.984 .48349 Mdot
.984 .4835 Mdot
.984 .48455 Mdot
.984 .48524 Mdot
.984 .48556 Mdot
.984 .48602 Mdot
.984 .4862 Mdot
.984 .48661 Mdot
.984 .48743 Mdot
.984 .48755 Mdot
.984 .48795 Mdot
.984 .48844 Mdot
.984 .48858 Mdot
.984 .48864 Mdot
.984 .4896 Mdot
.984 .49138 Mdot
.984 .49204 Mdot
.984 .49205 Mdot
.984 .49639 Mdot
.984 .49783 Mdot
.984 .49843 Mdot
.984 .49908 Mdot
.984 .49983 Mdot
.984 .50372 Mdot
.984 .50397 Mdot
.984 .50513 Mdot
.984 .50555 Mdot
.984 .50725 Mdot
.984 .50817 Mdot
.984 .509 Mdot
.984 .50938 Mdot
.984 .51034 Mdot
.984 .51036 Mdot
.984 .51091 Mdot
.984 .5126 Mdot
.984 .51276 Mdot
.984 .51309 Mdot
.984 .51311 Mdot
.984 .5136 Mdot
.984 .51564 Mdot
.984 .51651 Mdot
.984 .51745 Mdot
.984 .51812 Mdot
.984 .51844 Mdot
.984 .51889 Mdot
.984 .51892 Mdot
.984 .51948 Mdot
.984 .51949 Mdot
.984 .52026 Mdot
.984 .52037 Mdot
.984 .52104 Mdot
.984 .5213 Mdot
.984 .52132 Mdot
.984 .52161 Mdot
.984 .52165 Mdot
.984 .52179 Mdot
.984 .52278 Mdot
.984 .52377 Mdot
.984 .52398 Mdot
.984 .52422 Mdot
.984 .52478 Mdot
.984 .5249 Mdot
.984 .52583 Mdot
.984 .52607 Mdot
.984 .52631 Mdot
.984 .52669 Mdot
.984 .52695 Mdot
.984 .52698 Mdot
.984 .52904 Mdot
.984 .52905 Mdot
.984 .5296 Mdot
.984 .52977 Mdot
.984 .53124 Mdot
.984 .53141 Mdot
.984 .5315 Mdot
.984 .533 Mdot
.984 .53329 Mdot
.984 .53546 Mdot
.984 .5355 Mdot
.984 .53641 Mdot
.984 .53666 Mdot
.984 .53747 Mdot
.984 .53768 Mdot
.984 .53801 Mdot
.984 .53802 Mdot
.984 .53834 Mdot
.984 .53874 Mdot
.984 .5393 Mdot
.984 .53937 Mdot
.984 .53941 Mdot
.984 .5401 Mdot
.984 .54055 Mdot
.984 .54224 Mdot
.984 .54363 Mdot
.984 .5441 Mdot
.984 .54493 Mdot
.984 .54526 Mdot
.984 .5453 Mdot
.984 .54586 Mdot
.984 .54623 Mdot
.984 .54707 Mdot
.984 .54764 Mdot
.984 .54841 Mdot
.984 .54852 Mdot
.984 .54991 Mdot
.984 .55084 Mdot
.984 .55089 Mdot
.984 .55127 Mdot
.984 .55146 Mdot
.984 .55188 Mdot
.984 .55256 Mdot
.984 .55278 Mdot
.984 .55298 Mdot
.984 .55327 Mdot
.984 .55329 Mdot
.984 .55409 Mdot
.984 .5546 Mdot
.984 .55614 Mdot
.984 .55722 Mdot
.984 .55722 Mdot
.984 .55727 Mdot
.984 .55808 Mdot
.984 .5583 Mdot
.984 .55852 Mdot
.984 .55875 Mdot
.984 .55927 Mdot
.984 .55946 Mdot
.984 .55969 Mdot
.984 .55978 Mdot
.984 .56018 Mdot
.984 .56057 Mdot
.984 .56165 Mdot
.984 .56204 Mdot
.984 .56218 Mdot
.984 .56229 Mdot
.984 .56234 Mdot
.984 .56244 Mdot
.984 .56302 Mdot
.984 .56363 Mdot
.984 .56509 Mdot
.984 .56559 Mdot
.984 .56567 Mdot
.984 .56592 Mdot
.984 .56739 Mdot
.984 .56765 Mdot
.984 .5679 Mdot
.984 .56801 Mdot
.984 .56845 Mdot
.984 .56855 Mdot
.984 .56856 Mdot
.984 .56884 Mdot
.984 .5697 Mdot
.984 .56971 Mdot
.984 .5707 Mdot
.984 .57094 Mdot
.984 .57101 Mdot
.984 .57102 Mdot
.984 .57179 Mdot
.984 .57225 Mdot
.984 .57226 Mdot
.984 .57261 Mdot
.984 .5731 Mdot
.984 .57314 Mdot
.984 .57335 Mdot
.984 .57368 Mdot
.984 .57376 Mdot
.984 .57438 Mdot
.984 .57442 Mdot
.984 .57445 Mdot
.984 .57451 Mdot
.984 .57462 Mdot
.984 .57503 Mdot
.984 .57573 Mdot
.984 .57607 Mdot
.984 .57634 Mdot
.984 .57647 Mdot
.984 .57671 Mdot
.984 .57691 Mdot
.984 .57698 Mdot
.984 .5772 Mdot
.984 .57753 Mdot
.984 .57826 Mdot
.984 .57828 Mdot
.984 .57829 Mdot
.984 .57859 Mdot
.984 .57872 Mdot
.984 .57883 Mdot
.984 .57911 Mdot
.984 .57929 Mdot
.984 .57931 Mdot
.984 .57938 Mdot
.984 .57944 Mdot
.984 .57948 Mdot
.984 .57971 Mdot
.984 .57972 Mdot
.984 .57992 Mdot
.984 .58012 Mdot
.984 .58028 Mdot
.984 .58043 Mdot
.984 .58054 Mdot
.984 .58059 Mdot
.984 .5807 Mdot
.984 .58087 Mdot
.984 .58139 Mdot
.984 .58139 Mdot
.984 .58162 Mdot
.984 .58171 Mdot
.984 .58187 Mdot
.984 .58206 Mdot
.984 .58321 Mdot
.984 .58362 Mdot
.984 .58421 Mdot
.984 .58497 Mdot
.984 .58572 Mdot
.984 .58604 Mdot
.984 .58652 Mdot
.984 .58658 Mdot
.984 .58659 Mdot
.984 .58676 Mdot
.984 .58688 Mdot
.984 .58703 Mdot
.984 .58759 Mdot
.984 .5876 Mdot
.984 .5876 Mdot
.984 .58762 Mdot
.984 .58767 Mdot
.984 .58769 Mdot
.984 .58771 Mdot
.984 .58775 Mdot
.984 .58775 Mdot
.984 .58776 Mdot
.984 .58777 Mdot
.984 .58778 Mdot
.984 .58821 Mdot
.984 .58834 Mdot
.984 .58837 Mdot
.984 .5885 Mdot
.984 .58874 Mdot
.984 .58884 Mdot
.984 .58892 Mdot
.984 .58892 Mdot
.984 .58906 Mdot
.984 .58907 Mdot
.984 .58928 Mdot
.984 .58929 Mdot
.984 .58934 Mdot
.984 .58955 Mdot
.984 .58962 Mdot
.984 .59001 Mdot
.984 .59008 Mdot
.984 .59022 Mdot
.984 .59052 Mdot
.984 .59062 Mdot
.984 .59075 Mdot
.984 .59083 Mdot
.984 .59106 Mdot
.984 .59107 Mdot
.984 .59108 Mdot
.984 .5911 Mdot
.984 .5911 Mdot
.984 .59111 Mdot
.984 .59117 Mdot
.984 .59118 Mdot
.984 .59126 Mdot
.984 .59172 Mdot
.984 .59183 Mdot
.984 .59185 Mdot
.984 .59195 Mdot
.984 .59209 Mdot
.984 .59211 Mdot
.984 .59227 Mdot
.984 .59229 Mdot
.984 .59234 Mdot
.984 .59241 Mdot
.984 .59246 Mdot
.984 .59262 Mdot
.984 .59269 Mdot
.984 .59281 Mdot
.984 .59287 Mdot
.984 .59289 Mdot
.984 .59294 Mdot
.984 .593 Mdot
.984 .59308 Mdot
.984 .59314 Mdot
.984 .59316 Mdot
.984 .59319 Mdot
.984 .5932 Mdot
.984 .59322 Mdot
.984 .59322 Mdot
.984 .59327 Mdot
.984 .59338 Mdot
.984 .59345 Mdot
.984 .59346 Mdot
.984 .59361 Mdot
.984 .59367 Mdot
.984 .59369 Mdot
.984 .59376 Mdot
.984 .59379 Mdot
.984 .59381 Mdot
.984 .59387 Mdot
.984 .59391 Mdot
.984 .59391 Mdot
.984 .59391 Mdot
.984 .59391 Mdot
.984 .59391 Mdot
.984 .59392 Mdot
.984 .59392 Mdot
.984 .59392 Mdot
.984 .59392 Mdot
.986 .04024 Mdot
.986 .04024 Mdot
.986 .04025 Mdot
.986 .04026 Mdot
.986 .04027 Mdot
.986 .04028 Mdot
.986 .04031 Mdot
.986 .04036 Mdot
.986 .04046 Mdot
.986 .04046 Mdot
.986 .04053 Mdot
.986 .04065 Mdot
.986 .04072 Mdot
.986 .04073 Mdot
.986 .0408 Mdot
.986 .04126 Mdot
.986 .04131 Mdot
.986 .04151 Mdot
.986 .04153 Mdot
.986 .04158 Mdot
.986 .04158 Mdot
.986 .04163 Mdot
.986 .04172 Mdot
.986 .04181 Mdot
.986 .04207 Mdot
.986 .04214 Mdot
.986 .04218 Mdot
.986 .04228 Mdot
.986 .04246 Mdot
.986 .04249 Mdot
.986 .04259 Mdot
.986 .04265 Mdot
.986 .04271 Mdot
.986 .04315 Mdot
.986 .04324 Mdot
.986 .04337 Mdot
.986 .04356 Mdot
.986 .04366 Mdot
.986 .04395 Mdot
.986 .04446 Mdot
.986 .04456 Mdot
.986 .04461 Mdot
.986 .04493 Mdot
.986 .04524 Mdot
.986 .04534 Mdot
.986 .04574 Mdot
.986 .04584 Mdot
.986 .04586 Mdot
.986 .0459 Mdot
.986 .04663 Mdot
.986 .04677 Mdot
.986 .04713 Mdot
.986 .04719 Mdot
.986 .04725 Mdot
.986 .04798 Mdot
.986 .0482 Mdot
.986 .04865 Mdot
.986 .04886 Mdot
.986 .05053 Mdot
.986 .05077 Mdot
.986 .05095 Mdot
.986 .05132 Mdot
.986 .05163 Mdot
.986 .05188 Mdot
.986 .05222 Mdot
.986 .05223 Mdot
.986 .05292 Mdot
.986 .05337 Mdot
.986 .05342 Mdot
.986 .05343 Mdot
.986 .05419 Mdot
.986 .05469 Mdot
.986 .05615 Mdot
.986 .05635 Mdot
.986 .05696 Mdot
.986 .057 Mdot
.986 .05882 Mdot
.986 .05906 Mdot
.986 .06008 Mdot
.986 .06031 Mdot
.986 .06056 Mdot
.986 .06077 Mdot
.986 .06079 Mdot
.986 .06082 Mdot
.986 .06095 Mdot
.986 .06155 Mdot
.986 .06281 Mdot
.986 .06342 Mdot
.986 .06383 Mdot
.986 .06392 Mdot
.986 .06399 Mdot
.986 .064 Mdot
.986 .06471 Mdot
.986 .06487 Mdot
.986 .065 Mdot
.986 .06568 Mdot
.986 .06642 Mdot
.986 .0669 Mdot
.986 .06693 Mdot
.986 .06834 Mdot
.986 .06835 Mdot
.986 .06976 Mdot
.986 .07146 Mdot
.986 .07249 Mdot
.986 .07254 Mdot
.986 .07342 Mdot
.986 .07407 Mdot
.986 .07437 Mdot
.986 .07452 Mdot
.986 .07521 Mdot
.986 .07647 Mdot
.986 .07693 Mdot
.986 .07732 Mdot
.986 .0777 Mdot
.986 .07824 Mdot
.986 .08032 Mdot
.986 .08043 Mdot
.986 .08054 Mdot
.986 .08083 Mdot
.986 .08208 Mdot
.986 .08274 Mdot
.986 .0829 Mdot
.986 .08312 Mdot
.986 .08405 Mdot
.986 .08417 Mdot
.986 .08675 Mdot
.986 .08877 Mdot
.986 .08997 Mdot
.986 .09056 Mdot
.986 .09107 Mdot
.986 .09231 Mdot
.986 .09326 Mdot
.986 .09333 Mdot
.986 .09354 Mdot
.986 .09354 Mdot
.986 .09356 Mdot
.986 .09359 Mdot
.986 .09363 Mdot
.986 .09365 Mdot
.986 .09375 Mdot
.986 .09392 Mdot
.986 .0942 Mdot
.986 .09422 Mdot
.986 .09428 Mdot
.986 .09443 Mdot
.986 .09469 Mdot
.986 .09471 Mdot
.986 .09479 Mdot
.986 .095 Mdot
.986 .095 Mdot
.986 .09503 Mdot
.986 .09524 Mdot
.986 .0957 Mdot
.986 .09607 Mdot
.986 .09666 Mdot
.986 .09683 Mdot
.986 .09743 Mdot
.986 .09749 Mdot
.986 .09764 Mdot
.986 .09765 Mdot
.986 .0978 Mdot
.986 .09808 Mdot
.986 .09836 Mdot
.986 .0987 Mdot
.986 .09915 Mdot
.986 .09938 Mdot
.986 .09949 Mdot
.986 .09979 Mdot
.986 .09981 Mdot
.986 .10018 Mdot
.986 .10035 Mdot
.986 .10043 Mdot
.986 .10075 Mdot
.986 .10091 Mdot
.986 .1011 Mdot
.986 .10214 Mdot
.986 .10245 Mdot
.986 .10273 Mdot
.986 .10295 Mdot
.986 .10312 Mdot
.986 .10313 Mdot
.986 .1037 Mdot
.986 .10389 Mdot
.986 .1039 Mdot
.986 .10395 Mdot
.986 .10402 Mdot
.986 .10491 Mdot
.986 .10513 Mdot
.986 .10557 Mdot
.986 .10646 Mdot
.986 .10654 Mdot
.986 .10677 Mdot
.986 .10692 Mdot
.986 .10763 Mdot
.986 .1079 Mdot
.986 .10885 Mdot
.986 .10911 Mdot
.986 .10916 Mdot
.986 .10932 Mdot
.986 .10987 Mdot
.986 .11039 Mdot
.986 .1107 Mdot
.986 .11074 Mdot
.986 .11078 Mdot
.986 .11086 Mdot
.986 .11143 Mdot
.986 .11165 Mdot
.986 .11166 Mdot
.986 .11309 Mdot
.986 .11324 Mdot
.986 .11352 Mdot
.986 .11387 Mdot
.986 .114 Mdot
.986 .11463 Mdot
.986 .11481 Mdot
.986 .115 Mdot
.986 .11601 Mdot
.986 .11714 Mdot
.986 .11723 Mdot
.986 .11761 Mdot
.986 .11773 Mdot
.986 .11788 Mdot
.986 .11866 Mdot
.986 .11921 Mdot
.986 .11927 Mdot
.986 .1193 Mdot
.986 .11991 Mdot
.986 .11999 Mdot
.986 .12132 Mdot
.986 .12206 Mdot
.986 .12226 Mdot
.986 .12258 Mdot
.986 .12282 Mdot
.986 .12298 Mdot
.986 .12299 Mdot
.986 .12464 Mdot
.986 .12499 Mdot
.986 .12522 Mdot
.986 .12571 Mdot
.986 .12627 Mdot
.986 .12706 Mdot
.986 .12739 Mdot
.986 .12834 Mdot
.986 .12909 Mdot
.986 .12971 Mdot
.986 .13011 Mdot
.986 .13016 Mdot
.986 .13225 Mdot
.986 .1323 Mdot
.986 .13248 Mdot
.986 .13317 Mdot
.986 .13362 Mdot
.986 .13377 Mdot
.986 .13378 Mdot
.986 .1361 Mdot
.986 .13723 Mdot
.986 .1376 Mdot
.986 .13862 Mdot
.986 .13914 Mdot
.986 .14035 Mdot
.986 .14079 Mdot
.986 .14114 Mdot
.986 .14146 Mdot
.986 .14203 Mdot
.986 .14262 Mdot
.986 .14395 Mdot
.986 .14447 Mdot
.986 .14458 Mdot
.986 .14845 Mdot
.986 .14853 Mdot
.986 .14965 Mdot
.986 .15008 Mdot
.986 .15049 Mdot
.986 .15081 Mdot
.986 .15388 Mdot
.986 .15399 Mdot
.986 .154 Mdot
.986 .15455 Mdot
.986 .1553 Mdot
.986 .15593 Mdot
.986 .156 Mdot
.986 .1561 Mdot
.986 .15647 Mdot
.986 .15674 Mdot
.986 .1583 Mdot
.986 .15935 Mdot
.986 .16109 Mdot
.986 .16207 Mdot
.986 .16389 Mdot
.986 .16397 Mdot
.986 .16511 Mdot
.986 .16525 Mdot
.986 .16538 Mdot
.986 .16549 Mdot
.986 .16558 Mdot
.986 .16564 Mdot
.986 .16776 Mdot
.986 .16824 Mdot
.986 .16861 Mdot
.986 .16884 Mdot
.986 .17038 Mdot
.986 .17065 Mdot
.986 .17284 Mdot
.986 .17429 Mdot
.986 .17438 Mdot
.986 .17457 Mdot
.986 .17857 Mdot
.986 .17858 Mdot
.986 .1786 Mdot
.986 .17878 Mdot
.986 .18011 Mdot
.986 .18279 Mdot
.986 .18363 Mdot
.986 .18458 Mdot
.986 .18499 Mdot
.986 .18508 Mdot
.986 .18532 Mdot
.986 .18553 Mdot
.986 .18593 Mdot
.986 .18781 Mdot
.986 .18846 Mdot
.986 .18858 Mdot
.986 .18904 Mdot
.986 .19085 Mdot
.986 .191 Mdot
.986 .19206 Mdot
.986 .19262 Mdot
.986 .19321 Mdot
.986 .1936 Mdot
.986 .19406 Mdot
.986 .19525 Mdot
.986 .19552 Mdot
.986 .19565 Mdot
.986 .19567 Mdot
.986 .19639 Mdot
.986 .19684 Mdot
.986 .19761 Mdot
.986 .19887 Mdot
.986 .20002 Mdot
.986 .20102 Mdot
.986 .20178 Mdot
.986 .20256 Mdot
.986 .2039 Mdot
.986 .20505 Mdot
.986 .20615 Mdot
.986 .20774 Mdot
.986 .20974 Mdot
.986 .2138 Mdot
.986 .21408 Mdot
.986 .21412 Mdot
.986 .21445 Mdot
.986 .2146 Mdot
.986 .21529 Mdot
.986 .21535 Mdot
.986 .21769 Mdot
.986 .21892 Mdot
.986 .22031 Mdot
.986 .22084 Mdot
.986 .221 Mdot
.986 .22129 Mdot
.986 .22192 Mdot
.986 .22463 Mdot
.986 .22495 Mdot
.986 .22607 Mdot
.986 .22861 Mdot
.986 .22977 Mdot
.986 .22988 Mdot
.986 .23042 Mdot
.986 .23155 Mdot
.986 .2324 Mdot
.986 .23257 Mdot
.986 .23266 Mdot
.986 .23557 Mdot
.986 .23676 Mdot
.986 .23818 Mdot
.986 .23825 Mdot
.986 .23948 Mdot
.986 .24161 Mdot
.986 .24252 Mdot
.986 .2433 Mdot
.986 .24332 Mdot
.986 .24474 Mdot
.986 .24575 Mdot
.986 .24825 Mdot
.986 .25096 Mdot
.986 .25116 Mdot
.986 .25174 Mdot
.986 .25174 Mdot
.986 .2518 Mdot
.986 .25188 Mdot
.986 .252 Mdot
.986 .25207 Mdot
.986 .25233 Mdot
.986 .25281 Mdot
.986 .25305 Mdot
.986 .25329 Mdot
.986 .25362 Mdot
.986 .25366 Mdot
.986 .25384 Mdot
.986 .25425 Mdot
.986 .25499 Mdot
.986 .25504 Mdot
.986 .25528 Mdot
.986 .25587 Mdot
.986 .25587 Mdot
.986 .25596 Mdot
.986 .2562 Mdot
.986 .25655 Mdot
.986 .25684 Mdot
.986 .25784 Mdot
.986 .25822 Mdot
.986 .25839 Mdot
.986 .25888 Mdot
.986 .25959 Mdot
.986 .26054 Mdot
.986 .261 Mdot
.986 .26269 Mdot
.986 .26287 Mdot
.986 .26328 Mdot
.986 .26331 Mdot
.986 .26373 Mdot
.986 .2645 Mdot
.986 .2653 Mdot
.986 .26623 Mdot
.986 .2675 Mdot
.986 .26813 Mdot
.986 .26845 Mdot
.986 .26927 Mdot
.986 .26932 Mdot
.986 .27037 Mdot
.986 .27085 Mdot
.986 .27105 Mdot
.986 .27195 Mdot
.986 .27232 Mdot
.986 .27241 Mdot
.986 .27292 Mdot
.986 .27341 Mdot
.986 .27344 Mdot
.986 .27581 Mdot
.986 .27666 Mdot
.986 .27698 Mdot
.986 .27743 Mdot
.986 .27804 Mdot
.986 .27851 Mdot
.986 .27855 Mdot
.986 .27887 Mdot
.986 .28012 Mdot
.986 .28062 Mdot
.986 .28064 Mdot
.986 .28066 Mdot
.986 .2808 Mdot
.986 .28098 Mdot
.986 .2834 Mdot
.986 .28343 Mdot
.986 .28406 Mdot
.986 .28524 Mdot
.986 .28565 Mdot
.986 .2863 Mdot
.986 .28767 Mdot
.986 .2879 Mdot
.986 .28854 Mdot
.986 .28895 Mdot
.986 .29088 Mdot
.986 .29161 Mdot
.986 .29253 Mdot
.986 .2926 Mdot
.986 .29321 Mdot
.986 .29419 Mdot
.986 .29421 Mdot
.986 .29489 Mdot
.986 .29504 Mdot
.986 .29548 Mdot
.986 .29697 Mdot
.986 .29746 Mdot
.986 .29795 Mdot
.986 .29835 Mdot
.986 .29919 Mdot
.986 .29932 Mdot
.986 .29942 Mdot
.986 .29964 Mdot
.986 .3003 Mdot
.986 .30055 Mdot
.986 .30117 Mdot
.986 .30177 Mdot
.986 .30178 Mdot
.986 .30254 Mdot
.986 .30562 Mdot
.986 .30604 Mdot
.986 .30678 Mdot
.986 .30771 Mdot
.986 .30807 Mdot
.986 .30852 Mdot
.986 .30956 Mdot
.986 .30976 Mdot
.986 .31022 Mdot
.986 .31074 Mdot
.986 .31199 Mdot
.986 .31306 Mdot
.986 .31338 Mdot
.986 .31342 Mdot
.986 .31372 Mdot
.986 .31536 Mdot
.986 .31609 Mdot
.986 .31615 Mdot
.986 .31642 Mdot
.986 .31665 Mdot
.986 .31767 Mdot
.986 .31797 Mdot
.986 .31837 Mdot
.986 .31987 Mdot
.986 .32043 Mdot
.986 .32188 Mdot
.986 .32204 Mdot
.986 .32211 Mdot
.986 .32371 Mdot
.986 .32392 Mdot
.986 .32502 Mdot
.986 .3256 Mdot
.986 .32668 Mdot
.986 .32741 Mdot
.986 .32934 Mdot
.986 .32986 Mdot
.986 .33069 Mdot
.986 .33071 Mdot
.986 .33132 Mdot
.986 .33171 Mdot
.986 .33176 Mdot
.986 .33416 Mdot
.986 .33602 Mdot
.986 .3362 Mdot
.986 .33692 Mdot
.986 .33753 Mdot
.986 .33879 Mdot
.986 .33945 Mdot
.986 .33956 Mdot
.986 .34012 Mdot
.986 .3402 Mdot
.986 .34138 Mdot
.986 .34224 Mdot
.986 .34308 Mdot
.986 .34405 Mdot
.986 .34549 Mdot
.986 .34677 Mdot
.986 .34741 Mdot
.986 .34884 Mdot
.986 .34899 Mdot
.986 .35 Mdot
.986 .35011 Mdot
.986 .35061 Mdot
.986 .3533 Mdot
.986 .35379 Mdot
.986 .35538 Mdot
.986 .3555 Mdot
.986 .3558 Mdot
.986 .35596 Mdot
.986 .35767 Mdot
.986 .3588 Mdot
.986 .35887 Mdot
.986 .35918 Mdot
.986 .3592 Mdot
.986 .36065 Mdot
.986 .3613 Mdot
.986 .36497 Mdot
.986 .36774 Mdot
.986 .36864 Mdot
.986 .36952 Mdot
.986 .37115 Mdot
.986 .37161 Mdot
.986 .37177 Mdot
.986 .37217 Mdot
.986 .37242 Mdot
.986 .37252 Mdot
.986 .37511 Mdot
.986 .37537 Mdot
.986 .37645 Mdot
.986 .37728 Mdot
.986 .37806 Mdot
.986 .37943 Mdot
.986 .38085 Mdot
.986 .38363 Mdot
.986 .38368 Mdot
.986 .38405 Mdot
.986 .38502 Mdot
.986 .38529 Mdot
.986 .38542 Mdot
.986 .38555 Mdot
.986 .38635 Mdot
.986 .38638 Mdot
.986 .38733 Mdot
.986 .38748 Mdot
.986 .38786 Mdot
.986 .3883 Mdot
.986 .38881 Mdot
.986 .38972 Mdot
.986 .38991 Mdot
.986 .39324 Mdot
.986 .39402 Mdot
.986 .39469 Mdot
.986 .39486 Mdot
.986 .39708 Mdot
.986 .39749 Mdot
.986 .39777 Mdot
.986 .39848 Mdot
.986 .39878 Mdot
.986 .39944 Mdot
.986 .40018 Mdot
.986 .40096 Mdot
.986 .40724 Mdot
.986 .4075 Mdot
.986 .4075 Mdot
.986 .40876 Mdot
.986 .40916 Mdot
.986 .4098 Mdot
.986 .41047 Mdot
.986 .41189 Mdot
.986 .41204 Mdot
.986 .41227 Mdot
.986 .41312 Mdot
.986 .41365 Mdot
.986 .41371 Mdot
.986 .41574 Mdot
.986 .41652 Mdot
.986 .41659 Mdot
.986 .41667 Mdot
.986 .4172 Mdot
.986 .41721 Mdot
.986 .41932 Mdot
.986 .41956 Mdot
.986 .4234 Mdot
.986 .42555 Mdot
.986 .42667 Mdot
.986 .42951 Mdot
.986 .42968 Mdot
.986 .43214 Mdot
.986 .43244 Mdot
.986 .43273 Mdot
.986 .43295 Mdot
.986 .43316 Mdot
.986 .43328 Mdot
.986 .43352 Mdot
.986 .43426 Mdot
.986 .43511 Mdot
.986 .43549 Mdot
.986 .43597 Mdot
.986 .43781 Mdot
.986 .43881 Mdot
.986 .43961 Mdot
.986 .44009 Mdot
.986 .44175 Mdot
.986 .44332 Mdot
.986 .44388 Mdot
.986 .44842 Mdot
.986 .45116 Mdot
.986 .45139 Mdot
.986 .45156 Mdot
.986 .45196 Mdot
.986 .45231 Mdot
.986 .45547 Mdot
.986 .45881 Mdot
.986 .45977 Mdot
.986 .46 Mdot
.986 .46004 Mdot
.986 .46007 Mdot
.986 .46042 Mdot
.986 .46135 Mdot
.986 .46305 Mdot
.986 .46333 Mdot
.986 .46691 Mdot
.986 .46785 Mdot
.986 .46829 Mdot
.986 .46858 Mdot
.986 .46989 Mdot
.986 .47022 Mdot
.986 .47164 Mdot
.986 .47172 Mdot
.986 .4721 Mdot
.986 .47232 Mdot
.986 .4725 Mdot
.986 .47267 Mdot
.986 .47273 Mdot
.986 .47312 Mdot
.986 .47314 Mdot
.986 .47353 Mdot
.986 .47369 Mdot
.986 .47426 Mdot
.986 .47428 Mdot
.986 .47781 Mdot
.986 .47888 Mdot
.986 .47902 Mdot
.986 .47918 Mdot
.986 .47925 Mdot
.986 .48011 Mdot
.986 .48344 Mdot
.986 .4837 Mdot
.986 .48441 Mdot
.986 .48564 Mdot
.986 .48644 Mdot
.986 .48664 Mdot
.986 .4877 Mdot
.986 .4884 Mdot
.986 .48922 Mdot
.986 .49029 Mdot
.986 .49133 Mdot
.986 .49182 Mdot
.986 .49204 Mdot
.986 .49208 Mdot
.986 .49335 Mdot
.986 .49414 Mdot
.986 .49547 Mdot
.986 .49701 Mdot
.986 .49743 Mdot
.986 .49765 Mdot
.986 .49961 Mdot
.986 .50102 Mdot
.986 .50104 Mdot
.986 .50132 Mdot
.986 .50194 Mdot
.986 .50207 Mdot
.986 .50219 Mdot
.986 .50259 Mdot
.986 .5035 Mdot
.986 .50389 Mdot
.986 .50612 Mdot
.986 .50686 Mdot
.986 .50695 Mdot
.986 .50782 Mdot
.986 .508 Mdot
.986 .5092 Mdot
.986 .50957 Mdot
.986 .5098 Mdot
.986 .50982 Mdot
.986 .5121 Mdot
.986 .51234 Mdot
.986 .51316 Mdot
.986 .51417 Mdot
.986 .51481 Mdot
.986 .51549 Mdot
.986 .51677 Mdot
.986 .51678 Mdot
.986 .51717 Mdot
.986 .52174 Mdot
.986 .52216 Mdot
.986 .52222 Mdot
.986 .52271 Mdot
.986 .52294 Mdot
.986 .52397 Mdot
.986 .52405 Mdot
.986 .52663 Mdot
.986 .52749 Mdot
.986 .52777 Mdot
.986 .52883 Mdot
.986 .52926 Mdot
.986 .52978 Mdot
.986 .5302 Mdot
.986 .53122 Mdot
.986 .53125 Mdot
.986 .5316 Mdot
.986 .53199 Mdot
.986 .53218 Mdot
.986 .53222 Mdot
.986 .53262 Mdot
.986 .53351 Mdot
.986 .53526 Mdot
.986 .5355 Mdot
.986 .5364 Mdot
.986 .53721 Mdot
.986 .53747 Mdot
.986 .53764 Mdot
.986 .53913 Mdot
.986 .54186 Mdot
.986 .54211 Mdot
.986 .54246 Mdot
.986 .54328 Mdot
.986 .54393 Mdot
.986 .54394 Mdot
.986 .54408 Mdot
.986 .54448 Mdot
.986 .54477 Mdot
.986 .54497 Mdot
.986 .54516 Mdot
.986 .54618 Mdot
.986 .54634 Mdot
.986 .54638 Mdot
.986 .54724 Mdot
.986 .54737 Mdot
.986 .54744 Mdot
.986 .54752 Mdot
.986 .54755 Mdot
.986 .54769 Mdot
.986 .54801 Mdot
.986 .5492 Mdot
.986 .54965 Mdot
.986 .54971 Mdot
.986 .55106 Mdot
.986 .55247 Mdot
.986 .55298 Mdot
.986 .55411 Mdot
.986 .55418 Mdot
.986 .55461 Mdot
.986 .55557 Mdot
.986 .55615 Mdot
.986 .55702 Mdot
.986 .55794 Mdot
.986 .55794 Mdot
.986 .55892 Mdot
.986 .5591 Mdot
.986 .55938 Mdot
.986 .55975 Mdot
.986 .55978 Mdot
.986 .56127 Mdot
.986 .56209 Mdot
.986 .5622 Mdot
.986 .56231 Mdot
.986 .56246 Mdot
.986 .56286 Mdot
.986 .56303 Mdot
.986 .56349 Mdot
.986 .56483 Mdot
.986 .56506 Mdot
.986 .56512 Mdot
.986 .56597 Mdot
.986 .56684 Mdot
.986 .56745 Mdot
.986 .56764 Mdot
.986 .56818 Mdot
.986 .56819 Mdot
.986 .56824 Mdot
.986 .56832 Mdot
.986 .56842 Mdot
.986 .56849 Mdot
.986 .56873 Mdot
.986 .56917 Mdot
.986 .56939 Mdot
.986 .56942 Mdot
.986 .5696 Mdot
.986 .56991 Mdot
.986 .56995 Mdot
.986 .5701 Mdot
.986 .57047 Mdot
.986 .57113 Mdot
.986 .57118 Mdot
.986 .57138 Mdot
.986 .5719 Mdot
.986 .5719 Mdot
.986 .57197 Mdot
.986 .57219 Mdot
.986 .57248 Mdot
.986 .57266 Mdot
.986 .57273 Mdot
.986 .57322 Mdot
.986 .57357 Mdot
.986 .57389 Mdot
.986 .57403 Mdot
.986 .57442 Mdot
.986 .57444 Mdot
.986 .57444 Mdot
.986 .57469 Mdot
.986 .57475 Mdot
.986 .57501 Mdot
.986 .57565 Mdot
.986 .57577 Mdot
.986 .57614 Mdot
.986 .57699 Mdot
.986 .57711 Mdot
.986 .57734 Mdot
.986 .57744 Mdot
.986 .57744 Mdot
.986 .57758 Mdot
.986 .57788 Mdot
.986 .57791 Mdot
.986 .57822 Mdot
.986 .57862 Mdot
.986 .57879 Mdot
.986 .57898 Mdot
.986 .57937 Mdot
.986 .58003 Mdot
.986 .58087 Mdot
.986 .5809 Mdot
.986 .58121 Mdot
.986 .58128 Mdot
.986 .58133 Mdot
.986 .58155 Mdot
.986 .58195 Mdot
.986 .58205 Mdot
.986 .58208 Mdot
.986 .58212 Mdot
.986 .58279 Mdot
.986 .58297 Mdot
.986 .58309 Mdot
.986 .58322 Mdot
.986 .58337 Mdot
.986 .58378 Mdot
.986 .584 Mdot
.986 .58405 Mdot
.986 .58415 Mdot
.986 .58436 Mdot
.986 .58464 Mdot
.986 .58466 Mdot
.986 .585 Mdot
.986 .58554 Mdot
.986 .586 Mdot
.986 .58601 Mdot
.986 .58646 Mdot
.986 .58647 Mdot
.986 .58663 Mdot
.986 .58687 Mdot
.986 .58709 Mdot
.986 .58713 Mdot
.986 .58718 Mdot
.986 .58741 Mdot
.986 .58742 Mdot
.986 .58744 Mdot
.986 .58747 Mdot
.986 .5876 Mdot
.986 .5878 Mdot
.986 .58821 Mdot
.986 .5884 Mdot
.986 .58844 Mdot
.986 .58845 Mdot
.986 .58846 Mdot
.986 .58853 Mdot
.986 .58861 Mdot
.986 .58868 Mdot
.986 .58901 Mdot
.986 .58909 Mdot
.986 .58968 Mdot
.986 .58969 Mdot
.986 .58989 Mdot
.986 .58995 Mdot
.986 .59043 Mdot
.986 .59059 Mdot
.986 .59084 Mdot
.986 .59084 Mdot
.986 .59085 Mdot
.986 .591 Mdot
.986 .59122 Mdot
.986 .59123 Mdot
.986 .59134 Mdot
.986 .59142 Mdot
.986 .59152 Mdot
.986 .59164 Mdot
.986 .5917 Mdot
.986 .59177 Mdot
.986 .59231 Mdot
.986 .59238 Mdot
.986 .59253 Mdot
.986 .5926 Mdot
.986 .59283 Mdot
.986 .59285 Mdot
.986 .59287 Mdot
.986 .59299 Mdot
.986 .59304 Mdot
.986 .59327 Mdot
.986 .59328 Mdot
.986 .59329 Mdot
.986 .59332 Mdot
.986 .59345 Mdot
.986 .59348 Mdot
.986 .59358 Mdot
.986 .59369 Mdot
.986 .5937 Mdot
.986 .59374 Mdot
.986 .5939 Mdot
.986 .594 Mdot
.986 .59403 Mdot
.986 .59409 Mdot
.986 .59413 Mdot
.986 .59416 Mdot
.986 .5943 Mdot
.986 .59432 Mdot
.986 .59434 Mdot
.986 .59437 Mdot
.986 .59438 Mdot
.986 .59444 Mdot
.986 .59447 Mdot
.986 .59448 Mdot
.986 .59451 Mdot
.986 .59459 Mdot
.986 .59462 Mdot
.986 .59465 Mdot
.986 .59467 Mdot
.986 .59467 Mdot
.986 .59468 Mdot
.986 .59469 Mdot
.986 .59475 Mdot
.986 .59477 Mdot
.986 .59492 Mdot
.986 .59494 Mdot
.986 .59495 Mdot
.986 .59497 Mdot
.986 .59501 Mdot
.986 .59503 Mdot
.986 .59503 Mdot
.986 .59506 Mdot
.986 .59508 Mdot
.986 .59509 Mdot
.986 .59509 Mdot
.986 .59509 Mdot
.986 .5951 Mdot
.986 .5951 Mdot
.986 .5951 Mdot
.988 .03664 Mdot
.988 .03664 Mdot
.988 .03666 Mdot
.988 .03666 Mdot
.988 .03669 Mdot
.988 .03671 Mdot
.988 .03671 Mdot
.988 .03673 Mdot
.988 .03689 Mdot
.988 .03689 Mdot
.988 .03696 Mdot
.988 .03708 Mdot
.988 .03708 Mdot
.988 .03712 Mdot
.988 .03712 Mdot
.988 .0376 Mdot
.988 .03785 Mdot
.988 .03785 Mdot
.988 .03791 Mdot
.988 .03811 Mdot
.988 .03815 Mdot
.988 .03823 Mdot
.988 .03837 Mdot
.988 .03841 Mdot
.988 .03844 Mdot
.988 .03871 Mdot
.988 .039 Mdot
.988 .03903 Mdot
.988 .03936 Mdot
.988 .03945 Mdot
.988 .04015 Mdot
.988 .04023 Mdot
.988 .04038 Mdot
.988 .04055 Mdot
.988 .04056 Mdot
.988 .04056 Mdot
.988 .04062 Mdot
.988 .04079 Mdot
.988 .04093 Mdot
.988 .04127 Mdot
.988 .04137 Mdot
.988 .04202 Mdot
.988 .04218 Mdot
.988 .0423 Mdot
.988 .04234 Mdot
.988 .04255 Mdot
.988 .04316 Mdot
.988 .04346 Mdot
.988 .04356 Mdot
.988 .04393 Mdot
.988 .04418 Mdot
.988 .04534 Mdot
.988 .04563 Mdot
.988 .04637 Mdot
.988 .04666 Mdot
.988 .04686 Mdot
.988 .04704 Mdot
.988 .04793 Mdot
.988 .04801 Mdot
.988 .04809 Mdot
.988 .04817 Mdot
.988 .04869 Mdot
.988 .04892 Mdot
.988 .04935 Mdot
.988 .0498 Mdot
.988 .0503 Mdot
.988 .05056 Mdot
.988 .0523 Mdot
.988 .05238 Mdot
.988 .05287 Mdot
.988 .05451 Mdot
.988 .055 Mdot
.988 .05502 Mdot
.988 .05554 Mdot
.988 .05574 Mdot
.988 .05644 Mdot
.988 .05768 Mdot
.988 .05809 Mdot
.988 .05874 Mdot
.988 .0588 Mdot
.988 .05888 Mdot
.988 .05998 Mdot
.988 .06015 Mdot
.988 .06091 Mdot
.988 .06158 Mdot
.988 .06346 Mdot
.988 .0677 Mdot
.988 .06805 Mdot
.988 .06824 Mdot
.988 .06869 Mdot
.988 .0697 Mdot
.988 .07 Mdot
.988 .0705 Mdot
.988 .07056 Mdot
.988 .07277 Mdot
.988 .07393 Mdot
.988 .07425 Mdot
.988 .07428 Mdot
.988 .07447 Mdot
.988 .07463 Mdot
.988 .07473 Mdot
.988 .07638 Mdot
.988 .07647 Mdot
.988 .07668 Mdot
.988 .07942 Mdot
.988 .08157 Mdot
.988 .08237 Mdot
.988 .0826 Mdot
.988 .08261 Mdot
.988 .08267 Mdot
.988 .08269 Mdot
.988 .08277 Mdot
.988 .08282 Mdot
.988 .08283 Mdot
.988 .0829 Mdot
.988 .08337 Mdot
.988 .08339 Mdot
.988 .08344 Mdot
.988 .08359 Mdot
.988 .08395 Mdot
.988 .08397 Mdot
.988 .08408 Mdot
.988 .0841 Mdot
.988 .08485 Mdot
.988 .08512 Mdot
.988 .08529 Mdot
.988 .08556 Mdot
.988 .08573 Mdot
.988 .08633 Mdot
.988 .08635 Mdot
.988 .08652 Mdot
.988 .08715 Mdot
.988 .08728 Mdot
.988 .08731 Mdot
.988 .08752 Mdot
.988 .08753 Mdot
.988 .08793 Mdot
.988 .08808 Mdot
.988 .08816 Mdot
.988 .08852 Mdot
.988 .08867 Mdot
.988 .08869 Mdot
.988 .08898 Mdot
.988 .08971 Mdot
.988 .08987 Mdot
.988 .08998 Mdot
.988 .09099 Mdot
.988 .09127 Mdot
.988 .09137 Mdot
.988 .09196 Mdot
.988 .09343 Mdot
.988 .09351 Mdot
.988 .09368 Mdot
.988 .09401 Mdot
.988 .09413 Mdot
.988 .09465 Mdot
.988 .09467 Mdot
.988 .09469 Mdot
.988 .09487 Mdot
.988 .09538 Mdot
.988 .09555 Mdot
.988 .0958 Mdot
.988 .09685 Mdot
.988 .09716 Mdot
.988 .09918 Mdot
.988 .09966 Mdot
.988 .09971 Mdot
.988 .10003 Mdot
.988 .10016 Mdot
.988 .10044 Mdot
.988 .1008 Mdot
.988 .10125 Mdot
.988 .10268 Mdot
.988 .10304 Mdot
.988 .1036 Mdot
.988 .10391 Mdot
.988 .10428 Mdot
.988 .10442 Mdot
.988 .10503 Mdot
.988 .10578 Mdot
.988 .10806 Mdot
.988 .10869 Mdot
.988 .10934 Mdot
.988 .10942 Mdot
.988 .10951 Mdot
.988 .10956 Mdot
.988 .10974 Mdot
.988 .11025 Mdot
.988 .11251 Mdot
.988 .11296 Mdot
.988 .1134 Mdot
.988 .11378 Mdot
.988 .114 Mdot
.988 .11454 Mdot
.988 .1147 Mdot
.988 .11476 Mdot
.988 .11478 Mdot
.988 .11726 Mdot
.988 .11728 Mdot
.988 .11751 Mdot
.988 .11777 Mdot
.988 .11801 Mdot
.988 .11868 Mdot
.988 .11925 Mdot
.988 .1196 Mdot
.988 .12015 Mdot
.988 .12029 Mdot
.988 .12161 Mdot
.988 .12213 Mdot
.988 .12216 Mdot
.988 .12297 Mdot
.988 .12451 Mdot
.988 .12531 Mdot
.988 .12648 Mdot
.988 .12882 Mdot
.988 .12883 Mdot
.988 .12926 Mdot
.988 .13058 Mdot
.988 .13084 Mdot
.988 .13151 Mdot
.988 .13198 Mdot
.988 .13234 Mdot
.988 .13486 Mdot
.988 .13641 Mdot
.988 .13669 Mdot
.988 .13729 Mdot
.988 .13761 Mdot
.988 .13767 Mdot
.988 .13804 Mdot
.988 .1388 Mdot
.988 .13884 Mdot
.988 .14014 Mdot
.988 .14044 Mdot
.988 .14104 Mdot
.988 .14317 Mdot
.988 .14381 Mdot
.988 .14692 Mdot
.988 .14812 Mdot
.988 .14815 Mdot
.988 .14933 Mdot
.988 .1501 Mdot
.988 .15029 Mdot
.988 .15041 Mdot
.988 .15051 Mdot
.988 .15055 Mdot
.988 .15186 Mdot
.988 .15297 Mdot
.988 .15384 Mdot
.988 .15394 Mdot
.988 .15436 Mdot
.988 .15513 Mdot
.988 .15534 Mdot
.988 .15595 Mdot
.988 .1562 Mdot
.988 .15666 Mdot
.988 .15675 Mdot
.988 .15821 Mdot
.988 .15865 Mdot
.988 .1589 Mdot
.988 .15893 Mdot
.988 .16175 Mdot
.988 .16195 Mdot
.988 .16237 Mdot
.988 .16343 Mdot
.988 .16431 Mdot
.988 .16699 Mdot
.988 .16714 Mdot
.988 .16782 Mdot
.988 .16865 Mdot
.988 .16934 Mdot
.988 .16969 Mdot
.988 .16993 Mdot
.988 .17056 Mdot
.988 .17315 Mdot
.988 .17335 Mdot
.988 .17341 Mdot
.988 .17352 Mdot
.988 .17569 Mdot
.988 .17595 Mdot
.988 .177 Mdot
.988 .17735 Mdot
.988 .17746 Mdot
.988 .17802 Mdot
.988 .17861 Mdot
.988 .17864 Mdot
.988 .17995 Mdot
.988 .18055 Mdot
.988 .18294 Mdot
.988 .18383 Mdot
.988 .1839 Mdot
.988 .18531 Mdot
.988 .18549 Mdot
.988 .18574 Mdot
.988 .18596 Mdot
.988 .18992 Mdot
.988 .19205 Mdot
.988 .19237 Mdot
.988 .19418 Mdot
.988 .19548 Mdot
.988 .19549 Mdot
.988 .19642 Mdot
.988 .19651 Mdot
.988 .19706 Mdot
.988 .19719 Mdot
.988 .19753 Mdot
.988 .19784 Mdot
.988 .19901 Mdot
.988 .2003 Mdot
.988 .20046 Mdot
.988 .20205 Mdot
.988 .20268 Mdot
.988 .20295 Mdot
.988 .20335 Mdot
.988 .20356 Mdot
.988 .20413 Mdot
.988 .2046 Mdot
.988 .20582 Mdot
.988 .20646 Mdot
.988 .2081 Mdot
.988 .21021 Mdot
.988 .21049 Mdot
.988 .21069 Mdot
.988 .21072 Mdot
.988 .21158 Mdot
.988 .21194 Mdot
.988 .21212 Mdot
.988 .21413 Mdot
.988 .21629 Mdot
.988 .21697 Mdot
.988 .21764 Mdot
.988 .21785 Mdot
.988 .21787 Mdot
.988 .21807 Mdot
.988 .21864 Mdot
.988 .21882 Mdot
.988 .22018 Mdot
.988 .22085 Mdot
.988 .22086 Mdot
.988 .22104 Mdot
.988 .22109 Mdot
.988 .22134 Mdot
.988 .22148 Mdot
.988 .22151 Mdot
.988 .22172 Mdot
.988 .2219 Mdot
.988 .22308 Mdot
.988 .22312 Mdot
.988 .22327 Mdot
.988 .22354 Mdot
.988 .22371 Mdot
.988 .22426 Mdot
.988 .22477 Mdot
.988 .22481 Mdot
.988 .22512 Mdot
.988 .22513 Mdot
.988 .22518 Mdot
.988 .22525 Mdot
.988 .22579 Mdot
.988 .22681 Mdot
.988 .22702 Mdot
.988 .22735 Mdot
.988 .22777 Mdot
.988 .22781 Mdot
.988 .22815 Mdot
.988 .22862 Mdot
.988 .22907 Mdot
.988 .22942 Mdot
.988 .2299 Mdot
.988 .23055 Mdot
.988 .23162 Mdot
.988 .23167 Mdot
.988 .23217 Mdot
.988 .23397 Mdot
.988 .23436 Mdot
.988 .23443 Mdot
.988 .23504 Mdot
.988 .23509 Mdot
.988 .23612 Mdot
.988 .23622 Mdot
.988 .23642 Mdot
.988 .23665 Mdot
.988 .23685 Mdot
.988 .23689 Mdot
.988 .23792 Mdot
.988 .23822 Mdot
.988 .23835 Mdot
.988 .2384 Mdot
.988 .23923 Mdot
.988 .23924 Mdot
.988 .23944 Mdot
.988 .24004 Mdot
.988 .24011 Mdot
.988 .24036 Mdot
.988 .24071 Mdot
.988 .241 Mdot
.988 .24134 Mdot
.988 .24178 Mdot
.988 .24211 Mdot
.988 .24381 Mdot
.988 .24497 Mdot
.988 .24577 Mdot
.988 .24607 Mdot
.988 .24666 Mdot
.988 .24775 Mdot
.988 .25091 Mdot
.988 .25193 Mdot
.988 .25213 Mdot
.988 .25262 Mdot
.988 .25352 Mdot
.988 .25355 Mdot
.988 .25388 Mdot
.988 .25537 Mdot
.988 .25544 Mdot
.988 .25549 Mdot
.988 .25576 Mdot
.988 .256 Mdot
.988 .25739 Mdot
.988 .25744 Mdot
.988 .25792 Mdot
.988 .25862 Mdot
.988 .26156 Mdot
.988 .26242 Mdot
.988 .26385 Mdot
.988 .26435 Mdot
.988 .26445 Mdot
.988 .26515 Mdot
.988 .26669 Mdot
.988 .26707 Mdot
.988 .26809 Mdot
.988 .26943 Mdot
.988 .26958 Mdot
.988 .27041 Mdot
.988 .27047 Mdot
.988 .27055 Mdot
.988 .27082 Mdot
.988 .27143 Mdot
.988 .27162 Mdot
.988 .2726 Mdot
.988 .27264 Mdot
.988 .27291 Mdot
.988 .27307 Mdot
.988 .27388 Mdot
.988 .27399 Mdot
.988 .27418 Mdot
.988 .27782 Mdot
.988 .27824 Mdot
.988 .27873 Mdot
.988 .27884 Mdot
.988 .28036 Mdot
.988 .28122 Mdot
.988 .28187 Mdot
.988 .28225 Mdot
.988 .28226 Mdot
.988 .28262 Mdot
.988 .28431 Mdot
.988 .28594 Mdot
.988 .28638 Mdot
.988 .28797 Mdot
.988 .28805 Mdot
.988 .28906 Mdot
.988 .29189 Mdot
.988 .29217 Mdot
.988 .2926 Mdot
.988 .29412 Mdot
.988 .29433 Mdot
.988 .2961 Mdot
.988 .29631 Mdot
.988 .29657 Mdot
.988 .29667 Mdot
.988 .29668 Mdot
.988 .29719 Mdot
.988 .29732 Mdot
.988 .29856 Mdot
.988 .29944 Mdot
.988 .30134 Mdot
.988 .30199 Mdot
.988 .30215 Mdot
.988 .30291 Mdot
.988 .30467 Mdot
.988 .3047 Mdot
.988 .30486 Mdot
.988 .30489 Mdot
.988 .30548 Mdot
.988 .30587 Mdot
.988 .3059 Mdot
.988 .30705 Mdot
.988 .30806 Mdot
.988 .30867 Mdot
.988 .30874 Mdot
.988 .3101 Mdot
.988 .31053 Mdot
.988 .31071 Mdot
.988 .31075 Mdot
.988 .31589 Mdot
.988 .31661 Mdot
.988 .31691 Mdot
.988 .31724 Mdot
.988 .31735 Mdot
.988 .31742 Mdot
.988 .31801 Mdot
.988 .31869 Mdot
.988 .31933 Mdot
.988 .32111 Mdot
.988 .3214 Mdot
.988 .32246 Mdot
.988 .3226 Mdot
.988 .32352 Mdot
.988 .32389 Mdot
.988 .32421 Mdot
.988 .32498 Mdot
.988 .32534 Mdot
.988 .32745 Mdot
.988 .32776 Mdot
.988 .32851 Mdot
.988 .3288 Mdot
.988 .32916 Mdot
.988 .33016 Mdot
.988 .33024 Mdot
.988 .33071 Mdot
.988 .33091 Mdot
.988 .3313 Mdot
.988 .33234 Mdot
.988 .33381 Mdot
.988 .3342 Mdot
.988 .33633 Mdot
.988 .33797 Mdot
.988 .3384 Mdot
.988 .33845 Mdot
.988 .3385 Mdot
.988 .3414 Mdot
.988 .34443 Mdot
.988 .3474 Mdot
.988 .34741 Mdot
.988 .34852 Mdot
.988 .35186 Mdot
.988 .35251 Mdot
.988 .35263 Mdot
.988 .35271 Mdot
.988 .35415 Mdot
.988 .35422 Mdot
.988 .35467 Mdot
.988 .35538 Mdot
.988 .35628 Mdot
.988 .35714 Mdot
.988 .35883 Mdot
.988 .35912 Mdot
.988 .36261 Mdot
.988 .36388 Mdot
.988 .36453 Mdot
.988 .36645 Mdot
.988 .36714 Mdot
.988 .36862 Mdot
.988 .36941 Mdot
.988 .36941 Mdot
.988 .36956 Mdot
.988 .37046 Mdot
.988 .3719 Mdot
.988 .37231 Mdot
.988 .37242 Mdot
.988 .37558 Mdot
.988 .37631 Mdot
.988 .37776 Mdot
.988 .37818 Mdot
.988 .38201 Mdot
.988 .38218 Mdot
.988 .38291 Mdot
.988 .38299 Mdot
.988 .38412 Mdot
.988 .38444 Mdot
.988 .38497 Mdot
.988 .39137 Mdot
.988 .39168 Mdot
.988 .39185 Mdot
.988 .39468 Mdot
.988 .39474 Mdot
.988 .39575 Mdot
.988 .39752 Mdot
.988 .39931 Mdot
.988 .39975 Mdot
.988 .40004 Mdot
.988 .40026 Mdot
.988 .40035 Mdot
.988 .4034 Mdot
.988 .40431 Mdot
.988 .40582 Mdot
.988 .40596 Mdot
.988 .40656 Mdot
.988 .40791 Mdot
.988 .40795 Mdot
.988 .40816 Mdot
.988 .4082 Mdot
.988 .40913 Mdot
.988 .40925 Mdot
.988 .41005 Mdot
.988 .41089 Mdot
.988 .41135 Mdot
.988 .41137 Mdot
.988 .4123 Mdot
.988 .41274 Mdot
.988 .41331 Mdot
.988 .41436 Mdot
.988 .41454 Mdot
.988 .41515 Mdot
.988 .41515 Mdot
.988 .41528 Mdot
.988 .41782 Mdot
.988 .4179 Mdot
.988 .41882 Mdot
.988 .41937 Mdot
.988 .41944 Mdot
.988 .42015 Mdot
.988 .42038 Mdot
.988 .42091 Mdot
.988 .42246 Mdot
.988 .42567 Mdot
.988 .42612 Mdot
.988 .42666 Mdot
.988 .42703 Mdot
.988 .42709 Mdot
.988 .42828 Mdot
.988 .42934 Mdot
.988 .42989 Mdot
.988 .43126 Mdot
.988 .43214 Mdot
.988 .43701 Mdot
.988 .43735 Mdot
.988 .43781 Mdot
.988 .43788 Mdot
.988 .43829 Mdot
.988 .43858 Mdot
.988 .43879 Mdot
.988 .43942 Mdot
.988 .44054 Mdot
.988 .44201 Mdot
.988 .44274 Mdot
.988 .44325 Mdot
.988 .44455 Mdot
.988 .44994 Mdot
.988 .45034 Mdot
.988 .45047 Mdot
.988 .45067 Mdot
.988 .4507 Mdot
.988 .45334 Mdot
.988 .45438 Mdot
.988 .45512 Mdot
.988 .45566 Mdot
.988 .45586 Mdot
.988 .45776 Mdot
.988 .45846 Mdot
.988 .4587 Mdot
.988 .45881 Mdot
.988 .45982 Mdot
.988 .46098 Mdot
.988 .46104 Mdot
.988 .46104 Mdot
.988 .4623 Mdot
.988 .46272 Mdot
.988 .46329 Mdot
.988 .46365 Mdot
.988 .4641 Mdot
.988 .46423 Mdot
.988 .46482 Mdot
.988 .46515 Mdot
.988 .4658 Mdot
.988 .46948 Mdot
.988 .47121 Mdot
.988 .47134 Mdot
.988 .47403 Mdot
.988 .47439 Mdot
.988 .47486 Mdot
.988 .47519 Mdot
.988 .47527 Mdot
.988 .47685 Mdot
.988 .47943 Mdot
.988 .48044 Mdot
.988 .48242 Mdot
.988 .48268 Mdot
.988 .48459 Mdot
.988 .48471 Mdot
.988 .48538 Mdot
.988 .48637 Mdot
.988 .48657 Mdot
.988 .48714 Mdot
.988 .48717 Mdot
.988 .4904 Mdot
.988 .49271 Mdot
.988 .49273 Mdot
.988 .49292 Mdot
.988 .49437 Mdot
.988 .49452 Mdot
.988 .49549 Mdot
.988 .49564 Mdot
.988 .49572 Mdot
.988 .49631 Mdot
.988 .49656 Mdot
.988 .49685 Mdot
.988 .49696 Mdot
.988 .4982 Mdot
.988 .49832 Mdot
.988 .49886 Mdot
.988 .49927 Mdot
.988 .50084 Mdot
.988 .50096 Mdot
.988 .50108 Mdot
.988 .50135 Mdot
.988 .50403 Mdot
.988 .50509 Mdot
.988 .50524 Mdot
.988 .50547 Mdot
.988 .50547 Mdot
.988 .50553 Mdot
.988 .5062 Mdot
.988 .50648 Mdot
.988 .50654 Mdot
.988 .50678 Mdot
.988 .50748 Mdot
.988 .50827 Mdot
.988 .50851 Mdot
.988 .50944 Mdot
.988 .51016 Mdot
.988 .51026 Mdot
.988 .5113 Mdot
.988 .51167 Mdot
.988 .51169 Mdot
.988 .51243 Mdot
.988 .51378 Mdot
.988 .51392 Mdot
.988 .51505 Mdot
.988 .51523 Mdot
.988 .51669 Mdot
.988 .51676 Mdot
.988 .51709 Mdot
.988 .51715 Mdot
.988 .51725 Mdot
.988 .51768 Mdot
.988 .518 Mdot
.988 .51805 Mdot
.988 .51925 Mdot
.988 .51938 Mdot
.988 .51993 Mdot
.988 .52018 Mdot
.988 .52022 Mdot
.988 .5204 Mdot
.988 .52269 Mdot
.988 .52327 Mdot
.988 .52406 Mdot
.988 .52498 Mdot
.988 .52648 Mdot
.988 .52748 Mdot
.988 .52846 Mdot
.988 .52856 Mdot
.988 .52869 Mdot
.988 .52877 Mdot
.988 .5288 Mdot
.988 .52901 Mdot
.988 .52908 Mdot
.988 .52943 Mdot
.988 .52991 Mdot
.988 .53006 Mdot
.988 .53016 Mdot
.988 .5321 Mdot
.988 .53262 Mdot
.988 .53305 Mdot
.988 .53307 Mdot
.988 .53333 Mdot
.988 .5334 Mdot
.988 .53375 Mdot
.988 .53394 Mdot
.988 .53398 Mdot
.988 .53428 Mdot
.988 .53453 Mdot
.988 .53509 Mdot
.988 .53615 Mdot
.988 .53622 Mdot
.988 .53641 Mdot
.988 .53648 Mdot
.988 .53656 Mdot
.988 .53679 Mdot
.988 .53703 Mdot
.988 .53776 Mdot
.988 .53845 Mdot
.988 .53852 Mdot
.988 .53893 Mdot
.988 .53894 Mdot
.988 .53901 Mdot
.988 .53911 Mdot
.988 .53983 Mdot
.988 .54039 Mdot
.988 .54061 Mdot
.988 .54102 Mdot
.988 .54119 Mdot
.988 .54145 Mdot
.988 .54189 Mdot
.988 .54243 Mdot
.988 .54249 Mdot
.988 .54293 Mdot
.988 .54354 Mdot
.988 .54412 Mdot
.988 .54456 Mdot
.988 .54518 Mdot
.988 .546 Mdot
.988 .54734 Mdot
.988 .54742 Mdot
.988 .54804 Mdot
.988 .54916 Mdot
.988 .54981 Mdot
.988 .5502 Mdot
.988 .55024 Mdot
.988 .55071 Mdot
.988 .5508 Mdot
.988 .55152 Mdot
.988 .55156 Mdot
.988 .55158 Mdot
.988 .55164 Mdot
.988 .55251 Mdot
.988 .55272 Mdot
.988 .5528 Mdot
.988 .55292 Mdot
.988 .55315 Mdot
.988 .55343 Mdot
.988 .55365 Mdot
.988 .55371 Mdot
.988 .55489 Mdot
.988 .55525 Mdot
.988 .55538 Mdot
.988 .55545 Mdot
.988 .55639 Mdot
.988 .5564 Mdot
.988 .55663 Mdot
.988 .55712 Mdot
.988 .5573 Mdot
.988 .55738 Mdot
.988 .55758 Mdot
.988 .55765 Mdot
.988 .55805 Mdot
.988 .55837 Mdot
.988 .55874 Mdot
.988 .55919 Mdot
.988 .55922 Mdot
.988 .55958 Mdot
.988 .55998 Mdot
.988 .5614 Mdot
.988 .56262 Mdot
.988 .56331 Mdot
.988 .56343 Mdot
.988 .56345 Mdot
.988 .56375 Mdot
.988 .56384 Mdot
.988 .56435 Mdot
.988 .5653 Mdot
.988 .56546 Mdot
.988 .5662 Mdot
.988 .56634 Mdot
.988 .56634 Mdot
.988 .56711 Mdot
.988 .56853 Mdot
.988 .56854 Mdot
.988 .56918 Mdot
.988 .56948 Mdot
.988 .56967 Mdot
.988 .57012 Mdot
.988 .57094 Mdot
.988 .57095 Mdot
.988 .57097 Mdot
.988 .57127 Mdot
.988 .57154 Mdot
.988 .57259 Mdot
.988 .57265 Mdot
.988 .57266 Mdot
.988 .57269 Mdot
.988 .57293 Mdot
.988 .57314 Mdot
.988 .57433 Mdot
.988 .57437 Mdot
.988 .57477 Mdot
.988 .57536 Mdot
.988 .57562 Mdot
.988 .57586 Mdot
.988 .57721 Mdot
.988 .57772 Mdot
.988 .57788 Mdot
.988 .57838 Mdot
.988 .57857 Mdot
.988 .57911 Mdot
.988 .57945 Mdot
.988 .57945 Mdot
.988 .5795 Mdot
.988 .57982 Mdot
.988 .57989 Mdot
.988 .58041 Mdot
.988 .58055 Mdot
.988 .5806 Mdot
.988 .58069 Mdot
.988 .58115 Mdot
.988 .5815 Mdot
.988 .58176 Mdot
.988 .58245 Mdot
.988 .58334 Mdot
.988 .58341 Mdot
.988 .58344 Mdot
.988 .58397 Mdot
.988 .58401 Mdot
.988 .58406 Mdot
.988 .58412 Mdot
.988 .58413 Mdot
.988 .58423 Mdot
.988 .58461 Mdot
.988 .58532 Mdot
.988 .58534 Mdot
.988 .5855 Mdot
.988 .5856 Mdot
.988 .58593 Mdot
.988 .58607 Mdot
.988 .58614 Mdot
.988 .58625 Mdot
.988 .58762 Mdot
.988 .58823 Mdot
.988 .58844 Mdot
.988 .58869 Mdot
.988 .58875 Mdot
.988 .5891 Mdot
.988 .58913 Mdot
.988 .58915 Mdot
.988 .58936 Mdot
.988 .58949 Mdot
.988 .58989 Mdot
.988 .59011 Mdot
.988 .59018 Mdot
.988 .59035 Mdot
.988 .59035 Mdot
.988 .59051 Mdot
.988 .59104 Mdot
.988 .5912 Mdot
.988 .59123 Mdot
.988 .59179 Mdot
.988 .59187 Mdot
.988 .59203 Mdot
.988 .59218 Mdot
.988 .59232 Mdot
.988 .59239 Mdot
.988 .59256 Mdot
.988 .59258 Mdot
.988 .59261 Mdot
.988 .59264 Mdot
.988 .59292 Mdot
.988 .59298 Mdot
.988 .59304 Mdot
.988 .59314 Mdot
.988 .59338 Mdot
.988 .59347 Mdot
.988 .59385 Mdot
.988 .59393 Mdot
.988 .59404 Mdot
.988 .59408 Mdot
.988 .59417 Mdot
.988 .59437 Mdot
.988 .59444 Mdot
.988 .59445 Mdot
.988 .59449 Mdot
.988 .59454 Mdot
.988 .59475 Mdot
.988 .59479 Mdot
.988 .5949 Mdot
.988 .59494 Mdot
.988 .59499 Mdot
.988 .59501 Mdot
.988 .59501 Mdot
.988 .59502 Mdot
.988 .59507 Mdot
.988 .59512 Mdot
.988 .59514 Mdot
.988 .59537 Mdot
.988 .5954 Mdot
.988 .59551 Mdot
.988 .59552 Mdot
.988 .59561 Mdot
.988 .5957 Mdot
.988 .59571 Mdot
.988 .59572 Mdot
.988 .59576 Mdot
.988 .59579 Mdot
.988 .5958 Mdot
.988 .59587 Mdot
.988 .59589 Mdot
.988 .59589 Mdot
.988 .59597 Mdot
.988 .59612 Mdot
.988 .59612 Mdot
.988 .59614 Mdot
.988 .59614 Mdot
.988 .59618 Mdot
.988 .5962 Mdot
.988 .5962 Mdot
.988 .59625 Mdot
.988 .59625 Mdot
.988 .59626 Mdot
.988 .59626 Mdot
.988 .59627 Mdot
.988 .59627 Mdot
.988 .59628 Mdot
.988 .59628 Mdot
.99 .03304 Mdot
.99 .03305 Mdot
.99 .03306 Mdot
.99 .03314 Mdot
.99 .03316 Mdot
.99 .03317 Mdot
.99 .0332 Mdot
.99 .03322 Mdot
.99 .03325 Mdot
.99 .0333 Mdot
.99 .03341 Mdot
.99 .03348 Mdot
.99 .03349 Mdot
.99 .03357 Mdot
.99 .03363 Mdot
.99 .03366 Mdot
.99 .03366 Mdot
.99 .03377 Mdot
.99 .03383 Mdot
.99 .03409 Mdot
.99 .03425 Mdot
.99 .03428 Mdot
.99 .03468 Mdot
.99 .03533 Mdot
.99 .03537 Mdot
.99 .0355 Mdot
.99 .03568 Mdot
.99 .03609 Mdot
.99 .03621 Mdot
.99 .03647 Mdot
.99 .03648 Mdot
.99 .03653 Mdot
.99 .0367 Mdot
.99 .03676 Mdot
.99 .03749 Mdot
.99 .03752 Mdot
.99 .03759 Mdot
.99 .03829 Mdot
.99 .03889 Mdot
.99 .03917 Mdot
.99 .04058 Mdot
.99 .04064 Mdot
.99 .04126 Mdot
.99 .04163 Mdot
.99 .04192 Mdot
.99 .0423 Mdot
.99 .04272 Mdot
.99 .04333 Mdot
.99 .04558 Mdot
.99 .04621 Mdot
.99 .04641 Mdot
.99 .0465 Mdot
.99 .04775 Mdot
.99 .04818 Mdot
.99 .0484 Mdot
.99 .04852 Mdot
.99 .05089 Mdot
.99 .05119 Mdot
.99 .05234 Mdot
.99 .05276 Mdot
.99 .05394 Mdot
.99 .05433 Mdot
.99 .05448 Mdot
.99 .05457 Mdot
.99 .05475 Mdot
.99 .05519 Mdot
.99 .05534 Mdot
.99 .05794 Mdot
.99 .05796 Mdot
.99 .05804 Mdot
.99 .05818 Mdot
.99 .05828 Mdot
.99 .06022 Mdot
.99 .06094 Mdot
.99 .06125 Mdot
.99 .06133 Mdot
.99 .06164 Mdot
.99 .06248 Mdot
.99 .06273 Mdot
.99 .06419 Mdot
.99 .06507 Mdot
.99 .06549 Mdot
.99 .06896 Mdot
.99 .06928 Mdot
.99 .07091 Mdot
.99 .07104 Mdot
.99 .07133 Mdot
.99 .07159 Mdot
.99 .07161 Mdot
.99 .07165 Mdot
.99 .07169 Mdot
.99 .07182 Mdot
.99 .07187 Mdot
.99 .07192 Mdot
.99 .07194 Mdot
.99 .07199 Mdot
.99 .07201 Mdot
.99 .07203 Mdot
.99 .07212 Mdot
.99 .07216 Mdot
.99 .07226 Mdot
.99 .07235 Mdot
.99 .07242 Mdot
.99 .07276 Mdot
.99 .07298 Mdot
.99 .07301 Mdot
.99 .07324 Mdot
.99 .07345 Mdot
.99 .07354 Mdot
.99 .07355 Mdot
.99 .07389 Mdot
.99 .07406 Mdot
.99 .07488 Mdot
.99 .07534 Mdot
.99 .07538 Mdot
.99 .07544 Mdot
.99 .0758 Mdot
.99 .0767 Mdot
.99 .07802 Mdot
.99 .07805 Mdot
.99 .07871 Mdot
.99 .07882 Mdot
.99 .07924 Mdot
.99 .07942 Mdot
.99 .07979 Mdot
.99 .08105 Mdot
.99 .08121 Mdot
.99 .08135 Mdot
.99 .08143 Mdot
.99 .08223 Mdot
.99 .08224 Mdot
.99 .08241 Mdot
.99 .0828 Mdot
.99 .08287 Mdot
.99 .08293 Mdot
.99 .08311 Mdot
.99 .08342 Mdot
.99 .08366 Mdot
.99 .08456 Mdot
.99 .08536 Mdot
.99 .08547 Mdot
.99 .08569 Mdot
.99 .08677 Mdot
.99 .08711 Mdot
.99 .08733 Mdot
.99 .08738 Mdot
.99 .08786 Mdot
.99 .08816 Mdot
.99 .08846 Mdot
.99 .08853 Mdot
.99 .08968 Mdot
.99 .09055 Mdot
.99 .09077 Mdot
.99 .09118 Mdot
.99 .09333 Mdot
.99 .09366 Mdot
.99 .09372 Mdot
.99 .0949 Mdot
.99 .09509 Mdot
.99 .09538 Mdot
.99 .09587 Mdot
.99 .09623 Mdot
.99 .097 Mdot
.99 .09716 Mdot
.99 .09717 Mdot
.99 .09726 Mdot
.99 .09811 Mdot
.99 .09813 Mdot
.99 .09865 Mdot
.99 .09903 Mdot
.99 .09963 Mdot
.99 .0997 Mdot
.99 .09972 Mdot
.99 .1002 Mdot
.99 .10118 Mdot
.99 .10148 Mdot
.99 .10177 Mdot
.99 .10185 Mdot
.99 .10251 Mdot
.99 .10312 Mdot
.99 .10315 Mdot
.99 .10326 Mdot
.99 .1033 Mdot
.99 .10336 Mdot
.99 .10375 Mdot
.99 .10512 Mdot
.99 .10579 Mdot
.99 .10655 Mdot
.99 .1076 Mdot
.99 .10949 Mdot
.99 .1096 Mdot
.99 .11028 Mdot
.99 .11221 Mdot
.99 .11234 Mdot
.99 .11247 Mdot
.99 .11281 Mdot
.99 .11289 Mdot
.99 .1131 Mdot
.99 .11432 Mdot
.99 .1144 Mdot
.99 .11482 Mdot
.99 .11551 Mdot
.99 .11578 Mdot
.99 .11593 Mdot
.99 .11692 Mdot
.99 .11749 Mdot
.99 .11825 Mdot
.99 .11843 Mdot
.99 .11887 Mdot
.99 .11891 Mdot
.99 .11929 Mdot
.99 .12342 Mdot
.99 .1243 Mdot
.99 .12576 Mdot
.99 .12579 Mdot
.99 .12652 Mdot
.99 .12661 Mdot
.99 .1268 Mdot
.99 .12746 Mdot
.99 .12866 Mdot
.99 .12878 Mdot
.99 .13096 Mdot
.99 .13223 Mdot
.99 .13299 Mdot
.99 .13321 Mdot
.99 .13382 Mdot
.99 .13463 Mdot
.99 .13549 Mdot
.99 .13583 Mdot
.99 .1364 Mdot
.99 .13702 Mdot
.99 .13745 Mdot
.99 .13748 Mdot
.99 .13773 Mdot
.99 .1383 Mdot
.99 .13833 Mdot
.99 .13851 Mdot
.99 .13899 Mdot
.99 .13945 Mdot
.99 .13949 Mdot
.99 .13964 Mdot
.99 .14007 Mdot
.99 .1413 Mdot
.99 .142 Mdot
.99 .14231 Mdot
.99 .14292 Mdot
.99 .14345 Mdot
.99 .14581 Mdot
.99 .1469 Mdot
.99 .14734 Mdot
.99 .14758 Mdot
.99 .14796 Mdot
.99 .14802 Mdot
.99 .14826 Mdot
.99 .14867 Mdot
.99 .149 Mdot
.99 .15084 Mdot
.99 .15222 Mdot
.99 .15487 Mdot
.99 .1562 Mdot
.99 .15701 Mdot
.99 .15704 Mdot
.99 .15795 Mdot
.99 .1582 Mdot
.99 .1584 Mdot
.99 .15878 Mdot
.99 .15913 Mdot
.99 .15951 Mdot
.99 .16167 Mdot
.99 .16178 Mdot
.99 .16241 Mdot
.99 .16244 Mdot
.99 .16287 Mdot
.99 .16548 Mdot
.99 .1655 Mdot
.99 .16682 Mdot
.99 .16945 Mdot
.99 .17038 Mdot
.99 .17072 Mdot
.99 .17074 Mdot
.99 .17092 Mdot
.99 .17322 Mdot
.99 .17531 Mdot
.99 .17677 Mdot
.99 .18108 Mdot
.99 .18203 Mdot
.99 .18391 Mdot
.99 .18687 Mdot
.99 .18728 Mdot
.99 .18746 Mdot
.99 .18761 Mdot
.99 .18814 Mdot
.99 .18835 Mdot
.99 .1889 Mdot
.99 .18897 Mdot
.99 .18908 Mdot
.99 .18921 Mdot
.99 .18958 Mdot
.99 .18973 Mdot
.99 .18988 Mdot
.99 .18993 Mdot
.99 .19008 Mdot
.99 .19015 Mdot
.99 .19021 Mdot
.99 .19047 Mdot
.99 .19059 Mdot
.99 .19075 Mdot
.99 .19089 Mdot
.99 .19116 Mdot
.99 .19136 Mdot
.99 .1919 Mdot
.99 .19238 Mdot
.99 .19303 Mdot
.99 .19312 Mdot
.99 .1938 Mdot
.99 .19441 Mdot
.99 .19467 Mdot
.99 .19471 Mdot
.99 .19571 Mdot
.99 .19615 Mdot
.99 .19621 Mdot
.99 .19653 Mdot
.99 .19727 Mdot
.99 .19775 Mdot
.99 .19864 Mdot
.99 .19929 Mdot
.99 .2 Mdot
.99 .20011 Mdot
.99 .20029 Mdot
.99 .2008 Mdot
.99 .20134 Mdot
.99 .2026 Mdot
.99 .20263 Mdot
.99 .20399 Mdot
.99 .20488 Mdot
.99 .2055 Mdot
.99 .20559 Mdot
.99 .20656 Mdot
.99 .20789 Mdot
.99 .20797 Mdot
.99 .20991 Mdot
.99 .21022 Mdot
.99 .21065 Mdot
.99 .21109 Mdot
.99 .21145 Mdot
.99 .21198 Mdot
.99 .21292 Mdot
.99 .21306 Mdot
.99 .21337 Mdot
.99 .21392 Mdot
.99 .21512 Mdot
.99 .21653 Mdot
.99 .21674 Mdot
.99 .2171 Mdot
.99 .2172 Mdot
.99 .21748 Mdot
.99 .21763 Mdot
.99 .21787 Mdot
.99 .21934 Mdot
.99 .21958 Mdot
.99 .2202 Mdot
.99 .22023 Mdot
.99 .22032 Mdot
.99 .22072 Mdot
.99 .2212 Mdot
.99 .22183 Mdot
.99 .22205 Mdot
.99 .22223 Mdot
.99 .22275 Mdot
.99 .22334 Mdot
.99 .22363 Mdot
.99 .22377 Mdot
.99 .22435 Mdot
.99 .22574 Mdot
.99 .2265 Mdot
.99 .22696 Mdot
.99 .22735 Mdot
.99 .22775 Mdot
.99 .22787 Mdot
.99 .22927 Mdot
.99 .22958 Mdot
.99 .23021 Mdot
.99 .23041 Mdot
.99 .23045 Mdot
.99 .2314 Mdot
.99 .23333 Mdot
.99 .23431 Mdot
.99 .23495 Mdot
.99 .2351 Mdot
.99 .23647 Mdot
.99 .23734 Mdot
.99 .23753 Mdot
.99 .23818 Mdot
.99 .2384 Mdot
.99 .23851 Mdot
.99 .23915 Mdot
.99 .24032 Mdot
.99 .24073 Mdot
.99 .24171 Mdot
.99 .24224 Mdot
.99 .24313 Mdot
.99 .24419 Mdot
.99 .24435 Mdot
.99 .24482 Mdot
.99 .24598 Mdot
.99 .24861 Mdot
.99 .2491 Mdot
.99 .25211 Mdot
.99 .25303 Mdot
.99 .25323 Mdot
.99 .25422 Mdot
.99 .25657 Mdot
.99 .25661 Mdot
.99 .2571 Mdot
.99 .25792 Mdot
.99 .25793 Mdot
.99 .25796 Mdot
.99 .25855 Mdot
.99 .25893 Mdot
.99 .25929 Mdot
.99 .26033 Mdot
.99 .26249 Mdot
.99 .26261 Mdot
.99 .26294 Mdot
.99 .26297 Mdot
.99 .26321 Mdot
.99 .26491 Mdot
.99 .2656 Mdot
.99 .26566 Mdot
.99 .26648 Mdot
.99 .26712 Mdot
.99 .26819 Mdot
.99 .26841 Mdot
.99 .26988 Mdot
.99 .27005 Mdot
.99 .27012 Mdot
.99 .27026 Mdot
.99 .27061 Mdot
.99 .27145 Mdot
.99 .27161 Mdot
.99 .2742 Mdot
.99 .27503 Mdot
.99 .27584 Mdot
.99 .27607 Mdot
.99 .2779 Mdot
.99 .27958 Mdot
.99 .27967 Mdot
.99 .27996 Mdot
.99 .28009 Mdot
.99 .28015 Mdot
.99 .28025 Mdot
.99 .28051 Mdot
.99 .28133 Mdot
.99 .28459 Mdot
.99 .28511 Mdot
.99 .2864 Mdot
.99 .28695 Mdot
.99 .28903 Mdot
.99 .29045 Mdot
.99 .29075 Mdot
.99 .29115 Mdot
.99 .2919 Mdot
.99 .29394 Mdot
.99 .29708 Mdot
.99 .29736 Mdot
.99 .2979 Mdot
.99 .29812 Mdot
.99 .29922 Mdot
.99 .30403 Mdot
.99 .30416 Mdot
.99 .30443 Mdot
.99 .3048 Mdot
.99 .30514 Mdot
.99 .30605 Mdot
.99 .30627 Mdot
.99 .30637 Mdot
.99 .3067 Mdot
.99 .30684 Mdot
.99 .30988 Mdot
.99 .31013 Mdot
.99 .31034 Mdot
.99 .31147 Mdot
.99 .31232 Mdot
.99 .3133 Mdot
.99 .31401 Mdot
.99 .31443 Mdot
.99 .31463 Mdot
.99 .31548 Mdot
.99 .31595 Mdot
.99 .31601 Mdot
.99 .31706 Mdot
.99 .3185 Mdot
.99 .31857 Mdot
.99 .31919 Mdot
.99 .3206 Mdot
.99 .32061 Mdot
.99 .32107 Mdot
.99 .32219 Mdot
.99 .32224 Mdot
.99 .32234 Mdot
.99 .32333 Mdot
.99 .32447 Mdot
.99 .32622 Mdot
.99 .328 Mdot
.99 .32843 Mdot
.99 .33183 Mdot
.99 .33191 Mdot
.99 .3333 Mdot
.99 .33356 Mdot
.99 .33416 Mdot
.99 .33537 Mdot
.99 .3356 Mdot
.99 .33643 Mdot
.99 .34017 Mdot
.99 .34022 Mdot
.99 .34031 Mdot
.99 .34037 Mdot
.99 .34156 Mdot
.99 .34217 Mdot
.99 .3424 Mdot
.99 .34289 Mdot
.99 .34435 Mdot
.99 .34458 Mdot
.99 .34752 Mdot
.99 .34767 Mdot
.99 .34791 Mdot
.99 .34796 Mdot
.99 .35093 Mdot
.99 .35311 Mdot
.99 .35339 Mdot
.99 .3535 Mdot
.99 .35389 Mdot
.99 .355 Mdot
.99 .3556 Mdot
.99 .35654 Mdot
.99 .35671 Mdot
.99 .3576 Mdot
.99 .35776 Mdot
.99 .35842 Mdot
.99 .35862 Mdot
.99 .35914 Mdot
.99 .35917 Mdot
.99 .35972 Mdot
.99 .3607 Mdot
.99 .36092 Mdot
.99 .36121 Mdot
.99 .36144 Mdot
.99 .36151 Mdot
.99 .36168 Mdot
.99 .36219 Mdot
.99 .36244 Mdot
.99 .36272 Mdot
.99 .36311 Mdot
.99 .3638 Mdot
.99 .36487 Mdot
.99 .36553 Mdot
.99 .36556 Mdot
.99 .36571 Mdot
.99 .36604 Mdot
.99 .3661 Mdot
.99 .36664 Mdot
.99 .36697 Mdot
.99 .36712 Mdot
.99 .36867 Mdot
.99 .36946 Mdot
.99 .36973 Mdot
.99 .36979 Mdot
.99 .37041 Mdot
.99 .37044 Mdot
.99 .37181 Mdot
.99 .37188 Mdot
.99 .37233 Mdot
.99 .37261 Mdot
.99 .3729 Mdot
.99 .3735 Mdot
.99 .37356 Mdot
.99 .37443 Mdot
.99 .37465 Mdot
.99 .37474 Mdot
.99 .37509 Mdot
.99 .37614 Mdot
.99 .37628 Mdot
.99 .37915 Mdot
.99 .38084 Mdot
.99 .38158 Mdot
.99 .38306 Mdot
.99 .38432 Mdot
.99 .38989 Mdot
.99 .38999 Mdot
.99 .39157 Mdot
.99 .39214 Mdot
.99 .3923 Mdot
.99 .39257 Mdot
.99 .3936 Mdot
.99 .39417 Mdot
.99 .39507 Mdot
.99 .39521 Mdot
.99 .39577 Mdot
.99 .39675 Mdot
.99 .39753 Mdot
.99 .39849 Mdot
.99 .40181 Mdot
.99 .40282 Mdot
.99 .405 Mdot
.99 .40523 Mdot
.99 .40792 Mdot
.99 .41109 Mdot
.99 .4124 Mdot
.99 .41411 Mdot
.99 .41594 Mdot
.99 .41602 Mdot
.99 .41807 Mdot
.99 .41861 Mdot
.99 .41908 Mdot
.99 .41992 Mdot
.99 .42069 Mdot
.99 .42155 Mdot
.99 .4223 Mdot
.99 .42622 Mdot
.99 .42633 Mdot
.99 .42657 Mdot
.99 .42713 Mdot
.99 .42796 Mdot
.99 .42801 Mdot
.99 .42886 Mdot
.99 .42896 Mdot
.99 .43039 Mdot
.99 .43451 Mdot
.99 .43464 Mdot
.99 .43467 Mdot
.99 .43751 Mdot
.99 .4381 Mdot
.99 .43909 Mdot
.99 .44216 Mdot
.99 .44236 Mdot
.99 .44309 Mdot
.99 .44402 Mdot
.99 .44506 Mdot
.99 .44576 Mdot
.99 .44581 Mdot
.99 .44619 Mdot
.99 .44817 Mdot
.99 .44896 Mdot
.99 .44905 Mdot
.99 .4505 Mdot
.99 .45096 Mdot
.99 .45263 Mdot
.99 .45454 Mdot
.99 .45524 Mdot
.99 .45602 Mdot
.99 .45644 Mdot
.99 .45821 Mdot
.99 .46261 Mdot
.99 .46458 Mdot
.99 .46574 Mdot
.99 .46678 Mdot
.99 .46864 Mdot
.99 .47127 Mdot
.99 .47134 Mdot
.99 .47158 Mdot
.99 .47228 Mdot
.99 .47794 Mdot
.99 .47869 Mdot
.99 .47905 Mdot
.99 .47932 Mdot
.99 .47943 Mdot
.99 .48031 Mdot
.99 .48071 Mdot
.99 .48172 Mdot
.99 .48185 Mdot
.99 .48207 Mdot
.99 .48209 Mdot
.99 .48229 Mdot
.99 .4823 Mdot
.99 .483 Mdot
.99 .48328 Mdot
.99 .48354 Mdot
.99 .48364 Mdot
.99 .48385 Mdot
.99 .48392 Mdot
.99 .48394 Mdot
.99 .48404 Mdot
.99 .48415 Mdot
.99 .48463 Mdot
.99 .48486 Mdot
.99 .48515 Mdot
.99 .48541 Mdot
.99 .48548 Mdot
.99 .48589 Mdot
.99 .48627 Mdot
.99 .48651 Mdot
.99 .48694 Mdot
.99 .48714 Mdot
.99 .48725 Mdot
.99 .48811 Mdot
.99 .4893 Mdot
.99 .48945 Mdot
.99 .49069 Mdot
.99 .49178 Mdot
.99 .49224 Mdot
.99 .49232 Mdot
.99 .49408 Mdot
.99 .49417 Mdot
.99 .49487 Mdot
.99 .49497 Mdot
.99 .4955 Mdot
.99 .49553 Mdot
.99 .49683 Mdot
.99 .49699 Mdot
.99 .49767 Mdot
.99 .49834 Mdot
.99 .4992 Mdot
.99 .4998 Mdot
.99 .50034 Mdot
.99 .5006 Mdot
.99 .50153 Mdot
.99 .50155 Mdot
.99 .50173 Mdot
.99 .50205 Mdot
.99 .50292 Mdot
.99 .50383 Mdot
.99 .50501 Mdot
.99 .50513 Mdot
.99 .50595 Mdot
.99 .506 Mdot
.99 .50818 Mdot
.99 .50826 Mdot
.99 .50972 Mdot
.99 .51074 Mdot
.99 .51088 Mdot
.99 .51099 Mdot
.99 .51247 Mdot
.99 .51313 Mdot
.99 .5146 Mdot
.99 .51473 Mdot
.99 .5178 Mdot
.99 .51816 Mdot
.99 .51829 Mdot
.99 .51895 Mdot
.99 .51964 Mdot
.99 .5202 Mdot
.99 .52101 Mdot
.99 .52232 Mdot
.99 .52245 Mdot
.99 .52266 Mdot
.99 .52267 Mdot
.99 .52314 Mdot
.99 .52398 Mdot
.99 .52579 Mdot
.99 .52596 Mdot
.99 .52745 Mdot
.99 .52788 Mdot
.99 .52819 Mdot
.99 .52872 Mdot
.99 .52886 Mdot
.99 .52927 Mdot
.99 .52949 Mdot
.99 .52983 Mdot
.99 .53196 Mdot
.99 .53229 Mdot
.99 .5323 Mdot
.99 .53318 Mdot
.99 .53322 Mdot
.99 .53336 Mdot
.99 .53365 Mdot
.99 .53392 Mdot
.99 .53459 Mdot
.99 .53474 Mdot
.99 .53548 Mdot
.99 .53578 Mdot
.99 .53604 Mdot
.99 .53612 Mdot
.99 .53676 Mdot
.99 .53689 Mdot
.99 .53708 Mdot
.99 .53756 Mdot
.99 .53797 Mdot
.99 .53816 Mdot
.99 .53832 Mdot
.99 .53894 Mdot
.99 .53909 Mdot
.99 .54049 Mdot
.99 .54082 Mdot
.99 .54085 Mdot
.99 .54106 Mdot
.99 .54182 Mdot
.99 .54183 Mdot
.99 .54244 Mdot
.99 .54296 Mdot
.99 .54348 Mdot
.99 .54364 Mdot
.99 .54389 Mdot
.99 .54402 Mdot
.99 .54546 Mdot
.99 .54585 Mdot
.99 .54665 Mdot
.99 .5469 Mdot
.99 .54695 Mdot
.99 .54815 Mdot
.99 .55054 Mdot
.99 .55103 Mdot
.99 .55173 Mdot
.99 .5525 Mdot
.99 .55256 Mdot
.99 .55268 Mdot
.99 .5543 Mdot
.99 .55431 Mdot
.99 .55518 Mdot
.99 .55532 Mdot
.99 .55554 Mdot
.99 .5563 Mdot
.99 .55654 Mdot
.99 .55666 Mdot
.99 .55712 Mdot
.99 .55739 Mdot
.99 .55871 Mdot
.99 .55917 Mdot
.99 .56025 Mdot
.99 .56032 Mdot
.99 .56047 Mdot
.99 .56083 Mdot
.99 .56161 Mdot
.99 .56178 Mdot
.99 .56198 Mdot
.99 .56208 Mdot
.99 .56231 Mdot
.99 .56291 Mdot
.99 .56308 Mdot
.99 .56323 Mdot
.99 .56329 Mdot
.99 .56357 Mdot
.99 .56393 Mdot
.99 .56423 Mdot
.99 .56451 Mdot
.99 .56478 Mdot
.99 .56498 Mdot
.99 .56505 Mdot
.99 .56643 Mdot
.99 .56647 Mdot
.99 .56708 Mdot
.99 .56714 Mdot
.99 .56741 Mdot
.99 .56742 Mdot
.99 .5679 Mdot
.99 .56818 Mdot
.99 .56967 Mdot
.99 .56982 Mdot
.99 .57012 Mdot
.99 .57063 Mdot
.99 .57068 Mdot
.99 .57077 Mdot
.99 .57099 Mdot
.99 .57113 Mdot
.99 .57116 Mdot
.99 .57163 Mdot
.99 .57176 Mdot
.99 .5718 Mdot
.99 .5727 Mdot
.99 .57273 Mdot
.99 .57335 Mdot
.99 .57369 Mdot
.99 .57394 Mdot
.99 .57416 Mdot
.99 .5746 Mdot
.99 .57475 Mdot
.99 .57476 Mdot
.99 .5748 Mdot
.99 .57481 Mdot
.99 .57501 Mdot
.99 .57522 Mdot
.99 .57525 Mdot
.99 .57544 Mdot
.99 .57591 Mdot
.99 .57592 Mdot
.99 .57594 Mdot
.99 .57626 Mdot
.99 .57644 Mdot
.99 .57671 Mdot
.99 .57674 Mdot
.99 .57674 Mdot
.99 .57705 Mdot
.99 .57717 Mdot
.99 .57732 Mdot
.99 .57786 Mdot
.99 .57788 Mdot
.99 .57799 Mdot
.99 .57869 Mdot
.99 .57882 Mdot
.99 .57955 Mdot
.99 .57957 Mdot
.99 .57966 Mdot
.99 .57992 Mdot
.99 .57993 Mdot
.99 .58001 Mdot
.99 .58012 Mdot
.99 .58083 Mdot
.99 .58112 Mdot
.99 .5812 Mdot
.99 .58138 Mdot
.99 .5814 Mdot
.99 .58187 Mdot
.99 .58192 Mdot
.99 .5825 Mdot
.99 .58294 Mdot
.99 .58295 Mdot
.99 .58367 Mdot
.99 .58381 Mdot
.99 .58478 Mdot
.99 .58489 Mdot
.99 .58492 Mdot
.99 .58494 Mdot
.99 .58495 Mdot
.99 .58503 Mdot
.99 .58511 Mdot
.99 .5852 Mdot
.99 .58525 Mdot
.99 .58577 Mdot
.99 .58588 Mdot
.99 .587 Mdot
.99 .58713 Mdot
.99 .58742 Mdot
.99 .58789 Mdot
.99 .58797 Mdot
.99 .58824 Mdot
.99 .58834 Mdot
.99 .58837 Mdot
.99 .58846 Mdot
.99 .5887 Mdot
.99 .58932 Mdot
.99 .58936 Mdot
.99 .5894 Mdot
.99 .58943 Mdot
.99 .58943 Mdot
.99 .59027 Mdot
.99 .59032 Mdot
.99 .59046 Mdot
.99 .59052 Mdot
.99 .59055 Mdot
.99 .59059 Mdot
.99 .59072 Mdot
.99 .5911 Mdot
.99 .59124 Mdot
.99 .59161 Mdot
.99 .59171 Mdot
.99 .59222 Mdot
.99 .59247 Mdot
.99 .59251 Mdot
.99 .59258 Mdot
.99 .59272 Mdot
.99 .59312 Mdot
.99 .59315 Mdot
.99 .59321 Mdot
.99 .59341 Mdot
.99 .59414 Mdot
.99 .59434 Mdot
.99 .59447 Mdot
.99 .59459 Mdot
.99 .59469 Mdot
.99 .5948 Mdot
.99 .595 Mdot
.99 .59502 Mdot
.99 .59548 Mdot
.99 .59557 Mdot
.99 .59576 Mdot
.99 .59599 Mdot
.99 .59601 Mdot
.99 .59602 Mdot
.99 .59625 Mdot
.99 .59627 Mdot
.99 .59633 Mdot
.99 .59634 Mdot
.99 .59635 Mdot
.99 .59643 Mdot
.99 .59647 Mdot
.99 .5966 Mdot
.99 .59666 Mdot
.99 .5967 Mdot
.99 .59671 Mdot
.99 .59692 Mdot
.99 .59705 Mdot
.99 .59706 Mdot
.99 .59711 Mdot
.99 .5972 Mdot
.99 .59721 Mdot
.99 .59725 Mdot
.99 .59725 Mdot
.99 .59726 Mdot
.99 .59728 Mdot
.99 .59731 Mdot
.99 .59731 Mdot
.99 .59733 Mdot
.99 .59737 Mdot
.99 .59738 Mdot
.99 .59739 Mdot
.99 .5974 Mdot
.99 .59741 Mdot
.99 .59741 Mdot
.99 .59742 Mdot
.99 .59744 Mdot
.99 .59745 Mdot
.99 .59745 Mdot
.992 .02939 Mdot
.992 .02941 Mdot
.992 .02943 Mdot
.992 .02957 Mdot
.992 .02958 Mdot
.992 .02959 Mdot
.992 .02974 Mdot
.992 .0298 Mdot
.992 .0298 Mdot
.992 .02982 Mdot
.992 .02983 Mdot
.992 .02987 Mdot
.992 .02992 Mdot
.992 .02997 Mdot
.992 .02999 Mdot
.992 .03068 Mdot
.992 .03073 Mdot
.992 .03128 Mdot
.992 .03146 Mdot
.992 .03167 Mdot
.992 .0317 Mdot
.992 .03243 Mdot
.992 .03259 Mdot
.992 .03309 Mdot
.992 .03311 Mdot
.992 .03329 Mdot
.992 .0336 Mdot
.992 .03419 Mdot
.992 .03422 Mdot
.992 .03438 Mdot
.992 .03465 Mdot
.992 .03501 Mdot
.992 .03556 Mdot
.992 .03592 Mdot
.992 .03593 Mdot
.992 .036 Mdot
.992 .03633 Mdot
.992 .03661 Mdot
.992 .03679 Mdot
.992 .03687 Mdot
.992 .03694 Mdot
.992 .03725 Mdot
.992 .03862 Mdot
.992 .03904 Mdot
.992 .03933 Mdot
.992 .03936 Mdot
.992 .03985 Mdot
.992 .04066 Mdot
.992 .04165 Mdot
.992 .04241 Mdot
.992 .04519 Mdot
.992 .04576 Mdot
.992 .04605 Mdot
.992 .04606 Mdot
.992 .0463 Mdot
.992 .04652 Mdot
.992 .04809 Mdot
.992 .04832 Mdot
.992 .04837 Mdot
.992 .04863 Mdot
.992 .04999 Mdot
.992 .05052 Mdot
.992 .05052 Mdot
.992 .0511 Mdot
.992 .0521 Mdot
.992 .05214 Mdot
.992 .05219 Mdot
.992 .05247 Mdot
.992 .05258 Mdot
.992 .0527 Mdot
.992 .05293 Mdot
.992 .05437 Mdot
.992 .05497 Mdot
.992 .05505 Mdot
.992 .05506 Mdot
.992 .05537 Mdot
.992 .05695 Mdot
.992 .05697 Mdot
.992 .0571 Mdot
.992 .05744 Mdot
.992 .05797 Mdot
.992 .05815 Mdot
.992 .0594 Mdot
.992 .0604 Mdot
.992 .06046 Mdot
.992 .06052 Mdot
.992 .06096 Mdot
.992 .061 Mdot
.992 .06102 Mdot
.992 .0615 Mdot
.992 .06166 Mdot
.992 .06168 Mdot
.992 .06174 Mdot
.992 .06178 Mdot
.992 .06188 Mdot
.992 .06193 Mdot
.992 .06204 Mdot
.992 .06214 Mdot
.992 .06221 Mdot
.992 .06227 Mdot
.992 .06298 Mdot
.992 .06371 Mdot
.992 .06377 Mdot
.992 .06441 Mdot
.992 .06457 Mdot
.992 .06582 Mdot
.992 .06585 Mdot
.992 .06626 Mdot
.992 .06682 Mdot
.992 .06687 Mdot
.992 .06711 Mdot
.992 .06749 Mdot
.992 .06758 Mdot
.992 .0698 Mdot
.992 .06985 Mdot
.992 .07033 Mdot
.992 .07033 Mdot
.992 .0719 Mdot
.992 .07195 Mdot
.992 .07204 Mdot
.992 .07209 Mdot
.992 .0725 Mdot
.992 .07336 Mdot
.992 .07348 Mdot
.992 .07414 Mdot
.992 .07441 Mdot
.992 .07488 Mdot
.992 .07528 Mdot
.992 .0753 Mdot
.992 .07538 Mdot
.992 .07558 Mdot
.992 .07587 Mdot
.992 .07673 Mdot
.992 .07688 Mdot
.992 .07742 Mdot
.992 .07783 Mdot
.992 .07804 Mdot
.992 .07895 Mdot
.992 .0793 Mdot
.992 .07954 Mdot
.992 .07966 Mdot
.992 .07979 Mdot
.992 .08047 Mdot
.992 .08048 Mdot
.992 .08065 Mdot
.992 .0807 Mdot
.992 .08091 Mdot
.992 .08192 Mdot
.992 .082 Mdot
.992 .08208 Mdot
.992 .08267 Mdot
.992 .08279 Mdot
.992 .08337 Mdot
.992 .0836 Mdot
.992 .08382 Mdot
.992 .08383 Mdot
.992 .08477 Mdot
.992 .08554 Mdot
.992 .08763 Mdot
.992 .08788 Mdot
.992 .08849 Mdot
.992 .08901 Mdot
.992 .0895 Mdot
.992 .08981 Mdot
.992 .09031 Mdot
.992 .09062 Mdot
.992 .09115 Mdot
.992 .09121 Mdot
.992 .09129 Mdot
.992 .09258 Mdot
.992 .09281 Mdot
.992 .09371 Mdot
.992 .09436 Mdot
.992 .09445 Mdot
.992 .09532 Mdot
.992 .09558 Mdot
.992 .09601 Mdot
.992 .09836 Mdot
.992 .09855 Mdot
.992 .09889 Mdot
.992 .09977 Mdot
.992 .10071 Mdot
.992 .10211 Mdot
.992 .10274 Mdot
.992 .10277 Mdot
.992 .10309 Mdot
.992 .10747 Mdot
.992 .10785 Mdot
.992 .10917 Mdot
.992 .10927 Mdot
.992 .11103 Mdot
.992 .11191 Mdot
.992 .11193 Mdot
.992 .11268 Mdot
.992 .11336 Mdot
.992 .11518 Mdot
.992 .11633 Mdot
.992 .11703 Mdot
.992 .11817 Mdot
.992 .11889 Mdot
.992 .11903 Mdot
.992 .11984 Mdot
.992 .12327 Mdot
.992 .12327 Mdot
.992 .124 Mdot
.992 .12492 Mdot
.992 .12562 Mdot
.992 .12563 Mdot
.992 .12635 Mdot
.992 .1274 Mdot
.992 .1282 Mdot
.992 .12888 Mdot
.992 .12945 Mdot
.992 .13046 Mdot
.992 .13058 Mdot
.992 .13072 Mdot
.992 .131 Mdot
.992 .1313 Mdot
.992 .13158 Mdot
.992 .13193 Mdot
.992 .13207 Mdot
.992 .13228 Mdot
.992 .133 Mdot
.992 .13326 Mdot
.992 .13364 Mdot
.992 .13427 Mdot
.992 .13714 Mdot
.992 .13736 Mdot
.992 .13819 Mdot
.992 .1392 Mdot
.992 .13926 Mdot
.992 .13944 Mdot
.992 .13949 Mdot
.992 .13971 Mdot
.992 .14038 Mdot
.992 .14041 Mdot
.992 .14115 Mdot
.992 .14155 Mdot
.992 .14174 Mdot
.992 .14233 Mdot
.992 .14331 Mdot
.992 .1447 Mdot
.992 .14523 Mdot
.992 .14528 Mdot
.992 .14569 Mdot
.992 .14582 Mdot
.992 .14673 Mdot
.992 .14832 Mdot
.992 .14881 Mdot
.992 .14886 Mdot
.992 .1491 Mdot
.992 .14948 Mdot
.992 .15116 Mdot
.992 .15267 Mdot
.992 .15422 Mdot
.992 .15461 Mdot
.992 .15524 Mdot
.992 .15568 Mdot
.992 .15587 Mdot
.992 .15606 Mdot
.992 .15738 Mdot
.992 .15751 Mdot
.992 .15755 Mdot
.992 .15866 Mdot
.992 .15901 Mdot
.992 .1595 Mdot
.992 .15955 Mdot
.992 .15973 Mdot
.992 .15984 Mdot
.992 .16016 Mdot
.992 .16028 Mdot
.992 .1603 Mdot
.992 .16055 Mdot
.992 .16064 Mdot
.992 .16065 Mdot
.992 .16075 Mdot
.992 .16095 Mdot
.992 .16116 Mdot
.992 .16133 Mdot
.992 .16138 Mdot
.992 .16278 Mdot
.992 .16328 Mdot
.992 .16347 Mdot
.992 .16533 Mdot
.992 .16567 Mdot
.992 .16587 Mdot
.992 .16779 Mdot
.992 .16801 Mdot
.992 .16826 Mdot
.992 .17202 Mdot
.992 .17211 Mdot
.992 .17333 Mdot
.992 .17391 Mdot
.992 .17473 Mdot
.992 .17501 Mdot
.992 .17518 Mdot
.992 .17589 Mdot
.992 .17626 Mdot
.992 .17703 Mdot
.992 .17728 Mdot
.992 .17979 Mdot
.992 .18393 Mdot
.992 .18407 Mdot
.992 .18506 Mdot
.992 .18538 Mdot
.992 .18546 Mdot
.992 .18551 Mdot
.992 .18551 Mdot
.992 .18644 Mdot
.992 .18742 Mdot
.992 .19018 Mdot
.992 .19034 Mdot
.992 .1906 Mdot
.992 .19075 Mdot
.992 .19128 Mdot
.992 .19172 Mdot
.992 .19197 Mdot
.992 .19386 Mdot
.992 .19398 Mdot
.992 .19452 Mdot
.992 .19486 Mdot
.992 .19519 Mdot
.992 .19523 Mdot
.992 .19552 Mdot
.992 .19653 Mdot
.992 .1967 Mdot
.992 .19681 Mdot
.992 .19761 Mdot
.992 .19901 Mdot
.992 .20014 Mdot
.992 .20018 Mdot
.992 .20027 Mdot
.992 .2005 Mdot
.992 .20107 Mdot
.992 .20194 Mdot
.992 .20314 Mdot
.992 .20408 Mdot
.992 .20447 Mdot
.992 .20475 Mdot
.992 .20482 Mdot
.992 .20484 Mdot
.992 .20491 Mdot
.992 .20524 Mdot
.992 .20588 Mdot
.992 .20651 Mdot
.992 .2074 Mdot
.992 .20772 Mdot
.992 .20796 Mdot
.992 .20832 Mdot
.992 .21013 Mdot
.992 .21101 Mdot
.992 .21203 Mdot
.992 .21273 Mdot
.992 .21309 Mdot
.992 .21346 Mdot
.992 .21546 Mdot
.992 .21549 Mdot
.992 .21598 Mdot
.992 .21612 Mdot
.992 .21674 Mdot
.992 .21695 Mdot
.992 .21832 Mdot
.992 .21961 Mdot
.992 .21969 Mdot
.992 .21992 Mdot
.992 .22016 Mdot
.992 .22039 Mdot
.992 .22189 Mdot
.992 .22222 Mdot
.992 .22391 Mdot
.992 .22445 Mdot
.992 .22459 Mdot
.992 .22523 Mdot
.992 .22524 Mdot
.992 .22525 Mdot
.992 .22542 Mdot
.992 .22566 Mdot
.992 .22642 Mdot
.992 .22734 Mdot
.992 .22768 Mdot
.992 .22769 Mdot
.992 .228 Mdot
.992 .22803 Mdot
.992 .23022 Mdot
.992 .23173 Mdot
.992 .23268 Mdot
.992 .23309 Mdot
.992 .23626 Mdot
.992 .23697 Mdot
.992 .23873 Mdot
.992 .23884 Mdot
.992 .23973 Mdot
.992 .24023 Mdot
.992 .24165 Mdot
.992 .24236 Mdot
.992 .24254 Mdot
.992 .24296 Mdot
.992 .24395 Mdot
.992 .24484 Mdot
.992 .24504 Mdot
.992 .24516 Mdot
.992 .24637 Mdot
.992 .24655 Mdot
.992 .24677 Mdot
.992 .24838 Mdot
.992 .25047 Mdot
.992 .2511 Mdot
.992 .25367 Mdot
.992 .2538 Mdot
.992 .2554 Mdot
.992 .25553 Mdot
.992 .25576 Mdot
.992 .25697 Mdot
.992 .25824 Mdot
.992 .25897 Mdot
.992 .25999 Mdot
.992 .2602 Mdot
.992 .26351 Mdot
.992 .26446 Mdot
.992 .26608 Mdot
.992 .26681 Mdot
.992 .26735 Mdot
.992 .26831 Mdot
.992 .26834 Mdot
.992 .27078 Mdot
.992 .2734 Mdot
.992 .27636 Mdot
.992 .27731 Mdot
.992 .27793 Mdot
.992 .27899 Mdot
.992 .27907 Mdot
.992 .27914 Mdot
.992 .27932 Mdot
.992 .28004 Mdot
.992 .28044 Mdot
.992 .28329 Mdot
.992 .28442 Mdot
.992 .28726 Mdot
.992 .28972 Mdot
.992 .29014 Mdot
.992 .2916 Mdot
.992 .29195 Mdot
.992 .29203 Mdot
.992 .29212 Mdot
.992 .29233 Mdot
.992 .29315 Mdot
.992 .29359 Mdot
.992 .2943 Mdot
.992 .29537 Mdot
.992 .29627 Mdot
.992 .29676 Mdot
.992 .29704 Mdot
.992 .29819 Mdot
.992 .29964 Mdot
.992 .30183 Mdot
.992 .30421 Mdot
.992 .30428 Mdot
.992 .30506 Mdot
.992 .30629 Mdot
.992 .30814 Mdot
.992 .30907 Mdot
.992 .31028 Mdot
.992 .31167 Mdot
.992 .3118 Mdot
.992 .31273 Mdot
.992 .31302 Mdot
.992 .31311 Mdot
.992 .31317 Mdot
.992 .31332 Mdot
.992 .31355 Mdot
.992 .31609 Mdot
.992 .31756 Mdot
.992 .31796 Mdot
.992 .31847 Mdot
.992 .32014 Mdot
.992 .32099 Mdot
.992 .32265 Mdot
.992 .32291 Mdot
.992 .32329 Mdot
.992 .32493 Mdot
.992 .32501 Mdot
.992 .3254 Mdot
.992 .32863 Mdot
.992 .32866 Mdot
.992 .32913 Mdot
.992 .3299 Mdot
.992 .33146 Mdot
.992 .33375 Mdot
.992 .33419 Mdot
.992 .33441 Mdot
.992 .33442 Mdot
.992 .3346 Mdot
.992 .33592 Mdot
.992 .33609 Mdot
.992 .33613 Mdot
.992 .33631 Mdot
.992 .33726 Mdot
.992 .33763 Mdot
.992 .33868 Mdot
.992 .33871 Mdot
.992 .33922 Mdot
.992 .3405 Mdot
.992 .34055 Mdot
.992 .34056 Mdot
.992 .34171 Mdot
.992 .34179 Mdot
.992 .34199 Mdot
.992 .3423 Mdot
.992 .34241 Mdot
.992 .34313 Mdot
.992 .34454 Mdot
.992 .34511 Mdot
.992 .34551 Mdot
.992 .34554 Mdot
.992 .34662 Mdot
.992 .34663 Mdot
.992 .34716 Mdot
.992 .34863 Mdot
.992 .34889 Mdot
.992 .35035 Mdot
.992 .35084 Mdot
.992 .35106 Mdot
.992 .35138 Mdot
.992 .35223 Mdot
.992 .3525 Mdot
.992 .35292 Mdot
.992 .35307 Mdot
.992 .35323 Mdot
.992 .35329 Mdot
.992 .35359 Mdot
.992 .35425 Mdot
.992 .35429 Mdot
.992 .35504 Mdot
.992 .35577 Mdot
.992 .35664 Mdot
.992 .35674 Mdot
.992 .35699 Mdot
.992 .3574 Mdot
.992 .35753 Mdot
.992 .35864 Mdot
.992 .35934 Mdot
.992 .35938 Mdot
.992 .35999 Mdot
.992 .36096 Mdot
.992 .36142 Mdot
.992 .36254 Mdot
.992 .36486 Mdot
.992 .36735 Mdot
.992 .36968 Mdot
.992 .37022 Mdot
.992 .37069 Mdot
.992 .37218 Mdot
.992 .37228 Mdot
.992 .37252 Mdot
.992 .37443 Mdot
.992 .37476 Mdot
.992 .3749 Mdot
.992 .37534 Mdot
.992 .37546 Mdot
.992 .37599 Mdot
.992 .37674 Mdot
.992 .37763 Mdot
.992 .37772 Mdot
.992 .37951 Mdot
.992 .38049 Mdot
.992 .38095 Mdot
.992 .38103 Mdot
.992 .38106 Mdot
.992 .38127 Mdot
.992 .38166 Mdot
.992 .38238 Mdot
.992 .38312 Mdot
.992 .38474 Mdot
.992 .38773 Mdot
.992 .38781 Mdot
.992 .38809 Mdot
.992 .38835 Mdot
.992 .38936 Mdot
.992 .38947 Mdot
.992 .39045 Mdot
.992 .39076 Mdot
.992 .39293 Mdot
.992 .39309 Mdot
.992 .39649 Mdot
.992 .39668 Mdot
.992 .39785 Mdot
.992 .39796 Mdot
.992 .39845 Mdot
.992 .39853 Mdot
.992 .39942 Mdot
.992 .39964 Mdot
.992 .40334 Mdot
.992 .40683 Mdot
.992 .40742 Mdot
.992 .41041 Mdot
.992 .4113 Mdot
.992 .41273 Mdot
.992 .41374 Mdot
.992 .41418 Mdot
.992 .4146 Mdot
.992 .41726 Mdot
.992 .41759 Mdot
.992 .41789 Mdot
.992 .41797 Mdot
.992 .41885 Mdot
.992 .41941 Mdot
.992 .41995 Mdot
.992 .42046 Mdot
.992 .42125 Mdot
.992 .42186 Mdot
.992 .42236 Mdot
.992 .42245 Mdot
.992 .42286 Mdot
.992 .42312 Mdot
.992 .42342 Mdot
.992 .42383 Mdot
.992 .42409 Mdot
.992 .42414 Mdot
.992 .42438 Mdot
.992 .42469 Mdot
.992 .42489 Mdot
.992 .4249 Mdot
.992 .42513 Mdot
.992 .42514 Mdot
.992 .42557 Mdot
.992 .42604 Mdot
.992 .42616 Mdot
.992 .4264 Mdot
.992 .42652 Mdot
.992 .42832 Mdot
.992 .42906 Mdot
.992 .4296 Mdot
.992 .43032 Mdot
.992 .43071 Mdot
.992 .43112 Mdot
.992 .43401 Mdot
.992 .43515 Mdot
.992 .43589 Mdot
.992 .43632 Mdot
.992 .43658 Mdot
.992 .44043 Mdot
.992 .44091 Mdot
.992 .44145 Mdot
.992 .44201 Mdot
.992 .4424 Mdot
.992 .44935 Mdot
.992 .44953 Mdot
.992 .45207 Mdot
.992 .45326 Mdot
.992 .45495 Mdot
.992 .45553 Mdot
.992 .45586 Mdot
.992 .45684 Mdot
.992 .45731 Mdot
.992 .45764 Mdot
.992 .45808 Mdot
.992 .45878 Mdot
.992 .45963 Mdot
.992 .45987 Mdot
.992 .46012 Mdot
.992 .46083 Mdot
.992 .46514 Mdot
.992 .46848 Mdot
.992 .46899 Mdot
.992 .46982 Mdot
.992 .47126 Mdot
.992 .47325 Mdot
.992 .47347 Mdot
.992 .47351 Mdot
.992 .47542 Mdot
.992 .47602 Mdot
.992 .47619 Mdot
.992 .47627 Mdot
.992 .47628 Mdot
.992 .47804 Mdot
.992 .47899 Mdot
.992 .47976 Mdot
.992 .4799 Mdot
.992 .48051 Mdot
.992 .48185 Mdot
.992 .48286 Mdot
.992 .48423 Mdot
.992 .48504 Mdot
.992 .48534 Mdot
.992 .48583 Mdot
.992 .48609 Mdot
.992 .48707 Mdot
.992 .48754 Mdot
.992 .48776 Mdot
.992 .48787 Mdot
.992 .4882 Mdot
.992 .48833 Mdot
.992 .48842 Mdot
.992 .48928 Mdot
.992 .49006 Mdot
.992 .49007 Mdot
.992 .49049 Mdot
.992 .4905 Mdot
.992 .49088 Mdot
.992 .49142 Mdot
.992 .49175 Mdot
.992 .49186 Mdot
.992 .49194 Mdot
.992 .49197 Mdot
.992 .49242 Mdot
.992 .49294 Mdot
.992 .49315 Mdot
.992 .49355 Mdot
.992 .49369 Mdot
.992 .49413 Mdot
.992 .49414 Mdot
.992 .49421 Mdot
.992 .49471 Mdot
.992 .49487 Mdot
.992 .49504 Mdot
.992 .49592 Mdot
.992 .49651 Mdot
.992 .4968 Mdot
.992 .49699 Mdot
.992 .497 Mdot
.992 .49837 Mdot
.992 .4984 Mdot
.992 .49926 Mdot
.992 .50021 Mdot
.992 .50084 Mdot
.992 .50118 Mdot
.992 .50268 Mdot
.992 .50277 Mdot
.992 .50282 Mdot
.992 .50284 Mdot
.992 .50299 Mdot
.992 .50333 Mdot
.992 .50338 Mdot
.992 .5039 Mdot
.992 .50435 Mdot
.992 .50583 Mdot
.992 .50784 Mdot
.992 .50837 Mdot
.992 .50907 Mdot
.992 .5094 Mdot
.992 .50979 Mdot
.992 .51005 Mdot
.992 .51051 Mdot
.992 .51062 Mdot
.992 .51065 Mdot
.992 .51078 Mdot
.992 .51131 Mdot
.992 .51146 Mdot
.992 .51235 Mdot
.992 .51338 Mdot
.992 .51379 Mdot
.992 .51482 Mdot
.992 .51522 Mdot
.992 .51534 Mdot
.992 .51572 Mdot
.992 .51629 Mdot
.992 .51916 Mdot
.992 .51996 Mdot
.992 .52053 Mdot
.992 .52087 Mdot
.992 .52212 Mdot
.992 .52319 Mdot
.992 .52374 Mdot
.992 .5243 Mdot
.992 .52621 Mdot
.992 .52733 Mdot
.992 .52737 Mdot
.992 .5281 Mdot
.992 .52831 Mdot
.992 .52922 Mdot
.992 .52953 Mdot
.992 .53152 Mdot
.992 .53167 Mdot
.992 .532 Mdot
.992 .53327 Mdot
.992 .53339 Mdot
.992 .53339 Mdot
.992 .53351 Mdot
.992 .53383 Mdot
.992 .53409 Mdot
.992 .53417 Mdot
.992 .53424 Mdot
.992 .53451 Mdot
.992 .5359 Mdot
.992 .53617 Mdot
.992 .53661 Mdot
.992 .53708 Mdot
.992 .53941 Mdot
.992 .54014 Mdot
.992 .54033 Mdot
.992 .54085 Mdot
.992 .54107 Mdot
.992 .5412 Mdot
.992 .54121 Mdot
.992 .54123 Mdot
.992 .54146 Mdot
.992 .54178 Mdot
.992 .5428 Mdot
.992 .54396 Mdot
.992 .54401 Mdot
.992 .54436 Mdot
.992 .54445 Mdot
.992 .54447 Mdot
.992 .54488 Mdot
.992 .54492 Mdot
.992 .54564 Mdot
.992 .54579 Mdot
.992 .54708 Mdot
.992 .54741 Mdot
.992 .54774 Mdot
.992 .54777 Mdot
.992 .54788 Mdot
.992 .54964 Mdot
.992 .55082 Mdot
.992 .55133 Mdot
.992 .55161 Mdot
.992 .55357 Mdot
.992 .55446 Mdot
.992 .55514 Mdot
.992 .55531 Mdot
.992 .55577 Mdot
.992 .55598 Mdot
.992 .55602 Mdot
.992 .55605 Mdot
.992 .55614 Mdot
.992 .55667 Mdot
.992 .55781 Mdot
.992 .55801 Mdot
.992 .55814 Mdot
.992 .55915 Mdot
.992 .55971 Mdot
.992 .55983 Mdot
.992 .55993 Mdot
.992 .56091 Mdot
.992 .56128 Mdot
.992 .56174 Mdot
.992 .56206 Mdot
.992 .56225 Mdot
.992 .56232 Mdot
.992 .56245 Mdot
.992 .5627 Mdot
.992 .56292 Mdot
.992 .56307 Mdot
.992 .56342 Mdot
.992 .56376 Mdot
.992 .56471 Mdot
.992 .56491 Mdot
.992 .56504 Mdot
.992 .56543 Mdot
.992 .56568 Mdot
.992 .56578 Mdot
.992 .56629 Mdot
.992 .56647 Mdot
.992 .56669 Mdot
.992 .5673 Mdot
.992 .56777 Mdot
.992 .56831 Mdot
.992 .56831 Mdot
.992 .57034 Mdot
.992 .57057 Mdot
.992 .57095 Mdot
.992 .5729 Mdot
.992 .57333 Mdot
.992 .57345 Mdot
.992 .57487 Mdot
.992 .57498 Mdot
.992 .57499 Mdot
.992 .57519 Mdot
.992 .57595 Mdot
.992 .57624 Mdot
.992 .57635 Mdot
.992 .57717 Mdot
.992 .57731 Mdot
.992 .57768 Mdot
.992 .57771 Mdot
.992 .57792 Mdot
.992 .57828 Mdot
.992 .57875 Mdot
.992 .57892 Mdot
.992 .57918 Mdot
.992 .57928 Mdot
.992 .57961 Mdot
.992 .57981 Mdot
.992 .57989 Mdot
.992 .58056 Mdot
.992 .58112 Mdot
.992 .58149 Mdot
.992 .58168 Mdot
.992 .58171 Mdot
.992 .58219 Mdot
.992 .5822 Mdot
.992 .58242 Mdot
.992 .58246 Mdot
.992 .58258 Mdot
.992 .58269 Mdot
.992 .58298 Mdot
.992 .58318 Mdot
.992 .58336 Mdot
.992 .58378 Mdot
.992 .58387 Mdot
.992 .584 Mdot
.992 .58416 Mdot
.992 .58424 Mdot
.992 .58449 Mdot
.992 .5849 Mdot
.992 .58492 Mdot
.992 .58547 Mdot
.992 .58564 Mdot
.992 .58651 Mdot
.992 .58658 Mdot
.992 .58691 Mdot
.992 .58692 Mdot
.992 .58758 Mdot
.992 .5876 Mdot
.992 .58784 Mdot
.992 .58811 Mdot
.992 .58818 Mdot
.992 .58899 Mdot
.992 .58939 Mdot
.992 .58945 Mdot
.992 .58962 Mdot
.992 .58973 Mdot
.992 .58977 Mdot
.992 .58978 Mdot
.992 .59029 Mdot
.992 .59039 Mdot
.992 .59039 Mdot
.992 .59042 Mdot
.992 .59061 Mdot
.992 .59107 Mdot
.992 .59115 Mdot
.992 .59118 Mdot
.992 .59122 Mdot
.992 .59131 Mdot
.992 .59132 Mdot
.992 .59134 Mdot
.992 .59166 Mdot
.992 .59185 Mdot
.992 .59185 Mdot
.992 .59202 Mdot
.992 .59245 Mdot
.992 .59254 Mdot
.992 .59255 Mdot
.992 .59263 Mdot
.992 .59313 Mdot
.992 .5932 Mdot
.992 .59328 Mdot
.992 .59328 Mdot
.992 .59338 Mdot
.992 .59356 Mdot
.992 .5936 Mdot
.992 .59445 Mdot
.992 .5947 Mdot
.992 .59501 Mdot
.992 .59528 Mdot
.992 .59543 Mdot
.992 .59544 Mdot
.992 .59554 Mdot
.992 .59567 Mdot
.992 .59611 Mdot
.992 .59621 Mdot
.992 .59623 Mdot
.992 .59626 Mdot
.992 .59632 Mdot
.992 .59641 Mdot
.992 .59651 Mdot
.992 .59653 Mdot
.992 .59654 Mdot
.992 .59665 Mdot
.992 .59683 Mdot
.992 .59694 Mdot
.992 .59703 Mdot
.992 .59708 Mdot
.992 .59709 Mdot
.992 .59728 Mdot
.992 .59738 Mdot
.992 .59744 Mdot
.992 .59744 Mdot
.992 .59761 Mdot
.992 .59766 Mdot
.992 .59789 Mdot
.992 .5979 Mdot
.992 .59797 Mdot
.992 .59803 Mdot
.992 .5982 Mdot
.992 .59822 Mdot
.992 .59844 Mdot
.992 .59845 Mdot
.992 .59846 Mdot
.992 .59848 Mdot
.992 .59849 Mdot
.992 .5985 Mdot
.992 .5985 Mdot
.992 .5985 Mdot
.992 .59852 Mdot
.992 .59857 Mdot
.992 .59857 Mdot
.992 .59858 Mdot
.992 .59862 Mdot
.992 .59863 Mdot
.992 .59863 Mdot
.994 .02576 Mdot
.994 .02577 Mdot
.994 .0258 Mdot
.994 .02583 Mdot
.994 .02583 Mdot
.994 .02583 Mdot
.994 .02593 Mdot
.994 .02599 Mdot
.994 .02672 Mdot
.994 .02678 Mdot
.994 .02709 Mdot
.994 .02732 Mdot
.994 .02739 Mdot
.994 .02741 Mdot
.994 .02746 Mdot
.994 .02766 Mdot
.994 .02806 Mdot
.994 .02824 Mdot
.994 .02851 Mdot
.994 .02853 Mdot
.994 .02875 Mdot
.994 .02901 Mdot
.994 .0291 Mdot
.994 .0292 Mdot
.994 .02921 Mdot
.994 .02989 Mdot
.994 .03044 Mdot
.994 .03059 Mdot
.994 .03134 Mdot
.994 .03225 Mdot
.994 .03279 Mdot
.994 .03306 Mdot
.994 .03329 Mdot
.994 .03352 Mdot
.994 .03467 Mdot
.994 .03589 Mdot
.994 .03645 Mdot
.994 .0369 Mdot
.994 .03744 Mdot
.994 .03753 Mdot
.994 .03757 Mdot
.994 .03768 Mdot
.994 .03796 Mdot
.994 .03835 Mdot
.994 .03871 Mdot
.994 .0394 Mdot
.994 .0396 Mdot
.994 .03966 Mdot
.994 .04006 Mdot
.994 .04031 Mdot
.994 .04037 Mdot
.994 .04044 Mdot
.994 .04061 Mdot
.994 .04157 Mdot
.994 .04165 Mdot
.994 .04187 Mdot
.994 .04224 Mdot
.994 .04323 Mdot
.994 .04337 Mdot
.994 .04356 Mdot
.994 .04371 Mdot
.994 .04374 Mdot
.994 .04377 Mdot
.994 .04397 Mdot
.994 .04403 Mdot
.994 .04461 Mdot
.994 .04474 Mdot
.994 .04525 Mdot
.994 .04546 Mdot
.994 .04574 Mdot
.994 .0489 Mdot
.994 .04918 Mdot
.994 .04922 Mdot
.994 .04932 Mdot
.994 .04939 Mdot
.994 .04939 Mdot
.994 .0494 Mdot
.994 .04942 Mdot
.994 .04954 Mdot
.994 .04971 Mdot
.994 .04974 Mdot
.994 .0499 Mdot
.994 .05016 Mdot
.994 .0502 Mdot
.994 .05217 Mdot
.994 .05236 Mdot
.994 .05246 Mdot
.994 .05291 Mdot
.994 .05312 Mdot
.994 .05332 Mdot
.994 .05364 Mdot
.994 .05405 Mdot
.994 .05425 Mdot
.994 .05426 Mdot
.994 .05433 Mdot
.994 .05448 Mdot
.994 .05492 Mdot
.994 .05512 Mdot
.994 .05513 Mdot
.994 .05598 Mdot
.994 .0562 Mdot
.994 .05635 Mdot
.994 .05692 Mdot
.994 .05774 Mdot
.994 .0578 Mdot
.994 .05781 Mdot
.994 .05824 Mdot
.994 .05832 Mdot
.994 .0585 Mdot
.994 .05872 Mdot
.994 .05932 Mdot
.994 .05937 Mdot
.994 .05948 Mdot
.994 .05958 Mdot
.994 .05989 Mdot
.994 .05993 Mdot
.994 .06036 Mdot
.994 .06098 Mdot
.994 .06106 Mdot
.994 .06204 Mdot
.994 .06225 Mdot
.994 .06375 Mdot
.994 .06423 Mdot
.994 .06532 Mdot
.994 .06564 Mdot
.994 .06658 Mdot
.994 .06698 Mdot
.994 .0694 Mdot
.994 .06975 Mdot
.994 .0706 Mdot
.994 .07106 Mdot
.994 .07118 Mdot
.994 .07137 Mdot
.994 .07159 Mdot
.994 .0719 Mdot
.994 .07262 Mdot
.994 .07271 Mdot
.994 .07333 Mdot
.994 .07408 Mdot
.994 .07583 Mdot
.994 .07688 Mdot
.994 .0769 Mdot
.994 .07968 Mdot
.994 .08069 Mdot
.994 .08243 Mdot
.994 .08244 Mdot
.994 .08288 Mdot
.994 .08323 Mdot
.994 .08383 Mdot
.994 .08499 Mdot
.994 .08514 Mdot
.994 .08552 Mdot
.994 .0858 Mdot
.994 .0858 Mdot
.994 .08591 Mdot
.994 .08623 Mdot
.994 .08711 Mdot
.994 .08782 Mdot
.994 .08791 Mdot
.994 .08826 Mdot
.994 .08833 Mdot
.994 .08924 Mdot
.994 .08945 Mdot
.994 .08989 Mdot
.994 .09102 Mdot
.994 .09157 Mdot
.994 .09219 Mdot
.994 .09239 Mdot
.994 .09356 Mdot
.994 .09362 Mdot
.994 .09366 Mdot
.994 .09396 Mdot
.994 .0944 Mdot
.994 .09457 Mdot
.994 .09478 Mdot
.994 .0948 Mdot
.994 .09497 Mdot
.994 .09531 Mdot
.994 .09653 Mdot
.994 .09781 Mdot
.994 .09822 Mdot
.994 .09825 Mdot
.994 .09828 Mdot
.994 .09852 Mdot
.994 .09923 Mdot
.994 .10036 Mdot
.994 .10058 Mdot
.994 .10122 Mdot
.994 .10169 Mdot
.994 .10229 Mdot
.994 .10341 Mdot
.994 .10363 Mdot
.994 .10386 Mdot
.994 .10396 Mdot
.994 .10443 Mdot
.994 .10445 Mdot
.994 .10489 Mdot
.994 .105 Mdot
.994 .10508 Mdot
.994 .10566 Mdot
.994 .1057 Mdot
.994 .10588 Mdot
.994 .10766 Mdot
.994 .10808 Mdot
.994 .10883 Mdot
.994 .10922 Mdot
.994 .10934 Mdot
.994 .10966 Mdot
.994 .11031 Mdot
.994 .11054 Mdot
.994 .11114 Mdot
.994 .11234 Mdot
.994 .11403 Mdot
.994 .11414 Mdot
.994 .11575 Mdot
.994 .11645 Mdot
.994 .11849 Mdot
.994 .12088 Mdot
.994 .12109 Mdot
.994 .12174 Mdot
.994 .12186 Mdot
.994 .12215 Mdot
.994 .12238 Mdot
.994 .12239 Mdot
.994 .12242 Mdot
.994 .12247 Mdot
.994 .12285 Mdot
.994 .12324 Mdot
.994 .12338 Mdot
.994 .12339 Mdot
.994 .12345 Mdot
.994 .12347 Mdot
.994 .12393 Mdot
.994 .12475 Mdot
.994 .12487 Mdot
.994 .12495 Mdot
.994 .12602 Mdot
.994 .12616 Mdot
.994 .12733 Mdot
.994 .12746 Mdot
.994 .12771 Mdot
.994 .12864 Mdot
.994 .1309 Mdot
.994 .13149 Mdot
.994 .1318 Mdot
.994 .13318 Mdot
.994 .13381 Mdot
.994 .13416 Mdot
.994 .13441 Mdot
.994 .13533 Mdot
.994 .1354 Mdot
.994 .13637 Mdot
.994 .13665 Mdot
.994 .13727 Mdot
.994 .1373 Mdot
.994 .13749 Mdot
.994 .13797 Mdot
.994 .13932 Mdot
.994 .13946 Mdot
.994 .1399 Mdot
.994 .13994 Mdot
.994 .14061 Mdot
.994 .14061 Mdot
.994 .14253 Mdot
.994 .14265 Mdot
.994 .14319 Mdot
.994 .14365 Mdot
.994 .14423 Mdot
.994 .14461 Mdot
.994 .14541 Mdot
.994 .14783 Mdot
.994 .14789 Mdot
.994 .14809 Mdot
.994 .14811 Mdot
.994 .1483 Mdot
.994 .14851 Mdot
.994 .1494 Mdot
.994 .14948 Mdot
.994 .14965 Mdot
.994 .15001 Mdot
.994 .15005 Mdot
.994 .15017 Mdot
.994 .15021 Mdot
.994 .15022 Mdot
.994 .15088 Mdot
.994 .15155 Mdot
.994 .15232 Mdot
.994 .1527 Mdot
.994 .15284 Mdot
.994 .15318 Mdot
.994 .15348 Mdot
.994 .15365 Mdot
.994 .15379 Mdot
.994 .15443 Mdot
.994 .15453 Mdot
.994 .15517 Mdot
.994 .15585 Mdot
.994 .15586 Mdot
.994 .15596 Mdot
.994 .15678 Mdot
.994 .15773 Mdot
.994 .15785 Mdot
.994 .15798 Mdot
.994 .15858 Mdot
.994 .16094 Mdot
.994 .16158 Mdot
.994 .16205 Mdot
.994 .16368 Mdot
.994 .16406 Mdot
.994 .1661 Mdot
.994 .1668 Mdot
.994 .16755 Mdot
.994 .16783 Mdot
.994 .1682 Mdot
.994 .17083 Mdot
.994 .1718 Mdot
.994 .1727 Mdot
.994 .17338 Mdot
.994 .17423 Mdot
.994 .17461 Mdot
.994 .17566 Mdot
.994 .1758 Mdot
.994 .17686 Mdot
.994 .17695 Mdot
.994 .17736 Mdot
.994 .1781 Mdot
.994 .17814 Mdot
.994 .18118 Mdot
.994 .18215 Mdot
.994 .18248 Mdot
.994 .18305 Mdot
.994 .18412 Mdot
.994 .18542 Mdot
.994 .18565 Mdot
.994 .18666 Mdot
.994 .18711 Mdot
.994 .18738 Mdot
.994 .18803 Mdot
.994 .18839 Mdot
.994 .18896 Mdot
.994 .1896 Mdot
.994 .19052 Mdot
.994 .19107 Mdot
.994 .19268 Mdot
.994 .19295 Mdot
.994 .19301 Mdot
.994 .19472 Mdot
.994 .1948 Mdot
.994 .197 Mdot
.994 .20004 Mdot
.994 .20024 Mdot
.994 .20219 Mdot
.994 .20528 Mdot
.994 .20531 Mdot
.994 .20537 Mdot
.994 .20736 Mdot
.994 .21149 Mdot
.994 .2115 Mdot
.994 .21153 Mdot
.994 .21162 Mdot
.994 .21355 Mdot
.994 .21617 Mdot
.994 .2165 Mdot
.994 .21668 Mdot
.994 .2168 Mdot
.994 .21685 Mdot
.994 .21868 Mdot
.994 .21891 Mdot
.994 .22013 Mdot
.994 .2208 Mdot
.994 .22159 Mdot
.994 .22164 Mdot
.994 .22287 Mdot
.994 .2229 Mdot
.994 .2229 Mdot
.994 .22392 Mdot
.994 .2257 Mdot
.994 .22803 Mdot
.994 .22898 Mdot
.994 .22904 Mdot
.994 .22948 Mdot
.994 .23025 Mdot
.994 .2306 Mdot
.994 .2314 Mdot
.994 .23141 Mdot
.994 .23161 Mdot
.994 .23171 Mdot
.994 .23244 Mdot
.994 .23267 Mdot
.994 .23407 Mdot
.994 .23521 Mdot
.994 .23673 Mdot
.994 .23694 Mdot
.994 .23724 Mdot
.994 .23747 Mdot
.994 .2375 Mdot
.994 .2377 Mdot
.994 .23809 Mdot
.994 .23822 Mdot
.994 .23851 Mdot
.994 .23873 Mdot
.994 .23933 Mdot
.994 .23961 Mdot
.994 .23967 Mdot
.994 .23981 Mdot
.994 .24134 Mdot
.994 .24195 Mdot
.994 .24323 Mdot
.994 .246 Mdot
.994 .24641 Mdot
.994 .24645 Mdot
.994 .24804 Mdot
.994 .24981 Mdot
.994 .25038 Mdot
.994 .25096 Mdot
.994 .25328 Mdot
.994 .25372 Mdot
.994 .25389 Mdot
.994 .254 Mdot
.994 .25487 Mdot
.994 .25612 Mdot
.994 .2566 Mdot
.994 .25719 Mdot
.994 .25726 Mdot
.994 .25773 Mdot
.994 .25871 Mdot
.994 .25915 Mdot
.994 .25941 Mdot
.994 .2598 Mdot
.994 .25994 Mdot
.994 .25997 Mdot
.994 .26112 Mdot
.994 .26217 Mdot
.994 .26501 Mdot
.994 .26579 Mdot
.994 .26641 Mdot
.994 .26693 Mdot
.994 .26703 Mdot
.994 .26711 Mdot
.994 .26778 Mdot
.994 .26977 Mdot
.994 .26993 Mdot
.994 .27294 Mdot
.994 .273 Mdot
.994 .27357 Mdot
.994 .27475 Mdot
.994 .27536 Mdot
.994 .27623 Mdot
.994 .27654 Mdot
.994 .27666 Mdot
.994 .27832 Mdot
.994 .27835 Mdot
.994 .28147 Mdot
.994 .28207 Mdot
.994 .2827 Mdot
.994 .28283 Mdot
.994 .28297 Mdot
.994 .28382 Mdot
.994 .28428 Mdot
.994 .28434 Mdot
.994 .28555 Mdot
.994 .28588 Mdot
.994 .2861 Mdot
.994 .28735 Mdot
.994 .2876 Mdot
.994 .2877 Mdot
.994 .28773 Mdot
.994 .28781 Mdot
.994 .28831 Mdot
.994 .2905 Mdot
.994 .29173 Mdot
.994 .29257 Mdot
.994 .29321 Mdot
.994 .29435 Mdot
.994 .2964 Mdot
.994 .29749 Mdot
.994 .29751 Mdot
.994 .29767 Mdot
.994 .29781 Mdot
.994 .29868 Mdot
.994 .29872 Mdot
.994 .30044 Mdot
.994 .30108 Mdot
.994 .30185 Mdot
.994 .30272 Mdot
.994 .30596 Mdot
.994 .30721 Mdot
.994 .30824 Mdot
.994 .31008 Mdot
.994 .31053 Mdot
.994 .3108 Mdot
.994 .31082 Mdot
.994 .31171 Mdot
.994 .31515 Mdot
.994 .31682 Mdot
.994 .31703 Mdot
.994 .31715 Mdot
.994 .31846 Mdot
.994 .31883 Mdot
.994 .31978 Mdot
.994 .32246 Mdot
.994 .32268 Mdot
.994 .3258 Mdot
.994 .32607 Mdot
.994 .32879 Mdot
.994 .32932 Mdot
.994 .33106 Mdot
.994 .33137 Mdot
.994 .33212 Mdot
.994 .33271 Mdot
.994 .33276 Mdot
.994 .33282 Mdot
.994 .33295 Mdot
.994 .33395 Mdot
.994 .33498 Mdot
.994 .33533 Mdot
.994 .33538 Mdot
.994 .33553 Mdot
.994 .33557 Mdot
.994 .33608 Mdot
.994 .33645 Mdot
.994 .33678 Mdot
.994 .3389 Mdot
.994 .33924 Mdot
.994 .33932 Mdot
.994 .33944 Mdot
.994 .34113 Mdot
.994 .34219 Mdot
.994 .34258 Mdot
.994 .34318 Mdot
.994 .3442 Mdot
.994 .34444 Mdot
.994 .3447 Mdot
.994 .34558 Mdot
.994 .34591 Mdot
.994 .34596 Mdot
.994 .34658 Mdot
.994 .34894 Mdot
.994 .35067 Mdot
.994 .35352 Mdot
.994 .35473 Mdot
.994 .35607 Mdot
.994 .35622 Mdot
.994 .357 Mdot
.994 .35727 Mdot
.994 .36037 Mdot
.994 .36048 Mdot
.994 .36208 Mdot
.994 .3621 Mdot
.994 .36295 Mdot
.994 .36336 Mdot
.994 .36358 Mdot
.994 .36589 Mdot
.994 .36603 Mdot
.994 .36607 Mdot
.994 .36648 Mdot
.994 .36771 Mdot
.994 .36849 Mdot
.994 .36916 Mdot
.994 .37071 Mdot
.994 .37076 Mdot
.994 .37078 Mdot
.994 .37127 Mdot
.994 .37202 Mdot
.994 .37243 Mdot
.994 .37415 Mdot
.994 .37451 Mdot
.994 .37577 Mdot
.994 .37611 Mdot
.994 .37719 Mdot
.994 .3773 Mdot
.994 .37888 Mdot
.994 .37889 Mdot
.994 .37893 Mdot
.994 .37894 Mdot
.994 .37993 Mdot
.994 .38229 Mdot
.994 .38275 Mdot
.994 .3836 Mdot
.994 .38389 Mdot
.994 .38521 Mdot
.994 .386 Mdot
.994 .38632 Mdot
.994 .38772 Mdot
.994 .38863 Mdot
.994 .39053 Mdot
.994 .39097 Mdot
.994 .39231 Mdot
.994 .39362 Mdot
.994 .39517 Mdot
.994 .3963 Mdot
.994 .39645 Mdot
.994 .39691 Mdot
.994 .39696 Mdot
.994 .39742 Mdot
.994 .39792 Mdot
.994 .39968 Mdot
.994 .4 Mdot
.994 .4002 Mdot
.994 .40058 Mdot
.994 .40144 Mdot
.994 .40153 Mdot
.994 .40182 Mdot
.994 .4019 Mdot
.994 .40193 Mdot
.994 .40337 Mdot
.994 .40346 Mdot
.994 .40504 Mdot
.994 .40638 Mdot
.994 .40683 Mdot
.994 .40771 Mdot
.994 .40803 Mdot
.994 .40882 Mdot
.994 .40951 Mdot
.994 .4099 Mdot
.994 .41023 Mdot
.994 .4103 Mdot
.994 .41169 Mdot
.994 .41191 Mdot
.994 .41339 Mdot
.994 .41366 Mdot
.994 .41384 Mdot
.994 .41492 Mdot
.994 .41496 Mdot
.994 .41519 Mdot
.994 .41704 Mdot
.994 .41726 Mdot
.994 .41766 Mdot
.994 .41912 Mdot
.994 .41919 Mdot
.994 .41947 Mdot
.994 .41955 Mdot
.994 .41976 Mdot
.994 .42038 Mdot
.994 .42111 Mdot
.994 .42396 Mdot
.994 .42434 Mdot
.994 .42478 Mdot
.994 .425 Mdot
.994 .42638 Mdot
.994 .42779 Mdot
.994 .42882 Mdot
.994 .42976 Mdot
.994 .43148 Mdot
.994 .43241 Mdot
.994 .43314 Mdot
.994 .43324 Mdot
.994 .43529 Mdot
.994 .43768 Mdot
.994 .43833 Mdot
.994 .43918 Mdot
.994 .44079 Mdot
.994 .44138 Mdot
.994 .44217 Mdot
.994 .44235 Mdot
.994 .4442 Mdot
.994 .44667 Mdot
.994 .44774 Mdot
.994 .44891 Mdot
.994 .44978 Mdot
.994 .45165 Mdot
.994 .45306 Mdot
.994 .45404 Mdot
.994 .45481 Mdot
.994 .45559 Mdot
.994 .45774 Mdot
.994 .45784 Mdot
.994 .45803 Mdot
.994 .45821 Mdot
.994 .4598 Mdot
.994 .46017 Mdot
.994 .46036 Mdot
.994 .46101 Mdot
.994 .46118 Mdot
.994 .46269 Mdot
.994 .46277 Mdot
.994 .46423 Mdot
.994 .46593 Mdot
.994 .46722 Mdot
.994 .4688 Mdot
.994 .47071 Mdot
.994 .47136 Mdot
.994 .47191 Mdot
.994 .47247 Mdot
.994 .47454 Mdot
.994 .47588 Mdot
.994 .47607 Mdot
.994 .47704 Mdot
.994 .47746 Mdot
.994 .47747 Mdot
.994 .47925 Mdot
.994 .47939 Mdot
.994 .48026 Mdot
.994 .48077 Mdot
.994 .482 Mdot
.994 .48249 Mdot
.994 .48267 Mdot
.994 .48374 Mdot
.994 .48424 Mdot
.994 .48493 Mdot
.994 .48615 Mdot
.994 .48663 Mdot
.994 .48763 Mdot
.994 .48875 Mdot
.994 .49059 Mdot
.994 .49107 Mdot
.994 .49117 Mdot
.994 .49127 Mdot
.994 .49166 Mdot
.994 .49245 Mdot
.994 .49315 Mdot
.994 .49426 Mdot
.994 .49439 Mdot
.994 .49821 Mdot
.994 .49831 Mdot
.994 .49948 Mdot
.994 .50058 Mdot
.994 .50093 Mdot
.994 .50107 Mdot
.994 .50156 Mdot
.994 .50169 Mdot
.994 .50359 Mdot
.994 .50393 Mdot
.994 .5042 Mdot
.994 .50488 Mdot
.994 .50526 Mdot
.994 .50724 Mdot
.994 .50838 Mdot
.994 .50876 Mdot
.994 .50883 Mdot
.994 .51063 Mdot
.994 .51093 Mdot
.994 .51138 Mdot
.994 .51239 Mdot
.994 .51243 Mdot
.994 .51252 Mdot
.994 .5138 Mdot
.994 .51415 Mdot
.994 .51577 Mdot
.994 .51641 Mdot
.994 .51652 Mdot
.994 .51705 Mdot
.994 .51768 Mdot
.994 .51877 Mdot
.994 .52002 Mdot
.994 .52052 Mdot
.994 .5219 Mdot
.994 .5223 Mdot
.994 .52231 Mdot
.994 .52236 Mdot
.994 .5225 Mdot
.994 .52259 Mdot
.994 .52465 Mdot
.994 .52547 Mdot
.994 .52706 Mdot
.994 .5272 Mdot
.994 .52935 Mdot
.994 .5294 Mdot
.994 .52942 Mdot
.994 .52952 Mdot
.994 .5299 Mdot
.994 .52995 Mdot
.994 .53008 Mdot
.994 .53016 Mdot
.994 .53035 Mdot
.994 .53042 Mdot
.994 .53134 Mdot
.994 .5319 Mdot
.994 .53219 Mdot
.994 .53266 Mdot
.994 .5331 Mdot
.994 .53342 Mdot
.994 .53518 Mdot
.994 .53519 Mdot
.994 .5359 Mdot
.994 .53613 Mdot
.994 .53655 Mdot
.994 .53663 Mdot
.994 .53725 Mdot
.994 .53727 Mdot
.994 .53731 Mdot
.994 .53748 Mdot
.994 .53903 Mdot
.994 .53906 Mdot
.994 .53907 Mdot
.994 .53908 Mdot
.994 .54048 Mdot
.994 .54118 Mdot
.994 .54289 Mdot
.994 .54295 Mdot
.994 .54475 Mdot
.994 .54533 Mdot
.994 .54598 Mdot
.994 .54721 Mdot
.994 .5473 Mdot
.994 .5478 Mdot
.994 .54787 Mdot
.994 .54885 Mdot
.994 .54896 Mdot
.994 .54929 Mdot
.994 .5503 Mdot
.994 .55032 Mdot
.994 .55056 Mdot
.994 .5507 Mdot
.994 .55073 Mdot
.994 .55113 Mdot
.994 .55161 Mdot
.994 .55189 Mdot
.994 .55211 Mdot
.994 .55361 Mdot
.994 .55373 Mdot
.994 .55407 Mdot
.994 .55498 Mdot
.994 .55511 Mdot
.994 .55565 Mdot
.994 .55679 Mdot
.994 .55704 Mdot
.994 .55739 Mdot
.994 .55766 Mdot
.994 .55769 Mdot
.994 .55792 Mdot
.994 .55837 Mdot
.994 .55842 Mdot
.994 .55852 Mdot
.994 .55886 Mdot
.994 .55911 Mdot
.994 .55955 Mdot
.994 .55957 Mdot
.994 .55961 Mdot
.994 .55962 Mdot
.994 .5598 Mdot
.994 .56011 Mdot
.994 .56018 Mdot
.994 .56034 Mdot
.994 .5614 Mdot
.994 .56152 Mdot
.994 .56204 Mdot
.994 .56271 Mdot
.994 .56271 Mdot
.994 .56309 Mdot
.994 .5641 Mdot
.994 .56444 Mdot
.994 .56482 Mdot
.994 .56663 Mdot
.994 .56693 Mdot
.994 .56701 Mdot
.994 .56705 Mdot
.994 .56743 Mdot
.994 .56748 Mdot
.994 .56783 Mdot
.994 .56832 Mdot
.994 .56834 Mdot
.994 .56839 Mdot
.994 .56909 Mdot
.994 .56993 Mdot
.994 .5706 Mdot
.994 .57083 Mdot
.994 .57135 Mdot
.994 .57138 Mdot
.994 .57193 Mdot
.994 .57252 Mdot
.994 .57291 Mdot
.994 .57294 Mdot
.994 .57307 Mdot
.994 .5741 Mdot
.994 .5745 Mdot
.994 .57465 Mdot
.994 .57476 Mdot
.994 .57519 Mdot
.994 .57539 Mdot
.994 .57554 Mdot
.994 .57574 Mdot
.994 .5765 Mdot
.994 .57651 Mdot
.994 .57664 Mdot
.994 .57706 Mdot
.994 .57756 Mdot
.994 .57762 Mdot
.994 .57789 Mdot
.994 .57799 Mdot
.994 .57802 Mdot
.994 .57884 Mdot
.994 .5792 Mdot
.994 .57941 Mdot
.994 .57973 Mdot
.994 .57984 Mdot
.994 .57987 Mdot
.994 .58052 Mdot
.994 .58074 Mdot
.994 .58079 Mdot
.994 .58135 Mdot
.994 .58147 Mdot
.994 .58161 Mdot
.994 .5825 Mdot
.994 .5834 Mdot
.994 .58374 Mdot
.994 .5843 Mdot
.994 .58474 Mdot
.994 .5851 Mdot
.994 .58517 Mdot
.994 .58523 Mdot
.994 .58542 Mdot
.994 .58569 Mdot
.994 .58658 Mdot
.994 .58701 Mdot
.994 .58712 Mdot
.994 .5881 Mdot
.994 .58848 Mdot
.994 .58851 Mdot
.994 .58871 Mdot
.994 .58899 Mdot
.994 .58903 Mdot
.994 .58924 Mdot
.994 .58937 Mdot
.994 .58939 Mdot
.994 .58953 Mdot
.994 .59005 Mdot
.994 .59012 Mdot
.994 .59039 Mdot
.994 .59046 Mdot
.994 .59067 Mdot
.994 .59087 Mdot
.994 .59103 Mdot
.994 .5911 Mdot
.994 .59125 Mdot
.994 .59197 Mdot
.994 .59198 Mdot
.994 .59212 Mdot
.994 .59218 Mdot
.994 .59222 Mdot
.994 .59239 Mdot
.994 .5934 Mdot
.994 .59349 Mdot
.994 .59356 Mdot
.994 .59372 Mdot
.994 .59377 Mdot
.994 .59395 Mdot
.994 .59397 Mdot
.994 .59403 Mdot
.994 .59404 Mdot
.994 .59406 Mdot
.994 .5941 Mdot
.994 .59416 Mdot
.994 .59421 Mdot
.994 .59453 Mdot
.994 .59464 Mdot
.994 .59472 Mdot
.994 .59474 Mdot
.994 .59505 Mdot
.994 .5951 Mdot
.994 .59513 Mdot
.994 .59514 Mdot
.994 .59522 Mdot
.994 .59535 Mdot
.994 .59537 Mdot
.994 .59544 Mdot
.994 .59566 Mdot
.994 .59577 Mdot
.994 .5959 Mdot
.994 .59599 Mdot
.994 .59602 Mdot
.994 .59603 Mdot
.994 .59606 Mdot
.994 .59624 Mdot
.994 .59638 Mdot
.994 .59656 Mdot
.994 .59695 Mdot
.994 .59732 Mdot
.994 .59739 Mdot
.994 .59747 Mdot
.994 .59755 Mdot
.994 .59773 Mdot
.994 .59802 Mdot
.994 .59826 Mdot
.994 .59831 Mdot
.994 .59848 Mdot
.994 .5987 Mdot
.994 .5987 Mdot
.994 .59874 Mdot
.994 .59876 Mdot
.994 .59885 Mdot
.994 .59892 Mdot
.994 .59893 Mdot
.994 .59901 Mdot
.994 .59907 Mdot
.994 .5992 Mdot
.994 .59926 Mdot
.994 .59928 Mdot
.994 .59928 Mdot
.994 .59931 Mdot
.994 .59938 Mdot
.994 .59948 Mdot
.994 .5995 Mdot
.994 .59973 Mdot
.994 .59975 Mdot
.994 .59978 Mdot
.994 .59978 Mdot
.994 .59978 Mdot
.994 .59979 Mdot
.994 .5998 Mdot
.994 .59981 Mdot
.996 .02208 Mdot
.996 .02208 Mdot
.996 .0221 Mdot
.996 .0221 Mdot
.996 .02213 Mdot
.996 .02216 Mdot
.996 .02241 Mdot
.996 .02242 Mdot
.996 .02251 Mdot
.996 .02269 Mdot
.996 .02279 Mdot
.996 .02293 Mdot
.996 .02294 Mdot
.996 .02295 Mdot
.996 .02317 Mdot
.996 .02322 Mdot
.996 .02328 Mdot
.996 .02329 Mdot
.996 .02362 Mdot
.996 .02419 Mdot
.996 .02425 Mdot
.996 .02449 Mdot
.996 .02463 Mdot
.996 .02469 Mdot
.996 .02529 Mdot
.996 .02562 Mdot
.996 .02577 Mdot
.996 .02591 Mdot
.996 .02656 Mdot
.996 .02659 Mdot
.996 .02732 Mdot
.996 .02736 Mdot
.996 .02748 Mdot
.996 .02781 Mdot
.996 .02823 Mdot
.996 .02825 Mdot
.996 .02846 Mdot
.996 .02852 Mdot
.996 .02895 Mdot
.996 .02946 Mdot
.996 .02953 Mdot
.996 .02954 Mdot
.996 .02981 Mdot
.996 .02982 Mdot
.996 .03025 Mdot
.996 .03134 Mdot
.996 .03169 Mdot
.996 .03199 Mdot
.996 .0323 Mdot
.996 .03237 Mdot
.996 .03282 Mdot
.996 .03287 Mdot
.996 .03363 Mdot
.996 .03413 Mdot
.996 .03418 Mdot
.996 .03444 Mdot
.996 .03449 Mdot
.996 .03453 Mdot
.996 .03479 Mdot
.996 .03516 Mdot
.996 .03644 Mdot
.996 .03708 Mdot
.996 .03733 Mdot
.996 .03776 Mdot
.996 .03777 Mdot
.996 .0378 Mdot
.996 .03781 Mdot
.996 .03793 Mdot
.996 .03802 Mdot
.996 .03844 Mdot
.996 .03879 Mdot
.996 .03883 Mdot
.996 .0391 Mdot
.996 .03933 Mdot
.996 .03965 Mdot
.996 .03999 Mdot
.996 .04043 Mdot
.996 .04045 Mdot
.996 .04048 Mdot
.996 .04055 Mdot
.996 .04058 Mdot
.996 .0407 Mdot
.996 .04116 Mdot
.996 .04133 Mdot
.996 .04152 Mdot
.996 .04152 Mdot
.996 .04181 Mdot
.996 .04254 Mdot
.996 .04256 Mdot
.996 .04285 Mdot
.996 .0429 Mdot
.996 .04303 Mdot
.996 .04436 Mdot
.996 .04449 Mdot
.996 .04453 Mdot
.996 .04454 Mdot
.996 .04504 Mdot
.996 .04517 Mdot
.996 .04527 Mdot
.996 .04529 Mdot
.996 .04573 Mdot
.996 .04587 Mdot
.996 .04592 Mdot
.996 .04635 Mdot
.996 .04638 Mdot
.996 .04779 Mdot
.996 .04882 Mdot
.996 .04928 Mdot
.996 .0493 Mdot
.996 .04949 Mdot
.996 .04962 Mdot
.996 .04971 Mdot
.996 .04978 Mdot
.996 .0498 Mdot
.996 .05005 Mdot
.996 .05035 Mdot
.996 .05037 Mdot
.996 .05053 Mdot
.996 .05169 Mdot
.996 .05175 Mdot
.996 .05183 Mdot
.996 .05232 Mdot
.996 .05381 Mdot
.996 .05413 Mdot
.996 .05426 Mdot
.996 .05461 Mdot
.996 .05564 Mdot
.996 .05697 Mdot
.996 .05703 Mdot
.996 .05768 Mdot
.996 .05787 Mdot
.996 .05803 Mdot
.996 .05921 Mdot
.996 .05988 Mdot
.996 .06079 Mdot
.996 .06102 Mdot
.996 .06107 Mdot
.996 .06119 Mdot
.996 .06191 Mdot
.996 .06194 Mdot
.996 .06325 Mdot
.996 .06389 Mdot
.996 .06647 Mdot
.996 .06654 Mdot
.996 .06666 Mdot
.996 .06678 Mdot
.996 .06734 Mdot
.996 .06777 Mdot
.996 .0678 Mdot
.996 .0687 Mdot
.996 .06886 Mdot
.996 .06896 Mdot
.996 .06965 Mdot
.996 .06987 Mdot
.996 .07017 Mdot
.996 .07059 Mdot
.996 .07077 Mdot
.996 .07115 Mdot
.996 .07129 Mdot
.996 .07131 Mdot
.996 .07139 Mdot
.996 .07142 Mdot
.996 .07155 Mdot
.996 .07311 Mdot
.996 .07343 Mdot
.996 .07381 Mdot
.996 .07461 Mdot
.996 .07537 Mdot
.996 .0755 Mdot
.996 .07552 Mdot
.996 .07631 Mdot
.996 .07647 Mdot
.996 .07661 Mdot
.996 .0771 Mdot
.996 .07741 Mdot
.996 .07745 Mdot
.996 .07849 Mdot
.996 .07857 Mdot
.996 .07886 Mdot
.996 .08149 Mdot
.996 .08213 Mdot
.996 .08253 Mdot
.996 .08311 Mdot
.996 .08314 Mdot
.996 .08316 Mdot
.996 .08407 Mdot
.996 .08454 Mdot
.996 .08531 Mdot
.996 .08549 Mdot
.996 .08587 Mdot
.996 .08647 Mdot
.996 .08665 Mdot
.996 .08666 Mdot
.996 .08678 Mdot
.996 .08681 Mdot
.996 .08715 Mdot
.996 .08744 Mdot
.996 .0876 Mdot
.996 .08767 Mdot
.996 .08818 Mdot
.996 .08819 Mdot
.996 .08874 Mdot
.996 .0888 Mdot
.996 .089 Mdot
.996 .08934 Mdot
.996 .08985 Mdot
.996 .08997 Mdot
.996 .09081 Mdot
.996 .09104 Mdot
.996 .09122 Mdot
.996 .09153 Mdot
.996 .09246 Mdot
.996 .0925 Mdot
.996 .09356 Mdot
.996 .09491 Mdot
.996 .09498 Mdot
.996 .09507 Mdot
.996 .0953 Mdot
.996 .09538 Mdot
.996 .09576 Mdot
.996 .0972 Mdot
.996 .09771 Mdot
.996 .09809 Mdot
.996 .0983 Mdot
.996 .09831 Mdot
.996 .09921 Mdot
.996 .09979 Mdot
.996 .10145 Mdot
.996 .10152 Mdot
.996 .10241 Mdot
.996 .10259 Mdot
.996 .10297 Mdot
.996 .1071 Mdot
.996 .1075 Mdot
.996 .10762 Mdot
.996 .10763 Mdot
.996 .10844 Mdot
.996 .10881 Mdot
.996 .10918 Mdot
.996 .10958 Mdot
.996 .10991 Mdot
.996 .10995 Mdot
.996 .11115 Mdot
.996 .11133 Mdot
.996 .11176 Mdot
.996 .11192 Mdot
.996 .11325 Mdot
.996 .11334 Mdot
.996 .11352 Mdot
.996 .11378 Mdot
.996 .11682 Mdot
.996 .11693 Mdot
.996 .11768 Mdot
.996 .11956 Mdot
.996 .11968 Mdot
.996 .12029 Mdot
.996 .12084 Mdot
.996 .12113 Mdot
.996 .12131 Mdot
.996 .12142 Mdot
.996 .12224 Mdot
.996 .12232 Mdot
.996 .12291 Mdot
.996 .12325 Mdot
.996 .12329 Mdot
.996 .12359 Mdot
.996 .12378 Mdot
.996 .12386 Mdot
.996 .12442 Mdot
.996 .12445 Mdot
.996 .12463 Mdot
.996 .12555 Mdot
.996 .12561 Mdot
.996 .12611 Mdot
.996 .12966 Mdot
.996 .12969 Mdot
.996 .12983 Mdot
.996 .1301 Mdot
.996 .131 Mdot
.996 .13159 Mdot
.996 .13175 Mdot
.996 .13212 Mdot
.996 .13299 Mdot
.996 .13616 Mdot
.996 .13702 Mdot
.996 .13715 Mdot
.996 .13755 Mdot
.996 .13862 Mdot
.996 .14031 Mdot
.996 .14057 Mdot
.996 .14176 Mdot
.996 .1423 Mdot
.996 .14288 Mdot
.996 .14582 Mdot
.996 .14599 Mdot
.996 .14622 Mdot
.996 .14712 Mdot
.996 .14798 Mdot
.996 .14834 Mdot
.996 .14842 Mdot
.996 .14855 Mdot
.996 .14904 Mdot
.996 .1493 Mdot
.996 .15265 Mdot
.996 .15275 Mdot
.996 .15369 Mdot
.996 .15441 Mdot
.996 .15467 Mdot
.996 .15539 Mdot
.996 .15606 Mdot
.996 .15743 Mdot
.996 .15813 Mdot
.996 .15827 Mdot
.996 .15866 Mdot
.996 .15901 Mdot
.996 .15968 Mdot
.996 .16082 Mdot
.996 .16092 Mdot
.996 .16265 Mdot
.996 .16301 Mdot
.996 .16426 Mdot
.996 .1644 Mdot
.996 .16449 Mdot
.996 .1649 Mdot
.996 .16631 Mdot
.996 .16638 Mdot
.996 .16682 Mdot
.996 .16975 Mdot
.996 .17273 Mdot
.996 .17462 Mdot
.996 .17481 Mdot
.996 .17518 Mdot
.996 .17542 Mdot
.996 .17554 Mdot
.996 .17699 Mdot
.996 .17722 Mdot
.996 .17757 Mdot
.996 .17851 Mdot
.996 .1786 Mdot
.996 .17892 Mdot
.996 .18132 Mdot
.996 .18178 Mdot
.996 .18208 Mdot
.996 .18286 Mdot
.996 .18416 Mdot
.996 .18481 Mdot
.996 .18536 Mdot
.996 .18571 Mdot
.996 .18641 Mdot
.996 .18675 Mdot
.996 .18696 Mdot
.996 .1875 Mdot
.996 .18767 Mdot
.996 .18863 Mdot
.996 .18907 Mdot
.996 .18912 Mdot
.996 .18935 Mdot
.996 .18946 Mdot
.996 .18976 Mdot
.996 .18984 Mdot
.996 .19162 Mdot
.996 .19298 Mdot
.996 .19448 Mdot
.996 .19546 Mdot
.996 .19656 Mdot
.996 .19713 Mdot
.996 .19879 Mdot
.996 .19894 Mdot
.996 .20056 Mdot
.996 .20094 Mdot
.996 .20121 Mdot
.996 .2016 Mdot
.996 .20164 Mdot
.996 .20329 Mdot
.996 .20369 Mdot
.996 .2039 Mdot
.996 .20401 Mdot
.996 .20433 Mdot
.996 .2044 Mdot
.996 .20448 Mdot
.996 .20458 Mdot
.996 .20484 Mdot
.996 .2049 Mdot
.996 .20634 Mdot
.996 .20724 Mdot
.996 .20735 Mdot
.996 .20971 Mdot
.996 .21012 Mdot
.996 .2103 Mdot
.996 .21044 Mdot
.996 .21068 Mdot
.996 .21128 Mdot
.996 .21152 Mdot
.996 .21358 Mdot
.996 .21607 Mdot
.996 .2182 Mdot
.996 .21902 Mdot
.996 .21926 Mdot
.996 .22113 Mdot
.996 .22174 Mdot
.996 .22229 Mdot
.996 .22253 Mdot
.996 .22387 Mdot
.996 .22393 Mdot
.996 .22399 Mdot
.996 .2241 Mdot
.996 .22415 Mdot
.996 .22492 Mdot
.996 .22682 Mdot
.996 .22716 Mdot
.996 .22817 Mdot
.996 .2284 Mdot
.996 .22876 Mdot
.996 .23043 Mdot
.996 .23093 Mdot
.996 .23135 Mdot
.996 .23206 Mdot
.996 .23378 Mdot
.996 .2343 Mdot
.996 .23433 Mdot
.996 .23468 Mdot
.996 .23478 Mdot
.996 .23577 Mdot
.996 .23659 Mdot
.996 .23706 Mdot
.996 .23726 Mdot
.996 .23753 Mdot
.996 .23875 Mdot
.996 .23878 Mdot
.996 .24036 Mdot
.996 .24053 Mdot
.996 .24111 Mdot
.996 .24209 Mdot
.996 .24357 Mdot
.996 .24391 Mdot
.996 .24632 Mdot
.996 .24699 Mdot
.996 .24749 Mdot
.996 .24835 Mdot
.996 .24838 Mdot
.996 .25105 Mdot
.996 .25117 Mdot
.996 .25419 Mdot
.996 .25741 Mdot
.996 .25806 Mdot
.996 .25827 Mdot
.996 .2585 Mdot
.996 .2585 Mdot
.996 .25917 Mdot
.996 .2594 Mdot
.996 .26048 Mdot
.996 .26116 Mdot
.996 .26224 Mdot
.996 .26283 Mdot
.996 .26365 Mdot
.996 .26404 Mdot
.996 .26455 Mdot
.996 .26549 Mdot
.996 .26556 Mdot
.996 .266 Mdot
.996 .26659 Mdot
.996 .26708 Mdot
.996 .26729 Mdot
.996 .26755 Mdot
.996 .26766 Mdot
.996 .26769 Mdot
.996 .27024 Mdot
.996 .27186 Mdot
.996 .27411 Mdot
.996 .27607 Mdot
.996 .27608 Mdot
.996 .27642 Mdot
.996 .27651 Mdot
.996 .27659 Mdot
.996 .27672 Mdot
.996 .2792 Mdot
.996 .2797 Mdot
.996 .28068 Mdot
.996 .28076 Mdot
.996 .28399 Mdot
.996 .28664 Mdot
.996 .28718 Mdot
.996 .28727 Mdot
.996 .28754 Mdot
.996 .2887 Mdot
.996 .28918 Mdot
.996 .28954 Mdot
.996 .28984 Mdot
.996 .29134 Mdot
.996 .29181 Mdot
.996 .29222 Mdot
.996 .29281 Mdot
.996 .29333 Mdot
.996 .29366 Mdot
.996 .29368 Mdot
.996 .29422 Mdot
.996 .29466 Mdot
.996 .2959 Mdot
.996 .29594 Mdot
.996 .29693 Mdot
.996 .29794 Mdot
.996 .29903 Mdot
.996 .29992 Mdot
.996 .30004 Mdot
.996 .30136 Mdot
.996 .30224 Mdot
.996 .30242 Mdot
.996 .30329 Mdot
.996 .30332 Mdot
.996 .30381 Mdot
.996 .30422 Mdot
.996 .30498 Mdot
.996 .30541 Mdot
.996 .30547 Mdot
.996 .30726 Mdot
.996 .30822 Mdot
.996 .30901 Mdot
.996 .30925 Mdot
.996 .30975 Mdot
.996 .31045 Mdot
.996 .31479 Mdot
.996 .31548 Mdot
.996 .31581 Mdot
.996 .31863 Mdot
.996 .31891 Mdot
.996 .32067 Mdot
.996 .32092 Mdot
.996 .3232 Mdot
.996 .32325 Mdot
.996 .32466 Mdot
.996 .32592 Mdot
.996 .32594 Mdot
.996 .32624 Mdot
.996 .32786 Mdot
.996 .32881 Mdot
.996 .32932 Mdot
.996 .33007 Mdot
.996 .33056 Mdot
.996 .33084 Mdot
.996 .3311 Mdot
.996 .33249 Mdot
.996 .33301 Mdot
.996 .33321 Mdot
.996 .33475 Mdot
.996 .33564 Mdot
.996 .33566 Mdot
.996 .33575 Mdot
.996 .33654 Mdot
.996 .33704 Mdot
.996 .33725 Mdot
.996 .33838 Mdot
.996 .33871 Mdot
.996 .33879 Mdot
.996 .33925 Mdot
.996 .33955 Mdot
.996 .33957 Mdot
.996 .34165 Mdot
.996 .3418 Mdot
.996 .34208 Mdot
.996 .34275 Mdot
.996 .34311 Mdot
.996 .34715 Mdot
.996 .34913 Mdot
.996 .35151 Mdot
.996 .35225 Mdot
.996 .35233 Mdot
.996 .35261 Mdot
.996 .35268 Mdot
.996 .35337 Mdot
.996 .35508 Mdot
.996 .35567 Mdot
.996 .35716 Mdot
.996 .35755 Mdot
.996 .35757 Mdot
.996 .35794 Mdot
.996 .3585 Mdot
.996 .35933 Mdot
.996 .35935 Mdot
.996 .35987 Mdot
.996 .36071 Mdot
.996 .36093 Mdot
.996 .36118 Mdot
.996 .36326 Mdot
.996 .3678 Mdot
.996 .36859 Mdot
.996 .36868 Mdot
.996 .3706 Mdot
.996 .3708 Mdot
.996 .37113 Mdot
.996 .37116 Mdot
.996 .37211 Mdot
.996 .37212 Mdot
.996 .37375 Mdot
.996 .37438 Mdot
.996 .37476 Mdot
.996 .37702 Mdot
.996 .37867 Mdot
.996 .37893 Mdot
.996 .37956 Mdot
.996 .38127 Mdot
.996 .38247 Mdot
.996 .38378 Mdot
.996 .3843 Mdot
.996 .3852 Mdot
.996 .38728 Mdot
.996 .38865 Mdot
.996 .38957 Mdot
.996 .39042 Mdot
.996 .39228 Mdot
.996 .3927 Mdot
.996 .39323 Mdot
.996 .39381 Mdot
.996 .39408 Mdot
.996 .39538 Mdot
.996 .39548 Mdot
.996 .39743 Mdot
.996 .39763 Mdot
.996 .39828 Mdot
.996 .39847 Mdot
.996 .39879 Mdot
.996 .39957 Mdot
.996 .39994 Mdot
.996 .40055 Mdot
.996 .40803 Mdot
.996 .40837 Mdot
.996 .4086 Mdot
.996 .40875 Mdot
.996 .40881 Mdot
.996 .41027 Mdot
.996 .4107 Mdot
.996 .41078 Mdot
.996 .41244 Mdot
.996 .41302 Mdot
.996 .41314 Mdot
.996 .41468 Mdot
.996 .41505 Mdot
.996 .41623 Mdot
.996 .41664 Mdot
.996 .41771 Mdot
.996 .41934 Mdot
.996 .42038 Mdot
.996 .42092 Mdot
.996 .42123 Mdot
.996 .42212 Mdot
.996 .4229 Mdot
.996 .4244 Mdot
.996 .4244 Mdot
.996 .42494 Mdot
.996 .42601 Mdot
.996 .42694 Mdot
.996 .42717 Mdot
.996 .42769 Mdot
.996 .4286 Mdot
.996 .43098 Mdot
.996 .43179 Mdot
.996 .43453 Mdot
.996 .43482 Mdot
.996 .43502 Mdot
.996 .43592 Mdot
.996 .43715 Mdot
.996 .43897 Mdot
.996 .43913 Mdot
.996 .44008 Mdot
.996 .44165 Mdot
.996 .44632 Mdot
.996 .45051 Mdot
.996 .45259 Mdot
.996 .45649 Mdot
.996 .4569 Mdot
.996 .45765 Mdot
.996 .45814 Mdot
.996 .45838 Mdot
.996 .46016 Mdot
.996 .46134 Mdot
.996 .46181 Mdot
.996 .46251 Mdot
.996 .46334 Mdot
.996 .4644 Mdot
.996 .46459 Mdot
.996 .46522 Mdot
.996 .46524 Mdot
.996 .46556 Mdot
.996 .46917 Mdot
.996 .46999 Mdot
.996 .4709 Mdot
.996 .47148 Mdot
.996 .4716 Mdot
.996 .47301 Mdot
.996 .47337 Mdot
.996 .47375 Mdot
.996 .47432 Mdot
.996 .47555 Mdot
.996 .47679 Mdot
.996 .47785 Mdot
.996 .47852 Mdot
.996 .4796 Mdot
.996 .47985 Mdot
.996 .48051 Mdot
.996 .4809 Mdot
.996 .48112 Mdot
.996 .48193 Mdot
.996 .48224 Mdot
.996 .48406 Mdot
.996 .48488 Mdot
.996 .48498 Mdot
.996 .4854 Mdot
.996 .4856 Mdot
.996 .48561 Mdot
.996 .48616 Mdot
.996 .48631 Mdot
.996 .48728 Mdot
.996 .48826 Mdot
.996 .48868 Mdot
.996 .48961 Mdot
.996 .49038 Mdot
.996 .49208 Mdot
.996 .49234 Mdot
.996 .49331 Mdot
.996 .49331 Mdot
.996 .4948 Mdot
.996 .49601 Mdot
.996 .49654 Mdot
.996 .49741 Mdot
.996 .4985 Mdot
.996 .49897 Mdot
.996 .4995 Mdot
.996 .49952 Mdot
.996 .50047 Mdot
.996 .50229 Mdot
.996 .50241 Mdot
.996 .50267 Mdot
.996 .5051 Mdot
.996 .50546 Mdot
.996 .50611 Mdot
.996 .50657 Mdot
.996 .50692 Mdot
.996 .50724 Mdot
.996 .5073 Mdot
.996 .50762 Mdot
.996 .50961 Mdot
.996 .51007 Mdot
.996 .51023 Mdot
.996 .51074 Mdot
.996 .51111 Mdot
.996 .51127 Mdot
.996 .51182 Mdot
.996 .51193 Mdot
.996 .51206 Mdot
.996 .51223 Mdot
.996 .51265 Mdot
.996 .51275 Mdot
.996 .51278 Mdot
.996 .51298 Mdot
.996 .51393 Mdot
.996 .51512 Mdot
.996 .51658 Mdot
.996 .51664 Mdot
.996 .51677 Mdot
.996 .51677 Mdot
.996 .51747 Mdot
.996 .5198 Mdot
.996 .51989 Mdot
.996 .52014 Mdot
.996 .5205 Mdot
.996 .52053 Mdot
.996 .52104 Mdot
.996 .52118 Mdot
.996 .52147 Mdot
.996 .52168 Mdot
.996 .52206 Mdot
.996 .52299 Mdot
.996 .52337 Mdot
.996 .52654 Mdot
.996 .5303 Mdot
.996 .53243 Mdot
.996 .53332 Mdot
.996 .53344 Mdot
.996 .53387 Mdot
.996 .53463 Mdot
.996 .53497 Mdot
.996 .53499 Mdot
.996 .53545 Mdot
.996 .53572 Mdot
.996 .53665 Mdot
.996 .53693 Mdot
.996 .53766 Mdot
.996 .5385 Mdot
.996 .53928 Mdot
.996 .53961 Mdot
.996 .53968 Mdot
.996 .53981 Mdot
.996 .54146 Mdot
.996 .54155 Mdot
.996 .54161 Mdot
.996 .54163 Mdot
.996 .54178 Mdot
.996 .54185 Mdot
.996 .54199 Mdot
.996 .54278 Mdot
.996 .54291 Mdot
.996 .5435 Mdot
.996 .54406 Mdot
.996 .54546 Mdot
.996 .54591 Mdot
.996 .54653 Mdot
.996 .54723 Mdot
.996 .54754 Mdot
.996 .54766 Mdot
.996 .54801 Mdot
.996 .54884 Mdot
.996 .55015 Mdot
.996 .5506 Mdot
.996 .55079 Mdot
.996 .55132 Mdot
.996 .55221 Mdot
.996 .5532 Mdot
.996 .55431 Mdot
.996 .55434 Mdot
.996 .55494 Mdot
.996 .55497 Mdot
.996 .55502 Mdot
.996 .55543 Mdot
.996 .55555 Mdot
.996 .55653 Mdot
.996 .55675 Mdot
.996 .55772 Mdot
.996 .55794 Mdot
.996 .55826 Mdot
.996 .5585 Mdot
.996 .55881 Mdot
.996 .55994 Mdot
.996 .56023 Mdot
.996 .56026 Mdot
.996 .56066 Mdot
.996 .56096 Mdot
.996 .56205 Mdot
.996 .56224 Mdot
.996 .56281 Mdot
.996 .56289 Mdot
.996 .56397 Mdot
.996 .56528 Mdot
.996 .56557 Mdot
.996 .56569 Mdot
.996 .56593 Mdot
.996 .56636 Mdot
.996 .56806 Mdot
.996 .56807 Mdot
.996 .56846 Mdot
.996 .56905 Mdot
.996 .56908 Mdot
.996 .56915 Mdot
.996 .56942 Mdot
.996 .56962 Mdot
.996 .56965 Mdot
.996 .57051 Mdot
.996 .57054 Mdot
.996 .57153 Mdot
.996 .57161 Mdot
.996 .57238 Mdot
.996 .57314 Mdot
.996 .57326 Mdot
.996 .57606 Mdot
.996 .57661 Mdot
.996 .57842 Mdot
.996 .57882 Mdot
.996 .57888 Mdot
.996 .57943 Mdot
.996 .57954 Mdot
.996 .5796 Mdot
.996 .5798 Mdot
.996 .5798 Mdot
.996 .57997 Mdot
.996 .57999 Mdot
.996 .58035 Mdot
.996 .58055 Mdot
.996 .58067 Mdot
.996 .58112 Mdot
.996 .58142 Mdot
.996 .58142 Mdot
.996 .58144 Mdot
.996 .58175 Mdot
.996 .58196 Mdot
.996 .5828 Mdot
.996 .58292 Mdot
.996 .58326 Mdot
.996 .58337 Mdot
.996 .58388 Mdot
.996 .58417 Mdot
.996 .58455 Mdot
.996 .58465 Mdot
.996 .58515 Mdot
.996 .5852 Mdot
.996 .58523 Mdot
.996 .58528 Mdot
.996 .5854 Mdot
.996 .58546 Mdot
.996 .58559 Mdot
.996 .58598 Mdot
.996 .58602 Mdot
.996 .58635 Mdot
.996 .5865 Mdot
.996 .58668 Mdot
.996 .58676 Mdot
.996 .58678 Mdot
.996 .58761 Mdot
.996 .58847 Mdot
.996 .5889 Mdot
.996 .58949 Mdot
.996 .59084 Mdot
.996 .59132 Mdot
.996 .59152 Mdot
.996 .59189 Mdot
.996 .59194 Mdot
.996 .59195 Mdot
.996 .59204 Mdot
.996 .59212 Mdot
.996 .59213 Mdot
.996 .59218 Mdot
.996 .59222 Mdot
.996 .59229 Mdot
.996 .59322 Mdot
.996 .59323 Mdot
.996 .59338 Mdot
.996 .59357 Mdot
.996 .59361 Mdot
.996 .59365 Mdot
.996 .59381 Mdot
.996 .59382 Mdot
.996 .59429 Mdot
.996 .59433 Mdot
.996 .59435 Mdot
.996 .59445 Mdot
.996 .59468 Mdot
.996 .59504 Mdot
.996 .59507 Mdot
.996 .59508 Mdot
.996 .59547 Mdot
.996 .59576 Mdot
.996 .59611 Mdot
.996 .59619 Mdot
.996 .5964 Mdot
.996 .59681 Mdot
.996 .59693 Mdot
.996 .59701 Mdot
.996 .59702 Mdot
.996 .59704 Mdot
.996 .59712 Mdot
.996 .59714 Mdot
.996 .5973 Mdot
.996 .59754 Mdot
.996 .59755 Mdot
.996 .5977 Mdot
.996 .59772 Mdot
.996 .59782 Mdot
.996 .59792 Mdot
.996 .59803 Mdot
.996 .59838 Mdot
.996 .59851 Mdot
.996 .59852 Mdot
.996 .5986 Mdot
.996 .59861 Mdot
.996 .59863 Mdot
.996 .59879 Mdot
.996 .59893 Mdot
.996 .59895 Mdot
.996 .59902 Mdot
.996 .59902 Mdot
.996 .59916 Mdot
.996 .59926 Mdot
.996 .5993 Mdot
.996 .59931 Mdot
.996 .59955 Mdot
.996 .59956 Mdot
.996 .59977 Mdot
.996 .59981 Mdot
.996 .59986 Mdot
.996 .59996 Mdot
.996 .60015 Mdot
.996 .60017 Mdot
.996 .60022 Mdot
.996 .6003 Mdot
.996 .60031 Mdot
.996 .6005 Mdot
.996 .6006 Mdot
.996 .6006 Mdot
.996 .60062 Mdot
.996 .60064 Mdot
.996 .60071 Mdot
.996 .60071 Mdot
.996 .60072 Mdot
.996 .60076 Mdot
.996 .6008 Mdot
.996 .60085 Mdot
.996 .60088 Mdot
.996 .60088 Mdot
.996 .60096 Mdot
.996 .60097 Mdot
.996 .60098 Mdot
.996 .60098 Mdot
.996 .60099 Mdot
.996 .60099 Mdot
.998 .01843 Mdot
.998 .01846 Mdot
.998 .01848 Mdot
.998 .0185 Mdot
.998 .01897 Mdot
.998 .0191 Mdot
.998 .01913 Mdot
.998 .01916 Mdot
.998 .01926 Mdot
.998 .01939 Mdot
.998 .01944 Mdot
.998 .01948 Mdot
.998 .01961 Mdot
.998 .01987 Mdot
.998 .0202 Mdot
.998 .02024 Mdot
.998 .02043 Mdot
.998 .02056 Mdot
.998 .0208 Mdot
.998 .02087 Mdot
.998 .02098 Mdot
.998 .02143 Mdot
.998 .02145 Mdot
.998 .02184 Mdot
.998 .02208 Mdot
.998 .02228 Mdot
.998 .02245 Mdot
.998 .02291 Mdot
.998 .02293 Mdot
.998 .02365 Mdot
.998 .02427 Mdot
.998 .02455 Mdot
.998 .02524 Mdot
.998 .0255 Mdot
.998 .02584 Mdot
.998 .02612 Mdot
.998 .02637 Mdot
.998 .02643 Mdot
.998 .02644 Mdot
.998 .02653 Mdot
.998 .02659 Mdot
.998 .02734 Mdot
.998 .02757 Mdot
.998 .02786 Mdot
.998 .02797 Mdot
.998 .02805 Mdot
.998 .02845 Mdot
.998 .02856 Mdot
.998 .02865 Mdot
.998 .02896 Mdot
.998 .02936 Mdot
.998 .02954 Mdot
.998 .02966 Mdot
.998 .02982 Mdot
.998 .03007 Mdot
.998 .03087 Mdot
.998 .031 Mdot
.998 .03182 Mdot
.998 .0319 Mdot
.998 .03205 Mdot
.998 .03214 Mdot
.998 .03218 Mdot
.998 .03262 Mdot
.998 .03305 Mdot
.998 .03379 Mdot
.998 .03387 Mdot
.998 .03401 Mdot
.998 .03424 Mdot
.998 .03434 Mdot
.998 .03506 Mdot
.998 .03517 Mdot
.998 .03577 Mdot
.998 .03582 Mdot
.998 .03614 Mdot
.998 .03704 Mdot
.998 .03778 Mdot
.998 .03844 Mdot
.998 .03848 Mdot
.998 .03895 Mdot
.998 .03944 Mdot
.998 .04019 Mdot
.998 .04034 Mdot
.998 .0404 Mdot
.998 .04048 Mdot
.998 .04049 Mdot
.998 .04105 Mdot
.998 .04163 Mdot
.998 .04273 Mdot
.998 .04282 Mdot
.998 .04423 Mdot
.998 .04467 Mdot
.998 .04495 Mdot
.998 .04554 Mdot
.998 .04602 Mdot
.998 .04685 Mdot
.998 .04723 Mdot
.998 .04768 Mdot
.998 .04852 Mdot
.998 .04959 Mdot
.998 .04973 Mdot
.998 .04974 Mdot
.998 .05045 Mdot
.998 .05059 Mdot
.998 .0506 Mdot
.998 .05125 Mdot
.998 .05143 Mdot
.998 .05147 Mdot
.998 .05173 Mdot
.998 .0519 Mdot
.998 .05192 Mdot
.998 .05195 Mdot
.998 .05221 Mdot
.998 .05302 Mdot
.998 .05399 Mdot
.998 .05426 Mdot
.998 .05472 Mdot
.998 .05499 Mdot
.998 .05532 Mdot
.998 .05576 Mdot
.998 .0559 Mdot
.998 .05624 Mdot
.998 .0565 Mdot
.998 .05679 Mdot
.998 .05768 Mdot
.998 .05768 Mdot
.998 .05774 Mdot
.998 .05808 Mdot
.998 .05838 Mdot
.998 .05887 Mdot
.998 .05925 Mdot
.998 .05935 Mdot
.998 .05986 Mdot
.998 .0606 Mdot
.998 .06114 Mdot
.998 .06151 Mdot
.998 .06202 Mdot
.998 .06217 Mdot
.998 .06223 Mdot
.998 .06281 Mdot
.998 .06365 Mdot
.998 .06392 Mdot
.998 .06394 Mdot
.998 .06529 Mdot
.998 .06537 Mdot
.998 .0657 Mdot
.998 .06602 Mdot
.998 .06646 Mdot
.998 .06827 Mdot
.998 .06835 Mdot
.998 .0685 Mdot
.998 .06899 Mdot
.998 .06927 Mdot
.998 .06939 Mdot
.998 .0701 Mdot
.998 .07038 Mdot
.998 .07072 Mdot
.998 .07075 Mdot
.998 .07088 Mdot
.998 .07206 Mdot
.998 .0721 Mdot
.998 .07295 Mdot
.998 .07319 Mdot
.998 .0739 Mdot
.998 .07429 Mdot
.998 .07442 Mdot
.998 .07467 Mdot
.998 .07485 Mdot
.998 .07489 Mdot
.998 .07512 Mdot
.998 .07583 Mdot
.998 .07613 Mdot
.998 .07758 Mdot
.998 .07837 Mdot
.998 .07873 Mdot
.998 .07945 Mdot
.998 .0798 Mdot
.998 .07986 Mdot
.998 .08011 Mdot
.998 .08058 Mdot
.998 .08075 Mdot
.998 .08168 Mdot
.998 .08173 Mdot
.998 .08204 Mdot
.998 .08234 Mdot
.998 .08405 Mdot
.998 .08429 Mdot
.998 .08455 Mdot
.998 .08555 Mdot
.998 .0863 Mdot
.998 .08686 Mdot
.998 .08729 Mdot
.998 .08738 Mdot
.998 .08748 Mdot
.998 .08886 Mdot
.998 .08889 Mdot
.998 .08898 Mdot
.998 .08903 Mdot
.998 .09049 Mdot
.998 .09197 Mdot
.998 .09202 Mdot
.998 .09436 Mdot
.998 .09454 Mdot
.998 .09455 Mdot
.998 .0948 Mdot
.998 .095 Mdot
.998 .09523 Mdot
.998 .09527 Mdot
.998 .0959 Mdot
.998 .09657 Mdot
.998 .097 Mdot
.998 .09883 Mdot
.998 .09988 Mdot
.998 .10003 Mdot
.998 .10109 Mdot
.998 .10149 Mdot
.998 .10223 Mdot
.998 .10237 Mdot
.998 .1025 Mdot
.998 .10622 Mdot
.998 .10665 Mdot
.998 .10689 Mdot
.998 .10786 Mdot
.998 .10823 Mdot
.998 .10824 Mdot
.998 .10849 Mdot
.998 .1091 Mdot
.998 .10971 Mdot
.998 .1103 Mdot
.998 .11073 Mdot
.998 .11094 Mdot
.998 .11241 Mdot
.998 .11498 Mdot
.998 .11614 Mdot
.998 .11663 Mdot
.998 .11728 Mdot
.998 .11755 Mdot
.998 .11873 Mdot
.998 .11904 Mdot
.998 .11942 Mdot
.998 .12012 Mdot
.998 .12149 Mdot
.998 .12278 Mdot
.998 .12341 Mdot
.998 .12386 Mdot
.998 .12389 Mdot
.998 .12525 Mdot
.998 .12552 Mdot
.998 .12607 Mdot
.998 .12607 Mdot
.998 .12652 Mdot
.998 .12653 Mdot
.998 .12797 Mdot
.998 .12853 Mdot
.998 .12909 Mdot
.998 .12921 Mdot
.998 .12996 Mdot
.998 .13002 Mdot
.998 .13004 Mdot
.998 .13054 Mdot
.998 .13061 Mdot
.998 .1307 Mdot
.998 .13071 Mdot
.998 .13149 Mdot
.998 .13398 Mdot
.998 .13537 Mdot
.998 .13585 Mdot
.998 .13667 Mdot
.998 .13694 Mdot
.998 .13698 Mdot
.998 .13703 Mdot
.998 .13779 Mdot
.998 .13786 Mdot
.998 .13919 Mdot
.998 .14001 Mdot
.998 .14053 Mdot
.998 .14102 Mdot
.998 .14236 Mdot
.998 .14281 Mdot
.998 .14385 Mdot
.998 .144 Mdot
.998 .14465 Mdot
.998 .14552 Mdot
.998 .14824 Mdot
.998 .14825 Mdot
.998 .14843 Mdot
.998 .1485 Mdot
.998 .14945 Mdot
.998 .15037 Mdot
.998 .15101 Mdot
.998 .1518 Mdot
.998 .15188 Mdot
.998 .15204 Mdot
.998 .15235 Mdot
.998 .1525 Mdot
.998 .15271 Mdot
.998 .15277 Mdot
.998 .15298 Mdot
.998 .15302 Mdot
.998 .15333 Mdot
.998 .15397 Mdot
.998 .1549 Mdot
.998 .15713 Mdot
.998 .15745 Mdot
.998 .15878 Mdot
.998 .15992 Mdot
.998 .16118 Mdot
.998 .16146 Mdot
.998 .1619 Mdot
.998 .1621 Mdot
.998 .16349 Mdot
.998 .16386 Mdot
.998 .16387 Mdot
.998 .16484 Mdot
.998 .16549 Mdot
.998 .16608 Mdot
.998 .16639 Mdot
.998 .16721 Mdot
.998 .16727 Mdot
.998 .16815 Mdot
.998 .16866 Mdot
.998 .16891 Mdot
.998 .17138 Mdot
.998 .17161 Mdot
.998 .17176 Mdot
.998 .17198 Mdot
.998 .17262 Mdot
.998 .17358 Mdot
.998 .17416 Mdot
.998 .1749 Mdot
.998 .17772 Mdot
.998 .17801 Mdot
.998 .17854 Mdot
.998 .17913 Mdot
.998 .18001 Mdot
.998 .18034 Mdot
.998 .18059 Mdot
.998 .18105 Mdot
.998 .18241 Mdot
.998 .1825 Mdot
.998 .18297 Mdot
.998 .18336 Mdot
.998 .18373 Mdot
.998 .18584 Mdot
.998 .18598 Mdot
.998 .18615 Mdot
.998 .18668 Mdot
.998 .18771 Mdot
.998 .18778 Mdot
.998 .18781 Mdot
.998 .18819 Mdot
.998 .18872 Mdot
.998 .18944 Mdot
.998 .19173 Mdot
.998 .19184 Mdot
.998 .19439 Mdot
.998 .19452 Mdot
.998 .19508 Mdot
.998 .19722 Mdot
.998 .19744 Mdot
.998 .19837 Mdot
.998 .19874 Mdot
.998 .19951 Mdot
.998 .20003 Mdot
.998 .20014 Mdot
.998 .20083 Mdot
.998 .20185 Mdot
.998 .20294 Mdot
.998 .20384 Mdot
.998 .20466 Mdot
.998 .20518 Mdot
.998 .20787 Mdot
.998 .20813 Mdot
.998 .20836 Mdot
.998 .20904 Mdot
.998 .21046 Mdot
.998 .21154 Mdot
.998 .21197 Mdot
.998 .21263 Mdot
.998 .2128 Mdot
.998 .21367 Mdot
.998 .2147 Mdot
.998 .21488 Mdot
.998 .21562 Mdot
.998 .21567 Mdot
.998 .21651 Mdot
.998 .21701 Mdot
.998 .21722 Mdot
.998 .2175 Mdot
.998 .22022 Mdot
.998 .22039 Mdot
.998 .22127 Mdot
.998 .22131 Mdot
.998 .22147 Mdot
.998 .22218 Mdot
.998 .22324 Mdot
.998 .22392 Mdot
.998 .22501 Mdot
.998 .22718 Mdot
.998 .22787 Mdot
.998 .22864 Mdot
.998 .22878 Mdot
.998 .22991 Mdot
.998 .22999 Mdot
.998 .23091 Mdot
.998 .23154 Mdot
.998 .23304 Mdot
.998 .23363 Mdot
.998 .23374 Mdot
.998 .23537 Mdot
.998 .23661 Mdot
.998 .23668 Mdot
.998 .23674 Mdot
.998 .23678 Mdot
.998 .23687 Mdot
.998 .23693 Mdot
.998 .23716 Mdot
.998 .24014 Mdot
.998 .24091 Mdot
.998 .24117 Mdot
.998 .24126 Mdot
.998 .2415 Mdot
.998 .24165 Mdot
.998 .24304 Mdot
.998 .24546 Mdot
.998 .24586 Mdot
.998 .24931 Mdot
.998 .24965 Mdot
.998 .25005 Mdot
.998 .25014 Mdot
.998 .25026 Mdot
.998 .25299 Mdot
.998 .25488 Mdot
.998 .25488 Mdot
.998 .25696 Mdot
.998 .25748 Mdot
.998 .25752 Mdot
.998 .25793 Mdot
.998 .25822 Mdot
.998 .2587 Mdot
.998 .25879 Mdot
.998 .25946 Mdot
.998 .25958 Mdot
.998 .25972 Mdot
.998 .26044 Mdot
.998 .26136 Mdot
.998 .26318 Mdot
.998 .26328 Mdot
.998 .26365 Mdot
.998 .2645 Mdot
.998 .26526 Mdot
.998 .2661 Mdot
.998 .26725 Mdot
.998 .26726 Mdot
.998 .26739 Mdot
.998 .26808 Mdot
.998 .26918 Mdot
.998 .26966 Mdot
.998 .27025 Mdot
.998 .27025 Mdot
.998 .27069 Mdot
.998 .27144 Mdot
.998 .27263 Mdot
.998 .27306 Mdot
.998 .27394 Mdot
.998 .27605 Mdot
.998 .27717 Mdot
.998 .27761 Mdot
.998 .27848 Mdot
.998 .27923 Mdot
.998 .27961 Mdot
.998 .27998 Mdot
.998 .28068 Mdot
.998 .28372 Mdot
.998 .28473 Mdot
.998 .2861 Mdot
.998 .28816 Mdot
.998 .28992 Mdot
.998 .29033 Mdot
.998 .29057 Mdot
.998 .29153 Mdot
.998 .29218 Mdot
.998 .29407 Mdot
.998 .29488 Mdot
.998 .29589 Mdot
.998 .29592 Mdot
.998 .29662 Mdot
.998 .29829 Mdot
.998 .29913 Mdot
.998 .29996 Mdot
.998 .30156 Mdot
.998 .30274 Mdot
.998 .30291 Mdot
.998 .30332 Mdot
.998 .3039 Mdot
.998 .30711 Mdot
.998 .30731 Mdot
.998 .30764 Mdot
.998 .31006 Mdot
.998 .31367 Mdot
.998 .31428 Mdot
.998 .31439 Mdot
.998 .31543 Mdot
.998 .31581 Mdot
.998 .31729 Mdot
.998 .3174 Mdot
.998 .3178 Mdot
.998 .31858 Mdot
.998 .31872 Mdot
.998 .3198 Mdot
.998 .32047 Mdot
.998 .32086 Mdot
.998 .32119 Mdot
.998 .32434 Mdot
.998 .32517 Mdot
.998 .32548 Mdot
.998 .32618 Mdot
.998 .32802 Mdot
.998 .33095 Mdot
.998 .33166 Mdot
.998 .33193 Mdot
.998 .33362 Mdot
.998 .33424 Mdot
.998 .33505 Mdot
.998 .33672 Mdot
.998 .33788 Mdot
.998 .33798 Mdot
.998 .34152 Mdot
.998 .34223 Mdot
.998 .34364 Mdot
.998 .34365 Mdot
.998 .34412 Mdot
.998 .34483 Mdot
.998 .34486 Mdot
.998 .34593 Mdot
.998 .34631 Mdot
.998 .34684 Mdot
.998 .34858 Mdot
.998 .35001 Mdot
.998 .35146 Mdot
.998 .35176 Mdot
.998 .35368 Mdot
.998 .35383 Mdot
.998 .3539 Mdot
.998 .35518 Mdot
.998 .35534 Mdot
.998 .35558 Mdot
.998 .35559 Mdot
.998 .35746 Mdot
.998 .3576 Mdot
.998 .35772 Mdot
.998 .3605 Mdot
.998 .36114 Mdot
.998 .36225 Mdot
.998 .36366 Mdot
.998 .3639 Mdot
.998 .36512 Mdot
.998 .36549 Mdot
.998 .36563 Mdot
.998 .36593 Mdot
.998 .36724 Mdot
.998 .36739 Mdot
.998 .3686 Mdot
.998 .37066 Mdot
.998 .37087 Mdot
.998 .37133 Mdot
.998 .37143 Mdot
.998 .37155 Mdot
.998 .37336 Mdot
.998 .37345 Mdot
.998 .37361 Mdot
.998 .37419 Mdot
.998 .3748 Mdot
.998 .37482 Mdot
.998 .3769 Mdot
.998 .37892 Mdot
.998 .3802 Mdot
.998 .38139 Mdot
.998 .38172 Mdot
.998 .3837 Mdot
.998 .38468 Mdot
.998 .38486 Mdot
.998 .38557 Mdot
.998 .3857 Mdot
.998 .38577 Mdot
.998 .38658 Mdot
.998 .38828 Mdot
.998 .38844 Mdot
.998 .38866 Mdot
.998 .39023 Mdot
.998 .39064 Mdot
.998 .39106 Mdot
.998 .39233 Mdot
.998 .39495 Mdot
.998 .3956 Mdot
.998 .39572 Mdot
.998 .39747 Mdot
.998 .39881 Mdot
.998 .39884 Mdot
.998 .39926 Mdot
.998 .39942 Mdot
.998 .39967 Mdot
.998 .40082 Mdot
.998 .40168 Mdot
.998 .4024 Mdot
.998 .40241 Mdot
.998 .40384 Mdot
.998 .40534 Mdot
.998 .40651 Mdot
.998 .4072 Mdot
.998 .40737 Mdot
.998 .40776 Mdot
.998 .40837 Mdot
.998 .40847 Mdot
.998 .40883 Mdot
.998 .40927 Mdot
.998 .40927 Mdot
.998 .4093 Mdot
.998 .40945 Mdot
.998 .40993 Mdot
.998 .41003 Mdot
.998 .41074 Mdot
.998 .41154 Mdot
.998 .41174 Mdot
.998 .41221 Mdot
.998 .4131 Mdot
.998 .41384 Mdot
.998 .41436 Mdot
.998 .41702 Mdot
.998 .41947 Mdot
.998 .41977 Mdot
.998 .42019 Mdot
.998 .42036 Mdot
.998 .42182 Mdot
.998 .42318 Mdot
.998 .42576 Mdot
.998 .42614 Mdot
.998 .42856 Mdot
.998 .4292 Mdot
.998 .42957 Mdot
.998 .43017 Mdot
.998 .43062 Mdot
.998 .43221 Mdot
.998 .43367 Mdot
.998 .43409 Mdot
.998 .43448 Mdot
.998 .43451 Mdot
.998 .43647 Mdot
.998 .43661 Mdot
.998 .43663 Mdot
.998 .43805 Mdot
.998 .43933 Mdot
.998 .43952 Mdot
.998 .44001 Mdot
.998 .4405 Mdot
.998 .44118 Mdot
.998 .44178 Mdot
.998 .4419 Mdot
.998 .44222 Mdot
.998 .44379 Mdot
.998 .44489 Mdot
.998 .44541 Mdot
.998 .45064 Mdot
.998 .45112 Mdot
.998 .45144 Mdot
.998 .45189 Mdot
.998 .45323 Mdot
.998 .45329 Mdot
.998 .45438 Mdot
.998 .45523 Mdot
.998 .45643 Mdot
.998 .45667 Mdot
.998 .45797 Mdot
.998 .45989 Mdot
.998 .46053 Mdot
.998 .46079 Mdot
.998 .462 Mdot
.998 .46339 Mdot
.998 .46371 Mdot
.998 .4643 Mdot
.998 .46438 Mdot
.998 .46536 Mdot
.998 .46536 Mdot
.998 .46575 Mdot
.998 .46655 Mdot
.998 .4683 Mdot
.998 .4683 Mdot
.998 .46897 Mdot
.998 .46945 Mdot
.998 .47038 Mdot
.998 .47112 Mdot
.998 .47117 Mdot
.998 .47144 Mdot
.998 .47306 Mdot
.998 .47323 Mdot
.998 .47415 Mdot
.998 .47492 Mdot
.998 .47528 Mdot
.998 .47533 Mdot
.998 .47562 Mdot
.998 .4761 Mdot
.998 .47691 Mdot
.998 .47971 Mdot
.998 .47972 Mdot
.998 .47996 Mdot
.998 .4803 Mdot
.998 .4813 Mdot
.998 .48275 Mdot
.998 .48327 Mdot
.998 .48339 Mdot
.998 .48345 Mdot
.998 .48359 Mdot
.998 .48417 Mdot
.998 .48473 Mdot
.998 .48517 Mdot
.998 .48542 Mdot
.998 .48652 Mdot
.998 .48662 Mdot
.998 .49076 Mdot
.998 .49096 Mdot
.998 .49111 Mdot
.998 .49181 Mdot
.998 .49559 Mdot
.998 .49582 Mdot
.998 .49647 Mdot
.998 .49684 Mdot
.998 .4989 Mdot
.998 .50063 Mdot
.998 .50103 Mdot
.998 .50148 Mdot
.998 .50177 Mdot
.998 .50251 Mdot
.998 .50265 Mdot
.998 .50304 Mdot
.998 .50331 Mdot
.998 .50464 Mdot
.998 .50553 Mdot
.998 .50573 Mdot
.998 .50691 Mdot
.998 .50727 Mdot
.998 .50865 Mdot
.998 .51049 Mdot
.998 .51176 Mdot
.998 .51199 Mdot
.998 .51263 Mdot
.998 .51337 Mdot
.998 .51386 Mdot
.998 .51422 Mdot
.998 .51531 Mdot
.998 .5161 Mdot
.998 .51641 Mdot
.998 .51772 Mdot
.998 .5186 Mdot
.998 .51887 Mdot
.998 .51902 Mdot
.998 .51902 Mdot
.998 .5194 Mdot
.998 .51979 Mdot
.998 .52004 Mdot
.998 .52008 Mdot
.998 .52008 Mdot
.998 .52049 Mdot
.998 .52079 Mdot
.998 .52135 Mdot
.998 .52152 Mdot
.998 .52248 Mdot
.998 .52274 Mdot
.998 .52309 Mdot
.998 .52336 Mdot
.998 .52443 Mdot
.998 .52443 Mdot
.998 .52509 Mdot
.998 .52611 Mdot
.998 .52625 Mdot
.998 .52637 Mdot
.998 .52771 Mdot
.998 .52855 Mdot
.998 .52928 Mdot
.998 .52955 Mdot
.998 .53066 Mdot
.998 .53071 Mdot
.998 .53072 Mdot
.998 .53074 Mdot
.998 .53179 Mdot
.998 .532 Mdot
.998 .53273 Mdot
.998 .53304 Mdot
.998 .53307 Mdot
.998 .53346 Mdot
.998 .53475 Mdot
.998 .53512 Mdot
.998 .53535 Mdot
.998 .53595 Mdot
.998 .53601 Mdot
.998 .5374 Mdot
.998 .53764 Mdot
.998 .53793 Mdot
.998 .5389 Mdot
.998 .53896 Mdot
.998 .53918 Mdot
.998 .54017 Mdot
.998 .5404 Mdot
.998 .54057 Mdot
.998 .54148 Mdot
.998 .54165 Mdot
.998 .5426 Mdot
.998 .54408 Mdot
.998 .54506 Mdot
.998 .54676 Mdot
.998 .547 Mdot
.998 .54731 Mdot
.998 .54786 Mdot
.998 .54791 Mdot
.998 .54892 Mdot
.998 .5491 Mdot
.998 .5499 Mdot
.998 .55019 Mdot
.998 .55039 Mdot
.998 .55057 Mdot
.998 .55066 Mdot
.998 .55184 Mdot
.998 .55257 Mdot
.998 .55264 Mdot
.998 .55358 Mdot
.998 .55366 Mdot
.998 .55383 Mdot
.998 .55451 Mdot
.998 .55471 Mdot
.998 .55492 Mdot
.998 .55524 Mdot
.998 .55537 Mdot
.998 .55613 Mdot
.998 .55736 Mdot
.998 .5585 Mdot
.998 .55883 Mdot
.998 .55889 Mdot
.998 .55892 Mdot
.998 .55898 Mdot
.998 .55903 Mdot
.998 .55913 Mdot
.998 .55921 Mdot
.998 .55947 Mdot
.998 .5603 Mdot
.998 .56177 Mdot
.998 .5629 Mdot
.998 .56377 Mdot
.998 .56404 Mdot
.998 .56406 Mdot
.998 .56416 Mdot
.998 .56443 Mdot
.998 .56459 Mdot
.998 .5661 Mdot
.998 .56632 Mdot
.998 .56635 Mdot
.998 .56699 Mdot
.998 .56761 Mdot
.998 .56779 Mdot
.998 .56788 Mdot
.998 .56868 Mdot
.998 .5691 Mdot
.998 .56977 Mdot
.998 .56989 Mdot
.998 .56999 Mdot
.998 .57046 Mdot
.998 .57067 Mdot
.998 .57258 Mdot
.998 .57272 Mdot
.998 .57291 Mdot
.998 .5733 Mdot
.998 .57339 Mdot
.998 .57351 Mdot
.998 .5739 Mdot
.998 .57404 Mdot
.998 .57528 Mdot
.998 .57556 Mdot
.998 .57569 Mdot
.998 .57603 Mdot
.998 .57608 Mdot
.998 .57715 Mdot
.998 .57737 Mdot
.998 .5778 Mdot
.998 .5778 Mdot
.998 .57863 Mdot
.998 .57959 Mdot
.998 .57963 Mdot
.998 .58008 Mdot
.998 .58011 Mdot
.998 .58014 Mdot
.998 .58045 Mdot
.998 .5807 Mdot
.998 .5811 Mdot
.998 .58118 Mdot
.998 .58173 Mdot
.998 .58182 Mdot
.998 .58194 Mdot
.998 .58244 Mdot
.998 .58252 Mdot
.998 .58254 Mdot
.998 .58265 Mdot
.998 .58325 Mdot
.998 .58412 Mdot
.998 .58413 Mdot
.998 .58431 Mdot
.998 .58443 Mdot
.998 .58466 Mdot
.998 .58474 Mdot
.998 .58502 Mdot
.998 .5854 Mdot
.998 .58545 Mdot
.998 .58556 Mdot
.998 .58565 Mdot
.998 .58621 Mdot
.998 .58682 Mdot
.998 .58696 Mdot
.998 .58717 Mdot
.998 .58763 Mdot
.998 .58763 Mdot
.998 .58772 Mdot
.998 .58817 Mdot
.998 .58819 Mdot
.998 .58893 Mdot
.998 .58913 Mdot
.998 .58925 Mdot
.998 .58963 Mdot
.998 .58963 Mdot
.998 .58991 Mdot
.998 .59024 Mdot
.998 .59038 Mdot
.998 .59057 Mdot
.998 .59081 Mdot
.998 .59112 Mdot
.998 .59138 Mdot
.998 .59146 Mdot
.998 .59147 Mdot
.998 .59189 Mdot
.998 .59189 Mdot
.998 .59216 Mdot
.998 .59217 Mdot
.998 .59297 Mdot
.998 .59309 Mdot
.998 .59335 Mdot
.998 .59369 Mdot
.998 .59392 Mdot
.998 .59438 Mdot
.998 .59475 Mdot
.998 .59494 Mdot
.998 .59512 Mdot
.998 .59517 Mdot
.998 .59521 Mdot
.998 .59545 Mdot
.998 .59576 Mdot
.998 .59651 Mdot
.998 .59682 Mdot
.998 .59685 Mdot
.998 .59711 Mdot
.998 .59723 Mdot
.998 .59777 Mdot
.998 .59778 Mdot
.998 .59789 Mdot
.998 .59815 Mdot
.998 .59852 Mdot
.998 .59911 Mdot
.998 .59915 Mdot
.998 .59924 Mdot
.998 .59932 Mdot
.998 .59961 Mdot
.998 .59971 Mdot
.998 .59979 Mdot
.998 .5999 Mdot
.998 .59999 Mdot
.998 .6002 Mdot
.998 .60029 Mdot
.998 .60049 Mdot
.998 .60072 Mdot
.998 .60073 Mdot
.998 .60088 Mdot
.998 .60093 Mdot
.998 .601 Mdot
.998 .60107 Mdot
.998 .6012 Mdot
.998 .6012 Mdot
.998 .60135 Mdot
.998 .60138 Mdot
.998 .6014 Mdot
.998 .60148 Mdot
.998 .60152 Mdot
.998 .60158 Mdot
.998 .60159 Mdot
.998 .6017 Mdot
.998 .60178 Mdot
.998 .60182 Mdot
.998 .60183 Mdot
.998 .60185 Mdot
.998 .60189 Mdot
.998 .60192 Mdot
.998 .60193 Mdot
.998 .60195 Mdot
.998 .60199 Mdot
.998 .60213 Mdot
.998 .60214 Mdot
.998 .60215 Mdot
.998 .60216 Mdot
1 .01479 Mdot
1 .01479 Mdot
1 .01479 Mdot
1 .01479 Mdot
1 .01482 Mdot
1 .01484 Mdot
1 .01495 Mdot
1 .01495 Mdot
1 .01496 Mdot
1 .01496 Mdot
1 .015 Mdot
1 .01505 Mdot
1 .01511 Mdot
1 .01545 Mdot
1 .01546 Mdot
1 .01547 Mdot
1 .01549 Mdot
1 .01557 Mdot
1 .0156 Mdot
1 .01565 Mdot
1 .01577 Mdot
1 .0158 Mdot
1 .01588 Mdot
1 .01597 Mdot
1 .01599 Mdot
1 .01618 Mdot
1 .01622 Mdot
1 .01629 Mdot
1 .01631 Mdot
1 .01669 Mdot
1 .01676 Mdot
1 .01682 Mdot
1 .01704 Mdot
1 .01705 Mdot
1 .0171 Mdot
1 .01715 Mdot
1 .0174 Mdot
1 .0175 Mdot
1 .01765 Mdot
1 .01774 Mdot
1 .01803 Mdot
1 .01803 Mdot
1 .0181 Mdot
1 .01812 Mdot
1 .01838 Mdot
1 .01851 Mdot
1 .01866 Mdot
1 .01874 Mdot
1 .01894 Mdot
1 .01902 Mdot
1 .01931 Mdot
1 .01933 Mdot
1 .01933 Mdot
1 .01944 Mdot
1 .01965 Mdot
1 .01965 Mdot
1 .01971 Mdot
1 .02093 Mdot
1 .02095 Mdot
1 .02105 Mdot
1 .02113 Mdot
1 .02118 Mdot
1 .02133 Mdot
1 .02157 Mdot
1 .02177 Mdot
1 .02187 Mdot
1 .02202 Mdot
1 .02206 Mdot
1 .02212 Mdot
1 .02219 Mdot
1 .02221 Mdot
1 .02225 Mdot
1 .02236 Mdot
1 .02275 Mdot
1 .02315 Mdot
1 .02337 Mdot
1 .02348 Mdot
1 .02356 Mdot
1 .02394 Mdot
1 .02421 Mdot
1 .02421 Mdot
1 .02493 Mdot
1 .02511 Mdot
1 .02514 Mdot
1 .02535 Mdot
1 .0254 Mdot
1 .02583 Mdot
1 .02622 Mdot
1 .02657 Mdot
1 .02661 Mdot
1 .02664 Mdot
1 .0271 Mdot
1 .02722 Mdot
1 .02735 Mdot
1 .02771 Mdot
1 .02772 Mdot
1 .02797 Mdot
1 .02814 Mdot
1 .02823 Mdot
1 .02879 Mdot
1 .02916 Mdot
1 .02922 Mdot
1 .02922 Mdot
1 .02925 Mdot
1 .02956 Mdot
1 .02978 Mdot
1 .03013 Mdot
1 .03023 Mdot
1 .03023 Mdot
1 .0304 Mdot
1 .03092 Mdot
1 .03299 Mdot
1 .03342 Mdot
1 .03422 Mdot
1 .0343 Mdot
1 .03462 Mdot
1 .03486 Mdot
1 .03502 Mdot
1 .0353 Mdot
1 .03536 Mdot
1 .03548 Mdot
1 .03625 Mdot
1 .03673 Mdot
1 .03686 Mdot
1 .03718 Mdot
1 .03718 Mdot
1 .03737 Mdot
1 .03765 Mdot
1 .0378 Mdot
1 .03798 Mdot
1 .0382 Mdot
1 .03826 Mdot
1 .03827 Mdot
1 .03838 Mdot
1 .03873 Mdot
1 .03916 Mdot
1 .03979 Mdot
1 .03995 Mdot
1 .03995 Mdot
1 .04091 Mdot
1 .0412 Mdot
1 .04124 Mdot
1 .04189 Mdot
1 .04224 Mdot
1 .04239 Mdot
1 .04249 Mdot
1 .0426 Mdot
1 .04349 Mdot
1 .04368 Mdot
1 .04412 Mdot
1 .04415 Mdot
1 .04453 Mdot
1 .04453 Mdot
1 .04458 Mdot
1 .0453 Mdot
1 .04633 Mdot
1 .0468 Mdot
1 .04685 Mdot
1 .04692 Mdot
1 .04737 Mdot
1 .04744 Mdot
1 .04795 Mdot
1 .04811 Mdot
1 .04827 Mdot
1 .04864 Mdot
1 .04897 Mdot
1 .04927 Mdot
1 .04963 Mdot
1 .05015 Mdot
1 .0505 Mdot
1 .05083 Mdot
1 .05194 Mdot
1 .05206 Mdot
1 .05217 Mdot
1 .05243 Mdot
1 .05318 Mdot
1 .05359 Mdot
1 .05397 Mdot
1 .05436 Mdot
1 .05447 Mdot
1 .05472 Mdot
1 .0555 Mdot
1 .05554 Mdot
1 .05633 Mdot
1 .05684 Mdot
1 .05714 Mdot
1 .05889 Mdot
1 .05947 Mdot
1 .06006 Mdot
1 .06011 Mdot
1 .06023 Mdot
1 .06023 Mdot
1 .06034 Mdot
1 .0607 Mdot
1 .06093 Mdot
1 .06131 Mdot
1 .06145 Mdot
1 .062 Mdot
1 .06203 Mdot
1 .0631 Mdot
1 .06328 Mdot
1 .0634 Mdot
1 .0634 Mdot
1 .06395 Mdot
1 .06461 Mdot
1 .06556 Mdot
1 .06715 Mdot
1 .06841 Mdot
1 .0696 Mdot
1 .06963 Mdot
1 .07173 Mdot
1 .07204 Mdot
1 .07294 Mdot
1 .07337 Mdot
1 .07339 Mdot
1 .07432 Mdot
1 .07527 Mdot
1 .07588 Mdot
1 .07614 Mdot
1 .07655 Mdot
1 .07675 Mdot
1 .07712 Mdot
1 .07789 Mdot
1 .07838 Mdot
1 .07876 Mdot
1 .07925 Mdot
1 .07945 Mdot
1 .07983 Mdot
1 .08215 Mdot
1 .08223 Mdot
1 .08291 Mdot
1 .08293 Mdot
1 .08372 Mdot
1 .08372 Mdot
1 .08412 Mdot
1 .08415 Mdot
1 .08512 Mdot
1 .08513 Mdot
1 .08554 Mdot
1 .08573 Mdot
1 .08659 Mdot
1 .08699 Mdot
1 .08704 Mdot
1 .08707 Mdot
1 .08761 Mdot
1 .08831 Mdot
1 .08847 Mdot
1 .08854 Mdot
1 .08886 Mdot
1 .08887 Mdot
1 .08897 Mdot
1 .0891 Mdot
1 .08957 Mdot
1 .08974 Mdot
1 .08979 Mdot
1 .08994 Mdot
1 .09001 Mdot
1 .09057 Mdot
1 .09129 Mdot
1 .09289 Mdot
1 .09305 Mdot
1 .09309 Mdot
1 .09325 Mdot
1 .09374 Mdot
1 .09375 Mdot
1 .09398 Mdot
1 .09418 Mdot
1 .09452 Mdot
1 .09583 Mdot
1 .09675 Mdot
1 .09734 Mdot
1 .09763 Mdot
1 .09775 Mdot
1 .09979 Mdot
1 .09998 Mdot
1 .10019 Mdot
1 .1005 Mdot
1 .10087 Mdot
1 .10134 Mdot
1 .10165 Mdot
1 .10199 Mdot
1 .10269 Mdot
1 .10442 Mdot
1 .10475 Mdot
1 .10475 Mdot
1 .10535 Mdot
1 .10671 Mdot
1 .10682 Mdot
1 .10686 Mdot
1 .10694 Mdot
1 .10799 Mdot
1 .108 Mdot
1 .10815 Mdot
1 .10955 Mdot
1 .11005 Mdot
1 .11038 Mdot
1 .11162 Mdot
1 .11356 Mdot
1 .11502 Mdot
1 .11519 Mdot
1 .11539 Mdot
1 .11602 Mdot
1 .11678 Mdot
1 .11702 Mdot
1 .11751 Mdot
1 .11857 Mdot
1 .11908 Mdot
1 .11931 Mdot
1 .11956 Mdot
1 .11963 Mdot
1 .12072 Mdot
1 .12123 Mdot
1 .12174 Mdot
1 .12185 Mdot
1 .12266 Mdot
1 .1233 Mdot
1 .12376 Mdot
1 .12381 Mdot
1 .12499 Mdot
1 .12503 Mdot
1 .12537 Mdot
1 .12538 Mdot
1 .12646 Mdot
1 .12748 Mdot
1 .1293 Mdot
1 .12994 Mdot
1 .1309 Mdot
1 .13105 Mdot
1 .13125 Mdot
1 .13128 Mdot
1 .13159 Mdot
1 .1321 Mdot
1 .13222 Mdot
1 .13234 Mdot
1 .1324 Mdot
1 .13312 Mdot
1 .13368 Mdot
1 .13381 Mdot
1 .1347 Mdot
1 .13555 Mdot
1 .13596 Mdot
1 .13616 Mdot
1 .13713 Mdot
1 .13717 Mdot
1 .13783 Mdot
1 .13835 Mdot
1 .13856 Mdot
1 .13868 Mdot
1 .13881 Mdot
1 .13889 Mdot
1 .13928 Mdot
1 .13944 Mdot
1 .14019 Mdot
1 .14183 Mdot
1 .14195 Mdot
1 .14438 Mdot
1 .145 Mdot
1 .14507 Mdot
1 .14595 Mdot
1 .14688 Mdot
1 .15057 Mdot
1 .1509 Mdot
1 .15111 Mdot
1 .15143 Mdot
1 .1522 Mdot
1 .15399 Mdot
1 .15575 Mdot
1 .15578 Mdot
1 .15594 Mdot
1 .15631 Mdot
1 .15631 Mdot
1 .15663 Mdot
1 .15774 Mdot
1 .15823 Mdot
1 .15844 Mdot
1 .1596 Mdot
1 .15972 Mdot
1 .15999 Mdot
1 .16002 Mdot
1 .1608 Mdot
1 .16171 Mdot
1 .16179 Mdot
1 .16188 Mdot
1 .16349 Mdot
1 .16503 Mdot
1 .16511 Mdot
1 .16559 Mdot
1 .16595 Mdot
1 .16596 Mdot
1 .16719 Mdot
1 .16761 Mdot
1 .16963 Mdot
1 .17043 Mdot
1 .17178 Mdot
1 .17195 Mdot
1 .17251 Mdot
1 .1773 Mdot
1 .18019 Mdot
1 .18112 Mdot
1 .18297 Mdot
1 .18335 Mdot
1 .18365 Mdot
1 .18469 Mdot
1 .18477 Mdot
1 .18478 Mdot
1 .1878 Mdot
1 .18805 Mdot
1 .18805 Mdot
1 .18968 Mdot
1 .19037 Mdot
1 .19109 Mdot
1 .192 Mdot
1 .19407 Mdot
1 .1947 Mdot
1 .19599 Mdot
1 .19605 Mdot
1 .19676 Mdot
1 .19743 Mdot
1 .19766 Mdot
1 .19883 Mdot
1 .19893 Mdot
1 .20167 Mdot
1 .20349 Mdot
1 .20424 Mdot
1 .20548 Mdot
1 .20582 Mdot
1 .20592 Mdot
1 .20605 Mdot
1 .207 Mdot
1 .20717 Mdot
1 .20817 Mdot
1 .20946 Mdot
1 .2109 Mdot
1 .21202 Mdot
1 .21348 Mdot
1 .21406 Mdot
1 .21518 Mdot
1 .22201 Mdot
1 .22227 Mdot
1 .22427 Mdot
1 .22432 Mdot
1 .22449 Mdot
1 .22515 Mdot
1 .22663 Mdot
1 .22663 Mdot
1 .22781 Mdot
1 .22791 Mdot
1 .22861 Mdot
1 .23072 Mdot
1 .23077 Mdot
1 .23196 Mdot
1 .23251 Mdot
1 .23501 Mdot
1 .23619 Mdot
1 .23628 Mdot
1 .23634 Mdot
1 .23643 Mdot
1 .23798 Mdot
1 .2396 Mdot
1 .24002 Mdot
1 .2405 Mdot
1 .24068 Mdot
1 .24122 Mdot
1 .24161 Mdot
1 .24165 Mdot
1 .24192 Mdot
1 .24232 Mdot
1 .24369 Mdot
1 .24379 Mdot
1 .24416 Mdot
1 .24432 Mdot
1 .24476 Mdot
1 .24495 Mdot
1 .2461 Mdot
1 .24657 Mdot
1 .24863 Mdot
1 .24948 Mdot
1 .25021 Mdot
1 .25031 Mdot
1 .25174 Mdot
1 .25324 Mdot
1 .2537 Mdot
1 .25382 Mdot
1 .25427 Mdot
1 .2551 Mdot
1 .2553 Mdot
1 .25546 Mdot
1 .25568 Mdot
1 .25572 Mdot
1 .25637 Mdot
1 .2564 Mdot
1 .25694 Mdot
1 .25792 Mdot
1 .26167 Mdot
1 .26185 Mdot
1 .26323 Mdot
1 .26427 Mdot
1 .26597 Mdot
1 .26679 Mdot
1 .26703 Mdot
1 .26714 Mdot
1 .26741 Mdot
1 .2677 Mdot
1 .27228 Mdot
1 .2729 Mdot
1 .27307 Mdot
1 .27344 Mdot
1 .27404 Mdot
1 .2749 Mdot
1 .27593 Mdot
1 .27725 Mdot
1 .27745 Mdot
1 .27804 Mdot
1 .27814 Mdot
1 .27853 Mdot
1 .27908 Mdot
1 .28008 Mdot
1 .28104 Mdot
1 .28235 Mdot
1 .28552 Mdot
1 .28583 Mdot
1 .2859 Mdot
1 .28679 Mdot
1 .28681 Mdot
1 .28847 Mdot
1 .28932 Mdot
1 .29225 Mdot
1 .29254 Mdot
1 .29266 Mdot
1 .29289 Mdot
1 .29579 Mdot
1 .29581 Mdot
1 .29624 Mdot
1 .29782 Mdot
1 .30009 Mdot
1 .30126 Mdot
1 .30147 Mdot
1 .30156 Mdot
1 .30238 Mdot
1 .30333 Mdot
1 .30575 Mdot
1 .30732 Mdot
1 .30734 Mdot
1 .31072 Mdot
1 .31076 Mdot
1 .31104 Mdot
1 .31123 Mdot
1 .31499 Mdot
1 .31544 Mdot
1 .316 Mdot
1 .31676 Mdot
1 .31769 Mdot
1 .31783 Mdot
1 .31974 Mdot
1 .32037 Mdot
1 .32104 Mdot
1 .32169 Mdot
1 .32273 Mdot
1 .32442 Mdot
1 .32454 Mdot
1 .3247 Mdot
1 .3259 Mdot
1 .32595 Mdot
1 .3265 Mdot
1 .32716 Mdot
1 .32736 Mdot
1 .32803 Mdot
1 .33026 Mdot
1 .33029 Mdot
1 .33083 Mdot
1 .33162 Mdot
1 .33297 Mdot
1 .33324 Mdot
1 .33385 Mdot
1 .33539 Mdot
1 .33706 Mdot
1 .33827 Mdot
1 .33839 Mdot
1 .34149 Mdot
1 .34161 Mdot
1 .34249 Mdot
1 .34251 Mdot
1 .34276 Mdot
1 .34373 Mdot
1 .34406 Mdot
1 .34532 Mdot
1 .34596 Mdot
1 .34695 Mdot
1 .34732 Mdot
1 .34797 Mdot
1 .34809 Mdot
1 .35153 Mdot
1 .35268 Mdot
1 .35432 Mdot
1 .35484 Mdot
1 .35571 Mdot
1 .35677 Mdot
1 .35715 Mdot
1 .35767 Mdot
1 .35774 Mdot
1 .35853 Mdot
1 .35984 Mdot
1 .36013 Mdot
1 .36044 Mdot
1 .3606 Mdot
1 .36243 Mdot
1 .36266 Mdot
1 .36268 Mdot
1 .36384 Mdot
1 .36386 Mdot
1 .36417 Mdot
1 .36534 Mdot
1 .36625 Mdot
1 .36643 Mdot
1 .36716 Mdot
1 .36855 Mdot
1 .36959 Mdot
1 .37009 Mdot
1 .37252 Mdot
1 .37262 Mdot
1 .37426 Mdot
1 .37555 Mdot
1 .37607 Mdot
1 .37638 Mdot
1 .37668 Mdot
1 .37688 Mdot
1 .37785 Mdot
1 .37825 Mdot
1 .37832 Mdot
1 .37835 Mdot
1 .37872 Mdot
1 .3801 Mdot
1 .38371 Mdot
1 .38411 Mdot
1 .38419 Mdot
1 .3844 Mdot
1 .38512 Mdot
1 .38694 Mdot
1 .39032 Mdot
1 .39061 Mdot
1 .39136 Mdot
1 .39183 Mdot
1 .392 Mdot
1 .3941 Mdot
1 .39576 Mdot
1 .39633 Mdot
1 .40017 Mdot
1 .40032 Mdot
1 .40112 Mdot
1 .40363 Mdot
1 .4051 Mdot
1 .40586 Mdot
1 .40602 Mdot
1 .40636 Mdot
1 .40711 Mdot
1 .40719 Mdot
1 .4074 Mdot
1 .4089 Mdot
1 .40974 Mdot
1 .40982 Mdot
1 .41307 Mdot
1 .41375 Mdot
1 .41712 Mdot
1 .41718 Mdot
1 .41756 Mdot
1 .4184 Mdot
1 .41841 Mdot
1 .41913 Mdot
1 .42166 Mdot
1 .42233 Mdot
1 .42277 Mdot
1 .42324 Mdot
1 .42585 Mdot
1 .42612 Mdot
1 .42652 Mdot
1 .42673 Mdot
1 .42681 Mdot
1 .42856 Mdot
1 .43057 Mdot
1 .43076 Mdot
1 .43095 Mdot
1 .43451 Mdot
1 .43586 Mdot
1 .43602 Mdot
1 .4379 Mdot
1 .43807 Mdot
1 .4386 Mdot
1 .43911 Mdot
1 .43936 Mdot
1 .4394 Mdot
1 .4399 Mdot
1 .43992 Mdot
1 .44259 Mdot
1 .44349 Mdot
1 .44551 Mdot
1 .44629 Mdot
1 .4478 Mdot
1 .44914 Mdot
1 .4495 Mdot
1 .45234 Mdot
1 .45236 Mdot
1 .4527 Mdot
1 .45389 Mdot
1 .45396 Mdot
1 .45816 Mdot
1 .46002 Mdot
1 .46377 Mdot
1 .46547 Mdot
1 .4655 Mdot
1 .4665 Mdot
1 .46659 Mdot
1 .46709 Mdot
1 .46811 Mdot
1 .46917 Mdot
1 .46951 Mdot
1 .46957 Mdot
1 .47142 Mdot
1 .47325 Mdot
1 .47356 Mdot
1 .47507 Mdot
1 .47582 Mdot
1 .4762 Mdot
1 .47639 Mdot
1 .47843 Mdot
1 .47858 Mdot
1 .47859 Mdot
1 .48306 Mdot
1 .48342 Mdot
1 .48378 Mdot
1 .48437 Mdot
1 .48484 Mdot
1 .48485 Mdot
1 .48757 Mdot
1 .48791 Mdot
1 .4892 Mdot
1 .49053 Mdot
1 .49083 Mdot
1 .49097 Mdot
1 .49135 Mdot
1 .49209 Mdot
1 .49221 Mdot
1 .49258 Mdot
1 .49598 Mdot
1 .49712 Mdot
1 .49732 Mdot
1 .49818 Mdot
1 .49896 Mdot
1 .49942 Mdot
1 .49953 Mdot
1 .50016 Mdot
1 .50079 Mdot
1 .50199 Mdot
1 .50239 Mdot
1 .50443 Mdot
1 .5046 Mdot
1 .50462 Mdot
1 .50586 Mdot
1 .50587 Mdot
1 .50733 Mdot
1 .50797 Mdot
1 .50808 Mdot
1 .50933 Mdot
1 .5124 Mdot
1 .51366 Mdot
1 .51377 Mdot
1 .5149 Mdot
1 .51571 Mdot
1 .51627 Mdot
1 .51644 Mdot
1 .51665 Mdot
1 .51821 Mdot
1 .51849 Mdot
1 .5201 Mdot
1 .52021 Mdot
1 .52034 Mdot
1 .52168 Mdot
1 .52216 Mdot
1 .52407 Mdot
1 .5244 Mdot
1 .52445 Mdot
1 .52452 Mdot
1 .52569 Mdot
1 .52619 Mdot
1 .52622 Mdot
1 .52648 Mdot
1 .52765 Mdot
1 .52845 Mdot
1 .52933 Mdot
1 .52989 Mdot
1 .53103 Mdot
1 .53366 Mdot
1 .53485 Mdot
1 .53507 Mdot
1 .5406 Mdot
1 .54099 Mdot
1 .54136 Mdot
1 .54139 Mdot
1 .5437 Mdot
1 .54413 Mdot
1 .54421 Mdot
1 .54443 Mdot
1 .54533 Mdot
1 .54656 Mdot
1 .54679 Mdot
1 .54734 Mdot
1 .54734 Mdot
1 .54742 Mdot
1 .54843 Mdot
1 .5488 Mdot
1 .5489 Mdot
1 .54903 Mdot
1 .54995 Mdot
1 .55268 Mdot
1 .55273 Mdot
1 .55318 Mdot
1 .55425 Mdot
1 .55493 Mdot
1 .55547 Mdot
1 .55635 Mdot
1 .55662 Mdot
1 .55671 Mdot
1 .5572 Mdot
1 .55801 Mdot
1 .55942 Mdot
1 .55953 Mdot
1 .5596 Mdot
1 .5597 Mdot
1 .5615 Mdot
1 .56152 Mdot
1 .56309 Mdot
1 .56339 Mdot
1 .56352 Mdot
1 .56355 Mdot
1 .56363 Mdot
1 .56386 Mdot
1 .56408 Mdot
1 .5644 Mdot
1 .56461 Mdot
1 .56517 Mdot
1 .56521 Mdot
1 .56539 Mdot
1 .56565 Mdot
1 .56569 Mdot
1 .56573 Mdot
1 .56599 Mdot
1 .56607 Mdot
1 .56643 Mdot
1 .56663 Mdot
1 .56791 Mdot
1 .56802 Mdot
1 .56803 Mdot
1 .56842 Mdot
1 .56858 Mdot
1 .56905 Mdot
1 .56925 Mdot
1 .56977 Mdot
1 .56987 Mdot
1 .57045 Mdot
1 .57093 Mdot
1 .57236 Mdot
1 .57286 Mdot
1 .57302 Mdot
1 .57387 Mdot
1 .57389 Mdot
1 .57457 Mdot
1 .57468 Mdot
1 .57524 Mdot
1 .57594 Mdot
1 .57604 Mdot
1 .5761 Mdot
1 .57695 Mdot
1 .57744 Mdot
1 .57786 Mdot
1 .57797 Mdot
1 .57803 Mdot
1 .57832 Mdot
1 .57833 Mdot
1 .57839 Mdot
1 .57913 Mdot
1 .57931 Mdot
1 .57938 Mdot
1 .5794 Mdot
1 .57945 Mdot
1 .5796 Mdot
1 .57964 Mdot
1 .57968 Mdot
1 .58025 Mdot
1 .58028 Mdot
1 .58074 Mdot
1 .58119 Mdot
1 .58133 Mdot
1 .58158 Mdot
1 .58159 Mdot
1 .58183 Mdot
1 .58292 Mdot
1 .58356 Mdot
1 .58362 Mdot
1 .58403 Mdot
1 .58434 Mdot
1 .58464 Mdot
1 .58478 Mdot
1 .58516 Mdot
1 .58584 Mdot
1 .58585 Mdot
1 .58623 Mdot
1 .58663 Mdot
1 .58744 Mdot
1 .58787 Mdot
1 .58827 Mdot
1 .58845 Mdot
1 .58862 Mdot
1 .58869 Mdot
1 .58888 Mdot
1 .58908 Mdot
1 .5906 Mdot
1 .59068 Mdot
1 .59109 Mdot
1 .59133 Mdot
1 .59194 Mdot
1 .59206 Mdot
1 .59234 Mdot
1 .59243 Mdot
1 .59254 Mdot
1 .59276 Mdot
1 .59309 Mdot
1 .59311 Mdot
1 .59328 Mdot
1 .5936 Mdot
1 .59383 Mdot
1 .59397 Mdot
1 .59398 Mdot
1 .59418 Mdot
1 .59446 Mdot
1 .59453 Mdot
1 .5949 Mdot
1 .595 Mdot
1 .59531 Mdot
1 .59536 Mdot
1 .59556 Mdot
1 .59584 Mdot
1 .59613 Mdot
1 .59619 Mdot
1 .59633 Mdot
1 .59677 Mdot
1 .59679 Mdot
1 .59739 Mdot
1 .59752 Mdot
1 .59818 Mdot
1 .59843 Mdot
1 .59855 Mdot
1 .59872 Mdot
1 .59886 Mdot
1 .59907 Mdot
1 .5992 Mdot
1 .59921 Mdot
1 .59936 Mdot
1 .59956 Mdot
1 .59957 Mdot
1 .5998 Mdot
1 .60009 Mdot
1 .60032 Mdot
1 .60053 Mdot
1 .60059 Mdot
1 .60079 Mdot
1 .60094 Mdot
1 .60096 Mdot
1 .60099 Mdot
1 .60107 Mdot
1 .6011 Mdot
1 .60116 Mdot
1 .60128 Mdot
1 .60133 Mdot
1 .60136 Mdot
1 .60177 Mdot
1 .60187 Mdot
1 .60188 Mdot
1 .60197 Mdot
1 .602 Mdot
1 .60213 Mdot
1 .60226 Mdot
1 .60229 Mdot
1 .60238 Mdot
1 .60267 Mdot
1 .60269 Mdot
1 .60271 Mdot
1 .60284 Mdot
1 .60284 Mdot
1 .60286 Mdot
1 .60287 Mdot
1 .60294 Mdot
1 .60297 Mdot
1 .603 Mdot
1 .60305 Mdot
1 .60307 Mdot
1 .60325 Mdot
1 .6033 Mdot
1 .60331 Mdot
1 .60332 Mdot
1 .60332 Mdot
1 .60332 Mdot
1 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[51]:=",
  ImageSize->{740.75, 457.813},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000AG0002[R000`400?l00000o`00003oo`3ooooo
0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0
ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3o
oomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?oo
o`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00l@3o
ool4000000H0oooo0P0000050?ooo`H00000_P3oool4000000H0oooo0P0000070?ooo`@00000_`3o
ool4000000H0oooo0P0000070?ooo`@00000_P3oool4000000H0oooo0P0000060?ooo`@00000a`3o
ool700000080oooo003`0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2
000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool2000000T0oooo00<000000?ooo`3oool0_@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0a`3oool0
0`000000oooo0?ooo`030?ooo`00l03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool00`3oool00?00oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`H00000_P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo0P0000030?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0a`3oool00`000000
oooo0?ooo`030?ooo`00l03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00@000000?ooo`3oool00000_`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`0000000P00002m0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool400000<X0oooo00<000000?ooo`3oool00`3oool00?00oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo00000;l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0a`3oool00`000000oooo0?ooo`030?ooo`00l03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2k0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002o0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2n0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0<L0oooo00<000000?ooo`3oool00`3oool00?00oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0^`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000_`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0_@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`350?ooo`<000001@3oool00?40oooo1000000>0?ooo`@00000_`3oool4
00000100oooo0P0000300?ooo`@000004@3oool300000;d0oooo1000000>0?ooo`@00000bP3oool0
0`000000oooo0?ooo`030?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3o
ool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`3o0?ooool0ooooe@3oool00`000000oooo0?ooo`03
0?ooo`00:03ooooo00000?l00000o`00003o000002h000001@3oool002P0oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`030?ooo`00:03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0300oooo00<000000?ooo`0000001@3o
ool002P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
000000D0oooo000X0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0dP3oool00`00
0000oooo0?ooo`3B0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0d03oool00`00
0000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo0=80
oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo0=00
oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3ooolV0?ooo`050000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooooo`3ooolV0?ooo`050000003oool000000?ooo`0000001@3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolV0?ooo`050000003oool000000?ooo`00
00001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolT0?ooo`070000
003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooooo0?ooob@0oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo903oool01`000000oooo0000003oool0
00000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolT
0?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooooo0?ooob80oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolR0?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooool0oooo8P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooob80oooo
00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooool0oooo7`3oool030000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo
7`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000D0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo7`3oool030000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000D0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooool0oooo7`3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3o
oolM0?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolM0?ooo`03
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolM0?ooo`030000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolM0?ooo`030000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooo`3ooolK0?ooo`050000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooooo0?oooa/0oooo00D000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooool0oooo6`3oool01@000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooool0oooo6`3oool01@000000oooo0000003oool0000000@0oooo
00L000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooool0oooo6@3oool01@000000oooo0000003oool0000000H0oooo00L000000?oo
o`000000oooo0000003oool0000000D0oooo000X0?ooo`D00000o`3ooooo0?ooool0ooooo`3ooolG
0?ooo`050000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooaT0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3ooolI0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`03
0000003oool0oooo0?l0ooooo`3oooo00?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001@3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolI0?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo6@3oool01@000000oooo
0?ooo`3oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolE0?ooo`0;0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oooo0?oooaD0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool0103oool01@000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooool0oooo5@3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolE0?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo
0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo
4`3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooool0oooo4`3oool00`000000oooo000000030?ooo`070000003o
ool0oooo0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo4`3oool0
0`000000oooo000000030?ooo`050000003oool000000?ooo`0000001P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3ooolC0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooool0oooo4@3oool01@000000oooo0000003oool0000000<0oooo00L0
00000?ooo`3oool0oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo4@3oool01@00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooool0oooo4@3oool01@000000oooo0000003oool0000000<0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolA0?ooo`05
0000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooo`h0oooo00P000000?ooo`3oool000000?ooo`000000
oooo000000D0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
ool0oooo3P3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo
000000030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000050?oo
o`00:03oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0o`3ooooo0?oookD0
oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo303oool00`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooo`3oool<0?ooo`030000003oool000000080oooo00<000000?ooo`0000001@3oool0
0`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo
000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooo``0oooo00<0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
1P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooo`3oool<0?ooo`030000003oool000000080oooo00D000000?ooo`00
0000oooo000000070?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
ool0oooo2P3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?oo
o`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool:0?ooo`05
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool:0?oo
o`050000003oool000000?ooo`000000103oool00`000000oooo000000070?ooo`030000003oool0
oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooool0oooo2P3oool01@000000oooo0000003oool000000080oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooo`3oool80?ooo`070000003oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooo`3oool80?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`D00000o`3ooooo0?ooool0ooooo`3o
ool60?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooooo0?ooo`H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool000000080oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0
o`3ooomG0?ooo`030000003oool0oooo0?l0ooooo`3ooon[0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo1P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooool0oooo1P3oool00`000000oooo000000050?ooo`040000003oool0oooo000000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo103oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3o
ool02`3oool010000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`0000001@3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool40?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00L0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool00000
00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo103oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`000003
0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
ool0oooo103oool01`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`3oool0oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooool0oooo0P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000D0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool20?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
1@3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0
oooo0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001@3oool002P0
oooo00<000000?ooo`3oool0o`3ooomI0?ooo`030000003oool0oooo0?l0ooooo`3ooonS0?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo
00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003o
ool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooool0?ooo`040000003oool0oooo000000D0oooo00L000000?ooo`000000oooo0000003oool0
000000H0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooo03oool010000000oooo0?ooo`0000030?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooo`0oooo
00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooj0?ooo`030000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000060?oo
o`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooonP3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool00`3oool002P0oooo00<000000?ooo`3oool0o`3ooomK0?ooo`030000003oool0oooo0?l0
ooooo`3ooonL0?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oooj0?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool0
1@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooon03oool00`000000
oooo000000040?ooo`030000003oool0000000D0oooo00L000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooh0?ooo`050000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0
oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003oool000000?ooo`000000103oool0
1`000000oooo0?ooo`3oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0oooon03oool01@000000oooo0000003oool000000080oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0
oooo00D0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
ooof0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00D000000?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo0000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooooH0oooo00D000000?ooo`00
0000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooomP3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
oed0oooo00<000000?ooo`3oool0o`3ooooo0?oooiH0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`050000003oool000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0oooom03oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooood0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000060?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000090?ooo`00:03oool500000?l0ooooo`3o
oooo0?oooo80oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0oooolP3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`0000001P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooolP3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`070000003oool000000?oo
o`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000001`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0oooolP3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0
000000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool0103oool01@000000oooo0000003oool0000000D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?oooo80oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000001@3oool00`000000oooo
000000020?ooo`030000003oool0oooo00D0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooomP0?ooo`030000003oool0oooo0?l0ooooo`3ooon=0?ooo`070000003o
ool000000?ooo`000000oooo000000050?ooo`060000003oool0oooo0000003oool000000`3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01@3oool01@000000oooo0000
003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?oooo00oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000060?ooo`030000003oool0oooo00D0oooo00L000000?ooo`000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooo00oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00<000000?oo
o`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooond0oooo00P000000?ooo`3o
ool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000001P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0000
00030?ooo`030000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooo00oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000080?ooo`050000003oool0oooo0?ooo`000000
0`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooo00
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0000000D0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooHP3oool0
0`000000oooo0?ooo`3o0?ooool0ooooR`3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo00<0
00000?ooo`0000001P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooool03oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`0000001@3oool010000000oooo0?oo
o`0000030?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`060000003oool0oooo
0000003oool000000`3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3oooo[0?ooo`030000003oool0oooo0080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000001P3oool00`000000oooo000000030?ooo`030000
003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`0000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo`0?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00<000000?ooo`00
00001@3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooj@3o
ool00`000000oooo0?ooo`040?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000X0oooo00<00000
0?ooo`0000001@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000050?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?oooo00oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000D0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooond0oooo00X000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000`3oool00`000000oooo000000020?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`050?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`030000003oool0
oooo0?l0ooooo`3ooon90?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000X0
oooo00<000000?ooo`0000000`3oool00`000000oooo000000080?ooo`070000003oool000000?oo
o`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooW0?oo
o`030000003oool0oooo00H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
000000H0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool01P000000
oooo0?ooo`000000oooo000000D0oooo00D000000?ooo`000000oooo000000060?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooool03oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooool03oool01`000000oooo0000003oool000000?ooo`00
0000203oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`0<0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000001@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooi@3oool00`000000oooo0?ooo`080?ooo`050000003oool000000?ooo`000000
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`000000
oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooonD0oooo00<000000?ooo`3oool02P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000P0oooo00<000000?ooo`0000001@3oool01@000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool0
02P0oooo00<000000?ooo`3oool0o`3ooomV0?ooo`030000003oool0oooo0?l0ooooo`3oooml0?oo
o`030000003oool0oooo00X0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooh`3oool00`000000oooo0000000<0?ooo`050000003oool000000?oo
o`0000000`3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000050?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000D0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooon<0oooo00<000000?ooo`000000
303oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000
oooo0?ooo`050?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000D0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooh`3oool0
0`000000oooo0000000<0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00040?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000001@3oool00080oooo100000060?ooo`8000001@3o
ool6000000l0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooh`3oool00`000000oooo0000
000<0?ooo`050000003oool000000?ooo`0000001@3oool03P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000001P3oool01@000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000D0oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00<0oooo
0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`3o0?ooofP0oooo00<000000?ooo`3oool0o`3ooooo0?ooogH0oooo00D000000?ooo`000000
oooo0000000<0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000040?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`0000<0oooo0000
003oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooh@3oool01@000000oooo0000003oool0000000`0oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`030?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0100oooo1`00003o0?ooool0ooooo`3ooooM0?ooo`050000003oool0
00000?ooo`000000303oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000080?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool0
00000?ooo`0000030?ooo`030000003oool0oooo00<0oooo00000`3oool000000?ooo`030?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooooO0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool02P3oool01@000000
oooo0000003oool0000000`0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000<0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000D0oooo00000`3oool00000
0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooooO0?ooo`070000003oool000000?ooo`000000oooo0000000<0?oo
o`070000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?oo
o`070000003oool0oooo0?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000
oooo000000050?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooooO0?ooo`070000003oool000000?ooo`000000oooo0000000<0?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000003oool00000
0?ooo`000000oooo000000050?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o
0?ooofX0oooo00<000000?ooo`3oool0o`3ooooo0?ooofl0oooo00X000000?ooo`3oool000000?oo
o`000000oooo0000003oool00000303oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool01P000000oooo0?ooo`000000oooo000000L0oooo00D000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`000P3oool40000
00h0oooo1000000@0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooom`0oooo00X000000?oo
o`3oool000000?ooo`000000oooo0000003oool00000303oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`000000
oooo000000060?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooL0?ooo`0:0000003oool0oooo0000
003oool000000?ooo`000000oooo000000`0oooo00/000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo000000080?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooofP3oool00`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo0000000<0?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000D0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooomX0oooo00<000000?ooo`0000000P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000003P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`05
0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooom/0?ooo`030000003oool0oooo0?l0ooooo`3ooom[0?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`070000003o
ool000000?ooo`000000oooo000000060?ooo`030000003oool0000000D0oooo00<000000?ooo`00
00001P3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00@000000?ooo`3o
ool000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooomX0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000003P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000D0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000
oooo0000003oool000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooof03o
ool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00`0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo
000000050?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooomP0oooo
00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000<
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000060?ooo`0;0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo00000005
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooH0?ooo`050000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00X0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo000000070?ooo`03
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`0<
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000001@3oool002P0oooo
00<000000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo0?l0ooooo`3ooomU0?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
000<0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`030000
003oool0000000h0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooomH0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000h0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo000000050?oo
o`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0
oooo0?ooo`000000oooo000000060?ooo`030000003oool0oooo00L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooomH0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool000000100oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0000000<0oooo00<000000?ooo`000000203oool01@000000oooo0000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooom@0oooo00D000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool0
00000?ooo`000000oooo000000h0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool00`00
0000oooo000000050?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooog40oooo
00<000000?ooo`3oool0o`3ooooo0?ooof00oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000303oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool00`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01@000000
oooo0000003oool0000000H0oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooom@0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000303oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000001@3oool00`000000oooo000000060?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo
000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooB0?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000h0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool00P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo00000004
0?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooooB0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00X0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000070?ooo`050000003oool0
oooo0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0oooodP3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000`0
oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00070?ooo`030000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`030000003oool0oooo0?l0
ooooo`3ooomL0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`000000303oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooom00oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`00000@0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`050000003oool00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooood03oool02@000000oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`070000003oool000000?ooo`000000oooo0000000<0?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000050?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`070000
003oool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo0000
00050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo@0?ooo`050000003oool0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000050?ooo`030000003oool0oooo00<0oooo00`000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000050?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooogD0oooo00<000000?ooo`3oool0o`3ooooo0?oooeH0oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`000000303oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000D0oooo00D000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooolh0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`040000003oool0oooo0000
00<0oooo00D000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3oooo>0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000004P3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00<000000?ooo`0000003P3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0oooob`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000040?ooo`070000003oool000000?ooo`000000oooo0000000@0?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000050?ooo`00:03oool500000?l0ooooM@3oool00`000000oooo0?oo
o`3o0?ooool0ooooE03oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`000000403oool01`000000oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`3oool0
oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0oooob`3oool04P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00L00000
0?ooo`000000oooo0000003oool0000000h0oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo90?ooo`030000003oool0oooo0080oooo
00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`000000303oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo
00<000000?ooo`0000000P3oool00`000000oooo000000070?ooo`030000003oool0000000H0oooo
00D000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3oooo90?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0000000H0oooo00<000000?ooo`000000403oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000D0oooo00<00000
0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`000000
1@3oool002P0oooo00<000000?ooo`3oool0o`3ooomi0?ooo`030000003oool0oooo0?l0ooooo`3o
oom=0?ooo`030000003oool0oooo0080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool000000180
oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0ooooa`3oool00`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000003P3oool01@000000oooo0000003oool0000000<0oooo0100
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
0000103oool01@000000oooo0000003oool0000000L0oooo00<000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooa`3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000004P3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooa`3oool00`00
0000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`0000004P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003o
ool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool000000?ooo`00
00002P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooog/0oooo
00<000000?ooo`3oool0o`3ooooo0?ooodL0oooo00D000000?ooo`000000oooo000000040?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo
000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000
oooo0?ooo`3oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000D0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooolD0oooo00D000000?ooo`000000oooo0000
00040?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`030000003oool000000080
oooo00D000000?ooo`000000oooo0000000>0?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00L000000?oo
o`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo50?ooo`050000003oool0
00000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000B0?oo
o`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`050000003oool0
00000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3oooo30?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`00000>0?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000060?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooogd0oooo00<000000?ooo`3oool0o`3ooooo0?oood<0oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000>
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00001@3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo00000003
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo``3o
ool01`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo
0000003oool0000000h0oooo00D000000?ooo`000000oooo000000030?ooo`080000003oool0oooo
0000003oool000000?ooo`0000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo000000060?ooo`070000003oool0
00000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
ooo10?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo0000
000@0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0000
00070?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000090?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo10?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000h0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
2`3oool01P000000oooo0?ooo`000000oooo000000/0oooo000X0?ooo`030000003oool0oooo0?l0
ooooO`3oool00`000000oooo0?ooo`3o0?ooool0oooo?`3oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool0103oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000003P3oool01`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01@000000oooo
0?ooo`3oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo_`3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000H0oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000000>
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`0000001P3oool01@000000oooo0000003oool0000000L0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oookl0oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo
0000003oool0000000h0oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo
000000<0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`000000403oool00`000000oooo000000070?ooo`00:03oool00`00
0000oooo0?ooo`3o0?oooh80oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0
oooo00D000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?oo
o`000000oooo00000100oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00/00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonl
0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00040?ooo`050000003oool000000?ooo`0000001`3oool00`000000oooo000000020?ooo`070000
003oool0oooo0?ooo`000000oooo0000000B0?ooo`050000003oool000000?ooo`0000000P3oool0
0`000000oooo000000050?ooo`030000003oool0000000H0oooo00<000000?ooo`0000002`3oool0
0`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonl0?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool03P3oool00`000000oooo000000030?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?oo
o`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonl0?oo
o`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000004
0?ooo`030000003oool0000000<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo
00<000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool002P0
oooo00<000000?ooo`3oool0o`3ooon40?ooo`030000003oool0oooo0?l0ooooo`3ooolc0?ooo`03
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0000000D0oooo00L000000?ooo`3oool0oooo0000003oool00000
0080oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0000000H0oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooonj0?ooo`030000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000080?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`00
0000303oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`3oool00`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000040?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooonj0?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
0000000>0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000203oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool0o`3o
oooo0?ooobl0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000`0oooo00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000T0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo^03oool01@000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo000000040?ooo`050000003oool000000?ooo`0000003P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo^03oool01@000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool00000
00@0oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`000000403oool01@000000oooo0000003oool00000
00<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`000000
0`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000070?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooohP0oooo00<000000?ooo`3oool0o`3ooooo0?ooob/0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`05
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000003P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool00000
00<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo
0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oookH0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000203oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo000000060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0000000:0?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000D0oooo
00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo]P3o
ool00`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo
000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000`0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000203oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000D0oooo000X0?ooo`D00000o`3ooooo0?ooool0oooo/P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000001P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003o
ool0oooo0100oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
00000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo
00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolW0?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000060?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0000003oool000000100oooo00<000000?ooo`0000001P3oool00`000000oooo
0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`0000002@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo]03oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000004P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oook80oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool000000100oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000
oooo0000003oool0000000P0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooS03oool00`000000oooo0?ooo`3o0?ooool0oooo8`3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo0000
000@0?ooo`050000003oool000000?ooo`0000002P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oook00oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000070?ooo`080000003oool0oooo0000003oool000000?ooo`00000@0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`050000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000005
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon`0?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00D0oooo00<000000?ooo`000000103oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`000005
0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooSP3oool00`000000oooo0?ooo`3o
0?ooool0oooo7`3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`050000003oool000000?ooo`000000303oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool00000
00D0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000D0oooo00D000000?ooo`000000
oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000D0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooojh0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool00`000000oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
000<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooon^0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
1P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<0
00000?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo0000000D0?ooo`030000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`050000003oool000000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00L0
00000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0oooo
T@3oool00`000000oooo0?ooo`3o0?ooool0oooo6P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?oo
o`000000oooo000000060?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000@0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?oooj/0oooo018000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003o
ool0oooo00<0oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0oooo00D0oooo
00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000004P3oool00`00
0000oooo000000030?ooo`060000003oool0oooo0000003oool000001@3oool01`000000oooo0000
003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooZ`3oool04P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo0000000>0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`3oool0oooo000000050?ooo`050000003oool000000?ooo`00
00000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000050?ooo`00:03oool0
0`000000oooo0?ooo`3o0?oooi<0oooo00<000000?ooo`3oool0o`3ooooo0?oooaP0oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3o
ool01`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
0000000>0?ooo`050000003oool000000?ooo`0000001P3oool03@000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool00000
00D0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooojT0oooo
00<000000?ooo`3oool00P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`0000001P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000180oooo00D000000?ooo`00
0000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`3oool0oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooZ@3oool00`000000oooo0?ooo`020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D00000
0?ooo`000000oooo0000000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000203o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooonE0?ooo`030000003oool0oooo0?l0ooooo`3ooolA0?ooo`030000003o
ool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`000000oooo00000004
0?ooo`050000003oool000000?ooo`000000403oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000001@3oool01@000000oooo0?ooo`3oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooY`3oool00`000000oooo000000040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo0000000<0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0103o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
oiL0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`d0oooo00<000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool000000100oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000050?ooo`040000003o
ool0oooo000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000X0oooo00D000000?oo
o`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonU0?oo
o`050000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool02P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000001P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooY@3o
ool01@000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo0100oooo00D000000?ooo`3oool0oooo000000040?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool01@3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oooiT0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooo`T0oooo00D000000?ooo`000000oooo000000060?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000002P3oool01@000000oooo0000003o
ool0000000H0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000003P3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool00P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000070?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000050?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooonS0?ooo`070000003oool000000?ooo`000000oooo
000000060?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0;
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo
0?ooo`3oool000000?ooo`0000004P3oool01@000000oooo0?ooo`3oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000050?ooo`030000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooj<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool02P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000403oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`0;0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooonK0?ooo`030000003oool0oooo0?l0
ooooo`3oool50?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo0000000:0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`00
00001@3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo0000
00030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0ooooX@3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000060?ooo`030000003oool0
000000D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0
7@3oool00`000000oooo000000050?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`070000003oool0
00000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oonQ0?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?oo
o`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool0
1@000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000
003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooW@3oool00`000000oooo0?oo
o`3o0?ooooh0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000203oool00`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo0000000>0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000080?ooo`050000003oool0oooo0?ooo`00
00000`3oool01`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo00000007
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonQ0?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`07
0000003oool0oooo0?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool00000
0?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000006@3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000000D0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0
000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooW`3oool00`000000oooo0?ooo`3o0?oo
ooh0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000001P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool00`000000oooo0000000B0?ooo`030000003oool00000
00D0oooo00<000000?ooo`3oool00P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`070?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooonM0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00D000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo1@00003o
0?ooool0ooooo`3ooonK0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000001`3oool01@000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooXP3oool0
0`000000oooo0?ooo`3o0?ooooL0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0000000H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`030000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000T0oooo00`000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooonJ0?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo00000006
0?ooo`050000003oool000000?ooo`000000403oool01@000000oooo0000003oool0000000<0oooo
010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool00000203oool00`000000oooo0?ooo`050?ooo`030000003oool0000000P0oooo00<000000?oo
o`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooonT0?ooo`030000003oool0oooo0?l0
oooolP3oool010000000oooo0?ooo`0000030?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0000003oool000000180oooo00<000000?ooo`0000000`3o
ool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooVP3oool010000000oooo0?oo
o`0000030?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000h0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000103o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooonH0?ooo`030000003oool000000080oooo00d000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`00000>0?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooonV0?ooo`030000003oool0oooo0?l0ooool03oool010000000oooo0?ooo`00
00030?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00/000000?oo
o`3oool0oooo0000003oool000000?ooo`000000oooo000000060?ooo`070000003oool000000?oo
o`000000oooo000000060?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000001/0oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080
oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?oooiH0oooo00<000000?ooo`3oool0103oool03@000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000001P3oool02`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool0000000@0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo000000060?ooo`070000003oool000000?ooo`000000oooo0000000@0?ooo`030000003oool0
000000P0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X
0?ooo`030000003oool0oooo0?l0ooooZ03oool00`000000oooo0?ooo`3o0?oooo40oooo00d00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000P0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0?0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo
0000003oool000000100oooo00<000000?ooo`0000001P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
ooooW@3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0103oool0
3`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00060?ooo`030000003oool0000000`0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool01@000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooojX0oooo00<000000?ooo`3oool0o`3ooooV0?ooo`030000003o
ool0oooo00H0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00H0oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0000000>0?ooo`030000003oool0000000P0oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo
00L000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?oooid0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool02P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`00000@0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D0
00000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?oooid0oooo00d000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000180
oooo00<000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00<0
00000?ooo`0000001P3oool00`000000oooo000000030?ooo`030000003oool0000000D0oooo000X
0?ooo`030000003oool0oooo0?l0oooo[03oool00`000000oooo0?ooo`3o0?ooonX0oooo00@00000
0?ooo`3oool000000`3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo00@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool02P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`00000>0?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000L0oooo
00<000000?ooo`000000103oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?oooid0oooo00d000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`050000003oool000000?ooo`0000004P3oool00`000000oooo0?ooo`030?ooo`06
0000003oool0oooo0000003oool000000`3oool01`000000oooo0000003oool000000?ooo`000000
1P3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000060?oo
o`050000003oool0oooo0?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooon^0?oo
o`030000003oool0oooo0?l0ooooh03oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo
000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000070?ooo`030000003oool0
oooo00H0oooo00D000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3ooon@0?ooo`030000003oool0oooo00X0oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo00P0oooo00D000000?ooo`000000oooo000000060?ooo`050000003oool000000?oo
o`0000005P3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00L000000?oo
o`000000oooo0000003oool0000000H0oooo00<000000?ooo`3oool00`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00050?ooo`00:03oool00`000000oooo0?ooo`3o0?oook00oooo00<000000?ooo`3oool0o`3ooooV
0?ooo`040000003oool0oooo000000<0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000H0oooo00/000000?oo
o`3oool0oooo0000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0000000h0
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000
003oool0oooo00D0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?oo
o`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon>0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000003
0?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`030?ooo`0<0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?oo
o`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0o`3o
oonc0?ooo`030000003oool0oooo0?l0ooooh`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0000000<0oooo00<000000?ooo`000000103oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool01`000000oooo0000
003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000h0
oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000030?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`03
0000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooh/0oooo
00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool000000100oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00<000000?ooo`0000002@3oool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
oiP0oooo00<000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000001P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0000000<0?ooo`030000003oool0000000D0oooo00<000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00P0
00000?ooo`3oool000000?ooo`000000oooo000000D0oooo00<000000?ooo`000000103oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?oo
o`3o0?oookD0oooo00<000000?ooo`3oool0o`3oooo@0?ooo`030000003oool0oooo00h0oooo00@0
00000?ooo`3oool000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000003P3oool00`000000oooo000000030?ooo`030000003o
ool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooonJ0?ooo`040000003oool0oooo000000<0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000
403oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?ooo`000000
0`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo000000030?ooo`060000003oool0oooo0000003oool0
00000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?oookL0oooo
00<000000?ooo`3oool0o`3oooo<0?ooo`030000003oool0oooo0100oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000P0oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0203oool01`000000oooo0000003o
ool000000?ooo`0000001P3oool00`000000oooo0?ooo`0@0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`070000003o
ool0oooo0?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonJ0?ooo`04
0000003oool0oooo000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000203oool01`000000
oooo0?ooo`3oool000000?ooo`0000002P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo000X
0?ooo`030000003oool0oooo0?l0oooo^@3oool00`000000oooo0?ooo`3o0?ooolP0oooo00<00000
0?ooo`3oool05@3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool020000000oooo
0?ooo`000000oooo0000003oool000001@3oool00`000000oooo0?ooo`020?ooo`0?0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool05P3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooid0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0
oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool03P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00020?ooo`@000001P3oool20000
00L0oooo1000000?0?ooo`030000003oool0oooo0?l0oooo^`3oool00`000000oooo0?ooo`3o0?oo
omh0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`070000003oool00000
0?ooo`000000oooo0000000>0?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`03
0000003oool0000000<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000050?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo
000000090?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`030?ooo`8000002@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooh<0oooo00<0
00000?ooo`3oool05`3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`0I0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0000003oool0000000T0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?oookd0oooo00<000000?ooo`3oool0o`3ooooP
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool02`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool0000000P0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000003P3oool00`00
0000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo0000000<0?ooo`030000003oool0oooo00`0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000D0oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo
00X0oooo1P00000?0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooj40oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000403oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000D0oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00/0oooo00@0
00000?ooo`3oool00000403oool700000?l0oooo^`3oool00`000000oooo0?ooo`3o0?oookh0oooo
00<000000?ooo`3oool07@3oool02@000000oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000002P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0>0?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000001@3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`030?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0;0?oo
o`040000003oool0oooo00000100oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooX@3oool0
1`000000oooo0000003oool000000?ooo`000000203oool01@000000oooo0000003oool0000000<0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0000000X0oooo00D000000?oo
o`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`050000
003oool0oooo0?ooo`000000403oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080
oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
000@0?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
00000100oooo00<000000?ooo`3oool0o`3oooo20?ooo`030000003oool0oooo0?l0oooof`3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?oo
o`000000oooo0000000:0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000004P3oool01@000000oooo0000
003oool000000080oooo00<000000?ooo`0000001`3oool01@000000oooo0000003oool000000080
oooo00<000000?ooo`0000001@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`030000003oool0000000D0oooo00000`3oool000000?ooo`030?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooomo0?ooo`030000003oool0oooo01d0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000h0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000001P3oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo00000003
0?ooo`030000003oool0oooo00<0oooo00020?ooo`@00000403oool200000100oooo00<000000?oo
o`3oool0o`3oooo40?ooo`030000003oool0oooo0?l0oooof@3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool01@000000oooo0?ooo`3oool000000100oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo000000040?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo000000040?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooX@3oool00`000000oooo000000030?ooo`030000003oool0000000H0
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`000000403oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooaP3o
ool00`000000oooo0?ooo`3o0?ooomL0oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`000000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000060?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
01@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooomm0?ooo`030000003oool0oooo0240oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo
00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000001P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000
003oool000000?ooo`000000oooo000000`0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3o
ool002P0oooo00<000000?ooo`3oool0o`3oooo80?ooo`030000003oool0oooo0?l0ooooe@3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?oo
o`0000001@3oool00`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000001P3oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool03P3oool01`000000oooo0000003oool000000?ooo`000000103oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`0000001@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
X@3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000001P3oool00`000000oooo0000000>0?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0
000000<0oooo00@000000?ooo`3oool000001`3oool00`000000oooo000000030?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool0o`3ooooC0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool000000180oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0000000P0oooo00D000000?ooo`000000oooo000000070?ooo`00:03oool0
0`000000oooo0?ooo`3o0?oool`0oooo00<000000?ooo`3oool0o`3ooonZ0?ooo`030000003oool0
oooo02@0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0
00000?ooo`000000303oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000<0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooonQ0?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0203o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00h0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool01P3oool02`000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo
000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooolh0oooo00<000000?ooo`3oool0o`3o
ooo?0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0000003oool0000000P0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000403oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00060?ooo`030000003oool0000000D0oooo00D000000?ooo`000000oooo000000040?ooo`070000
003oool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooonQ0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L0
00000?ooo`000000oooo0000003oool0000000D0oooo00H000000?ooo`3oool000000?ooo`000005
0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000303oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000040?ooo`050000003oool000000?ooo`0000001@3oool0
1@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3oooo@0?ooo`030000003oool0oooo0?l0
ooooc@3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000H0oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000h0oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`05
0?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0000000<0
oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000050?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonQ0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000203oool01`000000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool000000100oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`000000oooo000000070?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooom<0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0<0?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo00000005
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000005
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonQ0?ooo`030000003oool00000
00<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000203oool00`000000oooo0?ooo`030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo0000000>0?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000001@3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooe@3oool00`000000oooo0?ooo`3o0?oooil0
oooo00<000000?ooo`3oool09P3oool00`000000oooo000000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003oool000000?ooo`000000103oool0
2`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?oo
o`000000oooo0000000@0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo0000000<0?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooomL0oooo00<000000?ooo`3oool0o`3oooo60?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3o
ool000000?ooo`000000203oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000`3oool020000000oooo0?ooo`000000oooo0000003oool00000403oool00`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool0000000D0oooo00D000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonO0?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000
oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000>0?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`070000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0oooo00D0oooo000X
0?ooo`030000003oool0oooo0?l0oooof@3oool00`000000oooo0?ooo`3o0?oool@0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo
000000050?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00H0oooo00L000000?ooo`000000oooo0000003oool0000000h0oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<000000?ooo`000000203o
ool01@000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?oooj40oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo0?ooo`030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000H0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003o
ool0000000h0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0000000D0oooo00<000000?ooo`000000103oool00`000000oooo00000003
0?ooo`030000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0oooof`3oool00`00
0000oooo0?ooo`3o0?oool80oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool000000100oooo00<000000?ooo`0000001@3oool030000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`00
0000103oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo00000006
0?ooo`050000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooM
0?ooo`030000003oool0oooo0?l0oooo`03oool00`000000oooo000000050?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`000000oooo000000070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000002P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000P0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
1@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonQ0?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo0000
000@0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool0
0`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooO0?ooo`030000003oool0oooo
0?l0ooooT`3oool00`000000oooo0?ooo`0X0?ooo`070000003oool000000?ooo`000000oooo0000
00080?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`0>0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000060?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo
0000003oool0000000`0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooog@0oooo00<000000?ooo`3oool0:P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000`0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo00000006
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000D0oooo000X0?ooo`030000
003oool0oooo0?l0ooooh@3oool00`000000oooo0?ooo`3o0?ooohd0oooo00<000000?ooo`3oool0
;03oool02@000000oooo0000003oool000000?ooo`000000oooo0000000:0?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000003P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0000000h0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
1@3oool01@000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooT0?ooo`030000003oool0
oooo0?l0ooooR03oool00`000000oooo0?ooo`0^0?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000060?oo
o`050000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D0
00000?ooo`000000oooo0000000@0?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000001@3oool01@000000oooo0000003oool0000000@0oooo00<0
00000?ooo`0000001@3oool00`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo
00D000000?ooo`000000oooo000000050?ooo`00:03oool500000?l0ooooo`3ooooo0?oooil0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000203oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000`0oooo
00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool000000080oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooV0?ooo`030000003oool0oooo0?l0ooooQ03oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo000000080?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo00P0
00000?ooo`3oool000000?ooo`000000oooo000000h0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0o`3ooooX
0?ooo`030000003oool0oooo0?l0ooooO`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
000000<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003o
ool0oooo00P0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool00`00
0000oooo000000070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooofT0oooo00<00000
0?ooo`3oool0<@3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00L00000
0?ooo`000000oooo0000003oool0000000X0oooo00D000000?ooo`000000oooo000000070?ooo`04
0000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000H0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooonX0oooo00<000000?ooo`3oool0o`3ooomi0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool08P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
00H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo000000X0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooon`0oooo00<000000?ooo`3oool0o`3ooome0?ooo`03
0000003oool0oooo03D0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
0000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo0000000<0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000X0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooof<0oooo00<000000?ooo`3oool0=`3oool03@000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`060?ooo`070000003oool000000?ooo`000000oooo00000007
0?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000X0oooo00D000000?oo
o`000000oooo000000050?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo0000
00050?ooo`050000003oool0oooo0?ooo`0000002P3oool01`000000oooo0000003oool000000?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<00000
0?ooo`3oool0o`3oooo^0?ooo`030000003oool0oooo0?l0ooooK`3oool00`000000oooo0?ooo`0i
0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo
00<000000?ooo`0000000`3oool00`000000oooo000000060?ooo`0=0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`00
00002P3oool00`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000`3oool020000000oooo0?ooo`00
0000oooo0000003oool000000`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo
0?ooo`3o0?oooo00oooo00<000000?ooo`3oool0o`3ooom[0?ooo`030000003oool0oooo03/0oooo
00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
0000303oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00<000000?ooo`3oool01@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`000000oooo000000060?ooo`070000003o
ool0oooo0?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooonM0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000060?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`0:0000003oool0oooo
0000003oool000000?ooo`000000oooo000000P0oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`000000303oool00`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000070?ooo`030000003oool0oooo00P0oooo00L000000?ooo`000000
oooo0000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000050?ooo`00:03oool00`00
0000oooo0?ooo`3o0?oooo<0oooo00<000000?ooo`3oool0o`3ooomV0?ooo`030000003oool0oooo
03d0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`03
0000003oool0000000D0oooo00<000000?ooo`000000103oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`050000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo00<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000001`3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooe0?ooo`030000003oool0oooo0?l0ooooH@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01@3oool01@00
0000oooo0000003oool0000000P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool02000
0000oooo0?ooo`000000oooo0000003oool00000303oool00`000000oooo000000050?ooo`050000
003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomH0?ooo`030000003oool0oooo0480oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000060?ooo`030000003oool0
000000<0oooo00<000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
0`3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`000000303oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000103oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000
oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooooL0oooo00<0
00000?ooo`3oool0o`3ooomK0?ooo`030000003oool0oooo04@0oooo00d000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
0000000<0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool04P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000X0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooooT0oooo00<0
00000?ooo`3oool0o`3ooonM0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000
oooo0000000C0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?oooe@0oooo00<000000?ooo`3oool0@`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0
000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo000000030?ooo`050000003oool0
oooo0?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000P0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooook0?oo
o`030000003oool0oooo0?l0ooooD`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
01d0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0000000H0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`05
0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00X0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`0000001`3oool00`000000oooo000000040?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo@3o
ool00`000000oooo0?ooo`3o0?ooodl0oooo00<000000?ooo`3oool0BP3oool01@000000oooo0?oo
o`3oool0000000D0oooo00<000000?ooo`000000103oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000D0
oooo00<000000?ooo`3oool0103oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0000
00030?ooo`050000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?oo
o`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo00<000000?oo
o`3oool0o`3ooonG0?ooo`040000003oool0oooo000000<0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo
000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000<0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
0`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooCP3oool00`000000oooo0?oo
o`190?ooo`040000003oool0oooo000000<0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo0000000:0?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0
000000P0oooo00<000000?ooo`0000001@3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3oool20?ooo`030000003oool0oooo0?l0ooooA`3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo01/0oooo00L000000?ooo`3oool0oooo0000003oool0000000D0
oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool000000080
oooo00D000000?ooo`3oool0oooo0000000<0?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000P0oooo00D000000?ooo`000000oooo000000070?ooo`030000003oool0oooo00@0
oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
oooo1@3oool00`000000oooo0?ooo`3o0?oood40oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool0
00000`3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`00
0000oooo0000000<0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000P0oooo
00L000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3oool70?ooo`030000003oool0oooo0?l0ooooT`3oool00`000000oooo0?ooo`050?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0000003oool0000000D0oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000103o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo
000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom70?ooo`030000003o
ool0oooo0500oooo00@000000?ooo`3oool000000`3oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000303oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000003P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool000000?oo
o`0000001@3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo2@3oool00`00
0000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0F0?oo
o`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000080?ooo`030000003o
ool0000000D0oooo00<000000?ooo`3oool02P3oool01@000000oooo0000003oool0000000H0oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000P0oooo
00<000000?ooo`0000002P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`00
00001P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooo`/0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`030000003oool0oooo
0080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`000000103o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo00P0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0
000000H0oooo00D000000?ooo`000000oooo000000090?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`d0oooo00<0
00000?ooo`3oool0o`3ooolc0?ooo`030000003oool0oooo05L0oooo00d000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0oooo
00P0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool010000000oooo
0?ooo`0000070?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003oool0
oooo0?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo@@3oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool0
1`000000oooo0?ooo`3oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000060?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?oo
o`3oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
oooo3`3oool00`000000oooo0?ooo`3o0?oooh/0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000H0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo000000040?ooo`050000003oool000000?ooo`000000303oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000050?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo4@3oool00`000000oooo0?ooo`3o0?ooob/0
oooo00<000000?ooo`3oool0E03oool01@000000oooo0?ooo`3oool000000080oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000
003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`030000003oool0000000P0oooo00<000000?ooo`0000001@3oool0
0`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0203oool0
1@000000oooo0000003oool0000000L0oooo00P000000?ooo`3oool000000?ooo`000000oooo0000
00<0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0000000D0oooo00D00000
0?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0oooo4`3oool00`000000oooo0?ooo`3o0?ooobL0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0B0?ooo`0@0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?oo
o`3oool0oooo0000003oool0000000H0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?oo
o`3oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000`0oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00090?ooo`00:03oool500000?l0ooooo`3ooolD0?ooo`030000003oool0oooo0?l0ooooQ03oool0
1@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool01P3oool0
1`000000oooo0000003oool000000?ooo`000000203oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000
003oool0oooo00P0oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0oooo>P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo01<0oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0000000@0oooo
00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0000003oool000000`3oool0
0`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool0
1@000000oooo0000003oool0000000P0oooo00/000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo603oool00`000000oooo0?ooo`3o
0?oooad0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`030?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000050?oo
o`030000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000h0oooo00D000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
1@3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo6P3oool00`000000oooo0?ooo`3o0?ooogL0
oooo00<000000?ooo`3oool01P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool0
0`000000oooo0000000:0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool000000?oo
o`000000303oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000003@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooa`0
oooo00<000000?ooo`3oool0o`3ooolG0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool04@3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000H0oooo
00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`000000203oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00X0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool00`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooolN0?ooo`030000003oool0oooo0?l0oooo4`3oool00`000000oooo0?ooo`1S0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000060?oo
o`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool0103oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`000000203oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000007
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo00000007
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon;0?ooo`030000003oool0oooo
00l0oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo
000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0;0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000040?ooo`070000003oool00000
0?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo803oool0
0`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool0K03oool01`000000oooo0000003o
ool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0303oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3o
ool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo8P3oool00`000000oooo0?oo
o`3o0?ooofT0oooo00<000000?ooo`3oool0503oool01@000000oooo0000003oool0000000@0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo00@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`00000<0?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool0000000H0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00<000000?ooo`0000001`3oool01@000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
oooo9@3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<000000?ooo`3oool0I`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0000000X0oooo00<000000?ooo`0000001@3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`030000003oool0
oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000X0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00@0oooo00l000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolW0?ooo`03
0000003oool0oooo0?l0ooooIP3oool00`000000oooo0?ooo`0:0?ooo`0=0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?oo
o`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?oo
o`030?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03P3oool01@000000oooo0000003oool0000000D0
oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?oo
o`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0?oo
o`3oool000000?ooo`000000103oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolY0?ooo`030000003oool0oooo0?l0oooo0P3oool00`000000
oooo0?ooo`1/0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
203oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000001P3oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000P0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0000000H0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo:`3o
ool00`000000oooo0?ooo`3m0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0203o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000103oool00`000000oooo
000000030?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`080?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`3oool01@3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo;@3oool0
0`000000oooo0?ooo`3o0?ooofd0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000X0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000050?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool0
0`000000oooo000000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo:@3oool00`000000oooo0?ooo`1a0?oo
o`030000003oool0oooo00D0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0
000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`070000003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`000000
2P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0
oooo000000<0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0oooo;`3oool00`000000oooo0?ooo`3o0?ooof/0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000D0oooo00<000000?ooo`0000001P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool0203oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`04
0000003oool0oooo000000D0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00<0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000180oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooola0?ooo`030000003oool0oooo0?80oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000000P0oooo00<000000?ooo`0000001@3o
ool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool00P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
0000000<0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`000000oooo000000020?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooolc0?ooo`030000003oool0oooo0?l0ooooI`3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`00
00000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0303oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`03
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
=P3oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo07T0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000050?oo
o`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0
oooo0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000<0?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0?0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo>03o
ool00`000000oooo0?ooo`3o0?ooof80oooo00d000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0000
00040?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`070000003oool0oooo0?ooo`000000oooo0000000<0?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00L000000?oo
o`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000050?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`3U0?ooo`030000003o
ool0oooo07L0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000`3oool03P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool00`000000oooo0000
00070?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000`0
oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00<000000?ooo`3oool00`3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00D0
oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo?03oool00`000000oooo0?ooo`3o
0?oooeh0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000203oool02@000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`000000203oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`000000
303oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000001@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000D0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0
000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3oooln0?ooo`030000003oool0oooo
0=l0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo000000060?ooo`030000003oool0000000<0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0000003oool0000000D0oooo00D00000
0?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo0000000<0?ooo`03
0000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`000000203oool01@000000oooo0?ooo`3oool00000
00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooom00?ooo`030000003oool0oooo0?l0
ooooFP3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00D000000?ooo`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`000000303oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0000000@0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?oood80oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`1k0?oo
o`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000060?ooo`0;0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool0
00000?ooo`000000303oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000
203oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0
oooo00<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?ooo`000000
oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooA03oool00`000000oooo
0?ooo`3o0?oooe<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000000H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo
000000020?ooo`070000003oool0oooo0?ooo`000000oooo0000000<0?ooo`030000003oool00000
00<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo
000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooA`3oool00`000000oooo0?oo
o`3o0?oooe<0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0000000H0oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo00000005
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo0000000<0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00<000000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
B@3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo07H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`030000003oool0
oooo00@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`000000303oool00`000000oooo000000030?ooo`050000003oool0
oooo0?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000080?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`070000003oool0
00000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooB`3o
ool00`000000oooo0?ooo`3o0?ooodl0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?oo
o`3oool000000?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000002P3oool0
0`000000oooo0?ooo`0:0?ooo`070000003oool000000?ooo`000000oooo0000000<0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0000000D0
oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000T0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooom=0?ooo`030000003oool0oooo0<X0oooo
00<000000?ooo`3oool0O`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`000000303oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01@00
0000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0
oooo00<000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`3o
0?ooodP0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`0000001`3oool00`000000oooo000000020?ooo`030000003o
ool0000000D0oooo00<000000?ooo`3oool0103oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003o
ool00000303oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000D0oooo00<000000?ooo`000000103oool01@000000oooo0000
003oool0000000D0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0O@3oool00`000000oooo000000020?ooo`0=0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000001`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000D0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo
00D000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`030?ooo`00:03oool500000?l0ooooo`3ooomA0?ooo`030000003oool0oooo0?l0
ooooA`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo00000006
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000001P3oool01@000000oooo0000003o
ool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00X0oooo00D000000?ooo`000000oooo0000000:0?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo000000090?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooEP3oool00`000000oooo0?ooo`3o0?oood40oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000X0oooo
00<000000?ooo`0000000`3oool00`000000oooo000000060?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000<
0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000050?ooo`030000003oool000000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`00
000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooF03oool00`000000oooo0?ooo`2j
0?ooo`030000003oool0oooo0840oooo00@000000?ooo`3oool000000`3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo0000
00050?ooo`060000003oool0oooo0000003oool000001@3oool00`000000oooo000000040?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`07
0000003oool000000?ooo`000000oooo0000000<0?ooo`070000003oool0oooo0?ooo`000000oooo
000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`000000oooo
000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000D0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooomJ0?ooo`030000003oool0oooo0?l0oooo?@3oool01000
0000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`0=0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`3oool0oooo0000
00090?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0:0?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo
000000050?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooG03oool0
0`000000oooo0?ooo`3o0?oooc/0oooo00@000000?ooo`3oool000000`3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool0103oool01`000000oooo0000003oool000000?ooo`000000303oool02`000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000
00030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo000000050?ooo`030000
003oool0oooo00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?oooeh0oooo00<000000?ooo`3oool0/P3oool00`00
0000oooo0?ooo`230?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`000000oooo0000
003oool0000000P0oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00L000000?oo
o`3oool0oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000
003oool000000?ooo`000000303oool00`000000oooo000000050?ooo`030000003oool0000000@0
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooH03oool00`000000oooo0?ooo`3o0?ooocX0oooo00d000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`000000303oool01@000000oooo0000003o
ool0000000D0oooo00<000000?ooo`3oool00P3oool03@000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003o
ool0000000H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooHP3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0
oooo08P0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`000000
1P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`000000
1@3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000`0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool0
00000?ooo`000000oooo000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo00000003
0?ooo`030000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomT0?oo
o`040000003oool0oooo00000?l0oooo=@3oool03@000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01@000000
oooo0000003oool0000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo0000000<0?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000050?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooJ@3oool00`000000oooo0?ooo`3o0?oooc40
oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003oool000000?ooo`000000103oool0
0`000000oooo000000030?ooo`050000003oool000000?ooo`0000002P3oool01`000000oooo0000
003oool000000?ooo`000000103oool00`000000oooo000000070?ooo`050000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000h0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000D0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooom[0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3o
ool0RP3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
00001P3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo00000002
0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000`0oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`030000003oool0000000D0oooo00<000000?ooo`0000001P3oool01@000000oooo0000003o
ool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooom]0?ooo`030000003oool0
oooo0?l0oooo<@3oool01`000000oooo0000003oool000000?ooo`0000003P3oool01@000000oooo
0?ooo`3oool0000000P0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`000000303oool00`000000oooo000000030?ooo`030000003oool00000
00@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@00000
0?ooo`3oool000001`3oool00`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooofl0oooo00<00000
0?ooo`3oool0o`3oool_0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0203oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool01@000000oooo0000003oool0000000H0oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000`0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
00080?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`0000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooL@3oool0
0`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0900oooo00L000000?ooo`000000oooo0000
003oool0000000P0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0
oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0000003oool0000000D0oooo00<000000?ooo`000000103oool01`000000oooo0000
003oool000000?ooo`000000403oool00`000000oooo0?ooo`080?ooo`050000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooog<0oooo00<000000?ooo`3o
ool0o`3oool[0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000060?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000003P3oool01@000000oooo0000003oool0000000P0oooo00L000000?ooo`3oool0
oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooM@3o
ool010000000oooo0?ooo`00003o0?ooobH0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`000000303oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool00000
00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomj0?ooo`030000003oool0oooo0?l0
oooo903oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool01@000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
0000303oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooO03oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo09@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00L0
00000?ooo`3oool0oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000`0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooOP3oool00`000000oooo0?ooo`3o0?ooob00oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000001P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?oo
o`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0000
003oool000000080oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo00<0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooon00?ooo`030000003oool0oooo0?l0oooo7P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0
oooo0080oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`000000303oool00`000000oooo000000030?oo
o`050000003oool000000?ooo`000000203oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00`0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000050?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooPP3oool00`000000oooo000000230?ooo`030000003oool0
oooo09D0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0
00000180oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000050?oo
o`050000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooohL0oooo00<00000
0?ooo`3oool0o`3ooolG0?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo0000
00030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo0000000<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000
003oool000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooohT0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`050000003oool0oooo0?ooo`00
00003P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000070?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool000000100oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`030000003oool0000000L0oooo00<000000?ooo`00
0000203oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool030000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000D0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooon;0?ooo`030000003oool0oooo0?l0oooo5@3oool00`000000oooo000000030?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000030?ooo`0:0000003oool0
oooo0000003oool000000?ooo`000000oooo000000h0oooo00L000000?ooo`000000oooo0000003o
ool0000000P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooon=
0?ooo`030000003oool0000007H0oooo00<000000?ooo`3oool0V@3oool01`000000oooo0000003o
ool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000<0?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?oo
o`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooT@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`050000003oool000000?ooo`0000001@3oool01@000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00<0
00000?ooo`0000002@3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo0000000>0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oi<0oooo00<000000?ooo`3oool0o`3oool=0?ooo`070000003oool000000?ooo`000000oooo0000
00060?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`0;0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000003P3oool01@000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000h0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000
003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3o
ool01`000000oooo0?ooo`3oool000000?ooo`000000203oool00`000000oooo000000050?ooo`00
0P3oool4000000H0oooo0P0000070?ooo`@000003`3oool00`000000oooo0?ooo`3o0?ooool0oooo
U@3oool010000000oooo0?ooo`00003o0?ooo``0oooo00D000000?ooo`000000oooo000000060?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`0000003P3oool01`000000oooo0000003oool0
00000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo000000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000001@3oool00003
0?ooo`000000oooo00<0oooo00<000000?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooo`3ooonJ0?ooo`03
0000003oool0oooo0?l0oooo2P3oool00`000000oooo000000040?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`000000403oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00050?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`070000003oool0oooo0?oo
o`000000oooo000000050?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?oo
ool0ooooW03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo09d0oooo00D000000?oo
o`000000oooo000000040?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000001P3oool0
0`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000h0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`050000003oool000000?ooo`0000001`3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001@3oool000030?ooo`000000
oooo00<0oooo00<000000?ooo`3oool02`3oool2000000<0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`3o0?ooool0ooooWP3oool00`000000oooo0000003o0?ooo`@0oooo00D00000
0?ooo`000000oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`03
0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000`0oooo00/000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001@3o
ool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo
000000080?ooo`030000003oool0000000T0oooo00000`3oool000000?ooo`030?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`0000000P00000?0?ooo`L00000o`3ooooo0?oooih0oooo00<0
00000?ooo`3oool0o`3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000
oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000060?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000004P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?oo
o`070000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
1@3oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000D0oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`3o0?ooool0ooooY03oool00`000000oooo0?ooo`3m0?oo
o`030000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000>0?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooo`3ooonV0?ooo`040000003oool0
oooo00000?X0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00D0oooo
00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000002P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo0000000<0?ooo`070000003oool000000?ooo`00
0000oooo000000060?ooo`030000003oool0oooo00D0oooo00D000000?ooo`000000oooo00000004
0?ooo`030000003oool0000000L0oooo00D000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000070?ooo`0000<0oooo0000003oool00`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooooo0?oooj/0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000h0oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool01@000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000001`3oool00080oooo1000000A0?oo
o`<000003P3oool00`000000oooo0?ooo`3o0?ooool0oooo[@3oool00`000000oooo0000003f0?oo
o`030000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo
00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00X0oooo00/000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo0000000:0?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool01@000000oooo0000003o
ool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0oooo/@3oool00`000000oooo0?ooo`3b0?ooo`030000003oool0
000000H0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000
103oool01`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo000000030?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000`0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0
000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0oooo/`3oool00`000000oooo0000003`0?ooo`030000003oool0000000@0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000D0oooo00H000000?ooo`3oool000000?ooo`000003
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0000000H0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`0<0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000001@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?oookP0oooo00<000000?ooo`3oool0j`3oool00`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`0>0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0oooo^P3oool00`000000oooo0?ooo`3Y0?ooo`030000003oool0000000H0oooo00<0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0
oooo0000003oool0000000h0oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?oo
o`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0oooo_03oool00`000000oooo0000003Y0?ooo`030000003oool0oooo0080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo
000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool000000100oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0oooo`03oool00`000000oooo0?ooo`3U0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000050?ooo`040000003oool0oooo
000000<0oooo00D000000?ooo`000000oooo000000080?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo0000000@0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000D0oooo00<000000?ooo`000000203oool01@000000oooo0?ooo`3oool0000000D0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3oooo20?ooo`030000003oool0000003/0oooo00<00000
0?ooo`3oool0Y@3oool00`000000oooo0?ooo`020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
0000000@0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00D0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo
0000003oool000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooolH0oooo00<00000
0?ooo`3oool0g`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000203oool02@000000oooo0000003oool000000?ooo`000000oooo
000000060?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool0oooo0?ooo`000000oooo0000000@0?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooolT0oooo00<000000?ooo`000000g03oool00`000000oooo0?ooo`020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000H0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo0000000B0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool000000080oooo00<000000?ooo`0000001`3oool0
1@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000L0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3oooo=0?ooo`030000003oool000000=P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000>0?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo00000007
0?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooA0?ooo`030000003oool0oooo0=T0oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo0000000B0?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000050?ooo`070000003oool0oooo0?ooo`000000oooo000000020?oo
o`030000003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooC0?ooo`03
0000003oool000000=L0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
000000050?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0000003oool00000
0?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooomL0oooo00<000000?oo
o`3oool0d`3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo0000000>0?ooo`050000003oool000000?oo
o`0000000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00D000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooomX0oooo00<000000?ooo`000000d03oool00`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`00000:0?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool0000000H0oooo00<000000?ooo`000000303oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo
000000020?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool01P3oool01@000000oooo
0?ooo`3oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooN0?ooo`030000
003oool000000<T0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<0
00000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`080000003oool0oooo0000003oool000000?ooo`00000>0?ooo`030000003oool0000000<0oooo
00<000000?ooo`000000103oool01@000000oooo0000003oool0000000L0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000203oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooon80oooo00<000000?ooo`3oool0b03oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo
00<000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000h0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo00000009
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooi03oool00`000000oooo000000330?oo
o`030000003oool0oooo00@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00H0
00000?ooo`3oool000000?ooo`0000050?ooo`030000003oool0oooo00@0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000001P3oool01@000000oooo0000003o
ool0000000h0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000D0oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool000000?ooo`00
00001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooonT0oooo00<000000?ooo`000000
`@3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000001P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo0000000<0?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000002@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooond0oooo00<000000?ooo`3oool0_@3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo0000000@0?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
onl0oooo00<000000?ooo`000000^`3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
3P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`000000
1@3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooo<0oooo00<00000
0?ooo`000000203oool00`000000oooo0?ooo`2/0?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00<00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000`0oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00L00000
0?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
ooog0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`0000001@3oool00`000000oooo0000
00030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000303o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`080?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00<00000
0?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000002@3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooooX0oooo00<000000?ooo`000000/03oool01`000000oooo
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00<00000
0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`00000<0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000050?ooo`030000003oool0000000<0oooo00P000000?ooo`3oool0
00000?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo
00D000000?ooo`3oool0oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooon^0?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000`0oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oook00oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00L000000?oo
o`000000oooo0000003oool000000100oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0oooooP3oool00`000000oooo0?ooo`2^0?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool01P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000h0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000001`3oool002P0oooo1@00003o0?ooool0ooooo`3ooon^0?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo0000000>0?ooo`050000003oool000000?ooo`0000001@3oool010000000oooo0?oo
o`0000050?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oook80oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo0000000>0?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
ok00oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D00000
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000h0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon`0?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
0000403oool01`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0000000D0oooo
00D000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo00000005
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon`0?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo0000000D0?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3o
ool01@000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oook80oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00D000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000007
0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000T0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooonb0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000303oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000050?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0
000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oook80oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000D0oooo00@000000?oo
o`3oool000002@3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo
000000070?ooo`030000003oool000000100oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?oook80oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo0000000@0?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003o
ool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?oook80oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo
000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00000@0?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000060?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000030?ooo`030000003oool0000000D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?oook80oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000h0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0
oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`0000000`3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooonb0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`00000>0?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000001@3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0oooo]03oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000003P3oool01@000000oooo0?ooo`3oool0000000<0oooo0180
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`030000003oool0000000D0oooo00D000000?ooo`000000oooo00000006
0?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3oool10?ooo`030000003oool0oooo0;00oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<00000
0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000003P3oool01`000000oooo
0?ooo`3oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`05
0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo
000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooond0?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@00
0000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000h0oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001P3oool00`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo]03o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo0000000>0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo
0000003oool0000000@0oooo00D000000?ooo`000000oooo000000070?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooond0?ooo`050000003oool000000?ooo`0000000`3oool03P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool0oooo0?ooo`000000403oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
1P000000oooo0?ooo`000000oooo000000L0oooo00<000000?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooond0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool01@3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`030000003oool0000000D0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?oook@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo0000000<0?ooo`030000003oool00000
00<0oooo00<000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0000003oool0000000T0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?oook@0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000h0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000L0oooo
00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00L0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooo`<0oooo00<000000?ooo`3oool0/03oool00`000000oooo
000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00@0oooo00D000000?ooo`000000oooo0000000>0?ooo`070000003oool0oooo0?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool01P3o
ool01`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0oooo]P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool000000100oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo
00<000000?ooo`0000001@3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooonf0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo000000060?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool00000
0180oooo00<000000?ooo`0000001P3oool00`000000oooo000000030?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000070?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooonf0?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`00
00030?ooo`030000003oool000000100oooo00L000000?ooo`000000oooo0000003oool0000000X0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonf0?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0
oooo00`0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000050?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003oool0
oooo0?ooo`0000001`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool50?ooo`030000
003oool0oooo0:h0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool000000100oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00`000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`0000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooonf0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3o
ool0oooo0000003oool000000100oooo00D000000?ooo`000000oooo000000040?ooo`0?0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooonf0?ooo`050000003oool000000?ooo`000000103o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000003P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3o
ool00`000000oooo000000050?ooo`030000003oool0000000H0oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
oooo^03oool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003o
ool0000000h0oooo00D000000?ooo`3oool0oooo000000030?ooo`0<0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000`3oool00`000000oooo000000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0000003oool0000000T0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oookP0oooo00D000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000B0?ooo`050000003oool0
00000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`000000103oool01@000000oooo0000003oool0000000T0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooo`L0oooo00<000000?ooo`3oool0[P3oool01@000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00060?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000h0oooo00D000000?ooo`000000oooo0000
00030?ooo`080000003oool0oooo0000003oool000000?ooo`0000050?ooo`050000003oool00000
0?ooo`0000000P3oool00`000000oooo000000050?ooo`070000003oool0oooo0?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?oookP0oooo00D000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000h0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000030?ooo`030000
003oool000000080oooo00<000000?ooo`0000001@3oool01`000000oooo0000003oool000000?oo
o`0000001P3oool01@000000oooo0?ooo`3oool0000000D0oooo000X0?ooo`D00000o`3ooooo0?oo
ool0oooo]P3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?oo
o`000000303oool01`000000oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?oo
o`000000oooo000000D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000001@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo`T0oooo
00<000000?ooo`3oool0[03oool01@000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000h0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000L0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonh0?ooo`05
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00H0oooo00L000000?ooo`3oool0oooo0000003oool0000000h0oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001@3oool01@000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool00000
00@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooonj0?ooo`030000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000003P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000090?ooo`030000003oool000000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0oooo^P3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0B0?ooo`070000003oool0oooo
0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooo303oool00`000000oooo0?ooo`2Y0?ooo`050000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000h0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo
00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?oookP0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000003P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool03`000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000001P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oookP0oooo
00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000000B0?ooo`030000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
0000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000001@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0oooo3P3oool00`000000oooo0?ooo`2W0?ooo`050000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0303oool02@000000oooo
0000003oool000000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool00000
00H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00<0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?oookH0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000002@3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0000000h0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooonf0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000
oooo0000003oool00000403oool00`000000oooo000000060?ooo`030000003oool0000000D0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000005
0?ooo`050000003oool000000?ooo`000000103oool00`000000oooo000000090?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3oool@0?ooo`030000003oool0oooo0:<0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`0@0?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001`3oool01@000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool00000
0?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonf0?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool00`000000oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool000000100oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo4P3oool00`000000oooo
0?ooo`2O0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000h0oooo00L000000?ooo`000000oooo0000003oool00000
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000D0oooo00D000000?ooo`000000oooo000000040?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?oook@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000003P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo]03oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000h0oooo00L00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`07
0000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo503oool00`00
0000oooo0?ooo`2K0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo0000000>0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`3oool01@3oool01@000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool000000?ooo`00
00002P3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooonb0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo0000000B0?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000`0oooo00<000000?ooo`0000001@3oool00`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000070?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooolF0?ooo`030000003oool0oooo09T0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`0<0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool000000?ooo`0000001`3oool00`000000oooo000000080?ooo`030000003o
ool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oook80oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000003P3oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`0000002@3o
ool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000050?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolH0?ooo`030000003oool0oooo09D0oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003o
ool000000?ooo`000000oooo000000050?ooo`030000003oool0000000H0oooo00<000000?ooo`00
00003P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo/03oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo
0000000@0?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool02`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooa/0oooo00<000000?ooo`3oool0TP3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000H0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000h0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000
003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo[P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo0000000>0?ooo`050000003oool0oooo0?ooo`000000
0`3oool010000000oooo0?ooo`0000030?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00`3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo7@3oool00`000000oooo0?ooo`2>0?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`3oool0oooo0000003oool000000180oooo00D000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo
0000003oool0000000H0oooo00<000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0oooo[P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000003P3oool01`000000oooo0?ooo`3o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0000000P0oooo00D000000?ooo`3oool0oooo000000070?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooolO0?ooo`030000003oool0oooo08T0oooo018000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool000000100oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000001@3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`0B0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000003P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo8@3oool00`00
0000oooo0?ooo`2:0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`070000003oool000000?ooo`000000oooo0000000>0?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool0000000`0oooo00D000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000D0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo
00L000000?ooo`3oool0oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooojT0oooo00<000000?ooo`3oool00P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000`0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`06
0000003oool0oooo0000003oool000001@3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooob<0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?oo
o`020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
3P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000103o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool0oooo0?ooo`000000oooo0000000>0?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00L00000
0?ooo`3oool0oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool00000
00L0oooo000X0?ooo`D00000o`3ooooo0?ooool0ooooY`3oool00`000000oooo0?ooo`020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000003P3oool01`000000oooo0?ooo`3oool00000
0?ooo`000000103oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`060?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooolU0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`00
0000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000h0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003o
ool0oooo0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobL0oooo00<00000
0?ooo`3oool0O@3oool00`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool00000
0100oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00/0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooojL0oooo00<000000?ooo`000000103oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00D000000?ooo`000000oooo0000000>0?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool000000?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`000000103oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooolY0?ooo`030000003oool0oooo07T0oooo00D000000?ooo`000000
oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
0000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo;03oool00`000000oooo
0?ooo`1f0?ooo`050000003oool000000?ooo`000000103oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`0<0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0oooo00D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000001`3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000L0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?oooj<0oooo00L000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000<0oooo
00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00040?ooo`050000003oool000000?ooo`000000403oool01`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3oool^0?ooo`030000003oool0oooo0780oooo00L000000?ooo`000000oooo0000003oool0
000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000H0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000
1P3oool00`000000oooo0000000<0?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00D000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000D0oooo00<000000?ooo`000000203oool01@00
0000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
oc00oooo00<000000?ooo`3oool0L03oool01`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`000000403oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`000000103o
ool00`000000oooo000000050?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
ooooX@3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000h0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000001P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0oooo0?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooc80oooo00<000000?ooo`3oool0K03o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000h0oooo00<000000?ooo`3oool00`3oool00`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`0000002P3oool00`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo=03oool00`00
0000oooo0?ooo`1X0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00001P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003o
ool0oooo0000003oool000000?ooo`000000oooo000000`0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonQ0?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000h0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
=P3oool00`000000oooo0?ooo`1T0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool00`000000oooo0000000B0?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000001`3oool00`000000
oooo0?ooo`020?ooo`050000003oool000000?ooo`0000001`3oool00`000000oooo0?ooo`020?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooocP0oooo00<000000?ooo`3oool0HP3oool03@000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`000000203oool00`000000oooo0000000B0?ooo`050000
003oool0oooo0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
1@000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0000
00060?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooolj0?ooo`030000003oool0oooo0600oooo00/000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo000000080?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000@0?oo
o`050000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool0
00000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000D0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
oiX0oooo00@000000?ooo`3oool000000`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000080?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo0000000@0?ooo`030000003oool0000000<0oooo00H0
00000?ooo`3oool000000?ooo`0000050?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000001@3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo?@3o
ool00`000000oooo0?ooo`1J0?ooo`040000003oool0oooo000000<0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000001@0oooo00D0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0
oooo00@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001@3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0oooo?`3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00080?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
1@000000oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000h0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`040000003oool0oooo000000<0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool0000000P0oooo00D000000?ooo`000000oooo000000050?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooom10?ooo`030000003oool0oooo0580oooo00D000000?ooo`3o
ool0oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000@0?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0000000D0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oood<0oooo00<000000?ooo`3oool0E03o
ool010000000oooo0?ooo`0000030?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000h0oooo00D000000?ooo`000000
oooo000000030?ooo`040000003oool0oooo000000L0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00H0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooA@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool000000`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool02P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`070000003oool000000?ooo`000000
oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom70?ooo`030000
003oool0oooo05<0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?oo
o`0000001P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000h0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?oooid0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool0000000H0oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`000000403oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`000000
0`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000001@3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooB@3oool00`000000oooo0?ooo`1A0?ooo`0=
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<00000
0?ooo`0000001@3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000001@3o
ool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00`0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000H0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oood`0oooo
00<000000?ooo`3oool0CP3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00X0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo0?ooo`030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooom>0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`0000002P3oool03@000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool000000180oooo00D000000?ooo`000000oooo000000040?ooo`03
0000003oool0oooo00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oom@0?ooo`030000003oool0oooo03P0oooo00@000000?ooo`3oool000003P3oool03@000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo0000000@0?ooo`050000003oool000000?ooo`000000103o
ool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000<0oooo00H00000
0?ooo`3oool000000?ooo`0000050?ooo`070000003oool0oooo0?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000070?ooo`000P3oool4000000H0oooo0P000006
0?ooo`@00000403oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomB0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`0000030?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo0000000>0?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool03@00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001@3oool000030?ooo`000000oooo00<0oooo00<00000
0?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooe@0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000>0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000001@3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooEP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
0000000<0?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000D0oooo00000`3oool000000?ooo`03
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=
0?ooo`L00000o`3ooooo0?ooool0ooooE03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo01L0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000003P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
1`3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool02`3oool400000100oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooFP3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo01T0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo0000000<0?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000001P3oool00`000000oooo000000050?ooo`070000003oool0oooo0?ooo`00
0000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`03
0?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomM0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool0
00000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000
oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000h0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`00
0000oooo0?ooo`030?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooomO0?ooo`030000003oool0oooo03/0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00003P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`030000003oool0oooo00<0oooo00000`3oool000000?ooo`030?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooof40oooo00<000000?ooo`0000006@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool000000080oooo00l000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000@0oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000003P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?oo
o`3oool000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool020000000oooo
0?ooo`000000oooo0000003oool000000`3oool01@000000oooo0000003oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000090?ooo`000P3oool4000000h0oooo1000000@0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooofD0oooo00<000000?ooo`3oool0<P3oool010000000oooo0?oo
o`0000030?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L00000
0?ooo`000000oooo0000003oool0000000`0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000050?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomW0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0803oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
000@0?ooo`030000003oool0000000H0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooofT0oooo
00<000000?ooo`3oool0;P3oool010000000oooo0?ooo`0000030?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo0180oooo00D000000?oo
o`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom[0?ooo`030000003o
ool0oooo02`0oooo00@000000?ooo`3oool000000`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`000000303oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000
003oool0oooo0?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool0
0`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooofh0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo000000<0oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
0000403oool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000001@3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000001`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000002@3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooL03oool00`000000oooo0000000Z0?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo0000000>0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0
00000`3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooomd0?ooo`030000003oool0oooo02H0oooo00d000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
4P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool03`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooooMP3oool00`000000oooo0?ooo`0T0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`0:0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001@3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0ooooW@3oool03@000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000
oooo0000000@0?ooo`030000003oool0000000H0oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooid0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00D000000?oo
o`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooX@3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000h0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000/0oooo00`000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`0000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooomh0?ooo`030000003oool0oooo02H0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000>0?ooo`030000003o
ool0000000<0oooo00<000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
00001@3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonQ0?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000h0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool01@000000oooo0?ooo`3oool00000
00H0oooo00D000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooonQ0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000`0oooo00/000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000005
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooX@3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool00000
3P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000D0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooNP3oool00`000000oooo0?ooo`0R0?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000001P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo0000
000<0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000
003oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool0
1`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooX@3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo00`000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000060?ooo`050000003oool000000?ooo`00
00000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000003P3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00P000000?oo
o`3oool000000?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooO@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0000000<0oooo00<000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
0000503oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`00
00001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooX@3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool0103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000004P3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooooO`3oool00`000000oooo0?ooo`0O0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000<
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooP@3oool00`000000oooo0?ooo`0M0?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000003P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo
0000003oool000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooX@3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooP`3oool00`000000oooo0?ooo`0K0?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000`0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000070?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0
000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooohD0oooo00<000000?oo
o`3oool05`3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000003P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00D000000?oo
o`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon70?ooo`030000003oool0
oooo01L0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003o
ool000000?ooo`000000oooo00000100oooo00<000000?ooo`0000000`3oool01P000000oooo0?oo
o`000000oooo000000<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooW@3oool03@000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000H0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool000000100oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
00001@3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooohT0oooo00<00000
0?ooo`3oool03P3oool010000000oooo0?ooo`0000030?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo0000000<0?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000001@3oool002P0oooo1@00003o0?ooool0ooooo`3ooon90?oo
o`030000003oool0oooo00`0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000001P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000`0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooohh0oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000001P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000`0oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`05
0000003oool000000?ooo`0000001P3oool00`000000oooo000000090?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooon@0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3o
ool000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000h0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01`000000oooo0?oo
o`3oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooTP3oool00`000000oooo0?ooo`050?oo
o`040000003oool0oooo000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000<0?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`00
0000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooVP3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000h0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?oooi@0oooo00<000000?ooo`3oool01P3oool03@000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000003P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00`3oool02P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`0000070?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooonF0?ooo`030000003oool0oooo00@0oooo00d000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00X0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000<0oooo
00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000050?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonH0?ooo`030000003oool000000080oooo00d0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<0
00000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`000000403oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonJ0?ooo`040000003oool0oooo0000
00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo0000000<0?ooo`0;0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonJ
0?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000`0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo000000030?ooo`030000003oool0000000D0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?oooid0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000h0oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0
oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooil0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000`0oooo00D000000?ooo`000000oooo0000
00050?ooo`080000003oool0oooo0000003oool000000?ooo`0000050?ooo`050000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000D0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?oooj40oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000001P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000403oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00001@3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonQ0?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000003P3oool01`000000oooo0000003oool000000?ooo`000000103o
ool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000000D0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?oooj<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`000000303oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000050?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`00
00001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooY@3oool01@000000oooo
0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool0000000@0oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000003P3o
ool01`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000001@3oool00`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo
000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonW0?ooo`030000003o
ool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0303oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0000000H0oooo00<000000?ooo`0000001@3oool00`00
0000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonY0?ooo`03
0000003oool0oooo0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000303o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooonY0?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`0B0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000003P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0
00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooojh0oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`000000403oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00040?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooon`0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000<0?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?oook80oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo0000000<0?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonb0?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool000000100oooo00<000000?ooo`0000001@3oool030000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?oo
o`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooond0?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`00000<0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?oookH0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000`0oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oookP0oooo00D000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000<0?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0oooo^P3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
0000000@0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
oooo^P3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000<
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooonl0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000h0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
1P3oool01@000000oooo0?ooo`3oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oookl0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000`0oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0000
00030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000D0oooo000X0?ooo`D00000o`3ooooo0?ooool0oooo_`3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000`0oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oool<0oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000003P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3oooo30?ooo`070000003oool000000?ooo`000000oooo0000
00040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000h0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
a@3oool01@000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000003P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000030?ooo`080000003oool0
oooo0000003oool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooolL0oooo00<000000?ooo`000000103oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo0000000>0?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000070?ooo`030000003oool00000
00H0oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooolT0oooo00<000000?ooo`3oool00P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo0000000<0?ooo`030000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo00000005
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo;0?ooo`0@0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00L0
00000?ooo`000000oooo0000003oool0000000h0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
1`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooob`3oool04P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00L000000?ooo`000000oooo0000003oool0000000`0oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooolh0oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`000000303oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`00
00001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooood03oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`000000303oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooodP3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000`0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooe03oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000<0?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooooe03oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo0000000<0?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo00000005
0?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooeP3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`000000303oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooH0?ooo`050000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`000000303oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
omX0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000303o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooooL0?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000h0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000D0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooom`0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000303oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000050?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?oooml0oooo00L000000?ooo`000000oooo0000003oool0000000`0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
ooooh@3oool01@000000oooo0000003oool0000000`0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
on<0oooo00<000000?ooo`000000303oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000070?ooo`030000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooi@3oool00`000000oooo0?ooo`0:0?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooonD0oooo00<000000?ooo`3oool0203oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooooW0?ooo`030000003oool0oooo00H0oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooooY0?ooo`050000003oool0oooo0?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooooj`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?oo
o`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooool03oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000
oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooond0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool00`000000oooo000000030?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooo00oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0oooolP3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?oooo@0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000050?ooo`00:03oool500000?l0ooooo`3ooooo0?oooo@0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooof0?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool00000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`030000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooooP0
oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`0000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooj
0?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooool0?ooo`0B
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooo`3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooo`80oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo103oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo1P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooooo0?ooo`P0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooool0oooo203oool01`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool:0?ooo`050000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool<0?ooo`030000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo3P3oool020000000oooo0?ooo`000000
oooo0000003oool000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooooo0?oooa40oooo00D000000?ooo`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo4@3o
ool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolC0?ooo`030000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolE
0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooooo0?oooaL0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooaT0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolI0?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo6`3oool01@00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolM0?ooo`030000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolO0?ooo`0<0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000001@3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooo`3ooolR0?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo8P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooooo0?ooob@0oooo00L000000?ooo`000000oooo0000003oool00000
00D0oooo000C0?ooo`L000003P3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooobH0
oooo00D000000?ooo`000000oooo000000050?ooo`005P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo:03oool00`000000oooo000000050?ooo`00
5P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo
:03oool00`000000oooo000000050?ooo`005P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooool0oooo:P3oool00`000000oooo0?ooo`030?ooo`005P3oool0
0`000000oooo0?ooo`0?0?ooo`L00000o`3ooooo0?ooool0ooooo`3oool/0?ooo`005P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool001H0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00
oooo000D0?ooo`<000004@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo
000F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3o
ool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool00?l0ooooo`3ooooo0?oo
ool0ooooF`3oool00?l0ooooo`3ooooo0?ooool0ooooF`3oool00?l0ooooo`3ooooo0?ooool0oooo
F`3oool00?l0ooooo`3ooooo0?ooool0ooooF`3oool00?l0ooooo`3ooooo0?ooool0ooooF`3oool0
0?l0ooooo`3ooooo0?ooool0ooooF`3oool00?l0ooooo`3ooooo0?ooool0ooooF`3oool00?l0oooo
o`3ooooo0?ooool0ooooF`3oool00001\
\>"],
  ImageRangeCache->{{{0, 1110.13}, {685.688, 0}} -> {-0.0378501, -0.0556469, \
0.00140806, 0.0023921}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BifuractionDiagram[CircleMap[r], \ {r, 0, 1}];\)\)], "Input",
  CellLabel->"In[52]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.0147151 0.58861 [
[.2 .00222 -9 -9 ]
[.2 .00222 9 0 ]
[.4 .00222 -9 -9 ]
[.4 .00222 9 0 ]
[.6 .00222 -9 -9 ]
[.6 .00222 9 0 ]
[.8 .00222 -9 -9 ]
[.8 .00222 9 0 ]
[1 .00222 -3 -9 ]
[1 .00222 3 0 ]
[-0.0125 .13244 -18 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .25016 -18 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .36788 -18 -4.5 ]
[-0.0125 .36788 0 4.5 ]
[-0.0125 .4856 -18 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .01472 m
.2 .02097 L
s
[(0.2)] .2 .00222 0 1 Mshowa
.4 .01472 m
.4 .02097 L
s
[(0.4)] .4 .00222 0 1 Mshowa
.6 .01472 m
.6 .02097 L
s
[(0.6)] .6 .00222 0 1 Mshowa
.8 .01472 m
.8 .02097 L
s
[(0.8)] .8 .00222 0 1 Mshowa
1 .01472 m
1 .02097 L
s
[(1)] 1 .00222 0 1 Mshowa
.125 Mabswid
.05 .01472 m
.05 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.15 .01472 m
.15 .01847 L
s
.25 .01472 m
.25 .01847 L
s
.3 .01472 m
.3 .01847 L
s
.35 .01472 m
.35 .01847 L
s
.45 .01472 m
.45 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.55 .01472 m
.55 .01847 L
s
.65 .01472 m
.65 .01847 L
s
.7 .01472 m
.7 .01847 L
s
.75 .01472 m
.75 .01847 L
s
.85 .01472 m
.85 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.95 .01472 m
.95 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
0 .13244 m
.00625 .13244 L
s
[(0.2)] -0.0125 .13244 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(0.4)] -0.0125 .25016 1 0 Mshowa
0 .36788 m
.00625 .36788 L
s
[(0.6)] -0.0125 .36788 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(0.8)] -0.0125 .4856 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
0 .01472 Mdot
.002 .01472 Mdot
.004 .01475 Mdot
.006 .0148 Mdot
.008 .01487 Mdot
.01 .01495 Mdot
.012 .01505 Mdot
.014 .01518 Mdot
.016 .01532 Mdot
.018 .01548 Mdot
.02 .01566 Mdot
.022 .01585 Mdot
.024 .01607 Mdot
.026 .0163 Mdot
.028 .01656 Mdot
.03 .01683 Mdot
.032 .01712 Mdot
.034 .01742 Mdot
.036 .01775 Mdot
.038 .0181 Mdot
.04 .01846 Mdot
.042 .01884 Mdot
.044 .01924 Mdot
.046 .01966 Mdot
.048 .02009 Mdot
.05 .02054 Mdot
.052 .02101 Mdot
.054 .0215 Mdot
.056 .02201 Mdot
.058 .02253 Mdot
.06 .02307 Mdot
.062 .02363 Mdot
.064 .0242 Mdot
.066 .0248 Mdot
.068 .0254 Mdot
.07 .02603 Mdot
.072 .02667 Mdot
.074 .02733 Mdot
.076 .02801 Mdot
.078 .0287 Mdot
.08 .02941 Mdot
.082 .03013 Mdot
.084 .03087 Mdot
.086 .03163 Mdot
.088 .0324 Mdot
.09 .03319 Mdot
.092 .03399 Mdot
.094 .03481 Mdot
.096 .03564 Mdot
.098 .03649 Mdot
.1 .03735 Mdot
.102 .03823 Mdot
.104 .03912 Mdot
.106 .04003 Mdot
.108 .04095 Mdot
.11 .04189 Mdot
.112 .04284 Mdot
.114 .0438 Mdot
.116 .04478 Mdot
.118 .04577 Mdot
.12 .04677 Mdot
.122 .04779 Mdot
.124 .04882 Mdot
.126 .04986 Mdot
.128 .05092 Mdot
.13 .05199 Mdot
.132 .05307 Mdot
.134 .05416 Mdot
.136 .05526 Mdot
.138 .05638 Mdot
.14 .05751 Mdot
.142 .05865 Mdot
.144 .0598 Mdot
.146 .06096 Mdot
.148 .06213 Mdot
.15 .06332 Mdot
.152 .06451 Mdot
.154 .06571 Mdot
.156 .06693 Mdot
.158 .06816 Mdot
.16 .06939 Mdot
.162 .07063 Mdot
.164 .07189 Mdot
.166 .07315 Mdot
.168 .07443 Mdot
.17 .07571 Mdot
.172 .077 Mdot
.174 .0783 Mdot
.176 .07961 Mdot
.178 .08092 Mdot
.18 .08225 Mdot
.182 .08358 Mdot
.184 .08492 Mdot
.186 .08627 Mdot
.188 .08762 Mdot
.19 .08899 Mdot
.192 .09036 Mdot
.194 .09173 Mdot
.196 .09312 Mdot
.198 .09451 Mdot
.2 .0959 Mdot
.202 .09731 Mdot
.204 .09871 Mdot
.206 .10013 Mdot
.208 .10155 Mdot
.21 .10298 Mdot
.212 .10441 Mdot
.214 .10585 Mdot
.216 .10729 Mdot
.218 .10873 Mdot
.22 .11019 Mdot
.222 .11164 Mdot
.224 .1131 Mdot
.226 .11457 Mdot
.228 .11604 Mdot
.23 .11751 Mdot
.232 .11899 Mdot
.234 .12047 Mdot
.236 .12196 Mdot
.238 .12344 Mdot
.24 .12494 Mdot
.242 .12643 Mdot
.244 .12793 Mdot
.246 .12943 Mdot
.248 .13093 Mdot
.25 .13244 Mdot
.252 .13395 Mdot
.254 .13546 Mdot
.256 .13697 Mdot
.258 .13848 Mdot
.26 .14 Mdot
.262 .14152 Mdot
.264 .14304 Mdot
.266 .14456 Mdot
.268 .14608 Mdot
.27 .1476 Mdot
.272 .14913 Mdot
.274 .15065 Mdot
.276 .15218 Mdot
.278 .15371 Mdot
.28 .15524 Mdot
.282 .15676 Mdot
.284 .15829 Mdot
.286 .15982 Mdot
.288 .16135 Mdot
.29 .16288 Mdot
.292 .16441 Mdot
.294 .16594 Mdot
.296 .16747 Mdot
.298 .169 Mdot
.3 .17052 Mdot
.302 .17205 Mdot
.304 .17358 Mdot
.306 .1751 Mdot
.308 .17663 Mdot
.31 .17815 Mdot
.312 .17967 Mdot
.314 .1812 Mdot
.316 .18272 Mdot
.318 .18424 Mdot
.32 .18575 Mdot
.322 .18727 Mdot
.324 .18878 Mdot
.326 .1903 Mdot
.328 .19181 Mdot
.33 .19332 Mdot
.332 .19482 Mdot
.334 .19633 Mdot
.336 .19783 Mdot
.338 .19933 Mdot
.34 .20083 Mdot
.342 .20233 Mdot
.344 .20382 Mdot
.346 .20531 Mdot
.348 .2068 Mdot
.35 .20828 Mdot
.352 .20977 Mdot
.354 .21125 Mdot
.356 .21273 Mdot
.358 .2142 Mdot
.36 .21567 Mdot
.362 .21714 Mdot
.364 .21861 Mdot
.366 .22007 Mdot
.368 .22153 Mdot
.37 .22299 Mdot
.372 .22444 Mdot
.374 .22589 Mdot
.376 .22734 Mdot
.378 .22878 Mdot
.38 .23022 Mdot
.382 .23166 Mdot
.384 .23309 Mdot
.386 .23452 Mdot
.388 .23594 Mdot
.39 .23737 Mdot
.392 .23878 Mdot
.394 .2402 Mdot
.396 .24161 Mdot
.398 .24301 Mdot
.4 .24442 Mdot
.402 .24582 Mdot
.404 .24721 Mdot
.406 .2486 Mdot
.408 .24999 Mdot
.41 .25137 Mdot
.412 .25275 Mdot
.414 .25412 Mdot
.416 .25549 Mdot
.418 .25686 Mdot
.42 .25822 Mdot
.422 .25958 Mdot
.424 .26093 Mdot
.426 .26228 Mdot
.428 .26363 Mdot
.43 .26497 Mdot
.432 .2663 Mdot
.434 .26763 Mdot
.436 .26896 Mdot
.438 .27028 Mdot
.44 .2716 Mdot
.442 .27292 Mdot
.444 .27422 Mdot
.446 .27553 Mdot
.448 .27683 Mdot
.45 .27813 Mdot
.452 .27942 Mdot
.454 .2807 Mdot
.456 .28199 Mdot
.458 .28326 Mdot
.46 .28454 Mdot
.462 .28581 Mdot
.464 .28707 Mdot
.466 .28833 Mdot
.468 .28958 Mdot
.47 .29083 Mdot
.472 .29208 Mdot
.474 .29332 Mdot
.476 .29455 Mdot
.478 .29579 Mdot
.48 .29701 Mdot
.482 .29823 Mdot
.484 .29945 Mdot
.486 .30066 Mdot
.488 .30187 Mdot
.49 .30308 Mdot
.492 .30427 Mdot
.494 .30547 Mdot
.496 .30666 Mdot
.498 .30784 Mdot
.5 .30902 Mdot
.502 .31019 Mdot
.504 .31137 Mdot
.506 .31253 Mdot
.508 .31369 Mdot
.51 .31485 Mdot
.512 .316 Mdot
.514 .31715 Mdot
.516 .31829 Mdot
.518 .31942 Mdot
.52 .32056 Mdot
.522 .32168 Mdot
.524 .32281 Mdot
.526 .32393 Mdot
.528 .32504 Mdot
.53 .32615 Mdot
.532 .32725 Mdot
.534 .32835 Mdot
.536 .32945 Mdot
.538 .33054 Mdot
.54 .33163 Mdot
.542 .33271 Mdot
.544 .33378 Mdot
.546 .33486 Mdot
.548 .33592 Mdot
.55 .33699 Mdot
.552 .33804 Mdot
.554 .3391 Mdot
.556 .34015 Mdot
.558 .34119 Mdot
.56 .34223 Mdot
.562 .34327 Mdot
.564 .3443 Mdot
.566 .34532 Mdot
.568 .34635 Mdot
.57 .34736 Mdot
.572 .34838 Mdot
.574 .34938 Mdot
.576 .35039 Mdot
.578 .35139 Mdot
.58 .35238 Mdot
.582 .35337 Mdot
.584 .35436 Mdot
.586 .35534 Mdot
.588 .35632 Mdot
.59 .35729 Mdot
.592 .35826 Mdot
.594 .35922 Mdot
.596 .36018 Mdot
.598 .36114 Mdot
.6 .36209 Mdot
.602 .36304 Mdot
.604 .36398 Mdot
.606 .36492 Mdot
.608 .36585 Mdot
.61 .36678 Mdot
.612 .36771 Mdot
.614 .36863 Mdot
.616 .36955 Mdot
.618 .37046 Mdot
.62 .37137 Mdot
.622 .37227 Mdot
.624 .37317 Mdot
.626 .37407 Mdot
.628 .37496 Mdot
.63 .37585 Mdot
.632 .37674 Mdot
.634 .37762 Mdot
.636 .37849 Mdot
.638 .37936 Mdot
.64 .38023 Mdot
.642 .3811 Mdot
.644 .38196 Mdot
.646 .38281 Mdot
.648 .38366 Mdot
.65 .38451 Mdot
.652 .38535 Mdot
.654 .38619 Mdot
.656 .38703 Mdot
.658 .38786 Mdot
.66 .38869 Mdot
.662 .38952 Mdot
.664 .39034 Mdot
.666 .39115 Mdot
.668 .39197 Mdot
.67 .39278 Mdot
.672 .39358 Mdot
.674 .39438 Mdot
.676 .39518 Mdot
.678 .39598 Mdot
.68 .39677 Mdot
.682 .39755 Mdot
.684 .39834 Mdot
.686 .39912 Mdot
.688 .39989 Mdot
.69 .40066 Mdot
.692 .40143 Mdot
.694 .4022 Mdot
.696 .40296 Mdot
.698 .40372 Mdot
.7 .40447 Mdot
.702 .40522 Mdot
.704 .40597 Mdot
.706 .40671 Mdot
.708 .40745 Mdot
.71 .40819 Mdot
.712 .40892 Mdot
.714 .40965 Mdot
.716 .41038 Mdot
.718 .4111 Mdot
.72 .41182 Mdot
.722 .41254 Mdot
.724 .41325 Mdot
.726 .41396 Mdot
.728 .41466 Mdot
.73 .41537 Mdot
.732 .41607 Mdot
.734 .41676 Mdot
.736 .41746 Mdot
.738 .41814 Mdot
.74 .41883 Mdot
.742 .41951 Mdot
.744 .42019 Mdot
.746 .42087 Mdot
.748 .42154 Mdot
.75 .42221 Mdot
.752 .42288 Mdot
.754 .42355 Mdot
.756 .42421 Mdot
.758 .42486 Mdot
.76 .42552 Mdot
.762 .42617 Mdot
.764 .42682 Mdot
.766 .42746 Mdot
.768 .42811 Mdot
.77 .42875 Mdot
.772 .42938 Mdot
.774 .43002 Mdot
.776 .43065 Mdot
.778 .43127 Mdot
.78 .4319 Mdot
.782 .43252 Mdot
.784 .43314 Mdot
.786 .43375 Mdot
.788 .43437 Mdot
.79 .43498 Mdot
.792 .43558 Mdot
.794 .43619 Mdot
.796 .43679 Mdot
.798 .43739 Mdot
.8 .43799 Mdot
.802 .43858 Mdot
.804 .43917 Mdot
.806 .43976 Mdot
.808 .44034 Mdot
.81 .44092 Mdot
.812 .4415 Mdot
.814 .44208 Mdot
.816 .44265 Mdot
.818 .44322 Mdot
.82 .44379 Mdot
.822 .44436 Mdot
.824 .44492 Mdot
.826 .44548 Mdot
.828 .44604 Mdot
.83 .4466 Mdot
.832 .44715 Mdot
.834 .4477 Mdot
.836 .44825 Mdot
.838 .44879 Mdot
.84 .44934 Mdot
.842 .44988 Mdot
.844 .45041 Mdot
.846 .45095 Mdot
.848 .45148 Mdot
.85 .45201 Mdot
.852 .45254 Mdot
.854 .45306 Mdot
.856 .45359 Mdot
.858 .45411 Mdot
.86 .45463 Mdot
.862 .45514 Mdot
.864 .45566 Mdot
.866 .45483 Mdot
.866 .45483 Mdot
.866 .45483 Mdot
.866 .45483 Mdot
.866 .45483 Mdot
.866 .45483 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45484 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45485 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45486 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45487 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45488 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .45489 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .4549 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45491 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45492 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45493 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45494 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45495 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45496 Mdot
.866 .45497 Mdot
.866 .45497 Mdot
.866 .45497 Mdot
.866 .45497 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45736 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45737 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45738 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .45739 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .4574 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45741 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45742 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45743 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45744 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45745 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45746 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45747 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45748 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.866 .45749 Mdot
.868 .42944 Mdot
.868 .4809 Mdot
.87 .41779 Mdot
.87 .49055 Mdot
.872 .40873 Mdot
.872 .49763 Mdot
.874 .40102 Mdot
.874 .50338 Mdot
.876 .39418 Mdot
.876 .50828 Mdot
.878 .38798 Mdot
.878 .51257 Mdot
.88 .38225 Mdot
.88 .5164 Mdot
.882 .37691 Mdot
.882 .51987 Mdot
.884 .37189 Mdot
.884 .52303 Mdot
.886 .36714 Mdot
.886 .52595 Mdot
.888 .36262 Mdot
.888 .52866 Mdot
.89 .35831 Mdot
.89 .53118 Mdot
.892 .35418 Mdot
.892 .53354 Mdot
.894 .35021 Mdot
.894 .53575 Mdot
.896 .34639 Mdot
.896 .53784 Mdot
.898 .3427 Mdot
.898 .53982 Mdot
.9 .33913 Mdot
.9 .54168 Mdot
.902 .33567 Mdot
.902 .54346 Mdot
.904 .33232 Mdot
.904 .54515 Mdot
.906 .32907 Mdot
.906 .54676 Mdot
.908 .3259 Mdot
.908 .54829 Mdot
.91 .32282 Mdot
.91 .54976 Mdot
.912 .31983 Mdot
.912 .55117 Mdot
.914 .3169 Mdot
.914 .55251 Mdot
.916 .31405 Mdot
.916 .5538 Mdot
.918 .31126 Mdot
.918 .55504 Mdot
.92 .30854 Mdot
.92 .55624 Mdot
.922 .30588 Mdot
.922 .55738 Mdot
.924 .30327 Mdot
.924 .55849 Mdot
.926 .30072 Mdot
.926 .55955 Mdot
.928 .29823 Mdot
.928 .56058 Mdot
.93 .29578 Mdot
.93 .56157 Mdot
.932 .29339 Mdot
.932 .56252 Mdot
.934 .29104 Mdot
.934 .56345 Mdot
.936 .28873 Mdot
.936 .56434 Mdot
.938 .28647 Mdot
.938 .56521 Mdot
.94 .28424 Mdot
.94 .56604 Mdot
.942 .28206 Mdot
.942 .56685 Mdot
.944 .27992 Mdot
.944 .56764 Mdot
.946 .27781 Mdot
.946 .5684 Mdot
.948 .27574 Mdot
.948 .56914 Mdot
.95 .27371 Mdot
.95 .56985 Mdot
.952 .2717 Mdot
.952 .57055 Mdot
.954 .26974 Mdot
.954 .57122 Mdot
.956 .2553 Mdot
.956 .28211 Mdot
.956 .56797 Mdot
.956 .57507 Mdot
.958 .24424 Mdot
.958 .29373 Mdot
.958 .56477 Mdot
.958 .57784 Mdot
.96 .237 Mdot
.96 .30151 Mdot
.96 .5626 Mdot
.96 .5796 Mdot
.962 .23127 Mdot
.962 .30779 Mdot
.962 .56084 Mdot
.962 .58095 Mdot
.964 .2264 Mdot
.964 .31319 Mdot
.964 .55932 Mdot
.964 .58208 Mdot
.966 .22212 Mdot
.966 .31801 Mdot
.966 .55796 Mdot
.966 .58305 Mdot
.968 .21828 Mdot
.968 .32238 Mdot
.968 .55673 Mdot
.968 .5839 Mdot
.97 .20964 Mdot
.97 .22235 Mdot
.97 .31179 Mdot
.97 .33649 Mdot
.97 .55213 Mdot
.97 .56035 Mdot
.97 .58317 Mdot
.97 .58564 Mdot
.972 .20357 Mdot
.972 .20529 Mdot
.972 .22332 Mdot
.972 .22739 Mdot
.972 .29908 Mdot
.972 .30691 Mdot
.972 .34279 Mdot
.972 .3463 Mdot
.972 .54886 Mdot
.972 .55013 Mdot
.972 .56205 Mdot
.972 .5644 Mdot
.972 .58223 Mdot
.972 .58306 Mdot
.972 .58652 Mdot
.972 .58683 Mdot
.974 .19718 Mdot
.974 .19723 Mdot
.974 .19724 Mdot
.974 .19731 Mdot
.974 .19737 Mdot
.974 .19739 Mdot
.974 .19741 Mdot
.974 .19753 Mdot
.974 .19753 Mdot
.974 .19754 Mdot
.974 .19756 Mdot
.974 .19787 Mdot
.974 .19789 Mdot
.974 .19794 Mdot
.974 .19796 Mdot
.974 .19796 Mdot
.974 .19803 Mdot
.974 .19804 Mdot
.974 .19811 Mdot
.974 .19819 Mdot
.974 .19835 Mdot
.974 .19842 Mdot
.974 .19844 Mdot
.974 .19852 Mdot
.974 .19869 Mdot
.974 .1987 Mdot
.974 .19874 Mdot
.974 .1989 Mdot
.974 .19892 Mdot
.974 .199 Mdot
.974 .199 Mdot
.974 .19912 Mdot
.974 .19918 Mdot
.974 .19922 Mdot
.974 .19927 Mdot
.974 .19936 Mdot
.974 .19942 Mdot
.974 .19946 Mdot
.974 .19971 Mdot
.974 .19979 Mdot
.974 .19988 Mdot
.974 .19994 Mdot
.974 .20007 Mdot
.974 .20014 Mdot
.974 .20021 Mdot
.974 .2003 Mdot
.974 .2003 Mdot
.974 .20037 Mdot
.974 .2004 Mdot
.974 .20047 Mdot
.974 .20052 Mdot
.974 .20055 Mdot
.974 .20058 Mdot
.974 .20071 Mdot
.974 .20078 Mdot
.974 .20098 Mdot
.974 .201 Mdot
.974 .20115 Mdot
.974 .20116 Mdot
.974 .20127 Mdot
.974 .20127 Mdot
.974 .20137 Mdot
.974 .20143 Mdot
.974 .20147 Mdot
.974 .20168 Mdot
.974 .20169 Mdot
.974 .2018 Mdot
.974 .20213 Mdot
.974 .20215 Mdot
.974 .20232 Mdot
.974 .20263 Mdot
.974 .20267 Mdot
.974 .20293 Mdot
.974 .20349 Mdot
.974 .2036 Mdot
.974 .20367 Mdot
.974 .20383 Mdot
.974 .20387 Mdot
.974 .204 Mdot
.974 .20419 Mdot
.974 .20425 Mdot
.974 .20426 Mdot
.974 .20427 Mdot
.974 .20439 Mdot
.974 .20445 Mdot
.974 .20463 Mdot
.974 .20483 Mdot
.974 .20498 Mdot
.974 .20498 Mdot
.974 .20509 Mdot
.974 .20523 Mdot
.974 .20548 Mdot
.974 .20554 Mdot
.974 .20572 Mdot
.974 .20576 Mdot
.974 .20578 Mdot
.974 .20613 Mdot
.974 .20624 Mdot
.974 .20628 Mdot
.974 .20642 Mdot
.974 .20661 Mdot
.974 .20691 Mdot
.974 .20695 Mdot
.974 .20715 Mdot
.974 .20718 Mdot
.974 .2076 Mdot
.974 .20784 Mdot
.974 .20794 Mdot
.974 .20803 Mdot
.974 .20824 Mdot
.974 .20834 Mdot
.974 .20844 Mdot
.974 .20847 Mdot
.974 .2085 Mdot
.974 .20853 Mdot
.974 .20855 Mdot
.974 .20861 Mdot
.974 .20867 Mdot
.974 .20884 Mdot
.974 .2089 Mdot
.974 .20903 Mdot
.974 .20943 Mdot
.974 .2096 Mdot
.974 .20972 Mdot
.974 .2098 Mdot
.974 .21015 Mdot
.974 .21026 Mdot
.974 .21055 Mdot
.974 .21062 Mdot
.974 .21097 Mdot
.974 .21101 Mdot
.974 .21109 Mdot
.974 .2111 Mdot
.974 .21115 Mdot
.974 .2114 Mdot
.974 .21151 Mdot
.974 .21156 Mdot
.974 .21164 Mdot
.974 .21225 Mdot
.974 .21267 Mdot
.974 .21295 Mdot
.974 .21305 Mdot
.974 .21327 Mdot
.974 .21332 Mdot
.974 .21341 Mdot
.974 .21351 Mdot
.974 .21352 Mdot
.974 .21405 Mdot
.974 .21408 Mdot
.974 .21417 Mdot
.974 .21423 Mdot
.974 .21433 Mdot
.974 .2145 Mdot
.974 .21457 Mdot
.974 .21471 Mdot
.974 .21487 Mdot
.974 .21526 Mdot
.974 .2153 Mdot
.974 .21537 Mdot
.974 .21559 Mdot
.974 .21567 Mdot
.974 .21583 Mdot
.974 .21583 Mdot
.974 .21619 Mdot
.974 .21665 Mdot
.974 .21706 Mdot
.974 .21721 Mdot
.974 .2175 Mdot
.974 .21751 Mdot
.974 .21754 Mdot
.974 .2177 Mdot
.974 .21814 Mdot
.974 .21847 Mdot
.974 .21856 Mdot
.974 .21896 Mdot
.974 .21913 Mdot
.974 .2194 Mdot
.974 .22079 Mdot
.974 .22147 Mdot
.974 .22156 Mdot
.974 .22236 Mdot
.974 .22282 Mdot
.974 .22287 Mdot
.974 .22374 Mdot
.974 .22403 Mdot
.974 .22406 Mdot
.974 .22462 Mdot
.974 .22475 Mdot
.974 .22491 Mdot
.974 .22518 Mdot
.974 .22518 Mdot
.974 .22547 Mdot
.974 .2255 Mdot
.974 .22591 Mdot
.974 .22597 Mdot
.974 .22651 Mdot
.974 .22671 Mdot
.974 .22707 Mdot
.974 .22717 Mdot
.974 .22724 Mdot
.974 .2274 Mdot
.974 .2276 Mdot
.974 .22767 Mdot
.974 .22786 Mdot
.974 .22788 Mdot
.974 .22813 Mdot
.974 .22832 Mdot
.974 .22852 Mdot
.974 .2289 Mdot
.974 .22907 Mdot
.974 .22932 Mdot
.974 .22957 Mdot
.974 .23029 Mdot
.974 .23039 Mdot
.974 .23057 Mdot
.974 .23084 Mdot
.974 .23098 Mdot
.974 .23109 Mdot
.974 .23127 Mdot
.974 .23143 Mdot
.974 .23162 Mdot
.974 .23163 Mdot
.974 .23187 Mdot
.974 .23194 Mdot
.974 .2324 Mdot
.974 .23252 Mdot
.974 .23254 Mdot
.974 .23306 Mdot
.974 .23331 Mdot
.974 .23336 Mdot
.974 .23358 Mdot
.974 .23405 Mdot
.974 .2343 Mdot
.974 .23452 Mdot
.974 .23456 Mdot
.974 .23475 Mdot
.974 .23477 Mdot
.974 .23482 Mdot
.974 .23499 Mdot
.974 .23505 Mdot
.974 .236 Mdot
.974 .23605 Mdot
.974 .23609 Mdot
.974 .2361 Mdot
.974 .23646 Mdot
.974 .23651 Mdot
.974 .23659 Mdot
.974 .23678 Mdot
.974 .23699 Mdot
.974 .23703 Mdot
.974 .23717 Mdot
.974 .27716 Mdot
.974 .27743 Mdot
.974 .2775 Mdot
.974 .27789 Mdot
.974 .27824 Mdot
.974 .2784 Mdot
.974 .27849 Mdot
.974 .27917 Mdot
.974 .27918 Mdot
.974 .27927 Mdot
.974 .27935 Mdot
.974 .28114 Mdot
.974 .28125 Mdot
.974 .28156 Mdot
.974 .28165 Mdot
.974 .28169 Mdot
.974 .28205 Mdot
.974 .28212 Mdot
.974 .28255 Mdot
.974 .283 Mdot
.974 .2839 Mdot
.974 .28431 Mdot
.974 .28442 Mdot
.974 .28488 Mdot
.974 .28587 Mdot
.974 .28591 Mdot
.974 .28615 Mdot
.974 .28702 Mdot
.974 .28715 Mdot
.974 .2876 Mdot
.974 .28762 Mdot
.974 .28799 Mdot
.974 .2883 Mdot
.974 .28864 Mdot
.974 .28884 Mdot
.974 .28911 Mdot
.974 .28964 Mdot
.974 .28999 Mdot
.974 .29018 Mdot
.974 .29157 Mdot
.974 .29204 Mdot
.974 .29253 Mdot
.974 .29286 Mdot
.974 .2936 Mdot
.974 .29398 Mdot
.974 .29434 Mdot
.974 .29484 Mdot
.974 .29488 Mdot
.974 .29525 Mdot
.974 .29539 Mdot
.974 .29577 Mdot
.974 .29607 Mdot
.974 .29623 Mdot
.974 .29642 Mdot
.974 .29712 Mdot
.974 .29751 Mdot
.974 .29857 Mdot
.974 .29869 Mdot
.974 .29948 Mdot
.974 .29954 Mdot
.974 .30011 Mdot
.974 .30012 Mdot
.974 .30065 Mdot
.974 .30097 Mdot
.974 .30121 Mdot
.974 .30233 Mdot
.974 .30237 Mdot
.974 .30295 Mdot
.974 .30467 Mdot
.974 .30476 Mdot
.974 .30568 Mdot
.974 .30726 Mdot
.974 .30745 Mdot
.974 .30881 Mdot
.974 .31158 Mdot
.974 .31214 Mdot
.974 .31247 Mdot
.974 .31327 Mdot
.974 .31346 Mdot
.974 .31501 Mdot
.974 .31532 Mdot
.974 .31538 Mdot
.974 .31541 Mdot
.974 .316 Mdot
.974 .31629 Mdot
.974 .31713 Mdot
.974 .31806 Mdot
.974 .31878 Mdot
.974 .31879 Mdot
.974 .31911 Mdot
.974 .31926 Mdot
.974 .31971 Mdot
.974 .31986 Mdot
.974 .31994 Mdot
.974 .32072 Mdot
.974 .32105 Mdot
.974 .32134 Mdot
.974 .32149 Mdot
.974 .32183 Mdot
.974 .32202 Mdot
.974 .32216 Mdot
.974 .32233 Mdot
.974 .3224 Mdot
.974 .32348 Mdot
.974 .3235 Mdot
.974 .32369 Mdot
.974 .32387 Mdot
.974 .32398 Mdot
.974 .32443 Mdot
.974 .32463 Mdot
.974 .32521 Mdot
.974 .32605 Mdot
.974 .3273 Mdot
.974 .32747 Mdot
.974 .32757 Mdot
.974 .3278 Mdot
.974 .32831 Mdot
.974 .32842 Mdot
.974 .32843 Mdot
.974 .3286 Mdot
.974 .32868 Mdot
.974 .3294 Mdot
.974 .32954 Mdot
.974 .33014 Mdot
.974 .33037 Mdot
.974 .33108 Mdot
.974 .33124 Mdot
.974 .33148 Mdot
.974 .33184 Mdot
.974 .33266 Mdot
.974 .33294 Mdot
.974 .33306 Mdot
.974 .3334 Mdot
.974 .33352 Mdot
.974 .33366 Mdot
.974 .3337 Mdot
.974 .33375 Mdot
.974 .33382 Mdot
.974 .33389 Mdot
.974 .33407 Mdot
.974 .33429 Mdot
.974 .33472 Mdot
.974 .33491 Mdot
.974 .33512 Mdot
.974 .33561 Mdot
.974 .33648 Mdot
.974 .33654 Mdot
.974 .33695 Mdot
.974 .33703 Mdot
.974 .33765 Mdot
.974 .33805 Mdot
.974 .33833 Mdot
.974 .33842 Mdot
.974 .33864 Mdot
.974 .33938 Mdot
.974 .33941 Mdot
.974 .33949 Mdot
.974 .33987 Mdot
.974 .34 Mdot
.974 .3405 Mdot
.974 .34081 Mdot
.974 .34102 Mdot
.974 .34102 Mdot
.974 .34134 Mdot
.974 .34175 Mdot
.974 .34212 Mdot
.974 .34224 Mdot
.974 .3425 Mdot
.974 .34251 Mdot
.974 .34254 Mdot
.974 .34267 Mdot
.974 .34306 Mdot
.974 .34333 Mdot
.974 .34342 Mdot
.974 .34375 Mdot
.974 .34389 Mdot
.974 .34412 Mdot
.974 .34527 Mdot
.974 .34583 Mdot
.974 .3459 Mdot
.974 .34654 Mdot
.974 .34691 Mdot
.974 .34695 Mdot
.974 .34763 Mdot
.974 .34786 Mdot
.974 .34787 Mdot
.974 .34831 Mdot
.974 .34841 Mdot
.974 .34853 Mdot
.974 .34874 Mdot
.974 .34874 Mdot
.974 .34896 Mdot
.974 .34898 Mdot
.974 .34929 Mdot
.974 .34934 Mdot
.974 .34974 Mdot
.974 .34989 Mdot
.974 .35016 Mdot
.974 .35023 Mdot
.974 .35029 Mdot
.974 .35041 Mdot
.974 .35055 Mdot
.974 .35061 Mdot
.974 .35075 Mdot
.974 .35076 Mdot
.974 .35095 Mdot
.974 .35109 Mdot
.974 .35123 Mdot
.974 .35151 Mdot
.974 .35163 Mdot
.974 .35182 Mdot
.974 .35199 Mdot
.974 .35251 Mdot
.974 .35258 Mdot
.974 .35271 Mdot
.974 .35291 Mdot
.974 .35301 Mdot
.974 .35309 Mdot
.974 .35321 Mdot
.974 .35346 Mdot
.974 .35347 Mdot
.974 .35363 Mdot
.974 .35368 Mdot
.974 .354 Mdot
.974 .35409 Mdot
.974 .3541 Mdot
.974 .35447 Mdot
.974 .35464 Mdot
.974 .35467 Mdot
.974 .35483 Mdot
.974 .35515 Mdot
.974 .35532 Mdot
.974 .35547 Mdot
.974 .3555 Mdot
.974 .35563 Mdot
.974 .35565 Mdot
.974 .35568 Mdot
.974 .35579 Mdot
.974 .35583 Mdot
.974 .35648 Mdot
.974 .35651 Mdot
.974 .35654 Mdot
.974 .35654 Mdot
.974 .35679 Mdot
.974 .35682 Mdot
.974 .35688 Mdot
.974 .357 Mdot
.974 .35714 Mdot
.974 .35717 Mdot
.974 .35727 Mdot
.974 .54501 Mdot
.974 .54505 Mdot
.974 .54506 Mdot
.974 .54511 Mdot
.974 .54516 Mdot
.974 .54518 Mdot
.974 .5452 Mdot
.974 .54529 Mdot
.974 .54529 Mdot
.974 .5453 Mdot
.974 .54532 Mdot
.974 .54556 Mdot
.974 .54558 Mdot
.974 .54562 Mdot
.974 .54563 Mdot
.974 .54564 Mdot
.974 .54569 Mdot
.974 .5457 Mdot
.974 .54576 Mdot
.974 .54582 Mdot
.974 .54594 Mdot
.974 .546 Mdot
.974 .54601 Mdot
.974 .54608 Mdot
.974 .54621 Mdot
.974 .54622 Mdot
.974 .54625 Mdot
.974 .54637 Mdot
.974 .54639 Mdot
.974 .54645 Mdot
.974 .54646 Mdot
.974 .54655 Mdot
.974 .5466 Mdot
.974 .54663 Mdot
.974 .54666 Mdot
.974 .54674 Mdot
.974 .54679 Mdot
.974 .54681 Mdot
.974 .54701 Mdot
.974 .54707 Mdot
.974 .54714 Mdot
.974 .54719 Mdot
.974 .54729 Mdot
.974 .54734 Mdot
.974 .5474 Mdot
.974 .54746 Mdot
.974 .54747 Mdot
.974 .54752 Mdot
.974 .54754 Mdot
.974 .5476 Mdot
.974 .54764 Mdot
.974 .54766 Mdot
.974 .54769 Mdot
.974 .54779 Mdot
.974 .54784 Mdot
.974 .54799 Mdot
.974 .54801 Mdot
.974 .54812 Mdot
.974 .54813 Mdot
.974 .54821 Mdot
.974 .54821 Mdot
.974 .54829 Mdot
.974 .54834 Mdot
.974 .54837 Mdot
.974 .54853 Mdot
.974 .54854 Mdot
.974 .54862 Mdot
.974 .54887 Mdot
.974 .54888 Mdot
.974 .54902 Mdot
.974 .54925 Mdot
.974 .54928 Mdot
.974 .54948 Mdot
.974 .54989 Mdot
.974 .54998 Mdot
.974 .55003 Mdot
.974 .55015 Mdot
.974 .55018 Mdot
.974 .55028 Mdot
.974 .55042 Mdot
.974 .55046 Mdot
.974 .55047 Mdot
.974 .55048 Mdot
.974 .55057 Mdot
.974 .55061 Mdot
.974 .55074 Mdot
.974 .55089 Mdot
.974 .551 Mdot
.974 .55101 Mdot
.974 .55108 Mdot
.974 .55119 Mdot
.974 .55137 Mdot
.974 .55141 Mdot
.974 .55155 Mdot
.974 .55157 Mdot
.974 .55159 Mdot
.974 .55185 Mdot
.974 .55192 Mdot
.974 .55196 Mdot
.974 .55205 Mdot
.974 .55219 Mdot
.974 .55241 Mdot
.974 .55244 Mdot
.974 .55258 Mdot
.974 .5526 Mdot
.974 .5529 Mdot
.974 .55307 Mdot
.974 .55315 Mdot
.974 .55321 Mdot
.974 .55336 Mdot
.974 .55343 Mdot
.974 .5535 Mdot
.974 .55352 Mdot
.974 .55355 Mdot
.974 .55356 Mdot
.974 .55358 Mdot
.974 .55363 Mdot
.974 .55367 Mdot
.974 .55378 Mdot
.974 .55382 Mdot
.974 .55392 Mdot
.974 .5542 Mdot
.974 .55432 Mdot
.974 .5544 Mdot
.974 .55446 Mdot
.974 .5547 Mdot
.974 .55478 Mdot
.974 .55498 Mdot
.974 .55503 Mdot
.974 .55527 Mdot
.974 .5553 Mdot
.974 .55535 Mdot
.974 .55536 Mdot
.974 .55539 Mdot
.974 .55556 Mdot
.974 .55564 Mdot
.974 .55568 Mdot
.974 .55573 Mdot
.974 .55615 Mdot
.974 .55642 Mdot
.974 .55662 Mdot
.974 .55668 Mdot
.974 .55683 Mdot
.974 .55687 Mdot
.974 .55693 Mdot
.974 .55699 Mdot
.974 .557 Mdot
.974 .55735 Mdot
.974 .55737 Mdot
.974 .55743 Mdot
.974 .55747 Mdot
.974 .55754 Mdot
.974 .55765 Mdot
.974 .5577 Mdot
.974 .55779 Mdot
.974 .5579 Mdot
.974 .55815 Mdot
.974 .55817 Mdot
.974 .55822 Mdot
.974 .55837 Mdot
.974 .55842 Mdot
.974 .55852 Mdot
.974 .55852 Mdot
.974 .55875 Mdot
.974 .55905 Mdot
.974 .55932 Mdot
.974 .55941 Mdot
.974 .55959 Mdot
.974 .5596 Mdot
.974 .55962 Mdot
.974 .55972 Mdot
.974 .56021 Mdot
.974 .56027 Mdot
.974 .56052 Mdot
.974 .56062 Mdot
.974 .56079 Mdot
.974 .56165 Mdot
.974 .56207 Mdot
.974 .56212 Mdot
.974 .5626 Mdot
.974 .56288 Mdot
.974 .56291 Mdot
.974 .56343 Mdot
.974 .5636 Mdot
.974 .56361 Mdot
.974 .56394 Mdot
.974 .56401 Mdot
.974 .56411 Mdot
.974 .56426 Mdot
.974 .56427 Mdot
.974 .56443 Mdot
.974 .56445 Mdot
.974 .56469 Mdot
.974 .56472 Mdot
.974 .56503 Mdot
.974 .56514 Mdot
.974 .56535 Mdot
.974 .5654 Mdot
.974 .56545 Mdot
.974 .56553 Mdot
.974 .56564 Mdot
.974 .56568 Mdot
.974 .56579 Mdot
.974 .5658 Mdot
.974 .56594 Mdot
.974 .56605 Mdot
.974 .56616 Mdot
.974 .56637 Mdot
.974 .56646 Mdot
.974 .5666 Mdot
.974 .56673 Mdot
.974 .56713 Mdot
.974 .56718 Mdot
.974 .56728 Mdot
.974 .56743 Mdot
.974 .5675 Mdot
.974 .56756 Mdot
.974 .56765 Mdot
.974 .56774 Mdot
.974 .56784 Mdot
.974 .56785 Mdot
.974 .56797 Mdot
.974 .56801 Mdot
.974 .56825 Mdot
.974 .56832 Mdot
.974 .56833 Mdot
.974 .5686 Mdot
.974 .56873 Mdot
.974 .56875 Mdot
.974 .56887 Mdot
.974 .56911 Mdot
.974 .56923 Mdot
.974 .56935 Mdot
.974 .56937 Mdot
.974 .56947 Mdot
.974 .56948 Mdot
.974 .5695 Mdot
.974 .56959 Mdot
.974 .56962 Mdot
.974 .57009 Mdot
.974 .57012 Mdot
.974 .57014 Mdot
.974 .57014 Mdot
.974 .57033 Mdot
.974 .57035 Mdot
.974 .57039 Mdot
.974 .57048 Mdot
.974 .57059 Mdot
.974 .5706 Mdot
.974 .57068 Mdot
.974 .58027 Mdot
.974 .5803 Mdot
.974 .5803 Mdot
.974 .58035 Mdot
.974 .58039 Mdot
.974 .58041 Mdot
.974 .58042 Mdot
.974 .5805 Mdot
.974 .5805 Mdot
.974 .58051 Mdot
.974 .58052 Mdot
.974 .58072 Mdot
.974 .58074 Mdot
.974 .58077 Mdot
.974 .58078 Mdot
.974 .58079 Mdot
.974 .58083 Mdot
.974 .58083 Mdot
.974 .58088 Mdot
.974 .58093 Mdot
.974 .58103 Mdot
.974 .58108 Mdot
.974 .58109 Mdot
.974 .58114 Mdot
.974 .58125 Mdot
.974 .58126 Mdot
.974 .58129 Mdot
.974 .58138 Mdot
.974 .5814 Mdot
.974 .58145 Mdot
.974 .58145 Mdot
.974 .58152 Mdot
.974 .58156 Mdot
.974 .58158 Mdot
.974 .58161 Mdot
.974 .58167 Mdot
.974 .58171 Mdot
.974 .58173 Mdot
.974 .58188 Mdot
.974 .58193 Mdot
.974 .58198 Mdot
.974 .58201 Mdot
.974 .58209 Mdot
.974 .58213 Mdot
.974 .58217 Mdot
.974 .58223 Mdot
.974 .58223 Mdot
.974 .58227 Mdot
.974 .58228 Mdot
.974 .58232 Mdot
.974 .58236 Mdot
.974 .58237 Mdot
.974 .58239 Mdot
.974 .58247 Mdot
.974 .58251 Mdot
.974 .58262 Mdot
.974 .58263 Mdot
.974 .58271 Mdot
.974 .58272 Mdot
.974 .58278 Mdot
.974 .58278 Mdot
.974 .58283 Mdot
.974 .58286 Mdot
.974 .58289 Mdot
.974 .583 Mdot
.974 .58301 Mdot
.974 .58307 Mdot
.974 .58324 Mdot
.974 .58325 Mdot
.974 .58334 Mdot
.974 .5835 Mdot
.974 .58352 Mdot
.974 .58365 Mdot
.974 .58393 Mdot
.974 .58398 Mdot
.974 .58401 Mdot
.974 .58409 Mdot
.974 .58411 Mdot
.974 .58417 Mdot
.974 .58426 Mdot
.974 .58429 Mdot
.974 .5843 Mdot
.974 .5843 Mdot
.974 .58436 Mdot
.974 .58438 Mdot
.974 .58446 Mdot
.974 .58455 Mdot
.974 .58462 Mdot
.974 .58462 Mdot
.974 .58465 Mdot
.974 .58467 Mdot
.974 .58471 Mdot
.974 .58472 Mdot
.974 .58473 Mdot
.974 .58481 Mdot
.974 .58484 Mdot
.974 .58486 Mdot
.974 .58488 Mdot
.974 .58491 Mdot
.974 .58493 Mdot
.974 .58494 Mdot
.974 .58496 Mdot
.974 .58496 Mdot
.974 .58506 Mdot
.974 .58507 Mdot
.974 .58508 Mdot
.974 .5851 Mdot
.974 .58511 Mdot
.974 .58515 Mdot
.974 .58517 Mdot
.974 .58523 Mdot
.974 .5853 Mdot
.974 .58542 Mdot
.974 .58543 Mdot
.974 .58544 Mdot
.974 .58546 Mdot
.974 .58551 Mdot
.974 .58552 Mdot
.974 .58552 Mdot
.974 .58554 Mdot
.974 .58554 Mdot
.974 .58561 Mdot
.974 .58562 Mdot
.974 .58568 Mdot
.974 .5857 Mdot
.974 .58576 Mdot
.974 .58578 Mdot
.974 .5858 Mdot
.974 .58583 Mdot
.974 .5859 Mdot
.974 .58593 Mdot
.974 .58594 Mdot
.974 .58597 Mdot
.974 .58598 Mdot
.974 .58599 Mdot
.974 .586 Mdot
.974 .586 Mdot
.974 .58601 Mdot
.974 .58601 Mdot
.974 .58603 Mdot
.974 .58605 Mdot
.974 .58609 Mdot
.974 .58611 Mdot
.974 .58612 Mdot
.974 .58617 Mdot
.974 .58624 Mdot
.974 .58625 Mdot
.974 .58629 Mdot
.974 .58629 Mdot
.974 .58635 Mdot
.974 .58638 Mdot
.974 .58641 Mdot
.974 .58642 Mdot
.974 .58644 Mdot
.974 .5865 Mdot
.974 .5865 Mdot
.974 .58651 Mdot
.974 .58654 Mdot
.974 .58656 Mdot
.974 .5866 Mdot
.974 .58663 Mdot
.974 .58664 Mdot
.974 .58664 Mdot
.974 .58667 Mdot
.974 .58671 Mdot
.974 .58674 Mdot
.974 .58675 Mdot
.974 .58677 Mdot
.974 .58677 Mdot
.974 .58678 Mdot
.974 .58679 Mdot
.974 .58682 Mdot
.974 .58685 Mdot
.974 .58685 Mdot
.974 .58688 Mdot
.974 .58689 Mdot
.974 .58691 Mdot
.974 .58701 Mdot
.974 .58706 Mdot
.974 .58707 Mdot
.974 .58712 Mdot
.974 .58715 Mdot
.974 .58716 Mdot
.974 .58721 Mdot
.974 .58723 Mdot
.974 .58723 Mdot
.974 .58727 Mdot
.974 .58728 Mdot
.974 .58729 Mdot
.974 .58731 Mdot
.974 .58731 Mdot
.974 .58733 Mdot
.974 .58733 Mdot
.974 .58736 Mdot
.974 .58736 Mdot
.974 .58739 Mdot
.974 .58741 Mdot
.974 .58743 Mdot
.974 .58743 Mdot
.974 .58744 Mdot
.974 .58745 Mdot
.974 .58746 Mdot
.974 .58747 Mdot
.974 .58748 Mdot
.974 .58748 Mdot
.974 .5875 Mdot
.974 .58751 Mdot
.974 .58752 Mdot
.974 .58754 Mdot
.974 .58755 Mdot
.974 .58757 Mdot
.974 .58758 Mdot
.974 .58763 Mdot
.974 .58763 Mdot
.974 .58764 Mdot
.974 .58766 Mdot
.974 .58767 Mdot
.974 .58767 Mdot
.974 .58768 Mdot
.974 .58771 Mdot
.974 .58771 Mdot
.974 .58772 Mdot
.974 .58772 Mdot
.974 .58775 Mdot
.974 .58776 Mdot
.974 .58776 Mdot
.974 .58779 Mdot
.974 .5878 Mdot
.974 .58781 Mdot
.974 .58782 Mdot
.974 .58785 Mdot
.974 .58786 Mdot
.974 .58787 Mdot
.974 .58787 Mdot
.974 .58789 Mdot
.974 .58789 Mdot
.974 .58789 Mdot
.974 .5879 Mdot
.974 .5879 Mdot
.974 .58796 Mdot
.974 .58796 Mdot
.974 .58796 Mdot
.974 .58796 Mdot
.974 .58798 Mdot
.974 .58798 Mdot
.974 .58799 Mdot
.974 .588 Mdot
.974 .58801 Mdot
.974 .58801 Mdot
.974 .58802 Mdot
.976 .19056 Mdot
.976 .19058 Mdot
.976 .19062 Mdot
.976 .19066 Mdot
.976 .19069 Mdot
.976 .19077 Mdot
.976 .19077 Mdot
.976 .19085 Mdot
.976 .19087 Mdot
.976 .19091 Mdot
.976 .19092 Mdot
.976 .19099 Mdot
.976 .19102 Mdot
.976 .19107 Mdot
.976 .19116 Mdot
.976 .19121 Mdot
.976 .19133 Mdot
.976 .19141 Mdot
.976 .19168 Mdot
.976 .19174 Mdot
.976 .19184 Mdot
.976 .19185 Mdot
.976 .19187 Mdot
.976 .19189 Mdot
.976 .19202 Mdot
.976 .19203 Mdot
.976 .19224 Mdot
.976 .19261 Mdot
.976 .19288 Mdot
.976 .193 Mdot
.976 .19305 Mdot
.976 .19315 Mdot
.976 .1932 Mdot
.976 .1933 Mdot
.976 .19366 Mdot
.976 .19372 Mdot
.976 .19383 Mdot
.976 .19413 Mdot
.976 .19436 Mdot
.976 .19438 Mdot
.976 .19476 Mdot
.976 .19532 Mdot
.976 .19539 Mdot
.976 .19544 Mdot
.976 .19587 Mdot
.976 .19609 Mdot
.976 .19617 Mdot
.976 .19658 Mdot
.976 .19709 Mdot
.976 .19718 Mdot
.976 .19727 Mdot
.976 .19769 Mdot
.976 .19809 Mdot
.976 .19816 Mdot
.976 .19831 Mdot
.976 .19849 Mdot
.976 .19852 Mdot
.976 .19869 Mdot
.976 .19895 Mdot
.976 .19901 Mdot
.976 .19934 Mdot
.976 .19942 Mdot
.976 .19996 Mdot
.976 .20075 Mdot
.976 .20124 Mdot
.976 .2015 Mdot
.976 .20171 Mdot
.976 .20177 Mdot
.976 .20179 Mdot
.976 .20198 Mdot
.976 .20367 Mdot
.976 .2037 Mdot
.976 .20396 Mdot
.976 .204 Mdot
.976 .20418 Mdot
.976 .20484 Mdot
.976 .20533 Mdot
.976 .20562 Mdot
.976 .20587 Mdot
.976 .20652 Mdot
.976 .20664 Mdot
.976 .20762 Mdot
.976 .20861 Mdot
.976 .20897 Mdot
.976 .20917 Mdot
.976 .20949 Mdot
.976 .2096 Mdot
.976 .20969 Mdot
.976 .21033 Mdot
.976 .21039 Mdot
.976 .21104 Mdot
.976 .21159 Mdot
.976 .2135 Mdot
.976 .21381 Mdot
.976 .21395 Mdot
.976 .21473 Mdot
.976 .21525 Mdot
.976 .21528 Mdot
.976 .21529 Mdot
.976 .21546 Mdot
.976 .21602 Mdot
.976 .21674 Mdot
.976 .21694 Mdot
.976 .21714 Mdot
.976 .21812 Mdot
.976 .21832 Mdot
.976 .21917 Mdot
.976 .21961 Mdot
.976 .22038 Mdot
.976 .22073 Mdot
.976 .22074 Mdot
.976 .22102 Mdot
.976 .22108 Mdot
.976 .22125 Mdot
.976 .2215 Mdot
.976 .22184 Mdot
.976 .22196 Mdot
.976 .22221 Mdot
.976 .22284 Mdot
.976 .22317 Mdot
.976 .22336 Mdot
.976 .22337 Mdot
.976 .22373 Mdot
.976 .22415 Mdot
.976 .22466 Mdot
.976 .22477 Mdot
.976 .22483 Mdot
.976 .22532 Mdot
.976 .22537 Mdot
.976 .22548 Mdot
.976 .22577 Mdot
.976 .22599 Mdot
.976 .22601 Mdot
.976 .22634 Mdot
.976 .22682 Mdot
.976 .22688 Mdot
.976 .22726 Mdot
.976 .22743 Mdot
.976 .2278 Mdot
.976 .2283 Mdot
.976 .2286 Mdot
.976 .22887 Mdot
.976 .22916 Mdot
.976 .22926 Mdot
.976 .22943 Mdot
.976 .22973 Mdot
.976 .23053 Mdot
.976 .23082 Mdot
.976 .23097 Mdot
.976 .23109 Mdot
.976 .23113 Mdot
.976 .23124 Mdot
.976 .23216 Mdot
.976 .23233 Mdot
.976 .23242 Mdot
.976 .23276 Mdot
.976 .23315 Mdot
.976 .23366 Mdot
.976 .23459 Mdot
.976 .23476 Mdot
.976 .235 Mdot
.976 .23569 Mdot
.976 .23594 Mdot
.976 .23676 Mdot
.976 .23689 Mdot
.976 .23751 Mdot
.976 .23819 Mdot
.976 .23827 Mdot
.976 .23874 Mdot
.976 .23908 Mdot
.976 .23925 Mdot
.976 .23969 Mdot
.976 .23969 Mdot
.976 .2398 Mdot
.976 .23982 Mdot
.976 .23989 Mdot
.976 .23999 Mdot
.976 .24012 Mdot
.976 .2405 Mdot
.976 .2407 Mdot
.976 .24083 Mdot
.976 .24124 Mdot
.976 .24145 Mdot
.976 .24149 Mdot
.976 .24168 Mdot
.976 .24181 Mdot
.976 .24198 Mdot
.976 .242 Mdot
.976 .24221 Mdot
.976 .24234 Mdot
.976 .24252 Mdot
.976 .24287 Mdot
.976 .24293 Mdot
.976 .24304 Mdot
.976 .24333 Mdot
.976 .24348 Mdot
.976 .24352 Mdot
.976 .24354 Mdot
.976 .24358 Mdot
.976 .24397 Mdot
.976 .24412 Mdot
.976 .24443 Mdot
.976 .24515 Mdot
.976 .24523 Mdot
.976 .24551 Mdot
.976 .24577 Mdot
.976 .2462 Mdot
.976 .24637 Mdot
.976 .24652 Mdot
.976 .24652 Mdot
.976 .24656 Mdot
.976 .24657 Mdot
.976 .24659 Mdot
.976 .24662 Mdot
.976 .24691 Mdot
.976 .24705 Mdot
.976 .24712 Mdot
.976 .24713 Mdot
.976 .2472 Mdot
.976 .24724 Mdot
.976 .24731 Mdot
.976 .24738 Mdot
.976 .24762 Mdot
.976 .24775 Mdot
.976 .24782 Mdot
.976 .24783 Mdot
.976 .24784 Mdot
.976 .24797 Mdot
.976 .24802 Mdot
.976 .24836 Mdot
.976 .24839 Mdot
.976 .24849 Mdot
.976 .24872 Mdot
.976 .24877 Mdot
.976 .24882 Mdot
.976 .24884 Mdot
.976 .24911 Mdot
.976 .24924 Mdot
.976 .24931 Mdot
.976 .24932 Mdot
.976 .24945 Mdot
.976 .24956 Mdot
.976 .24975 Mdot
.976 .24976 Mdot
.976 .25009 Mdot
.976 .25027 Mdot
.976 .25034 Mdot
.976 .25035 Mdot
.976 .25039 Mdot
.976 .25062 Mdot
.976 .25066 Mdot
.976 .25069 Mdot
.976 .25083 Mdot
.976 .25088 Mdot
.976 .2509 Mdot
.976 .2511 Mdot
.976 .25113 Mdot
.976 .2512 Mdot
.976 .25121 Mdot
.976 .25125 Mdot
.976 .25147 Mdot
.976 .25151 Mdot
.976 .25162 Mdot
.976 .25175 Mdot
.976 .25191 Mdot
.976 .25195 Mdot
.976 .25197 Mdot
.976 .25197 Mdot
.976 .25206 Mdot
.976 .25216 Mdot
.976 .25256 Mdot
.976 .25273 Mdot
.976 .25278 Mdot
.976 .25339 Mdot
.976 .25348 Mdot
.976 .25371 Mdot
.976 .25373 Mdot
.976 .25374 Mdot
.976 .25386 Mdot
.976 .2541 Mdot
.976 .25453 Mdot
.976 .25465 Mdot
.976 .25477 Mdot
.976 .25485 Mdot
.976 .25496 Mdot
.976 .25499 Mdot
.976 .25511 Mdot
.976 .25536 Mdot
.976 .25588 Mdot
.976 .25594 Mdot
.976 .25597 Mdot
.976 .25599 Mdot
.976 .25606 Mdot
.976 .25606 Mdot
.976 .25633 Mdot
.976 .25664 Mdot
.976 .2574 Mdot
.976 .25786 Mdot
.976 .25838 Mdot
.976 .25853 Mdot
.976 .25982 Mdot
.976 .26039 Mdot
.976 .26067 Mdot
.976 .26138 Mdot
.976 .26145 Mdot
.976 .26148 Mdot
.976 .26155 Mdot
.976 .26184 Mdot
.976 .26237 Mdot
.976 .26256 Mdot
.976 .26267 Mdot
.976 .26331 Mdot
.976 .26365 Mdot
.976 .2639 Mdot
.976 .26427 Mdot
.976 .26431 Mdot
.976 .26464 Mdot
.976 .26487 Mdot
.976 .26523 Mdot
.976 .2653 Mdot
.976 .26568 Mdot
.976 .26644 Mdot
.976 .2667 Mdot
.976 .26707 Mdot
.976 .26778 Mdot
.976 .26802 Mdot
.976 .26821 Mdot
.976 .26833 Mdot
.976 .26837 Mdot
.976 .26858 Mdot
.976 .26859 Mdot
.976 .26941 Mdot
.976 .26973 Mdot
.976 .27036 Mdot
.976 .27126 Mdot
.976 .27141 Mdot
.976 .2727 Mdot
.976 .27386 Mdot
.976 .27412 Mdot
.976 .27569 Mdot
.976 .27616 Mdot
.976 .2775 Mdot
.976 .27795 Mdot
.976 .27827 Mdot
.976 .28008 Mdot
.976 .28106 Mdot
.976 .28183 Mdot
.976 .28249 Mdot
.976 .28267 Mdot
.976 .283 Mdot
.976 .2848 Mdot
.976 .28501 Mdot
.976 .2851 Mdot
.976 .28533 Mdot
.976 .28562 Mdot
.976 .28619 Mdot
.976 .28777 Mdot
.976 .28835 Mdot
.976 .28869 Mdot
.976 .2889 Mdot
.976 .28946 Mdot
.976 .29001 Mdot
.976 .29059 Mdot
.976 .29158 Mdot
.976 .29232 Mdot
.976 .29266 Mdot
.976 .29343 Mdot
.976 .29355 Mdot
.976 .29449 Mdot
.976 .29517 Mdot
.976 .29521 Mdot
.976 .29565 Mdot
.976 .29622 Mdot
.976 .29644 Mdot
.976 .29655 Mdot
.976 .29753 Mdot
.976 .29765 Mdot
.976 .29787 Mdot
.976 .2989 Mdot
.976 .30047 Mdot
.976 .3005 Mdot
.976 .30088 Mdot
.976 .30155 Mdot
.976 .30283 Mdot
.976 .30334 Mdot
.976 .30358 Mdot
.976 .30426 Mdot
.976 .30478 Mdot
.976 .30512 Mdot
.976 .30524 Mdot
.976 .30582 Mdot
.976 .30584 Mdot
.976 .30655 Mdot
.976 .30813 Mdot
.976 .30903 Mdot
.976 .31076 Mdot
.976 .31118 Mdot
.976 .3132 Mdot
.976 .3136 Mdot
.976 .31402 Mdot
.976 .31551 Mdot
.976 .31667 Mdot
.976 .317 Mdot
.976 .31704 Mdot
.976 .31709 Mdot
.976 .31818 Mdot
.976 .31978 Mdot
.976 .32007 Mdot
.976 .32073 Mdot
.976 .32469 Mdot
.976 .32584 Mdot
.976 .3272 Mdot
.976 .32733 Mdot
.976 .32867 Mdot
.976 .32886 Mdot
.976 .32909 Mdot
.976 .32977 Mdot
.976 .33017 Mdot
.976 .33092 Mdot
.976 .33301 Mdot
.976 .33506 Mdot
.976 .33533 Mdot
.976 .33669 Mdot
.976 .33722 Mdot
.976 .33784 Mdot
.976 .33887 Mdot
.976 .34026 Mdot
.976 .34064 Mdot
.976 .34072 Mdot
.976 .34127 Mdot
.976 .34133 Mdot
.976 .3449 Mdot
.976 .34532 Mdot
.976 .34535 Mdot
.976 .34548 Mdot
.976 .34592 Mdot
.976 .34647 Mdot
.976 .34753 Mdot
.976 .3492 Mdot
.976 .35034 Mdot
.976 .35052 Mdot
.976 .3512 Mdot
.976 .35134 Mdot
.976 .35189 Mdot
.976 .35225 Mdot
.976 .35232 Mdot
.976 .3527 Mdot
.976 .35301 Mdot
.976 .35316 Mdot
.976 .35403 Mdot
.976 .35492 Mdot
.976 .35511 Mdot
.976 .35529 Mdot
.976 .35639 Mdot
.976 .35726 Mdot
.976 .35743 Mdot
.976 .3579 Mdot
.976 .35882 Mdot
.976 .35892 Mdot
.976 .35907 Mdot
.976 .36026 Mdot
.976 .36106 Mdot
.976 .36111 Mdot
.976 .36161 Mdot
.976 .36224 Mdot
.976 .36247 Mdot
.976 .3626 Mdot
.976 .36337 Mdot
.976 .36359 Mdot
.976 .3637 Mdot
.976 .36391 Mdot
.976 .36401 Mdot
.976 .36427 Mdot
.976 .36484 Mdot
.976 .36563 Mdot
.976 .36609 Mdot
.976 .36611 Mdot
.976 .36638 Mdot
.976 .36642 Mdot
.976 .36646 Mdot
.976 .36649 Mdot
.976 .36671 Mdot
.976 .36683 Mdot
.976 .36741 Mdot
.976 .36757 Mdot
.976 .36783 Mdot
.976 .36794 Mdot
.976 .36814 Mdot
.976 .36824 Mdot
.976 .36831 Mdot
.976 .36844 Mdot
.976 .36847 Mdot
.976 .36856 Mdot
.976 .3686 Mdot
.976 .36878 Mdot
.976 .36878 Mdot
.976 .36895 Mdot
.976 .36902 Mdot
.976 .36909 Mdot
.976 .36918 Mdot
.976 .36922 Mdot
.976 .54061 Mdot
.976 .54062 Mdot
.976 .54066 Mdot
.976 .54069 Mdot
.976 .54071 Mdot
.976 .54078 Mdot
.976 .54079 Mdot
.976 .54086 Mdot
.976 .54087 Mdot
.976 .54091 Mdot
.976 .54092 Mdot
.976 .54097 Mdot
.976 .541 Mdot
.976 .54104 Mdot
.976 .54112 Mdot
.976 .54116 Mdot
.976 .54127 Mdot
.976 .54133 Mdot
.976 .54156 Mdot
.976 .54161 Mdot
.976 .5417 Mdot
.976 .54171 Mdot
.976 .54172 Mdot
.976 .54174 Mdot
.976 .54185 Mdot
.976 .54186 Mdot
.976 .54204 Mdot
.976 .54235 Mdot
.976 .54257 Mdot
.976 .54268 Mdot
.976 .54272 Mdot
.976 .5428 Mdot
.976 .54284 Mdot
.976 .54293 Mdot
.976 .54323 Mdot
.976 .54328 Mdot
.976 .54337 Mdot
.976 .54361 Mdot
.976 .54381 Mdot
.976 .54383 Mdot
.976 .54413 Mdot
.976 .54459 Mdot
.976 .54465 Mdot
.976 .54469 Mdot
.976 .54504 Mdot
.976 .54522 Mdot
.976 .54528 Mdot
.976 .54561 Mdot
.976 .54603 Mdot
.976 .5461 Mdot
.976 .54617 Mdot
.976 .54651 Mdot
.976 .54683 Mdot
.976 .54689 Mdot
.976 .547 Mdot
.976 .54714 Mdot
.976 .54717 Mdot
.976 .5473 Mdot
.976 .54751 Mdot
.976 .54756 Mdot
.976 .54781 Mdot
.976 .54788 Mdot
.976 .5483 Mdot
.976 .54891 Mdot
.976 .54929 Mdot
.976 .54949 Mdot
.976 .54965 Mdot
.976 .54969 Mdot
.976 .54971 Mdot
.976 .54986 Mdot
.976 .55113 Mdot
.976 .55115 Mdot
.976 .55135 Mdot
.976 .55138 Mdot
.976 .55151 Mdot
.976 .552 Mdot
.976 .55236 Mdot
.976 .55257 Mdot
.976 .55276 Mdot
.976 .55323 Mdot
.976 .55332 Mdot
.976 .55402 Mdot
.976 .55473 Mdot
.976 .55499 Mdot
.976 .55512 Mdot
.976 .55535 Mdot
.976 .55542 Mdot
.976 .55549 Mdot
.976 .55594 Mdot
.976 .55598 Mdot
.976 .55643 Mdot
.976 .55681 Mdot
.976 .5581 Mdot
.976 .55831 Mdot
.976 .5584 Mdot
.976 .55891 Mdot
.976 .55926 Mdot
.976 .55928 Mdot
.976 .55929 Mdot
.976 .55939 Mdot
.976 .55976 Mdot
.976 .56022 Mdot
.976 .56036 Mdot
.976 .56048 Mdot
.976 .56111 Mdot
.976 .56124 Mdot
.976 .56177 Mdot
.976 .56204 Mdot
.976 .56252 Mdot
.976 .56274 Mdot
.976 .56274 Mdot
.976 .56292 Mdot
.976 .56295 Mdot
.976 .56305 Mdot
.976 .56321 Mdot
.976 .56342 Mdot
.976 .56349 Mdot
.976 .56364 Mdot
.976 .56401 Mdot
.976 .56421 Mdot
.976 .56433 Mdot
.976 .56433 Mdot
.976 .56479 Mdot
.976 .56509 Mdot
.976 .56516 Mdot
.976 .56519 Mdot
.976 .56547 Mdot
.976 .56551 Mdot
.976 .56557 Mdot
.976 .56574 Mdot
.976 .56586 Mdot
.976 .56587 Mdot
.976 .56606 Mdot
.976 .56634 Mdot
.976 .56637 Mdot
.976 .56659 Mdot
.976 .56668 Mdot
.976 .56689 Mdot
.976 .56717 Mdot
.976 .56733 Mdot
.976 .56749 Mdot
.976 .56764 Mdot
.976 .5677 Mdot
.976 .56779 Mdot
.976 .56796 Mdot
.976 .56839 Mdot
.976 .56855 Mdot
.976 .56863 Mdot
.976 .56869 Mdot
.976 .56871 Mdot
.976 .56877 Mdot
.976 .56926 Mdot
.976 .56935 Mdot
.976 .5694 Mdot
.976 .56958 Mdot
.976 .56978 Mdot
.976 .57004 Mdot
.976 .57053 Mdot
.976 .57061 Mdot
.976 .57073 Mdot
.976 .57108 Mdot
.976 .5712 Mdot
.976 .57161 Mdot
.976 .57168 Mdot
.976 .57198 Mdot
.976 .57231 Mdot
.976 .57235 Mdot
.976 .57258 Mdot
.976 .57274 Mdot
.976 .57282 Mdot
.976 .57303 Mdot
.976 .57303 Mdot
.976 .57308 Mdot
.976 .57309 Mdot
.976 .57312 Mdot
.976 .57317 Mdot
.976 .57323 Mdot
.976 .57341 Mdot
.976 .5735 Mdot
.976 .57357 Mdot
.976 .57376 Mdot
.976 .57385 Mdot
.976 .57387 Mdot
.976 .57396 Mdot
.976 .57402 Mdot
.976 .5741 Mdot
.976 .57411 Mdot
.976 .5742 Mdot
.976 .57426 Mdot
.976 .57434 Mdot
.976 .5745 Mdot
.976 .57453 Mdot
.976 .57457 Mdot
.976 .5747 Mdot
.976 .57477 Mdot
.976 .57479 Mdot
.976 .5748 Mdot
.976 .57482 Mdot
.976 .57499 Mdot
.976 .57506 Mdot
.976 .57519 Mdot
.976 .5755 Mdot
.976 .57554 Mdot
.976 .57566 Mdot
.976 .57578 Mdot
.976 .57596 Mdot
.976 .57603 Mdot
.976 .57609 Mdot
.976 .5761 Mdot
.976 .57611 Mdot
.976 .57611 Mdot
.976 .57612 Mdot
.976 .57614 Mdot
.976 .57626 Mdot
.976 .57632 Mdot
.976 .57635 Mdot
.976 .57635 Mdot
.976 .57638 Mdot
.976 .5764 Mdot
.976 .57643 Mdot
.976 .57646 Mdot
.976 .57656 Mdot
.976 .57661 Mdot
.976 .57664 Mdot
.976 .57664 Mdot
.976 .57665 Mdot
.976 .5767 Mdot
.976 .57672 Mdot
.976 .57687 Mdot
.976 .57688 Mdot
.976 .57692 Mdot
.976 .57701 Mdot
.976 .57703 Mdot
.976 .57705 Mdot
.976 .57705 Mdot
.976 .57706 Mdot
.976 .57707 Mdot
.976 .57711 Mdot
.976 .57713 Mdot
.976 .57716 Mdot
.976 .57717 Mdot
.976 .57722 Mdot
.976 .57723 Mdot
.976 .57723 Mdot
.976 .57725 Mdot
.976 .57726 Mdot
.976 .5773 Mdot
.976 .57731 Mdot
.976 .57732 Mdot
.976 .57735 Mdot
.976 .57736 Mdot
.976 .57737 Mdot
.976 .57742 Mdot
.976 .57743 Mdot
.976 .57743 Mdot
.976 .57745 Mdot
.976 .57749 Mdot
.976 .57757 Mdot
.976 .57757 Mdot
.976 .57761 Mdot
.976 .57764 Mdot
.976 .57766 Mdot
.976 .57767 Mdot
.976 .57769 Mdot
.976 .57771 Mdot
.976 .57778 Mdot
.976 .57778 Mdot
.976 .57779 Mdot
.976 .5778 Mdot
.976 .57786 Mdot
.976 .57788 Mdot
.976 .57788 Mdot
.976 .57796 Mdot
.976 .57797 Mdot
.976 .578 Mdot
.976 .57801 Mdot
.976 .57801 Mdot
.976 .57802 Mdot
.976 .57805 Mdot
.976 .57811 Mdot
.976 .57812 Mdot
.976 .57814 Mdot
.976 .57815 Mdot
.976 .57816 Mdot
.976 .57817 Mdot
.976 .57818 Mdot
.976 .57821 Mdot
.976 .57828 Mdot
.976 .57829 Mdot
.976 .57829 Mdot
.976 .57829 Mdot
.976 .5783 Mdot
.976 .5783 Mdot
.976 .57834 Mdot
.976 .57838 Mdot
.976 .57847 Mdot
.976 .57853 Mdot
.976 .57859 Mdot
.976 .57861 Mdot
.976 .57877 Mdot
.976 .57884 Mdot
.976 .57888 Mdot
.976 .57896 Mdot
.976 .57897 Mdot
.976 .57897 Mdot
.976 .57898 Mdot
.976 .57902 Mdot
.976 .57908 Mdot
.976 .57911 Mdot
.976 .57912 Mdot
.976 .5792 Mdot
.976 .57924 Mdot
.976 .57927 Mdot
.976 .57931 Mdot
.976 .57932 Mdot
.976 .57935 Mdot
.976 .57938 Mdot
.976 .57942 Mdot
.976 .57943 Mdot
.976 .57948 Mdot
.976 .57957 Mdot
.976 .5796 Mdot
.976 .57964 Mdot
.976 .57973 Mdot
.976 .57975 Mdot
.976 .57978 Mdot
.976 .57979 Mdot
.976 .57979 Mdot
.976 .57982 Mdot
.976 .57982 Mdot
.976 .57991 Mdot
.976 .57995 Mdot
.976 .58003 Mdot
.976 .58013 Mdot
.976 .58015 Mdot
.976 .58029 Mdot
.976 .58042 Mdot
.976 .58045 Mdot
.976 .58063 Mdot
.976 .58068 Mdot
.976 .58083 Mdot
.976 .58088 Mdot
.976 .58092 Mdot
.976 .58111 Mdot
.976 .58122 Mdot
.976 .5813 Mdot
.976 .58137 Mdot
.976 .58139 Mdot
.976 .58143 Mdot
.976 .58162 Mdot
.976 .58164 Mdot
.976 .58165 Mdot
.976 .58168 Mdot
.976 .58171 Mdot
.976 .58177 Mdot
.976 .58193 Mdot
.976 .582 Mdot
.976 .58203 Mdot
.976 .58205 Mdot
.976 .58211 Mdot
.976 .58217 Mdot
.976 .58223 Mdot
.976 .58233 Mdot
.976 .58241 Mdot
.976 .58244 Mdot
.976 .58252 Mdot
.976 .58253 Mdot
.976 .58263 Mdot
.976 .5827 Mdot
.976 .5827 Mdot
.976 .58274 Mdot
.976 .5828 Mdot
.976 .58282 Mdot
.976 .58284 Mdot
.976 .58293 Mdot
.976 .58295 Mdot
.976 .58297 Mdot
.976 .58307 Mdot
.976 .58315 Mdot
.976 .58323 Mdot
.976 .58323 Mdot
.976 .58327 Mdot
.976 .58333 Mdot
.976 .58346 Mdot
.976 .58351 Mdot
.976 .58353 Mdot
.976 .5836 Mdot
.976 .58365 Mdot
.976 .58368 Mdot
.976 .58369 Mdot
.976 .58375 Mdot
.976 .58375 Mdot
.976 .58382 Mdot
.976 .58397 Mdot
.976 .58406 Mdot
.976 .58422 Mdot
.976 .58426 Mdot
.976 .58445 Mdot
.976 .58449 Mdot
.976 .58453 Mdot
.976 .58467 Mdot
.976 .58477 Mdot
.976 .5848 Mdot
.976 .58481 Mdot
.976 .58481 Mdot
.976 .58491 Mdot
.976 .58508 Mdot
.976 .58514 Mdot
.976 .5855 Mdot
.976 .58561 Mdot
.976 .58573 Mdot
.976 .58574 Mdot
.976 .58586 Mdot
.976 .58587 Mdot
.976 .58589 Mdot
.976 .58595 Mdot
.976 .58599 Mdot
.976 .58605 Mdot
.976 .58624 Mdot
.976 .58641 Mdot
.976 .58644 Mdot
.976 .58656 Mdot
.976 .5866 Mdot
.976 .58665 Mdot
.976 .58674 Mdot
.976 .58686 Mdot
.976 .58689 Mdot
.976 .5869 Mdot
.976 .58694 Mdot
.976 .58695 Mdot
.976 .58725 Mdot
.976 .58728 Mdot
.976 .58729 Mdot
.976 .5873 Mdot
.976 .58733 Mdot
.976 .58738 Mdot
.976 .58747 Mdot
.976 .58761 Mdot
.976 .5877 Mdot
.976 .58771 Mdot
.976 .58777 Mdot
.976 .58778 Mdot
.976 .58783 Mdot
.976 .58785 Mdot
.976 .58786 Mdot
.976 .58789 Mdot
.976 .58792 Mdot
.976 .58793 Mdot
.976 .588 Mdot
.976 .58807 Mdot
.976 .58809 Mdot
.976 .5881 Mdot
.976 .58819 Mdot
.976 .58826 Mdot
.976 .58827 Mdot
.976 .58831 Mdot
.976 .58838 Mdot
.976 .58839 Mdot
.976 .5884 Mdot
.976 .5885 Mdot
.976 .58856 Mdot
.976 .58857 Mdot
.976 .5886 Mdot
.976 .58865 Mdot
.976 .58867 Mdot
.976 .58868 Mdot
.976 .58874 Mdot
.976 .58876 Mdot
.976 .58877 Mdot
.976 .58879 Mdot
.976 .58879 Mdot
.976 .58881 Mdot
.976 .58886 Mdot
.976 .58892 Mdot
.976 .58896 Mdot
.976 .58896 Mdot
.976 .58898 Mdot
.976 .58898 Mdot
.976 .58899 Mdot
.976 .58899 Mdot
.976 .589 Mdot
.976 .58901 Mdot
.976 .58906 Mdot
.976 .58907 Mdot
.976 .58909 Mdot
.976 .5891 Mdot
.976 .58912 Mdot
.976 .58912 Mdot
.976 .58913 Mdot
.976 .58914 Mdot
.976 .58914 Mdot
.976 .58915 Mdot
.976 .58915 Mdot
.976 .58916 Mdot
.976 .58916 Mdot
.976 .58918 Mdot
.976 .58918 Mdot
.976 .58919 Mdot
.976 .5892 Mdot
.976 .5892 Mdot
.978 .1836 Mdot
.978 .18361 Mdot
.978 .18363 Mdot
.978 .18364 Mdot
.978 .18365 Mdot
.978 .18371 Mdot
.978 .18378 Mdot
.978 .1838 Mdot
.978 .18387 Mdot
.978 .18394 Mdot
.978 .18397 Mdot
.978 .18404 Mdot
.978 .18414 Mdot
.978 .18419 Mdot
.978 .18426 Mdot
.978 .18427 Mdot
.978 .1844 Mdot
.978 .18446 Mdot
.978 .18449 Mdot
.978 .18457 Mdot
.978 .18462 Mdot
.978 .18466 Mdot
.978 .1848 Mdot
.978 .18495 Mdot
.978 .18503 Mdot
.978 .18525 Mdot
.978 .18533 Mdot
.978 .18543 Mdot
.978 .18544 Mdot
.978 .18557 Mdot
.978 .18561 Mdot
.978 .18564 Mdot
.978 .18586 Mdot
.978 .18593 Mdot
.978 .18607 Mdot
.978 .18612 Mdot
.978 .18631 Mdot
.978 .18653 Mdot
.978 .18654 Mdot
.978 .18672 Mdot
.978 .18699 Mdot
.978 .1872 Mdot
.978 .18724 Mdot
.978 .18743 Mdot
.978 .18752 Mdot
.978 .18764 Mdot
.978 .18779 Mdot
.978 .18785 Mdot
.978 .18789 Mdot
.978 .18807 Mdot
.978 .18829 Mdot
.978 .18834 Mdot
.978 .1886 Mdot
.978 .18866 Mdot
.978 .18876 Mdot
.978 .18878 Mdot
.978 .18889 Mdot
.978 .18892 Mdot
.978 .18908 Mdot
.978 .1891 Mdot
.978 .18916 Mdot
.978 .18936 Mdot
.978 .19092 Mdot
.978 .1911 Mdot
.978 .19135 Mdot
.978 .19208 Mdot
.978 .19228 Mdot
.978 .19328 Mdot
.978 .19348 Mdot
.978 .19348 Mdot
.978 .19514 Mdot
.978 .19553 Mdot
.978 .19565 Mdot
.978 .19569 Mdot
.978 .19597 Mdot
.978 .19621 Mdot
.978 .19808 Mdot
.978 .19839 Mdot
.978 .19855 Mdot
.978 .19871 Mdot
.978 .19937 Mdot
.978 .19969 Mdot
.978 .20027 Mdot
.978 .20093 Mdot
.978 .20179 Mdot
.978 .20192 Mdot
.978 .20224 Mdot
.978 .20229 Mdot
.978 .2026 Mdot
.978 .20271 Mdot
.978 .20285 Mdot
.978 .20286 Mdot
.978 .20311 Mdot
.978 .20312 Mdot
.978 .20334 Mdot
.978 .20336 Mdot
.978 .20349 Mdot
.978 .20354 Mdot
.978 .20389 Mdot
.978 .20417 Mdot
.978 .20441 Mdot
.978 .20484 Mdot
.978 .20498 Mdot
.978 .20512 Mdot
.978 .20598 Mdot
.978 .20631 Mdot
.978 .2065 Mdot
.978 .20801 Mdot
.978 .20871 Mdot
.978 .20997 Mdot
.978 .21003 Mdot
.978 .21014 Mdot
.978 .21016 Mdot
.978 .21025 Mdot
.978 .21056 Mdot
.978 .2106 Mdot
.978 .21077 Mdot
.978 .21099 Mdot
.978 .21111 Mdot
.978 .21149 Mdot
.978 .21191 Mdot
.978 .21208 Mdot
.978 .21231 Mdot
.978 .2125 Mdot
.978 .21277 Mdot
.978 .21302 Mdot
.978 .2131 Mdot
.978 .21327 Mdot
.978 .21339 Mdot
.978 .21378 Mdot
.978 .21389 Mdot
.978 .21411 Mdot
.978 .21446 Mdot
.978 .21464 Mdot
.978 .21476 Mdot
.978 .21503 Mdot
.978 .21517 Mdot
.978 .21528 Mdot
.978 .21569 Mdot
.978 .21577 Mdot
.978 .21599 Mdot
.978 .2162 Mdot
.978 .21628 Mdot
.978 .2166 Mdot
.978 .21706 Mdot
.978 .21725 Mdot
.978 .21799 Mdot
.978 .21841 Mdot
.978 .21848 Mdot
.978 .21988 Mdot
.978 .2204 Mdot
.978 .22103 Mdot
.978 .22108 Mdot
.978 .22193 Mdot
.978 .22217 Mdot
.978 .22238 Mdot
.978 .22275 Mdot
.978 .2229 Mdot
.978 .22336 Mdot
.978 .2238 Mdot
.978 .22403 Mdot
.978 .2242 Mdot
.978 .22427 Mdot
.978 .22455 Mdot
.978 .22458 Mdot
.978 .22514 Mdot
.978 .22519 Mdot
.978 .22528 Mdot
.978 .22552 Mdot
.978 .22571 Mdot
.978 .22676 Mdot
.978 .22704 Mdot
.978 .22748 Mdot
.978 .22819 Mdot
.978 .2283 Mdot
.978 .2283 Mdot
.978 .22946 Mdot
.978 .22948 Mdot
.978 .22963 Mdot
.978 .2309 Mdot
.978 .23128 Mdot
.978 .23271 Mdot
.978 .23276 Mdot
.978 .23293 Mdot
.978 .23293 Mdot
.978 .23303 Mdot
.978 .23304 Mdot
.978 .23348 Mdot
.978 .23365 Mdot
.978 .23433 Mdot
.978 .23493 Mdot
.978 .23576 Mdot
.978 .23599 Mdot
.978 .23673 Mdot
.978 .23682 Mdot
.978 .23722 Mdot
.978 .23735 Mdot
.978 .23746 Mdot
.978 .23811 Mdot
.978 .23875 Mdot
.978 .24023 Mdot
.978 .24029 Mdot
.978 .24066 Mdot
.978 .24084 Mdot
.978 .24085 Mdot
.978 .2418 Mdot
.978 .24207 Mdot
.978 .24245 Mdot
.978 .2425 Mdot
.978 .24291 Mdot
.978 .24351 Mdot
.978 .24359 Mdot
.978 .24373 Mdot
.978 .24453 Mdot
.978 .24476 Mdot
.978 .24585 Mdot
.978 .24604 Mdot
.978 .24642 Mdot
.978 .24686 Mdot
.978 .24788 Mdot
.978 .24857 Mdot
.978 .24914 Mdot
.978 .24938 Mdot
.978 .24959 Mdot
.978 .2497 Mdot
.978 .25031 Mdot
.978 .25044 Mdot
.978 .25088 Mdot
.978 .25096 Mdot
.978 .25101 Mdot
.978 .25135 Mdot
.978 .25161 Mdot
.978 .25182 Mdot
.978 .25252 Mdot
.978 .25262 Mdot
.978 .25284 Mdot
.978 .25287 Mdot
.978 .25372 Mdot
.978 .25447 Mdot
.978 .25461 Mdot
.978 .25484 Mdot
.978 .25489 Mdot
.978 .25533 Mdot
.978 .25547 Mdot
.978 .25595 Mdot
.978 .25631 Mdot
.978 .25681 Mdot
.978 .25708 Mdot
.978 .25708 Mdot
.978 .25724 Mdot
.978 .25727 Mdot
.978 .25813 Mdot
.978 .25836 Mdot
.978 .25914 Mdot
.978 .25922 Mdot
.978 .25924 Mdot
.978 .25995 Mdot
.978 .25995 Mdot
.978 .26002 Mdot
.978 .26046 Mdot
.978 .26091 Mdot
.978 .26169 Mdot
.978 .26189 Mdot
.978 .26228 Mdot
.978 .2623 Mdot
.978 .26248 Mdot
.978 .26263 Mdot
.978 .26278 Mdot
.978 .26336 Mdot
.978 .26346 Mdot
.978 .2637 Mdot
.978 .26383 Mdot
.978 .26399 Mdot
.978 .26454 Mdot
.978 .26458 Mdot
.978 .26499 Mdot
.978 .26534 Mdot
.978 .26627 Mdot
.978 .26632 Mdot
.978 .2666 Mdot
.978 .26724 Mdot
.978 .26755 Mdot
.978 .26783 Mdot
.978 .26798 Mdot
.978 .26818 Mdot
.978 .26854 Mdot
.978 .26864 Mdot
.978 .26883 Mdot
.978 .26891 Mdot
.978 .26904 Mdot
.978 .26929 Mdot
.978 .26945 Mdot
.978 .26952 Mdot
.978 .26981 Mdot
.978 .27001 Mdot
.978 .27007 Mdot
.978 .27025 Mdot
.978 .27045 Mdot
.978 .27075 Mdot
.978 .27087 Mdot
.978 .27118 Mdot
.978 .27145 Mdot
.978 .27155 Mdot
.978 .27171 Mdot
.978 .27186 Mdot
.978 .27209 Mdot
.978 .27216 Mdot
.978 .27218 Mdot
.978 .27226 Mdot
.978 .2723 Mdot
.978 .27379 Mdot
.978 .27498 Mdot
.978 .27632 Mdot
.978 .27667 Mdot
.978 .27755 Mdot
.978 .27756 Mdot
.978 .27775 Mdot
.978 .27776 Mdot
.978 .2781 Mdot
.978 .27819 Mdot
.978 .28107 Mdot
.978 .28183 Mdot
.978 .28439 Mdot
.978 .28468 Mdot
.978 .28472 Mdot
.978 .28708 Mdot
.978 .28709 Mdot
.978 .28731 Mdot
.978 .28875 Mdot
.978 .28965 Mdot
.978 .29021 Mdot
.978 .29237 Mdot
.978 .29276 Mdot
.978 .29325 Mdot
.978 .29343 Mdot
.978 .29353 Mdot
.978 .29469 Mdot
.978 .29475 Mdot
.978 .29532 Mdot
.978 .29548 Mdot
.978 .29582 Mdot
.978 .2963 Mdot
.978 .2972 Mdot
.978 .29816 Mdot
.978 .29847 Mdot
.978 .29924 Mdot
.978 .29966 Mdot
.978 .30016 Mdot
.978 .30193 Mdot
.978 .30205 Mdot
.978 .30335 Mdot
.978 .30444 Mdot
.978 .30737 Mdot
.978 .30751 Mdot
.978 .30839 Mdot
.978 .30995 Mdot
.978 .31035 Mdot
.978 .31132 Mdot
.978 .31198 Mdot
.978 .31215 Mdot
.978 .3126 Mdot
.978 .31306 Mdot
.978 .31322 Mdot
.978 .3141 Mdot
.978 .31433 Mdot
.978 .31462 Mdot
.978 .31519 Mdot
.978 .31544 Mdot
.978 .31583 Mdot
.978 .31657 Mdot
.978 .31703 Mdot
.978 .31726 Mdot
.978 .3181 Mdot
.978 .31835 Mdot
.978 .31871 Mdot
.978 .31888 Mdot
.978 .3194 Mdot
.978 .31999 Mdot
.978 .3204 Mdot
.978 .32087 Mdot
.978 .32123 Mdot
.978 .32213 Mdot
.978 .32293 Mdot
.978 .32319 Mdot
.978 .32366 Mdot
.978 .32402 Mdot
.978 .3241 Mdot
.978 .32476 Mdot
.978 .32496 Mdot
.978 .32501 Mdot
.978 .32524 Mdot
.978 .32536 Mdot
.978 .32807 Mdot
.978 .32954 Mdot
.978 .33278 Mdot
.978 .33319 Mdot
.978 .3339 Mdot
.978 .33576 Mdot
.978 .33605 Mdot
.978 .33636 Mdot
.978 .33727 Mdot
.978 .3378 Mdot
.978 .33839 Mdot
.978 .33915 Mdot
.978 .33926 Mdot
.978 .33954 Mdot
.978 .33959 Mdot
.978 .34006 Mdot
.978 .34008 Mdot
.978 .3406 Mdot
.978 .34065 Mdot
.978 .34094 Mdot
.978 .34117 Mdot
.978 .34184 Mdot
.978 .34195 Mdot
.978 .34265 Mdot
.978 .34291 Mdot
.978 .34478 Mdot
.978 .34621 Mdot
.978 .34746 Mdot
.978 .34815 Mdot
.978 .34957 Mdot
.978 .34991 Mdot
.978 .35027 Mdot
.978 .35093 Mdot
.978 .35498 Mdot
.978 .35551 Mdot
.978 .35611 Mdot
.978 .3562 Mdot
.978 .35647 Mdot
.978 .3573 Mdot
.978 .3609 Mdot
.978 .3609 Mdot
.978 .36133 Mdot
.978 .36351 Mdot
.978 .36395 Mdot
.978 .36552 Mdot
.978 .36607 Mdot
.978 .36646 Mdot
.978 .36985 Mdot
.978 .37029 Mdot
.978 .37041 Mdot
.978 .37047 Mdot
.978 .3708 Mdot
.978 .37087 Mdot
.978 .37111 Mdot
.978 .37116 Mdot
.978 .37137 Mdot
.978 .37151 Mdot
.978 .37206 Mdot
.978 .37217 Mdot
.978 .37265 Mdot
.978 .37305 Mdot
.978 .37313 Mdot
.978 .37325 Mdot
.978 .37359 Mdot
.978 .37385 Mdot
.978 .37404 Mdot
.978 .37445 Mdot
.978 .37455 Mdot
.978 .37501 Mdot
.978 .37558 Mdot
.978 .37597 Mdot
.978 .37601 Mdot
.978 .37647 Mdot
.978 .37688 Mdot
.978 .37699 Mdot
.978 .37729 Mdot
.978 .37745 Mdot
.978 .37793 Mdot
.978 .378 Mdot
.978 .37808 Mdot
.978 .37837 Mdot
.978 .37839 Mdot
.978 .3786 Mdot
.978 .37878 Mdot
.978 .37927 Mdot
.978 .37944 Mdot
.978 .37976 Mdot
.978 .38007 Mdot
.978 .38014 Mdot
.978 .38025 Mdot
.978 .38044 Mdot
.978 .38049 Mdot
.978 .38063 Mdot
.978 .3809 Mdot
.978 .38094 Mdot
.978 .38108 Mdot
.978 .38119 Mdot
.978 .38141 Mdot
.978 .38156 Mdot
.978 .38163 Mdot
.978 .38178 Mdot
.978 .38192 Mdot
.978 .38197 Mdot
.978 .38213 Mdot
.978 .38225 Mdot
.978 .38227 Mdot
.978 .38229 Mdot
.978 .38233 Mdot
.978 .38236 Mdot
.978 .53549 Mdot
.978 .5355 Mdot
.978 .53552 Mdot
.978 .53553 Mdot
.978 .53553 Mdot
.978 .53558 Mdot
.978 .53565 Mdot
.978 .53567 Mdot
.978 .53573 Mdot
.978 .5358 Mdot
.978 .53582 Mdot
.978 .53589 Mdot
.978 .53598 Mdot
.978 .53603 Mdot
.978 .53609 Mdot
.978 .53611 Mdot
.978 .53622 Mdot
.978 .53628 Mdot
.978 .5363 Mdot
.978 .53638 Mdot
.978 .53642 Mdot
.978 .53645 Mdot
.978 .53658 Mdot
.978 .53672 Mdot
.978 .53679 Mdot
.978 .53699 Mdot
.978 .53707 Mdot
.978 .53716 Mdot
.978 .53716 Mdot
.978 .53729 Mdot
.978 .53732 Mdot
.978 .53735 Mdot
.978 .53755 Mdot
.978 .53761 Mdot
.978 .53774 Mdot
.978 .53778 Mdot
.978 .53795 Mdot
.978 .53814 Mdot
.978 .53816 Mdot
.978 .53832 Mdot
.978 .53855 Mdot
.978 .53874 Mdot
.978 .53878 Mdot
.978 .53895 Mdot
.978 .53903 Mdot
.978 .53914 Mdot
.978 .53927 Mdot
.978 .53932 Mdot
.978 .53935 Mdot
.978 .53952 Mdot
.978 .53971 Mdot
.978 .53976 Mdot
.978 .53998 Mdot
.978 .54004 Mdot
.978 .54012 Mdot
.978 .54014 Mdot
.978 .54024 Mdot
.978 .54027 Mdot
.978 .5404 Mdot
.978 .54042 Mdot
.978 .54047 Mdot
.978 .54065 Mdot
.978 .54199 Mdot
.978 .54215 Mdot
.978 .54236 Mdot
.978 .54298 Mdot
.978 .54315 Mdot
.978 .54399 Mdot
.978 .54416 Mdot
.978 .54416 Mdot
.978 .54553 Mdot
.978 .54585 Mdot
.978 .54595 Mdot
.978 .54598 Mdot
.978 .54621 Mdot
.978 .54641 Mdot
.978 .54791 Mdot
.978 .54816 Mdot
.978 .54829 Mdot
.978 .54841 Mdot
.978 .54893 Mdot
.978 .54918 Mdot
.978 .54963 Mdot
.978 .55014 Mdot
.978 .55081 Mdot
.978 .5509 Mdot
.978 .55115 Mdot
.978 .55119 Mdot
.978 .55142 Mdot
.978 .5515 Mdot
.978 .55161 Mdot
.978 .55162 Mdot
.978 .55181 Mdot
.978 .55181 Mdot
.978 .55198 Mdot
.978 .552 Mdot
.978 .55209 Mdot
.978 .55213 Mdot
.978 .5524 Mdot
.978 .5526 Mdot
.978 .55279 Mdot
.978 .5531 Mdot
.978 .55321 Mdot
.978 .55331 Mdot
.978 .55394 Mdot
.978 .55418 Mdot
.978 .55432 Mdot
.978 .55541 Mdot
.978 .5559 Mdot
.978 .55679 Mdot
.978 .55683 Mdot
.978 .55691 Mdot
.978 .55693 Mdot
.978 .55699 Mdot
.978 .55721 Mdot
.978 .55723 Mdot
.978 .55735 Mdot
.978 .5575 Mdot
.978 .55759 Mdot
.978 .55784 Mdot
.978 .55814 Mdot
.978 .55825 Mdot
.978 .5584 Mdot
.978 .55853 Mdot
.978 .55872 Mdot
.978 .55889 Mdot
.978 .55894 Mdot
.978 .55906 Mdot
.978 .55914 Mdot
.978 .5594 Mdot
.978 .55947 Mdot
.978 .55962 Mdot
.978 .55985 Mdot
.978 .55997 Mdot
.978 .56005 Mdot
.978 .56023 Mdot
.978 .56032 Mdot
.978 .56039 Mdot
.978 .56067 Mdot
.978 .56072 Mdot
.978 .56086 Mdot
.978 .561 Mdot
.978 .56105 Mdot
.978 .56125 Mdot
.978 .56155 Mdot
.978 .56167 Mdot
.978 .56215 Mdot
.978 .56241 Mdot
.978 .56246 Mdot
.978 .56333 Mdot
.978 .56366 Mdot
.978 .56404 Mdot
.978 .56408 Mdot
.978 .5646 Mdot
.978 .56474 Mdot
.978 .56486 Mdot
.978 .56509 Mdot
.978 .56518 Mdot
.978 .56545 Mdot
.978 .56571 Mdot
.978 .56585 Mdot
.978 .56595 Mdot
.978 .56599 Mdot
.978 .56616 Mdot
.978 .56617 Mdot
.978 .5665 Mdot
.978 .56653 Mdot
.978 .56658 Mdot
.978 .56672 Mdot
.978 .56683 Mdot
.978 .56743 Mdot
.978 .56759 Mdot
.978 .56784 Mdot
.978 .56824 Mdot
.978 .5683 Mdot
.978 .5683 Mdot
.978 .56894 Mdot
.978 .56896 Mdot
.978 .56903 Mdot
.978 .56972 Mdot
.978 .56993 Mdot
.978 .57069 Mdot
.978 .57071 Mdot
.978 .5708 Mdot
.978 .57081 Mdot
.978 .57085 Mdot
.978 .57086 Mdot
.978 .57109 Mdot
.978 .57118 Mdot
.978 .57153 Mdot
.978 .57183 Mdot
.978 .57222 Mdot
.978 .57223 Mdot
.978 .57225 Mdot
.978 .57225 Mdot
.978 .57227 Mdot
.978 .57233 Mdot
.978 .57237 Mdot
.978 .57241 Mdot
.978 .57243 Mdot
.978 .5725 Mdot
.978 .57258 Mdot
.978 .57261 Mdot
.978 .57269 Mdot
.978 .57274 Mdot
.978 .57279 Mdot
.978 .5728 Mdot
.978 .57285 Mdot
.978 .57292 Mdot
.978 .57294 Mdot
.978 .57298 Mdot
.978 .57304 Mdot
.978 .57308 Mdot
.978 .5731 Mdot
.978 .57315 Mdot
.978 .57317 Mdot
.978 .57326 Mdot
.978 .57331 Mdot
.978 .57335 Mdot
.978 .57342 Mdot
.978 .5735 Mdot
.978 .57366 Mdot
.978 .57373 Mdot
.978 .57374 Mdot
.978 .57397 Mdot
.978 .57405 Mdot
.978 .57416 Mdot
.978 .57417 Mdot
.978 .5743 Mdot
.978 .57434 Mdot
.978 .57437 Mdot
.978 .57443 Mdot
.978 .57446 Mdot
.978 .5746 Mdot
.978 .57463 Mdot
.978 .57467 Mdot
.978 .57471 Mdot
.978 .57472 Mdot
.978 .57481 Mdot
.978 .57486 Mdot
.978 .57505 Mdot
.978 .57516 Mdot
.978 .57527 Mdot
.978 .57528 Mdot
.978 .57528 Mdot
.978 .57546 Mdot
.978 .57546 Mdot
.978 .57548 Mdot
.978 .57566 Mdot
.978 .57572 Mdot
.978 .57592 Mdot
.978 .57593 Mdot
.978 .57597 Mdot
.978 .57597 Mdot
.978 .57603 Mdot
.978 .57615 Mdot
.978 .57624 Mdot
.978 .57635 Mdot
.978 .57638 Mdot
.978 .57649 Mdot
.978 .5765 Mdot
.978 .57655 Mdot
.978 .57658 Mdot
.978 .57676 Mdot
.978 .57696 Mdot
.978 .57697 Mdot
.978 .57702 Mdot
.978 .57704 Mdot
.978 .5772 Mdot
.978 .57725 Mdot
.978 .57731 Mdot
.978 .57739 Mdot
.978 .5774 Mdot
.978 .57742 Mdot
.978 .57752 Mdot
.978 .57755 Mdot
.978 .57769 Mdot
.978 .57771 Mdot
.978 .57776 Mdot
.978 .57782 Mdot
.978 .57795 Mdot
.978 .5781 Mdot
.978 .57833 Mdot
.978 .57843 Mdot
.978 .57852 Mdot
.978 .57856 Mdot
.978 .5788 Mdot
.978 .57886 Mdot
.978 .57903 Mdot
.978 .57906 Mdot
.978 .57908 Mdot
.978 .57921 Mdot
.978 .5793 Mdot
.978 .57932 Mdot
.978 .5794 Mdot
.978 .57946 Mdot
.978 .57967 Mdot
.978 .57967 Mdot
.978 .57971 Mdot
.978 .57979 Mdot
.978 .5798 Mdot
.978 .58012 Mdot
.978 .58026 Mdot
.978 .5804 Mdot
.978 .58042 Mdot
.978 .58045 Mdot
.978 .58054 Mdot
.978 .58056 Mdot
.978 .58072 Mdot
.978 .58076 Mdot
.978 .58094 Mdot
.978 .58107 Mdot
.978 .58121 Mdot
.978 .58125 Mdot
.978 .58134 Mdot
.978 .58134 Mdot
.978 .58136 Mdot
.978 .58136 Mdot
.978 .5814 Mdot
.978 .58141 Mdot
.978 .58171 Mdot
.978 .58178 Mdot
.978 .58205 Mdot
.978 .58208 Mdot
.978 .58208 Mdot
.978 .58232 Mdot
.978 .58232 Mdot
.978 .58234 Mdot
.978 .58249 Mdot
.978 .58258 Mdot
.978 .58263 Mdot
.978 .58284 Mdot
.978 .58288 Mdot
.978 .58293 Mdot
.978 .58295 Mdot
.978 .58296 Mdot
.978 .58307 Mdot
.978 .58308 Mdot
.978 .58313 Mdot
.978 .58315 Mdot
.978 .58318 Mdot
.978 .58323 Mdot
.978 .58331 Mdot
.978 .58341 Mdot
.978 .58344 Mdot
.978 .58351 Mdot
.978 .58355 Mdot
.978 .5836 Mdot
.978 .58376 Mdot
.978 .58377 Mdot
.978 .5839 Mdot
.978 .584 Mdot
.978 .58427 Mdot
.978 .58428 Mdot
.978 .58437 Mdot
.978 .58451 Mdot
.978 .58454 Mdot
.978 .58463 Mdot
.978 .58469 Mdot
.978 .58471 Mdot
.978 .58475 Mdot
.978 .58479 Mdot
.978 .58481 Mdot
.978 .58489 Mdot
.978 .58491 Mdot
.978 .58493 Mdot
.978 .58498 Mdot
.978 .58501 Mdot
.978 .58504 Mdot
.978 .58511 Mdot
.978 .58515 Mdot
.978 .58517 Mdot
.978 .58524 Mdot
.978 .58527 Mdot
.978 .5853 Mdot
.978 .58531 Mdot
.978 .58536 Mdot
.978 .58541 Mdot
.978 .58545 Mdot
.978 .58549 Mdot
.978 .58552 Mdot
.978 .5856 Mdot
.978 .58567 Mdot
.978 .58569 Mdot
.978 .58573 Mdot
.978 .58576 Mdot
.978 .58577 Mdot
.978 .58583 Mdot
.978 .58584 Mdot
.978 .58585 Mdot
.978 .58587 Mdot
.978 .58588 Mdot
.978 .58611 Mdot
.978 .58624 Mdot
.978 .58651 Mdot
.978 .58655 Mdot
.978 .58661 Mdot
.978 .58676 Mdot
.978 .58679 Mdot
.978 .58681 Mdot
.978 .58689 Mdot
.978 .58693 Mdot
.978 .58698 Mdot
.978 .58704 Mdot
.978 .58705 Mdot
.978 .58707 Mdot
.978 .58708 Mdot
.978 .58712 Mdot
.978 .58712 Mdot
.978 .58716 Mdot
.978 .58716 Mdot
.978 .58719 Mdot
.978 .58721 Mdot
.978 .58726 Mdot
.978 .58727 Mdot
.978 .58733 Mdot
.978 .58735 Mdot
.978 .5875 Mdot
.978 .58762 Mdot
.978 .58772 Mdot
.978 .58777 Mdot
.978 .58789 Mdot
.978 .58791 Mdot
.978 .58794 Mdot
.978 .58799 Mdot
.978 .58831 Mdot
.978 .58836 Mdot
.978 .5884 Mdot
.978 .58841 Mdot
.978 .58843 Mdot
.978 .5885 Mdot
.978 .58877 Mdot
.978 .58877 Mdot
.978 .58881 Mdot
.978 .58897 Mdot
.978 .58901 Mdot
.978 .58913 Mdot
.978 .58917 Mdot
.978 .5892 Mdot
.978 .58945 Mdot
.978 .58949 Mdot
.978 .5895 Mdot
.978 .5895 Mdot
.978 .58952 Mdot
.978 .58953 Mdot
.978 .58955 Mdot
.978 .58955 Mdot
.978 .58957 Mdot
.978 .58958 Mdot
.978 .58962 Mdot
.978 .58963 Mdot
.978 .58966 Mdot
.978 .58969 Mdot
.978 .5897 Mdot
.978 .58971 Mdot
.978 .58973 Mdot
.978 .58975 Mdot
.978 .58977 Mdot
.978 .5898 Mdot
.978 .5898 Mdot
.978 .58984 Mdot
.978 .58988 Mdot
.978 .58991 Mdot
.978 .58991 Mdot
.978 .58995 Mdot
.978 .58998 Mdot
.978 .58998 Mdot
.978 .59001 Mdot
.978 .59002 Mdot
.978 .59005 Mdot
.978 .59006 Mdot
.978 .59006 Mdot
.978 .59008 Mdot
.978 .59009 Mdot
.978 .5901 Mdot
.978 .59011 Mdot
.978 .59015 Mdot
.978 .59016 Mdot
.978 .59019 Mdot
.978 .59021 Mdot
.978 .59021 Mdot
.978 .59022 Mdot
.978 .59024 Mdot
.978 .59025 Mdot
.978 .59027 Mdot
.978 .59027 Mdot
.978 .59028 Mdot
.978 .59029 Mdot
.978 .59031 Mdot
.978 .59032 Mdot
.978 .59032 Mdot
.978 .59033 Mdot
.978 .59034 Mdot
.978 .59035 Mdot
.978 .59036 Mdot
.978 .59037 Mdot
.978 .59037 Mdot
.978 .59037 Mdot
.978 .59037 Mdot
.978 .59037 Mdot
.98 .17623 Mdot
.98 .17627 Mdot
.98 .17635 Mdot
.98 .17637 Mdot
.98 .17637 Mdot
.98 .17655 Mdot
.98 .17667 Mdot
.98 .17668 Mdot
.98 .17679 Mdot
.98 .17688 Mdot
.98 .1769 Mdot
.98 .17692 Mdot
.98 .17702 Mdot
.98 .17724 Mdot
.98 .17726 Mdot
.98 .17746 Mdot
.98 .17768 Mdot
.98 .17769 Mdot
.98 .17771 Mdot
.98 .17789 Mdot
.98 .17876 Mdot
.98 .17886 Mdot
.98 .17897 Mdot
.98 .17902 Mdot
.98 .17907 Mdot
.98 .17907 Mdot
.98 .17918 Mdot
.98 .17922 Mdot
.98 .17951 Mdot
.98 .17964 Mdot
.98 .1798 Mdot
.98 .17981 Mdot
.98 .17984 Mdot
.98 .17986 Mdot
.98 .1799 Mdot
.98 .18013 Mdot
.98 .18031 Mdot
.98 .18032 Mdot
.98 .18034 Mdot
.98 .18037 Mdot
.98 .18039 Mdot
.98 .18044 Mdot
.98 .1805 Mdot
.98 .18077 Mdot
.98 .18083 Mdot
.98 .18141 Mdot
.98 .18142 Mdot
.98 .18148 Mdot
.98 .18151 Mdot
.98 .18163 Mdot
.98 .18212 Mdot
.98 .18213 Mdot
.98 .18289 Mdot
.98 .1829 Mdot
.98 .1829 Mdot
.98 .18298 Mdot
.98 .18339 Mdot
.98 .18342 Mdot
.98 .18361 Mdot
.98 .18465 Mdot
.98 .1849 Mdot
.98 .18616 Mdot
.98 .18708 Mdot
.98 .1875 Mdot
.98 .18768 Mdot
.98 .18785 Mdot
.98 .188 Mdot
.98 .18814 Mdot
.98 .18822 Mdot
.98 .18831 Mdot
.98 .18845 Mdot
.98 .18845 Mdot
.98 .18848 Mdot
.98 .18894 Mdot
.98 .18914 Mdot
.98 .1892 Mdot
.98 .18944 Mdot
.98 .18987 Mdot
.98 .19053 Mdot
.98 .19054 Mdot
.98 .19089 Mdot
.98 .19116 Mdot
.98 .19134 Mdot
.98 .19193 Mdot
.98 .19198 Mdot
.98 .19204 Mdot
.98 .19209 Mdot
.98 .19216 Mdot
.98 .19224 Mdot
.98 .19247 Mdot
.98 .19263 Mdot
.98 .19312 Mdot
.98 .19365 Mdot
.98 .19366 Mdot
.98 .19404 Mdot
.98 .19415 Mdot
.98 .19452 Mdot
.98 .19459 Mdot
.98 .19468 Mdot
.98 .19476 Mdot
.98 .19492 Mdot
.98 .19506 Mdot
.98 .19532 Mdot
.98 .19562 Mdot
.98 .19584 Mdot
.98 .19616 Mdot
.98 .19655 Mdot
.98 .19715 Mdot
.98 .19749 Mdot
.98 .19789 Mdot
.98 .19839 Mdot
.98 .1993 Mdot
.98 .19947 Mdot
.98 .2 Mdot
.98 .20089 Mdot
.98 .20095 Mdot
.98 .20127 Mdot
.98 .20146 Mdot
.98 .20194 Mdot
.98 .20209 Mdot
.98 .20221 Mdot
.98 .20368 Mdot
.98 .20419 Mdot
.98 .20463 Mdot
.98 .20493 Mdot
.98 .20527 Mdot
.98 .20533 Mdot
.98 .20704 Mdot
.98 .20787 Mdot
.98 .20868 Mdot
.98 .209 Mdot
.98 .20914 Mdot
.98 .20989 Mdot
.98 .20994 Mdot
.98 .20996 Mdot
.98 .21028 Mdot
.98 .21032 Mdot
.98 .21037 Mdot
.98 .21087 Mdot
.98 .2111 Mdot
.98 .21246 Mdot
.98 .21312 Mdot
.98 .21348 Mdot
.98 .21369 Mdot
.98 .21374 Mdot
.98 .21391 Mdot
.98 .21448 Mdot
.98 .21518 Mdot
.98 .21558 Mdot
.98 .21636 Mdot
.98 .2174 Mdot
.98 .21741 Mdot
.98 .2183 Mdot
.98 .21833 Mdot
.98 .21884 Mdot
.98 .21942 Mdot
.98 .21971 Mdot
.98 .22001 Mdot
.98 .22001 Mdot
.98 .22027 Mdot
.98 .22163 Mdot
.98 .22205 Mdot
.98 .22261 Mdot
.98 .22301 Mdot
.98 .22343 Mdot
.98 .22348 Mdot
.98 .22443 Mdot
.98 .22474 Mdot
.98 .22548 Mdot
.98 .22631 Mdot
.98 .22709 Mdot
.98 .22718 Mdot
.98 .22732 Mdot
.98 .22794 Mdot
.98 .22845 Mdot
.98 .22881 Mdot
.98 .22912 Mdot
.98 .22937 Mdot
.98 .22958 Mdot
.98 .22981 Mdot
.98 .22997 Mdot
.98 .23001 Mdot
.98 .2323 Mdot
.98 .23302 Mdot
.98 .23397 Mdot
.98 .23408 Mdot
.98 .23509 Mdot
.98 .23547 Mdot
.98 .23551 Mdot
.98 .23576 Mdot
.98 .23578 Mdot
.98 .2366 Mdot
.98 .23693 Mdot
.98 .23701 Mdot
.98 .23817 Mdot
.98 .23845 Mdot
.98 .23897 Mdot
.98 .23989 Mdot
.98 .2404 Mdot
.98 .24087 Mdot
.98 .2411 Mdot
.98 .24113 Mdot
.98 .2415 Mdot
.98 .24195 Mdot
.98 .24343 Mdot
.98 .24362 Mdot
.98 .24362 Mdot
.98 .24386 Mdot
.98 .24395 Mdot
.98 .24398 Mdot
.98 .24439 Mdot
.98 .24454 Mdot
.98 .24494 Mdot
.98 .24525 Mdot
.98 .24579 Mdot
.98 .24584 Mdot
.98 .24585 Mdot
.98 .24647 Mdot
.98 .24716 Mdot
.98 .24719 Mdot
.98 .24794 Mdot
.98 .24834 Mdot
.98 .24834 Mdot
.98 .24845 Mdot
.98 .24948 Mdot
.98 .2497 Mdot
.98 .25007 Mdot
.98 .25085 Mdot
.98 .25114 Mdot
.98 .25192 Mdot
.98 .25197 Mdot
.98 .25215 Mdot
.98 .25261 Mdot
.98 .25261 Mdot
.98 .25299 Mdot
.98 .25361 Mdot
.98 .25587 Mdot
.98 .25673 Mdot
.98 .25747 Mdot
.98 .25752 Mdot
.98 .25797 Mdot
.98 .25889 Mdot
.98 .25907 Mdot
.98 .25992 Mdot
.98 .26015 Mdot
.98 .26172 Mdot
.98 .26277 Mdot
.98 .26333 Mdot
.98 .26472 Mdot
.98 .26553 Mdot
.98 .26564 Mdot
.98 .26567 Mdot
.98 .26581 Mdot
.98 .26647 Mdot
.98 .26751 Mdot
.98 .26784 Mdot
.98 .26788 Mdot
.98 .2679 Mdot
.98 .26813 Mdot
.98 .26816 Mdot
.98 .26866 Mdot
.98 .26876 Mdot
.98 .26952 Mdot
.98 .27129 Mdot
.98 .27133 Mdot
.98 .27157 Mdot
.98 .27178 Mdot
.98 .27353 Mdot
.98 .27373 Mdot
.98 .27409 Mdot
.98 .27423 Mdot
.98 .27447 Mdot
.98 .27451 Mdot
.98 .27519 Mdot
.98 .27715 Mdot
.98 .27742 Mdot
.98 .27867 Mdot
.98 .27892 Mdot
.98 .27914 Mdot
.98 .27925 Mdot
.98 .27939 Mdot
.98 .27946 Mdot
.98 .27953 Mdot
.98 .27959 Mdot
.98 .27991 Mdot
.98 .28001 Mdot
.98 .28033 Mdot
.98 .28034 Mdot
.98 .28081 Mdot
.98 .28124 Mdot
.98 .28138 Mdot
.98 .28158 Mdot
.98 .28166 Mdot
.98 .28177 Mdot
.98 .28182 Mdot
.98 .28187 Mdot
.98 .2824 Mdot
.98 .28257 Mdot
.98 .28315 Mdot
.98 .28316 Mdot
.98 .2842 Mdot
.98 .2845 Mdot
.98 .2847 Mdot
.98 .28517 Mdot
.98 .28519 Mdot
.98 .28543 Mdot
.98 .28551 Mdot
.98 .28565 Mdot
.98 .28581 Mdot
.98 .28599 Mdot
.98 .28617 Mdot
.98 .28662 Mdot
.98 .28762 Mdot
.98 .28936 Mdot
.98 .29065 Mdot
.98 .29092 Mdot
.98 .29147 Mdot
.98 .29156 Mdot
.98 .29157 Mdot
.98 .29158 Mdot
.98 .29262 Mdot
.98 .29353 Mdot
.98 .29358 Mdot
.98 .29367 Mdot
.98 .29457 Mdot
.98 .29467 Mdot
.98 .29512 Mdot
.98 .29521 Mdot
.98 .29533 Mdot
.98 .29541 Mdot
.98 .29573 Mdot
.98 .29624 Mdot
.98 .29631 Mdot
.98 .29661 Mdot
.98 .29684 Mdot
.98 .29749 Mdot
.98 .29769 Mdot
.98 .2977 Mdot
.98 .29781 Mdot
.98 .29814 Mdot
.98 .29834 Mdot
.98 .30039 Mdot
.98 .30093 Mdot
.98 .30094 Mdot
.98 .30159 Mdot
.98 .30221 Mdot
.98 .30345 Mdot
.98 .30452 Mdot
.98 .30459 Mdot
.98 .30651 Mdot
.98 .30653 Mdot
.98 .30877 Mdot
.98 .31043 Mdot
.98 .3113 Mdot
.98 .31282 Mdot
.98 .31403 Mdot
.98 .31441 Mdot
.98 .31452 Mdot
.98 .31497 Mdot
.98 .31575 Mdot
.98 .31717 Mdot
.98 .32013 Mdot
.98 .32063 Mdot
.98 .32172 Mdot
.98 .32183 Mdot
.98 .3219 Mdot
.98 .32261 Mdot
.98 .32266 Mdot
.98 .32275 Mdot
.98 .32438 Mdot
.98 .32469 Mdot
.98 .3254 Mdot
.98 .32716 Mdot
.98 .32897 Mdot
.98 .33271 Mdot
.98 .33284 Mdot
.98 .3336 Mdot
.98 .33425 Mdot
.98 .33522 Mdot
.98 .33632 Mdot
.98 .33955 Mdot
.98 .33981 Mdot
.98 .34014 Mdot
.98 .34121 Mdot
.98 .34161 Mdot
.98 .34231 Mdot
.98 .34244 Mdot
.98 .34442 Mdot
.98 .34558 Mdot
.98 .34594 Mdot
.98 .34795 Mdot
.98 .34906 Mdot
.98 .34993 Mdot
.98 .35068 Mdot
.98 .352 Mdot
.98 .35287 Mdot
.98 .35357 Mdot
.98 .35406 Mdot
.98 .35471 Mdot
.98 .35529 Mdot
.98 .3556 Mdot
.98 .35595 Mdot
.98 .35613 Mdot
.98 .35632 Mdot
.98 .35647 Mdot
.98 .3573 Mdot
.98 .35755 Mdot
.98 .35837 Mdot
.98 .3584 Mdot
.98 .35958 Mdot
.98 .36065 Mdot
.98 .36101 Mdot
.98 .36151 Mdot
.98 .36169 Mdot
.98 .36183 Mdot
.98 .36195 Mdot
.98 .36208 Mdot
.98 .3622 Mdot
.98 .3635 Mdot
.98 .3639 Mdot
.98 .36449 Mdot
.98 .36526 Mdot
.98 .36529 Mdot
.98 .36675 Mdot
.98 .36769 Mdot
.98 .36822 Mdot
.98 .36836 Mdot
.98 .3688 Mdot
.98 .36982 Mdot
.98 .36987 Mdot
.98 .36989 Mdot
.98 .37018 Mdot
.98 .3704 Mdot
.98 .37056 Mdot
.98 .37088 Mdot
.98 .37121 Mdot
.98 .37159 Mdot
.98 .37198 Mdot
.98 .3729 Mdot
.98 .37493 Mdot
.98 .37773 Mdot
.98 .37827 Mdot
.98 .38057 Mdot
.98 .38097 Mdot
.98 .38104 Mdot
.98 .38196 Mdot
.98 .38212 Mdot
.98 .38214 Mdot
.98 .38215 Mdot
.98 .38382 Mdot
.98 .38384 Mdot
.98 .38493 Mdot
.98 .3852 Mdot
.98 .38526 Mdot
.98 .38538 Mdot
.98 .3854 Mdot
.98 .38669 Mdot
.98 .38682 Mdot
.98 .38743 Mdot
.98 .38755 Mdot
.98 .38765 Mdot
.98 .38771 Mdot
.98 .38778 Mdot
.98 .38781 Mdot
.98 .38784 Mdot
.98 .38823 Mdot
.98 .38874 Mdot
.98 .38884 Mdot
.98 .38887 Mdot
.98 .38895 Mdot
.98 .38897 Mdot
.98 .38931 Mdot
.98 .38959 Mdot
.98 .39024 Mdot
.98 .39033 Mdot
.98 .39056 Mdot
.98 .39057 Mdot
.98 .39068 Mdot
.98 .39079 Mdot
.98 .39104 Mdot
.98 .39125 Mdot
.98 .39317 Mdot
.98 .39356 Mdot
.98 .39361 Mdot
.98 .39362 Mdot
.98 .39411 Mdot
.98 .39454 Mdot
.98 .39459 Mdot
.98 .39508 Mdot
.98 .39529 Mdot
.98 .39533 Mdot
.98 .39539 Mdot
.98 .39558 Mdot
.98 .39582 Mdot
.98 .39585 Mdot
.98 .3961 Mdot
.98 .3965 Mdot
.98 .39651 Mdot
.98 .39656 Mdot
.98 .39672 Mdot
.98 .39681 Mdot
.98 .5295 Mdot
.98 .52954 Mdot
.98 .52961 Mdot
.98 .52964 Mdot
.98 .52964 Mdot
.98 .52982 Mdot
.98 .52993 Mdot
.98 .52994 Mdot
.98 .53005 Mdot
.98 .53014 Mdot
.98 .53016 Mdot
.98 .53018 Mdot
.98 .53028 Mdot
.98 .53049 Mdot
.98 .53052 Mdot
.98 .53071 Mdot
.98 .53093 Mdot
.98 .53093 Mdot
.98 .53095 Mdot
.98 .53113 Mdot
.98 .53198 Mdot
.98 .53207 Mdot
.98 .53218 Mdot
.98 .53222 Mdot
.98 .53228 Mdot
.98 .53228 Mdot
.98 .53238 Mdot
.98 .53242 Mdot
.98 .5327 Mdot
.98 .53282 Mdot
.98 .53297 Mdot
.98 .53298 Mdot
.98 .53302 Mdot
.98 .53303 Mdot
.98 .53307 Mdot
.98 .53329 Mdot
.98 .53346 Mdot
.98 .53348 Mdot
.98 .53349 Mdot
.98 .53352 Mdot
.98 .53354 Mdot
.98 .53359 Mdot
.98 .53364 Mdot
.98 .5339 Mdot
.98 .53396 Mdot
.98 .53451 Mdot
.98 .53452 Mdot
.98 .53457 Mdot
.98 .5346 Mdot
.98 .53472 Mdot
.98 .53518 Mdot
.98 .53519 Mdot
.98 .53589 Mdot
.98 .5359 Mdot
.98 .53591 Mdot
.98 .53597 Mdot
.98 .53636 Mdot
.98 .53639 Mdot
.98 .53656 Mdot
.98 .53751 Mdot
.98 .53774 Mdot
.98 .53889 Mdot
.98 .53971 Mdot
.98 .54008 Mdot
.98 .54024 Mdot
.98 .54039 Mdot
.98 .54053 Mdot
.98 .54065 Mdot
.98 .54072 Mdot
.98 .5408 Mdot
.98 .54092 Mdot
.98 .54093 Mdot
.98 .54095 Mdot
.98 .54135 Mdot
.98 .54153 Mdot
.98 .54158 Mdot
.98 .54179 Mdot
.98 .54216 Mdot
.98 .54274 Mdot
.98 .54275 Mdot
.98 .54305 Mdot
.98 .54328 Mdot
.98 .54343 Mdot
.98 .54393 Mdot
.98 .54398 Mdot
.98 .54403 Mdot
.98 .54407 Mdot
.98 .54413 Mdot
.98 .5442 Mdot
.98 .54439 Mdot
.98 .54453 Mdot
.98 .54494 Mdot
.98 .54538 Mdot
.98 .54539 Mdot
.98 .54571 Mdot
.98 .5458 Mdot
.98 .54611 Mdot
.98 .54617 Mdot
.98 .54624 Mdot
.98 .5463 Mdot
.98 .54644 Mdot
.98 .54655 Mdot
.98 .54677 Mdot
.98 .54701 Mdot
.98 .54719 Mdot
.98 .54745 Mdot
.98 .54777 Mdot
.98 .54826 Mdot
.98 .54853 Mdot
.98 .54884 Mdot
.98 .54925 Mdot
.98 .54997 Mdot
.98 .5501 Mdot
.98 .55051 Mdot
.98 .55121 Mdot
.98 .55126 Mdot
.98 .55151 Mdot
.98 .55165 Mdot
.98 .55202 Mdot
.98 .55213 Mdot
.98 .55222 Mdot
.98 .55334 Mdot
.98 .55372 Mdot
.98 .55405 Mdot
.98 .55427 Mdot
.98 .55452 Mdot
.98 .55457 Mdot
.98 .55582 Mdot
.98 .55641 Mdot
.98 .55699 Mdot
.98 .55722 Mdot
.98 .55732 Mdot
.98 .55785 Mdot
.98 .55788 Mdot
.98 .55789 Mdot
.98 .55812 Mdot
.98 .55815 Mdot
.98 .55818 Mdot
.98 .55853 Mdot
.98 .55869 Mdot
.98 .55962 Mdot
.98 .56007 Mdot
.98 .56031 Mdot
.98 .56045 Mdot
.98 .56049 Mdot
.98 .5606 Mdot
.98 .56098 Mdot
.98 .56145 Mdot
.98 .56171 Mdot
.98 .56221 Mdot
.98 .56289 Mdot
.98 .56289 Mdot
.98 .56346 Mdot
.98 .56348 Mdot
.98 .5638 Mdot
.98 .56417 Mdot
.98 .56435 Mdot
.98 .56454 Mdot
.98 .56454 Mdot
.98 .5647 Mdot
.98 .56529 Mdot
.98 .56535 Mdot
.98 .56544 Mdot
.98 .56548 Mdot
.98 .56548 Mdot
.98 .56554 Mdot
.98 .56572 Mdot
.98 .56579 Mdot
.98 .56588 Mdot
.98 .56589 Mdot
.98 .56604 Mdot
.98 .56613 Mdot
.98 .56615 Mdot
.98 .56619 Mdot
.98 .56621 Mdot
.98 .56634 Mdot
.98 .56637 Mdot
.98 .56662 Mdot
.98 .56665 Mdot
.98 .56666 Mdot
.98 .56692 Mdot
.98 .56721 Mdot
.98 .56721 Mdot
.98 .56721 Mdot
.98 .56724 Mdot
.98 .56739 Mdot
.98 .56747 Mdot
.98 .56783 Mdot
.98 .56831 Mdot
.98 .56858 Mdot
.98 .5687 Mdot
.98 .56875 Mdot
.98 .5688 Mdot
.98 .56884 Mdot
.98 .56888 Mdot
.98 .5689 Mdot
.98 .56897 Mdot
.98 .56897 Mdot
.98 .5691 Mdot
.98 .56915 Mdot
.98 .56923 Mdot
.98 .56951 Mdot
.98 .56952 Mdot
.98 .56967 Mdot
.98 .56972 Mdot
.98 .56986 Mdot
.98 .56987 Mdot
.98 .56989 Mdot
.98 .56992 Mdot
.98 .56993 Mdot
.98 .56999 Mdot
.98 .57003 Mdot
.98 .57014 Mdot
.98 .57026 Mdot
.98 .57027 Mdot
.98 .57035 Mdot
.98 .57038 Mdot
.98 .57048 Mdot
.98 .5705 Mdot
.98 .57052 Mdot
.98 .57055 Mdot
.98 .57058 Mdot
.98 .57064 Mdot
.98 .5707 Mdot
.98 .57103 Mdot
.98 .5711 Mdot
.98 .57161 Mdot
.98 .57179 Mdot
.98 .5718 Mdot
.98 .57186 Mdot
.98 .57189 Mdot
.98 .57199 Mdot
.98 .57204 Mdot
.98 .57248 Mdot
.98 .57254 Mdot
.98 .5726 Mdot
.98 .57261 Mdot
.98 .57305 Mdot
.98 .57325 Mdot
.98 .57327 Mdot
.98 .5734 Mdot
.98 .5734 Mdot
.98 .57346 Mdot
.98 .57347 Mdot
.98 .57348 Mdot
.98 .57356 Mdot
.98 .57382 Mdot
.98 .57398 Mdot
.98 .57401 Mdot
.98 .57402 Mdot
.98 .57405 Mdot
.98 .57425 Mdot
.98 .57459 Mdot
.98 .57472 Mdot
.98 .57498 Mdot
.98 .57536 Mdot
.98 .57541 Mdot
.98 .57561 Mdot
.98 .57566 Mdot
.98 .57588 Mdot
.98 .57598 Mdot
.98 .57599 Mdot
.98 .57617 Mdot
.98 .57637 Mdot
.98 .5769 Mdot
.98 .57704 Mdot
.98 .57713 Mdot
.98 .57713 Mdot
.98 .57724 Mdot
.98 .57728 Mdot
.98 .57729 Mdot
.98 .57747 Mdot
.98 .57754 Mdot
.98 .57771 Mdot
.98 .5778 Mdot
.98 .57785 Mdot
.98 .57808 Mdot
.98 .57811 Mdot
.98 .57811 Mdot
.98 .5782 Mdot
.98 .57837 Mdot
.98 .57837 Mdot
.98 .57853 Mdot
.98 .57867 Mdot
.98 .57867 Mdot
.98 .57868 Mdot
.98 .5788 Mdot
.98 .57887 Mdot
.98 .57896 Mdot
.98 .57899 Mdot
.98 .57908 Mdot
.98 .57909 Mdot
.98 .57911 Mdot
.98 .57916 Mdot
.98 .57916 Mdot
.98 .5792 Mdot
.98 .57953 Mdot
.98 .57962 Mdot
.98 .57971 Mdot
.98 .57971 Mdot
.98 .57976 Mdot
.98 .57986 Mdot
.98 .57998 Mdot
.98 .58017 Mdot
.98 .58029 Mdot
.98 .58035 Mdot
.98 .58059 Mdot
.98 .58061 Mdot
.98 .58068 Mdot
.98 .58086 Mdot
.98 .58086 Mdot
.98 .58091 Mdot
.98 .58092 Mdot
.98 .581 Mdot
.98 .58121 Mdot
.98 .58124 Mdot
.98 .58144 Mdot
.98 .58158 Mdot
.98 .58206 Mdot
.98 .58207 Mdot
.98 .5821 Mdot
.98 .58215 Mdot
.98 .58219 Mdot
.98 .58224 Mdot
.98 .5823 Mdot
.98 .58238 Mdot
.98 .58248 Mdot
.98 .58261 Mdot
.98 .58264 Mdot
.98 .58265 Mdot
.98 .58281 Mdot
.98 .58298 Mdot
.98 .58312 Mdot
.98 .58319 Mdot
.98 .58337 Mdot
.98 .58338 Mdot
.98 .58347 Mdot
.98 .58355 Mdot
.98 .58366 Mdot
.98 .58374 Mdot
.98 .58401 Mdot
.98 .58405 Mdot
.98 .58406 Mdot
.98 .58411 Mdot
.98 .58417 Mdot
.98 .58428 Mdot
.98 .58438 Mdot
.98 .58439 Mdot
.98 .58456 Mdot
.98 .58456 Mdot
.98 .58476 Mdot
.98 .58491 Mdot
.98 .58498 Mdot
.98 .58511 Mdot
.98 .58522 Mdot
.98 .58525 Mdot
.98 .58526 Mdot
.98 .5853 Mdot
.98 .58537 Mdot
.98 .58549 Mdot
.98 .58574 Mdot
.98 .58579 Mdot
.98 .58588 Mdot
.98 .58589 Mdot
.98 .58589 Mdot
.98 .58595 Mdot
.98 .58596 Mdot
.98 .58597 Mdot
.98 .5861 Mdot
.98 .58613 Mdot
.98 .58619 Mdot
.98 .58633 Mdot
.98 .58649 Mdot
.98 .58679 Mdot
.98 .5868 Mdot
.98 .58686 Mdot
.98 .58692 Mdot
.98 .587 Mdot
.98 .58709 Mdot
.98 .58734 Mdot
.98 .58737 Mdot
.98 .58739 Mdot
.98 .58748 Mdot
.98 .58751 Mdot
.98 .58756 Mdot
.98 .58757 Mdot
.98 .58773 Mdot
.98 .58782 Mdot
.98 .58785 Mdot
.98 .58801 Mdot
.98 .58809 Mdot
.98 .58816 Mdot
.98 .58822 Mdot
.98 .58832 Mdot
.98 .58839 Mdot
.98 .58844 Mdot
.98 .58848 Mdot
.98 .58853 Mdot
.98 .58857 Mdot
.98 .58859 Mdot
.98 .58862 Mdot
.98 .58864 Mdot
.98 .58865 Mdot
.98 .58866 Mdot
.98 .58872 Mdot
.98 .58874 Mdot
.98 .58881 Mdot
.98 .58881 Mdot
.98 .5889 Mdot
.98 .58898 Mdot
.98 .589 Mdot
.98 .58904 Mdot
.98 .58905 Mdot
.98 .58907 Mdot
.98 .58907 Mdot
.98 .58908 Mdot
.98 .58909 Mdot
.98 .58919 Mdot
.98 .58922 Mdot
.98 .58926 Mdot
.98 .58932 Mdot
.98 .58932 Mdot
.98 .58943 Mdot
.98 .5895 Mdot
.98 .58954 Mdot
.98 .58955 Mdot
.98 .58958 Mdot
.98 .58965 Mdot
.98 .58966 Mdot
.98 .58966 Mdot
.98 .58968 Mdot
.98 .5897 Mdot
.98 .58971 Mdot
.98 .58973 Mdot
.98 .58976 Mdot
.98 .58978 Mdot
.98 .58981 Mdot
.98 .58988 Mdot
.98 .59003 Mdot
.98 .59023 Mdot
.98 .59026 Mdot
.98 .59043 Mdot
.98 .59046 Mdot
.98 .59046 Mdot
.98 .59053 Mdot
.98 .59054 Mdot
.98 .59054 Mdot
.98 .59054 Mdot
.98 .59066 Mdot
.98 .59066 Mdot
.98 .59073 Mdot
.98 .59075 Mdot
.98 .59076 Mdot
.98 .59077 Mdot
.98 .59077 Mdot
.98 .59086 Mdot
.98 .59087 Mdot
.98 .59091 Mdot
.98 .59092 Mdot
.98 .59092 Mdot
.98 .59093 Mdot
.98 .59093 Mdot
.98 .59094 Mdot
.98 .59094 Mdot
.98 .59096 Mdot
.98 .591 Mdot
.98 .59101 Mdot
.98 .59101 Mdot
.98 .59101 Mdot
.98 .59102 Mdot
.98 .59104 Mdot
.98 .59106 Mdot
.98 .5911 Mdot
.98 .59111 Mdot
.98 .59113 Mdot
.98 .59113 Mdot
.98 .59113 Mdot
.98 .59114 Mdot
.98 .59116 Mdot
.98 .59117 Mdot
.98 .5913 Mdot
.98 .59133 Mdot
.98 .59133 Mdot
.98 .59134 Mdot
.98 .59137 Mdot
.98 .5914 Mdot
.98 .5914 Mdot
.98 .59143 Mdot
.98 .59145 Mdot
.98 .59145 Mdot
.98 .59146 Mdot
.98 .59147 Mdot
.98 .59149 Mdot
.98 .59149 Mdot
.98 .5915 Mdot
.98 .59153 Mdot
.98 .59153 Mdot
.98 .59154 Mdot
.98 .59155 Mdot
.98 .59155 Mdot
.982 .16841 Mdot
.982 .16843 Mdot
.982 .16847 Mdot
.982 .16847 Mdot
.982 .16853 Mdot
.982 .16854 Mdot
.982 .16855 Mdot
.982 .16859 Mdot
.982 .16863 Mdot
.982 .16869 Mdot
.982 .16871 Mdot
.982 .16883 Mdot
.982 .16884 Mdot
.982 .16884 Mdot
.982 .16885 Mdot
.982 .16885 Mdot
.982 .16896 Mdot
.982 .16907 Mdot
.982 .16907 Mdot
.982 .16919 Mdot
.982 .16924 Mdot
.982 .16925 Mdot
.982 .16929 Mdot
.982 .16933 Mdot
.982 .16935 Mdot
.982 .1694 Mdot
.982 .1695 Mdot
.982 .16985 Mdot
.982 .17001 Mdot
.982 .17007 Mdot
.982 .17021 Mdot
.982 .17021 Mdot
.982 .17025 Mdot
.982 .17032 Mdot
.982 .17034 Mdot
.982 .17035 Mdot
.982 .17053 Mdot
.982 .17059 Mdot
.982 .17064 Mdot
.982 .17068 Mdot
.982 .1708 Mdot
.982 .17081 Mdot
.982 .17087 Mdot
.982 .17087 Mdot
.982 .17094 Mdot
.982 .17106 Mdot
.982 .17119 Mdot
.982 .17126 Mdot
.982 .17138 Mdot
.982 .1714 Mdot
.982 .17143 Mdot
.982 .17147 Mdot
.982 .17166 Mdot
.982 .17177 Mdot
.982 .17177 Mdot
.982 .17178 Mdot
.982 .17192 Mdot
.982 .17217 Mdot
.982 .17233 Mdot
.982 .17282 Mdot
.982 .17311 Mdot
.982 .17314 Mdot
.982 .17321 Mdot
.982 .17326 Mdot
.982 .17397 Mdot
.982 .17433 Mdot
.982 .1745 Mdot
.982 .17459 Mdot
.982 .17464 Mdot
.982 .17474 Mdot
.982 .17474 Mdot
.982 .17482 Mdot
.982 .17488 Mdot
.982 .1749 Mdot
.982 .1751 Mdot
.982 .17556 Mdot
.982 .17557 Mdot
.982 .1756 Mdot
.982 .17601 Mdot
.982 .17604 Mdot
.982 .17606 Mdot
.982 .17627 Mdot
.982 .17638 Mdot
.982 .17638 Mdot
.982 .17643 Mdot
.982 .17646 Mdot
.982 .17646 Mdot
.982 .17648 Mdot
.982 .17648 Mdot
.982 .1765 Mdot
.982 .17653 Mdot
.982 .17655 Mdot
.982 .17665 Mdot
.982 .17672 Mdot
.982 .17703 Mdot
.982 .17712 Mdot
.982 .17717 Mdot
.982 .17741 Mdot
.982 .17743 Mdot
.982 .17756 Mdot
.982 .17774 Mdot
.982 .1778 Mdot
.982 .17782 Mdot
.982 .1781 Mdot
.982 .17811 Mdot
.982 .17829 Mdot
.982 .17836 Mdot
.982 .17837 Mdot
.982 .17883 Mdot
.982 .17884 Mdot
.982 .17923 Mdot
.982 .17945 Mdot
.982 .18035 Mdot
.982 .1806 Mdot
.982 .18069 Mdot
.982 .18096 Mdot
.982 .18134 Mdot
.982 .18137 Mdot
.982 .18225 Mdot
.982 .18229 Mdot
.982 .18258 Mdot
.982 .18269 Mdot
.982 .18284 Mdot
.982 .18399 Mdot
.982 .18416 Mdot
.982 .18421 Mdot
.982 .18425 Mdot
.982 .18522 Mdot
.982 .18535 Mdot
.982 .18561 Mdot
.982 .18566 Mdot
.982 .18566 Mdot
.982 .18677 Mdot
.982 .18763 Mdot
.982 .18832 Mdot
.982 .18836 Mdot
.982 .19072 Mdot
.982 .19084 Mdot
.982 .19217 Mdot
.982 .19274 Mdot
.982 .19657 Mdot
.982 .19799 Mdot
.982 .19813 Mdot
.982 .19814 Mdot
.982 .19819 Mdot
.982 .19862 Mdot
.982 .19985 Mdot
.982 .20048 Mdot
.982 .20246 Mdot
.982 .20345 Mdot
.982 .20521 Mdot
.982 .20543 Mdot
.982 .20929 Mdot
.982 .21025 Mdot
.982 .21082 Mdot
.982 .21213 Mdot
.982 .21242 Mdot
.982 .21325 Mdot
.982 .21468 Mdot
.982 .21554 Mdot
.982 .21676 Mdot
.982 .21722 Mdot
.982 .21769 Mdot
.982 .21994 Mdot
.982 .22136 Mdot
.982 .22531 Mdot
.982 .22559 Mdot
.982 .22577 Mdot
.982 .22618 Mdot
.982 .2269 Mdot
.982 .227 Mdot
.982 .22757 Mdot
.982 .22801 Mdot
.982 .22834 Mdot
.982 .23543 Mdot
.982 .23571 Mdot
.982 .23588 Mdot
.982 .23658 Mdot
.982 .2377 Mdot
.982 .23884 Mdot
.982 .23999 Mdot
.982 .24034 Mdot
.982 .24037 Mdot
.982 .2426 Mdot
.982 .24752 Mdot
.982 .24754 Mdot
.982 .24772 Mdot
.982 .24891 Mdot
.982 .24949 Mdot
.982 .25009 Mdot
.982 .25386 Mdot
.982 .25404 Mdot
.982 .25428 Mdot
.982 .25459 Mdot
.982 .25464 Mdot
.982 .25504 Mdot
.982 .25536 Mdot
.982 .2577 Mdot
.982 .26005 Mdot
.982 .26031 Mdot
.982 .26102 Mdot
.982 .26152 Mdot
.982 .26236 Mdot
.982 .26285 Mdot
.982 .26303 Mdot
.982 .26381 Mdot
.982 .26415 Mdot
.982 .26473 Mdot
.982 .26713 Mdot
.982 .26727 Mdot
.982 .26903 Mdot
.982 .27032 Mdot
.982 .27074 Mdot
.982 .27189 Mdot
.982 .27614 Mdot
.982 .27723 Mdot
.982 .27908 Mdot
.982 .27911 Mdot
.982 .27966 Mdot
.982 .28037 Mdot
.982 .2813 Mdot
.982 .2813 Mdot
.982 .28134 Mdot
.982 .28167 Mdot
.982 .28251 Mdot
.982 .28255 Mdot
.982 .28259 Mdot
.982 .28274 Mdot
.982 .28392 Mdot
.982 .28402 Mdot
.982 .28429 Mdot
.982 .28432 Mdot
.982 .28516 Mdot
.982 .28518 Mdot
.982 .28555 Mdot
.982 .28582 Mdot
.982 .28591 Mdot
.982 .28615 Mdot
.982 .28706 Mdot
.982 .2873 Mdot
.982 .28771 Mdot
.982 .28924 Mdot
.982 .28954 Mdot
.982 .29006 Mdot
.982 .29013 Mdot
.982 .29028 Mdot
.982 .29036 Mdot
.982 .29039 Mdot
.982 .29046 Mdot
.982 .29046 Mdot
.982 .2906 Mdot
.982 .29085 Mdot
.982 .29088 Mdot
.982 .29141 Mdot
.982 .29242 Mdot
.982 .29252 Mdot
.982 .29266 Mdot
.982 .29461 Mdot
.982 .29469 Mdot
.982 .29479 Mdot
.982 .29484 Mdot
.982 .29706 Mdot
.982 .29779 Mdot
.982 .29801 Mdot
.982 .29815 Mdot
.982 .29842 Mdot
.982 .29881 Mdot
.982 .29881 Mdot
.982 .29929 Mdot
.982 .29953 Mdot
.982 .29999 Mdot
.982 .30078 Mdot
.982 .30256 Mdot
.982 .30271 Mdot
.982 .30373 Mdot
.982 .30474 Mdot
.982 .30482 Mdot
.982 .306 Mdot
.982 .30625 Mdot
.982 .30658 Mdot
.982 .30675 Mdot
.982 .30743 Mdot
.982 .30815 Mdot
.982 .30933 Mdot
.982 .31059 Mdot
.982 .31133 Mdot
.982 .31247 Mdot
.982 .31259 Mdot
.982 .31328 Mdot
.982 .3133 Mdot
.982 .31332 Mdot
.982 .31384 Mdot
.982 .3143 Mdot
.982 .31477 Mdot
.982 .31495 Mdot
.982 .31498 Mdot
.982 .31511 Mdot
.982 .31525 Mdot
.982 .31581 Mdot
.982 .31614 Mdot
.982 .31682 Mdot
.982 .31739 Mdot
.982 .31774 Mdot
.982 .31775 Mdot
.982 .31784 Mdot
.982 .31802 Mdot
.982 .31808 Mdot
.982 .31864 Mdot
.982 .31884 Mdot
.982 .31909 Mdot
.982 .31912 Mdot
.982 .31938 Mdot
.982 .3203 Mdot
.982 .32035 Mdot
.982 .32043 Mdot
.982 .32079 Mdot
.982 .32098 Mdot
.982 .32099 Mdot
.982 .32124 Mdot
.982 .32169 Mdot
.982 .32194 Mdot
.982 .32275 Mdot
.982 .32446 Mdot
.982 .32497 Mdot
.982 .32519 Mdot
.982 .32532 Mdot
.982 .32551 Mdot
.982 .3257 Mdot
.982 .32573 Mdot
.982 .32599 Mdot
.982 .32657 Mdot
.982 .32658 Mdot
.982 .32713 Mdot
.982 .32768 Mdot
.982 .3277 Mdot
.982 .3277 Mdot
.982 .32772 Mdot
.982 .32778 Mdot
.982 .32835 Mdot
.982 .32845 Mdot
.982 .32878 Mdot
.982 .32895 Mdot
.982 .32915 Mdot
.982 .32922 Mdot
.982 .32924 Mdot
.982 .32954 Mdot
.982 .32955 Mdot
.982 .32975 Mdot
.982 .32983 Mdot
.982 .32984 Mdot
.982 .33034 Mdot
.982 .33426 Mdot
.982 .33648 Mdot
.982 .34089 Mdot
.982 .34232 Mdot
.982 .34506 Mdot
.982 .34604 Mdot
.982 .34613 Mdot
.982 .34617 Mdot
.982 .34647 Mdot
.982 .34965 Mdot
.982 .35826 Mdot
.982 .35954 Mdot
.982 .36253 Mdot
.982 .36278 Mdot
.982 .3681 Mdot
.982 .36818 Mdot
.982 .36973 Mdot
.982 .37166 Mdot
.982 .37415 Mdot
.982 .37416 Mdot
.982 .37425 Mdot
.982 .37485 Mdot
.982 .37514 Mdot
.982 .37731 Mdot
.982 .3774 Mdot
.982 .37751 Mdot
.982 .37789 Mdot
.982 .38047 Mdot
.982 .38081 Mdot
.982 .38106 Mdot
.982 .3817 Mdot
.982 .38179 Mdot
.982 .38376 Mdot
.982 .38383 Mdot
.982 .38467 Mdot
.982 .38529 Mdot
.982 .38549 Mdot
.982 .38603 Mdot
.982 .38805 Mdot
.982 .38856 Mdot
.982 .38943 Mdot
.982 .38944 Mdot
.982 .39047 Mdot
.982 .39048 Mdot
.982 .39064 Mdot
.982 .39105 Mdot
.982 .39107 Mdot
.982 .39169 Mdot
.982 .39174 Mdot
.982 .39188 Mdot
.982 .39228 Mdot
.982 .39258 Mdot
.982 .39262 Mdot
.982 .39315 Mdot
.982 .39326 Mdot
.982 .39345 Mdot
.982 .39416 Mdot
.982 .3943 Mdot
.982 .39454 Mdot
.982 .39458 Mdot
.982 .39464 Mdot
.982 .39468 Mdot
.982 .3947 Mdot
.982 .39473 Mdot
.982 .39473 Mdot
.982 .39479 Mdot
.982 .39491 Mdot
.982 .39492 Mdot
.982 .39517 Mdot
.982 .39563 Mdot
.982 .39568 Mdot
.982 .39574 Mdot
.982 .39664 Mdot
.982 .39672 Mdot
.982 .39675 Mdot
.982 .39777 Mdot
.982 .3982 Mdot
.982 .39827 Mdot
.982 .39839 Mdot
.982 .39857 Mdot
.982 .39857 Mdot
.982 .39879 Mdot
.982 .3989 Mdot
.982 .39911 Mdot
.982 .39947 Mdot
.982 .40028 Mdot
.982 .40185 Mdot
.982 .40197 Mdot
.982 .40212 Mdot
.982 .40219 Mdot
.982 .40283 Mdot
.982 .40393 Mdot
.982 .40427 Mdot
.982 .40484 Mdot
.982 .40515 Mdot
.982 .40517 Mdot
.982 .40517 Mdot
.982 .40541 Mdot
.982 .40583 Mdot
.982 .40592 Mdot
.982 .40598 Mdot
.982 .40604 Mdot
.982 .4063 Mdot
.982 .40645 Mdot
.982 .40676 Mdot
.982 .40701 Mdot
.982 .40717 Mdot
.982 .40717 Mdot
.982 .40729 Mdot
.982 .40732 Mdot
.982 .40758 Mdot
.982 .40767 Mdot
.982 .40778 Mdot
.982 .40791 Mdot
.982 .40832 Mdot
.982 .40835 Mdot
.982 .40838 Mdot
.982 .40854 Mdot
.982 .40863 Mdot
.982 .40864 Mdot
.982 .40895 Mdot
.982 .40906 Mdot
.982 .40943 Mdot
.982 .4102 Mdot
.982 .41042 Mdot
.982 .41052 Mdot
.982 .41058 Mdot
.982 .41067 Mdot
.982 .41075 Mdot
.982 .41077 Mdot
.982 .41088 Mdot
.982 .41114 Mdot
.982 .41115 Mdot
.982 .4114 Mdot
.982 .41164 Mdot
.982 .41165 Mdot
.982 .41165 Mdot
.982 .41166 Mdot
.982 .41169 Mdot
.982 .41194 Mdot
.982 .41199 Mdot
.982 .41213 Mdot
.982 .41221 Mdot
.982 .4123 Mdot
.982 .41233 Mdot
.982 .41234 Mdot
.982 .41248 Mdot
.982 .41248 Mdot
.982 .41257 Mdot
.982 .41261 Mdot
.982 .5225 Mdot
.982 .52251 Mdot
.982 .52256 Mdot
.982 .52256 Mdot
.982 .52262 Mdot
.982 .52263 Mdot
.982 .52264 Mdot
.982 .52269 Mdot
.982 .52272 Mdot
.982 .52279 Mdot
.982 .52282 Mdot
.982 .52294 Mdot
.982 .52295 Mdot
.982 .52296 Mdot
.982 .52296 Mdot
.982 .52296 Mdot
.982 .52308 Mdot
.982 .5232 Mdot
.982 .5232 Mdot
.982 .52333 Mdot
.982 .52338 Mdot
.982 .52339 Mdot
.982 .52343 Mdot
.982 .52347 Mdot
.982 .5235 Mdot
.982 .52354 Mdot
.982 .52365 Mdot
.982 .52402 Mdot
.982 .52419 Mdot
.982 .52425 Mdot
.982 .5244 Mdot
.982 .5244 Mdot
.982 .52444 Mdot
.982 .52452 Mdot
.982 .52453 Mdot
.982 .52454 Mdot
.982 .52474 Mdot
.982 .5248 Mdot
.982 .52485 Mdot
.982 .5249 Mdot
.982 .52502 Mdot
.982 .52503 Mdot
.982 .52509 Mdot
.982 .52509 Mdot
.982 .52516 Mdot
.982 .52528 Mdot
.982 .52543 Mdot
.982 .5255 Mdot
.982 .52562 Mdot
.982 .52565 Mdot
.982 .52567 Mdot
.982 .52572 Mdot
.982 .52592 Mdot
.982 .52602 Mdot
.982 .52603 Mdot
.982 .52603 Mdot
.982 .52618 Mdot
.982 .52644 Mdot
.982 .5266 Mdot
.982 .52711 Mdot
.982 .5274 Mdot
.982 .52744 Mdot
.982 .52751 Mdot
.982 .52756 Mdot
.982 .52828 Mdot
.982 .52865 Mdot
.982 .52881 Mdot
.982 .52891 Mdot
.982 .52896 Mdot
.982 .52906 Mdot
.982 .52906 Mdot
.982 .52914 Mdot
.982 .5292 Mdot
.982 .52922 Mdot
.982 .52942 Mdot
.982 .52988 Mdot
.982 .52989 Mdot
.982 .52993 Mdot
.982 .53033 Mdot
.982 .53036 Mdot
.982 .53038 Mdot
.982 .53058 Mdot
.982 .53069 Mdot
.982 .5307 Mdot
.982 .53075 Mdot
.982 .53078 Mdot
.982 .53078 Mdot
.982 .53079 Mdot
.982 .5308 Mdot
.982 .53082 Mdot
.982 .53085 Mdot
.982 .53086 Mdot
.982 .53097 Mdot
.982 .53103 Mdot
.982 .53134 Mdot
.982 .53143 Mdot
.982 .53148 Mdot
.982 .53171 Mdot
.982 .53173 Mdot
.982 .53186 Mdot
.982 .53204 Mdot
.982 .5321 Mdot
.982 .53212 Mdot
.982 .53239 Mdot
.982 .5324 Mdot
.982 .53258 Mdot
.982 .53265 Mdot
.982 .53265 Mdot
.982 .5331 Mdot
.982 .53311 Mdot
.982 .53348 Mdot
.982 .5337 Mdot
.982 .53457 Mdot
.982 .5348 Mdot
.982 .53488 Mdot
.982 .53515 Mdot
.982 .5355 Mdot
.982 .53553 Mdot
.982 .53636 Mdot
.982 .5364 Mdot
.982 .53666 Mdot
.982 .53677 Mdot
.982 .53691 Mdot
.982 .53798 Mdot
.982 .53813 Mdot
.982 .53818 Mdot
.982 .53822 Mdot
.982 .5391 Mdot
.982 .53922 Mdot
.982 .53946 Mdot
.982 .5395 Mdot
.982 .5395 Mdot
.982 .5405 Mdot
.982 .54127 Mdot
.982 .54188 Mdot
.982 .54192 Mdot
.982 .54398 Mdot
.982 .54408 Mdot
.982 .54522 Mdot
.982 .5457 Mdot
.982 .54888 Mdot
.982 .55002 Mdot
.982 .55013 Mdot
.982 .55014 Mdot
.982 .55017 Mdot
.982 .55052 Mdot
.982 .55149 Mdot
.982 .55199 Mdot
.982 .55351 Mdot
.982 .55426 Mdot
.982 .55558 Mdot
.982 .55574 Mdot
.982 .55574 Mdot
.982 .55577 Mdot
.982 .55584 Mdot
.982 .55584 Mdot
.982 .55594 Mdot
.982 .55595 Mdot
.982 .55597 Mdot
.982 .55604 Mdot
.982 .55609 Mdot
.982 .5562 Mdot
.982 .55623 Mdot
.982 .55642 Mdot
.982 .55644 Mdot
.982 .55644 Mdot
.982 .55645 Mdot
.982 .55645 Mdot
.982 .55663 Mdot
.982 .55681 Mdot
.982 .55682 Mdot
.982 .55701 Mdot
.982 .55709 Mdot
.982 .5571 Mdot
.982 .55716 Mdot
.982 .55722 Mdot
.982 .55726 Mdot
.982 .55734 Mdot
.982 .5575 Mdot
.982 .55805 Mdot
.982 .55831 Mdot
.982 .55839 Mdot
.982 .55853 Mdot
.982 .55861 Mdot
.982 .55862 Mdot
.982 .55868 Mdot
.982 .55879 Mdot
.982 .55882 Mdot
.982 .55883 Mdot
.982 .55912 Mdot
.982 .55921 Mdot
.982 .55922 Mdot
.982 .55929 Mdot
.982 .55936 Mdot
.982 .55953 Mdot
.982 .55955 Mdot
.982 .55961 Mdot
.982 .55964 Mdot
.982 .55964 Mdot
.982 .55975 Mdot
.982 .55993 Mdot
.982 .56014 Mdot
.982 .56024 Mdot
.982 .56042 Mdot
.982 .56046 Mdot
.982 .5605 Mdot
.982 .56051 Mdot
.982 .56057 Mdot
.982 .56071 Mdot
.982 .56085 Mdot
.982 .56101 Mdot
.982 .56102 Mdot
.982 .56102 Mdot
.982 .56123 Mdot
.982 .56127 Mdot
.982 .56162 Mdot
.982 .56185 Mdot
.982 .56223 Mdot
.982 .56258 Mdot
.982 .5628 Mdot
.982 .563 Mdot
.982 .56305 Mdot
.982 .56315 Mdot
.982 .56322 Mdot
.982 .56359 Mdot
.982 .56389 Mdot
.982 .56419 Mdot
.982 .56424 Mdot
.982 .56475 Mdot
.982 .56498 Mdot
.982 .56512 Mdot
.982 .56519 Mdot
.982 .56532 Mdot
.982 .56532 Mdot
.982 .56543 Mdot
.982 .56551 Mdot
.982 .56555 Mdot
.982 .56562 Mdot
.982 .56582 Mdot
.982 .56645 Mdot
.982 .56647 Mdot
.982 .5665 Mdot
.982 .56652 Mdot
.982 .56707 Mdot
.982 .5671 Mdot
.982 .56713 Mdot
.982 .56741 Mdot
.982 .56756 Mdot
.982 .56757 Mdot
.982 .56764 Mdot
.982 .56768 Mdot
.982 .56768 Mdot
.982 .56769 Mdot
.982 .5677 Mdot
.982 .56773 Mdot
.982 .56777 Mdot
.982 .56779 Mdot
.982 .56793 Mdot
.982 .56801 Mdot
.982 .56843 Mdot
.982 .56854 Mdot
.982 .56861 Mdot
.982 .56886 Mdot
.982 .56892 Mdot
.982 .56895 Mdot
.982 .56902 Mdot
.982 .56912 Mdot
.982 .56912 Mdot
.982 .56935 Mdot
.982 .56936 Mdot
.982 .56943 Mdot
.982 .56946 Mdot
.982 .56977 Mdot
.982 .56981 Mdot
.982 .56982 Mdot
.982 .56983 Mdot
.982 .57006 Mdot
.982 .57015 Mdot
.982 .57015 Mdot
.982 .57015 Mdot
.982 .5704 Mdot
.982 .57059 Mdot
.982 .57073 Mdot
.982 .57074 Mdot
.982 .57122 Mdot
.982 .5715 Mdot
.982 .57259 Mdot
.982 .57288 Mdot
.982 .57298 Mdot
.982 .57331 Mdot
.982 .57375 Mdot
.982 .57378 Mdot
.982 .57437 Mdot
.982 .57451 Mdot
.982 .57459 Mdot
.982 .57478 Mdot
.982 .57483 Mdot
.982 .57494 Mdot
.982 .57515 Mdot
.982 .57527 Mdot
.982 .57544 Mdot
.982 .5755 Mdot
.982 .57606 Mdot
.982 .57661 Mdot
.982 .57668 Mdot
.982 .57677 Mdot
.982 .57679 Mdot
.982 .57686 Mdot
.982 .57691 Mdot
.982 .57695 Mdot
.982 .57782 Mdot
.982 .57795 Mdot
.982 .57809 Mdot
.982 .57835 Mdot
.982 .57839 Mdot
.982 .5784 Mdot
.982 .57949 Mdot
.982 .57997 Mdot
.982 .57998 Mdot
.982 .58005 Mdot
.982 .5803 Mdot
.982 .58054 Mdot
.982 .58078 Mdot
.982 .58093 Mdot
.982 .58096 Mdot
.982 .58102 Mdot
.982 .58249 Mdot
.982 .58255 Mdot
.982 .58264 Mdot
.982 .58276 Mdot
.982 .58278 Mdot
.982 .58292 Mdot
.982 .583 Mdot
.982 .58304 Mdot
.982 .5831 Mdot
.982 .58387 Mdot
.982 .58415 Mdot
.982 .58458 Mdot
.982 .58467 Mdot
.982 .58476 Mdot
.982 .58499 Mdot
.982 .58515 Mdot
.982 .58542 Mdot
.982 .58557 Mdot
.982 .58563 Mdot
.982 .58587 Mdot
.982 .58597 Mdot
.982 .58615 Mdot
.982 .58684 Mdot
.982 .58688 Mdot
.982 .58719 Mdot
.982 .58737 Mdot
.982 .58771 Mdot
.982 .58782 Mdot
.982 .58803 Mdot
.982 .58811 Mdot
.982 .58811 Mdot
.982 .58812 Mdot
.982 .58814 Mdot
.982 .58838 Mdot
.982 .58902 Mdot
.982 .58911 Mdot
.982 .58933 Mdot
.982 .58935 Mdot
.982 .58973 Mdot
.982 .58974 Mdot
.982 .58985 Mdot
.982 .58998 Mdot
.982 .59016 Mdot
.982 .59016 Mdot
.982 .59017 Mdot
.982 .59021 Mdot
.982 .59023 Mdot
.982 .59038 Mdot
.982 .59039 Mdot
.982 .5904 Mdot
.982 .59042 Mdot
.982 .5906 Mdot
.982 .59062 Mdot
.982 .59064 Mdot
.982 .59069 Mdot
.982 .59069 Mdot
.982 .59083 Mdot
.982 .59083 Mdot
.982 .59089 Mdot
.982 .59093 Mdot
.982 .59094 Mdot
.982 .59098 Mdot
.982 .59112 Mdot
.982 .59115 Mdot
.982 .59121 Mdot
.982 .59121 Mdot
.982 .59128 Mdot
.982 .59128 Mdot
.982 .59129 Mdot
.982 .59132 Mdot
.982 .59132 Mdot
.982 .59136 Mdot
.982 .59137 Mdot
.982 .59138 Mdot
.982 .5914 Mdot
.982 .59142 Mdot
.982 .59143 Mdot
.982 .59146 Mdot
.982 .59147 Mdot
.982 .59148 Mdot
.982 .59153 Mdot
.982 .59154 Mdot
.982 .59155 Mdot
.982 .59156 Mdot
.982 .59156 Mdot
.982 .59156 Mdot
.982 .59157 Mdot
.982 .59157 Mdot
.982 .59157 Mdot
.982 .59157 Mdot
.982 .59158 Mdot
.982 .59158 Mdot
.982 .5916 Mdot
.982 .59163 Mdot
.982 .59163 Mdot
.982 .59163 Mdot
.982 .59169 Mdot
.982 .5917 Mdot
.982 .5917 Mdot
.982 .59177 Mdot
.982 .5918 Mdot
.982 .5918 Mdot
.982 .59181 Mdot
.982 .59182 Mdot
.982 .59182 Mdot
.982 .59184 Mdot
.982 .59184 Mdot
.982 .59186 Mdot
.982 .59188 Mdot
.982 .59193 Mdot
.982 .59204 Mdot
.982 .59204 Mdot
.982 .59205 Mdot
.982 .59206 Mdot
.982 .5921 Mdot
.982 .59217 Mdot
.982 .59219 Mdot
.982 .59223 Mdot
.982 .59225 Mdot
.982 .59225 Mdot
.982 .59225 Mdot
.982 .59227 Mdot
.982 .5923 Mdot
.982 .5923 Mdot
.982 .59231 Mdot
.982 .59231 Mdot
.982 .59233 Mdot
.982 .59234 Mdot
.982 .59236 Mdot
.982 .59237 Mdot
.982 .59238 Mdot
.982 .59238 Mdot
.982 .59239 Mdot
.982 .59239 Mdot
.982 .59241 Mdot
.982 .59241 Mdot
.982 .59242 Mdot
.982 .59243 Mdot
.982 .59246 Mdot
.982 .59246 Mdot
.982 .59246 Mdot
.982 .59247 Mdot
.982 .59248 Mdot
.982 .59248 Mdot
.982 .5925 Mdot
.982 .5925 Mdot
.982 .59253 Mdot
.982 .59258 Mdot
.982 .59259 Mdot
.982 .5926 Mdot
.982 .5926 Mdot
.982 .59261 Mdot
.982 .59261 Mdot
.982 .59261 Mdot
.982 .59262 Mdot
.982 .59264 Mdot
.982 .59264 Mdot
.982 .59265 Mdot
.982 .59267 Mdot
.982 .59267 Mdot
.982 .59267 Mdot
.982 .59267 Mdot
.982 .59267 Mdot
.982 .59269 Mdot
.982 .59269 Mdot
.982 .5927 Mdot
.982 .5927 Mdot
.982 .59271 Mdot
.982 .59271 Mdot
.982 .59271 Mdot
.982 .59272 Mdot
.982 .59272 Mdot
.982 .59273 Mdot
.982 .59273 Mdot
.984 .16006 Mdot
.984 .16007 Mdot
.984 .16008 Mdot
.984 .16008 Mdot
.984 .16008 Mdot
.984 .16008 Mdot
.984 .16011 Mdot
.984 .16014 Mdot
.984 .16015 Mdot
.984 .16016 Mdot
.984 .16019 Mdot
.984 .16024 Mdot
.984 .16039 Mdot
.984 .16043 Mdot
.984 .16045 Mdot
.984 .16051 Mdot
.984 .16052 Mdot
.984 .16053 Mdot
.984 .16059 Mdot
.984 .16074 Mdot
.984 .16092 Mdot
.984 .16118 Mdot
.984 .16128 Mdot
.984 .16134 Mdot
.984 .16135 Mdot
.984 .16149 Mdot
.984 .16174 Mdot
.984 .16186 Mdot
.984 .16192 Mdot
.984 .16194 Mdot
.984 .16201 Mdot
.984 .16205 Mdot
.984 .16257 Mdot
.984 .16304 Mdot
.984 .16315 Mdot
.984 .1636 Mdot
.984 .16401 Mdot
.984 .16411 Mdot
.984 .16443 Mdot
.984 .16449 Mdot
.984 .16456 Mdot
.984 .16476 Mdot
.984 .16549 Mdot
.984 .16555 Mdot
.984 .16607 Mdot
.984 .16616 Mdot
.984 .16653 Mdot
.984 .16686 Mdot
.984 .16698 Mdot
.984 .16716 Mdot
.984 .16716 Mdot
.984 .16749 Mdot
.984 .16804 Mdot
.984 .16845 Mdot
.984 .16875 Mdot
.984 .1689 Mdot
.984 .16962 Mdot
.984 .16964 Mdot
.984 .17055 Mdot
.984 .17085 Mdot
.984 .17099 Mdot
.984 .17103 Mdot
.984 .1711 Mdot
.984 .17122 Mdot
.984 .17124 Mdot
.984 .17127 Mdot
.984 .17141 Mdot
.984 .17212 Mdot
.984 .17221 Mdot
.984 .17268 Mdot
.984 .17285 Mdot
.984 .17307 Mdot
.984 .17356 Mdot
.984 .17398 Mdot
.984 .17472 Mdot
.984 .17557 Mdot
.984 .17578 Mdot
.984 .1768 Mdot
.984 .1769 Mdot
.984 .17692 Mdot
.984 .17745 Mdot
.984 .17764 Mdot
.984 .17781 Mdot
.984 .17794 Mdot
.984 .17856 Mdot
.984 .17866 Mdot
.984 .17927 Mdot
.984 .18011 Mdot
.984 .18035 Mdot
.984 .18067 Mdot
.984 .18082 Mdot
.984 .18099 Mdot
.984 .1812 Mdot
.984 .18146 Mdot
.984 .18208 Mdot
.984 .18219 Mdot
.984 .18225 Mdot
.984 .18233 Mdot
.984 .18235 Mdot
.984 .18244 Mdot
.984 .18258 Mdot
.984 .18276 Mdot
.984 .18337 Mdot
.984 .18451 Mdot
.984 .18492 Mdot
.984 .18541 Mdot
.984 .1863 Mdot
.984 .18665 Mdot
.984 .18692 Mdot
.984 .18781 Mdot
.984 .1879 Mdot
.984 .18832 Mdot
.984 .18866 Mdot
.984 .18877 Mdot
.984 .1896 Mdot
.984 .18997 Mdot
.984 .19066 Mdot
.984 .19122 Mdot
.984 .19203 Mdot
.984 .19532 Mdot
.984 .19539 Mdot
.984 .19763 Mdot
.984 .19791 Mdot
.984 .19904 Mdot
.984 .19989 Mdot
.984 .20173 Mdot
.984 .20215 Mdot
.984 .20399 Mdot
.984 .20415 Mdot
.984 .20629 Mdot
.984 .2069 Mdot
.984 .20817 Mdot
.984 .2086 Mdot
.984 .20901 Mdot
.984 .20963 Mdot
.984 .20969 Mdot
.984 .20981 Mdot
.984 .21035 Mdot
.984 .21084 Mdot
.984 .2114 Mdot
.984 .21154 Mdot
.984 .21244 Mdot
.984 .21377 Mdot
.984 .21382 Mdot
.984 .21423 Mdot
.984 .21502 Mdot
.984 .21515 Mdot
.984 .21572 Mdot
.984 .21658 Mdot
.984 .21659 Mdot
.984 .21909 Mdot
.984 .2194 Mdot
.984 .21953 Mdot
.984 .22035 Mdot
.984 .2204 Mdot
.984 .22081 Mdot
.984 .22087 Mdot
.984 .22115 Mdot
.984 .22145 Mdot
.984 .22166 Mdot
.984 .22181 Mdot
.984 .22225 Mdot
.984 .22267 Mdot
.984 .22287 Mdot
.984 .22293 Mdot
.984 .22306 Mdot
.984 .22362 Mdot
.984 .22378 Mdot
.984 .22398 Mdot
.984 .22416 Mdot
.984 .22479 Mdot
.984 .22527 Mdot
.984 .22558 Mdot
.984 .22564 Mdot
.984 .22617 Mdot
.984 .22647 Mdot
.984 .22656 Mdot
.984 .22667 Mdot
.984 .22678 Mdot
.984 .22694 Mdot
.984 .22719 Mdot
.984 .22724 Mdot
.984 .22725 Mdot
.984 .22728 Mdot
.984 .22733 Mdot
.984 .22738 Mdot
.984 .22865 Mdot
.984 .22874 Mdot
.984 .22905 Mdot
.984 .23129 Mdot
.984 .23307 Mdot
.984 .2343 Mdot
.984 .23591 Mdot
.984 .23793 Mdot
.984 .23819 Mdot
.984 .23998 Mdot
.984 .2422 Mdot
.984 .24226 Mdot
.984 .24418 Mdot
.984 .24615 Mdot
.984 .24627 Mdot
.984 .24959 Mdot
.984 .25088 Mdot
.984 .2525 Mdot
.984 .25333 Mdot
.984 .25401 Mdot
.984 .25446 Mdot
.984 .25454 Mdot
.984 .25465 Mdot
.984 .25495 Mdot
.984 .2552 Mdot
.984 .25523 Mdot
.984 .25573 Mdot
.984 .25873 Mdot
.984 .25949 Mdot
.984 .25998 Mdot
.984 .26101 Mdot
.984 .26186 Mdot
.984 .26258 Mdot
.984 .26293 Mdot
.984 .26416 Mdot
.984 .26533 Mdot
.984 .26557 Mdot
.984 .26942 Mdot
.984 .26944 Mdot
.984 .27244 Mdot
.984 .2729 Mdot
.984 .27429 Mdot
.984 .27496 Mdot
.984 .27515 Mdot
.984 .27601 Mdot
.984 .27665 Mdot
.984 .27748 Mdot
.984 .27793 Mdot
.984 .27806 Mdot
.984 .27816 Mdot
.984 .27823 Mdot
.984 .27824 Mdot
.984 .27835 Mdot
.984 .27843 Mdot
.984 .27889 Mdot
.984 .27925 Mdot
.984 .2795 Mdot
.984 .27974 Mdot
.984 .27993 Mdot
.984 .28058 Mdot
.984 .28107 Mdot
.984 .28114 Mdot
.984 .28165 Mdot
.984 .28176 Mdot
.984 .28189 Mdot
.984 .28258 Mdot
.984 .28363 Mdot
.984 .28503 Mdot
.984 .28541 Mdot
.984 .28586 Mdot
.984 .28623 Mdot
.984 .28676 Mdot
.984 .28746 Mdot
.984 .28776 Mdot
.984 .28783 Mdot
.984 .28787 Mdot
.984 .28832 Mdot
.984 .28926 Mdot
.984 .29007 Mdot
.984 .29023 Mdot
.984 .29057 Mdot
.984 .29104 Mdot
.984 .29169 Mdot
.984 .29209 Mdot
.984 .29231 Mdot
.984 .29246 Mdot
.984 .29336 Mdot
.984 .29347 Mdot
.984 .2953 Mdot
.984 .29561 Mdot
.984 .2958 Mdot
.984 .2963 Mdot
.984 .29794 Mdot
.984 .3004 Mdot
.984 .30152 Mdot
.984 .30188 Mdot
.984 .30192 Mdot
.984 .30236 Mdot
.984 .30385 Mdot
.984 .30475 Mdot
.984 .30512 Mdot
.984 .3052 Mdot
.984 .30541 Mdot
.984 .30719 Mdot
.984 .30812 Mdot
.984 .30824 Mdot
.984 .30884 Mdot
.984 .30954 Mdot
.984 .3097 Mdot
.984 .30979 Mdot
.984 .31036 Mdot
.984 .31072 Mdot
.984 .31094 Mdot
.984 .31123 Mdot
.984 .31167 Mdot
.984 .3132 Mdot
.984 .31327 Mdot
.984 .31358 Mdot
.984 .31484 Mdot
.984 .31595 Mdot
.984 .31718 Mdot
.984 .31745 Mdot
.984 .31759 Mdot
.984 .3178 Mdot
.984 .3179 Mdot
.984 .319 Mdot
.984 .31992 Mdot
.984 .32089 Mdot
.984 .32157 Mdot
.984 .32233 Mdot
.984 .32378 Mdot
.984 .32386 Mdot
.984 .32516 Mdot
.984 .32596 Mdot
.984 .32875 Mdot
.984 .33002 Mdot
.984 .3304 Mdot
.984 .33041 Mdot
.984 .33045 Mdot
.984 .33137 Mdot
.984 .33197 Mdot
.984 .33367 Mdot
.984 .33459 Mdot
.984 .33554 Mdot
.984 .33555 Mdot
.984 .33599 Mdot
.984 .33866 Mdot
.984 .33895 Mdot
.984 .33973 Mdot
.984 .34168 Mdot
.984 .34265 Mdot
.984 .34369 Mdot
.984 .34403 Mdot
.984 .34426 Mdot
.984 .34434 Mdot
.984 .34489 Mdot
.984 .34596 Mdot
.984 .34649 Mdot
.984 .34858 Mdot
.984 .35001 Mdot
.984 .35018 Mdot
.984 .35086 Mdot
.984 .35137 Mdot
.984 .35379 Mdot
.984 .35642 Mdot
.984 .35665 Mdot
.984 .357 Mdot
.984 .3571 Mdot
.984 .3574 Mdot
.984 .35767 Mdot
.984 .35798 Mdot
.984 .35928 Mdot
.984 .35953 Mdot
.984 .35996 Mdot
.984 .36003 Mdot
.984 .36034 Mdot
.984 .3608 Mdot
.984 .36081 Mdot
.984 .36214 Mdot
.984 .36238 Mdot
.984 .36305 Mdot
.984 .36323 Mdot
.984 .3638 Mdot
.984 .36413 Mdot
.984 .36416 Mdot
.984 .36423 Mdot
.984 .36452 Mdot
.984 .3646 Mdot
.984 .3648 Mdot
.984 .36513 Mdot
.984 .36537 Mdot
.984 .36557 Mdot
.984 .36584 Mdot
.984 .366 Mdot
.984 .36604 Mdot
.984 .3661 Mdot
.984 .36615 Mdot
.984 .36624 Mdot
.984 .36636 Mdot
.984 .36639 Mdot
.984 .36639 Mdot
.984 .36641 Mdot
.984 .36643 Mdot
.984 .36646 Mdot
.984 .36711 Mdot
.984 .36731 Mdot
.984 .36935 Mdot
.984 .36996 Mdot
.984 .37076 Mdot
.984 .37278 Mdot
.984 .37389 Mdot
.984 .37483 Mdot
.984 .37744 Mdot
.984 .37883 Mdot
.984 .37922 Mdot
.984 .37955 Mdot
.984 .37976 Mdot
.984 .3798 Mdot
.984 .37999 Mdot
.984 .38012 Mdot
.984 .38036 Mdot
.984 .38177 Mdot
.984 .38236 Mdot
.984 .38284 Mdot
.984 .38324 Mdot
.984 .38358 Mdot
.984 .38431 Mdot
.984 .38486 Mdot
.984 .38676 Mdot
.984 .38814 Mdot
.984 .38835 Mdot
.984 .38978 Mdot
.984 .39007 Mdot
.984 .39045 Mdot
.984 .39088 Mdot
.984 .39209 Mdot
.984 .39212 Mdot
.984 .39235 Mdot
.984 .39466 Mdot
.984 .39515 Mdot
.984 .39707 Mdot
.984 .39873 Mdot
.984 .39969 Mdot
.984 .40079 Mdot
.984 .40128 Mdot
.984 .40166 Mdot
.984 .40272 Mdot
.984 .40292 Mdot
.984 .40454 Mdot
.984 .40485 Mdot
.984 .40492 Mdot
.984 .40496 Mdot
.984 .40521 Mdot
.984 .40537 Mdot
.984 .40547 Mdot
.984 .40579 Mdot
.984 .40647 Mdot
.984 .4085 Mdot
.984 .40855 Mdot
.984 .41017 Mdot
.984 .4105 Mdot
.984 .41118 Mdot
.984 .4121 Mdot
.984 .41333 Mdot
.984 .41406 Mdot
.984 .41407 Mdot
.984 .41448 Mdot
.984 .41474 Mdot
.984 .41549 Mdot
.984 .41631 Mdot
.984 .41651 Mdot
.984 .41768 Mdot
.984 .4178 Mdot
.984 .41942 Mdot
.984 .41988 Mdot
.984 .42003 Mdot
.984 .42017 Mdot
.984 .42088 Mdot
.984 .42111 Mdot
.984 .42202 Mdot
.984 .42302 Mdot
.984 .42325 Mdot
.984 .42431 Mdot
.984 .42546 Mdot
.984 .42556 Mdot
.984 .42571 Mdot
.984 .42575 Mdot
.984 .42589 Mdot
.984 .42614 Mdot
.984 .42671 Mdot
.984 .42701 Mdot
.984 .42704 Mdot
.984 .42717 Mdot
.984 .42738 Mdot
.984 .42796 Mdot
.984 .42836 Mdot
.984 .42869 Mdot
.984 .42884 Mdot
.984 .42885 Mdot
.984 .42888 Mdot
.984 .42901 Mdot
.984 .42904 Mdot
.984 .42913 Mdot
.984 .42946 Mdot
.984 .42958 Mdot
.984 .42965 Mdot
.984 .42967 Mdot
.984 .4297 Mdot
.984 .42976 Mdot
.984 .42981 Mdot
.984 .42983 Mdot
.984 .42983 Mdot
.984 .42983 Mdot
.984 .42984 Mdot
.984 .42986 Mdot
.984 .51424 Mdot
.984 .51425 Mdot
.984 .51426 Mdot
.984 .51426 Mdot
.984 .51426 Mdot
.984 .51427 Mdot
.984 .5143 Mdot
.984 .51433 Mdot
.984 .51434 Mdot
.984 .51435 Mdot
.984 .51439 Mdot
.984 .51445 Mdot
.984 .51462 Mdot
.984 .51467 Mdot
.984 .51469 Mdot
.984 .51475 Mdot
.984 .51477 Mdot
.984 .51478 Mdot
.984 .51485 Mdot
.984 .51502 Mdot
.984 .51523 Mdot
.984 .51553 Mdot
.984 .51564 Mdot
.984 .51571 Mdot
.984 .51572 Mdot
.984 .51588 Mdot
.984 .51617 Mdot
.984 .5163 Mdot
.984 .51637 Mdot
.984 .51639 Mdot
.984 .51647 Mdot
.984 .51652 Mdot
.984 .5171 Mdot
.984 .51764 Mdot
.984 .51775 Mdot
.984 .51826 Mdot
.984 .51872 Mdot
.984 .51883 Mdot
.984 .51919 Mdot
.984 .51925 Mdot
.984 .51933 Mdot
.984 .51956 Mdot
.984 .52036 Mdot
.984 .52042 Mdot
.984 .52099 Mdot
.984 .52109 Mdot
.984 .52149 Mdot
.984 .52185 Mdot
.984 .52198 Mdot
.984 .52218 Mdot
.984 .52219 Mdot
.984 .52254 Mdot
.984 .52313 Mdot
.984 .52357 Mdot
.984 .52389 Mdot
.984 .52405 Mdot
.984 .52482 Mdot
.984 .52484 Mdot
.984 .52579 Mdot
.984 .52611 Mdot
.984 .52626 Mdot
.984 .5263 Mdot
.984 .52638 Mdot
.984 .52649 Mdot
.984 .52651 Mdot
.984 .52654 Mdot
.984 .52669 Mdot
.984 .52743 Mdot
.984 .52752 Mdot
.984 .52801 Mdot
.984 .52818 Mdot
.984 .52841 Mdot
.984 .52891 Mdot
.984 .52934 Mdot
.984 .53008 Mdot
.984 .53094 Mdot
.984 .53115 Mdot
.984 .53217 Mdot
.984 .53227 Mdot
.984 .53228 Mdot
.984 .53281 Mdot
.984 .53299 Mdot
.984 .53316 Mdot
.984 .53328 Mdot
.984 .5339 Mdot
.984 .53399 Mdot
.984 .53458 Mdot
.984 .53539 Mdot
.984 .53562 Mdot
.984 .53592 Mdot
.984 .53607 Mdot
.984 .53623 Mdot
.984 .53643 Mdot
.984 .53668 Mdot
.984 .53726 Mdot
.984 .53736 Mdot
.984 .53742 Mdot
.984 .5375 Mdot
.984 .53751 Mdot
.984 .5376 Mdot
.984 .53773 Mdot
.984 .5379 Mdot
.984 .53847 Mdot
.984 .53953 Mdot
.984 .5399 Mdot
.984 .54035 Mdot
.984 .54115 Mdot
.984 .54147 Mdot
.984 .54171 Mdot
.984 .5425 Mdot
.984 .54258 Mdot
.984 .54284 Mdot
.984 .54285 Mdot
.984 .54286 Mdot
.984 .54286 Mdot
.984 .54286 Mdot
.984 .54287 Mdot
.984 .54292 Mdot
.984 .54296 Mdot
.984 .54298 Mdot
.984 .543 Mdot
.984 .54302 Mdot
.984 .54308 Mdot
.984 .54318 Mdot
.984 .54326 Mdot
.984 .54335 Mdot
.984 .54348 Mdot
.984 .54355 Mdot
.984 .54359 Mdot
.984 .5437 Mdot
.984 .54373 Mdot
.984 .54374 Mdot
.984 .54386 Mdot
.984 .54408 Mdot
.984 .54415 Mdot
.984 .54441 Mdot
.984 .5445 Mdot
.984 .545 Mdot
.984 .54501 Mdot
.984 .54518 Mdot
.984 .5453 Mdot
.984 .54532 Mdot
.984 .54549 Mdot
.984 .54558 Mdot
.984 .54607 Mdot
.984 .54618 Mdot
.984 .54628 Mdot
.984 .5464 Mdot
.984 .54644 Mdot
.984 .54656 Mdot
.984 .54665 Mdot
.984 .54762 Mdot
.984 .5485 Mdot
.984 .54869 Mdot
.984 .54894 Mdot
.984 .549 Mdot
.984 .54951 Mdot
.984 .55026 Mdot
.984 .55044 Mdot
.984 .55082 Mdot
.984 .55102 Mdot
.984 .55104 Mdot
.984 .55112 Mdot
.984 .55124 Mdot
.984 .55161 Mdot
.984 .55195 Mdot
.984 .55262 Mdot
.984 .55289 Mdot
.984 .55299 Mdot
.984 .5539 Mdot
.984 .55405 Mdot
.984 .55405 Mdot
.984 .55437 Mdot
.984 .55468 Mdot
.984 .55525 Mdot
.984 .55545 Mdot
.984 .55575 Mdot
.984 .55576 Mdot
.984 .55577 Mdot
.984 .55589 Mdot
.984 .55631 Mdot
.984 .55722 Mdot
.984 .55748 Mdot
.984 .5579 Mdot
.984 .55792 Mdot
.984 .55839 Mdot
.984 .55863 Mdot
.984 .55884 Mdot
.984 .55915 Mdot
.984 .55944 Mdot
.984 .55978 Mdot
.984 .55981 Mdot
.984 .55988 Mdot
.984 .55992 Mdot
.984 .56001 Mdot
.984 .56039 Mdot
.984 .56073 Mdot
.984 .56112 Mdot
.984 .56121 Mdot
.984 .56123 Mdot
.984 .5617 Mdot
.984 .56183 Mdot
.984 .56192 Mdot
.984 .56199 Mdot
.984 .5621 Mdot
.984 .56227 Mdot
.984 .5623 Mdot
.984 .56234 Mdot
.984 .56255 Mdot
.984 .56273 Mdot
.984 .56277 Mdot
.984 .56305 Mdot
.984 .56357 Mdot
.984 .56363 Mdot
.984 .56366 Mdot
.984 .56377 Mdot
.984 .56403 Mdot
.984 .56446 Mdot
.984 .56459 Mdot
.984 .5646 Mdot
.984 .56471 Mdot
.984 .56503 Mdot
.984 .56574 Mdot
.984 .5662 Mdot
.984 .56634 Mdot
.984 .5664 Mdot
.984 .56648 Mdot
.984 .567 Mdot
.984 .56703 Mdot
.984 .56728 Mdot
.984 .56732 Mdot
.984 .56738 Mdot
.984 .56749 Mdot
.984 .56767 Mdot
.984 .5678 Mdot
.984 .56789 Mdot
.984 .56816 Mdot
.984 .56842 Mdot
.984 .56854 Mdot
.984 .56855 Mdot
.984 .56857 Mdot
.984 .56865 Mdot
.984 .56884 Mdot
.984 .56898 Mdot
.984 .56908 Mdot
.984 .5692 Mdot
.984 .56931 Mdot
.984 .56968 Mdot
.984 .56996 Mdot
.984 .57014 Mdot
.984 .57018 Mdot
.984 .57021 Mdot
.984 .57034 Mdot
.984 .57036 Mdot
.984 .57049 Mdot
.984 .57066 Mdot
.984 .57071 Mdot
.984 .57077 Mdot
.984 .57084 Mdot
.984 .57093 Mdot
.984 .57105 Mdot
.984 .57107 Mdot
.984 .5711 Mdot
.984 .5711 Mdot
.984 .57112 Mdot
.984 .57115 Mdot
.984 .57118 Mdot
.984 .57129 Mdot
.984 .57151 Mdot
.984 .57167 Mdot
.984 .57189 Mdot
.984 .57194 Mdot
.984 .57211 Mdot
.984 .57247 Mdot
.984 .57258 Mdot
.984 .57334 Mdot
.984 .57334 Mdot
.984 .57429 Mdot
.984 .57435 Mdot
.984 .57463 Mdot
.984 .57493 Mdot
.984 .57501 Mdot
.984 .57519 Mdot
.984 .57539 Mdot
.984 .57563 Mdot
.984 .57575 Mdot
.984 .57593 Mdot
.984 .57663 Mdot
.984 .57675 Mdot
.984 .57676 Mdot
.984 .57681 Mdot
.984 .57688 Mdot
.984 .57691 Mdot
.984 .57693 Mdot
.984 .57703 Mdot
.984 .57719 Mdot
.984 .57738 Mdot
.984 .57775 Mdot
.984 .57804 Mdot
.984 .57878 Mdot
.984 .57881 Mdot
.984 .57924 Mdot
.984 .57966 Mdot
.984 .57967 Mdot
.984 .58015 Mdot
.984 .58054 Mdot
.984 .58059 Mdot
.984 .58102 Mdot
.984 .58135 Mdot
.984 .58161 Mdot
.984 .58198 Mdot
.984 .58243 Mdot
.984 .58249 Mdot
.984 .58251 Mdot
.984 .58277 Mdot
.984 .58278 Mdot
.984 .58279 Mdot
.984 .5828 Mdot
.984 .5828 Mdot
.984 .58281 Mdot
.984 .58286 Mdot
.984 .58289 Mdot
.984 .58291 Mdot
.984 .58293 Mdot
.984 .58295 Mdot
.984 .58301 Mdot
.984 .58312 Mdot
.984 .58313 Mdot
.984 .58319 Mdot
.984 .58328 Mdot
.984 .58341 Mdot
.984 .58344 Mdot
.984 .58348 Mdot
.984 .58352 Mdot
.984 .58362 Mdot
.984 .58365 Mdot
.984 .58366 Mdot
.984 .5837 Mdot
.984 .58378 Mdot
.984 .58387 Mdot
.984 .5839 Mdot
.984 .58394 Mdot
.984 .584 Mdot
.984 .58405 Mdot
.984 .58406 Mdot
.984 .58414 Mdot
.984 .58415 Mdot
.984 .58431 Mdot
.984 .58433 Mdot
.984 .58439 Mdot
.984 .58487 Mdot
.984 .58487 Mdot
.984 .58503 Mdot
.984 .58514 Mdot
.984 .58516 Mdot
.984 .58531 Mdot
.984 .58539 Mdot
.984 .5854 Mdot
.984 .58564 Mdot
.984 .58581 Mdot
.984 .58584 Mdot
.984 .58594 Mdot
.984 .58603 Mdot
.984 .58613 Mdot
.984 .58615 Mdot
.984 .58616 Mdot
.984 .58627 Mdot
.984 .58634 Mdot
.984 .58642 Mdot
.984 .58665 Mdot
.984 .58676 Mdot
.984 .58714 Mdot
.984 .58717 Mdot
.984 .58749 Mdot
.984 .58756 Mdot
.984 .58788 Mdot
.984 .58802 Mdot
.984 .58822 Mdot
.984 .58826 Mdot
.984 .58864 Mdot
.984 .58865 Mdot
.984 .58919 Mdot
.984 .58933 Mdot
.984 .58942 Mdot
.984 .58953 Mdot
.984 .58959 Mdot
.984 .58972 Mdot
.984 .58974 Mdot
.984 .58979 Mdot
.984 .58986 Mdot
.984 .58987 Mdot
.984 .59002 Mdot
.984 .59006 Mdot
.984 .59011 Mdot
.984 .59025 Mdot
.984 .59033 Mdot
.984 .59039 Mdot
.984 .59057 Mdot
.984 .59067 Mdot
.984 .59069 Mdot
.984 .59071 Mdot
.984 .59073 Mdot
.984 .59073 Mdot
.984 .59074 Mdot
.984 .59075 Mdot
.984 .59077 Mdot
.984 .59086 Mdot
.984 .5909 Mdot
.984 .59094 Mdot
.984 .59096 Mdot
.984 .59099 Mdot
.984 .59103 Mdot
.984 .59107 Mdot
.984 .5912 Mdot
.984 .59129 Mdot
.984 .5913 Mdot
.984 .5914 Mdot
.984 .59142 Mdot
.984 .59144 Mdot
.984 .59147 Mdot
.984 .59155 Mdot
.984 .59155 Mdot
.984 .59157 Mdot
.984 .59172 Mdot
.984 .59175 Mdot
.984 .59187 Mdot
.984 .59198 Mdot
.984 .59204 Mdot
.984 .59211 Mdot
.984 .59214 Mdot
.984 .59217 Mdot
.984 .59224 Mdot
.984 .59225 Mdot
.984 .59235 Mdot
.984 .59237 Mdot
.984 .59237 Mdot
.984 .59238 Mdot
.984 .59239 Mdot
.984 .5924 Mdot
.984 .59241 Mdot
.984 .59243 Mdot
.984 .59247 Mdot
.984 .5926 Mdot
.984 .5926 Mdot
.984 .59271 Mdot
.984 .59273 Mdot
.984 .59277 Mdot
.984 .59283 Mdot
.984 .5929 Mdot
.984 .59295 Mdot
.984 .59295 Mdot
.984 .59297 Mdot
.984 .59299 Mdot
.984 .59304 Mdot
.984 .59309 Mdot
.984 .5931 Mdot
.984 .59317 Mdot
.984 .59318 Mdot
.984 .59328 Mdot
.984 .59331 Mdot
.984 .59331 Mdot
.984 .59332 Mdot
.984 .59337 Mdot
.984 .59338 Mdot
.984 .59344 Mdot
.984 .5935 Mdot
.984 .59351 Mdot
.984 .59357 Mdot
.984 .59364 Mdot
.984 .59365 Mdot
.984 .59366 Mdot
.984 .59366 Mdot
.984 .59367 Mdot
.984 .59368 Mdot
.984 .59372 Mdot
.984 .59374 Mdot
.984 .59374 Mdot
.984 .59375 Mdot
.984 .59376 Mdot
.984 .59379 Mdot
.984 .59382 Mdot
.984 .59384 Mdot
.984 .59385 Mdot
.984 .59385 Mdot
.984 .59385 Mdot
.984 .59386 Mdot
.984 .59386 Mdot
.984 .59386 Mdot
.984 .59388 Mdot
.984 .59389 Mdot
.984 .59389 Mdot
.984 .5939 Mdot
.984 .5939 Mdot
.984 .5939 Mdot
.984 .5939 Mdot
.984 .59391 Mdot
.984 .59391 Mdot
.984 .59391 Mdot
.984 .59391 Mdot
.984 .59391 Mdot
.986 .1511 Mdot
.986 .15149 Mdot
.986 .30838 Mdot
.986 .31283 Mdot
.986 .40571 Mdot
.986 .40764 Mdot
.986 .4478 Mdot
.986 .44864 Mdot
.986 .50446 Mdot
.986 .50494 Mdot
.986 .52562 Mdot
.986 .52651 Mdot
.986 .56153 Mdot
.986 .56287 Mdot
.986 .59504 Mdot
.986 .59508 Mdot
.988 .14136 Mdot
.988 .14136 Mdot
.988 .14139 Mdot
.988 .14144 Mdot
.988 .14155 Mdot
.988 .14179 Mdot
.988 .14181 Mdot
.988 .14195 Mdot
.988 .14219 Mdot
.988 .14225 Mdot
.988 .14227 Mdot
.988 .14263 Mdot
.988 .14294 Mdot
.988 .14297 Mdot
.988 .14298 Mdot
.988 .14304 Mdot
.988 .14322 Mdot
.988 .14322 Mdot
.988 .14337 Mdot
.988 .14353 Mdot
.988 .14378 Mdot
.988 .14442 Mdot
.988 .14481 Mdot
.988 .14491 Mdot
.988 .14496 Mdot
.988 .1453 Mdot
.988 .14533 Mdot
.988 .14581 Mdot
.988 .14591 Mdot
.988 .146 Mdot
.988 .1461 Mdot
.988 .14656 Mdot
.988 .1467 Mdot
.988 .14683 Mdot
.988 .14698 Mdot
.988 .14713 Mdot
.988 .14726 Mdot
.988 .14879 Mdot
.988 .14974 Mdot
.988 .14988 Mdot
.988 .15041 Mdot
.988 .15103 Mdot
.988 .15115 Mdot
.988 .15117 Mdot
.988 .15145 Mdot
.988 .15145 Mdot
.988 .15181 Mdot
.988 .15195 Mdot
.988 .15201 Mdot
.988 .15227 Mdot
.988 .15315 Mdot
.988 .15324 Mdot
.988 .15326 Mdot
.988 .15406 Mdot
.988 .15438 Mdot
.988 .15458 Mdot
.988 .15521 Mdot
.988 .15543 Mdot
.988 .1557 Mdot
.988 .15585 Mdot
.988 .15611 Mdot
.988 .15613 Mdot
.988 .15652 Mdot
.988 .15727 Mdot
.988 .15749 Mdot
.988 .15752 Mdot
.988 .15837 Mdot
.988 .15907 Mdot
.988 .15912 Mdot
.988 .15945 Mdot
.988 .1633 Mdot
.988 .16501 Mdot
.988 .16514 Mdot
.988 .16642 Mdot
.988 .16657 Mdot
.988 .16921 Mdot
.988 .17026 Mdot
.988 .17078 Mdot
.988 .17118 Mdot
.988 .1712 Mdot
.988 .17122 Mdot
.988 .17136 Mdot
.988 .17146 Mdot
.988 .17236 Mdot
.988 .17251 Mdot
.988 .17356 Mdot
.988 .17577 Mdot
.988 .17605 Mdot
.988 .17621 Mdot
.988 .17729 Mdot
.988 .17811 Mdot
.988 .17982 Mdot
.988 .17991 Mdot
.988 .17991 Mdot
.988 .1814 Mdot
.988 .18227 Mdot
.988 .18252 Mdot
.988 .18278 Mdot
.988 .18441 Mdot
.988 .18592 Mdot
.988 .18801 Mdot
.988 .18918 Mdot
.988 .18944 Mdot
.988 .18952 Mdot
.988 .18967 Mdot
.988 .19209 Mdot
.988 .1921 Mdot
.988 .19435 Mdot
.988 .19524 Mdot
.988 .19535 Mdot
.988 .19872 Mdot
.988 .1999 Mdot
.988 .20053 Mdot
.988 .20061 Mdot
.988 .201 Mdot
.988 .20124 Mdot
.988 .20162 Mdot
.988 .20287 Mdot
.988 .20348 Mdot
.988 .20611 Mdot
.988 .20707 Mdot
.988 .20761 Mdot
.988 .20839 Mdot
.988 .20846 Mdot
.988 .21069 Mdot
.988 .21089 Mdot
.988 .21306 Mdot
.988 .21538 Mdot
.988 .21542 Mdot
.988 .21654 Mdot
.988 .21871 Mdot
.988 .21893 Mdot
.988 .21939 Mdot
.988 .22033 Mdot
.988 .22038 Mdot
.988 .22095 Mdot
.988 .22148 Mdot
.988 .22376 Mdot
.988 .22479 Mdot
.988 .22504 Mdot
.988 .22511 Mdot
.988 .22535 Mdot
.988 .22539 Mdot
.988 .22567 Mdot
.988 .22631 Mdot
.988 .22786 Mdot
.988 .22792 Mdot
.988 .22838 Mdot
.988 .23069 Mdot
.988 .23167 Mdot
.988 .23218 Mdot
.988 .23432 Mdot
.988 .23552 Mdot
.988 .23602 Mdot
.988 .23655 Mdot
.988 .2373 Mdot
.988 .23735 Mdot
.988 .23798 Mdot
.988 .23845 Mdot
.988 .23876 Mdot
.988 .2412 Mdot
.988 .24133 Mdot
.988 .24183 Mdot
.988 .24418 Mdot
.988 .24442 Mdot
.988 .24486 Mdot
.988 .24593 Mdot
.988 .24617 Mdot
.988 .24733 Mdot
.988 .24744 Mdot
.988 .24807 Mdot
.988 .24914 Mdot
.988 .24938 Mdot
.988 .24965 Mdot
.988 .24967 Mdot
.988 .25012 Mdot
.988 .25033 Mdot
.988 .25147 Mdot
.988 .25202 Mdot
.988 .25418 Mdot
.988 .25905 Mdot
.988 .25924 Mdot
.988 .2596 Mdot
.988 .2602 Mdot
.988 .26198 Mdot
.988 .26244 Mdot
.988 .26363 Mdot
.988 .2649 Mdot
.988 .26579 Mdot
.988 .26775 Mdot
.988 .2688 Mdot
.988 .26894 Mdot
.988 .26943 Mdot
.988 .27028 Mdot
.988 .27132 Mdot
.988 .2718 Mdot
.988 .27253 Mdot
.988 .27401 Mdot
.988 .27466 Mdot
.988 .27475 Mdot
.988 .2753 Mdot
.988 .27545 Mdot
.988 .27547 Mdot
.988 .27548 Mdot
.988 .27573 Mdot
.988 .27605 Mdot
.988 .27672 Mdot
.988 .27844 Mdot
.988 .2794 Mdot
.988 .27949 Mdot
.988 .28371 Mdot
.988 .28375 Mdot
.988 .28429 Mdot
.988 .28498 Mdot
.988 .28575 Mdot
.988 .28607 Mdot
.988 .2863 Mdot
.988 .28642 Mdot
.988 .28684 Mdot
.988 .28738 Mdot
.988 .28863 Mdot
.988 .28944 Mdot
.988 .28969 Mdot
.988 .29022 Mdot
.988 .29023 Mdot
.988 .29063 Mdot
.988 .29126 Mdot
.988 .29297 Mdot
.988 .29493 Mdot
.988 .29511 Mdot
.988 .2953 Mdot
.988 .29566 Mdot
.988 .29641 Mdot
.988 .29654 Mdot
.988 .29668 Mdot
.988 .29736 Mdot
.988 .29742 Mdot
.988 .29794 Mdot
.988 .29801 Mdot
.988 .29881 Mdot
.988 .30076 Mdot
.988 .30107 Mdot
.988 .30163 Mdot
.988 .30246 Mdot
.988 .30348 Mdot
.988 .30455 Mdot
.988 .30512 Mdot
.988 .30647 Mdot
.988 .30738 Mdot
.988 .3086 Mdot
.988 .30906 Mdot
.988 .31003 Mdot
.988 .31285 Mdot
.988 .31433 Mdot
.988 .31449 Mdot
.988 .31634 Mdot
.988 .31643 Mdot
.988 .31656 Mdot
.988 .31696 Mdot
.988 .31761 Mdot
.988 .31808 Mdot
.988 .31988 Mdot
.988 .32176 Mdot
.988 .32257 Mdot
.988 .32328 Mdot
.988 .32609 Mdot
.988 .32624 Mdot
.988 .32752 Mdot
.988 .32755 Mdot
.988 .32817 Mdot
.988 .3283 Mdot
.988 .32948 Mdot
.988 .32951 Mdot
.988 .33022 Mdot
.988 .33049 Mdot
.988 .33139 Mdot
.988 .33196 Mdot
.988 .33289 Mdot
.988 .33309 Mdot
.988 .33458 Mdot
.988 .33737 Mdot
.988 .3395 Mdot
.988 .34267 Mdot
.988 .34535 Mdot
.988 .34561 Mdot
.988 .34771 Mdot
.988 .34776 Mdot
.988 .34938 Mdot
.988 .35112 Mdot
.988 .35287 Mdot
.988 .35301 Mdot
.988 .35306 Mdot
.988 .35442 Mdot
.988 .35611 Mdot
.988 .35875 Mdot
.988 .35911 Mdot
.988 .3593 Mdot
.988 .35993 Mdot
.988 .36023 Mdot
.988 .36153 Mdot
.988 .36201 Mdot
.988 .36227 Mdot
.988 .36265 Mdot
.988 .36268 Mdot
.988 .36377 Mdot
.988 .36491 Mdot
.988 .36604 Mdot
.988 .3676 Mdot
.988 .37045 Mdot
.988 .37057 Mdot
.988 .37073 Mdot
.988 .37086 Mdot
.988 .37116 Mdot
.988 .3719 Mdot
.988 .37483 Mdot
.988 .37498 Mdot
.988 .37538 Mdot
.988 .37561 Mdot
.988 .37585 Mdot
.988 .37619 Mdot
.988 .37649 Mdot
.988 .37794 Mdot
.988 .378 Mdot
.988 .37823 Mdot
.988 .37939 Mdot
.988 .38017 Mdot
.988 .38102 Mdot
.988 .3816 Mdot
.988 .38172 Mdot
.988 .38173 Mdot
.988 .38193 Mdot
.988 .38277 Mdot
.988 .38595 Mdot
.988 .38611 Mdot
.988 .38715 Mdot
.988 .38786 Mdot
.988 .38842 Mdot
.988 .38881 Mdot
.988 .39039 Mdot
.988 .39076 Mdot
.988 .39121 Mdot
.988 .39141 Mdot
.988 .39299 Mdot
.988 .39301 Mdot
.988 .39311 Mdot
.988 .39354 Mdot
.988 .39469 Mdot
.988 .39473 Mdot
.988 .39655 Mdot
.988 .39679 Mdot
.988 .39742 Mdot
.988 .39756 Mdot
.988 .39789 Mdot
.988 .39812 Mdot
.988 .399 Mdot
.988 .39934 Mdot
.988 .39951 Mdot
.988 .39978 Mdot
.988 .40051 Mdot
.988 .40134 Mdot
.988 .40142 Mdot
.988 .40165 Mdot
.988 .40197 Mdot
.988 .40203 Mdot
.988 .40209 Mdot
.988 .40238 Mdot
.988 .4024 Mdot
.988 .40299 Mdot
.988 .40382 Mdot
.988 .40396 Mdot
.988 .4042 Mdot
.988 .40455 Mdot
.988 .40544 Mdot
.988 .40568 Mdot
.988 .40625 Mdot
.988 .40664 Mdot
.988 .40776 Mdot
.988 .40895 Mdot
.988 .41047 Mdot
.988 .41053 Mdot
.988 .4107 Mdot
.988 .41117 Mdot
.988 .41273 Mdot
.988 .41307 Mdot
.988 .41337 Mdot
.988 .41462 Mdot
.988 .41516 Mdot
.988 .41543 Mdot
.988 .41549 Mdot
.988 .41599 Mdot
.988 .416 Mdot
.988 .4163 Mdot
.988 .42022 Mdot
.988 .42156 Mdot
.988 .42371 Mdot
.988 .4244 Mdot
.988 .42513 Mdot
.988 .42588 Mdot
.988 .42653 Mdot
.988 .42725 Mdot
.988 .42899 Mdot
.988 .42954 Mdot
.988 .42974 Mdot
.988 .42985 Mdot
.988 .43002 Mdot
.988 .43049 Mdot
.988 .43098 Mdot
.988 .43145 Mdot
.988 .43333 Mdot
.988 .43338 Mdot
.988 .43345 Mdot
.988 .4335 Mdot
.988 .43394 Mdot
.988 .43519 Mdot
.988 .43542 Mdot
.988 .43562 Mdot
.988 .4359 Mdot
.988 .43652 Mdot
.988 .43654 Mdot
.988 .43713 Mdot
.988 .43747 Mdot
.988 .43783 Mdot
.988 .43808 Mdot
.988 .43857 Mdot
.988 .44 Mdot
.988 .44045 Mdot
.988 .44099 Mdot
.988 .44116 Mdot
.988 .44219 Mdot
.988 .44295 Mdot
.988 .44296 Mdot
.988 .443 Mdot
.988 .44319 Mdot
.988 .44368 Mdot
.988 .4437 Mdot
.988 .44458 Mdot
.988 .44485 Mdot
.988 .44491 Mdot
.988 .44505 Mdot
.988 .44515 Mdot
.988 .44575 Mdot
.988 .44587 Mdot
.988 .44618 Mdot
.988 .44654 Mdot
.988 .44699 Mdot
.988 .447 Mdot
.988 .44761 Mdot
.988 .44767 Mdot
.988 .44793 Mdot
.988 .44831 Mdot
.988 .44842 Mdot
.988 .44866 Mdot
.988 .44932 Mdot
.988 .44983 Mdot
.988 .45049 Mdot
.988 .45052 Mdot
.988 .45059 Mdot
.988 .4508 Mdot
.988 .45175 Mdot
.988 .45229 Mdot
.988 .45253 Mdot
.988 .45265 Mdot
.988 .45267 Mdot
.988 .45289 Mdot
.988 .45627 Mdot
.988 .45657 Mdot
.988 .45689 Mdot
.988 .45722 Mdot
.988 .4575 Mdot
.988 .45782 Mdot
.988 .45883 Mdot
.988 .45904 Mdot
.988 .45925 Mdot
.988 .45946 Mdot
.988 .4605 Mdot
.988 .46058 Mdot
.988 .46133 Mdot
.988 .46143 Mdot
.988 .46164 Mdot
.988 .4625 Mdot
.988 .4639 Mdot
.988 .46444 Mdot
.988 .46478 Mdot
.988 .46511 Mdot
.988 .46511 Mdot
.988 .46551 Mdot
.988 .46563 Mdot
.988 .46566 Mdot
.988 .46572 Mdot
.988 .46639 Mdot
.988 .46718 Mdot
.988 .46723 Mdot
.988 .46734 Mdot
.988 .46787 Mdot
.988 .46817 Mdot
.988 .46821 Mdot
.988 .46873 Mdot
.988 .46898 Mdot
.988 .46908 Mdot
.988 .46914 Mdot
.988 .46915 Mdot
.988 .49267 Mdot
.988 .49267 Mdot
.988 .49271 Mdot
.988 .49278 Mdot
.988 .49293 Mdot
.988 .49326 Mdot
.988 .49328 Mdot
.988 .49348 Mdot
.988 .49381 Mdot
.988 .49388 Mdot
.988 .49391 Mdot
.988 .4944 Mdot
.988 .49482 Mdot
.988 .49486 Mdot
.988 .49487 Mdot
.988 .49495 Mdot
.988 .4952 Mdot
.988 .4952 Mdot
.988 .4954 Mdot
.988 .49561 Mdot
.988 .49594 Mdot
.988 .49681 Mdot
.988 .49733 Mdot
.988 .49746 Mdot
.988 .49752 Mdot
.988 .49797 Mdot
.988 .49802 Mdot
.988 .49864 Mdot
.988 .49877 Mdot
.988 .4989 Mdot
.988 .49902 Mdot
.988 .49963 Mdot
.988 .49981 Mdot
.988 .49998 Mdot
.988 .50018 Mdot
.988 .50037 Mdot
.988 .50055 Mdot
.988 .50252 Mdot
.988 .50265 Mdot
.988 .50266 Mdot
.988 .50273 Mdot
.988 .50287 Mdot
.988 .50318 Mdot
.988 .50373 Mdot
.988 .50385 Mdot
.988 .50389 Mdot
.988 .5039 Mdot
.988 .50428 Mdot
.988 .50458 Mdot
.988 .50495 Mdot
.988 .50509 Mdot
.988 .50515 Mdot
.988 .50536 Mdot
.988 .50551 Mdot
.988 .50554 Mdot
.988 .50589 Mdot
.988 .50589 Mdot
.988 .50614 Mdot
.988 .50634 Mdot
.988 .50652 Mdot
.988 .50658 Mdot
.988 .50692 Mdot
.988 .50697 Mdot
.988 .50705 Mdot
.988 .50709 Mdot
.988 .50724 Mdot
.988 .50773 Mdot
.988 .50774 Mdot
.988 .50801 Mdot
.988 .50811 Mdot
.988 .50814 Mdot
.988 .50814 Mdot
.988 .50856 Mdot
.988 .50912 Mdot
.988 .50921 Mdot
.988 .50951 Mdot
.988 .50975 Mdot
.988 .51052 Mdot
.988 .51079 Mdot
.988 .51093 Mdot
.988 .51112 Mdot
.988 .5113 Mdot
.988 .51161 Mdot
.988 .51163 Mdot
.988 .51196 Mdot
.988 .5121 Mdot
.988 .51221 Mdot
.988 .51233 Mdot
.988 .51299 Mdot
.988 .51322 Mdot
.988 .51325 Mdot
.988 .51329 Mdot
.988 .51331 Mdot
.988 .51429 Mdot
.988 .51454 Mdot
.988 .51479 Mdot
.988 .51504 Mdot
.988 .51512 Mdot
.988 .51518 Mdot
.988 .51528 Mdot
.988 .51556 Mdot
.988 .51646 Mdot
.988 .51682 Mdot
.988 .51715 Mdot
.988 .51753 Mdot
.988 .5179 Mdot
.988 .51824 Mdot
.988 .51997 Mdot
.988 .52189 Mdot
.988 .52203 Mdot
.988 .52204 Mdot
.988 .52228 Mdot
.988 .5223 Mdot
.988 .52244 Mdot
.988 .5227 Mdot
.988 .52329 Mdot
.988 .52344 Mdot
.988 .5236 Mdot
.988 .52434 Mdot
.988 .52456 Mdot
.988 .52464 Mdot
.988 .52466 Mdot
.988 .52538 Mdot
.988 .52593 Mdot
.988 .52645 Mdot
.988 .52663 Mdot
.988 .52689 Mdot
.988 .527 Mdot
.988 .52741 Mdot
.988 .52757 Mdot
.988 .52768 Mdot
.988 .52774 Mdot
.988 .52812 Mdot
.988 .52839 Mdot
.988 .5284 Mdot
.988 .52853 Mdot
.988 .52856 Mdot
.988 .52858 Mdot
.988 .52873 Mdot
.988 .52883 Mdot
.988 .52886 Mdot
.988 .52924 Mdot
.988 .52957 Mdot
.988 .52969 Mdot
.988 .52976 Mdot
.988 .52992 Mdot
.988 .53031 Mdot
.988 .53041 Mdot
.988 .53055 Mdot
.988 .53062 Mdot
.988 .53089 Mdot
.988 .531 Mdot
.988 .5318 Mdot
.988 .53181 Mdot
.988 .53232 Mdot
.988 .5325 Mdot
.988 .53255 Mdot
.988 .53255 Mdot
.988 .53324 Mdot
.988 .53333 Mdot
.988 .53352 Mdot
.988 .53368 Mdot
.988 .53435 Mdot
.988 .53452 Mdot
.988 .53475 Mdot
.988 .53505 Mdot
.988 .53549 Mdot
.988 .53556 Mdot
.988 .53688 Mdot
.988 .53723 Mdot
.988 .53731 Mdot
.988 .53732 Mdot
.988 .53737 Mdot
.988 .53761 Mdot
.988 .53795 Mdot
.988 .53827 Mdot
.988 .53874 Mdot
.988 .53883 Mdot
.988 .53886 Mdot
.988 .53944 Mdot
.988 .53957 Mdot
.988 .5397 Mdot
.988 .5398 Mdot
.988 .53989 Mdot
.988 .54005 Mdot
.988 .54011 Mdot
.988 .54127 Mdot
.988 .54156 Mdot
.988 .54168 Mdot
.988 .54173 Mdot
.988 .54179 Mdot
.988 .54184 Mdot
.988 .54295 Mdot
.988 .54355 Mdot
.988 .54398 Mdot
.988 .54442 Mdot
.988 .54483 Mdot
.988 .54484 Mdot
.988 .54498 Mdot
.988 .54508 Mdot
.988 .54526 Mdot
.988 .54575 Mdot
.988 .54586 Mdot
.988 .54609 Mdot
.988 .54617 Mdot
.988 .5463 Mdot
.988 .54727 Mdot
.988 .54789 Mdot
.988 .54839 Mdot
.988 .5484 Mdot
.988 .54845 Mdot
.988 .54909 Mdot
.988 .54971 Mdot
.988 .55028 Mdot
.988 .5503 Mdot
.988 .55104 Mdot
.988 .55113 Mdot
.988 .55206 Mdot
.988 .55315 Mdot
.988 .55387 Mdot
.988 .55481 Mdot
.988 .5553 Mdot
.988 .55537 Mdot
.988 .55568 Mdot
.988 .55586 Mdot
.988 .55616 Mdot
.988 .55625 Mdot
.988 .55648 Mdot
.988 .55649 Mdot
.988 .55687 Mdot
.988 .55692 Mdot
.988 .55712 Mdot
.988 .55712 Mdot
.988 .55754 Mdot
.988 .55758 Mdot
.988 .55848 Mdot
.988 .55871 Mdot
.988 .55896 Mdot
.988 .55955 Mdot
.988 .56011 Mdot
.988 .56026 Mdot
.988 .56045 Mdot
.988 .56058 Mdot
.988 .56062 Mdot
.988 .56065 Mdot
.988 .56121 Mdot
.988 .56126 Mdot
.988 .56171 Mdot
.988 .56256 Mdot
.988 .56284 Mdot
.988 .56298 Mdot
.988 .56334 Mdot
.988 .56361 Mdot
.988 .564 Mdot
.988 .56417 Mdot
.988 .56448 Mdot
.988 .56478 Mdot
.988 .56501 Mdot
.988 .56517 Mdot
.988 .56526 Mdot
.988 .56582 Mdot
.988 .56604 Mdot
.988 .56606 Mdot
.988 .56621 Mdot
.988 .56623 Mdot
.988 .56642 Mdot
.988 .56646 Mdot
.988 .56649 Mdot
.988 .5667 Mdot
.988 .5668 Mdot
.988 .56686 Mdot
.988 .56691 Mdot
.988 .56745 Mdot
.988 .56792 Mdot
.988 .56809 Mdot
.988 .5682 Mdot
.988 .5682 Mdot
.988 .56835 Mdot
.988 .56842 Mdot
.988 .56863 Mdot
.988 .56897 Mdot
.988 .56912 Mdot
.988 .56923 Mdot
.988 .56926 Mdot
.988 .56932 Mdot
.988 .56941 Mdot
.988 .56961 Mdot
.988 .5698 Mdot
.988 .56994 Mdot
.988 .56995 Mdot
.988 .57105 Mdot
.988 .57108 Mdot
.988 .57132 Mdot
.988 .57176 Mdot
.988 .57193 Mdot
.988 .57202 Mdot
.988 .57208 Mdot
.988 .57208 Mdot
.988 .57209 Mdot
.988 .57212 Mdot
.988 .57227 Mdot
.988 .57229 Mdot
.988 .57245 Mdot
.988 .57282 Mdot
.988 .57301 Mdot
.988 .57313 Mdot
.988 .57338 Mdot
.988 .57359 Mdot
.988 .57371 Mdot
.988 .57375 Mdot
.988 .57401 Mdot
.988 .57448 Mdot
.988 .5747 Mdot
.988 .575 Mdot
.988 .57529 Mdot
.988 .5754 Mdot
.988 .57582 Mdot
.988 .57596 Mdot
.988 .57604 Mdot
.988 .57609 Mdot
.988 .57722 Mdot
.988 .57771 Mdot
.988 .57783 Mdot
.988 .57809 Mdot
.988 .57814 Mdot
.988 .57823 Mdot
.988 .57824 Mdot
.988 .5783 Mdot
.988 .57836 Mdot
.988 .57859 Mdot
.988 .57873 Mdot
.988 .57876 Mdot
.988 .57901 Mdot
.988 .57906 Mdot
.988 .5793 Mdot
.988 .57939 Mdot
.988 .57945 Mdot
.988 .57995 Mdot
.988 .58006 Mdot
.988 .58009 Mdot
.988 .58061 Mdot
.988 .58067 Mdot
.988 .58077 Mdot
.988 .5809 Mdot
.988 .58091 Mdot
.988 .58107 Mdot
.988 .58118 Mdot
.988 .58129 Mdot
.988 .58153 Mdot
.988 .58197 Mdot
.988 .58208 Mdot
.988 .58228 Mdot
.988 .58274 Mdot
.988 .58283 Mdot
.988 .58284 Mdot
.988 .58315 Mdot
.988 .58328 Mdot
.988 .58333 Mdot
.988 .58334 Mdot
.988 .58339 Mdot
.988 .5834 Mdot
.988 .58345 Mdot
.988 .58365 Mdot
.988 .5841 Mdot
.988 .5842 Mdot
.988 .58431 Mdot
.988 .58432 Mdot
.988 .5845 Mdot
.988 .58458 Mdot
.988 .58462 Mdot
.988 .58503 Mdot
.988 .58524 Mdot
.988 .58525 Mdot
.988 .58568 Mdot
.988 .58608 Mdot
.988 .58611 Mdot
.988 .58651 Mdot
.988 .58652 Mdot
.988 .58666 Mdot
.988 .58676 Mdot
.988 .58693 Mdot
.988 .58739 Mdot
.988 .5875 Mdot
.988 .58771 Mdot
.988 .58778 Mdot
.988 .58782 Mdot
.988 .58788 Mdot
.988 .5879 Mdot
.988 .58801 Mdot
.988 .58821 Mdot
.988 .58877 Mdot
.988 .58879 Mdot
.988 .58893 Mdot
.988 .5893 Mdot
.988 .5893 Mdot
.988 .58969 Mdot
.988 .58971 Mdot
.988 .58973 Mdot
.988 .58977 Mdot
.988 .58995 Mdot
.988 .59028 Mdot
.988 .59052 Mdot
.988 .59077 Mdot
.988 .59081 Mdot
.988 .59084 Mdot
.988 .59098 Mdot
.988 .5912 Mdot
.988 .5912 Mdot
.988 .59121 Mdot
.988 .59147 Mdot
.988 .59159 Mdot
.988 .59175 Mdot
.988 .59177 Mdot
.988 .59181 Mdot
.988 .59213 Mdot
.988 .59228 Mdot
.988 .59231 Mdot
.988 .59243 Mdot
.988 .59245 Mdot
.988 .59247 Mdot
.988 .59247 Mdot
.988 .59247 Mdot
.988 .59253 Mdot
.988 .5926 Mdot
.988 .59275 Mdot
.988 .59311 Mdot
.988 .59313 Mdot
.988 .59331 Mdot
.988 .59333 Mdot
.988 .59356 Mdot
.988 .59406 Mdot
.988 .59411 Mdot
.988 .59411 Mdot
.988 .5942 Mdot
.988 .59431 Mdot
.988 .59432 Mdot
.988 .59435 Mdot
.988 .59444 Mdot
.988 .59449 Mdot
.988 .59449 Mdot
.988 .59453 Mdot
.988 .59454 Mdot
.988 .59458 Mdot
.988 .59461 Mdot
.988 .59469 Mdot
.988 .59471 Mdot
.988 .59475 Mdot
.988 .59485 Mdot
.988 .59485 Mdot
.988 .59486 Mdot
.988 .59497 Mdot
.988 .59501 Mdot
.988 .59501 Mdot
.988 .59503 Mdot
.988 .59507 Mdot
.988 .59507 Mdot
.988 .59511 Mdot
.988 .59511 Mdot
.988 .59513 Mdot
.988 .5952 Mdot
.988 .59527 Mdot
.988 .59528 Mdot
.988 .5954 Mdot
.988 .59558 Mdot
.988 .59559 Mdot
.988 .59561 Mdot
.988 .59563 Mdot
.988 .59565 Mdot
.988 .59566 Mdot
.988 .59572 Mdot
.988 .59573 Mdot
.988 .59574 Mdot
.988 .59575 Mdot
.988 .59581 Mdot
.988 .59581 Mdot
.988 .59585 Mdot
.988 .59585 Mdot
.988 .59587 Mdot
.988 .59591 Mdot
.988 .59599 Mdot
.988 .59601 Mdot
.988 .59603 Mdot
.988 .59605 Mdot
.988 .59605 Mdot
.988 .59607 Mdot
.988 .59608 Mdot
.988 .59608 Mdot
.988 .59608 Mdot
.988 .59612 Mdot
.988 .59616 Mdot
.988 .59616 Mdot
.988 .59617 Mdot
.988 .59619 Mdot
.988 .59621 Mdot
.988 .59621 Mdot
.988 .59624 Mdot
.988 .59625 Mdot
.988 .59626 Mdot
.988 .59626 Mdot
.988 .59626 Mdot
.99 .13069 Mdot
.99 .13074 Mdot
.99 .13078 Mdot
.99 .13078 Mdot
.99 .1308 Mdot
.99 .13081 Mdot
.99 .13081 Mdot
.99 .13082 Mdot
.99 .13088 Mdot
.99 .13095 Mdot
.99 .13145 Mdot
.99 .13154 Mdot
.99 .13199 Mdot
.99 .1325 Mdot
.99 .13296 Mdot
.99 .13303 Mdot
.99 .13389 Mdot
.99 .13434 Mdot
.99 .1345 Mdot
.99 .13487 Mdot
.99 .13608 Mdot
.99 .13702 Mdot
.99 .13754 Mdot
.99 .13898 Mdot
.99 .13916 Mdot
.99 .13921 Mdot
.99 .13927 Mdot
.99 .13941 Mdot
.99 .14028 Mdot
.99 .14039 Mdot
.99 .14039 Mdot
.99 .14145 Mdot
.99 .14313 Mdot
.99 .14317 Mdot
.99 .14391 Mdot
.99 .14603 Mdot
.99 .14727 Mdot
.99 .14749 Mdot
.99 .14819 Mdot
.99 .14827 Mdot
.99 .14942 Mdot
.99 .14946 Mdot
.99 .15073 Mdot
.99 .15124 Mdot
.99 .15133 Mdot
.99 .15173 Mdot
.99 .15301 Mdot
.99 .15311 Mdot
.99 .15322 Mdot
.99 .15398 Mdot
.99 .15403 Mdot
.99 .15512 Mdot
.99 .15547 Mdot
.99 .15652 Mdot
.99 .15743 Mdot
.99 .15748 Mdot
.99 .15777 Mdot
.99 .15849 Mdot
.99 .16004 Mdot
.99 .16416 Mdot
.99 .16721 Mdot
.99 .16741 Mdot
.99 .16921 Mdot
.99 .16923 Mdot
.99 .17084 Mdot
.99 .17138 Mdot
.99 .17197 Mdot
.99 .17198 Mdot
.99 .17213 Mdot
.99 .17308 Mdot
.99 .17458 Mdot
.99 .17699 Mdot
.99 .17875 Mdot
.99 .17932 Mdot
.99 .18034 Mdot
.99 .18056 Mdot
.99 .18064 Mdot
.99 .18151 Mdot
.99 .18172 Mdot
.99 .18289 Mdot
.99 .18323 Mdot
.99 .18389 Mdot
.99 .18415 Mdot
.99 .18652 Mdot
.99 .18706 Mdot
.99 .18714 Mdot
.99 .18881 Mdot
.99 .18959 Mdot
.99 .18979 Mdot
.99 .19026 Mdot
.99 .1908 Mdot
.99 .19151 Mdot
.99 .19177 Mdot
.99 .1928 Mdot
.99 .19313 Mdot
.99 .19364 Mdot
.99 .194 Mdot
.99 .19401 Mdot
.99 .19659 Mdot
.99 .19685 Mdot
.99 .19777 Mdot
.99 .19778 Mdot
.99 .19852 Mdot
.99 .19906 Mdot
.99 .19966 Mdot
.99 .2021 Mdot
.99 .20249 Mdot
.99 .20255 Mdot
.99 .20258 Mdot
.99 .20466 Mdot
.99 .20525 Mdot
.99 .20628 Mdot
.99 .20675 Mdot
.99 .20736 Mdot
.99 .20854 Mdot
.99 .20967 Mdot
.99 .21022 Mdot
.99 .21027 Mdot
.99 .21381 Mdot
.99 .21478 Mdot
.99 .21524 Mdot
.99 .2171 Mdot
.99 .21771 Mdot
.99 .21908 Mdot
.99 .22041 Mdot
.99 .22135 Mdot
.99 .22173 Mdot
.99 .22264 Mdot
.99 .22444 Mdot
.99 .22536 Mdot
.99 .22549 Mdot
.99 .22661 Mdot
.99 .227 Mdot
.99 .22741 Mdot
.99 .2276 Mdot
.99 .2293 Mdot
.99 .23079 Mdot
.99 .23193 Mdot
.99 .23276 Mdot
.99 .23433 Mdot
.99 .23566 Mdot
.99 .23638 Mdot
.99 .23667 Mdot
.99 .23711 Mdot
.99 .23776 Mdot
.99 .23831 Mdot
.99 .23844 Mdot
.99 .2387 Mdot
.99 .23883 Mdot
.99 .23913 Mdot
.99 .23943 Mdot
.99 .24003 Mdot
.99 .24034 Mdot
.99 .24161 Mdot
.99 .24312 Mdot
.99 .24396 Mdot
.99 .24414 Mdot
.99 .24431 Mdot
.99 .2448 Mdot
.99 .24486 Mdot
.99 .24648 Mdot
.99 .24706 Mdot
.99 .24938 Mdot
.99 .24959 Mdot
.99 .25244 Mdot
.99 .25298 Mdot
.99 .25326 Mdot
.99 .25521 Mdot
.99 .25685 Mdot
.99 .25745 Mdot
.99 .2579 Mdot
.99 .25802 Mdot
.99 .25926 Mdot
.99 .26047 Mdot
.99 .2614 Mdot
.99 .26264 Mdot
.99 .26409 Mdot
.99 .26532 Mdot
.99 .26543 Mdot
.99 .26587 Mdot
.99 .26684 Mdot
.99 .26776 Mdot
.99 .27034 Mdot
.99 .27042 Mdot
.99 .27074 Mdot
.99 .27293 Mdot
.99 .27721 Mdot
.99 .27881 Mdot
.99 .27939 Mdot
.99 .28028 Mdot
.99 .2816 Mdot
.99 .28253 Mdot
.99 .28322 Mdot
.99 .28414 Mdot
.99 .28497 Mdot
.99 .28504 Mdot
.99 .28572 Mdot
.99 .28666 Mdot
.99 .28836 Mdot
.99 .28901 Mdot
.99 .29047 Mdot
.99 .29145 Mdot
.99 .29434 Mdot
.99 .29492 Mdot
.99 .29604 Mdot
.99 .29814 Mdot
.99 .29837 Mdot
.99 .30051 Mdot
.99 .30064 Mdot
.99 .3069 Mdot
.99 .30701 Mdot
.99 .3072 Mdot
.99 .30833 Mdot
.99 .31042 Mdot
.99 .31078 Mdot
.99 .31094 Mdot
.99 .31106 Mdot
.99 .3115 Mdot
.99 .31191 Mdot
.99 .3139 Mdot
.99 .31417 Mdot
.99 .31538 Mdot
.99 .31652 Mdot
.99 .31899 Mdot
.99 .32043 Mdot
.99 .32522 Mdot
.99 .3254 Mdot
.99 .32545 Mdot
.99 .32551 Mdot
.99 .32565 Mdot
.99 .32649 Mdot
.99 .3266 Mdot
.99 .32907 Mdot
.99 .33249 Mdot
.99 .33392 Mdot
.99 .33517 Mdot
.99 .33524 Mdot
.99 .33637 Mdot
.99 .33651 Mdot
.99 .33702 Mdot
.99 .33704 Mdot
.99 .33798 Mdot
.99 .33926 Mdot
.99 .33943 Mdot
.99 .33988 Mdot
.99 .34326 Mdot
.99 .345 Mdot
.99 .34611 Mdot
.99 .34612 Mdot
.99 .347 Mdot
.99 .34762 Mdot
.99 .34821 Mdot
.99 .34902 Mdot
.99 .35149 Mdot
.99 .35202 Mdot
.99 .35213 Mdot
.99 .35331 Mdot
.99 .35348 Mdot
.99 .35382 Mdot
.99 .35513 Mdot
.99 .35543 Mdot
.99 .35626 Mdot
.99 .35674 Mdot
.99 .35697 Mdot
.99 .35723 Mdot
.99 .3577 Mdot
.99 .3582 Mdot
.99 .35836 Mdot
.99 .3586 Mdot
.99 .35878 Mdot
.99 .36058 Mdot
.99 .36094 Mdot
.99 .36147 Mdot
.99 .36262 Mdot
.99 .3628 Mdot
.99 .36284 Mdot
.99 .36381 Mdot
.99 .36409 Mdot
.99 .36456 Mdot
.99 .36612 Mdot
.99 .36637 Mdot
.99 .36639 Mdot
.99 .36801 Mdot
.99 .36949 Mdot
.99 .36977 Mdot
.99 .37038 Mdot
.99 .3714 Mdot
.99 .37197 Mdot
.99 .37277 Mdot
.99 .37417 Mdot
.99 .37557 Mdot
.99 .37607 Mdot
.99 .37712 Mdot
.99 .37814 Mdot
.99 .37833 Mdot
.99 .37885 Mdot
.99 .37902 Mdot
.99 .37908 Mdot
.99 .38129 Mdot
.99 .38144 Mdot
.99 .38168 Mdot
.99 .38263 Mdot
.99 .38362 Mdot
.99 .38493 Mdot
.99 .38516 Mdot
.99 .38681 Mdot
.99 .38707 Mdot
.99 .38731 Mdot
.99 .38783 Mdot
.99 .38834 Mdot
.99 .38927 Mdot
.99 .38988 Mdot
.99 .3904 Mdot
.99 .39251 Mdot
.99 .39607 Mdot
.99 .39724 Mdot
.99 .39792 Mdot
.99 .3983 Mdot
.99 .39865 Mdot
.99 .39868 Mdot
.99 .39935 Mdot
.99 .40006 Mdot
.99 .40135 Mdot
.99 .40255 Mdot
.99 .40413 Mdot
.99 .40512 Mdot
.99 .40517 Mdot
.99 .4079 Mdot
.99 .40923 Mdot
.99 .40938 Mdot
.99 .40945 Mdot
.99 .40968 Mdot
.99 .40985 Mdot
.99 .41079 Mdot
.99 .41537 Mdot
.99 .41544 Mdot
.99 .41589 Mdot
.99 .41696 Mdot
.99 .41949 Mdot
.99 .41999 Mdot
.99 .42005 Mdot
.99 .42066 Mdot
.99 .42126 Mdot
.99 .42285 Mdot
.99 .42357 Mdot
.99 .42466 Mdot
.99 .42649 Mdot
.99 .42703 Mdot
.99 .4271 Mdot
.99 .42791 Mdot
.99 .42855 Mdot
.99 .42866 Mdot
.99 .42886 Mdot
.99 .42906 Mdot
.99 .42913 Mdot
.99 .42931 Mdot
.99 .43005 Mdot
.99 .4302 Mdot
.99 .43043 Mdot
.99 .431 Mdot
.99 .4314 Mdot
.99 .43172 Mdot
.99 .43237 Mdot
.99 .43247 Mdot
.99 .43248 Mdot
.99 .43316 Mdot
.99 .43378 Mdot
.99 .43457 Mdot
.99 .43573 Mdot
.99 .43697 Mdot
.99 .43777 Mdot
.99 .43779 Mdot
.99 .43879 Mdot
.99 .43889 Mdot
.99 .4397 Mdot
.99 .44025 Mdot
.99 .44035 Mdot
.99 .44116 Mdot
.99 .44126 Mdot
.99 .44148 Mdot
.99 .44169 Mdot
.99 .44208 Mdot
.99 .44234 Mdot
.99 .44256 Mdot
.99 .44546 Mdot
.99 .44574 Mdot
.99 .44636 Mdot
.99 .44772 Mdot
.99 .44839 Mdot
.99 .44999 Mdot
.99 .45057 Mdot
.99 .45066 Mdot
.99 .45076 Mdot
.99 .45123 Mdot
.99 .4532 Mdot
.99 .45323 Mdot
.99 .45342 Mdot
.99 .45497 Mdot
.99 .45519 Mdot
.99 .45521 Mdot
.99 .45548 Mdot
.99 .45574 Mdot
.99 .45642 Mdot
.99 .45673 Mdot
.99 .45721 Mdot
.99 .45823 Mdot
.99 .45826 Mdot
.99 .45862 Mdot
.99 .45889 Mdot
.99 .45894 Mdot
.99 .45903 Mdot
.99 .45912 Mdot
.99 .45915 Mdot
.99 .45922 Mdot
.99 .45961 Mdot
.99 .45971 Mdot
.99 .45996 Mdot
.99 .46014 Mdot
.99 .4606 Mdot
.99 .4609 Mdot
.99 .46117 Mdot
.99 .46203 Mdot
.99 .46293 Mdot
.99 .46337 Mdot
.99 .46341 Mdot
.99 .46377 Mdot
.99 .46441 Mdot
.99 .46446 Mdot
.99 .46455 Mdot
.99 .46465 Mdot
.99 .46644 Mdot
.99 .46761 Mdot
.99 .46832 Mdot
.99 .46866 Mdot
.99 .46888 Mdot
.99 .46975 Mdot
.99 .47064 Mdot
.99 .47066 Mdot
.99 .47089 Mdot
.99 .4712 Mdot
.99 .47134 Mdot
.99 .47155 Mdot
.99 .47203 Mdot
.99 .47218 Mdot
.99 .47231 Mdot
.99 .47233 Mdot
.99 .47237 Mdot
.99 .47241 Mdot
.99 .47242 Mdot
.99 .47246 Mdot
.99 .47263 Mdot
.99 .47268 Mdot
.99 .47279 Mdot
.99 .47287 Mdot
.99 .47308 Mdot
.99 .47321 Mdot
.99 .47334 Mdot
.99 .47372 Mdot
.99 .47433 Mdot
.99 .47435 Mdot
.99 .47451 Mdot
.99 .4748 Mdot
.99 .47482 Mdot
.99 .47573 Mdot
.99 .47626 Mdot
.99 .47674 Mdot
.99 .47684 Mdot
.99 .47724 Mdot
.99 .4779 Mdot
.99 .47797 Mdot
.99 .47828 Mdot
.99 .47835 Mdot
.99 .47841 Mdot
.99 .47842 Mdot
.99 .47844 Mdot
.99 .47846 Mdot
.99 .47846 Mdot
.99 .47848 Mdot
.99 .47856 Mdot
.99 .47858 Mdot
.99 .47867 Mdot
.99 .47934 Mdot
.99 .47935 Mdot
.99 .47943 Mdot
.99 .47956 Mdot
.99 .47957 Mdot
.99 .47999 Mdot
.99 .48023 Mdot
.99 .48046 Mdot
.99 .48069 Mdot
.99 .48099 Mdot
.99 .48131 Mdot
.99 .48166 Mdot
.99 .48167 Mdot
.99 .48177 Mdot
.99 .48218 Mdot
.99 .48229 Mdot
.99 .48258 Mdot
.99 .48275 Mdot
.99 .48299 Mdot
.99 .48304 Mdot
.99 .48325 Mdot
.99 .48337 Mdot
.99 .48349 Mdot
.99 .4836 Mdot
.99 .48365 Mdot
.99 .48368 Mdot
.99 .48369 Mdot
.99 .48369 Mdot
.99 .4837 Mdot
.99 .4837 Mdot
.99 .48371 Mdot
.99 .48371 Mdot
.99 .48373 Mdot
.99 .48377 Mdot
.99 .48384 Mdot
.99 .48393 Mdot
.99 .484 Mdot
.99 .48418 Mdot
.99 .48435 Mdot
.99 .48446 Mdot
.99 .48466 Mdot
.99 .48473 Mdot
.99 .48508 Mdot
.99 .48532 Mdot
.99 .48574 Mdot
.99 .4859 Mdot
.99 .48621 Mdot
.99 .48649 Mdot
.99 .48664 Mdot
.99 .48664 Mdot
.99 .48715 Mdot
.99 .48756 Mdot
.99 .4876 Mdot
.99 .48804 Mdot
.99 .4883 Mdot
.99 .48837 Mdot
.99 .48868 Mdot
.99 .48903 Mdot
.99 .48962 Mdot
.99 .48963 Mdot
.99 .48982 Mdot
.99 .48993 Mdot
.99 .48994 Mdot
.99 .49033 Mdot
.99 .49058 Mdot
.99 .49066 Mdot
.99 .49075 Mdot
.99 .49088 Mdot
.99 .49093 Mdot
.99 .491 Mdot
.99 .49103 Mdot
.99 .49115 Mdot
.99 .49117 Mdot
.99 .49118 Mdot
.99 .4912 Mdot
.99 .49123 Mdot
.99 .49124 Mdot
.99 .49132 Mdot
.99 .49142 Mdot
.99 .49186 Mdot
.99 .49195 Mdot
.99 .49215 Mdot
.99 .4923 Mdot
.99 .4923 Mdot
.99 .49287 Mdot
.99 .49342 Mdot
.99 .49355 Mdot
.99 .49376 Mdot
.99 .49421 Mdot
.99 .49494 Mdot
.99 .49604 Mdot
.99 .4961 Mdot
.99 .49616 Mdot
.99 .49619 Mdot
.99 .49658 Mdot
.99 .4968 Mdot
.99 .49683 Mdot
.99 .49709 Mdot
.99 .49764 Mdot
.99 .49816 Mdot
.99 .49832 Mdot
.99 .4985 Mdot
.99 .49878 Mdot
.99 .49888 Mdot
.99 .49903 Mdot
.99 .49909 Mdot
.99 .49932 Mdot
.99 .49937 Mdot
.99 .49939 Mdot
.99 .49944 Mdot
.99 .49949 Mdot
.99 .49952 Mdot
.99 .49969 Mdot
.99 .49989 Mdot
.99 .49991 Mdot
.99 .50052 Mdot
.99 .5008 Mdot
.99 .50098 Mdot
.99 .50138 Mdot
.99 .50153 Mdot
.99 .50169 Mdot
.99 .5017 Mdot
.99 .50183 Mdot
.99 .50273 Mdot
.99 .50284 Mdot
.99 .50286 Mdot
.99 .50399 Mdot
.99 .50426 Mdot
.99 .50431 Mdot
.99 .50437 Mdot
.99 .50469 Mdot
.99 .5056 Mdot
.99 .50598 Mdot
.99 .50674 Mdot
.99 .50707 Mdot
.99 .50723 Mdot
.99 .50883 Mdot
.99 .50895 Mdot
.99 .50909 Mdot
.99 .5093 Mdot
.99 .50942 Mdot
.99 .50954 Mdot
.99 .50959 Mdot
.99 .51003 Mdot
.99 .51008 Mdot
.99 .51038 Mdot
.99 .51082 Mdot
.99 .51087 Mdot
.99 .5114 Mdot
.99 .51141 Mdot
.99 .51184 Mdot
.99 .51249 Mdot
.99 .5131 Mdot
.99 .51352 Mdot
.99 .51385 Mdot
.99 .5142 Mdot
.99 .5142 Mdot
.99 .51426 Mdot
.99 .51459 Mdot
.99 .51476 Mdot
.99 .51496 Mdot
.99 .51526 Mdot
.99 .51537 Mdot
.99 .51545 Mdot
.99 .51583 Mdot
.99 .51592 Mdot
.99 .51596 Mdot
.99 .51606 Mdot
.99 .51616 Mdot
.99 .51622 Mdot
.99 .51654 Mdot
.99 .51696 Mdot
.99 .51699 Mdot
.99 .51726 Mdot
.99 .51818 Mdot
.99 .51872 Mdot
.99 .51908 Mdot
.99 .51987 Mdot
.99 .52016 Mdot
.99 .52046 Mdot
.99 .52049 Mdot
.99 .52073 Mdot
.99 .52196 Mdot
.99 .52247 Mdot
.99 .52269 Mdot
.99 .52273 Mdot
.99 .52489 Mdot
.99 .52533 Mdot
.99 .52541 Mdot
.99 .52552 Mdot
.99 .52555 Mdot
.99 .52562 Mdot
.99 .52624 Mdot
.99 .52749 Mdot
.99 .52751 Mdot
.99 .52796 Mdot
.99 .52867 Mdot
.99 .52921 Mdot
.99 .52979 Mdot
.99 .5301 Mdot
.99 .5304 Mdot
.99 .53042 Mdot
.99 .53057 Mdot
.99 .53074 Mdot
.99 .53104 Mdot
.99 .53155 Mdot
.99 .53309 Mdot
.99 .534 Mdot
.99 .53422 Mdot
.99 .53448 Mdot
.99 .53487 Mdot
.99 .53508 Mdot
.99 .5353 Mdot
.99 .5354 Mdot
.99 .53551 Mdot
.99 .5362 Mdot
.99 .5363 Mdot
.99 .53684 Mdot
.99 .53725 Mdot
.99 .53764 Mdot
.99 .53773 Mdot
.99 .5378 Mdot
.99 .5387 Mdot
.99 .53872 Mdot
.99 .53879 Mdot
.99 .539 Mdot
.99 .53908 Mdot
.99 .53949 Mdot
.99 .53991 Mdot
.99 .54011 Mdot
.99 .54066 Mdot
.99 .54121 Mdot
.99 .54153 Mdot
.99 .54175 Mdot
.99 .54215 Mdot
.99 .54239 Mdot
.99 .54249 Mdot
.99 .54307 Mdot
.99 .54369 Mdot
.99 .54369 Mdot
.99 .54379 Mdot
.99 .54438 Mdot
.99 .54456 Mdot
.99 .54467 Mdot
.99 .54503 Mdot
.99 .54505 Mdot
.99 .54512 Mdot
.99 .54555 Mdot
.99 .54575 Mdot
.99 .54588 Mdot
.99 .54655 Mdot
.99 .54661 Mdot
.99 .5467 Mdot
.99 .54676 Mdot
.99 .54694 Mdot
.99 .54712 Mdot
.99 .54721 Mdot
.99 .5473 Mdot
.99 .54747 Mdot
.99 .54777 Mdot
.99 .54789 Mdot
.99 .54836 Mdot
.99 .54848 Mdot
.99 .54854 Mdot
.99 .54897 Mdot
.99 .54901 Mdot
.99 .5492 Mdot
.99 .55008 Mdot
.99 .55036 Mdot
.99 .55057 Mdot
.99 .55079 Mdot
.99 .5511 Mdot
.99 .5511 Mdot
.99 .55149 Mdot
.99 .55209 Mdot
.99 .55324 Mdot
.99 .5534 Mdot
.99 .55346 Mdot
.99 .55389 Mdot
.99 .5542 Mdot
.99 .55421 Mdot
.99 .55438 Mdot
.99 .55443 Mdot
.99 .55481 Mdot
.99 .55483 Mdot
.99 .55524 Mdot
.99 .55571 Mdot
.99 .55683 Mdot
.99 .55762 Mdot
.99 .55766 Mdot
.99 .55793 Mdot
.99 .55797 Mdot
.99 .55799 Mdot
.99 .55801 Mdot
.99 .55806 Mdot
.99 .55957 Mdot
.99 .56002 Mdot
.99 .56078 Mdot
.99 .56113 Mdot
.99 .56149 Mdot
.99 .56157 Mdot
.99 .56217 Mdot
.99 .5623 Mdot
.99 .56243 Mdot
.99 .56246 Mdot
.99 .56251 Mdot
.99 .56262 Mdot
.99 .56323 Mdot
.99 .56357 Mdot
.99 .56362 Mdot
.99 .56366 Mdot
.99 .56546 Mdot
.99 .5655 Mdot
.99 .5661 Mdot
.99 .56617 Mdot
.99 .56676 Mdot
.99 .56707 Mdot
.99 .56723 Mdot
.99 .56802 Mdot
.99 .56829 Mdot
.99 .56868 Mdot
.99 .56886 Mdot
.99 .56931 Mdot
.99 .56956 Mdot
.99 .56974 Mdot
.99 .56976 Mdot
.99 .56998 Mdot
.99 .57022 Mdot
.99 .5704 Mdot
.99 .57064 Mdot
.99 .57098 Mdot
.99 .57122 Mdot
.99 .57136 Mdot
.99 .57177 Mdot
.99 .57285 Mdot
.99 .5734 Mdot
.99 .57348 Mdot
.99 .5735 Mdot
.99 .57413 Mdot
.99 .57435 Mdot
.99 .57459 Mdot
.99 .57469 Mdot
.99 .57472 Mdot
.99 .57501 Mdot
.99 .57536 Mdot
.99 .57565 Mdot
.99 .57587 Mdot
.99 .57616 Mdot
.99 .57644 Mdot
.99 .57647 Mdot
.99 .57657 Mdot
.99 .57672 Mdot
.99 .57709 Mdot
.99 .57754 Mdot
.99 .5776 Mdot
.99 .57772 Mdot
.99 .57836 Mdot
.99 .57841 Mdot
.99 .57892 Mdot
.99 .57905 Mdot
.99 .5794 Mdot
.99 .57941 Mdot
.99 .57952 Mdot
.99 .57956 Mdot
.99 .57959 Mdot
.99 .57977 Mdot
.99 .5801 Mdot
.99 .58037 Mdot
.99 .58044 Mdot
.99 .58056 Mdot
.99 .58062 Mdot
.99 .58069 Mdot
.99 .58071 Mdot
.99 .58077 Mdot
.99 .5808 Mdot
.99 .58091 Mdot
.99 .58105 Mdot
.99 .58114 Mdot
.99 .5812 Mdot
.99 .58135 Mdot
.99 .58162 Mdot
.99 .58195 Mdot
.99 .58211 Mdot
.99 .58235 Mdot
.99 .58264 Mdot
.99 .58298 Mdot
.99 .58302 Mdot
.99 .5831 Mdot
.99 .58318 Mdot
.99 .5834 Mdot
.99 .58342 Mdot
.99 .5836 Mdot
.99 .58395 Mdot
.99 .58413 Mdot
.99 .5842 Mdot
.99 .58438 Mdot
.99 .58463 Mdot
.99 .58489 Mdot
.99 .585 Mdot
.99 .58535 Mdot
.99 .58544 Mdot
.99 .58561 Mdot
.99 .58626 Mdot
.99 .58627 Mdot
.99 .58637 Mdot
.99 .58657 Mdot
.99 .58678 Mdot
.99 .58688 Mdot
.99 .58697 Mdot
.99 .58715 Mdot
.99 .58725 Mdot
.99 .58761 Mdot
.99 .58762 Mdot
.99 .58763 Mdot
.99 .58769 Mdot
.99 .58811 Mdot
.99 .58821 Mdot
.99 .5883 Mdot
.99 .58842 Mdot
.99 .58843 Mdot
.99 .58858 Mdot
.99 .58862 Mdot
.99 .58905 Mdot
.99 .58905 Mdot
.99 .58911 Mdot
.99 .58919 Mdot
.99 .58924 Mdot
.99 .58941 Mdot
.99 .58945 Mdot
.99 .58957 Mdot
.99 .58965 Mdot
.99 .58973 Mdot
.99 .58976 Mdot
.99 .58988 Mdot
.99 .59015 Mdot
.99 .59016 Mdot
.99 .59024 Mdot
.99 .59061 Mdot
.99 .59065 Mdot
.99 .59075 Mdot
.99 .5908 Mdot
.99 .59098 Mdot
.99 .59101 Mdot
.99 .59114 Mdot
.99 .59115 Mdot
.99 .59119 Mdot
.99 .59134 Mdot
.99 .59142 Mdot
.99 .59168 Mdot
.99 .59203 Mdot
.99 .59225 Mdot
.99 .59238 Mdot
.99 .5924 Mdot
.99 .59241 Mdot
.99 .59249 Mdot
.99 .59257 Mdot
.99 .59279 Mdot
.99 .59279 Mdot
.99 .59304 Mdot
.99 .59307 Mdot
.99 .59348 Mdot
.99 .59403 Mdot
.99 .59423 Mdot
.99 .59432 Mdot
.99 .59436 Mdot
.99 .59436 Mdot
.99 .59448 Mdot
.99 .59461 Mdot
.99 .59465 Mdot
.99 .59479 Mdot
.99 .5948 Mdot
.99 .59489 Mdot
.99 .5949 Mdot
.99 .59492 Mdot
.99 .59507 Mdot
.99 .59512 Mdot
.99 .59513 Mdot
.99 .5952 Mdot
.99 .59535 Mdot
.99 .59535 Mdot
.99 .59549 Mdot
.99 .5955 Mdot
.99 .59558 Mdot
.99 .59561 Mdot
.99 .59576 Mdot
.99 .596 Mdot
.99 .59609 Mdot
.99 .59609 Mdot
.99 .59628 Mdot
.99 .5964 Mdot
.99 .5964 Mdot
.99 .59641 Mdot
.99 .59651 Mdot
.99 .59652 Mdot
.99 .59653 Mdot
.99 .59654 Mdot
.99 .59656 Mdot
.99 .59671 Mdot
.99 .59677 Mdot
.99 .59687 Mdot
.99 .597 Mdot
.99 .59704 Mdot
.99 .59706 Mdot
.99 .5971 Mdot
.99 .5972 Mdot
.99 .5972 Mdot
.99 .59725 Mdot
.99 .5973 Mdot
.99 .59735 Mdot
.99 .59736 Mdot
.99 .59741 Mdot
.99 .59742 Mdot
.99 .59742 Mdot
.99 .59742 Mdot
.99 .59743 Mdot
.99 .59743 Mdot
.99 .59743 Mdot
.99 .59743 Mdot
.99 .59743 Mdot
.99 .59744 Mdot
.992 .11882 Mdot
.992 .11882 Mdot
.992 .11916 Mdot
.992 .11926 Mdot
.992 .11943 Mdot
.992 .12009 Mdot
.992 .12118 Mdot
.992 .1212 Mdot
.992 .1216 Mdot
.992 .12169 Mdot
.992 .122 Mdot
.992 .12213 Mdot
.992 .12216 Mdot
.992 .1228 Mdot
.992 .12284 Mdot
.992 .12296 Mdot
.992 .12339 Mdot
.992 .12453 Mdot
.992 .1254 Mdot
.992 .12542 Mdot
.992 .1258 Mdot
.992 .12619 Mdot
.992 .12723 Mdot
.992 .12737 Mdot
.992 .12743 Mdot
.992 .1312 Mdot
.992 .13314 Mdot
.992 .13338 Mdot
.992 .13356 Mdot
.992 .13357 Mdot
.992 .1337 Mdot
.992 .13389 Mdot
.992 .13447 Mdot
.992 .1352 Mdot
.992 .13534 Mdot
.992 .13577 Mdot
.992 .1365 Mdot
.992 .13694 Mdot
.992 .13845 Mdot
.992 .13852 Mdot
.992 .13909 Mdot
.992 .13921 Mdot
.992 .14312 Mdot
.992 .14353 Mdot
.992 .14426 Mdot
.992 .14438 Mdot
.992 .145 Mdot
.992 .14558 Mdot
.992 .147 Mdot
.992 .14749 Mdot
.992 .14761 Mdot
.992 .14795 Mdot
.992 .148 Mdot
.992 .1505 Mdot
.992 .15222 Mdot
.992 .15224 Mdot
.992 .1528 Mdot
.992 .15294 Mdot
.992 .15357 Mdot
.992 .15383 Mdot
.992 .15471 Mdot
.992 .15814 Mdot
.992 .15824 Mdot
.992 .15876 Mdot
.992 .15883 Mdot
.992 .1609 Mdot
.992 .16174 Mdot
.992 .16295 Mdot
.992 .16494 Mdot
.992 .1673 Mdot
.992 .17224 Mdot
.992 .17298 Mdot
.992 .17604 Mdot
.992 .17694 Mdot
.992 .17808 Mdot
.992 .17907 Mdot
.992 .17915 Mdot
.992 .17935 Mdot
.992 .17946 Mdot
.992 .17977 Mdot
.992 .18041 Mdot
.992 .18163 Mdot
.992 .18181 Mdot
.992 .18219 Mdot
.992 .18286 Mdot
.992 .1832 Mdot
.992 .18321 Mdot
.992 .18442 Mdot
.992 .1864 Mdot
.992 .18664 Mdot
.992 .18664 Mdot
.992 .1879 Mdot
.992 .18921 Mdot
.992 .18933 Mdot
.992 .18934 Mdot
.992 .19215 Mdot
.992 .19299 Mdot
.992 .19343 Mdot
.992 .19344 Mdot
.992 .19432 Mdot
.992 .19472 Mdot
.992 .19658 Mdot
.992 .19694 Mdot
.992 .19868 Mdot
.992 .1988 Mdot
.992 .19939 Mdot
.992 .19966 Mdot
.992 .20041 Mdot
.992 .20222 Mdot
.992 .20255 Mdot
.992 .20294 Mdot
.992 .20378 Mdot
.992 .20416 Mdot
.992 .20564 Mdot
.992 .20673 Mdot
.992 .20753 Mdot
.992 .20866 Mdot
.992 .21169 Mdot
.992 .21239 Mdot
.992 .21247 Mdot
.992 .2127 Mdot
.992 .21364 Mdot
.992 .21438 Mdot
.992 .21445 Mdot
.992 .21646 Mdot
.992 .21652 Mdot
.992 .21656 Mdot
.992 .21792 Mdot
.992 .21813 Mdot
.992 .21943 Mdot
.992 .22009 Mdot
.992 .22024 Mdot
.992 .22033 Mdot
.992 .22131 Mdot
.992 .22263 Mdot
.992 .225 Mdot
.992 .22666 Mdot
.992 .22711 Mdot
.992 .2283 Mdot
.992 .22854 Mdot
.992 .22933 Mdot
.992 .22948 Mdot
.992 .23021 Mdot
.992 .23066 Mdot
.992 .23199 Mdot
.992 .23306 Mdot
.992 .23375 Mdot
.992 .23441 Mdot
.992 .23554 Mdot
.992 .23604 Mdot
.992 .23666 Mdot
.992 .23729 Mdot
.992 .23775 Mdot
.992 .23925 Mdot
.992 .24026 Mdot
.992 .24045 Mdot
.992 .24076 Mdot
.992 .24083 Mdot
.992 .24176 Mdot
.992 .24195 Mdot
.992 .24366 Mdot
.992 .24468 Mdot
.992 .24474 Mdot
.992 .24627 Mdot
.992 .24791 Mdot
.992 .24835 Mdot
.992 .24966 Mdot
.992 .2505 Mdot
.992 .25163 Mdot
.992 .25216 Mdot
.992 .25233 Mdot
.992 .2536 Mdot
.992 .25372 Mdot
.992 .25398 Mdot
.992 .25481 Mdot
.992 .25598 Mdot
.992 .25658 Mdot
.992 .25696 Mdot
.992 .25829 Mdot
.992 .25888 Mdot
.992 .25946 Mdot
.992 .25957 Mdot
.992 .26105 Mdot
.992 .26151 Mdot
.992 .26169 Mdot
.992 .26177 Mdot
.992 .26235 Mdot
.992 .26344 Mdot
.992 .2675 Mdot
.992 .27146 Mdot
.992 .27328 Mdot
.992 .27565 Mdot
.992 .27579 Mdot
.992 .27652 Mdot
.992 .27653 Mdot
.992 .27893 Mdot
.992 .27915 Mdot
.992 .27922 Mdot
.992 .27951 Mdot
.992 .28114 Mdot
.992 .28433 Mdot
.992 .28478 Mdot
.992 .28484 Mdot
.992 .28818 Mdot
.992 .28828 Mdot
.992 .28842 Mdot
.992 .2886 Mdot
.992 .29336 Mdot
.992 .29355 Mdot
.992 .29536 Mdot
.992 .29768 Mdot
.992 .29823 Mdot
.992 .29845 Mdot
.992 .30016 Mdot
.992 .30473 Mdot
.992 .30763 Mdot
.992 .3104 Mdot
.992 .31237 Mdot
.992 .31275 Mdot
.992 .31506 Mdot
.992 .31719 Mdot
.992 .31722 Mdot
.992 .31802 Mdot
.992 .31848 Mdot
.992 .31866 Mdot
.992 .31871 Mdot
.992 .31965 Mdot
.992 .32171 Mdot
.992 .32266 Mdot
.992 .32307 Mdot
.992 .32348 Mdot
.992 .32462 Mdot
.992 .32793 Mdot
.992 .32977 Mdot
.992 .33001 Mdot
.992 .33043 Mdot
.992 .33096 Mdot
.992 .33106 Mdot
.992 .33137 Mdot
.992 .33188 Mdot
.992 .33218 Mdot
.992 .33363 Mdot
.992 .3362 Mdot
.992 .33645 Mdot
.992 .33697 Mdot
.992 .33735 Mdot
.992 .3377 Mdot
.992 .33909 Mdot
.992 .34054 Mdot
.992 .34183 Mdot
.992 .3419 Mdot
.992 .34287 Mdot
.992 .3447 Mdot
.992 .34503 Mdot
.992 .34507 Mdot
.992 .34614 Mdot
.992 .3472 Mdot
.992 .3482 Mdot
.992 .34938 Mdot
.992 .35181 Mdot
.992 .35217 Mdot
.992 .35363 Mdot
.992 .35406 Mdot
.992 .35506 Mdot
.992 .3551 Mdot
.992 .3552 Mdot
.992 .35525 Mdot
.992 .35539 Mdot
.992 .35683 Mdot
.992 .357 Mdot
.992 .35756 Mdot
.992 .35858 Mdot
.992 .3598 Mdot
.992 .35981 Mdot
.992 .36166 Mdot
.992 .36166 Mdot
.992 .36224 Mdot
.992 .36307 Mdot
.992 .364 Mdot
.992 .36477 Mdot
.992 .36556 Mdot
.992 .36625 Mdot
.992 .36706 Mdot
.992 .36789 Mdot
.992 .36999 Mdot
.992 .37003 Mdot
.992 .37053 Mdot
.992 .37085 Mdot
.992 .37088 Mdot
.992 .37175 Mdot
.992 .37179 Mdot
.992 .37237 Mdot
.992 .37246 Mdot
.992 .37302 Mdot
.992 .3734 Mdot
.992 .37382 Mdot
.992 .37539 Mdot
.992 .37678 Mdot
.992 .37688 Mdot
.992 .37834 Mdot
.992 .37907 Mdot
.992 .37935 Mdot
.992 .37982 Mdot
.992 .38003 Mdot
.992 .38056 Mdot
.992 .3818 Mdot
.992 .38188 Mdot
.992 .38203 Mdot
.992 .38242 Mdot
.992 .38321 Mdot
.992 .38366 Mdot
.992 .38516 Mdot
.992 .3857 Mdot
.992 .38651 Mdot
.992 .38673 Mdot
.992 .3868 Mdot
.992 .38733 Mdot
.992 .38749 Mdot
.992 .38831 Mdot
.992 .38926 Mdot
.992 .38979 Mdot
.992 .39039 Mdot
.992 .39059 Mdot
.992 .39066 Mdot
.992 .39069 Mdot
.992 .39466 Mdot
.992 .39637 Mdot
.992 .39643 Mdot
.992 .39673 Mdot
.992 .39783 Mdot
.992 .4001 Mdot
.992 .40165 Mdot
.992 .4082 Mdot
.992 .41146 Mdot
.992 .41327 Mdot
.992 .41328 Mdot
.992 .4136 Mdot
.992 .41379 Mdot
.992 .41386 Mdot
.992 .41566 Mdot
.992 .41628 Mdot
.992 .41848 Mdot
.992 .41886 Mdot
.992 .4189 Mdot
.992 .41903 Mdot
.992 .41995 Mdot
.992 .421 Mdot
.992 .42131 Mdot
.992 .42161 Mdot
.992 .42217 Mdot
.992 .42277 Mdot
.992 .42329 Mdot
.992 .42446 Mdot
.992 .42548 Mdot
.992 .42637 Mdot
.992 .42737 Mdot
.992 .42751 Mdot
.992 .42811 Mdot
.992 .42829 Mdot
.992 .42875 Mdot
.992 .42877 Mdot
.992 .42942 Mdot
.992 .42949 Mdot
.992 .42972 Mdot
.992 .43064 Mdot
.992 .43064 Mdot
.992 .43198 Mdot
.992 .43236 Mdot
.992 .43268 Mdot
.992 .43301 Mdot
.992 .43329 Mdot
.992 .43396 Mdot
.992 .43505 Mdot
.992 .4352 Mdot
.992 .43555 Mdot
.992 .43557 Mdot
.992 .43581 Mdot
.992 .43607 Mdot
.992 .43705 Mdot
.992 .43767 Mdot
.992 .43919 Mdot
.992 .43971 Mdot
.992 .43974 Mdot
.992 .4398 Mdot
.992 .44029 Mdot
.992 .44048 Mdot
.992 .44132 Mdot
.992 .44166 Mdot
.992 .44175 Mdot
.992 .44178 Mdot
.992 .44207 Mdot
.992 .44241 Mdot
.992 .4428 Mdot
.992 .44302 Mdot
.992 .44328 Mdot
.992 .44336 Mdot
.992 .44339 Mdot
.992 .4434 Mdot
.992 .44577 Mdot
.992 .44592 Mdot
.992 .44638 Mdot
.992 .44733 Mdot
.992 .44798 Mdot
.992 .45212 Mdot
.992 .45288 Mdot
.992 .45288 Mdot
.992 .45302 Mdot
.992 .45313 Mdot
.992 .45389 Mdot
.992 .45416 Mdot
.992 .45525 Mdot
.992 .45527 Mdot
.992 .45533 Mdot
.992 .45572 Mdot
.992 .45616 Mdot
.992 .45642 Mdot
.992 .45666 Mdot
.992 .45692 Mdot
.992 .45764 Mdot
.992 .45808 Mdot
.992 .45846 Mdot
.992 .45889 Mdot
.992 .45895 Mdot
.992 .45948 Mdot
.992 .45949 Mdot
.992 .45977 Mdot
.992 .46029 Mdot
.992 .46029 Mdot
.992 .46087 Mdot
.992 .46104 Mdot
.992 .46117 Mdot
.992 .46131 Mdot
.992 .46143 Mdot
.992 .46173 Mdot
.992 .4622 Mdot
.992 .46226 Mdot
.992 .46241 Mdot
.992 .46242 Mdot
.992 .46252 Mdot
.992 .46264 Mdot
.992 .46306 Mdot
.992 .46399 Mdot
.992 .46423 Mdot
.992 .46425 Mdot
.992 .46455 Mdot
.992 .46492 Mdot
.992 .46506 Mdot
.992 .46512 Mdot
.992 .46539 Mdot
.992 .46556 Mdot
.992 .46566 Mdot
.992 .46577 Mdot
.992 .46582 Mdot
.992 .46686 Mdot
.992 .46692 Mdot
.992 .46712 Mdot
.992 .46783 Mdot
.992 .46964 Mdot
.992 .46998 Mdot
.992 .46998 Mdot
.992 .47103 Mdot
.992 .47106 Mdot
.992 .47124 Mdot
.992 .47143 Mdot
.992 .47155 Mdot
.992 .47166 Mdot
.992 .47177 Mdot
.992 .47209 Mdot
.992 .47228 Mdot
.992 .47264 Mdot
.992 .47291 Mdot
.992 .47291 Mdot
.992 .47391 Mdot
.992 .47412 Mdot
.992 .47415 Mdot
.992 .47422 Mdot
.992 .47427 Mdot
.992 .47432 Mdot
.992 .47517 Mdot
.992 .47543 Mdot
.992 .47555 Mdot
.992 .47567 Mdot
.992 .47762 Mdot
.992 .47762 Mdot
.992 .47819 Mdot
.992 .47828 Mdot
.992 .47833 Mdot
.992 .47843 Mdot
.992 .47858 Mdot
.992 .47895 Mdot
.992 .47957 Mdot
.992 .47998 Mdot
.992 .4801 Mdot
.992 .48016 Mdot
.992 .48021 Mdot
.992 .4811 Mdot
.992 .48136 Mdot
.992 .48141 Mdot
.992 .48143 Mdot
.992 .48148 Mdot
.992 .48171 Mdot
.992 .482 Mdot
.992 .48224 Mdot
.992 .48229 Mdot
.992 .48282 Mdot
.992 .48286 Mdot
.992 .48288 Mdot
.992 .48299 Mdot
.992 .48312 Mdot
.992 .48323 Mdot
.992 .48325 Mdot
.992 .4835 Mdot
.992 .48351 Mdot
.992 .48364 Mdot
.992 .4837 Mdot
.992 .48388 Mdot
.992 .48399 Mdot
.992 .48422 Mdot
.992 .48439 Mdot
.992 .48465 Mdot
.992 .48474 Mdot
.992 .48483 Mdot
.992 .48492 Mdot
.992 .48494 Mdot
.992 .4853 Mdot
.992 .48533 Mdot
.992 .48549 Mdot
.992 .48568 Mdot
.992 .48584 Mdot
.992 .48588 Mdot
.992 .48589 Mdot
.992 .48592 Mdot
.992 .48609 Mdot
.992 .48669 Mdot
.992 .48673 Mdot
.992 .48676 Mdot
.992 .48712 Mdot
.992 .48752 Mdot
.992 .48777 Mdot
.992 .48787 Mdot
.992 .48793 Mdot
.992 .48797 Mdot
.992 .48803 Mdot
.992 .4884 Mdot
.992 .4884 Mdot
.992 .48967 Mdot
.992 .48975 Mdot
.992 .48983 Mdot
.992 .48999 Mdot
.992 .49055 Mdot
.992 .49058 Mdot
.992 .49065 Mdot
.992 .49145 Mdot
.992 .49145 Mdot
.992 .49162 Mdot
.992 .49197 Mdot
.992 .49217 Mdot
.992 .49231 Mdot
.992 .49239 Mdot
.992 .49251 Mdot
.992 .4933 Mdot
.992 .4933 Mdot
.992 .49598 Mdot
.992 .49615 Mdot
.992 .49631 Mdot
.992 .49666 Mdot
.992 .497 Mdot
.992 .49756 Mdot
.992 .49782 Mdot
.992 .49789 Mdot
.992 .49795 Mdot
.992 .49805 Mdot
.992 .49808 Mdot
.992 .49837 Mdot
.992 .49854 Mdot
.992 .4987 Mdot
.992 .49953 Mdot
.992 .4997 Mdot
.992 .4997 Mdot
.992 .50006 Mdot
.992 .50031 Mdot
.992 .50053 Mdot
.992 .50079 Mdot
.992 .50121 Mdot
.992 .50136 Mdot
.992 .5015 Mdot
.992 .50165 Mdot
.992 .50191 Mdot
.992 .50214 Mdot
.992 .50217 Mdot
.992 .50218 Mdot
.992 .50281 Mdot
.992 .50297 Mdot
.992 .5034 Mdot
.992 .50347 Mdot
.992 .50355 Mdot
.992 .50355 Mdot
.992 .50398 Mdot
.992 .50631 Mdot
.992 .50668 Mdot
.992 .5072 Mdot
.992 .50746 Mdot
.992 .50754 Mdot
.992 .50884 Mdot
.992 .50885 Mdot
.992 .50887 Mdot
.992 .50891 Mdot
.992 .50905 Mdot
.992 .50917 Mdot
.992 .50938 Mdot
.992 .50957 Mdot
.992 .50972 Mdot
.992 .50974 Mdot
.992 .50978 Mdot
.992 .50997 Mdot
.992 .51042 Mdot
.992 .51052 Mdot
.992 .51078 Mdot
.992 .51082 Mdot
.992 .51084 Mdot
.992 .51111 Mdot
.992 .51192 Mdot
.992 .51225 Mdot
.992 .51276 Mdot
.992 .5129 Mdot
.992 .51303 Mdot
.992 .51304 Mdot
.992 .51322 Mdot
.992 .5133 Mdot
.992 .51387 Mdot
.992 .51422 Mdot
.992 .51436 Mdot
.992 .51453 Mdot
.992 .51469 Mdot
.992 .51489 Mdot
.992 .51558 Mdot
.992 .51558 Mdot
.992 .51605 Mdot
.992 .51617 Mdot
.992 .5162 Mdot
.992 .51653 Mdot
.992 .51654 Mdot
.992 .51678 Mdot
.992 .51686 Mdot
.992 .51717 Mdot
.992 .51724 Mdot
.992 .51774 Mdot
.992 .51819 Mdot
.992 .51869 Mdot
.992 .51927 Mdot
.992 .51953 Mdot
.992 .51982 Mdot
.992 .5201 Mdot
.992 .52025 Mdot
.992 .5204 Mdot
.992 .52091 Mdot
.992 .52135 Mdot
.992 .52142 Mdot
.992 .52144 Mdot
.992 .52162 Mdot
.992 .52267 Mdot
.992 .52297 Mdot
.992 .52382 Mdot
.992 .52386 Mdot
.992 .52395 Mdot
.992 .5241 Mdot
.992 .5241 Mdot
.992 .52495 Mdot
.992 .52646 Mdot
.992 .52943 Mdot
.992 .53012 Mdot
.992 .53112 Mdot
.992 .5316 Mdot
.992 .53173 Mdot
.992 .53175 Mdot
.992 .53249 Mdot
.992 .53419 Mdot
.992 .53421 Mdot
.992 .53424 Mdot
.992 .53432 Mdot
.992 .53458 Mdot
.992 .5348 Mdot
.992 .5352 Mdot
.992 .53554 Mdot
.992 .53561 Mdot
.992 .53583 Mdot
.992 .53586 Mdot
.992 .53595 Mdot
.992 .53629 Mdot
.992 .53651 Mdot
.992 .53713 Mdot
.992 .53731 Mdot
.992 .53764 Mdot
.992 .5378 Mdot
.992 .53786 Mdot
.992 .53789 Mdot
.992 .5384 Mdot
.992 .53861 Mdot
.992 .53869 Mdot
.992 .53888 Mdot
.992 .539 Mdot
.992 .53929 Mdot
.992 .53987 Mdot
.992 .53991 Mdot
.992 .54047 Mdot
.992 .54109 Mdot
.992 .54125 Mdot
.992 .5414 Mdot
.992 .54162 Mdot
.992 .54165 Mdot
.992 .54188 Mdot
.992 .5419 Mdot
.992 .54223 Mdot
.992 .54224 Mdot
.992 .54237 Mdot
.992 .54256 Mdot
.992 .54258 Mdot
.992 .54339 Mdot
.992 .5437 Mdot
.992 .54401 Mdot
.992 .54427 Mdot
.992 .54457 Mdot
.992 .54486 Mdot
.992 .54521 Mdot
.992 .54552 Mdot
.992 .54574 Mdot
.992 .54574 Mdot
.992 .54642 Mdot
.992 .54643 Mdot
.992 .54688 Mdot
.992 .54725 Mdot
.992 .54746 Mdot
.992 .54752 Mdot
.992 .54804 Mdot
.992 .54809 Mdot
.992 .54811 Mdot
.992 .54814 Mdot
.992 .54816 Mdot
.992 .54852 Mdot
.992 .54867 Mdot
.992 .5492 Mdot
.992 .54933 Mdot
.992 .55019 Mdot
.992 .5506 Mdot
.992 .55095 Mdot
.992 .55132 Mdot
.992 .55169 Mdot
.992 .55171 Mdot
.992 .55182 Mdot
.992 .55245 Mdot
.992 .55278 Mdot
.992 .55281 Mdot
.992 .55324 Mdot
.992 .55373 Mdot
.992 .5542 Mdot
.992 .55432 Mdot
.992 .55444 Mdot
.992 .55462 Mdot
.992 .5547 Mdot
.992 .55555 Mdot
.992 .55602 Mdot
.992 .55612 Mdot
.992 .55629 Mdot
.992 .55639 Mdot
.992 .55642 Mdot
.992 .55659 Mdot
.992 .55673 Mdot
.992 .55681 Mdot
.992 .5574 Mdot
.992 .55845 Mdot
.992 .55881 Mdot
.992 .55894 Mdot
.992 .55907 Mdot
.992 .55937 Mdot
.992 .56 Mdot
.992 .56029 Mdot
.992 .56031 Mdot
.992 .56036 Mdot
.992 .56051 Mdot
.992 .56075 Mdot
.992 .56076 Mdot
.992 .56141 Mdot
.992 .5621 Mdot
.992 .56221 Mdot
.992 .5628 Mdot
.992 .56361 Mdot
.992 .56446 Mdot
.992 .56576 Mdot
.992 .56624 Mdot
.992 .5663 Mdot
.992 .56646 Mdot
.992 .5671 Mdot
.992 .5676 Mdot
.992 .56765 Mdot
.992 .56894 Mdot
.992 .56899 Mdot
.992 .56903 Mdot
.992 .56905 Mdot
.992 .56994 Mdot
.992 .56995 Mdot
.992 .57007 Mdot
.992 .5709 Mdot
.992 .57132 Mdot
.992 .5714 Mdot
.992 .57141 Mdot
.992 .57147 Mdot
.992 .57208 Mdot
.992 .57208 Mdot
.992 .57227 Mdot
.992 .5723 Mdot
.992 .5729 Mdot
.992 .57335 Mdot
.992 .57432 Mdot
.992 .57529 Mdot
.992 .57555 Mdot
.992 .57568 Mdot
.992 .5757 Mdot
.992 .57574 Mdot
.992 .57585 Mdot
.992 .5762 Mdot
.992 .57622 Mdot
.992 .57636 Mdot
.992 .5765 Mdot
.992 .5768 Mdot
.992 .57689 Mdot
.992 .57703 Mdot
.992 .57729 Mdot
.992 .57748 Mdot
.992 .57754 Mdot
.992 .57757 Mdot
.992 .57785 Mdot
.992 .57789 Mdot
.992 .57801 Mdot
.992 .57826 Mdot
.992 .57845 Mdot
.992 .57874 Mdot
.992 .57883 Mdot
.992 .57919 Mdot
.992 .57953 Mdot
.992 .57954 Mdot
.992 .57976 Mdot
.992 .58012 Mdot
.992 .58016 Mdot
.992 .58036 Mdot
.992 .58038 Mdot
.992 .58044 Mdot
.992 .58048 Mdot
.992 .58069 Mdot
.992 .58101 Mdot
.992 .5811 Mdot
.992 .58123 Mdot
.992 .58136 Mdot
.992 .58147 Mdot
.992 .5817 Mdot
.992 .58183 Mdot
.992 .58197 Mdot
.992 .58219 Mdot
.992 .58246 Mdot
.992 .58255 Mdot
.992 .58269 Mdot
.992 .58272 Mdot
.992 .58288 Mdot
.992 .58293 Mdot
.992 .58316 Mdot
.992 .58325 Mdot
.992 .58358 Mdot
.992 .58403 Mdot
.992 .58429 Mdot
.992 .58447 Mdot
.992 .58449 Mdot
.992 .58452 Mdot
.992 .58464 Mdot
.992 .58489 Mdot
.992 .58493 Mdot
.992 .58518 Mdot
.992 .58519 Mdot
.992 .5852 Mdot
.992 .58557 Mdot
.992 .58558 Mdot
.992 .58572 Mdot
.992 .58589 Mdot
.992 .58593 Mdot
.992 .58595 Mdot
.992 .58607 Mdot
.992 .58662 Mdot
.992 .58682 Mdot
.992 .58696 Mdot
.992 .58715 Mdot
.992 .5874 Mdot
.992 .58747 Mdot
.992 .58761 Mdot
.992 .58768 Mdot
.992 .58774 Mdot
.992 .58805 Mdot
.992 .58817 Mdot
.992 .58822 Mdot
.992 .58832 Mdot
.992 .58834 Mdot
.992 .58863 Mdot
.992 .58869 Mdot
.992 .58899 Mdot
.992 .58906 Mdot
.992 .5892 Mdot
.992 .5892 Mdot
.992 .58927 Mdot
.992 .58941 Mdot
.992 .58986 Mdot
.992 .58986 Mdot
.992 .58988 Mdot
.992 .59008 Mdot
.992 .59028 Mdot
.992 .59028 Mdot
.992 .59032 Mdot
.992 .59062 Mdot
.992 .5908 Mdot
.992 .59081 Mdot
.992 .59086 Mdot
.992 .59096 Mdot
.992 .59102 Mdot
.992 .59104 Mdot
.992 .59123 Mdot
.992 .59132 Mdot
.992 .59137 Mdot
.992 .59138 Mdot
.992 .59141 Mdot
.992 .59143 Mdot
.992 .59157 Mdot
.992 .59174 Mdot
.992 .59187 Mdot
.992 .59231 Mdot
.992 .59241 Mdot
.992 .5931 Mdot
.992 .59342 Mdot
.992 .59368 Mdot
.992 .59384 Mdot
.992 .59395 Mdot
.992 .59422 Mdot
.992 .59423 Mdot
.992 .5943 Mdot
.992 .59431 Mdot
.992 .59474 Mdot
.992 .59485 Mdot
.992 .59488 Mdot
.992 .59496 Mdot
.992 .59498 Mdot
.992 .59505 Mdot
.992 .59505 Mdot
.992 .59526 Mdot
.992 .59556 Mdot
.992 .59556 Mdot
.992 .5956 Mdot
.992 .59561 Mdot
.992 .59567 Mdot
.992 .59584 Mdot
.992 .5959 Mdot
.992 .59598 Mdot
.992 .59599 Mdot
.992 .59607 Mdot
.992 .59612 Mdot
.992 .59656 Mdot
.992 .59657 Mdot
.992 .59663 Mdot
.992 .59664 Mdot
.992 .59681 Mdot
.992 .59685 Mdot
.992 .59693 Mdot
.992 .59698 Mdot
.992 .59699 Mdot
.992 .59707 Mdot
.992 .59713 Mdot
.992 .59715 Mdot
.992 .59716 Mdot
.992 .59716 Mdot
.992 .59718 Mdot
.992 .59721 Mdot
.992 .59741 Mdot
.992 .59779 Mdot
.992 .5978 Mdot
.992 .59781 Mdot
.992 .59791 Mdot
.992 .59795 Mdot
.992 .59799 Mdot
.992 .59799 Mdot
.992 .59807 Mdot
.992 .59818 Mdot
.992 .59822 Mdot
.992 .59824 Mdot
.992 .59824 Mdot
.992 .5983 Mdot
.992 .5983 Mdot
.992 .59831 Mdot
.992 .59834 Mdot
.992 .59835 Mdot
.992 .59839 Mdot
.992 .59839 Mdot
.992 .59849 Mdot
.992 .59855 Mdot
.992 .59857 Mdot
.992 .59858 Mdot
.992 .59861 Mdot
.992 .59861 Mdot
.994 .10509 Mdot
.994 .10511 Mdot
.994 .10518 Mdot
.994 .10522 Mdot
.994 .10527 Mdot
.994 .10563 Mdot
.994 .10593 Mdot
.994 .1062 Mdot
.994 .10638 Mdot
.994 .10686 Mdot
.994 .10699 Mdot
.994 .10723 Mdot
.994 .1078 Mdot
.994 .10785 Mdot
.994 .10841 Mdot
.994 .1086 Mdot
.994 .10906 Mdot
.994 .10931 Mdot
.994 .10945 Mdot
.994 .10967 Mdot
.994 .10972 Mdot
.994 .10974 Mdot
.994 .11005 Mdot
.994 .11126 Mdot
.994 .11184 Mdot
.994 .11186 Mdot
.994 .11216 Mdot
.994 .11242 Mdot
.994 .11243 Mdot
.994 .11261 Mdot
.994 .11269 Mdot
.994 .1129 Mdot
.994 .11335 Mdot
.994 .114 Mdot
.994 .11436 Mdot
.994 .11451 Mdot
.994 .11518 Mdot
.994 .1154 Mdot
.994 .11569 Mdot
.994 .11596 Mdot
.994 .11609 Mdot
.994 .11628 Mdot
.994 .11636 Mdot
.994 .11728 Mdot
.994 .11804 Mdot
.994 .11919 Mdot
.994 .12004 Mdot
.994 .12241 Mdot
.994 .12244 Mdot
.994 .12253 Mdot
.994 .12271 Mdot
.994 .12314 Mdot
.994 .12338 Mdot
.994 .12429 Mdot
.994 .12493 Mdot
.994 .12635 Mdot
.994 .12957 Mdot
.994 .13103 Mdot
.994 .1315 Mdot
.994 .13152 Mdot
.994 .13161 Mdot
.994 .13336 Mdot
.994 .13364 Mdot
.994 .13366 Mdot
.994 .1338 Mdot
.994 .13576 Mdot
.994 .13642 Mdot
.994 .13742 Mdot
.994 .13877 Mdot
.994 .14119 Mdot
.994 .14264 Mdot
.994 .14273 Mdot
.994 .14467 Mdot
.994 .14586 Mdot
.994 .14879 Mdot
.994 .15014 Mdot
.994 .15021 Mdot
.994 .15059 Mdot
.994 .15146 Mdot
.994 .15299 Mdot
.994 .15391 Mdot
.994 .15553 Mdot
.994 .15741 Mdot
.994 .15842 Mdot
.994 .15924 Mdot
.994 .16044 Mdot
.994 .16053 Mdot
.994 .16182 Mdot
.994 .16191 Mdot
.994 .16362 Mdot
.994 .16369 Mdot
.994 .16484 Mdot
.994 .16508 Mdot
.994 .16617 Mdot
.994 .16694 Mdot
.994 .16819 Mdot
.994 .16854 Mdot
.994 .16999 Mdot
.994 .17367 Mdot
.994 .17493 Mdot
.994 .17532 Mdot
.994 .17806 Mdot
.994 .17842 Mdot
.994 .17858 Mdot
.994 .17903 Mdot
.994 .18044 Mdot
.994 .18139 Mdot
.994 .18315 Mdot
.994 .18549 Mdot
.994 .18799 Mdot
.994 .19095 Mdot
.994 .19463 Mdot
.994 .19779 Mdot
.994 .19843 Mdot
.994 .20025 Mdot
.994 .20054 Mdot
.994 .20173 Mdot
.994 .20275 Mdot
.994 .20363 Mdot
.994 .20425 Mdot
.994 .20661 Mdot
.994 .21035 Mdot
.994 .21068 Mdot
.994 .211 Mdot
.994 .21173 Mdot
.994 .2119 Mdot
.994 .21219 Mdot
.994 .21229 Mdot
.994 .21268 Mdot
.994 .21315 Mdot
.994 .21324 Mdot
.994 .21374 Mdot
.994 .21786 Mdot
.994 .21789 Mdot
.994 .21832 Mdot
.994 .21975 Mdot
.994 .2204 Mdot
.994 .22123 Mdot
.994 .22279 Mdot
.994 .22317 Mdot
.994 .22344 Mdot
.994 .22435 Mdot
.994 .22631 Mdot
.994 .22637 Mdot
.994 .2264 Mdot
.994 .22914 Mdot
.994 .23008 Mdot
.994 .23114 Mdot
.994 .23187 Mdot
.994 .23224 Mdot
.994 .23341 Mdot
.994 .2338 Mdot
.994 .23517 Mdot
.994 .2356 Mdot
.994 .23609 Mdot
.994 .23627 Mdot
.994 .23682 Mdot
.994 .23789 Mdot
.994 .24128 Mdot
.994 .24226 Mdot
.994 .24252 Mdot
.994 .24311 Mdot
.994 .24518 Mdot
.994 .24611 Mdot
.994 .24637 Mdot
.994 .24792 Mdot
.994 .2489 Mdot
.994 .24915 Mdot
.994 .24952 Mdot
.994 .25056 Mdot
.994 .25132 Mdot
.994 .25159 Mdot
.994 .25292 Mdot
.994 .2568 Mdot
.994 .25781 Mdot
.994 .25897 Mdot
.994 .25959 Mdot
.994 .25978 Mdot
.994 .25985 Mdot
.994 .26 Mdot
.994 .2612 Mdot
.994 .26356 Mdot
.994 .26421 Mdot
.994 .26436 Mdot
.994 .26492 Mdot
.994 .26588 Mdot
.994 .2664 Mdot
.994 .26721 Mdot
.994 .26784 Mdot
.994 .26788 Mdot
.994 .26844 Mdot
.994 .26882 Mdot
.994 .27017 Mdot
.994 .27253 Mdot
.994 .27271 Mdot
.994 .27275 Mdot
.994 .27485 Mdot
.994 .27544 Mdot
.994 .27642 Mdot
.994 .27647 Mdot
.994 .27721 Mdot
.994 .28008 Mdot
.994 .28115 Mdot
.994 .28123 Mdot
.994 .28124 Mdot
.994 .2814 Mdot
.994 .28238 Mdot
.994 .28244 Mdot
.994 .2875 Mdot
.994 .28778 Mdot
.994 .28796 Mdot
.994 .29019 Mdot
.994 .29103 Mdot
.994 .2916 Mdot
.994 .29231 Mdot
.994 .29284 Mdot
.994 .29308 Mdot
.994 .29382 Mdot
.994 .29395 Mdot
.994 .29425 Mdot
.994 .29524 Mdot
.994 .29543 Mdot
.994 .2955 Mdot
.994 .29593 Mdot
.994 .29622 Mdot
.994 .29682 Mdot
.994 .29847 Mdot
.994 .29849 Mdot
.994 .29898 Mdot
.994 .29929 Mdot
.994 .29988 Mdot
.994 .30013 Mdot
.994 .30093 Mdot
.994 .30391 Mdot
.994 .30458 Mdot
.994 .30822 Mdot
.994 .30955 Mdot
.994 .31051 Mdot
.994 .3108 Mdot
.994 .31111 Mdot
.994 .31261 Mdot
.994 .31453 Mdot
.994 .31548 Mdot
.994 .31573 Mdot
.994 .31613 Mdot
.994 .31703 Mdot
.994 .31923 Mdot
.994 .31948 Mdot
.994 .31992 Mdot
.994 .32179 Mdot
.994 .32235 Mdot
.994 .32236 Mdot
.994 .32322 Mdot
.994 .32478 Mdot
.994 .32542 Mdot
.994 .32551 Mdot
.994 .32845 Mdot
.994 .33006 Mdot
.994 .33014 Mdot
.994 .3307 Mdot
.994 .33128 Mdot
.994 .33168 Mdot
.994 .33257 Mdot
.994 .33449 Mdot
.994 .33533 Mdot
.994 .33561 Mdot
.994 .33832 Mdot
.994 .33885 Mdot
.994 .33957 Mdot
.994 .34463 Mdot
.994 .34593 Mdot
.994 .34666 Mdot
.994 .3471 Mdot
.994 .34875 Mdot
.994 .35079 Mdot
.994 .35161 Mdot
.994 .35228 Mdot
.994 .35277 Mdot
.994 .35611 Mdot
.994 .35666 Mdot
.994 .35948 Mdot
.994 .36231 Mdot
.994 .36357 Mdot
.994 .3676 Mdot
.994 .3681 Mdot
.994 .3718 Mdot
.994 .37223 Mdot
.994 .37231 Mdot
.994 .37242 Mdot
.994 .37247 Mdot
.994 .37263 Mdot
.994 .37282 Mdot
.994 .37306 Mdot
.994 .37475 Mdot
.994 .37476 Mdot
.994 .37612 Mdot
.994 .37691 Mdot
.994 .37702 Mdot
.994 .37739 Mdot
.994 .37819 Mdot
.994 .37821 Mdot
.994 .37823 Mdot
.994 .37934 Mdot
.994 .37972 Mdot
.994 .38044 Mdot
.994 .38059 Mdot
.994 .38107 Mdot
.994 .38215 Mdot
.994 .38222 Mdot
.994 .38473 Mdot
.994 .38497 Mdot
.994 .38628 Mdot
.994 .38729 Mdot
.994 .3874 Mdot
.994 .38754 Mdot
.994 .38826 Mdot
.994 .38837 Mdot
.994 .39045 Mdot
.994 .39085 Mdot
.994 .39132 Mdot
.994 .39156 Mdot
.994 .39221 Mdot
.994 .39315 Mdot
.994 .39341 Mdot
.994 .39347 Mdot
.994 .39407 Mdot
.994 .39428 Mdot
.994 .39486 Mdot
.994 .39509 Mdot
.994 .39578 Mdot
.994 .39672 Mdot
.994 .39679 Mdot
.994 .39788 Mdot
.994 .39827 Mdot
.994 .39858 Mdot
.994 .40018 Mdot
.994 .40025 Mdot
.994 .40064 Mdot
.994 .40066 Mdot
.994 .40267 Mdot
.994 .40278 Mdot
.994 .40286 Mdot
.994 .40374 Mdot
.994 .40408 Mdot
.994 .40458 Mdot
.994 .40518 Mdot
.994 .40523 Mdot
.994 .40582 Mdot
.994 .40602 Mdot
.994 .40637 Mdot
.994 .40703 Mdot
.994 .40723 Mdot
.994 .40759 Mdot
.994 .40801 Mdot
.994 .40919 Mdot
.994 .40946 Mdot
.994 .41091 Mdot
.994 .41182 Mdot
.994 .41193 Mdot
.994 .41206 Mdot
.994 .41265 Mdot
.994 .41341 Mdot
.994 .41389 Mdot
.994 .41405 Mdot
.994 .41539 Mdot
.994 .41556 Mdot
.994 .41653 Mdot
.994 .41654 Mdot
.994 .41688 Mdot
.994 .41775 Mdot
.994 .41896 Mdot
.994 .41964 Mdot
.994 .41986 Mdot
.994 .42009 Mdot
.994 .42061 Mdot
.994 .42138 Mdot
.994 .42171 Mdot
.994 .42182 Mdot
.994 .42291 Mdot
.994 .42312 Mdot
.994 .42544 Mdot
.994 .42596 Mdot
.994 .42625 Mdot
.994 .42643 Mdot
.994 .42791 Mdot
.994 .42824 Mdot
.994 .42851 Mdot
.994 .42871 Mdot
.994 .43027 Mdot
.994 .43141 Mdot
.994 .43306 Mdot
.994 .43469 Mdot
.994 .4364 Mdot
.994 .43657 Mdot
.994 .4366 Mdot
.994 .43667 Mdot
.994 .43673 Mdot
.994 .43681 Mdot
.994 .43691 Mdot
.994 .4376 Mdot
.994 .43816 Mdot
.994 .43848 Mdot
.994 .43852 Mdot
.994 .43867 Mdot
.994 .439 Mdot
.994 .43901 Mdot
.994 .43991 Mdot
.994 .44017 Mdot
.994 .44061 Mdot
.994 .44064 Mdot
.994 .44167 Mdot
.994 .44176 Mdot
.994 .4423 Mdot
.994 .44276 Mdot
.994 .44282 Mdot
.994 .44316 Mdot
.994 .44401 Mdot
.994 .44418 Mdot
.994 .44447 Mdot
.994 .44473 Mdot
.994 .44512 Mdot
.994 .44523 Mdot
.994 .44525 Mdot
.994 .4455 Mdot
.994 .44559 Mdot
.994 .44582 Mdot
.994 .44592 Mdot
.994 .44621 Mdot
.994 .44659 Mdot
.994 .44662 Mdot
.994 .44707 Mdot
.994 .44723 Mdot
.994 .44736 Mdot
.994 .44802 Mdot
.994 .44821 Mdot
.994 .44822 Mdot
.994 .44905 Mdot
.994 .4491 Mdot
.994 .44913 Mdot
.994 .44963 Mdot
.994 .45009 Mdot
.994 .45012 Mdot
.994 .45036 Mdot
.994 .45044 Mdot
.994 .45059 Mdot
.994 .45086 Mdot
.994 .45095 Mdot
.994 .45127 Mdot
.994 .45176 Mdot
.994 .45248 Mdot
.994 .45286 Mdot
.994 .4529 Mdot
.994 .45352 Mdot
.994 .45372 Mdot
.994 .45379 Mdot
.994 .45483 Mdot
.994 .45483 Mdot
.994 .45497 Mdot
.994 .45534 Mdot
.994 .45585 Mdot
.994 .45632 Mdot
.994 .45654 Mdot
.994 .45686 Mdot
.994 .457 Mdot
.994 .45705 Mdot
.994 .45858 Mdot
.994 .45892 Mdot
.994 .459 Mdot
.994 .45976 Mdot
.994 .45988 Mdot
.994 .45996 Mdot
.994 .46111 Mdot
.994 .46181 Mdot
.994 .46324 Mdot
.994 .46335 Mdot
.994 .46414 Mdot
.994 .46435 Mdot
.994 .46577 Mdot
.994 .46597 Mdot
.994 .46715 Mdot
.994 .46719 Mdot
.994 .46733 Mdot
.994 .46762 Mdot
.994 .46763 Mdot
.994 .46795 Mdot
.994 .46832 Mdot
.994 .46833 Mdot
.994 .46872 Mdot
.994 .46947 Mdot
.994 .46965 Mdot
.994 .47018 Mdot
.994 .47034 Mdot
.994 .47072 Mdot
.994 .4712 Mdot
.994 .4712 Mdot
.994 .473 Mdot
.994 .47303 Mdot
.994 .47346 Mdot
.994 .47396 Mdot
.994 .47495 Mdot
.994 .47603 Mdot
.994 .47611 Mdot
.994 .477 Mdot
.994 .47716 Mdot
.994 .47768 Mdot
.994 .47776 Mdot
.994 .47807 Mdot
.994 .47824 Mdot
.994 .47845 Mdot
.994 .47926 Mdot
.994 .47969 Mdot
.994 .48014 Mdot
.994 .48066 Mdot
.994 .48106 Mdot
.994 .48114 Mdot
.994 .48137 Mdot
.994 .48141 Mdot
.994 .48155 Mdot
.994 .48209 Mdot
.994 .48249 Mdot
.994 .48291 Mdot
.994 .48294 Mdot
.994 .48338 Mdot
.994 .48356 Mdot
.994 .48375 Mdot
.994 .48377 Mdot
.994 .48397 Mdot
.994 .48405 Mdot
.994 .48414 Mdot
.994 .48415 Mdot
.994 .48427 Mdot
.994 .48432 Mdot
.994 .48457 Mdot
.994 .48459 Mdot
.994 .48469 Mdot
.994 .48475 Mdot
.994 .4848 Mdot
.994 .48494 Mdot
.994 .48495 Mdot
.994 .48508 Mdot
.994 .4852 Mdot
.994 .48549 Mdot
.994 .48552 Mdot
.994 .4858 Mdot
.994 .48607 Mdot
.994 .4867 Mdot
.994 .48675 Mdot
.994 .48736 Mdot
.994 .48765 Mdot
.994 .48794 Mdot
.994 .48861 Mdot
.994 .48872 Mdot
.994 .48892 Mdot
.994 .48897 Mdot
.994 .48931 Mdot
.994 .48941 Mdot
.994 .48999 Mdot
.994 .49004 Mdot
.994 .49073 Mdot
.994 .49137 Mdot
.994 .49196 Mdot
.994 .49198 Mdot
.994 .49311 Mdot
.994 .49341 Mdot
.994 .49365 Mdot
.994 .49408 Mdot
.994 .49419 Mdot
.994 .4949 Mdot
.994 .49513 Mdot
.994 .49534 Mdot
.994 .49635 Mdot
.994 .49647 Mdot
.994 .49733 Mdot
.994 .49745 Mdot
.994 .49793 Mdot
.994 .49927 Mdot
.994 .49995 Mdot
.994 .50007 Mdot
.994 .50052 Mdot
.994 .50056 Mdot
.994 .50165 Mdot
.994 .50294 Mdot
.994 .50294 Mdot
.994 .50357 Mdot
.994 .50406 Mdot
.994 .50428 Mdot
.994 .50496 Mdot
.994 .50519 Mdot
.994 .50547 Mdot
.994 .50616 Mdot
.994 .50667 Mdot
.994 .50667 Mdot
.994 .50714 Mdot
.994 .50722 Mdot
.994 .5073 Mdot
.994 .50755 Mdot
.994 .50757 Mdot
.994 .50778 Mdot
.994 .50794 Mdot
.994 .50812 Mdot
.994 .50817 Mdot
.994 .50889 Mdot
.994 .50966 Mdot
.994 .5099 Mdot
.994 .5108 Mdot
.994 .51167 Mdot
.994 .51192 Mdot
.994 .51194 Mdot
.994 .5129 Mdot
.994 .51304 Mdot
.994 .51392 Mdot
.994 .51477 Mdot
.994 .51561 Mdot
.994 .51619 Mdot
.994 .51699 Mdot
.994 .51708 Mdot
.994 .51722 Mdot
.994 .51739 Mdot
.994 .51813 Mdot
.994 .51821 Mdot
.994 .51836 Mdot
.994 .51862 Mdot
.994 .51976 Mdot
.994 .51987 Mdot
.994 .52039 Mdot
.994 .52045 Mdot
.994 .52061 Mdot
.994 .52099 Mdot
.994 .52124 Mdot
.994 .52135 Mdot
.994 .52146 Mdot
.994 .52178 Mdot
.994 .52236 Mdot
.994 .52278 Mdot
.994 .52294 Mdot
.994 .52294 Mdot
.994 .5234 Mdot
.994 .52348 Mdot
.994 .52411 Mdot
.994 .52419 Mdot
.994 .52441 Mdot
.994 .52477 Mdot
.994 .52505 Mdot
.994 .5251 Mdot
.994 .52516 Mdot
.994 .52558 Mdot
.994 .52625 Mdot
.994 .52637 Mdot
.994 .52691 Mdot
.994 .5271 Mdot
.994 .52727 Mdot
.994 .52736 Mdot
.994 .52766 Mdot
.994 .52782 Mdot
.994 .52791 Mdot
.994 .52817 Mdot
.994 .52819 Mdot
.994 .52846 Mdot
.994 .52869 Mdot
.994 .52884 Mdot
.994 .52924 Mdot
.994 .52927 Mdot
.994 .52932 Mdot
.994 .53021 Mdot
.994 .53022 Mdot
.994 .53039 Mdot
.994 .53042 Mdot
.994 .53112 Mdot
.994 .53126 Mdot
.994 .53143 Mdot
.994 .5319 Mdot
.994 .53194 Mdot
.994 .53234 Mdot
.994 .53264 Mdot
.994 .53274 Mdot
.994 .53299 Mdot
.994 .53308 Mdot
.994 .53334 Mdot
.994 .53336 Mdot
.994 .53347 Mdot
.994 .53387 Mdot
.994 .53415 Mdot
.994 .53425 Mdot
.994 .53445 Mdot
.994 .53462 Mdot
.994 .53549 Mdot
.994 .53553 Mdot
.994 .53583 Mdot
.994 .5359 Mdot
.994 .53594 Mdot
.994 .53636 Mdot
.994 .5369 Mdot
.994 .53699 Mdot
.994 .53802 Mdot
.994 .53805 Mdot
.994 .53849 Mdot
.994 .53868 Mdot
.994 .53874 Mdot
.994 .53903 Mdot
.994 .53918 Mdot
.994 .53963 Mdot
.994 .53963 Mdot
.994 .53964 Mdot
.994 .53996 Mdot
.994 .54011 Mdot
.994 .54015 Mdot
.994 .54046 Mdot
.994 .541 Mdot
.994 .54101 Mdot
.994 .54167 Mdot
.994 .54176 Mdot
.994 .54183 Mdot
.994 .5419 Mdot
.994 .54191 Mdot
.994 .54196 Mdot
.994 .54199 Mdot
.994 .54215 Mdot
.994 .54358 Mdot
.994 .54377 Mdot
.994 .54529 Mdot
.994 .54576 Mdot
.994 .5468 Mdot
.994 .54783 Mdot
.994 .54803 Mdot
.994 .54923 Mdot
.994 .5494 Mdot
.994 .54964 Mdot
.994 .54993 Mdot
.994 .55064 Mdot
.994 .55122 Mdot
.994 .55137 Mdot
.994 .55163 Mdot
.994 .55207 Mdot
.994 .55379 Mdot
.994 .55403 Mdot
.994 .55421 Mdot
.994 .55511 Mdot
.994 .5552 Mdot
.994 .55548 Mdot
.994 .55611 Mdot
.994 .55639 Mdot
.994 .55653 Mdot
.994 .55671 Mdot
.994 .55689 Mdot
.994 .55692 Mdot
.994 .55744 Mdot
.994 .55837 Mdot
.994 .5584 Mdot
.994 .5586 Mdot
.994 .55909 Mdot
.994 .55935 Mdot
.994 .55936 Mdot
.994 .55953 Mdot
.994 .56011 Mdot
.994 .56024 Mdot
.994 .56032 Mdot
.994 .56099 Mdot
.994 .56126 Mdot
.994 .56139 Mdot
.994 .56146 Mdot
.994 .56175 Mdot
.994 .56232 Mdot
.994 .56277 Mdot
.994 .56286 Mdot
.994 .56294 Mdot
.994 .56323 Mdot
.994 .56361 Mdot
.994 .56467 Mdot
.994 .56486 Mdot
.994 .5657 Mdot
.994 .56593 Mdot
.994 .566 Mdot
.994 .56617 Mdot
.994 .56625 Mdot
.994 .56639 Mdot
.994 .56639 Mdot
.994 .56685 Mdot
.994 .56702 Mdot
.994 .5671 Mdot
.994 .56722 Mdot
.994 .56724 Mdot
.994 .56729 Mdot
.994 .56756 Mdot
.994 .56764 Mdot
.994 .56768 Mdot
.994 .56788 Mdot
.994 .56795 Mdot
.994 .56809 Mdot
.994 .56828 Mdot
.994 .56844 Mdot
.994 .56866 Mdot
.994 .56926 Mdot
.994 .56931 Mdot
.994 .56938 Mdot
.994 .5707 Mdot
.994 .57072 Mdot
.994 .57097 Mdot
.994 .57102 Mdot
.994 .57102 Mdot
.994 .57104 Mdot
.994 .57131 Mdot
.994 .57204 Mdot
.994 .57223 Mdot
.994 .57224 Mdot
.994 .57249 Mdot
.994 .57264 Mdot
.994 .57316 Mdot
.994 .57317 Mdot
.994 .57321 Mdot
.994 .57379 Mdot
.994 .57412 Mdot
.994 .57421 Mdot
.994 .57435 Mdot
.994 .57436 Mdot
.994 .57451 Mdot
.994 .5747 Mdot
.994 .57483 Mdot
.994 .57506 Mdot
.994 .57519 Mdot
.994 .57523 Mdot
.994 .57538 Mdot
.994 .57593 Mdot
.994 .57621 Mdot
.994 .57625 Mdot
.994 .57626 Mdot
.994 .57631 Mdot
.994 .57645 Mdot
.994 .57672 Mdot
.994 .57695 Mdot
.994 .57783 Mdot
.994 .57813 Mdot
.994 .57819 Mdot
.994 .57835 Mdot
.994 .57858 Mdot
.994 .57867 Mdot
.994 .57872 Mdot
.994 .57894 Mdot
.994 .57927 Mdot
.994 .57933 Mdot
.994 .57953 Mdot
.994 .57998 Mdot
.994 .5801 Mdot
.994 .58016 Mdot
.994 .58036 Mdot
.994 .58107 Mdot
.994 .5813 Mdot
.994 .58141 Mdot
.994 .58144 Mdot
.994 .58155 Mdot
.994 .58163 Mdot
.994 .58191 Mdot
.994 .58199 Mdot
.994 .58223 Mdot
.994 .5823 Mdot
.994 .58245 Mdot
.994 .58266 Mdot
.994 .58285 Mdot
.994 .58339 Mdot
.994 .58339 Mdot
.994 .5834 Mdot
.994 .58379 Mdot
.994 .58396 Mdot
.994 .58401 Mdot
.994 .58408 Mdot
.994 .58438 Mdot
.994 .58454 Mdot
.994 .58466 Mdot
.994 .58493 Mdot
.994 .58501 Mdot
.994 .58502 Mdot
.994 .58577 Mdot
.994 .58586 Mdot
.994 .58588 Mdot
.994 .58597 Mdot
.994 .58604 Mdot
.994 .58606 Mdot
.994 .58611 Mdot
.994 .58614 Mdot
.994 .58627 Mdot
.994 .58633 Mdot
.994 .58638 Mdot
.994 .58705 Mdot
.994 .58746 Mdot
.994 .58756 Mdot
.994 .58771 Mdot
.994 .58789 Mdot
.994 .58809 Mdot
.994 .58814 Mdot
.994 .58844 Mdot
.994 .58855 Mdot
.994 .58906 Mdot
.994 .58966 Mdot
.994 .59012 Mdot
.994 .59051 Mdot
.994 .59087 Mdot
.994 .59113 Mdot
.994 .59127 Mdot
.994 .59148 Mdot
.994 .59155 Mdot
.994 .59157 Mdot
.994 .59162 Mdot
.994 .59202 Mdot
.994 .59208 Mdot
.994 .59226 Mdot
.994 .59277 Mdot
.994 .59297 Mdot
.994 .59302 Mdot
.994 .59319 Mdot
.994 .59329 Mdot
.994 .59344 Mdot
.994 .59347 Mdot
.994 .59362 Mdot
.994 .59363 Mdot
.994 .59386 Mdot
.994 .59387 Mdot
.994 .59404 Mdot
.994 .59405 Mdot
.994 .5942 Mdot
.994 .59431 Mdot
.994 .59444 Mdot
.994 .59467 Mdot
.994 .59487 Mdot
.994 .59499 Mdot
.994 .59517 Mdot
.994 .59528 Mdot
.994 .59532 Mdot
.994 .59533 Mdot
.994 .59549 Mdot
.994 .59584 Mdot
.994 .59597 Mdot
.994 .59619 Mdot
.994 .5962 Mdot
.994 .59637 Mdot
.994 .59663 Mdot
.994 .59678 Mdot
.994 .59689 Mdot
.994 .59696 Mdot
.994 .59716 Mdot
.994 .59718 Mdot
.994 .59718 Mdot
.994 .59721 Mdot
.994 .59739 Mdot
.994 .5974 Mdot
.994 .5974 Mdot
.994 .59745 Mdot
.994 .5976 Mdot
.994 .59792 Mdot
.994 .59806 Mdot
.994 .59812 Mdot
.994 .5982 Mdot
.994 .59823 Mdot
.994 .59827 Mdot
.994 .59829 Mdot
.994 .59829 Mdot
.994 .5983 Mdot
.994 .59852 Mdot
.994 .5986 Mdot
.994 .5987 Mdot
.994 .59877 Mdot
.994 .59885 Mdot
.994 .59887 Mdot
.994 .59888 Mdot
.994 .59891 Mdot
.994 .59893 Mdot
.994 .59895 Mdot
.994 .59901 Mdot
.994 .59903 Mdot
.994 .59906 Mdot
.994 .59911 Mdot
.994 .59915 Mdot
.994 .59917 Mdot
.994 .59918 Mdot
.994 .59919 Mdot
.994 .59919 Mdot
.994 .59921 Mdot
.994 .59924 Mdot
.994 .59924 Mdot
.994 .59929 Mdot
.994 .59939 Mdot
.994 .59942 Mdot
.994 .59942 Mdot
.994 .59942 Mdot
.994 .59944 Mdot
.994 .59945 Mdot
.994 .59947 Mdot
.994 .59951 Mdot
.994 .59953 Mdot
.994 .59957 Mdot
.994 .59958 Mdot
.994 .59962 Mdot
.994 .59964 Mdot
.994 .59965 Mdot
.994 .59969 Mdot
.994 .5997 Mdot
.994 .59973 Mdot
.994 .59975 Mdot
.994 .59978 Mdot
.994 .59978 Mdot
.994 .59979 Mdot
.994 .59979 Mdot
.994 .59979 Mdot
.996 .08881 Mdot
.996 .08881 Mdot
.996 .08885 Mdot
.996 .08887 Mdot
.996 .0889 Mdot
.996 .08902 Mdot
.996 .08908 Mdot
.996 .08913 Mdot
.996 .08914 Mdot
.996 .0892 Mdot
.996 .08951 Mdot
.996 .08965 Mdot
.996 .08984 Mdot
.996 .08986 Mdot
.996 .08992 Mdot
.996 .09015 Mdot
.996 .09058 Mdot
.996 .09076 Mdot
.996 .09087 Mdot
.996 .09116 Mdot
.996 .09131 Mdot
.996 .09132 Mdot
.996 .09133 Mdot
.996 .09149 Mdot
.996 .09155 Mdot
.996 .09155 Mdot
.996 .0917 Mdot
.996 .09199 Mdot
.996 .09212 Mdot
.996 .09231 Mdot
.996 .09232 Mdot
.996 .09239 Mdot
.996 .09254 Mdot
.996 .09315 Mdot
.996 .09329 Mdot
.996 .09336 Mdot
.996 .09366 Mdot
.996 .09368 Mdot
.996 .09415 Mdot
.996 .09416 Mdot
.996 .0942 Mdot
.996 .09429 Mdot
.996 .09455 Mdot
.996 .0947 Mdot
.996 .0948 Mdot
.996 .09501 Mdot
.996 .09546 Mdot
.996 .09597 Mdot
.996 .09618 Mdot
.996 .09665 Mdot
.996 .09726 Mdot
.996 .09861 Mdot
.996 .09879 Mdot
.996 .09901 Mdot
.996 .09958 Mdot
.996 .09976 Mdot
.996 .10015 Mdot
.996 .10169 Mdot
.996 .10204 Mdot
.996 .10222 Mdot
.996 .10238 Mdot
.996 .10293 Mdot
.996 .1039 Mdot
.996 .10404 Mdot
.996 .10435 Mdot
.996 .10462 Mdot
.996 .10465 Mdot
.996 .10502 Mdot
.996 .10529 Mdot
.996 .10533 Mdot
.996 .1054 Mdot
.996 .10553 Mdot
.996 .1075 Mdot
.996 .10779 Mdot
.996 .10823 Mdot
.996 .10841 Mdot
.996 .10877 Mdot
.996 .10885 Mdot
.996 .10898 Mdot
.996 .10898 Mdot
.996 .10941 Mdot
.996 .11005 Mdot
.996 .11133 Mdot
.996 .1116 Mdot
.996 .11183 Mdot
.996 .11209 Mdot
.996 .11227 Mdot
.996 .11228 Mdot
.996 .11228 Mdot
.996 .11435 Mdot
.996 .11461 Mdot
.996 .11801 Mdot
.996 .11906 Mdot
.996 .11917 Mdot
.996 .11986 Mdot
.996 .12235 Mdot
.996 .12544 Mdot
.996 .12859 Mdot
.996 .12872 Mdot
.996 .12953 Mdot
.996 .13068 Mdot
.996 .13075 Mdot
.996 .13117 Mdot
.996 .13315 Mdot
.996 .13495 Mdot
.996 .13822 Mdot
.996 .13965 Mdot
.996 .1403 Mdot
.996 .14073 Mdot
.996 .14175 Mdot
.996 .14624 Mdot
.996 .15259 Mdot
.996 .15341 Mdot
.996 .15563 Mdot
.996 .15662 Mdot
.996 .15857 Mdot
.996 .15882 Mdot
.996 .16141 Mdot
.996 .16274 Mdot
.996 .16453 Mdot
.996 .1657 Mdot
.996 .16878 Mdot
.996 .16932 Mdot
.996 .17088 Mdot
.996 .17121 Mdot
.996 .17205 Mdot
.996 .17281 Mdot
.996 .17675 Mdot
.996 .17742 Mdot
.996 .17749 Mdot
.996 .17953 Mdot
.996 .17998 Mdot
.996 .18027 Mdot
.996 .18126 Mdot
.996 .18157 Mdot
.996 .18206 Mdot
.996 .1844 Mdot
.996 .18601 Mdot
.996 .18909 Mdot
.996 .18923 Mdot
.996 .19134 Mdot
.996 .19297 Mdot
.996 .19305 Mdot
.996 .19549 Mdot
.996 .19668 Mdot
.996 .19672 Mdot
.996 .1991 Mdot
.996 .19977 Mdot
.996 .2 Mdot
.996 .20047 Mdot
.996 .20082 Mdot
.996 .20149 Mdot
.996 .20173 Mdot
.996 .20324 Mdot
.996 .20491 Mdot
.996 .20605 Mdot
.996 .2076 Mdot
.996 .20806 Mdot
.996 .20822 Mdot
.996 .20865 Mdot
.996 .20958 Mdot
.996 .20989 Mdot
.996 .21105 Mdot
.996 .21149 Mdot
.996 .21266 Mdot
.996 .21275 Mdot
.996 .2134 Mdot
.996 .22275 Mdot
.996 .22474 Mdot
.996 .22573 Mdot
.996 .22574 Mdot
.996 .22613 Mdot
.996 .22707 Mdot
.996 .2291 Mdot
.996 .22936 Mdot
.996 .2304 Mdot
.996 .23271 Mdot
.996 .23371 Mdot
.996 .2348 Mdot
.996 .23519 Mdot
.996 .23649 Mdot
.996 .23829 Mdot
.996 .23907 Mdot
.996 .24303 Mdot
.996 .24349 Mdot
.996 .24502 Mdot
.996 .24563 Mdot
.996 .24674 Mdot
.996 .2477 Mdot
.996 .24838 Mdot
.996 .24981 Mdot
.996 .25081 Mdot
.996 .25231 Mdot
.996 .25236 Mdot
.996 .2536 Mdot
.996 .25551 Mdot
.996 .25603 Mdot
.996 .25704 Mdot
.996 .25707 Mdot
.996 .25734 Mdot
.996 .2596 Mdot
.996 .26037 Mdot
.996 .2631 Mdot
.996 .26365 Mdot
.996 .26474 Mdot
.996 .26484 Mdot
.996 .26566 Mdot
.996 .26778 Mdot
.996 .27763 Mdot
.996 .27807 Mdot
.996 .27957 Mdot
.996 .28108 Mdot
.996 .28232 Mdot
.996 .28267 Mdot
.996 .28518 Mdot
.996 .2863 Mdot
.996 .2863 Mdot
.996 .28655 Mdot
.996 .28667 Mdot
.996 .28682 Mdot
.996 .28754 Mdot
.996 .28791 Mdot
.996 .28815 Mdot
.996 .28816 Mdot
.996 .28823 Mdot
.996 .28859 Mdot
.996 .28885 Mdot
.996 .28902 Mdot
.996 .29022 Mdot
.996 .29029 Mdot
.996 .29034 Mdot
.996 .29036 Mdot
.996 .29053 Mdot
.996 .29076 Mdot
.996 .29115 Mdot
.996 .29124 Mdot
.996 .29223 Mdot
.996 .29234 Mdot
.996 .2927 Mdot
.996 .29377 Mdot
.996 .29405 Mdot
.996 .29491 Mdot
.996 .29646 Mdot
.996 .29749 Mdot
.996 .2979 Mdot
.996 .29809 Mdot
.996 .2987 Mdot
.996 .29959 Mdot
.996 .29975 Mdot
.996 .30042 Mdot
.996 .3006 Mdot
.996 .30068 Mdot
.996 .30069 Mdot
.996 .30108 Mdot
.996 .30164 Mdot
.996 .30195 Mdot
.996 .30197 Mdot
.996 .30218 Mdot
.996 .30261 Mdot
.996 .30278 Mdot
.996 .3038 Mdot
.996 .30442 Mdot
.996 .30516 Mdot
.996 .30621 Mdot
.996 .30625 Mdot
.996 .30664 Mdot
.996 .30747 Mdot
.996 .30776 Mdot
.996 .30777 Mdot
.996 .31069 Mdot
.996 .31083 Mdot
.996 .31164 Mdot
.996 .31204 Mdot
.996 .31321 Mdot
.996 .31366 Mdot
.996 .31379 Mdot
.996 .31498 Mdot
.996 .31609 Mdot
.996 .31632 Mdot
.996 .3164 Mdot
.996 .31659 Mdot
.996 .31713 Mdot
.996 .31853 Mdot
.996 .31884 Mdot
.996 .31886 Mdot
.996 .31932 Mdot
.996 .31937 Mdot
.996 .31947 Mdot
.996 .31986 Mdot
.996 .321 Mdot
.996 .32118 Mdot
.996 .32208 Mdot
.996 .32327 Mdot
.996 .32343 Mdot
.996 .32386 Mdot
.996 .32558 Mdot
.996 .32617 Mdot
.996 .32708 Mdot
.996 .32726 Mdot
.996 .32955 Mdot
.996 .32976 Mdot
.996 .33164 Mdot
.996 .33174 Mdot
.996 .333 Mdot
.996 .33478 Mdot
.996 .33532 Mdot
.996 .34003 Mdot
.996 .34095 Mdot
.996 .34098 Mdot
.996 .34118 Mdot
.996 .34209 Mdot
.996 .34292 Mdot
.996 .3444 Mdot
.996 .34504 Mdot
.996 .34532 Mdot
.996 .34552 Mdot
.996 .34597 Mdot
.996 .34793 Mdot
.996 .35067 Mdot
.996 .35102 Mdot
.996 .35196 Mdot
.996 .35569 Mdot
.996 .35617 Mdot
.996 .35744 Mdot
.996 .35831 Mdot
.996 .35878 Mdot
.996 .3591 Mdot
.996 .36183 Mdot
.996 .36213 Mdot
.996 .36266 Mdot
.996 .36285 Mdot
.996 .36379 Mdot
.996 .36657 Mdot
.996 .36726 Mdot
.996 .3687 Mdot
.996 .36872 Mdot
.996 .36993 Mdot
.996 .37002 Mdot
.996 .3702 Mdot
.996 .37061 Mdot
.996 .37071 Mdot
.996 .37196 Mdot
.996 .3732 Mdot
.996 .37327 Mdot
.996 .37344 Mdot
.996 .3738 Mdot
.996 .37392 Mdot
.996 .37438 Mdot
.996 .37505 Mdot
.996 .37531 Mdot
.996 .38013 Mdot
.996 .38013 Mdot
.996 .38029 Mdot
.996 .38065 Mdot
.996 .38144 Mdot
.996 .38195 Mdot
.996 .38367 Mdot
.996 .38382 Mdot
.996 .38503 Mdot
.996 .38687 Mdot
.996 .38704 Mdot
.996 .38788 Mdot
.996 .38831 Mdot
.996 .3895 Mdot
.996 .38989 Mdot
.996 .39047 Mdot
.996 .39049 Mdot
.996 .39171 Mdot
.996 .39242 Mdot
.996 .3936 Mdot
.996 .39465 Mdot
.996 .39487 Mdot
.996 .39533 Mdot
.996 .39565 Mdot
.996 .39647 Mdot
.996 .40028 Mdot
.996 .40046 Mdot
.996 .40104 Mdot
.996 .40162 Mdot
.996 .4021 Mdot
.996 .40224 Mdot
.996 .40321 Mdot
.996 .40365 Mdot
.996 .40365 Mdot
.996 .40374 Mdot
.996 .40379 Mdot
.996 .40385 Mdot
.996 .40413 Mdot
.996 .40427 Mdot
.996 .40437 Mdot
.996 .40437 Mdot
.996 .4044 Mdot
.996 .40454 Mdot
.996 .4047 Mdot
.996 .40517 Mdot
.996 .4052 Mdot
.996 .40521 Mdot
.996 .40522 Mdot
.996 .40553 Mdot
.996 .40556 Mdot
.996 .40595 Mdot
.996 .40599 Mdot
.996 .40613 Mdot
.996 .40665 Mdot
.996 .40759 Mdot
.996 .40799 Mdot
.996 .40823 Mdot
.996 .40881 Mdot
.996 .40887 Mdot
.996 .40913 Mdot
.996 .4092 Mdot
.996 .40923 Mdot
.996 .40924 Mdot
.996 .4096 Mdot
.996 .40973 Mdot
.996 .40973 Mdot
.996 .41005 Mdot
.996 .41068 Mdot
.996 .41098 Mdot
.996 .41138 Mdot
.996 .4114 Mdot
.996 .41155 Mdot
.996 .41187 Mdot
.996 .41199 Mdot
.996 .41318 Mdot
.996 .4135 Mdot
.996 .41365 Mdot
.996 .41411 Mdot
.996 .41429 Mdot
.996 .41434 Mdot
.996 .41523 Mdot
.996 .41532 Mdot
.996 .41535 Mdot
.996 .41543 Mdot
.996 .41564 Mdot
.996 .41619 Mdot
.996 .41632 Mdot
.996 .4165 Mdot
.996 .41652 Mdot
.996 .4167 Mdot
.996 .41715 Mdot
.996 .4181 Mdot
.996 .41918 Mdot
.996 .41953 Mdot
.996 .4196 Mdot
.996 .4205 Mdot
.996 .42058 Mdot
.996 .42185 Mdot
.996 .42276 Mdot
.996 .42461 Mdot
.996 .42498 Mdot
.996 .42543 Mdot
.996 .42575 Mdot
.996 .42633 Mdot
.996 .42659 Mdot
.996 .42678 Mdot
.996 .42695 Mdot
.996 .42773 Mdot
.996 .42932 Mdot
.996 .4308 Mdot
.996 .43099 Mdot
.996 .43149 Mdot
.996 .43184 Mdot
.996 .43215 Mdot
.996 .43324 Mdot
.996 .43336 Mdot
.996 .43357 Mdot
.996 .43402 Mdot
.996 .43513 Mdot
.996 .4354 Mdot
.996 .43598 Mdot
.996 .4365 Mdot
.996 .43658 Mdot
.996 .43674 Mdot
.996 .43728 Mdot
.996 .4378 Mdot
.996 .43787 Mdot
.996 .43801 Mdot
.996 .43825 Mdot
.996 .43862 Mdot
.996 .44056 Mdot
.996 .44077 Mdot
.996 .44108 Mdot
.996 .44198 Mdot
.996 .44204 Mdot
.996 .44253 Mdot
.996 .44327 Mdot
.996 .44334 Mdot
.996 .44368 Mdot
.996 .44385 Mdot
.996 .44433 Mdot
.996 .44449 Mdot
.996 .44473 Mdot
.996 .44473 Mdot
.996 .44552 Mdot
.996 .44642 Mdot
.996 .44651 Mdot
.996 .4467 Mdot
.996 .44879 Mdot
.996 .44902 Mdot
.996 .44946 Mdot
.996 .44951 Mdot
.996 .44991 Mdot
.996 .45038 Mdot
.996 .45052 Mdot
.996 .45071 Mdot
.996 .45072 Mdot
.996 .45073 Mdot
.996 .45087 Mdot
.996 .4522 Mdot
.996 .45439 Mdot
.996 .45485 Mdot
.996 .45538 Mdot
.996 .45703 Mdot
.996 .45797 Mdot
.996 .45965 Mdot
.996 .46072 Mdot
.996 .4625 Mdot
.996 .46269 Mdot
.996 .46384 Mdot
.996 .46554 Mdot
.996 .46568 Mdot
.996 .46608 Mdot
.996 .46661 Mdot
.996 .46685 Mdot
.996 .46795 Mdot
.996 .46799 Mdot
.996 .46896 Mdot
.996 .46925 Mdot
.996 .46971 Mdot
.996 .46986 Mdot
.996 .47043 Mdot
.996 .47252 Mdot
.996 .47293 Mdot
.996 .47366 Mdot
.996 .47623 Mdot
.996 .47647 Mdot
.996 .4767 Mdot
.996 .47681 Mdot
.996 .47787 Mdot
.996 .47807 Mdot
.996 .47813 Mdot
.996 .47931 Mdot
.996 .48097 Mdot
.996 .48107 Mdot
.996 .48118 Mdot
.996 .48122 Mdot
.996 .48182 Mdot
.996 .48321 Mdot
.996 .4841 Mdot
.996 .48451 Mdot
.996 .48469 Mdot
.996 .48478 Mdot
.996 .48495 Mdot
.996 .48507 Mdot
.996 .48535 Mdot
.996 .48595 Mdot
.996 .48726 Mdot
.996 .48743 Mdot
.996 .48928 Mdot
.996 .49014 Mdot
.996 .49021 Mdot
.996 .49035 Mdot
.996 .49051 Mdot
.996 .49215 Mdot
.996 .49286 Mdot
.996 .49416 Mdot
.996 .49452 Mdot
.996 .49461 Mdot
.996 .49489 Mdot
.996 .49507 Mdot
.996 .49567 Mdot
.996 .49636 Mdot
.996 .49651 Mdot
.996 .49683 Mdot
.996 .49708 Mdot
.996 .49716 Mdot
.996 .50066 Mdot
.996 .50163 Mdot
.996 .50218 Mdot
.996 .50313 Mdot
.996 .50493 Mdot
.996 .50568 Mdot
.996 .50587 Mdot
.996 .50647 Mdot
.996 .50684 Mdot
.996 .50809 Mdot
.996 .50814 Mdot
.996 .50953 Mdot
.996 .50985 Mdot
.996 .51051 Mdot
.996 .51102 Mdot
.996 .51118 Mdot
.996 .5113 Mdot
.996 .51232 Mdot
.996 .5133 Mdot
.996 .51471 Mdot
.996 .51494 Mdot
.996 .51505 Mdot
.996 .51625 Mdot
.996 .51709 Mdot
.996 .51836 Mdot
.996 .51858 Mdot
.996 .51887 Mdot
.996 .52034 Mdot
.996 .52143 Mdot
.996 .5219 Mdot
.996 .52333 Mdot
.996 .52343 Mdot
.996 .52394 Mdot
.996 .52446 Mdot
.996 .52545 Mdot
.996 .52676 Mdot
.996 .52691 Mdot
.996 .52838 Mdot
.996 .52853 Mdot
.996 .52854 Mdot
.996 .52855 Mdot
.996 .52876 Mdot
.996 .52891 Mdot
.996 .52943 Mdot
.996 .52986 Mdot
.996 .52992 Mdot
.996 .53013 Mdot
.996 .53039 Mdot
.996 .53064 Mdot
.996 .53072 Mdot
.996 .53238 Mdot
.996 .53273 Mdot
.996 .53287 Mdot
.996 .53306 Mdot
.996 .53316 Mdot
.996 .53361 Mdot
.996 .5341 Mdot
.996 .5344 Mdot
.996 .53492 Mdot
.996 .53493 Mdot
.996 .53517 Mdot
.996 .53533 Mdot
.996 .53583 Mdot
.996 .53601 Mdot
.996 .53635 Mdot
.996 .53642 Mdot
.996 .53718 Mdot
.996 .53767 Mdot
.996 .53773 Mdot
.996 .53843 Mdot
.996 .53863 Mdot
.996 .53895 Mdot
.996 .5391 Mdot
.996 .53916 Mdot
.996 .53916 Mdot
.996 .54107 Mdot
.996 .54117 Mdot
.996 .54143 Mdot
.996 .54161 Mdot
.996 .54166 Mdot
.996 .5418 Mdot
.996 .54186 Mdot
.996 .54189 Mdot
.996 .54237 Mdot
.996 .54285 Mdot
.996 .54289 Mdot
.996 .54305 Mdot
.996 .54312 Mdot
.996 .54315 Mdot
.996 .54361 Mdot
.996 .54362 Mdot
.996 .54417 Mdot
.996 .54442 Mdot
.996 .54547 Mdot
.996 .54581 Mdot
.996 .54589 Mdot
.996 .54608 Mdot
.996 .54619 Mdot
.996 .54719 Mdot
.996 .54731 Mdot
.996 .54748 Mdot
.996 .54779 Mdot
.996 .54825 Mdot
.996 .54843 Mdot
.996 .54975 Mdot
.996 .55009 Mdot
.996 .55021 Mdot
.996 .55116 Mdot
.996 .55184 Mdot
.996 .552 Mdot
.996 .55206 Mdot
.996 .55216 Mdot
.996 .55238 Mdot
.996 .55288 Mdot
.996 .55316 Mdot
.996 .55347 Mdot
.996 .55354 Mdot
.996 .55355 Mdot
.996 .55386 Mdot
.996 .55542 Mdot
.996 .5556 Mdot
.996 .55617 Mdot
.996 .55658 Mdot
.996 .55662 Mdot
.996 .55722 Mdot
.996 .55728 Mdot
.996 .55801 Mdot
.996 .55807 Mdot
.996 .55836 Mdot
.996 .55854 Mdot
.996 .55908 Mdot
.996 .55921 Mdot
.996 .55927 Mdot
.996 .55963 Mdot
.996 .55991 Mdot
.996 .55997 Mdot
.996 .56032 Mdot
.996 .56044 Mdot
.996 .56047 Mdot
.996 .56048 Mdot
.996 .56062 Mdot
.996 .56063 Mdot
.996 .56072 Mdot
.996 .56115 Mdot
.996 .56131 Mdot
.996 .56137 Mdot
.996 .56139 Mdot
.996 .56146 Mdot
.996 .56179 Mdot
.996 .56215 Mdot
.996 .56219 Mdot
.996 .56232 Mdot
.996 .56267 Mdot
.996 .56279 Mdot
.996 .56302 Mdot
.996 .56306 Mdot
.996 .56392 Mdot
.996 .56392 Mdot
.996 .564 Mdot
.996 .56424 Mdot
.996 .56435 Mdot
.996 .56437 Mdot
.996 .56467 Mdot
.996 .56488 Mdot
.996 .56506 Mdot
.996 .56535 Mdot
.996 .56539 Mdot
.996 .56551 Mdot
.996 .56557 Mdot
.996 .56558 Mdot
.996 .56567 Mdot
.996 .56583 Mdot
.996 .56594 Mdot
.996 .56594 Mdot
.996 .56596 Mdot
.996 .56601 Mdot
.996 .5662 Mdot
.996 .56624 Mdot
.996 .56649 Mdot
.996 .56666 Mdot
.996 .56671 Mdot
.996 .56683 Mdot
.996 .56711 Mdot
.996 .56754 Mdot
.996 .56777 Mdot
.996 .56785 Mdot
.996 .56814 Mdot
.996 .56823 Mdot
.996 .56826 Mdot
.996 .56853 Mdot
.996 .56855 Mdot
.996 .56866 Mdot
.996 .56872 Mdot
.996 .56876 Mdot
.996 .56877 Mdot
.996 .56878 Mdot
.996 .5688 Mdot
.996 .56912 Mdot
.996 .56917 Mdot
.996 .56924 Mdot
.996 .56933 Mdot
.996 .56935 Mdot
.996 .56935 Mdot
.996 .56942 Mdot
.996 .56951 Mdot
.996 .5697 Mdot
.996 .56974 Mdot
.996 .56978 Mdot
.996 .56984 Mdot
.996 .56984 Mdot
.996 .57013 Mdot
.996 .57079 Mdot
.996 .57088 Mdot
.996 .57119 Mdot
.996 .57158 Mdot
.996 .57196 Mdot
.996 .57207 Mdot
.996 .57449 Mdot
.996 .575 Mdot
.996 .5752 Mdot
.996 .57522 Mdot
.996 .57548 Mdot
.996 .57561 Mdot
.996 .57624 Mdot
.996 .57642 Mdot
.996 .57694 Mdot
.996 .577 Mdot
.996 .57701 Mdot
.996 .57724 Mdot
.996 .57735 Mdot
.996 .57778 Mdot
.996 .57806 Mdot
.996 .57807 Mdot
.996 .5784 Mdot
.996 .57862 Mdot
.996 .57894 Mdot
.996 .57909 Mdot
.996 .57929 Mdot
.996 .57953 Mdot
.996 .57966 Mdot
.996 .57999 Mdot
.996 .58009 Mdot
.996 .58092 Mdot
.996 .58108 Mdot
.996 .58145 Mdot
.996 .58172 Mdot
.996 .5818 Mdot
.996 .58202 Mdot
.996 .58222 Mdot
.996 .58268 Mdot
.996 .58289 Mdot
.996 .58294 Mdot
.996 .58334 Mdot
.996 .58352 Mdot
.996 .5836 Mdot
.996 .5836 Mdot
.996 .58379 Mdot
.996 .58417 Mdot
.996 .58591 Mdot
.996 .58603 Mdot
.996 .58604 Mdot
.996 .58625 Mdot
.996 .58633 Mdot
.996 .58654 Mdot
.996 .58659 Mdot
.996 .58675 Mdot
.996 .58683 Mdot
.996 .58686 Mdot
.996 .58694 Mdot
.996 .58721 Mdot
.996 .58741 Mdot
.996 .58769 Mdot
.996 .58795 Mdot
.996 .58799 Mdot
.996 .5881 Mdot
.996 .58816 Mdot
.996 .58824 Mdot
.996 .58828 Mdot
.996 .58839 Mdot
.996 .58878 Mdot
.996 .58879 Mdot
.996 .58898 Mdot
.996 .58938 Mdot
.996 .58939 Mdot
.996 .58965 Mdot
.996 .58998 Mdot
.996 .59 Mdot
.996 .59048 Mdot
.996 .59073 Mdot
.996 .59108 Mdot
.996 .59115 Mdot
.996 .5912 Mdot
.996 .59135 Mdot
.996 .59139 Mdot
.996 .59146 Mdot
.996 .59175 Mdot
.996 .59176 Mdot
.996 .59186 Mdot
.996 .59242 Mdot
.996 .59253 Mdot
.996 .59264 Mdot
.996 .59269 Mdot
.996 .59291 Mdot
.996 .59298 Mdot
.996 .5934 Mdot
.996 .59355 Mdot
.996 .59379 Mdot
.996 .59396 Mdot
.996 .5943 Mdot
.996 .59433 Mdot
.996 .59457 Mdot
.996 .5947 Mdot
.996 .59497 Mdot
.996 .59507 Mdot
.996 .59582 Mdot
.996 .59633 Mdot
.996 .59645 Mdot
.996 .59649 Mdot
.996 .59656 Mdot
.996 .59672 Mdot
.996 .59707 Mdot
.996 .59726 Mdot
.996 .59746 Mdot
.996 .5975 Mdot
.996 .59751 Mdot
.996 .59763 Mdot
.996 .59771 Mdot
.996 .59772 Mdot
.996 .59803 Mdot
.996 .59832 Mdot
.996 .59855 Mdot
.996 .59862 Mdot
.996 .59863 Mdot
.996 .59872 Mdot
.996 .59902 Mdot
.996 .59904 Mdot
.996 .59922 Mdot
.996 .59922 Mdot
.996 .59922 Mdot
.996 .59924 Mdot
.996 .59926 Mdot
.996 .59928 Mdot
.996 .5993 Mdot
.996 .59941 Mdot
.996 .59946 Mdot
.996 .5995 Mdot
.996 .5995 Mdot
.996 .59951 Mdot
.996 .59951 Mdot
.996 .59954 Mdot
.996 .59956 Mdot
.996 .59959 Mdot
.996 .59962 Mdot
.996 .59977 Mdot
.996 .59978 Mdot
.996 .59979 Mdot
.996 .59979 Mdot
.996 .59981 Mdot
.996 .59984 Mdot
.996 .59984 Mdot
.996 .59987 Mdot
.996 .59989 Mdot
.996 .5999 Mdot
.996 .59997 Mdot
.996 .60002 Mdot
.996 .60003 Mdot
.996 .60004 Mdot
.996 .60007 Mdot
.996 .60018 Mdot
.996 .60021 Mdot
.996 .60022 Mdot
.996 .60027 Mdot
.996 .60028 Mdot
.996 .6003 Mdot
.996 .60039 Mdot
.996 .60044 Mdot
.996 .60047 Mdot
.996 .60048 Mdot
.996 .60052 Mdot
.996 .60055 Mdot
.996 .60057 Mdot
.996 .60057 Mdot
.996 .6006 Mdot
.996 .60061 Mdot
.996 .60061 Mdot
.996 .60061 Mdot
.996 .60064 Mdot
.996 .60064 Mdot
.996 .60066 Mdot
.996 .60067 Mdot
.996 .60068 Mdot
.996 .60072 Mdot
.996 .60073 Mdot
.996 .60074 Mdot
.996 .60074 Mdot
.996 .60075 Mdot
.996 .60076 Mdot
.996 .60078 Mdot
.996 .60079 Mdot
.996 .60079 Mdot
.996 .60079 Mdot
.996 .6008 Mdot
.996 .6008 Mdot
.996 .6008 Mdot
.996 .60081 Mdot
.996 .60083 Mdot
.996 .60084 Mdot
.996 .60085 Mdot
.996 .60088 Mdot
.996 .60089 Mdot
.996 .6009 Mdot
.996 .6009 Mdot
.996 .60091 Mdot
.996 .60092 Mdot
.996 .60094 Mdot
.996 .60094 Mdot
.996 .60094 Mdot
.996 .60095 Mdot
.996 .60095 Mdot
.996 .60096 Mdot
.996 .60096 Mdot
.996 .60096 Mdot
.996 .60097 Mdot
.996 .60097 Mdot
.998 .06721 Mdot
.998 .06722 Mdot
.998 .06725 Mdot
.998 .06731 Mdot
.998 .06733 Mdot
.998 .06733 Mdot
.998 .06745 Mdot
.998 .0676 Mdot
.998 .06789 Mdot
.998 .0685 Mdot
.998 .06863 Mdot
.998 .06883 Mdot
.998 .06921 Mdot
.998 .06947 Mdot
.998 .06991 Mdot
.998 .0719 Mdot
.998 .07261 Mdot
.998 .07298 Mdot
.998 .07449 Mdot
.998 .07462 Mdot
.998 .07473 Mdot
.998 .07489 Mdot
.998 .07548 Mdot
.998 .07682 Mdot
.998 .0782 Mdot
.998 .07856 Mdot
.998 .08 Mdot
.998 .08008 Mdot
.998 .08125 Mdot
.998 .08183 Mdot
.998 .084 Mdot
.998 .08577 Mdot
.998 .08578 Mdot
.998 .08619 Mdot
.998 .08696 Mdot
.998 .08698 Mdot
.998 .0889 Mdot
.998 .08963 Mdot
.998 .09022 Mdot
.998 .09076 Mdot
.998 .0908 Mdot
.998 .09288 Mdot
.998 .09489 Mdot
.998 .09651 Mdot
.998 .09692 Mdot
.998 .09918 Mdot
.998 .09946 Mdot
.998 .09992 Mdot
.998 .10104 Mdot
.998 .10352 Mdot
.998 .10692 Mdot
.998 .10739 Mdot
.998 .11092 Mdot
.998 .11243 Mdot
.998 .11409 Mdot
.998 .11574 Mdot
.998 .11761 Mdot
.998 .12232 Mdot
.998 .1226 Mdot
.998 .12263 Mdot
.998 .12351 Mdot
.998 .12566 Mdot
.998 .12572 Mdot
.998 .12618 Mdot
.998 .12685 Mdot
.998 .12708 Mdot
.998 .12745 Mdot
.998 .12981 Mdot
.998 .13048 Mdot
.998 .13056 Mdot
.998 .13115 Mdot
.998 .13217 Mdot
.998 .13218 Mdot
.998 .13323 Mdot
.998 .13358 Mdot
.998 .13398 Mdot
.998 .13572 Mdot
.998 .13759 Mdot
.998 .13912 Mdot
.998 .13923 Mdot
.998 .13987 Mdot
.998 .14003 Mdot
.998 .14011 Mdot
.998 .14061 Mdot
.998 .14077 Mdot
.998 .14093 Mdot
.998 .14096 Mdot
.998 .14163 Mdot
.998 .14179 Mdot
.998 .14188 Mdot
.998 .14207 Mdot
.998 .14294 Mdot
.998 .14499 Mdot
.998 .14544 Mdot
.998 .14553 Mdot
.998 .14581 Mdot
.998 .14597 Mdot
.998 .1467 Mdot
.998 .14768 Mdot
.998 .14949 Mdot
.998 .15039 Mdot
.998 .15066 Mdot
.998 .15184 Mdot
.998 .15186 Mdot
.998 .15283 Mdot
.998 .15323 Mdot
.998 .15371 Mdot
.998 .15465 Mdot
.998 .15609 Mdot
.998 .15649 Mdot
.998 .15841 Mdot
.998 .15971 Mdot
.998 .16097 Mdot
.998 .16243 Mdot
.998 .1684 Mdot
.998 .16889 Mdot
.998 .17398 Mdot
.998 .17437 Mdot
.998 .17486 Mdot
.998 .17898 Mdot
.998 .17916 Mdot
.998 .17932 Mdot
.998 .18164 Mdot
.998 .18711 Mdot
.998 .18848 Mdot
.998 .19009 Mdot
.998 .19148 Mdot
.998 .19223 Mdot
.998 .1928 Mdot
.998 .19307 Mdot
.998 .1939 Mdot
.998 .19398 Mdot
.998 .19498 Mdot
.998 .1953 Mdot
.998 .19781 Mdot
.998 .19864 Mdot
.998 .19903 Mdot
.998 .20273 Mdot
.998 .20383 Mdot
.998 .20388 Mdot
.998 .20418 Mdot
.998 .20482 Mdot
.998 .20502 Mdot
.998 .206 Mdot
.998 .20644 Mdot
.998 .20664 Mdot
.998 .20741 Mdot
.998 .2082 Mdot
.998 .20824 Mdot
.998 .20882 Mdot
.998 .21089 Mdot
.998 .21178 Mdot
.998 .21281 Mdot
.998 .21402 Mdot
.998 .21523 Mdot
.998 .21754 Mdot
.998 .21755 Mdot
.998 .21817 Mdot
.998 .21853 Mdot
.998 .21979 Mdot
.998 .21998 Mdot
.998 .22001 Mdot
.998 .22084 Mdot
.998 .22299 Mdot
.998 .22386 Mdot
.998 .2254 Mdot
.998 .22752 Mdot
.998 .22892 Mdot
.998 .22942 Mdot
.998 .22954 Mdot
.998 .23004 Mdot
.998 .23036 Mdot
.998 .23053 Mdot
.998 .23267 Mdot
.998 .23407 Mdot
.998 .23593 Mdot
.998 .23651 Mdot
.998 .23765 Mdot
.998 .23852 Mdot
.998 .23865 Mdot
.998 .23889 Mdot
.998 .23976 Mdot
.998 .24022 Mdot
.998 .24106 Mdot
.998 .24139 Mdot
.998 .24217 Mdot
.998 .2424 Mdot
.998 .24271 Mdot
.998 .24299 Mdot
.998 .24307 Mdot
.998 .24403 Mdot
.998 .24777 Mdot
.998 .24872 Mdot
.998 .25339 Mdot
.998 .25521 Mdot
.998 .25731 Mdot
.998 .25749 Mdot
.998 .25978 Mdot
.998 .26034 Mdot
.998 .26133 Mdot
.998 .26315 Mdot
.998 .26549 Mdot
.998 .26622 Mdot
.998 .26633 Mdot
.998 .26769 Mdot
.998 .26776 Mdot
.998 .26826 Mdot
.998 .26855 Mdot
.998 .2688 Mdot
.998 .26885 Mdot
.998 .26945 Mdot
.998 .27161 Mdot
.998 .27225 Mdot
.998 .27228 Mdot
.998 .27255 Mdot
.998 .2735 Mdot
.998 .27365 Mdot
.998 .2742 Mdot
.998 .27423 Mdot
.998 .27546 Mdot
.998 .28034 Mdot
.998 .28354 Mdot
.998 .28515 Mdot
.998 .28536 Mdot
.998 .28671 Mdot
.998 .28843 Mdot
.998 .28944 Mdot
.998 .28946 Mdot
.998 .29002 Mdot
.998 .29136 Mdot
.998 .29137 Mdot
.998 .29178 Mdot
.998 .29295 Mdot
.998 .29522 Mdot
.998 .2961 Mdot
.998 .29633 Mdot
.998 .29722 Mdot
.998 .29876 Mdot
.998 .29885 Mdot
.998 .30034 Mdot
.998 .30095 Mdot
.998 .30295 Mdot
.998 .30348 Mdot
.998 .30465 Mdot
.998 .30722 Mdot
.998 .30773 Mdot
.998 .30823 Mdot
.998 .30916 Mdot
.998 .30942 Mdot
.998 .31019 Mdot
.998 .31033 Mdot
.998 .31133 Mdot
.998 .31203 Mdot
.998 .3132 Mdot
.998 .3137 Mdot
.998 .31423 Mdot
.998 .31801 Mdot
.998 .31936 Mdot
.998 .31948 Mdot
.998 .3199 Mdot
.998 .32287 Mdot
.998 .32355 Mdot
.998 .32388 Mdot
.998 .32604 Mdot
.998 .32605 Mdot
.998 .32766 Mdot
.998 .32832 Mdot
.998 .33057 Mdot
.998 .33152 Mdot
.998 .33255 Mdot
.998 .33339 Mdot
.998 .33598 Mdot
.998 .33619 Mdot
.998 .33834 Mdot
.998 .33904 Mdot
.998 .33974 Mdot
.998 .34051 Mdot
.998 .34245 Mdot
.998 .34257 Mdot
.998 .34294 Mdot
.998 .34402 Mdot
.998 .34429 Mdot
.998 .34603 Mdot
.998 .34643 Mdot
.998 .34686 Mdot
.998 .347 Mdot
.998 .34715 Mdot
.998 .34785 Mdot
.998 .34955 Mdot
.998 .34958 Mdot
.998 .34984 Mdot
.998 .34991 Mdot
.998 .34992 Mdot
.998 .35018 Mdot
.998 .35025 Mdot
.998 .3507 Mdot
.998 .3515 Mdot
.998 .35167 Mdot
.998 .35188 Mdot
.998 .35217 Mdot
.998 .35325 Mdot
.998 .35361 Mdot
.998 .35371 Mdot
.998 .35417 Mdot
.998 .35418 Mdot
.998 .35455 Mdot
.998 .35471 Mdot
.998 .35526 Mdot
.998 .35581 Mdot
.998 .35597 Mdot
.998 .35721 Mdot
.998 .36268 Mdot
.998 .36301 Mdot
.998 .36458 Mdot
.998 .36471 Mdot
.998 .36559 Mdot
.998 .36767 Mdot
.998 .36819 Mdot
.998 .3688 Mdot
.998 .36961 Mdot
.998 .36982 Mdot
.998 .36992 Mdot
.998 .37024 Mdot
.998 .37065 Mdot
.998 .37077 Mdot
.998 .37171 Mdot
.998 .37203 Mdot
.998 .37218 Mdot
.998 .37357 Mdot
.998 .37399 Mdot
.998 .37412 Mdot
.998 .37436 Mdot
.998 .37443 Mdot
.998 .3748 Mdot
.998 .37565 Mdot
.998 .37737 Mdot
.998 .37915 Mdot
.998 .38 Mdot
.998 .38007 Mdot
.998 .38008 Mdot
.998 .3812 Mdot
.998 .3829 Mdot
.998 .38343 Mdot
.998 .38362 Mdot
.998 .38366 Mdot
.998 .38385 Mdot
.998 .38404 Mdot
.998 .38484 Mdot
.998 .38607 Mdot
.998 .38629 Mdot
.998 .38671 Mdot
.998 .38704 Mdot
.998 .38709 Mdot
.998 .38718 Mdot
.998 .38812 Mdot
.998 .38842 Mdot
.998 .38875 Mdot
.998 .39088 Mdot
.998 .39333 Mdot
.998 .39411 Mdot
.998 .39526 Mdot
.998 .39563 Mdot
.998 .39632 Mdot
.998 .39748 Mdot
.998 .39752 Mdot
.998 .39836 Mdot
.998 .39845 Mdot
.998 .39847 Mdot
.998 .3987 Mdot
.998 .39975 Mdot
.998 .39977 Mdot
.998 .40023 Mdot
.998 .40028 Mdot
.998 .40097 Mdot
.998 .40463 Mdot
.998 .40471 Mdot
.998 .40588 Mdot
.998 .40627 Mdot
.998 .40648 Mdot
.998 .40699 Mdot
.998 .40699 Mdot
.998 .40759 Mdot
.998 .40845 Mdot
.998 .40879 Mdot
.998 .40888 Mdot
.998 .4104 Mdot
.998 .41341 Mdot
.998 .41376 Mdot
.998 .41459 Mdot
.998 .41486 Mdot
.998 .4155 Mdot
.998 .4157 Mdot
.998 .41715 Mdot
.998 .41767 Mdot
.998 .41771 Mdot
.998 .41787 Mdot
.998 .41927 Mdot
.998 .42023 Mdot
.998 .42085 Mdot
.998 .4211 Mdot
.998 .42197 Mdot
.998 .42234 Mdot
.998 .42551 Mdot
.998 .42661 Mdot
.998 .42675 Mdot
.998 .42717 Mdot
.998 .42728 Mdot
.998 .42811 Mdot
.998 .42827 Mdot
.998 .42832 Mdot
.998 .42838 Mdot
.998 .42865 Mdot
.998 .43014 Mdot
.998 .43022 Mdot
.998 .43033 Mdot
.998 .43111 Mdot
.998 .43126 Mdot
.998 .43132 Mdot
.998 .43176 Mdot
.998 .43457 Mdot
.998 .43524 Mdot
.998 .4366 Mdot
.998 .43684 Mdot
.998 .43724 Mdot
.998 .43762 Mdot
.998 .43799 Mdot
.998 .43811 Mdot
.998 .43894 Mdot
.998 .43903 Mdot
.998 .43921 Mdot
.998 .44022 Mdot
.998 .44126 Mdot
.998 .44129 Mdot
.998 .44174 Mdot
.998 .44241 Mdot
.998 .44262 Mdot
.998 .4427 Mdot
.998 .44286 Mdot
.998 .44376 Mdot
.998 .44408 Mdot
.998 .44412 Mdot
.998 .44461 Mdot
.998 .44474 Mdot
.998 .44559 Mdot
.998 .44688 Mdot
.998 .44734 Mdot
.998 .44749 Mdot
.998 .44777 Mdot
.998 .44859 Mdot
.998 .44863 Mdot
.998 .44872 Mdot
.998 .44915 Mdot
.998 .45115 Mdot
.998 .45162 Mdot
.998 .45186 Mdot
.998 .45207 Mdot
.998 .45207 Mdot
.998 .45266 Mdot
.998 .45345 Mdot
.998 .45482 Mdot
.998 .45516 Mdot
.998 .45527 Mdot
.998 .45553 Mdot
.998 .4562 Mdot
.998 .45641 Mdot
.998 .4565 Mdot
.998 .45746 Mdot
.998 .45772 Mdot
.998 .46014 Mdot
.998 .46036 Mdot
.998 .46077 Mdot
.998 .46079 Mdot
.998 .46082 Mdot
.998 .46093 Mdot
.998 .46158 Mdot
.998 .46201 Mdot
.998 .46204 Mdot
.998 .46222 Mdot
.998 .46423 Mdot
.998 .4645 Mdot
.998 .46466 Mdot
.998 .46486 Mdot
.998 .46525 Mdot
.998 .46532 Mdot
.998 .46575 Mdot
.998 .46667 Mdot
.998 .46679 Mdot
.998 .46686 Mdot
.998 .46723 Mdot
.998 .46737 Mdot
.998 .46759 Mdot
.998 .46801 Mdot
.998 .46875 Mdot
.998 .46881 Mdot
.998 .46892 Mdot
.998 .46927 Mdot
.998 .46929 Mdot
.998 .46933 Mdot
.998 .47056 Mdot
.998 .47075 Mdot
.998 .47075 Mdot
.998 .471 Mdot
.998 .47211 Mdot
.998 .47264 Mdot
.998 .47421 Mdot
.998 .4743 Mdot
.998 .47448 Mdot
.998 .47449 Mdot
.998 .4745 Mdot
.998 .47483 Mdot
.998 .47501 Mdot
.998 .47502 Mdot
.998 .47609 Mdot
.998 .47644 Mdot
.998 .47663 Mdot
.998 .47703 Mdot
.998 .47733 Mdot
.998 .47761 Mdot
.998 .47873 Mdot
.998 .47941 Mdot
.998 .47964 Mdot
.998 .48045 Mdot
.998 .48045 Mdot
.998 .4806 Mdot
.998 .48068 Mdot
.998 .48139 Mdot
.998 .48171 Mdot
.998 .48183 Mdot
.998 .48263 Mdot
.998 .48273 Mdot
.998 .48309 Mdot
.998 .48309 Mdot
.998 .48316 Mdot
.998 .48351 Mdot
.998 .48427 Mdot
.998 .48427 Mdot
.998 .4843 Mdot
.998 .48585 Mdot
.998 .48637 Mdot
.998 .4866 Mdot
.998 .48665 Mdot
.998 .48665 Mdot
.998 .48695 Mdot
.998 .48776 Mdot
.998 .48828 Mdot
.998 .48838 Mdot
.998 .48838 Mdot
.998 .48891 Mdot
.998 .48906 Mdot
.998 .4895 Mdot
.998 .49022 Mdot
.998 .4904 Mdot
.998 .49085 Mdot
.998 .49187 Mdot
.998 .49199 Mdot
.998 .4922 Mdot
.998 .4922 Mdot
.998 .49221 Mdot
.998 .49336 Mdot
.998 .49369 Mdot
.998 .49438 Mdot
.998 .49453 Mdot
.998 .49465 Mdot
.998 .49543 Mdot
.998 .49565 Mdot
.998 .49576 Mdot
.998 .49621 Mdot
.998 .49647 Mdot
.998 .4966 Mdot
.998 .49668 Mdot
.998 .49691 Mdot
.998 .49695 Mdot
.998 .49702 Mdot
.998 .49758 Mdot
.998 .49783 Mdot
.998 .49788 Mdot
.998 .49811 Mdot
.998 .49823 Mdot
.998 .49832 Mdot
.998 .49848 Mdot
.998 .49968 Mdot
.998 .49978 Mdot
.998 .4998 Mdot
.998 .50005 Mdot
.998 .5005 Mdot
.998 .50051 Mdot
.998 .50052 Mdot
.998 .50076 Mdot
.998 .50089 Mdot
.998 .50244 Mdot
.998 .503 Mdot
.998 .50304 Mdot
.998 .50317 Mdot
.998 .50355 Mdot
.998 .5037 Mdot
.998 .50376 Mdot
.998 .50472 Mdot
.998 .50517 Mdot
.998 .5055 Mdot
.998 .5055 Mdot
.998 .50575 Mdot
.998 .50601 Mdot
.998 .50735 Mdot
.998 .5074 Mdot
.998 .50743 Mdot
.998 .50788 Mdot
.998 .50803 Mdot
.998 .50811 Mdot
.998 .50836 Mdot
.998 .50906 Mdot
.998 .50952 Mdot
.998 .50959 Mdot
.998 .50985 Mdot
.998 .50987 Mdot
.998 .51004 Mdot
.998 .51052 Mdot
.998 .51061 Mdot
.998 .51076 Mdot
.998 .51136 Mdot
.998 .51137 Mdot
.998 .51192 Mdot
.998 .51246 Mdot
.998 .51255 Mdot
.998 .5126 Mdot
.998 .51303 Mdot
.998 .51309 Mdot
.998 .51329 Mdot
.998 .51348 Mdot
.998 .51369 Mdot
.998 .51381 Mdot
.998 .51486 Mdot
.998 .51629 Mdot
.998 .51651 Mdot
.998 .51654 Mdot
.998 .51661 Mdot
.998 .51706 Mdot
.998 .5171 Mdot
.998 .51784 Mdot
.998 .51798 Mdot
.998 .51801 Mdot
.998 .51803 Mdot
.998 .51853 Mdot
.998 .51879 Mdot
.998 .5194 Mdot
.998 .52094 Mdot
.998 .52165 Mdot
.998 .52195 Mdot
.998 .52241 Mdot
.998 .52307 Mdot
.998 .52317 Mdot
.998 .52341 Mdot
.998 .52409 Mdot
.998 .52419 Mdot
.998 .52449 Mdot
.998 .52461 Mdot
.998 .525 Mdot
.998 .52654 Mdot
.998 .52743 Mdot
.998 .52809 Mdot
.998 .52809 Mdot
.998 .52832 Mdot
.998 .52859 Mdot
.998 .52911 Mdot
.998 .53076 Mdot
.998 .53128 Mdot
.998 .53129 Mdot
.998 .53175 Mdot
.998 .53185 Mdot
.998 .53189 Mdot
.998 .53277 Mdot
.998 .53306 Mdot
.998 .53322 Mdot
.998 .53371 Mdot
.998 .53507 Mdot
.998 .53595 Mdot
.998 .53609 Mdot
.998 .5366 Mdot
.998 .53664 Mdot
.998 .53666 Mdot
.998 .53697 Mdot
.998 .53706 Mdot
.998 .53756 Mdot
.998 .53788 Mdot
.998 .53805 Mdot
.998 .53813 Mdot
.998 .53834 Mdot
.998 .53903 Mdot
.998 .53947 Mdot
.998 .53951 Mdot
.998 .54054 Mdot
.998 .54155 Mdot
.998 .54169 Mdot
.998 .54172 Mdot
.998 .54181 Mdot
.998 .54187 Mdot
.998 .54203 Mdot
.998 .54262 Mdot
.998 .54274 Mdot
.998 .5431 Mdot
.998 .54346 Mdot
.998 .54385 Mdot
.998 .54408 Mdot
.998 .54428 Mdot
.998 .54538 Mdot
.998 .54601 Mdot
.998 .54863 Mdot
.998 .54902 Mdot
.998 .54908 Mdot
.998 .54921 Mdot
.998 .54938 Mdot
.998 .54992 Mdot
.998 .55002 Mdot
.998 .55009 Mdot
.998 .55062 Mdot
.998 .55143 Mdot
.998 .55166 Mdot
.998 .55172 Mdot
.998 .55177 Mdot
.998 .55191 Mdot
.998 .55205 Mdot
.998 .55264 Mdot
.998 .55273 Mdot
.998 .5531 Mdot
.998 .55322 Mdot
.998 .55326 Mdot
.998 .55391 Mdot
.998 .55417 Mdot
.998 .5544 Mdot
.998 .55464 Mdot
.998 .55534 Mdot
.998 .55541 Mdot
.998 .55625 Mdot
.998 .55652 Mdot
.998 .55686 Mdot
.998 .55716 Mdot
.998 .55788 Mdot
.998 .55809 Mdot
.998 .55859 Mdot
.998 .55859 Mdot
.998 .55927 Mdot
.998 .55937 Mdot
.998 .55958 Mdot
.998 .56049 Mdot
.998 .56062 Mdot
.998 .56065 Mdot
.998 .56106 Mdot
.998 .5622 Mdot
.998 .56235 Mdot
.998 .5625 Mdot
.998 .56284 Mdot
.998 .56305 Mdot
.998 .56334 Mdot
.998 .56339 Mdot
.998 .56361 Mdot
.998 .56368 Mdot
.998 .56395 Mdot
.998 .5641 Mdot
.998 .56424 Mdot
.998 .56498 Mdot
.998 .56531 Mdot
.998 .56546 Mdot
.998 .56602 Mdot
.998 .56619 Mdot
.998 .56661 Mdot
.998 .56663 Mdot
.998 .56706 Mdot
.998 .5673 Mdot
.998 .56736 Mdot
.998 .5676 Mdot
.998 .56822 Mdot
.998 .56853 Mdot
.998 .56864 Mdot
.998 .56865 Mdot
.998 .569 Mdot
.998 .56915 Mdot
.998 .56916 Mdot
.998 .56942 Mdot
.998 .56987 Mdot
.998 .57023 Mdot
.998 .57028 Mdot
.998 .5707 Mdot
.998 .57152 Mdot
.998 .57274 Mdot
.998 .57305 Mdot
.998 .57305 Mdot
.998 .57319 Mdot
.998 .57323 Mdot
.998 .57346 Mdot
.998 .57353 Mdot
.998 .57353 Mdot
.998 .57369 Mdot
.998 .57421 Mdot
.998 .57436 Mdot
.998 .57437 Mdot
.998 .57443 Mdot
.998 .5745 Mdot
.998 .57462 Mdot
.998 .57464 Mdot
.998 .57496 Mdot
.998 .57499 Mdot
.998 .57516 Mdot
.998 .57571 Mdot
.998 .57613 Mdot
.998 .57636 Mdot
.998 .57649 Mdot
.998 .57701 Mdot
.998 .57706 Mdot
.998 .57753 Mdot
.998 .57794 Mdot
.998 .57897 Mdot
.998 .57917 Mdot
.998 .57997 Mdot
.998 .58018 Mdot
.998 .58025 Mdot
.998 .58032 Mdot
.998 .58037 Mdot
.998 .58053 Mdot
.998 .5806 Mdot
.998 .58078 Mdot
.998 .58087 Mdot
.998 .58105 Mdot
.998 .5811 Mdot
.998 .58113 Mdot
.998 .58131 Mdot
.998 .58154 Mdot
.998 .58166 Mdot
.998 .58204 Mdot
.998 .58232 Mdot
.998 .58274 Mdot
.998 .58278 Mdot
.998 .58284 Mdot
.998 .58294 Mdot
.998 .58296 Mdot
.998 .58306 Mdot
.998 .58334 Mdot
.998 .58375 Mdot
.998 .58404 Mdot
.998 .58421 Mdot
.998 .58461 Mdot
.998 .58477 Mdot
.998 .58477 Mdot
.998 .58481 Mdot
.998 .58504 Mdot
.998 .58511 Mdot
.998 .58522 Mdot
.998 .58523 Mdot
.998 .58565 Mdot
.998 .58587 Mdot
.998 .58609 Mdot
.998 .58627 Mdot
.998 .58643 Mdot
.998 .58679 Mdot
.998 .5869 Mdot
.998 .5869 Mdot
.998 .58704 Mdot
.998 .58717 Mdot
.998 .58721 Mdot
.998 .58728 Mdot
.998 .58745 Mdot
.998 .58749 Mdot
.998 .5876 Mdot
.998 .58765 Mdot
.998 .58766 Mdot
.998 .58784 Mdot
.998 .58846 Mdot
.998 .58853 Mdot
.998 .58866 Mdot
.998 .58907 Mdot
.998 .58913 Mdot
.998 .58929 Mdot
.998 .5893 Mdot
.998 .58943 Mdot
.998 .58948 Mdot
.998 .58957 Mdot
.998 .58968 Mdot
.998 .5899 Mdot
.998 .59015 Mdot
.998 .59037 Mdot
.998 .59119 Mdot
.998 .59153 Mdot
.998 .59156 Mdot
.998 .59158 Mdot
.998 .59218 Mdot
.998 .59225 Mdot
.998 .5923 Mdot
.998 .59301 Mdot
.998 .59307 Mdot
.998 .59387 Mdot
.998 .59406 Mdot
.998 .59422 Mdot
.998 .59438 Mdot
.998 .59462 Mdot
.998 .59467 Mdot
.998 .59485 Mdot
.998 .59497 Mdot
.998 .59503 Mdot
.998 .59507 Mdot
.998 .59519 Mdot
.998 .59519 Mdot
.998 .59534 Mdot
.998 .59537 Mdot
.998 .59547 Mdot
.998 .59569 Mdot
.998 .5958 Mdot
.998 .59588 Mdot
.998 .5959 Mdot
.998 .59594 Mdot
.998 .59595 Mdot
.998 .596 Mdot
.998 .59623 Mdot
.998 .59633 Mdot
.998 .59635 Mdot
.998 .59636 Mdot
.998 .59637 Mdot
.998 .59645 Mdot
.998 .59645 Mdot
.998 .59647 Mdot
.998 .59649 Mdot
.998 .59654 Mdot
.998 .59655 Mdot
.998 .59657 Mdot
.998 .59664 Mdot
.998 .59665 Mdot
.998 .59681 Mdot
.998 .59701 Mdot
.998 .5972 Mdot
.998 .59724 Mdot
.998 .59727 Mdot
.998 .59738 Mdot
.998 .59738 Mdot
.998 .59749 Mdot
.998 .59755 Mdot
.998 .59755 Mdot
.998 .59762 Mdot
.998 .59785 Mdot
.998 .59789 Mdot
.998 .59791 Mdot
.998 .59798 Mdot
.998 .59802 Mdot
.998 .59803 Mdot
.998 .59823 Mdot
.998 .59832 Mdot
.998 .59832 Mdot
.998 .59835 Mdot
.998 .59878 Mdot
.998 .59894 Mdot
.998 .59908 Mdot
.998 .59923 Mdot
.998 .59935 Mdot
.998 .59964 Mdot
.998 .59968 Mdot
.998 .59994 Mdot
.998 .60013 Mdot
.998 .60021 Mdot
.998 .60025 Mdot
.998 .60027 Mdot
.998 .60043 Mdot
.998 .60046 Mdot
.998 .60057 Mdot
.998 .60071 Mdot
.998 .60085 Mdot
.998 .60085 Mdot
.998 .60088 Mdot
.998 .60092 Mdot
.998 .60097 Mdot
.998 .60109 Mdot
.998 .60109 Mdot
.998 .60114 Mdot
.998 .60116 Mdot
.998 .60116 Mdot
.998 .60127 Mdot
.998 .6014 Mdot
.998 .60143 Mdot
.998 .6015 Mdot
.998 .6015 Mdot
.998 .60158 Mdot
.998 .6016 Mdot
.998 .60168 Mdot
.998 .60175 Mdot
.998 .60178 Mdot
.998 .60178 Mdot
.998 .60179 Mdot
.998 .6018 Mdot
.998 .60187 Mdot
.998 .60189 Mdot
.998 .60193 Mdot
.998 .60202 Mdot
.998 .60204 Mdot
.998 .60206 Mdot
.998 .60207 Mdot
.998 .60208 Mdot
.998 .60209 Mdot
.998 .60212 Mdot
.998 .60213 Mdot
.998 .60214 Mdot
.998 .60214 Mdot
.998 .60214 Mdot
.998 .60214 Mdot
.998 .60215 Mdot
.998 .60215 Mdot
.998 .60215 Mdot
1 .01848 Mdot
1 .02056 Mdot
1 .02085 Mdot
1 .02094 Mdot
1 .02132 Mdot
1 .02154 Mdot
1 .02287 Mdot
1 .02307 Mdot
1 .02627 Mdot
1 .03847 Mdot
1 .04181 Mdot
1 .04221 Mdot
1 .04327 Mdot
1 .04446 Mdot
1 .04497 Mdot
1 .04572 Mdot
1 .04603 Mdot
1 .04882 Mdot
1 .0493 Mdot
1 .05477 Mdot
1 .05484 Mdot
1 .05725 Mdot
1 .05838 Mdot
1 .05949 Mdot
1 .06046 Mdot
1 .06344 Mdot
1 .06404 Mdot
1 .06434 Mdot
1 .06499 Mdot
1 .06518 Mdot
1 .06601 Mdot
1 .06668 Mdot
1 .06713 Mdot
1 .06871 Mdot
1 .06921 Mdot
1 .07087 Mdot
1 .07168 Mdot
1 .07293 Mdot
1 .07372 Mdot
1 .07411 Mdot
1 .07532 Mdot
1 .07627 Mdot
1 .07752 Mdot
1 .07848 Mdot
1 .07923 Mdot
1 .08151 Mdot
1 .08214 Mdot
1 .08321 Mdot
1 .08487 Mdot
1 .08806 Mdot
1 .0883 Mdot
1 .08918 Mdot
1 .08965 Mdot
1 .08972 Mdot
1 .09392 Mdot
1 .09498 Mdot
1 .09601 Mdot
1 .09702 Mdot
1 .09723 Mdot
1 .09795 Mdot
1 .09844 Mdot
1 .09853 Mdot
1 .09856 Mdot
1 .0989 Mdot
1 .09964 Mdot
1 .09974 Mdot
1 .10135 Mdot
1 .10229 Mdot
1 .10232 Mdot
1 .1032 Mdot
1 .10402 Mdot
1 .10406 Mdot
1 .10478 Mdot
1 .1053 Mdot
1 .10573 Mdot
1 .10625 Mdot
1 .10734 Mdot
1 .10861 Mdot
1 .10955 Mdot
1 .11093 Mdot
1 .11172 Mdot
1 .11208 Mdot
1 .11273 Mdot
1 .11399 Mdot
1 .11435 Mdot
1 .11501 Mdot
1 .11513 Mdot
1 .11663 Mdot
1 .11677 Mdot
1 .11763 Mdot
1 .11915 Mdot
1 .11978 Mdot
1 .11984 Mdot
1 .12077 Mdot
1 .1212 Mdot
1 .1249 Mdot
1 .12505 Mdot
1 .12511 Mdot
1 .12546 Mdot
1 .12673 Mdot
1 .12735 Mdot
1 .13031 Mdot
1 .13063 Mdot
1 .13146 Mdot
1 .1315 Mdot
1 .13344 Mdot
1 .1343 Mdot
1 .13511 Mdot
1 .13869 Mdot
1 .13907 Mdot
1 .13955 Mdot
1 .14035 Mdot
1 .14052 Mdot
1 .14071 Mdot
1 .14303 Mdot
1 .14415 Mdot
1 .14695 Mdot
1 .14896 Mdot
1 .14935 Mdot
1 .14965 Mdot
1 .15181 Mdot
1 .15228 Mdot
1 .15391 Mdot
1 .15394 Mdot
1 .15442 Mdot
1 .15444 Mdot
1 .15469 Mdot
1 .15619 Mdot
1 .15648 Mdot
1 .1569 Mdot
1 .15765 Mdot
1 .15823 Mdot
1 .1599 Mdot
1 .16504 Mdot
1 .16559 Mdot
1 .16611 Mdot
1 .16698 Mdot
1 .16725 Mdot
1 .17043 Mdot
1 .17117 Mdot
1 .17148 Mdot
1 .17206 Mdot
1 .17427 Mdot
1 .17524 Mdot
1 .1755 Mdot
1 .17698 Mdot
1 .17806 Mdot
1 .17849 Mdot
1 .17907 Mdot
1 .18018 Mdot
1 .1812 Mdot
1 .18145 Mdot
1 .18428 Mdot
1 .18432 Mdot
1 .18623 Mdot
1 .18642 Mdot
1 .18758 Mdot
1 .18905 Mdot
1 .18914 Mdot
1 .1897 Mdot
1 .19089 Mdot
1 .19119 Mdot
1 .19142 Mdot
1 .19227 Mdot
1 .19241 Mdot
1 .19312 Mdot
1 .19399 Mdot
1 .19621 Mdot
1 .19641 Mdot
1 .19853 Mdot
1 .19952 Mdot
1 .19997 Mdot
1 .20201 Mdot
1 .20204 Mdot
1 .20361 Mdot
1 .20399 Mdot
1 .20711 Mdot
1 .20721 Mdot
1 .20762 Mdot
1 .20887 Mdot
1 .20915 Mdot
1 .20966 Mdot
1 .21236 Mdot
1 .21465 Mdot
1 .21559 Mdot
1 .21706 Mdot
1 .21763 Mdot
1 .21793 Mdot
1 .21872 Mdot
1 .21952 Mdot
1 .22081 Mdot
1 .22085 Mdot
1 .22357 Mdot
1 .22371 Mdot
1 .2263 Mdot
1 .22799 Mdot
1 .23021 Mdot
1 .23555 Mdot
1 .23632 Mdot
1 .23779 Mdot
1 .23862 Mdot
1 .24034 Mdot
1 .24052 Mdot
1 .24165 Mdot
1 .24178 Mdot
1 .24362 Mdot
1 .24582 Mdot
1 .24626 Mdot
1 .24637 Mdot
1 .24756 Mdot
1 .24798 Mdot
1 .24805 Mdot
1 .24985 Mdot
1 .25022 Mdot
1 .25234 Mdot
1 .25313 Mdot
1 .25334 Mdot
1 .25372 Mdot
1 .25486 Mdot
1 .25809 Mdot
1 .25829 Mdot
1 .26115 Mdot
1 .26126 Mdot
1 .2614 Mdot
1 .26312 Mdot
1 .26476 Mdot
1 .26694 Mdot
1 .26763 Mdot
1 .2691 Mdot
1 .26978 Mdot
1 .2699 Mdot
1 .27145 Mdot
1 .27257 Mdot
1 .27287 Mdot
1 .27466 Mdot
1 .27495 Mdot
1 .27544 Mdot
1 .27679 Mdot
1 .27769 Mdot
1 .278 Mdot
1 .27835 Mdot
1 .27892 Mdot
1 .27955 Mdot
1 .27981 Mdot
1 .28267 Mdot
1 .28298 Mdot
1 .28419 Mdot
1 .28516 Mdot
1 .28619 Mdot
1 .28724 Mdot
1 .28801 Mdot
1 .28843 Mdot
1 .28915 Mdot
1 .28974 Mdot
1 .28992 Mdot
1 .29147 Mdot
1 .29157 Mdot
1 .29179 Mdot
1 .29284 Mdot
1 .29358 Mdot
1 .29485 Mdot
1 .29696 Mdot
1 .29806 Mdot
1 .29832 Mdot
1 .30669 Mdot
1 .30682 Mdot
1 .30769 Mdot
1 .31109 Mdot
1 .31119 Mdot
1 .31143 Mdot
1 .3119 Mdot
1 .31197 Mdot
1 .31311 Mdot
1 .31742 Mdot
1 .3186 Mdot
1 .31874 Mdot
1 .31912 Mdot
1 .31954 Mdot
1 .32009 Mdot
1 .32125 Mdot
1 .32321 Mdot
1 .32406 Mdot
1 .32486 Mdot
1 .3268 Mdot
1 .32687 Mdot
1 .32716 Mdot
1 .3274 Mdot
1 .32756 Mdot
1 .32917 Mdot
1 .3299 Mdot
1 .33046 Mdot
1 .33124 Mdot
1 .33158 Mdot
1 .33266 Mdot
1 .33326 Mdot
1 .33498 Mdot
1 .33554 Mdot
1 .33556 Mdot
1 .33706 Mdot
1 .33743 Mdot
1 .3378 Mdot
1 .33816 Mdot
1 .33866 Mdot
1 .33869 Mdot
1 .3387 Mdot
1 .33882 Mdot
1 .33908 Mdot
1 .34002 Mdot
1 .34064 Mdot
1 .34066 Mdot
1 .34091 Mdot
1 .3411 Mdot
1 .34143 Mdot
1 .34182 Mdot
1 .3435 Mdot
1 .34373 Mdot
1 .34418 Mdot
1 .34431 Mdot
1 .34455 Mdot
1 .34459 Mdot
1 .34512 Mdot
1 .34602 Mdot
1 .34624 Mdot
1 .34626 Mdot
1 .34675 Mdot
1 .34806 Mdot
1 .34812 Mdot
1 .34871 Mdot
1 .34999 Mdot
1 .3501 Mdot
1 .35311 Mdot
1 .35357 Mdot
1 .35363 Mdot
1 .35452 Mdot
1 .35592 Mdot
1 .35766 Mdot
1 .35841 Mdot
1 .35859 Mdot
1 .3586 Mdot
1 .35869 Mdot
1 .35923 Mdot
1 .35933 Mdot
1 .35948 Mdot
1 .36055 Mdot
1 .36239 Mdot
1 .36259 Mdot
1 .36278 Mdot
1 .36309 Mdot
1 .36459 Mdot
1 .36605 Mdot
1 .36614 Mdot
1 .36667 Mdot
1 .36722 Mdot
1 .36742 Mdot
1 .36828 Mdot
1 .3693 Mdot
1 .36931 Mdot
1 .37101 Mdot
1 .37104 Mdot
1 .37124 Mdot
1 .37186 Mdot
1 .37217 Mdot
1 .37247 Mdot
1 .37279 Mdot
1 .37359 Mdot
1 .37366 Mdot
1 .37478 Mdot
1 .37494 Mdot
1 .37568 Mdot
1 .37569 Mdot
1 .37756 Mdot
1 .37816 Mdot
1 .37826 Mdot
1 .37844 Mdot
1 .38059 Mdot
1 .38112 Mdot
1 .38133 Mdot
1 .38143 Mdot
1 .38201 Mdot
1 .38248 Mdot
1 .38348 Mdot
1 .38353 Mdot
1 .38447 Mdot
1 .38508 Mdot
1 .38589 Mdot
1 .38811 Mdot
1 .38865 Mdot
1 .38895 Mdot
1 .38958 Mdot
1 .38964 Mdot
1 .3901 Mdot
1 .39077 Mdot
1 .39158 Mdot
1 .39221 Mdot
1 .39237 Mdot
1 .39239 Mdot
1 .39305 Mdot
1 .39319 Mdot
1 .39396 Mdot
1 .39425 Mdot
1 .39488 Mdot
1 .39614 Mdot
1 .40036 Mdot
1 .4015 Mdot
1 .40227 Mdot
1 .40295 Mdot
1 .40352 Mdot
1 .40397 Mdot
1 .40406 Mdot
1 .40512 Mdot
1 .40523 Mdot
1 .40604 Mdot
1 .40642 Mdot
1 .40681 Mdot
1 .4071 Mdot
1 .40725 Mdot
1 .40752 Mdot
1 .40781 Mdot
1 .4085 Mdot
1 .40964 Mdot
1 .4141 Mdot
1 .4157 Mdot
1 .41645 Mdot
1 .41857 Mdot
1 .41871 Mdot
1 .41908 Mdot
1 .42057 Mdot
1 .42087 Mdot
1 .42174 Mdot
1 .42189 Mdot
1 .4225 Mdot
1 .42299 Mdot
1 .42329 Mdot
1 .42341 Mdot
1 .42382 Mdot
1 .4247 Mdot
1 .42491 Mdot
1 .42549 Mdot
1 .42591 Mdot
1 .4261 Mdot
1 .42611 Mdot
1 .42612 Mdot
1 .42616 Mdot
1 .42686 Mdot
1 .42703 Mdot
1 .42794 Mdot
1 .4282 Mdot
1 .42836 Mdot
1 .42856 Mdot
1 .429 Mdot
1 .42968 Mdot
1 .4297 Mdot
1 .43179 Mdot
1 .43336 Mdot
1 .43365 Mdot
1 .43372 Mdot
1 .43396 Mdot
1 .434 Mdot
1 .43406 Mdot
1 .43518 Mdot
1 .43526 Mdot
1 .43545 Mdot
1 .43603 Mdot
1 .43705 Mdot
1 .43713 Mdot
1 .43852 Mdot
1 .43853 Mdot
1 .43861 Mdot
1 .43885 Mdot
1 .43921 Mdot
1 .43952 Mdot
1 .44033 Mdot
1 .44034 Mdot
1 .44134 Mdot
1 .44141 Mdot
1 .44245 Mdot
1 .44258 Mdot
1 .44338 Mdot
1 .4434 Mdot
1 .44401 Mdot
1 .44432 Mdot
1 .44541 Mdot
1 .44553 Mdot
1 .44577 Mdot
1 .44624 Mdot
1 .44688 Mdot
1 .44714 Mdot
1 .44719 Mdot
1 .4475 Mdot
1 .44786 Mdot
1 .45004 Mdot
1 .45049 Mdot
1 .45147 Mdot
1 .45197 Mdot
1 .4526 Mdot
1 .45289 Mdot
1 .45328 Mdot
1 .45374 Mdot
1 .45553 Mdot
1 .45617 Mdot
1 .45733 Mdot
1 .45753 Mdot
1 .45861 Mdot
1 .45867 Mdot
1 .45892 Mdot
1 .45924 Mdot
1 .45946 Mdot
1 .46014 Mdot
1 .46039 Mdot
1 .46076 Mdot
1 .46124 Mdot
1 .46185 Mdot
1 .46364 Mdot
1 .46445 Mdot
1 .46548 Mdot
1 .46552 Mdot
1 .46561 Mdot
1 .46667 Mdot
1 .46711 Mdot
1 .46716 Mdot
1 .46749 Mdot
1 .46775 Mdot
1 .46789 Mdot
1 .46834 Mdot
1 .46895 Mdot
1 .46906 Mdot
1 .46936 Mdot
1 .47046 Mdot
1 .47135 Mdot
1 .47147 Mdot
1 .47183 Mdot
1 .47392 Mdot
1 .47402 Mdot
1 .47416 Mdot
1 .47425 Mdot
1 .4748 Mdot
1 .47603 Mdot
1 .47682 Mdot
1 .4778 Mdot
1 .47805 Mdot
1 .47832 Mdot
1 .47836 Mdot
1 .4794 Mdot
1 .47956 Mdot
1 .48051 Mdot
1 .48139 Mdot
1 .48227 Mdot
1 .48239 Mdot
1 .48241 Mdot
1 .48286 Mdot
1 .48335 Mdot
1 .48413 Mdot
1 .48419 Mdot
1 .48709 Mdot
1 .48771 Mdot
1 .4878 Mdot
1 .48838 Mdot
1 .48895 Mdot
1 .48956 Mdot
1 .48966 Mdot
1 .49033 Mdot
1 .49036 Mdot
1 .49053 Mdot
1 .49181 Mdot
1 .49307 Mdot
1 .49443 Mdot
1 .49465 Mdot
1 .49472 Mdot
1 .49527 Mdot
1 .49594 Mdot
1 .49612 Mdot
1 .49619 Mdot
1 .49656 Mdot
1 .49691 Mdot
1 .49707 Mdot
1 .4973 Mdot
1 .49756 Mdot
1 .49828 Mdot
1 .49937 Mdot
1 .50077 Mdot
1 .50105 Mdot
1 .50181 Mdot
1 .50193 Mdot
1 .50211 Mdot
1 .50226 Mdot
1 .50229 Mdot
1 .50506 Mdot
1 .50553 Mdot
1 .50569 Mdot
1 .50604 Mdot
1 .50686 Mdot
1 .5083 Mdot
1 .50866 Mdot
1 .50869 Mdot
1 .50883 Mdot
1 .50917 Mdot
1 .50956 Mdot
1 .50962 Mdot
1 .5102 Mdot
1 .51037 Mdot
1 .51071 Mdot
1 .51113 Mdot
1 .5112 Mdot
1 .51175 Mdot
1 .51231 Mdot
1 .5129 Mdot
1 .51309 Mdot
1 .51321 Mdot
1 .51325 Mdot
1 .51454 Mdot
1 .51494 Mdot
1 .51497 Mdot
1 .51554 Mdot
1 .51557 Mdot
1 .51559 Mdot
1 .5159 Mdot
1 .51773 Mdot
1 .51774 Mdot
1 .51809 Mdot
1 .51848 Mdot
1 .51861 Mdot
1 .51906 Mdot
1 .5195 Mdot
1 .5195 Mdot
1 .51981 Mdot
1 .52019 Mdot
1 .52062 Mdot
1 .52088 Mdot
1 .52125 Mdot
1 .52154 Mdot
1 .52162 Mdot
1 .52217 Mdot
1 .52288 Mdot
1 .52312 Mdot
1 .52447 Mdot
1 .52521 Mdot
1 .52725 Mdot
1 .52776 Mdot
1 .52808 Mdot
1 .5282 Mdot
1 .52852 Mdot
1 .52869 Mdot
1 .52922 Mdot
1 .52927 Mdot
1 .52978 Mdot
1 .53023 Mdot
1 .53053 Mdot
1 .53086 Mdot
1 .53136 Mdot
1 .53371 Mdot
1 .53397 Mdot
1 .53409 Mdot
1 .53442 Mdot
1 .53448 Mdot
1 .53475 Mdot
1 .53476 Mdot
1 .53509 Mdot
1 .53543 Mdot
1 .53571 Mdot
1 .53592 Mdot
1 .53618 Mdot
1 .5363 Mdot
1 .53743 Mdot
1 .53776 Mdot
1 .53801 Mdot
1 .53839 Mdot
1 .53841 Mdot
1 .539 Mdot
1 .53923 Mdot
1 .53927 Mdot
1 .53935 Mdot
1 .54041 Mdot
1 .54048 Mdot
1 .54076 Mdot
1 .54148 Mdot
1 .54149 Mdot
1 .54184 Mdot
1 .54227 Mdot
1 .5423 Mdot
1 .5426 Mdot
1 .54284 Mdot
1 .54296 Mdot
1 .54319 Mdot
1 .54327 Mdot
1 .54328 Mdot
1 .54393 Mdot
1 .54464 Mdot
1 .54471 Mdot
1 .54492 Mdot
1 .54515 Mdot
1 .54569 Mdot
1 .54624 Mdot
1 .54643 Mdot
1 .5465 Mdot
1 .54756 Mdot
1 .54761 Mdot
1 .54765 Mdot
1 .54784 Mdot
1 .54787 Mdot
1 .54788 Mdot
1 .54794 Mdot
1 .54821 Mdot
1 .54964 Mdot
1 .54966 Mdot
1 .54983 Mdot
1 .55088 Mdot
1 .55156 Mdot
1 .55158 Mdot
1 .5522 Mdot
1 .5522 Mdot
1 .55228 Mdot
1 .55258 Mdot
1 .55276 Mdot
1 .55278 Mdot
1 .5529 Mdot
1 .55313 Mdot
1 .55382 Mdot
1 .55394 Mdot
1 .55408 Mdot
1 .55409 Mdot
1 .55429 Mdot
1 .55469 Mdot
1 .55473 Mdot
1 .55473 Mdot
1 .55474 Mdot
1 .55491 Mdot
1 .55503 Mdot
1 .55515 Mdot
1 .55527 Mdot
1 .55576 Mdot
1 .55577 Mdot
1 .55595 Mdot
1 .5565 Mdot
1 .5567 Mdot
1 .55704 Mdot
1 .55715 Mdot
1 .5574 Mdot
1 .55781 Mdot
1 .55831 Mdot
1 .55836 Mdot
1 .55844 Mdot
1 .55853 Mdot
1 .55916 Mdot
1 .5594 Mdot
1 .56027 Mdot
1 .56062 Mdot
1 .56091 Mdot
1 .56103 Mdot
1 .56107 Mdot
1 .56142 Mdot
1 .5627 Mdot
1 .56304 Mdot
1 .56306 Mdot
1 .5633 Mdot
1 .56428 Mdot
1 .56453 Mdot
1 .56457 Mdot
1 .56691 Mdot
1 .56698 Mdot
1 .56728 Mdot
1 .56786 Mdot
1 .5682 Mdot
1 .5684 Mdot
1 .56868 Mdot
1 .56877 Mdot
1 .56918 Mdot
1 .56938 Mdot
1 .56957 Mdot
1 .56968 Mdot
1 .56988 Mdot
1 .57015 Mdot
1 .57042 Mdot
1 .57067 Mdot
1 .57098 Mdot
1 .57106 Mdot
1 .57179 Mdot
1 .57185 Mdot
1 .57215 Mdot
1 .57224 Mdot
1 .57254 Mdot
1 .57288 Mdot
1 .573 Mdot
1 .57351 Mdot
1 .57385 Mdot
1 .57423 Mdot
1 .57426 Mdot
1 .57442 Mdot
1 .57494 Mdot
1 .57545 Mdot
1 .57626 Mdot
1 .57629 Mdot
1 .57694 Mdot
1 .57772 Mdot
1 .57797 Mdot
1 .57805 Mdot
1 .5781 Mdot
1 .57828 Mdot
1 .57874 Mdot
1 .57882 Mdot
1 .57921 Mdot
1 .57923 Mdot
1 .57932 Mdot
1 .5796 Mdot
1 .57969 Mdot
1 .58016 Mdot
1 .58054 Mdot
1 .58057 Mdot
1 .58081 Mdot
1 .58085 Mdot
1 .5812 Mdot
1 .58137 Mdot
1 .58167 Mdot
1 .58183 Mdot
1 .58289 Mdot
1 .58333 Mdot
1 .58365 Mdot
1 .58415 Mdot
1 .58417 Mdot
1 .58469 Mdot
1 .58469 Mdot
1 .58493 Mdot
1 .58508 Mdot
1 .58523 Mdot
1 .58528 Mdot
1 .58539 Mdot
1 .58566 Mdot
1 .58583 Mdot
1 .58624 Mdot
1 .58672 Mdot
1 .5868 Mdot
1 .58685 Mdot
1 .58707 Mdot
1 .58714 Mdot
1 .58716 Mdot
1 .58769 Mdot
1 .58776 Mdot
1 .58802 Mdot
1 .58803 Mdot
1 .58837 Mdot
1 .58844 Mdot
1 .58861 Mdot
1 .58895 Mdot
1 .58899 Mdot
1 .58934 Mdot
1 .58948 Mdot
1 .58959 Mdot
1 .58962 Mdot
1 .58975 Mdot
1 .58979 Mdot
1 .58983 Mdot
1 .59002 Mdot
1 .59011 Mdot
1 .59012 Mdot
1 .59035 Mdot
1 .59052 Mdot
1 .59055 Mdot
1 .59084 Mdot
1 .59085 Mdot
1 .59127 Mdot
1 .59131 Mdot
1 .59146 Mdot
1 .59162 Mdot
1 .5917 Mdot
1 .59192 Mdot
1 .59213 Mdot
1 .59217 Mdot
1 .59231 Mdot
1 .59261 Mdot
1 .5927 Mdot
1 .59274 Mdot
1 .59284 Mdot
1 .59327 Mdot
1 .59331 Mdot
1 .59342 Mdot
1 .59349 Mdot
1 .59357 Mdot
1 .59423 Mdot
1 .59444 Mdot
1 .59452 Mdot
1 .59461 Mdot
1 .59466 Mdot
1 .5947 Mdot
1 .59488 Mdot
1 .59491 Mdot
1 .59491 Mdot
1 .59498 Mdot
1 .59523 Mdot
1 .59549 Mdot
1 .59552 Mdot
1 .59557 Mdot
1 .5958 Mdot
1 .59612 Mdot
1 .59625 Mdot
1 .59652 Mdot
1 .59654 Mdot
1 .59663 Mdot
1 .59668 Mdot
1 .59728 Mdot
1 .59747 Mdot
1 .59756 Mdot
1 .59759 Mdot
1 .59789 Mdot
1 .59795 Mdot
1 .59807 Mdot
1 .5981 Mdot
1 .59811 Mdot
1 .59812 Mdot
1 .59847 Mdot
1 .59851 Mdot
1 .59859 Mdot
1 .5986 Mdot
1 .59866 Mdot
1 .59879 Mdot
1 .59887 Mdot
1 .59888 Mdot
1 .59901 Mdot
1 .59902 Mdot
1 .59908 Mdot
1 .59911 Mdot
1 .59922 Mdot
1 .59927 Mdot
1 .5993 Mdot
1 .59937 Mdot
1 .59948 Mdot
1 .59966 Mdot
1 .59974 Mdot
1 .59979 Mdot
1 .59982 Mdot
1 .59986 Mdot
1 .59991 Mdot
1 .59992 Mdot
1 .59998 Mdot
1 .60005 Mdot
1 .60005 Mdot
1 .60012 Mdot
1 .60024 Mdot
1 .60025 Mdot
1 .6003 Mdot
1 .60032 Mdot
1 .60033 Mdot
1 .60033 Mdot
1 .60037 Mdot
1 .60042 Mdot
1 .60043 Mdot
1 .6005 Mdot
1 .60058 Mdot
1 .60065 Mdot
1 .60093 Mdot
1 .60093 Mdot
1 .60096 Mdot
1 .60102 Mdot
1 .60103 Mdot
1 .60123 Mdot
1 .60133 Mdot
1 .60139 Mdot
1 .60142 Mdot
1 .60155 Mdot
1 .60159 Mdot
1 .60164 Mdot
1 .60171 Mdot
1 .60176 Mdot
1 .60182 Mdot
1 .60184 Mdot
1 .60188 Mdot
1 .60194 Mdot
1 .60198 Mdot
1 .60206 Mdot
1 .60208 Mdot
1 .60216 Mdot
1 .60218 Mdot
1 .60221 Mdot
1 .60224 Mdot
1 .60225 Mdot
1 .60228 Mdot
1 .60229 Mdot
1 .60232 Mdot
1 .60243 Mdot
1 .60247 Mdot
1 .60251 Mdot
1 .60256 Mdot
1 .60264 Mdot
1 .60264 Mdot
1 .60282 Mdot
1 .60283 Mdot
1 .60291 Mdot
1 .60292 Mdot
1 .60294 Mdot
1 .60295 Mdot
1 .60298 Mdot
1 .603 Mdot
1 .60301 Mdot
1 .60309 Mdot
1 .60327 Mdot
1 .6033 Mdot
1 .6033 Mdot
1 .60331 Mdot
1 .60331 Mdot
1 .60331 Mdot
1 .60331 Mdot
1 .60331 Mdot
1 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[52]:=",
  ImageSize->{740.75, 457.813},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000AG0002[R000`400?l00000o`00003oo`3ooooo
0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0
ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3o
oomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?oo
o`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00l@3o
ool4000000H0oooo0P0000050?ooo`H00000_P3oool4000000H0oooo0P0000070?ooo`@00000_`3o
ool4000000H0oooo0P0000070?ooo`@00000_P3oool4000000H0oooo0P0000060?ooo`@00000a`3o
ool700000080oooo003`0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2
000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool2000000T0oooo00<000000?ooo`3oool0_@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0a`3oool0
0`000000oooo0?ooo`030?ooo`00l03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool00`3oool00?00oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`H00000_P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo0P0000030?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0a`3oool00`000000
oooo0?ooo`030?ooo`00l03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00@000000?ooo`3oool00000_`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`0000000P00002m0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool400000<X0oooo00<000000?ooo`3oool00`3oool00?00oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo00000;l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0a`3oool00`000000oooo0?ooo`030?ooo`00l03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2k0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002o0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2n0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0<L0oooo00<000000?ooo`3oool00`3oool00?00oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0^`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000_`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0_@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`350?ooo`<000001@3oool00?40oooo1000000>0?ooo`@00000_`3oool4
00000100oooo0P0000300?ooo`@000004@3oool300000;d0oooo1000000>0?ooo`@00000bP3oool0
0`000000oooo0?ooo`030?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3o
ool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000003o0?ooool0
ooooo`3ooooo0?ooob40oooo000X0?ooool00000o`00003o00000?l00000;P0000050?ooo`00:03o
ool00`000000oooo0?ooo`0K0?ooo`050000003oool000000?ooo`0000004P3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0240oooo00D0
00000?ooo`000000oooo0000000<0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
0`3oool002P0oooo00<000000?ooo`3oool09`3oool010000000oooo0?ooo`0000070?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0;03o
ool01`000000oooo0000003oool000000?ooo`000000=03oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`030?ooo`00
:03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0000009d0oooo00<000000?ooo`3oool0
dP3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0
dP3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0000009T0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`3B0?ooo`030000003o
ool0oooo0=80oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`030?ooo`00:03oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooon/0oooo00<00000
0?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0000003o0?oo
ool0ooooo`3ooooY0?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`000000o`3ooooo0?ooool0ooooj`3oool002P0oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooW0?ooo`00:03oool00`000000oooo0?oo
o`170?ooo`040000003oool0oooo00000?l0ooooo`3ooooo0?ooomh0oooo00<000000?ooo`3oool0
0`3oool002P0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oooP0?ooo`00:03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooomh0oooo000X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`000000o`3ooooo0?oo
ool0oooog03oool002P0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooooH0?ooo`00:03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooomH0oooo000X0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooe03oool002P0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0000003o
0?ooool0ooooo`3ooooA0?ooo`00:03oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooold0oooo000X0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0oooob`3oool002P0oooo00<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3oooo90?ooo`00:03oool00`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooolL0oooo000X0?ooo`030000003oool0oooo06L0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0ooooa@3oool002P0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooonm0?ooo`030000003oool0oooo00<0oooo000X0?ooo`03
0000003oool0oooo06`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo`03oool002P0oooo
00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonn0?ooo`00:03o
ool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oook`0oooo000X
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo]03oool0
0`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?oook80oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon`0?ooo`030000003oool0oooo00<0
oooo000X0?ooo`D00000MP3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon^0?ooo`030000
003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooZ`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`1m
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooojl0oooo000X0?ooo`030000003oool0oooo
07l0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo[@3oool002P0oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonU0?ooo`030000003oool0oooo00<0
oooo000X0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
X`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`250?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooojL0oooo000X0?ooo`030000003oool0oooo08L0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0ooooY@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?oooj<0oooo000X0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooooVP3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooih0oooo000X0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooW03oool002P0oooo00<000000?oo
o`3oool0TP3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonD0?ooo`030000003oool0oooo
00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo:P3oool00`000000
oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooi80oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0UP3o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon@0?ooo`030000003oool0oooo00<0oooo000X
0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooU03oool0
02P0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonB0?oo
o`00:03oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooohl0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo:P3oool00`000000oooo
0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooohL0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0X@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooon50?ooo`030000003oool0oooo00<0oooo000X0?oo
o`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooP`3oool00`00
0000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooobP0
oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooomo0?ooo`030000003oool0000000D0oooo000X0?ooo`030000003o
ool0oooo0:L0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooO@3oool00`000000oooo0000
00050?ooo`00:03oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooog/0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooooo`3ooolZ0?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0:`0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooN03oool00`000000oooo0?ooo`050?ooo`00
:03oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooogH0oooo
00<000000?ooo`0000001@3oool002P0oooo1@00002^0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooog@0oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooo`3ooolX0?ooo`030000003oool0000000D0oooo000X0?ooo`030000003oool0oooo
0;80oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooM03oool00`000000oooo0?ooo`030?oo
o`00:03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooog00
oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0]P3oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooom^0?ooo`030000003oool0000000D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooool0oooo:03oool00`000000oooo000000050?ooo`00:03oool0
0`000000oooo0?ooo`2h0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooof`0oooo00<00000
0?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooomb0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooobP0
oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0_@3oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooomY0?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003o
ool0oooo0;l0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooI`3oool00`000000oooo0?oo
o`030?ooo`00:03oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooof<0oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooooo`3ooolX0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0<<0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooH@3oool00`000000oooo0?ooo`050?ooo`00
:03oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooel0oooo
00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3o
oolZ0?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0<L0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0ooooF`3oool01@000000oooo0000003oool0000000D0oooo000X
0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooF@3oool0
1@000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooool0oooo9P3oool00`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3;0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?oooeL0oooo00<000000?ooo`3oool01`3oool002P0
oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomD0?ooo`03
0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo
9P3oool01@000000oooo0?ooo`3oool0000000D0oooo000X0?ooo`030000003oool0oooo0=00oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0ooooDP3oool01@000000oooo0000003oool0000000D0
oooo000X0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
D03oool01@000000oooo0?ooo`3oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooool0oooo9P3oool01@000000oooo0000003oool0000000D0oooo000X0?ooo`030000
003oool0oooo0=@0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooCP3oool01@000000oooo
0?ooo`3oool0000000D0oooo000X0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooooC03oool01@000000oooo0?ooo`3oool0000000D0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo9P3oool01@000000oooo0000003oool0000000D0
oooo000X0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
BP3oool00`000000oooo0?ooo`070?ooo`00:03oool00`000000oooo0?ooo`3J0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooodP0oooo00D000000?ooo`000000oooo000000050?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooobH0oooo00D000000?ooo`3oool0oooo
000000050?ooo`00:03oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooodD0oooo00D000000?ooo`000000oooo000000050?ooo`00:03oool500000=d0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooo@`3oool01@000000oooo0?ooo`3oool0000000D0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo903oool00`000000oooo0000
00030?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0>40oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0oooo?`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo000X0?ooo`030000003oool0oooo0><0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo?@3oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolT0?ooo`030000003oool0000000T0oooo000X0?oo
o`030000003oool0oooo0>D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo>`3oool00`00
0000oooo000000030?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0>L0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo>@3oool00`000000oooo000000030?ooo`03
0000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo
:03oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3Y0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooocL0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooob@0oooo00L00000
0?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0>/0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooo=@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo000X0?ooo`030000003oool0oooo0>h0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0oooo<P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolT0?ooo`070000003oool0oooo0?ooo`000000
oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3`0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooc00oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`00:03o
ool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobh0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooool0oooo903oool00`000000oooo000000090?ooo`00:03oool00`000000oooo0?oo
o`3d0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobX0oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?H0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooo:03oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3o
oolR0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool002P0oooo00<00000
0?ooo`3oool0n03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolV0?ooo`070000003oool0
00000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oooo0?ooob80oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool0
0`000000oooo0?ooo`3j0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobH0oooo00D00000
0?ooo`3oool0oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3l0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooob80oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`03
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooob80oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolQ0?ooo`070000003oool0oooo0?ooo`000000
oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0oooo7@3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000D0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo9P3oool00`000000oooo0?oo
o`070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooo`@0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0oooo7@3oool01@000000oooo0000003oool0000000L0oooo00020?ooo`@000001P3oool2
000000D0oooo1P00000?0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo7`3oool0
0`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000001@3oool000030?ooo`000000
oooo00<0oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo1P3oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3ooolF0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000001@3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0oooo203oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooolD0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00003
0?ooo`000000oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`L0
0000o`3ooooo0?ooool0ooooo`3ooolK0?ooo`0<0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000001@3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooolB0?ooo`060000003oool0oooo0000003oool000000`3oool00`00
0000oooo000000050?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3oool<0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?oooa00oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0
000000D0oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
ool0oooo7`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool01@3o
ool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooo`d0oooo00H000000?ooo`3oool000000?ooo`00000;0?ooo`000P3o
ool4000000h0oooo1000000@0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo7`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0000000L0oooo000X0?ooo`030000003oool0
oooo0?l0oooo4@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool;0?ooo`060000003oool0
oooo0000003oool000000`3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?oo
o`3o0?oooa<0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo2@3oool00`000000oooo0?oo
o`040?ooo`050000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooo`3ooolO0?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo
0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0oooo5@3oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3oool50?ooo`030000003oool0000000H0oooo00<000000?ooo`000000
1`3oool002P0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooo`<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003o
ool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo7@3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00/0oooo000X0?ooo`030000003oool0oooo
0?l0oooo6@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool10?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000050?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooad0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0oooo
6`3oool00`000000oooo0?ooo`3o0?ooool0oooooP3oool00`000000oooo000000060?ooo`030000
003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0oooo7@3oool00`000000oooo0?oo
o`3o0?ooool0ooooo03oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolO
0?ooo`040000003oool0oooo000000d0oooo000X0?ooo`030000003oool0oooo0?l0oooo803oool0
0`000000oooo0?ooo`3o0?ooool0oooon@3oool00`000000oooo000000040?ooo`070000003oool0
oooo0?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oooo0?oooad0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0oooo8P3oool00`000000oooo0?ooo`3o
0?ooool0oooom@3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo
000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool0o`3o
oooo0?ooooD0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo7@3oool0
0`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooobH0oooo00<000000?ooo`3oool0o`3ooooo0?oooo<0oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000D0oooo000X
0?ooo`030000003oool0oooo0?l0oooo:03oool00`000000oooo0?ooo`3o0?ooool0ooool@3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001@3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolM0?ooo`030000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0
oooo0?l0oooo:P3oool00`000000oooo0?ooo`3o0?ooool0ooook`3oool00`000000oooo00000006
0?ooo`050000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooo`3ooolM0?ooo`030000003oool000000080oooo00<000000?ooo`0000001@3oool0
0`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooob`0oooo00<000000?oo
o`3oool0o`3ooooo0?ooond0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooobh0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooon/0oooo00<000000?ooo`3oool0103oool01`000000oooo0?oo
o`3oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3ooolI0?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`00000;0?oo
o`00:03oool00`000000oooo0?ooo`3o0?oooc40oooo00<000000?ooo`3oool0o`3ooooo0?ooon@0
oooo00<000000?ooo`3oool01P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool0
02P0oooo1@00003o0?ooool0ooooo`3ooooo0?oooaL0oooo00<000000?ooo`3oool0203oool01@00
0000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0oooo<`3oool00`00
0000oooo0?ooo`3o0?ooool0oooohP3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooole0?ooo`030000003oool0oooo
0?l0ooooo`3ooooP0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooaT0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool00`3oool002P0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`030000003oool0oooo0?l0
ooooo`3ooooN0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000030?oo
o`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000
oooo0?ooo`3o0?ooool0oooog03oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000
003oool000001@3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooooo0?oooaL0oooo00<000000?ooo`0000002P3oool01@000000oooo0?ooo`3oool0
000000L0oooo000X0?ooo`030000003oool0oooo0?l0oooo>`3oool00`000000oooo0?ooo`3o0?oo
ool0oooof03oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00D000000?oo
o`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oo
oaL0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00T0oooo000X0?ooo`030000003oool0oooo0?l0oooo?@3oool00`000000oooo0?ooo`3o0?ooool0
ooooeP3oool00`000000oooo000000030?ooo`030000003oool0000000H0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oood00oooo00<000000?ooo`3o
ool0o`3ooooo0?ooom<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000060?ooo`05
0000003oool0oooo0?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
ooooo`3ooolG0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0oooo@P3oool00`000000
oooo0?ooo`3o0?ooool0ooood@3oool00`000000oooo000000030?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`3oool0oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooooo0?oooaL0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`07
0000003oool0oooo0?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
od@0oooo00<000000?ooo`3oool0o`3ooooo0?oooll0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool002P0
oooo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0?l0ooooo`3oooo;0?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolE0?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooodP0oooo00<000000?ooo`3oool0o`3ooooo0?ooolT0oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooodX0oooo00<000000?ooo`3oool0o`3ooooo
0?ooolL0oooo00D000000?ooo`000000oooo000000050?ooo`0<0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooo`3ooolE0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`00:03o
ool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0o`3ooooo0?ooolD0oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oooo0?oooaD0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00L000000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
ooooCP3oool00`000000oooo0?ooo`3o0?ooool0oooo``3oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000
oooo0?ooo`3o0?oooe40oooo00<000000?ooo`3oool0o`3ooooo0?oookh0oooo00D000000?ooo`00
0000oooo000000050?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
ool0oooo4`3oool01`000000oooo0000003oool000000?ooo`0000005P3oool002P0oooo00<00000
0?ooo`3oool0o`3ooomC0?ooo`030000003oool0oooo0?l0ooooo`3ooonl0?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oooo0?oooa<0oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oooeD0
oooo00<000000?ooo`3oool0o`3ooooo0?oookX0oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000050?ooo`030000003oool0
oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`3o0?oo
ool0oooo^03oool01`000000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo0?oo
o`040?ooo`050000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooo`3ooolC0?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`3o0?ooool0
oooo]03oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo000X0?ooo`030000
003oool0oooo0?l0ooooF`3oool00`000000oooo0?ooo`3o0?ooool0oooo/P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`05
0000003oool000000?ooo`0000001@3oool002P0oooo1@00003o0?ooool0ooooo`3ooooo0?ooo`l0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001@3oool002P0oooo00<00000
0?ooo`3oool0o`3ooomM0?ooo`030000003oool0oooo0?l0ooooo`3ooon`0?ooo`050000003oool0
00000?ooo`0000002@3oool010000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`00
00001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolA0?ooo`050000
003oool0oooo0?ooo`0000001`3oool00`000000oooo000000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`030000
003oool0oooo0?l0ooooo`3ooon]0?ooo`050000003oool000000?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000P0oooo00<000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooomR0?ooo`030000003oool0oooo0?l0ooooo`3ooon[0?ooo`070000003oool000000?oo
o`000000oooo000000070?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool00`3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool>0?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooI03oool00`000000oooo0?oo
o`3o0?ooool0ooooYP3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000L0oooo
000X0?ooo`030000003oool0oooo0?l0ooooIP3oool00`000000oooo0?ooo`3o0?ooool0ooooY03o
ool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<0
00000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000050?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooo`h0oooo00`000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00<0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooJ03oool00`000000oooo0?ooo`3o0?ooool0ooooXP3oool02P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`0000050?ooo`030000003oool0oooo0080oooo
00D000000?ooo`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooooo0?ooo`h0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00L00000
0?ooo`3oool0oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooJP3oool00`000000oooo
0?ooo`3o0?ooool0ooooX03oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooom/0?ooo`030000003oool0oooo0?l0oooo
o`3ooonL0?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo
3P3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`03
0?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooKP3oool00`000000oooo0?ooo`3o0?ooool0ooooVP3oool00`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3oooma
0?ooo`030000003oool0oooo0?l0ooooo`3ooonI0?ooo`060000003oool0oooo0000003oool00000
1@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool>
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000
00020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooL`3oool00`000000oooo0?ooo`3o0?ooool0ooooU`3oool020000000
oooo0?ooo`000000oooo0000003oool000000`3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001`3oool002P0oooo00<000000?oo
o`3oool0o`3ooome0?ooo`030000003oool0oooo0?l0ooooo`3ooonA0?ooo`050000003oool0oooo
0?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000050?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000050?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooo`h0oooo00`000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`0000030?ooo`030000003oool0000000@0oooo00<000000?ooo`00
00002@3oool002P0oooo00<000000?ooo`3oool0o`3ooomg0?ooo`030000003oool0oooo0?l0oooo
o`3ooonC0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0`3oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool>0?ooo`030000003oool0oooo0080oooo
00L000000?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooogT0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooi40oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
1@3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000070?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooog/0oooo00<000000?ooo`3oool0o`3ooooo0?ooohl0
oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00`3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool>0?ooo`0<0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000`3oool00`000000oooo000000080?ooo`030000
003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooO@3oool00`000000oooo0?oo
o`3o0?ooool0ooooS@3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooogl0oooo00<000000?ooo`3oool0o`3ooooo0?oooh/0oooo00`00000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooo`h0oooo00X000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000001`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<00000
0?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooon20?ooo`030000003oool0oooo
0?l0ooooo`3ooon20?ooo`030000003oool0oooo00<0oooo00P000000?ooo`3oool000000?ooo`00
0000oooo000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00L000000?oo
o`3oool0oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooQ03oool0
0`000000oooo0?ooo`3o0?ooool0ooooQP3oool030000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003
0?ooo`030000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
ool0oooo3P3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool00000
00D0oooo000X0?ooo`D00000o`3ooon40?ooo`030000003oool0oooo0?l0ooooo`3ooon40?ooo`0<
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool00`000000
oooo000000020?ooo`030000003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooool0oooo1P3oool01@000000oooo0?ooo`3oool0000000<0oooo00P000000?ooo`3o
ool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00`3oool020000000oooo0?oo
o`000000oooo0000003oool000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooon80?ooo`03
0000003oool0oooo0?l0ooooo`3ooon00?ooo`030000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`0000001P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`030000003o
ool0oooo0?l0ooooo`3ooon00?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?oo
o`070000003oool0oooo0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000
1`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool>0?ooo`0<0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool00`000000oooo0000
00020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo
0?ooo`3o0?oooh`0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`03
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohh0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ogX0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000050?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000001`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool>0?ooo`0:0000003oool0oooo0000003o
ool000000?ooo`000000oooo000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooT@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooN@3oool020000000oooo0?ooo`000000oooo0000003oool0
00000`3oool00`000000oooo0?ooo`030?ooo`0:0000003oool0oooo0000003oool000000?ooo`00
0000oooo000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooT`3oool00`000000oooo0?oo
o`3o0?ooool0ooooM`3oool020000000oooo0?ooo`000000oooo0000003oool00000303oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooooo0?ooo`80oooo00<000000?ooo`3oool02@3oool01P000000oooo0?oo
o`000000oooo000000D0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
oiD0oooo00<000000?ooo`3oool0o`3ooooo0?ooogD0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool000000080oooo00<000000?ooo`0000002`3oool0
02P0oooo00<000000?ooo`3oool0o`3ooonG0?ooo`030000003oool0oooo0?l0ooooo`3ooomc0?oo
o`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo000000070?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooooo0?ooo`h0oooo00P000000?ooo`3oool000000?ooo`000000oooo
000000`0oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooV@3oool00`000000oooo0?ooo`3o0?ooool0ooooL@3oool020000000oooo0?oo
o`000000oooo0000003oool000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooV`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooK`3oool030000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooooo0?ooo`h0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
1@3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooW@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooG`3oool00`000000oooo0?ooo`0;0?ooo`0<0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000`3oool00`000000oooo000000020?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooonO0?ooo`03
0000003oool0oooo0?l0ooooo`3ooom^0?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000001P3oool01@000000oooo0000003oool0000000D0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo4@3oool01@000000oooo0?oo
o`3oool0000000T0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000070?ooo`00
:03oool00`000000oooo0?ooo`3o0?oooj80oooo00<000000?ooo`3oool0o`3ooooo0?ooof/0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool010000000oooo0?ooo`00
00050?ooo`030000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooY03oool0
0`000000oooo0?ooo`3o0?ooool0ooooJ@3oool01@000000oooo0000003oool0000000L0oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000D0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo4@3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000`3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooojH0oooo
00<000000?ooo`3oool0o`3ooooo0?ooofL0oooo00D000000?ooo`000000oooo000000090?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`000000oooo000000070?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooojP0oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3o
ool04@3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000050?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooa40oooo00D000000?ooo`000000oooo0000
00070?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000090?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooojX0oooo00<000000?ooo`3oool0o`3ooooo0?ooof<0oooo00D0
00000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooon/0?ooo`030000003oool0oooo0?l0ooooo`3ooomQ0?ooo`050000003oool000000?oo
o`0000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00020?ooo`@0
00001P3oool2000000L0oooo1000000?0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0
oooo4@3oool01`000000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`02
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo00000`3oool00000
0?ooo`030?ooo`030000003oool0oooo00<0oooo0P0000090?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0o`3ooon^0?ooo`030000003oool0oooo0?l0ooooo`3ooomO0?ooo`070000
003oool000000?ooo`000000oooo000000050?ooo`030000003oool0oooo0080oooo00L000000?oo
o`000000oooo0000003oool0000000L0oooo00000`3oool000000?ooo`030?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?oook00oooo00<00000
0?ooo`3oool0o`3ooooo0?oooed0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`030?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0:0?ooo`H0
00003`3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooa40oooo00D000000?ooo`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool00`3oool000030?ooo`000000oooo00<0oooo00<00000
0?ooo`3oool02`3oool010000000oooo0?ooo`00000@0?ooo`L00000o`3ooon_0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomJ0?ooo`050000003oool000000?ooo`0000001`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000/0oooo00000`3oool000000?ooo`030?ooo`030000003o
ool0oooo00/0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`3o0?oookD0oooo
00<000000?ooo`3oool0o`3ooooo0?oooeP0oooo00D000000?ooo`000000oooo000000030?ooo`07
0000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`030?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool000000100oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolA
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo00@000000?ooo`3o
ool000000`3oool01@000000oooo0000003oool0000000D0oooo00000`3oool000000?ooo`030?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`3o0?oo
okL0oooo00<000000?ooo`3oool0o`3ooooo0?oooeH0oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00080
oooo1000000@0?ooo`800000403oool00`000000oooo0?ooo`3o0?oookT0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooch0oooo00<000000?ooo`3oool04`3oool00`000000oooo000000030?ooo`03
0000003oool0000000D0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool00000
00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo4@3oool01@000000
oooo0000003oool0000000`0oooo00D000000?ooo`3oool0oooo000000090?ooo`00:03oool00`00
0000oooo0?ooo`3o0?oook/0oooo00<000000?ooo`3oool0o`3ooooo0?oooe80oooo00D000000?oo
o`000000oooo000000090?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo0000
00L0oooo000X0?ooo`030000003oool0oooo0?l0oooo_@3oool00`000000oooo0?ooo`3o0?ooool0
ooooD03oool01`000000oooo0000003oool000000?ooo`0000001`3oool01P000000oooo0?ooo`00
0000oooo000000D0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooo`3ooolC0?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0
o`3ooono0?ooo`030000003oool0oooo0?l0ooooo`3ooom>0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003o
ool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3oooo20?ooo`030000003o
ool0oooo0?l0ooooo`3ooom;0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001@3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000001@3oool002P0oooo
00<000000?ooo`3oool0o`3oooo40?ooo`030000003oool0oooo0?l0ooooo`3ooom90?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oo
oa40oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000D0oooo000X0?oo
o`030000003oool0oooo0?l0ooooaP3oool00`000000oooo0?ooo`3o0?ooool0ooooA`3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00D000000?ooo`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooolP0oooo
00<000000?ooo`3oool0o`3ooooo0?ooodD0oooo00L000000?ooo`000000oooo0000003oool00000
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`030000003oool0oooo
00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo4@3oool01@000000
oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooolX0oooo00<0
00000?ooo`3oool0o`3ooooo0?oood<0oooo00D000000?ooo`000000oooo000000090?ooo`030000
003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooc03oool00`000000oooo0?ooo`3o0?ooool0oooo@@3oool01`000000
oooo0000003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooool0oooo4@3oool01@000000oooo0000003oool0000000L0oooo00<000000?ooo`3o
ool0103oool01@000000oooo0?ooo`3oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
oooocP3oool00`000000oooo0?ooo`3o0?ooool0oooo9`3oool00`000000oooo0?ooo`0E0?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0203o
ool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooom00oooo00<00000
0?ooo`3oool0o`3ooooo0?ooocd0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooom<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ob00oooo00<000000?ooo`3oool05`3oool01@000000oooo0000003oool0000000L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000D0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo4`3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000
oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooomD0oooo00<000000?ooo`3oool0
o`3ooooo0?ooocP0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000D0oooo000X0?oo
o`030000003oool0oooo0?l0ooooe`3oool00`000000oooo0?ooo`3o0?ooool0oooo6P3oool00`00
0000oooo0?ooo`0I0?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000X0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooo`3ooolC0?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooomT0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooom/0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooobl0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000D0
oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0o`3ooooM0?ooo`030000
003oool0oooo0?l0ooooo`3oool@0?ooo`030000003oool0oooo01X0oooo00P000000?ooo`3oool0
00000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3o
ool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo3P3oool0
0`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooO0?ooo`030000003oool0oooo0?l0ooooo`3oool;0?ooo`030000003oool0
oooo01d0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool00`3oool002P0oooo1@00003o0?oooml0oooo00<000000?ooo`3oool0o`3ooooo0?ooob`0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooi03oool00`00
0000oooo0?ooo`3o0?ooool0oooo9P3oool030000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000D0oooo00H000000?ooo`3oool000000?ooo`00000;0?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3oooo[0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0403oool010000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`000000
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
0`3oool002P0oooo00<000000?ooo`3oool0o`3ooooV0?ooo`030000003oool0oooo0?l0ooooo`3o
oolT0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0000000P0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooX0?ooo`030000003oool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0Q0?ooo`0:0000
003oool0oooo0000003oool000000?ooo`000000oooo000000D0oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooool0oooo3P3oool010000000oooo0?ooo`0000030?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo000000060?ooo`050000003oool000000?ooo`00
00001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooZ0?ooo`030000003oool0oooo0?l0oooo
n@3oool00`000000oooo0?ooo`0S0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo00000005
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooon`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oah0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3o
ool002P0oooo00<000000?ooo`3oool0o`3oooo^0?ooo`030000003oool0oooo0?l0ooooo`3ooolL
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000001@3oool030000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000D0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooonD0oooo00<000000?ooo`3oool09@3oool030000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000001P3oool0
1@000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooool03oool0
0`000000oooo0?ooo`3o0?ooool0oooo6P3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`00
0000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oooo<0oooo00<000000?ooo`3o
ool0o`3oooo/0?ooo`030000003oool0oooo02X0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`000000
1`3oool002P0oooo00<000000?ooo`3oool0o`3ooooe0?ooo`030000003oool0oooo0?l0ooooo`3o
oolE0?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000001@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool>0?ooo`0<0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`04
0?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooooL0oooo00<000000?ooo`3oool0o`3ooooV0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool03P3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`00
0000oooo0?ooo`060?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`03
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooooT0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oa40oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000001@3oool00`000000
oooo000000060?ooo`050000003oool0oooo0?ooo`0000001@3oool002P0oooo00<000000?ooo`3o
ool0o`3ooook0?ooo`030000003oool0oooo0?l0ooooh03oool00`000000oooo0?ooo`0[0?ooo`08
0000003oool0oooo0000003oool000000?ooo`0000030?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo
00<000000?ooo`3oool0o`3oooom0?ooo`030000003oool0oooo0?l0ooooo`3oool=0?ooo`0<0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool00`000000oooo
0?ooo`040?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooo`h0oooo00`000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3oool00`00
0000oooo0?ooo`3o0?ooomT0oooo00<000000?ooo`3oool0;P3oool02P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`0000050?ooo`030000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooo`80oooo00<000000?ooo`3oool0o`3ooooo0?ooo`L0oooo00<000000?ooo`000000103oool0
1@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`0000002@3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooo`D0oooo00<000000?ooo`3oool0o`3ooooB0?ooo`030000003oool0
oooo0300oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000003
0?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo00<000000?ooo`3oool02`3o
ool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`040?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooo`L0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`@0oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3oool90?oo
o`030000003oool0oooo0?l0ooooc03oool00`000000oooo0?ooo`0b0?ooo`0:0000003oool0oooo
0000003oool000000?ooo`000000oooo000000D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo2`3oool00`000000oooo
0?ooo`3o0?ooool0oooo0`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000002@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooo`d0oooo00<000000?ooo`3oool0o`3oooom0?ooo`040000003oool0oooo
000000<0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L0
00000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooomH0oooo00<000000?ooo`3oool0=03oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooo`l0oooo00<000000?ooo`3oool0o`3ooooi0?ooo`030000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000006
0?ooo`050000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?oooa40oooo00<000000?ooo`3oool0o`3oooo]0?ooo`030000003oool0oooo00T0oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000D0oooo00`000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000050?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0oooo4`3oool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0=P3o
ool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01@000000oooo0000003oool0
000000X0oooo00<000000?ooo`3oool01@3oool002P0oooo1@00003o0?ooool0oooo503oool00`00
0000oooo0?ooo`3o0?ooooT0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooool0oooo4@3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000050?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaP0oooo00<000000?ooo`3o
ool0o`3ooong0?ooo`030000003oool0oooo03@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool0
103oool01@000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooolJ0?ooo`030000003oool0oooo0?l0ooool03oool00`000000oooo0?ooo`020?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0000000/0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolL0?ooo`030000003oool0oooo0?l0oooo
i03oool00`000000oooo0?ooo`070?ooo`060000003oool0oooo0000003oool000000`3oool00`00
0000oooo000000050?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo00000005
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo7P3oool00`000000oooo0?ooo`3o0?oo
ojl0oooo00<000000?ooo`3oool0?@3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000070?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooo`h0oooo00X000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000001`3oool020000000oooo0?ooo`000000oooo0000003o
ool000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooob00oooo00<000000?ooo`3o
ool0o`3ooooZ0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo00000003
0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000002@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooob80oooo00<000000?ooo`3oool0o`3ooonY0?ooo`030000003oool0oooo
03`0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?oo
o`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolU0?ooo`030000003oool0oooo
0?l0oooog@3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0000003oool000000`3o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooobL0
oooo00<000000?ooo`3oool0o`3ooooS0?ooo`030000003oool0oooo0080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000D0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo;0?oo
o`030000003oool0oooo03l0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooobT0oooo00<0
00000?ooo`3oool0o`3ooooQ0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool00000303oool01@000000oooo0?ooo`3oool0000000D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3oool[0?ooo`030000003oool0oooo0?l0oooof@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000T0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3oool]0?ooo`030000003oool0oooo0?l0ooooV@3oool00`000000
oooo0?ooo`160?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3oool_0?ooo`030000003oool0oooo0?l0oooof`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
oooo<@3oool00`000000oooo0?ooo`3o0?ooomT0oooo00`000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`0000050?ooo`060000003oool0oooo0000003oool000001@3oool0
0`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo<`3oool00`00
0000oooo0?ooo`3o0?oooi40oooo00<000000?ooo`3oool0@`3oool030000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000103oool01@00
0000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
ool0oooo5`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000H0oooo00D000000?oo
o`3oool0oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo=P3oool00`00
0000oooo0?ooo`3o0?ooom@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo00000005
0?ooo`030000003oool0oooo0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooocP0oooo00<000000?ooo`3oool0
o`3ooooB0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0o`3ooon80?ooo`030000
003oool0oooo04D0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooc`0oooo00<000000?oo
o`3oool0o`3oooo>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001@3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?oooch0oooo00<000000?ooo`3oool0o`3oooo<0?oo
o`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooom00?ooo`030000003oool0oooo0?l0ooooP03oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool00000
0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000050?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooo`h0oooo00P000000?ooo`3oool000000?ooo`000000
oooo000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooom20?oo
o`030000003oool0oooo0?l0oooob03oool00`000000oooo0?ooo`020?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool02@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oood@0oooo00<000000?ooo`3oool0o`3oooo6
0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooA`3oool00`000000oooo0?ooo`3o0?ooogL0oooo00<0
00000?ooo`3oool0A@3oool01@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool0000000D0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003o
ool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooom90?ooo`030000003oool0
oooo0?l0oooo`@3oool01P000000oooo0?ooo`000000oooo000000T0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooom;0?ooo`030000003oool0oooo0?l0oooo_`3oool01P000000oooo0?oo
o`000000oooo000000/0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0
000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooom=0?ooo`030000003oool0oooo
0?l0ooooK`3oool00`000000oooo0?ooo`1;0?ooo`060000003oool0oooo0000003oool000001@3o
ool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000
oooo000000050?ooo`00:03oool500000?l0ooooo`3ooom=0?ooo`030000003oool0oooo0?l0oooo
^`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0?l0oooo^@3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0203oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooooo0?ooo`h0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool00`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooe<0oooo00<000000?ooo`3oool0
o`3ooomV0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo
0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooEP3oool0
0`000000oooo0?ooo`3o0?oook@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?oooeP0oooo00<000000?ooo`3oool0o`3ooonb0?ooo`080000003oool0oooo
0000003oool000000?ooo`0000030?ooo`030000003oool0oooo00H0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oeX0oooo00<000000?ooo`3oool0o`3ooon`0?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`0000001@3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooG03oool0
0`000000oooo0?ooo`3o0?oooe/0oooo00<000000?ooo`3oool0CP3oool00`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo00`000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000050?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooGP3oool00`000000oooo0?ooo`3o0?oooj`0oooo00H000000?ooo`3oool0
00000?ooo`0000090?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooH03oool00`000000
oooo0?ooo`3o0?ooojX0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool0
000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomR0?ooo`030000003oool0oooo
0?l0ooooZ03oool020000000oooo0?ooo`000000oooo0000003oool000001`3oool00`000000oooo
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooof@0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`030000003o
ool0oooo0580oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
000>0?ooo`030000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomW
0?ooo`030000003oool0oooo0?l0ooooX`3oool020000000oooo0?ooo`000000oooo0000003oool0
00000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01@000000oooo0000003o
ool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomY0?ooo`030000003oool0
oooo0?l0ooooX@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00L0oooo00X0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000001`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooof/0oooo00<000000?ooo`3oool0o`3ooonO0?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000040?ooo`070000003oool0
oooo0?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oonf0?ooo`030000003oool0oooo05@0oooo00@000000?ooo`3oool000000`3oool01@000000oooo
0?ooo`3oool0000000D0oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000050?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooK@3oool00`000000oooo0?ooo`3o0?oooid0
oooo00P000000?ooo`3oool000000?ooo`000000oooo000000L0oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000000D0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooom_0?ooo`030000003oool0oooo0?l0ooooV`3oool020000000oooo0?ooo`00
0000oooo0000003oool000001`3oool00`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3oooma
0?ooo`030000003oool0oooo0?l0ooooV@3oool020000000oooo0?ooo`000000oooo0000003oool0
00000`3oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool000002`3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooog<0oooo00<000000?ooo`3oool0o`3ooonG0?oo
o`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool0000000D0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooome0?ooo`030000003oool0oooo0?l0oooo?03oool00`000000
oooo0?ooo`1I0?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`030000003oool0
00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooomh0?ooo`030000003oool0oooo0?l0ooooU@3oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00<0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomj0?ooo`030000003oool0oooo0?l0ooooT`3oool01@000000
oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000X0oooo00<0
00000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooog`0oooo00<00000
0?ooo`3oool0o`3ooonA0?ooo`050000003oool000000?ooo`0000001`3oool00`000000oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooogh0oooo00<000000?ooo`3oool0o`3ooola0?ooo`030000003oool0oooo05/0oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooon00?ooo`030000003oool0oooo0?l0ooooS@3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool00`3oool030000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oon20?ooo`030000003oool0oooo0?l0ooooR`3oool01@000000oooo0000003oool0000000<0oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`0000001@3oool00080oooo100000060?ooo`8000001`3oool4000000l0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooh@0oooo00<000000?ooo`3oool0o`3ooon90?ooo`050000003o
ool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`0000<0oooo0000003oool00`3oool00`000000oooo
0?ooo`030?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0o`3ooooo0?ooohL0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000
003oool0000000D0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`030?ooo`0000<0oooo0000003oool00`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`3o0?ooool0ooooR@3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3o
ool0G@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool000030?ooo`000000oooo
00<0oooo00<000000?ooo`3oool02`3oool2000000<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`3o0?ooool0ooooR`3oool00`000000oooo0?ooo`3o0?oooh80oooo00L000000?oo
o`3oool0oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`030000003oool0000000D0oooo00000`3oool000000?ooo`030?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`0000000P00000?0?ooo`L00000o`3ooooo0?ooohT0oooo00<00000
0?ooo`3oool0o`3ooon00?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`0:0?ooo`050000003oool000000?ooo`0000001@3oool000030?ooo`000000oooo00<0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooo`3o
oon?0?ooo`030000003oool0oooo0?l0ooooP03oool01`000000oooo0000003oool000000?ooo`00
00001@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000L0oooo00000`3oool0
00000?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`3o0?ooool0ooooT@3oool00`000000oooo0?ooo`3o0?ooogh0oooo00<000000?ooo`00
00000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000050?ooo`0000<0oooo0000003oool00`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooooo0?oooi<0oooo
00<000000?ooo`3oool0o`3ooolH0?ooo`030000003oool0oooo0640oooo00D000000?ooo`000000
oooo000000050?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000001@3oool00080oooo1000000A0?ooo`<000003P3oool00`000000oooo0?ooo`3o
0?ooool0ooooU@3oool00`000000oooo0?ooo`3o0?ooogX0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo
000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooV03oool00`000000oooo0?oo
o`3o0?ooogL0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooonJ0?ooo`030000003oool000000?l0ooooM@3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooWP3oool00`000000oooo0?oo
o`3o0?ooog40oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool000000080oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?oooj00oooo00<000000?ooo`3oool0o`3ooom_0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooXP3oool00`000000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3o
ool0I03oool01`000000oooo0000003oool000000?ooo`0000001@3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?oooj@0oooo00<000000?ooo`3oool0o`3ooom[0?ooo`050000003oool000000?ooo`000000
1@3oool00`000000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
0`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooojH0oooo00<000000?ooo`3oool0o`3o
oomY0?ooo`030000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooZ@3oool00`000000oooo0?ooo`3o0?ooofH0oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooZ`3o
ool00`000000oooo0?ooo`3o0?ooof@0oooo00D000000?ooo`000000oooo000000050?ooo`030000
003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooon]0?ooo`030000003oool0oooo0?P0oooo00<000000?ooo`3o
ool0IP3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0oooo[`3oool00`000000oooo0?ooo`3o0?ooofH0oooo00L00000
0?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo/@3oool00`000000oooo0?oo
o`3o0?ooof00oooo00D000000?ooo`000000oooo000000050?ooo`040000003oool0oooo000000<0
oooo00D000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
oooo/`3oool00`000000oooo0?ooo`3o0?oooeh0oooo00D000000?ooo`000000oooo000000050?oo
o`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000001@3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?oookD0oooo00@000000?ooo`3oool00000o`3ooomK0?oo
o`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooonj0?ooo`03
0000003oool0oooo0?l0ooooE`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?oook`0oooo00<000000?ooo`3oool0i`3oool00`000000oooo0?ooo`1Z
0?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
_P3oool00`000000oooo0?ooo`3o0?oooe<0oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oool00oooo00<000000?ooo`3oool0o`3ooomA
0?ooo`050000003oool000000?ooo`0000001@3oool010000000oooo0?ooo`0000030?ooo`050000
003oool0oooo0?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oool80oooo
00<000000?ooo`3oool0o`3ooom?0?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3oooo40?ooo`030000003oool0oooo0?l0ooooC@3oool0
0`000000oooo000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooaP3oool01000
0000oooo0?ooo`00003o0?oood`0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?oool/0oooo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool00000
00D0oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool000000?ooo`0000001@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooold0oooo00<000000?ooo`3oool0e03oool0
0`000000oooo0?ooo`1/0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3oooo?0?ooo`030000003oool0oooo0?l0oooo@P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool0
00000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooom40oooo00<00000
0?ooo`3oool0o`3ooom00?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooood`3oool00`000000oooo0?ooo`3o0?oooch0oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`050?ooo`00:03oool500000?l0ooooo`3ooooC0?ooo`030000003oool000000?l0oooo
?P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooofP3o
ool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00040?ooo`050000003oool0oooo0?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooom`0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooomh0oooo00<000000?ooo`3oool0`@3oool00`000000oooo
0?ooo`1b0?ooo`050000003oool0oooo0?ooo`0000001P3oool01`000000oooo0000003oool00000
0?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooon00oooo00<000000?oo
o`000000o`3ooolc0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooon@0oooo00<000000?ooo`3oool0o`3oool_0?ooo`030000003oool00000
00<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo
00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooV0?ooo`030000003oool0oooo0?l0
oooo;@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
j@3oool00`000000oooo0?ooo`3o0?ooobX0oooo00<000000?ooo`0000000`3oool00`000000oooo
000000040?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooon/0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3oooo]0?ooo`030000003oool000000?l0oooo9P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00L000000?ooo`000000oooo
0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooa0?ooo`030000
003oool0oooo0?l0oooo8P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool01`00
0000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?oooo<0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0
000000D0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000005
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooom@3oool00`000000oooo0000003o0?oo
oah0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`070000003oool00000
0?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooonP3oool0
0`000000oooo0?ooo`3o0?oooaT0oooo00<000000?ooo`0000000`3oool00`000000oooo00000006
0?ooo`030000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooool0?oo
o`030000003oool0oooo0?l0oooo5`3oool00`000000oooo000000030?ooo`030000003oool00000
0080oooo00D000000?ooo`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0oooooP3oool00`000000oooo0?ooo`3o0?oooaD0oooo00<000000?ooo`0000002P3oool00`00
0000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool10?ooo`03
0000003oool000000?l0oooo4`3oool00`000000oooo000000030?ooo`030000003oool0oooo0080
oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooo`D0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`030000003oool0oooo
00H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooo1`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00D0
00000?ooo`3oool0oooo000000080?ooo`030000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooo`T0oooo00@000000?ooo`3oool00000o`3oool<0?ooo`070000
003oool0oooo0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo`h0oooo00<0
00000?ooo`3oool0o`3oool80?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`07
0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3oool@0?ooo`030000003oool0000008`0oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`080?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0oooo503oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooolF0?ooo`030000003oool0oooo0?l0oooo00<000000?ooo`3oool00`3oool02P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`0000070?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooolH0?ooo`040000003oool0oooo00000?`0oooo00L000000?ooo`3oool0
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooad0oooo00<000000?ooo`3oool0n03oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolO0?oo
o`030000003oool0oooo0?H0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000003
0?ooo`050000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0oooo8@3oool00`000000oooo0000003d0?ooo`070000003oool0oooo0?ooo`000000oooo
000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooo9@3oool00`000000oooo0?ooo`3`0?ooo`070000003o
ool0oooo0?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolW0?ooo`03
0000003oool000000>h0oooo00D000000?ooo`3oool0oooo000000040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooob`0oooo00<000000?ooo`3oool0j@3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3oool^0?ooo`030000003oool000000>L0oooo00L00000
0?ooo`3oool0oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000001@3oool002P0oooo1@00003o0?ooool0ooooo`3oool`0?ooo`030000003oool0oooo
0><0oooo00<000000?ooo`3oool00`3oool030000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooc@0
oooo00<000000?ooo`000000h@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooolh0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0
N03oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`030000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooocX0
oooo00@000000?ooo`3oool00000gP3oool00`000000oooo000000020?ooo`070000003oool0oooo
0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolo
0?ooo`030000003oool0oooo0=X0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooom10?ooo`030000003oool000000=X0oooo00H000000?ooo`3oool000000?ooo`00000;0?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom50?ooo`030000003oool0oooo0=@0
oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool00`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooA`3oool00`000000
oooo0000003D0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`05
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom<0?ooo`030000003oool0oooo
0<d0oooo00<000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom>0?ooo`030000003o
ool000000</0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomB0?ooo`03
0000003oool0oooo0<L0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomD
0?ooo`030000003oool000000<D0oooo00<000000?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooF03o
ool00`000000oooo0?ooo`330?ooo`060000003oool0oooo0000003oool000000`3oool00`000000
oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomJ0?ooo`040000
003oool0oooo00000;h0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomO
0?ooo`030000003oool000000;X0oooo00<000000?ooo`0000000P3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooomS0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooomU0?ooo`030000003oool000000;@0oooo00<000000?ooo`3oool00P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooomY0?ooo`030000003oool000000;00oooo00<000000?ooo`3oool0103o
ool01`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooooKP3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo00@0oooo
00D000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooom`0?ooo`030000003oool000000:T0oooo00<000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooomd0?ooo`030000003oool000000:D0oooo00<000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooomh0?ooo`030000003oool0oooo09l0oooo00D000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooNP3oool010000000oooo0?ooo`00002L0?ooo`050000
003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooogl0oooo00<000000?ooo`000000VP3oool00`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooon30?ooo`030000003oool0000009H0oooo00<000000?oo
o`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooohL0oooo00<000000?ooo`3oool0TP3oool00`000000
oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooon90?ooo`030000003oool000000900oooo00<000000?oo
o`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon>0?ooo`030000003oool0000008d0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000D0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?oooi80oooo00<000000?ooo`000000S03oool01@000000oooo
0?ooo`3oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooiH0oooo
00D000000?ooo`000000oooo000000230?ooo`0<0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3ooolM0?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo
000000050?ooo`00:03oool500000?l0ooooo`3ooooo0?oooiP0oooo00<000000?ooo`3oool0O`3o
ool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo7@3oool00`000000
oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooad0oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000050?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooool0oooo7`3oool030000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo
7@3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo7@3oool00`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001@3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolM0?ooo`030000003oool000000080
oooo00D000000?ooo`3oool0oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooooo0?oooad0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
ooooo`3ooolM0?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000
oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooad0oooo
00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000005
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooad0oooo00<000000?oo
o`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000050?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooad0oooo00<000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`030000003oool0000000D0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooool0oooo7@3oool00`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oooo0?oooad0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooal0
oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000050?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooal0oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`030000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooool0oooo7`3oool010000000oooo0?ooo`0000030?ooo`050000003oool00000
0?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolO0?oo
o`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000L0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo7`3oool030000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooool0oooo7`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`00
00001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolO0?ooo`0<0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000001@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolO0?ooo`030000003oool0oooo0080oooo00L0
00000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooool0oooo7`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo7`3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000001@3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolO0?ooo`0<0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000001@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooW@3oool00`000000oooo0?ooo`1n0?ooo`0<0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooo`3ooolO0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolO0?oo
o`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000050?ooo`000P3oool4
000000H0oooo0P0000060?ooo`@00000403oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo
0?oooal0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000005
0?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooooo`3ooolO0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000001@3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
ooooo`3ooolO0?ooo`080000003oool0oooo0000003oool000000?ooo`0000090?ooo`0000<0oooo
0000003oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03@3oool700000?l0ooooo`3ooooo0?ooool0oooo6`3oool02P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000070?ooo`0000<0oooo0000003oool00`3oool00`000000
oooo0?ooo`0;0?ooo`@00000403oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooal0
oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000050?ooo`00
00<0oooo0000003oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooal0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000D0oooo00000`3oool0
00000?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo7`3oool00`000000
oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`0000<0oooo0000
003oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooal0oooo00`000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000050?ooo`000P3oool4000000h0
oooo1000000@0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooil0oooo00<000000?ooo`3o
ool0O03oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000D0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo7`3oool030000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooool0oooo7@3oool00`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooooo0?oooad0oooo00<000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3ooolM0?ooo`030000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo7@3oool00`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo7@3oool00`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?oooj40oooo00<000000?ooo`3oool0N03oool00`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo7@3oool00`000000oooo000000020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooo`3ooolM0?ooo`030000003oool000000080oooo00<000000?ooo`00
00000`3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooooo0?oooad0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oo
oal0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000050?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooad0oooo00<000000?ooo`00
00000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000050?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooonS0?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolK0?ooo`050000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooool0oooo6`3oool01@000000oooo0000003oool0000000@0oooo
00L000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooool0oooo7@3oool00`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooool0oooo7@3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonU
0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003o
ool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3o
oolM0?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooad0oooo00<00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooad0oooo00<000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooad0oooo00<000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooonW0?ooo`030000003oool0oooo0780oooo00<000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooad0oooo00<000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3ooooo0?oooaT0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo6@3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03o
ool500000?l0ooooo`3ooooo0?ooojL0oooo00<000000?ooo`3oool0K03oool01`000000oooo0?oo
o`3oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooaT0oooo00L00000
0?ooo`3oool0oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo6@3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooaT0oooo
00<000000?ooo`3oool00`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooj/0oooo00<0
00000?ooo`3oool0JP3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooo`3ooolI0?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`030000003oool0000000D0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooool0oooo6@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooon^0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`00
00001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolG0?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?oo
o`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolG0?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon`
0?ooo`030000003oool0oooo06<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo5`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooaL0oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonb0?ooo`030000003oool0oooo0640oooo
00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`00
0000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooaD0
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooo`3ooolE0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?oook@0oooo00<000000?ooo`3oool0G@3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`030000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
ool0oooo5@3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool0
1`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0oooo]P3oool00`000000oooo0?ooo`1K0?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolE0?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo4`3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?oookP0oooo00<000000?ooo`3oool0E`3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0
oooo4`3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooonj0?ooo`030000003oool0oooo05D0oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo
0?oooa<0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooonl0?ooo`030000003oool0oooo05<0oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`030000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooool0oooo4@3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`0<
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000001@3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0oooo_`3oool00`000000oooo0?ooo`1>0?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooooo0?oooa40oooo00D000000?ooo`000000oooo000000030?ooo`07
0000003oool0oooo0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oool40oooo
00<000000?ooo`3oool0C03oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`3o
ool0oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolA0?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000050?ooo`00:03oool500000?l0oooo
o`3ooooo0?oool40oooo00<000000?ooo`3oool0A`3oool030000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3oooo50?ooo`030000003oool0oooo04D0oooo00P000000?ooo`3oool000000?ooo`00
0000oooo000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooo`3oool>0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooolL0
oooo00<000000?ooo`3oool0@`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo
0?ooo``0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo90?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
b`3oool00`000000oooo0?ooo`0o0?ooo`080000003oool0oooo0000003oool000000?ooo`000003
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
ool0oooo2P3oool01@000000oooo0?ooo`3oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooolh0oooo00<000000?ooo`3oool0?03oool01P000000oooo0?ooo`000000oooo000000D0oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooood03o
ool00`000000oooo0?ooo`0j0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooom80
oooo00<000000?ooo`3oool0>03oool020000000oooo0?ooo`000000oooo0000003oool000000`3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo
3P3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo
00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000005
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooD0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool00`3oool030000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oooF0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0oooof03oool00`000000oooo0?ooo`0b0?ooo`0<0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool00`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooomX0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`070?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooom`0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0oooog`3oool00`000000oooo0?ooo`0[0?ooo`0B0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooooQ0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooS
0?ooo`030000003oool0oooo02L0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooonD0oooo00<000000?ooo`3oool08`3oool00`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3ooooW0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03P3oool0
30000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<00000
0?ooo`000000103oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooonT0oooo00<000000?ooo`3oool08@3oool030000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooj`3oool00`000000oooo0?ooo`0O0?ooo`0<0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000`3oool00`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooond0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`0<
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool00`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooo00oooo00<000000?ooo`0000006P3oool0
30000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooood0?ooo`030000003oool0oooo01H0oooo
00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooomP3oool00`000000oooo0?ooo`0D0?oo
o`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool00`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooooP0oooo00<000000?ooo`3oool05@3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolA0?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`030000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0
oooo4@3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000050?ooo`00:03oool5
00000?l0ooooo`3ooooo0?ooool0oooo3`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooonP3oool0
0`000000oooo0?ooo`0C0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooa40oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooool0oooo4@3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo03oool0
0`000000oooo0?ooo`0A0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooo`030000003oool0
oooo00h0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo3P3oool030000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooooo0?ooo`80oooo00<000000?ooo`3oool02@3oool030000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooo`@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000005
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooo`H0oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3oool80?ooo`030000003oool0oooo00<0oooo00`000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000030?ooo`030000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooooo`3oool>0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?oo
o`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool:0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool<0?oo
o`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo3P3oool03000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooa40oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooool0oooo4@3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolC0?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooo`3ooolE0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo5`3oool00`000000oooo000000030?ooo`03
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolI0?ooo`070000003oool0
oooo0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo6@3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooa/0
oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo7@3o
ool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo7`3oool030000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000D0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo8P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oo
ob80oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolT0?ooo`070000003oool000000?ooo`000000
oooo000000050?ooo`004`3oool7000000h0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3ooolV0?ooo`050000003oool000000?ooo`0000001@3oool001H0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooobP0oooo00<000000?ooo`000000
1@3oool001H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oooo0?ooobX0oooo00<000000?ooo`3oool00`3oool001H0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooobX0oooo00<000000?ooo`3oool00`3oool0
01H0oooo00<000000?ooo`3oool03`3oool700000?l0ooooo`3ooooo0?ooool0oooo;03oool001H0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00
oooo000F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3oool`0?ooo`00503oool300000140oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3o
ool`0?ooo`005P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo
0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo003o0?ooool0
ooooo`3ooooo0?oooe/0oooo003o0?ooool0ooooo`3ooooo0?oooe/0oooo003o0?ooool0ooooo`3o
oooo0?oooe/0oooo003o0?ooool0ooooo`3ooooo0?oooe/0oooo003o0?ooool0ooooo`3ooooo0?oo
oe/0oooo003o0?ooool0ooooo`3ooooo0?oooe/0oooo003o0?ooool0ooooo`3ooooo0?oooe/0oooo
003o0?ooool0ooooo`3ooooo0?oooe/0oooo0000\
\>"],
  ImageRangeCache->{{{0, 1110.13}, {685.688, 0}} -> {-0.0378501, -0.0556486, \
0.00140806, 0.00239217}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BifuractionDiagram[ShiftMap[r], \ {r, 0, 1}];\)\)], "Input",
  CellLabel->"In[53]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.0147151 0.591362 [
[.2 .00222 -9 -9 ]
[.2 .00222 9 0 ]
[.4 .00222 -9 -9 ]
[.4 .00222 9 0 ]
[.6 .00222 -9 -9 ]
[.6 .00222 9 0 ]
[.8 .00222 -9 -9 ]
[.8 .00222 9 0 ]
[1 .00222 -3 -9 ]
[1 .00222 3 0 ]
[-0.0125 .13299 -18 -4.5 ]
[-0.0125 .13299 0 4.5 ]
[-0.0125 .25126 -18 -4.5 ]
[-0.0125 .25126 0 4.5 ]
[-0.0125 .36953 -18 -4.5 ]
[-0.0125 .36953 0 4.5 ]
[-0.0125 .4878 -18 -4.5 ]
[-0.0125 .4878 0 4.5 ]
[-0.0125 .60608 -6 -4.5 ]
[-0.0125 .60608 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .01472 m
.2 .02097 L
s
[(0.2)] .2 .00222 0 1 Mshowa
.4 .01472 m
.4 .02097 L
s
[(0.4)] .4 .00222 0 1 Mshowa
.6 .01472 m
.6 .02097 L
s
[(0.6)] .6 .00222 0 1 Mshowa
.8 .01472 m
.8 .02097 L
s
[(0.8)] .8 .00222 0 1 Mshowa
1 .01472 m
1 .02097 L
s
[(1)] 1 .00222 0 1 Mshowa
.125 Mabswid
.05 .01472 m
.05 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.15 .01472 m
.15 .01847 L
s
.25 .01472 m
.25 .01847 L
s
.3 .01472 m
.3 .01847 L
s
.35 .01472 m
.35 .01847 L
s
.45 .01472 m
.45 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.55 .01472 m
.55 .01847 L
s
.65 .01472 m
.65 .01847 L
s
.7 .01472 m
.7 .01847 L
s
.75 .01472 m
.75 .01847 L
s
.85 .01472 m
.85 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.95 .01472 m
.95 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
0 .13299 m
.00625 .13299 L
s
[(0.2)] -0.0125 .13299 1 0 Mshowa
0 .25126 m
.00625 .25126 L
s
[(0.4)] -0.0125 .25126 1 0 Mshowa
0 .36953 m
.00625 .36953 L
s
[(0.6)] -0.0125 .36953 1 0 Mshowa
0 .4878 m
.00625 .4878 L
s
[(0.8)] -0.0125 .4878 1 0 Mshowa
0 .60608 m
.00625 .60608 L
s
[(1)] -0.0125 .60608 1 0 Mshowa
.125 Mabswid
0 .04428 m
.00375 .04428 L
s
0 .07385 m
.00375 .07385 L
s
0 .10342 m
.00375 .10342 L
s
0 .16256 m
.00375 .16256 L
s
0 .19212 m
.00375 .19212 L
s
0 .22169 m
.00375 .22169 L
s
0 .28083 m
.00375 .28083 L
s
0 .3104 m
.00375 .3104 L
s
0 .33996 m
.00375 .33996 L
s
0 .3991 m
.00375 .3991 L
s
0 .42867 m
.00375 .42867 L
s
0 .45824 m
.00375 .45824 L
s
0 .51737 m
.00375 .51737 L
s
0 .54694 m
.00375 .54694 L
s
0 .57651 m
.00375 .57651 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
0 .01472 Mdot
.002 .01472 Mdot
.004 .01472 Mdot
.006 .01472 Mdot
.008 .01472 Mdot
.01 .01472 Mdot
.012 .01472 Mdot
.014 .01472 Mdot
.016 .01472 Mdot
.018 .01472 Mdot
.02 .01472 Mdot
.022 .01472 Mdot
.024 .01472 Mdot
.026 .01472 Mdot
.028 .01472 Mdot
.03 .01472 Mdot
.032 .01472 Mdot
.034 .01472 Mdot
.036 .01472 Mdot
.038 .01472 Mdot
.04 .01472 Mdot
.042 .01472 Mdot
.044 .01472 Mdot
.046 .01472 Mdot
.048 .01472 Mdot
.05 .01472 Mdot
.052 .01472 Mdot
.054 .01472 Mdot
.056 .01472 Mdot
.058 .01472 Mdot
.06 .01472 Mdot
.062 .01472 Mdot
.064 .01472 Mdot
.066 .01472 Mdot
.068 .01472 Mdot
.07 .01472 Mdot
.072 .01472 Mdot
.074 .01472 Mdot
.076 .01472 Mdot
.078 .01472 Mdot
.08 .01472 Mdot
.082 .01472 Mdot
.084 .01472 Mdot
.086 .01472 Mdot
.088 .01472 Mdot
.09 .01472 Mdot
.092 .01472 Mdot
.094 .01472 Mdot
.096 .01472 Mdot
.098 .01472 Mdot
.1 .01472 Mdot
.102 .01472 Mdot
.104 .01472 Mdot
.106 .01472 Mdot
.108 .01472 Mdot
.11 .01472 Mdot
.112 .01472 Mdot
.114 .01472 Mdot
.116 .01472 Mdot
.118 .01472 Mdot
.12 .01472 Mdot
.122 .01472 Mdot
.124 .01472 Mdot
.126 .01472 Mdot
.128 .01472 Mdot
.13 .01472 Mdot
.132 .01472 Mdot
.134 .01472 Mdot
.136 .01472 Mdot
.138 .01472 Mdot
.14 .01472 Mdot
.142 .01472 Mdot
.144 .01472 Mdot
.146 .01472 Mdot
.148 .01472 Mdot
.15 .01472 Mdot
.152 .01472 Mdot
.154 .01472 Mdot
.156 .01472 Mdot
.158 .01472 Mdot
.16 .01472 Mdot
.162 .01472 Mdot
.164 .01472 Mdot
.166 .01472 Mdot
.168 .01472 Mdot
.17 .01472 Mdot
.172 .01472 Mdot
.174 .01472 Mdot
.176 .01472 Mdot
.178 .01472 Mdot
.18 .01472 Mdot
.182 .01472 Mdot
.184 .01472 Mdot
.186 .01472 Mdot
.188 .01472 Mdot
.19 .01472 Mdot
.192 .01472 Mdot
.194 .01472 Mdot
.196 .01472 Mdot
.198 .01472 Mdot
.2 .01472 Mdot
.202 .01472 Mdot
.204 .01472 Mdot
.206 .01472 Mdot
.208 .01472 Mdot
.21 .01472 Mdot
.212 .01472 Mdot
.214 .01472 Mdot
.216 .01472 Mdot
.218 .01472 Mdot
.22 .01472 Mdot
.222 .01472 Mdot
.224 .01472 Mdot
.226 .01472 Mdot
.228 .01472 Mdot
.23 .01472 Mdot
.232 .01472 Mdot
.234 .01472 Mdot
.236 .01472 Mdot
.238 .01472 Mdot
.24 .01472 Mdot
.242 .01472 Mdot
.244 .01472 Mdot
.246 .01472 Mdot
.248 .01472 Mdot
.25 .01472 Mdot
.252 .01472 Mdot
.254 .01472 Mdot
.256 .01472 Mdot
.258 .01472 Mdot
.26 .01472 Mdot
.262 .01472 Mdot
.264 .01472 Mdot
.266 .01472 Mdot
.268 .01472 Mdot
.27 .01472 Mdot
.272 .01472 Mdot
.274 .01472 Mdot
.276 .01472 Mdot
.278 .01472 Mdot
.28 .01472 Mdot
.282 .01472 Mdot
.284 .01472 Mdot
.286 .01472 Mdot
.288 .01472 Mdot
.29 .01472 Mdot
.292 .01472 Mdot
.294 .01472 Mdot
.296 .01472 Mdot
.298 .01472 Mdot
.3 .01472 Mdot
.302 .01472 Mdot
.304 .01472 Mdot
.306 .01472 Mdot
.308 .01472 Mdot
.31 .01472 Mdot
.312 .01472 Mdot
.314 .01472 Mdot
.316 .01472 Mdot
.318 .01472 Mdot
.32 .01472 Mdot
.322 .01472 Mdot
.324 .01472 Mdot
.326 .01472 Mdot
.328 .01472 Mdot
.33 .01472 Mdot
.332 .01472 Mdot
.334 .01472 Mdot
.336 .01472 Mdot
.338 .01472 Mdot
.34 .01472 Mdot
.342 .01472 Mdot
.344 .01472 Mdot
.346 .01472 Mdot
.348 .01472 Mdot
.35 .01472 Mdot
.352 .01472 Mdot
.354 .01472 Mdot
.356 .01472 Mdot
.358 .01472 Mdot
.36 .01472 Mdot
.362 .01472 Mdot
.364 .01472 Mdot
.366 .01472 Mdot
.368 .01472 Mdot
.37 .01472 Mdot
.372 .01472 Mdot
.374 .01472 Mdot
.376 .01472 Mdot
.378 .01472 Mdot
.38 .01472 Mdot
.382 .01472 Mdot
.384 .01472 Mdot
.386 .01472 Mdot
.388 .01472 Mdot
.39 .01472 Mdot
.392 .01472 Mdot
.394 .01472 Mdot
.396 .01472 Mdot
.398 .01472 Mdot
.4 .01472 Mdot
.402 .01472 Mdot
.404 .01472 Mdot
.406 .01472 Mdot
.408 .01472 Mdot
.41 .01472 Mdot
.412 .01472 Mdot
.414 .01472 Mdot
.416 .01472 Mdot
.418 .01472 Mdot
.42 .01472 Mdot
.422 .01472 Mdot
.424 .01472 Mdot
.426 .01472 Mdot
.428 .01472 Mdot
.43 .01472 Mdot
.432 .01472 Mdot
.434 .01472 Mdot
.436 .01472 Mdot
.438 .01472 Mdot
.44 .01472 Mdot
.442 .01472 Mdot
.444 .01472 Mdot
.446 .01472 Mdot
.448 .01472 Mdot
.45 .01472 Mdot
.452 .01472 Mdot
.454 .01472 Mdot
.456 .01472 Mdot
.458 .01472 Mdot
.46 .01472 Mdot
.462 .01472 Mdot
.464 .01472 Mdot
.466 .01472 Mdot
.468 .01472 Mdot
.47 .01472 Mdot
.472 .01472 Mdot
.474 .01472 Mdot
.476 .01472 Mdot
.478 .01472 Mdot
.48 .01472 Mdot
.482 .01472 Mdot
.484 .01472 Mdot
.486 .01472 Mdot
.488 .01472 Mdot
.49 .01472 Mdot
.492 .01472 Mdot
.494 .01472 Mdot
.496 .01472 Mdot
.498 .01472 Mdot
.5 .20295 Mdot
.502 .01952 Mdot
.502 .01954 Mdot
.502 .01956 Mdot
.502 .01958 Mdot
.502 .0196 Mdot
.502 .01962 Mdot
.502 .01964 Mdot
.502 .01966 Mdot
.502 .01968 Mdot
.502 .0197 Mdot
.502 .01972 Mdot
.502 .01974 Mdot
.502 .01976 Mdot
.502 .01978 Mdot
.502 .0198 Mdot
.502 .01982 Mdot
.502 .01984 Mdot
.502 .01986 Mdot
.502 .01988 Mdot
.502 .0199 Mdot
.502 .01992 Mdot
.502 .01994 Mdot
.502 .01996 Mdot
.502 .01998 Mdot
.502 .02 Mdot
.502 .02002 Mdot
.502 .02005 Mdot
.502 .02007 Mdot
.502 .02009 Mdot
.502 .02011 Mdot
.502 .02013 Mdot
.502 .02015 Mdot
.502 .02017 Mdot
.502 .0202 Mdot
.502 .02022 Mdot
.502 .02024 Mdot
.502 .02026 Mdot
.502 .02028 Mdot
.502 .02031 Mdot
.502 .02033 Mdot
.502 .02035 Mdot
.502 .02037 Mdot
.502 .0204 Mdot
.502 .02042 Mdot
.502 .02044 Mdot
.502 .02047 Mdot
.502 .02049 Mdot
.502 .02051 Mdot
.502 .02053 Mdot
.502 .02056 Mdot
.502 .02058 Mdot
.502 .0206 Mdot
.502 .02063 Mdot
.502 .02065 Mdot
.502 .02068 Mdot
.502 .0207 Mdot
.502 .02072 Mdot
.502 .02075 Mdot
.502 .02077 Mdot
.502 .0208 Mdot
.502 .02082 Mdot
.502 .02084 Mdot
.502 .02087 Mdot
.502 .02089 Mdot
.502 .02092 Mdot
.502 .02094 Mdot
.502 .02097 Mdot
.502 .02099 Mdot
.502 .02102 Mdot
.502 .02104 Mdot
.502 .02107 Mdot
.502 .02109 Mdot
.502 .02112 Mdot
.502 .02115 Mdot
.502 .02117 Mdot
.502 .0212 Mdot
.502 .02122 Mdot
.502 .02125 Mdot
.502 .02127 Mdot
.502 .0213 Mdot
.502 .02133 Mdot
.502 .02135 Mdot
.502 .02138 Mdot
.502 .02141 Mdot
.502 .02143 Mdot
.502 .02146 Mdot
.502 .02149 Mdot
.502 .02151 Mdot
.502 .02154 Mdot
.502 .02157 Mdot
.502 .0216 Mdot
.502 .02162 Mdot
.502 .02165 Mdot
.502 .02168 Mdot
.502 .02171 Mdot
.502 .02174 Mdot
.502 .02176 Mdot
.502 .02179 Mdot
.502 .02182 Mdot
.502 .02185 Mdot
.502 .02188 Mdot
.502 .02191 Mdot
.502 .02193 Mdot
.502 .02196 Mdot
.502 .02199 Mdot
.502 .02202 Mdot
.502 .02205 Mdot
.502 .02208 Mdot
.502 .02211 Mdot
.502 .02214 Mdot
.502 .02217 Mdot
.502 .0222 Mdot
.502 .02223 Mdot
.502 .02226 Mdot
.502 .02229 Mdot
.502 .02232 Mdot
.502 .02235 Mdot
.502 .02238 Mdot
.502 .02241 Mdot
.502 .02244 Mdot
.502 .02247 Mdot
.502 .0225 Mdot
.502 .02253 Mdot
.502 .02257 Mdot
.502 .0226 Mdot
.502 .02263 Mdot
.502 .02266 Mdot
.502 .02269 Mdot
.502 .02272 Mdot
.502 .02276 Mdot
.502 .02279 Mdot
.502 .02282 Mdot
.502 .02285 Mdot
.502 .02289 Mdot
.502 .02292 Mdot
.502 .02295 Mdot
.502 .02298 Mdot
.502 .02302 Mdot
.502 .02305 Mdot
.502 .02308 Mdot
.502 .02312 Mdot
.502 .02315 Mdot
.502 .02318 Mdot
.502 .02322 Mdot
.502 .02325 Mdot
.502 .02329 Mdot
.502 .02332 Mdot
.502 .02335 Mdot
.502 .02339 Mdot
.502 .02342 Mdot
.502 .02346 Mdot
.502 .02349 Mdot
.502 .02353 Mdot
.502 .02356 Mdot
.502 .0236 Mdot
.502 .02364 Mdot
.502 .02367 Mdot
.502 .02371 Mdot
.502 .02374 Mdot
.502 .02378 Mdot
.502 .02382 Mdot
.502 .02385 Mdot
.502 .02389 Mdot
.502 .02392 Mdot
.502 .02396 Mdot
.502 .024 Mdot
.502 .02404 Mdot
.502 .02407 Mdot
.502 .02411 Mdot
.502 .02415 Mdot
.502 .02419 Mdot
.502 .02422 Mdot
.502 .02426 Mdot
.502 .0243 Mdot
.502 .02434 Mdot
.502 .02438 Mdot
.502 .02442 Mdot
.502 .02445 Mdot
.502 .02449 Mdot
.502 .02453 Mdot
.502 .02457 Mdot
.502 .02461 Mdot
.502 .02465 Mdot
.502 .02469 Mdot
.502 .02473 Mdot
.502 .02477 Mdot
.502 .02481 Mdot
.502 .02485 Mdot
.502 .02489 Mdot
.502 .02493 Mdot
.502 .02497 Mdot
.502 .02501 Mdot
.502 .02506 Mdot
.502 .0251 Mdot
.502 .02514 Mdot
.502 .02518 Mdot
.502 .02522 Mdot
.502 .02526 Mdot
.502 .02531 Mdot
.502 .02535 Mdot
.502 .02539 Mdot
.502 .02543 Mdot
.502 .02548 Mdot
.502 .02552 Mdot
.502 .02556 Mdot
.502 .02561 Mdot
.502 .02565 Mdot
.502 .02569 Mdot
.502 .02574 Mdot
.502 .02578 Mdot
.502 .02583 Mdot
.502 .02587 Mdot
.502 .02591 Mdot
.502 .02596 Mdot
.502 .026 Mdot
.502 .02605 Mdot
.502 .02609 Mdot
.502 .02614 Mdot
.502 .02619 Mdot
.502 .02623 Mdot
.502 .02628 Mdot
.502 .02632 Mdot
.502 .02637 Mdot
.502 .02642 Mdot
.502 .02646 Mdot
.502 .02651 Mdot
.502 .02656 Mdot
.502 .02661 Mdot
.502 .02665 Mdot
.502 .0267 Mdot
.502 .02675 Mdot
.502 .0268 Mdot
.502 .02685 Mdot
.502 .02689 Mdot
.502 .02694 Mdot
.502 .02699 Mdot
.502 .02704 Mdot
.502 .02709 Mdot
.502 .02714 Mdot
.502 .02719 Mdot
.502 .02724 Mdot
.502 .02729 Mdot
.502 .02734 Mdot
.502 .02739 Mdot
.502 .02744 Mdot
.502 .02749 Mdot
.502 .02754 Mdot
.502 .02759 Mdot
.502 .02765 Mdot
.502 .0277 Mdot
.502 .02775 Mdot
.502 .0278 Mdot
.502 .02785 Mdot
.502 .02791 Mdot
.502 .02796 Mdot
.502 .02801 Mdot
.502 .02807 Mdot
.502 .02812 Mdot
.502 .02817 Mdot
.502 .02823 Mdot
.502 .02828 Mdot
.502 .02833 Mdot
.502 .02839 Mdot
.502 .02844 Mdot
.502 .0285 Mdot
.502 .02855 Mdot
.502 .02861 Mdot
.502 .02866 Mdot
.502 .02872 Mdot
.502 .02878 Mdot
.502 .02883 Mdot
.502 .02889 Mdot
.502 .02895 Mdot
.502 .029 Mdot
.502 .02906 Mdot
.502 .02912 Mdot
.502 .02917 Mdot
.502 .02923 Mdot
.502 .02929 Mdot
.502 .02935 Mdot
.502 .02941 Mdot
.502 .02947 Mdot
.502 .02953 Mdot
.502 .02958 Mdot
.502 .02964 Mdot
.502 .0297 Mdot
.502 .02976 Mdot
.502 .02982 Mdot
.502 .02988 Mdot
.502 .02994 Mdot
.502 .03001 Mdot
.502 .03007 Mdot
.502 .03013 Mdot
.502 .03019 Mdot
.502 .03025 Mdot
.502 .03031 Mdot
.502 .03038 Mdot
.502 .03044 Mdot
.502 .0305 Mdot
.502 .03057 Mdot
.502 .03063 Mdot
.502 .03069 Mdot
.502 .03076 Mdot
.502 .03082 Mdot
.502 .03088 Mdot
.502 .03095 Mdot
.502 .03101 Mdot
.502 .03108 Mdot
.502 .03114 Mdot
.502 .03121 Mdot
.502 .03128 Mdot
.502 .03134 Mdot
.502 .03141 Mdot
.502 .03148 Mdot
.502 .03154 Mdot
.502 .03161 Mdot
.502 .03168 Mdot
.502 .03175 Mdot
.502 .03181 Mdot
.502 .03188 Mdot
.502 .03195 Mdot
.502 .03202 Mdot
.502 .03209 Mdot
.502 .03216 Mdot
.502 .03223 Mdot
.502 .0323 Mdot
.502 .03237 Mdot
.502 .03244 Mdot
.502 .03251 Mdot
.502 .03258 Mdot
.502 .03265 Mdot
.502 .03272 Mdot
.502 .0328 Mdot
.502 .03287 Mdot
.502 .03294 Mdot
.502 .03301 Mdot
.502 .03309 Mdot
.502 .03316 Mdot
.502 .03324 Mdot
.502 .03331 Mdot
.502 .03338 Mdot
.502 .03346 Mdot
.502 .03353 Mdot
.502 .03361 Mdot
.502 .03368 Mdot
.502 .03376 Mdot
.502 .03384 Mdot
.502 .03391 Mdot
.502 .03399 Mdot
.502 .03407 Mdot
.502 .03414 Mdot
.502 .03422 Mdot
.502 .0343 Mdot
.502 .03438 Mdot
.502 .03446 Mdot
.502 .03454 Mdot
.502 .03462 Mdot
.502 .03469 Mdot
.502 .03477 Mdot
.502 .03485 Mdot
.502 .03494 Mdot
.502 .03502 Mdot
.502 .0351 Mdot
.502 .03518 Mdot
.502 .03526 Mdot
.502 .03534 Mdot
.502 .03543 Mdot
.502 .03551 Mdot
.502 .03559 Mdot
.502 .03568 Mdot
.502 .03576 Mdot
.502 .03584 Mdot
.502 .03593 Mdot
.502 .03601 Mdot
.502 .0361 Mdot
.502 .03618 Mdot
.502 .03627 Mdot
.502 .03636 Mdot
.502 .03644 Mdot
.502 .03653 Mdot
.502 .03662 Mdot
.502 .0367 Mdot
.502 .03679 Mdot
.502 .03688 Mdot
.502 .03697 Mdot
.502 .03706 Mdot
.502 .03715 Mdot
.502 .03724 Mdot
.502 .03733 Mdot
.502 .03742 Mdot
.502 .03751 Mdot
.502 .0376 Mdot
.502 .03769 Mdot
.502 .03778 Mdot
.502 .03787 Mdot
.502 .03797 Mdot
.502 .03806 Mdot
.502 .03815 Mdot
.502 .03825 Mdot
.502 .03834 Mdot
.502 .03844 Mdot
.502 .03853 Mdot
.502 .03863 Mdot
.502 .03872 Mdot
.502 .03882 Mdot
.502 .03891 Mdot
.502 .03901 Mdot
.502 .03911 Mdot
.502 .03921 Mdot
.502 .0393 Mdot
.502 .0394 Mdot
.502 .0395 Mdot
.502 .0396 Mdot
.502 .0397 Mdot
.502 .0398 Mdot
.502 .0399 Mdot
.502 .04 Mdot
.502 .0401 Mdot
.502 .0402 Mdot
.502 .04031 Mdot
.502 .04041 Mdot
.502 .04051 Mdot
.502 .04061 Mdot
.502 .04072 Mdot
.502 .04082 Mdot
.502 .04093 Mdot
.502 .04103 Mdot
.502 .04114 Mdot
.502 .04124 Mdot
.502 .04135 Mdot
.502 .04145 Mdot
.502 .04156 Mdot
.502 .04167 Mdot
.502 .04178 Mdot
.502 .04188 Mdot
.502 .04199 Mdot
.502 .0421 Mdot
.502 .04221 Mdot
.502 .04232 Mdot
.502 .04243 Mdot
.502 .04254 Mdot
.502 .04265 Mdot
.502 .04277 Mdot
.502 .04288 Mdot
.502 .04299 Mdot
.502 .0431 Mdot
.502 .04322 Mdot
.502 .04333 Mdot
.502 .04345 Mdot
.502 .04356 Mdot
.502 .04368 Mdot
.502 .04379 Mdot
.502 .04391 Mdot
.502 .04403 Mdot
.502 .04414 Mdot
.502 .04426 Mdot
.502 .04438 Mdot
.502 .0445 Mdot
.502 .04462 Mdot
.502 .04474 Mdot
.502 .04486 Mdot
.502 .04498 Mdot
.502 .0451 Mdot
.502 .04522 Mdot
.502 .04534 Mdot
.502 .04546 Mdot
.502 .04559 Mdot
.502 .04571 Mdot
.502 .04583 Mdot
.502 .04596 Mdot
.502 .04608 Mdot
.502 .04621 Mdot
.502 .04634 Mdot
.502 .04646 Mdot
.502 .04659 Mdot
.502 .04672 Mdot
.502 .04684 Mdot
.502 .04697 Mdot
.502 .0471 Mdot
.502 .04723 Mdot
.502 .04736 Mdot
.502 .04749 Mdot
.502 .04762 Mdot
.502 .04775 Mdot
.502 .04789 Mdot
.502 .04802 Mdot
.502 .04815 Mdot
.502 .04829 Mdot
.502 .04842 Mdot
.502 .04856 Mdot
.502 .04869 Mdot
.502 .04883 Mdot
.502 .04896 Mdot
.502 .0491 Mdot
.502 .04924 Mdot
.502 .04938 Mdot
.502 .04951 Mdot
.502 .04965 Mdot
.502 .04979 Mdot
.502 .04993 Mdot
.502 .05007 Mdot
.502 .05022 Mdot
.502 .05036 Mdot
.502 .0505 Mdot
.502 .05064 Mdot
.502 .05079 Mdot
.502 .05093 Mdot
.502 .05108 Mdot
.502 .05122 Mdot
.502 .05137 Mdot
.502 .05151 Mdot
.502 .05166 Mdot
.502 .05181 Mdot
.502 .05196 Mdot
.502 .05211 Mdot
.502 .05226 Mdot
.502 .05241 Mdot
.502 .05256 Mdot
.502 .05271 Mdot
.502 .05286 Mdot
.502 .05301 Mdot
.502 .05317 Mdot
.502 .05332 Mdot
.502 .05347 Mdot
.502 .05363 Mdot
.502 .05379 Mdot
.502 .05394 Mdot
.502 .0541 Mdot
.502 .05426 Mdot
.502 .05441 Mdot
.502 .05457 Mdot
.502 .05473 Mdot
.502 .05489 Mdot
.502 .05505 Mdot
.502 .05521 Mdot
.502 .05538 Mdot
.502 .05554 Mdot
.502 .0557 Mdot
.502 .05587 Mdot
.502 .05603 Mdot
.502 .0562 Mdot
.502 .05636 Mdot
.502 .05653 Mdot
.502 .0567 Mdot
.502 .05686 Mdot
.502 .05703 Mdot
.502 .0572 Mdot
.502 .05737 Mdot
.502 .05754 Mdot
.502 .05771 Mdot
.502 .05789 Mdot
.502 .05806 Mdot
.502 .05823 Mdot
.502 .05841 Mdot
.502 .05858 Mdot
.502 .05876 Mdot
.502 .05893 Mdot
.502 .05911 Mdot
.502 .05929 Mdot
.502 .05947 Mdot
.502 .05964 Mdot
.502 .05982 Mdot
.502 .06 Mdot
.502 .06019 Mdot
.502 .06037 Mdot
.502 .06055 Mdot
.502 .06073 Mdot
.502 .06092 Mdot
.502 .0611 Mdot
.502 .06129 Mdot
.502 .06147 Mdot
.502 .06166 Mdot
.502 .06185 Mdot
.502 .06204 Mdot
.502 .06223 Mdot
.502 .06242 Mdot
.502 .06261 Mdot
.502 .0628 Mdot
.502 .06299 Mdot
.502 .06318 Mdot
.502 .06338 Mdot
.502 .06357 Mdot
.502 .06377 Mdot
.502 .06396 Mdot
.502 .06416 Mdot
.502 .06436 Mdot
.502 .06456 Mdot
.502 .06476 Mdot
.502 .06496 Mdot
.502 .06516 Mdot
.502 .06536 Mdot
.502 .06556 Mdot
.502 .06577 Mdot
.502 .06597 Mdot
.502 .06618 Mdot
.502 .06638 Mdot
.502 .06659 Mdot
.502 .0668 Mdot
.502 .067 Mdot
.502 .06721 Mdot
.502 .06742 Mdot
.502 .06763 Mdot
.502 .06785 Mdot
.502 .06806 Mdot
.502 .06827 Mdot
.502 .06849 Mdot
.502 .0687 Mdot
.502 .06892 Mdot
.502 .06913 Mdot
.502 .06935 Mdot
.502 .06957 Mdot
.502 .06979 Mdot
.502 .07001 Mdot
.502 .07023 Mdot
.502 .07045 Mdot
.502 .07068 Mdot
.502 .0709 Mdot
.502 .07112 Mdot
.502 .07135 Mdot
.502 .07158 Mdot
.502 .0718 Mdot
.502 .07203 Mdot
.502 .07226 Mdot
.502 .07249 Mdot
.502 .07272 Mdot
.502 .07296 Mdot
.502 .07319 Mdot
.502 .07342 Mdot
.502 .07366 Mdot
.502 .07389 Mdot
.502 .07413 Mdot
.502 .07437 Mdot
.502 .07461 Mdot
.502 .07485 Mdot
.502 .07509 Mdot
.502 .07533 Mdot
.502 .07557 Mdot
.502 .07581 Mdot
.502 .07606 Mdot
.502 .0763 Mdot
.502 .07655 Mdot
.502 .0768 Mdot
.502 .07704 Mdot
.502 .07729 Mdot
.502 .07754 Mdot
.502 .0778 Mdot
.502 .07805 Mdot
.502 .0783 Mdot
.502 .07856 Mdot
.502 .07881 Mdot
.502 .07907 Mdot
.502 .07932 Mdot
.502 .07958 Mdot
.502 .07984 Mdot
.502 .0801 Mdot
.502 .08036 Mdot
.502 .08063 Mdot
.502 .08089 Mdot
.502 .08116 Mdot
.502 .08142 Mdot
.502 .08169 Mdot
.502 .08196 Mdot
.502 .08223 Mdot
.502 .0825 Mdot
.502 .08277 Mdot
.502 .08304 Mdot
.502 .08331 Mdot
.502 .08359 Mdot
.502 .08386 Mdot
.502 .08414 Mdot
.502 .08442 Mdot
.502 .08469 Mdot
.502 .08497 Mdot
.502 .08526 Mdot
.502 .08554 Mdot
.502 .08582 Mdot
.502 .08611 Mdot
.502 .08639 Mdot
.502 .08668 Mdot
.502 .08697 Mdot
.502 .08725 Mdot
.502 .08754 Mdot
.502 .08784 Mdot
.502 .08813 Mdot
.502 .08842 Mdot
.502 .08872 Mdot
.502 .08901 Mdot
.502 .08931 Mdot
.502 .08961 Mdot
.502 .08991 Mdot
.502 .09021 Mdot
.502 .09051 Mdot
.502 .09081 Mdot
.502 .09112 Mdot
.502 .09142 Mdot
.502 .09173 Mdot
.502 .09204 Mdot
.502 .09235 Mdot
.502 .09266 Mdot
.502 .09297 Mdot
.502 .09328 Mdot
.502 .0936 Mdot
.502 .09391 Mdot
.502 .09423 Mdot
.502 .09455 Mdot
.502 .09487 Mdot
.502 .09519 Mdot
.502 .09551 Mdot
.502 .09583 Mdot
.502 .09616 Mdot
.502 .09648 Mdot
.502 .09681 Mdot
.502 .09714 Mdot
.502 .09747 Mdot
.502 .0978 Mdot
.502 .09813 Mdot
.502 .09847 Mdot
.502 .0988 Mdot
.502 .09914 Mdot
.502 .09947 Mdot
.502 .09981 Mdot
.502 .10015 Mdot
.502 .1005 Mdot
.502 .10084 Mdot
.502 .10118 Mdot
.502 .10153 Mdot
.502 .10188 Mdot
.502 .10223 Mdot
.502 .10258 Mdot
.502 .10293 Mdot
.502 .10328 Mdot
.502 .10363 Mdot
.502 .10399 Mdot
.502 .10435 Mdot
.502 .10471 Mdot
.502 .10507 Mdot
.502 .10543 Mdot
.502 .10579 Mdot
.502 .10615 Mdot
.502 .10652 Mdot
.502 .10689 Mdot
.502 .10726 Mdot
.502 .10763 Mdot
.502 .108 Mdot
.502 .10837 Mdot
.502 .10875 Mdot
.502 .10912 Mdot
.502 .1095 Mdot
.502 .10988 Mdot
.502 .11026 Mdot
.502 .11064 Mdot
.502 .11102 Mdot
.502 .11141 Mdot
.502 .1118 Mdot
.502 .11218 Mdot
.502 .11257 Mdot
.502 .11297 Mdot
.502 .11336 Mdot
.502 .11375 Mdot
.502 .11415 Mdot
.502 .11455 Mdot
.502 .11495 Mdot
.502 .11535 Mdot
.502 .11575 Mdot
.502 .11615 Mdot
.502 .11656 Mdot
.502 .11697 Mdot
.502 .11738 Mdot
.502 .11779 Mdot
.502 .1182 Mdot
.502 .11861 Mdot
.502 .11903 Mdot
.502 .11945 Mdot
.502 .11987 Mdot
.502 .12029 Mdot
.502 .12071 Mdot
.502 .12113 Mdot
.502 .12156 Mdot
.502 .12199 Mdot
.502 .12241 Mdot
.502 .12285 Mdot
.502 .12328 Mdot
.502 .12371 Mdot
.502 .12415 Mdot
.502 .12459 Mdot
.502 .12503 Mdot
.502 .12547 Mdot
.502 .12591 Mdot
.502 .12635 Mdot
.502 .1268 Mdot
.502 .12725 Mdot
.502 .1277 Mdot
.502 .12815 Mdot
.502 .1286 Mdot
.502 .12906 Mdot
.502 .12952 Mdot
.502 .12998 Mdot
.502 .13044 Mdot
.502 .1309 Mdot
.502 .13137 Mdot
.502 .13183 Mdot
.502 .1323 Mdot
.502 .13277 Mdot
.502 .13324 Mdot
.502 .13372 Mdot
.502 .13419 Mdot
.502 .13467 Mdot
.502 .13515 Mdot
.502 .13563 Mdot
.502 .13612 Mdot
.502 .1366 Mdot
.502 .13709 Mdot
.502 .13758 Mdot
.502 .13807 Mdot
.502 .13856 Mdot
.502 .13906 Mdot
.502 .13956 Mdot
.502 .14006 Mdot
.502 .14056 Mdot
.502 .14106 Mdot
.502 .14157 Mdot
.502 .14207 Mdot
.502 .14258 Mdot
.502 .14309 Mdot
.502 .14361 Mdot
.502 .14412 Mdot
.502 .14464 Mdot
.502 .14516 Mdot
.502 .14568 Mdot
.502 .14621 Mdot
.502 .14673 Mdot
.502 .14726 Mdot
.502 .14779 Mdot
.502 .14832 Mdot
.502 .14886 Mdot
.502 .14939 Mdot
.502 .14993 Mdot
.502 .15047 Mdot
.502 .15102 Mdot
.502 .15156 Mdot
.502 .15211 Mdot
.502 .15266 Mdot
.502 .15321 Mdot
.502 .15376 Mdot
.502 .15432 Mdot
.502 .15488 Mdot
.502 .15544 Mdot
.502 .156 Mdot
.502 .15657 Mdot
.502 .15714 Mdot
.502 .15771 Mdot
.502 .15828 Mdot
.502 .15885 Mdot
.502 .15943 Mdot
.502 .16001 Mdot
.502 .16059 Mdot
.502 .16117 Mdot
.502 .16176 Mdot
.502 .16235 Mdot
.502 .16294 Mdot
.502 .16353 Mdot
.502 .16412 Mdot
.502 .16472 Mdot
.502 .16532 Mdot
.502 .16592 Mdot
.502 .16653 Mdot
.502 .16714 Mdot
.502 .16775 Mdot
.502 .16836 Mdot
.502 .16897 Mdot
.502 .16959 Mdot
.502 .17021 Mdot
.502 .17083 Mdot
.502 .17146 Mdot
.502 .17208 Mdot
.502 .17271 Mdot
.502 .17334 Mdot
.502 .17398 Mdot
.502 .17462 Mdot
.502 .17526 Mdot
.502 .1759 Mdot
.502 .17654 Mdot
.502 .17719 Mdot
.502 .17784 Mdot
.502 .17849 Mdot
.502 .17915 Mdot
.502 .1798 Mdot
.502 .18047 Mdot
.502 .18113 Mdot
.502 .18179 Mdot
.502 .18246 Mdot
.502 .18313 Mdot
.502 .18381 Mdot
.502 .18448 Mdot
.502 .18516 Mdot
.502 .18584 Mdot
.502 .18653 Mdot
.502 .18722 Mdot
.502 .18791 Mdot
.502 .1886 Mdot
.502 .18929 Mdot
.502 .18999 Mdot
.502 .19069 Mdot
.502 .1914 Mdot
.502 .1921 Mdot
.502 .19281 Mdot
.502 .19353 Mdot
.502 .19424 Mdot
.502 .19496 Mdot
.502 .19568 Mdot
.502 .1964 Mdot
.502 .19713 Mdot
.502 .19786 Mdot
.502 .19859 Mdot
.502 .19933 Mdot
.502 .20007 Mdot
.502 .20081 Mdot
.502 .20155 Mdot
.502 .2023 Mdot
.502 .20305 Mdot
.502 .2038 Mdot
.502 .20456 Mdot
.502 .20532 Mdot
.502 .20608 Mdot
.502 .20685 Mdot
.502 .20762 Mdot
.502 .20839 Mdot
.502 .20916 Mdot
.502 .20994 Mdot
.502 .21072 Mdot
.502 .21151 Mdot
.502 .21229 Mdot
.502 .21308 Mdot
.502 .21388 Mdot
.502 .21467 Mdot
.502 .21547 Mdot
.502 .21628 Mdot
.502 .21708 Mdot
.502 .21789 Mdot
.502 .2187 Mdot
.502 .21952 Mdot
.502 .22034 Mdot
.502 .22116 Mdot
.502 .22199 Mdot
.502 .22282 Mdot
.502 .22365 Mdot
.502 .22448 Mdot
.502 .22532 Mdot
.502 .22617 Mdot
.502 .22701 Mdot
.502 .22786 Mdot
.502 .22871 Mdot
.502 .22957 Mdot
.502 .23043 Mdot
.502 .23129 Mdot
.502 .23216 Mdot
.502 .23303 Mdot
.502 .2339 Mdot
.502 .23478 Mdot
.502 .23566 Mdot
.502 .23654 Mdot
.502 .23743 Mdot
.502 .23832 Mdot
.502 .23922 Mdot
.502 .24011 Mdot
.502 .24101 Mdot
.502 .24192 Mdot
.502 .24283 Mdot
.502 .24374 Mdot
.502 .24466 Mdot
.502 .24558 Mdot
.502 .2465 Mdot
.502 .24743 Mdot
.502 .24836 Mdot
.502 .24929 Mdot
.502 .25023 Mdot
.502 .25117 Mdot
.502 .25212 Mdot
.502 .25307 Mdot
.502 .25402 Mdot
.502 .25498 Mdot
.502 .25594 Mdot
.502 .25691 Mdot
.502 .25787 Mdot
.502 .25885 Mdot
.502 .25982 Mdot
.502 .2608 Mdot
.502 .26179 Mdot
.502 .26278 Mdot
.502 .26377 Mdot
.502 .26476 Mdot
.502 .26577 Mdot
.502 .26677 Mdot
.502 .26778 Mdot
.502 .26879 Mdot
.502 .26981 Mdot
.502 .27083 Mdot
.502 .27185 Mdot
.502 .27288 Mdot
.502 .27391 Mdot
.502 .27495 Mdot
.504 .01507 Mdot
.504 .01508 Mdot
.504 .01508 Mdot
.504 .01508 Mdot
.504 .01509 Mdot
.504 .01509 Mdot
.504 .01509 Mdot
.504 .01509 Mdot
.504 .0151 Mdot
.504 .0151 Mdot
.504 .0151 Mdot
.504 .01511 Mdot
.504 .01511 Mdot
.504 .01511 Mdot
.504 .01512 Mdot
.504 .01512 Mdot
.504 .01512 Mdot
.504 .01513 Mdot
.504 .01513 Mdot
.504 .01513 Mdot
.504 .01514 Mdot
.504 .01514 Mdot
.504 .01514 Mdot
.504 .01515 Mdot
.504 .01515 Mdot
.504 .01515 Mdot
.504 .01516 Mdot
.504 .01516 Mdot
.504 .01516 Mdot
.504 .01517 Mdot
.504 .01517 Mdot
.504 .01517 Mdot
.504 .01518 Mdot
.504 .01518 Mdot
.504 .01519 Mdot
.504 .01519 Mdot
.504 .01519 Mdot
.504 .0152 Mdot
.504 .0152 Mdot
.504 .0152 Mdot
.504 .01521 Mdot
.504 .01521 Mdot
.504 .01522 Mdot
.504 .01522 Mdot
.504 .01522 Mdot
.504 .01523 Mdot
.504 .01523 Mdot
.504 .01524 Mdot
.504 .01524 Mdot
.504 .01525 Mdot
.504 .01525 Mdot
.504 .01525 Mdot
.504 .01526 Mdot
.504 .01526 Mdot
.504 .01527 Mdot
.504 .01527 Mdot
.504 .01528 Mdot
.504 .01528 Mdot
.504 .01528 Mdot
.504 .01529 Mdot
.504 .01529 Mdot
.504 .0153 Mdot
.504 .0153 Mdot
.504 .01531 Mdot
.504 .01531 Mdot
.504 .01532 Mdot
.504 .01532 Mdot
.504 .01533 Mdot
.504 .01533 Mdot
.504 .01534 Mdot
.504 .01534 Mdot
.504 .01535 Mdot
.504 .01535 Mdot
.504 .01536 Mdot
.504 .01536 Mdot
.504 .01537 Mdot
.504 .01537 Mdot
.504 .01538 Mdot
.504 .01538 Mdot
.504 .01539 Mdot
.504 .01539 Mdot
.504 .0154 Mdot
.504 .01541 Mdot
.504 .01541 Mdot
.504 .01542 Mdot
.504 .01542 Mdot
.504 .01543 Mdot
.504 .01543 Mdot
.504 .01544 Mdot
.504 .01544 Mdot
.504 .01545 Mdot
.504 .01546 Mdot
.504 .01546 Mdot
.504 .01547 Mdot
.504 .01547 Mdot
.504 .01548 Mdot
.504 .01549 Mdot
.504 .01549 Mdot
.504 .0155 Mdot
.504 .01551 Mdot
.504 .01551 Mdot
.504 .01552 Mdot
.504 .01552 Mdot
.504 .01553 Mdot
.504 .01554 Mdot
.504 .01554 Mdot
.504 .01555 Mdot
.504 .01556 Mdot
.504 .01556 Mdot
.504 .01557 Mdot
.504 .01558 Mdot
.504 .01558 Mdot
.504 .01559 Mdot
.504 .0156 Mdot
.504 .01561 Mdot
.504 .01561 Mdot
.504 .01562 Mdot
.504 .01563 Mdot
.504 .01563 Mdot
.504 .01564 Mdot
.504 .01565 Mdot
.504 .01566 Mdot
.504 .01566 Mdot
.504 .01567 Mdot
.504 .01568 Mdot
.504 .01569 Mdot
.504 .01569 Mdot
.504 .0157 Mdot
.504 .01571 Mdot
.504 .01572 Mdot
.504 .01573 Mdot
.504 .01573 Mdot
.504 .01574 Mdot
.504 .01575 Mdot
.504 .01576 Mdot
.504 .01577 Mdot
.504 .01578 Mdot
.504 .01578 Mdot
.504 .01579 Mdot
.504 .0158 Mdot
.504 .01581 Mdot
.504 .01582 Mdot
.504 .01583 Mdot
.504 .01584 Mdot
.504 .01585 Mdot
.504 .01585 Mdot
.504 .01586 Mdot
.504 .01587 Mdot
.504 .01588 Mdot
.504 .01589 Mdot
.504 .0159 Mdot
.504 .01591 Mdot
.504 .01592 Mdot
.504 .01593 Mdot
.504 .01594 Mdot
.504 .01595 Mdot
.504 .01595 Mdot
.504 .01596 Mdot
.504 .01596 Mdot
.504 .01597 Mdot
.504 .01597 Mdot
.504 .01598 Mdot
.504 .01598 Mdot
.504 .01599 Mdot
.504 .01599 Mdot
.504 .016 Mdot
.504 .016 Mdot
.504 .01601 Mdot
.504 .01601 Mdot
.504 .01602 Mdot
.504 .01602 Mdot
.504 .01603 Mdot
.504 .01603 Mdot
.504 .01604 Mdot
.504 .01604 Mdot
.504 .01605 Mdot
.504 .01605 Mdot
.504 .01606 Mdot
.504 .01606 Mdot
.504 .01607 Mdot
.504 .01607 Mdot
.504 .01608 Mdot
.504 .01608 Mdot
.504 .01609 Mdot
.504 .0161 Mdot
.504 .0161 Mdot
.504 .01611 Mdot
.504 .01611 Mdot
.504 .01612 Mdot
.504 .01613 Mdot
.504 .01613 Mdot
.504 .01614 Mdot
.504 .01614 Mdot
.504 .01615 Mdot
.504 .01615 Mdot
.504 .01616 Mdot
.504 .01616 Mdot
.504 .01617 Mdot
.504 .01617 Mdot
.504 .01618 Mdot
.504 .01619 Mdot
.504 .01619 Mdot
.504 .0162 Mdot
.504 .01621 Mdot
.504 .01621 Mdot
.504 .01622 Mdot
.504 .01622 Mdot
.504 .01623 Mdot
.504 .01623 Mdot
.504 .01624 Mdot
.504 .01625 Mdot
.504 .01625 Mdot
.504 .01626 Mdot
.504 .01627 Mdot
.504 .01627 Mdot
.504 .01628 Mdot
.504 .01628 Mdot
.504 .01629 Mdot
.504 .0163 Mdot
.504 .0163 Mdot
.504 .01631 Mdot
.504 .01632 Mdot
.504 .01632 Mdot
.504 .01633 Mdot
.504 .01633 Mdot
.504 .01634 Mdot
.504 .01635 Mdot
.504 .01636 Mdot
.504 .01636 Mdot
.504 .01637 Mdot
.504 .01637 Mdot
.504 .01638 Mdot
.504 .01639 Mdot
.504 .0164 Mdot
.504 .0164 Mdot
.504 .01641 Mdot
.504 .01641 Mdot
.504 .01642 Mdot
.504 .01643 Mdot
.504 .01644 Mdot
.504 .01644 Mdot
.504 .01645 Mdot
.504 .01645 Mdot
.504 .01646 Mdot
.504 .01647 Mdot
.504 .01648 Mdot
.504 .01648 Mdot
.504 .01649 Mdot
.504 .0165 Mdot
.504 .01651 Mdot
.504 .01651 Mdot
.504 .01652 Mdot
.504 .01652 Mdot
.504 .01654 Mdot
.504 .01654 Mdot
.504 .01655 Mdot
.504 .01655 Mdot
.504 .01656 Mdot
.504 .01657 Mdot
.504 .01658 Mdot
.504 .01658 Mdot
.504 .01659 Mdot
.504 .0166 Mdot
.504 .01661 Mdot
.504 .01661 Mdot
.504 .01662 Mdot
.504 .01663 Mdot
.504 .01664 Mdot
.504 .01664 Mdot
.504 .01665 Mdot
.504 .01666 Mdot
.504 .01667 Mdot
.504 .01667 Mdot
.504 .01669 Mdot
.504 .01669 Mdot
.504 .0167 Mdot
.504 .01671 Mdot
.504 .01672 Mdot
.504 .01672 Mdot
.504 .01673 Mdot
.504 .01674 Mdot
.504 .01675 Mdot
.504 .01675 Mdot
.504 .01677 Mdot
.504 .01677 Mdot
.504 .01678 Mdot
.504 .01679 Mdot
.504 .0168 Mdot
.504 .0168 Mdot
.504 .01682 Mdot
.504 .01682 Mdot
.504 .01683 Mdot
.504 .01684 Mdot
.504 .01685 Mdot
.504 .01685 Mdot
.504 .01687 Mdot
.504 .01687 Mdot
.504 .01688 Mdot
.504 .01689 Mdot
.504 .0169 Mdot
.504 .01691 Mdot
.504 .01692 Mdot
.504 .01692 Mdot
.504 .01694 Mdot
.504 .01694 Mdot
.504 .01695 Mdot
.504 .01696 Mdot
.504 .01697 Mdot
.504 .01698 Mdot
.504 .01699 Mdot
.504 .01699 Mdot
.504 .01701 Mdot
.504 .01701 Mdot
.504 .01703 Mdot
.504 .01703 Mdot
.504 .01705 Mdot
.504 .01705 Mdot
.504 .01706 Mdot
.504 .01707 Mdot
.504 .01708 Mdot
.504 .01709 Mdot
.504 .0171 Mdot
.504 .01711 Mdot
.504 .01712 Mdot
.504 .01713 Mdot
.504 .01714 Mdot
.504 .01714 Mdot
.504 .01716 Mdot
.504 .01716 Mdot
.504 .01718 Mdot
.504 .01718 Mdot
.504 .0172 Mdot
.504 .0172 Mdot
.504 .01722 Mdot
.504 .01722 Mdot
.504 .01724 Mdot
.504 .01724 Mdot
.504 .01726 Mdot
.504 .01726 Mdot
.504 .01728 Mdot
.504 .01728 Mdot
.504 .0173 Mdot
.504 .0173 Mdot
.504 .01732 Mdot
.504 .01733 Mdot
.504 .01734 Mdot
.504 .01735 Mdot
.504 .01736 Mdot
.504 .01737 Mdot
.504 .01738 Mdot
.504 .01739 Mdot
.504 .0174 Mdot
.504 .01741 Mdot
.504 .01743 Mdot
.504 .01743 Mdot
.504 .01745 Mdot
.504 .01745 Mdot
.504 .01747 Mdot
.504 .01748 Mdot
.504 .01749 Mdot
.504 .0175 Mdot
.504 .01751 Mdot
.504 .01752 Mdot
.504 .01754 Mdot
.504 .01754 Mdot
.504 .01756 Mdot
.504 .01756 Mdot
.504 .01758 Mdot
.504 .01759 Mdot
.504 .0176 Mdot
.504 .01761 Mdot
.504 .01763 Mdot
.504 .01763 Mdot
.504 .01765 Mdot
.504 .01766 Mdot
.504 .01767 Mdot
.504 .01768 Mdot
.504 .0177 Mdot
.504 .0177 Mdot
.504 .01772 Mdot
.504 .01773 Mdot
.504 .01775 Mdot
.504 .01775 Mdot
.504 .01777 Mdot
.504 .01778 Mdot
.504 .01779 Mdot
.504 .0178 Mdot
.504 .01782 Mdot
.504 .01783 Mdot
.504 .01784 Mdot
.504 .01785 Mdot
.504 .01787 Mdot
.504 .01788 Mdot
.504 .01789 Mdot
.504 .0179 Mdot
.504 .01792 Mdot
.504 .01793 Mdot
.504 .01795 Mdot
.504 .01795 Mdot
.504 .01797 Mdot
.504 .01798 Mdot
.504 .018 Mdot
.504 .018 Mdot
.504 .01802 Mdot
.504 .01803 Mdot
.504 .01805 Mdot
.504 .01806 Mdot
.504 .01808 Mdot
.504 .01808 Mdot
.504 .0181 Mdot
.504 .01811 Mdot
.504 .01813 Mdot
.504 .01814 Mdot
.504 .01816 Mdot
.504 .01817 Mdot
.504 .01819 Mdot
.504 .01819 Mdot
.504 .01821 Mdot
.504 .01822 Mdot
.504 .01824 Mdot
.504 .01825 Mdot
.504 .01827 Mdot
.504 .01828 Mdot
.504 .0183 Mdot
.504 .01831 Mdot
.504 .01833 Mdot
.504 .01833 Mdot
.504 .01836 Mdot
.504 .01836 Mdot
.504 .01838 Mdot
.504 .01839 Mdot
.504 .01841 Mdot
.504 .01842 Mdot
.504 .01844 Mdot
.504 .01845 Mdot
.504 .01847 Mdot
.504 .01848 Mdot
.504 .0185 Mdot
.504 .01851 Mdot
.504 .01853 Mdot
.504 .01854 Mdot
.504 .01856 Mdot
.504 .01857 Mdot
.504 .01859 Mdot
.504 .0186 Mdot
.504 .01863 Mdot
.504 .01863 Mdot
.504 .01866 Mdot
.504 .01867 Mdot
.504 .01869 Mdot
.504 .0187 Mdot
.504 .01872 Mdot
.504 .01873 Mdot
.504 .01875 Mdot
.504 .01876 Mdot
.504 .01878 Mdot
.504 .01879 Mdot
.504 .01882 Mdot
.504 .01883 Mdot
.504 .01885 Mdot
.504 .01886 Mdot
.504 .01888 Mdot
.504 .01889 Mdot
.504 .01892 Mdot
.504 .01893 Mdot
.504 .01895 Mdot
.504 .01896 Mdot
.504 .01898 Mdot
.504 .01899 Mdot
.504 .01902 Mdot
.504 .01905 Mdot
.504 .01909 Mdot
.504 .01912 Mdot
.504 .01916 Mdot
.504 .01919 Mdot
.504 .01923 Mdot
.504 .01927 Mdot
.504 .0193 Mdot
.504 .01934 Mdot
.504 .01938 Mdot
.504 .01941 Mdot
.504 .01945 Mdot
.504 .01949 Mdot
.504 .01953 Mdot
.504 .01956 Mdot
.504 .0196 Mdot
.504 .01964 Mdot
.504 .01968 Mdot
.504 .01972 Mdot
.504 .01976 Mdot
.504 .0198 Mdot
.504 .01984 Mdot
.504 .01988 Mdot
.504 .01993 Mdot
.504 .01997 Mdot
.504 .02001 Mdot
.504 .02005 Mdot
.504 .02009 Mdot
.504 .02014 Mdot
.504 .02018 Mdot
.504 .02022 Mdot
.504 .02027 Mdot
.504 .02031 Mdot
.504 .02036 Mdot
.504 .0204 Mdot
.504 .02045 Mdot
.504 .02049 Mdot
.504 .02054 Mdot
.504 .02059 Mdot
.504 .02063 Mdot
.504 .02068 Mdot
.504 .02073 Mdot
.504 .02078 Mdot
.504 .02083 Mdot
.504 .02087 Mdot
.504 .02092 Mdot
.504 .02097 Mdot
.504 .02102 Mdot
.504 .02107 Mdot
.504 .02112 Mdot
.504 .02118 Mdot
.504 .02123 Mdot
.504 .02128 Mdot
.504 .02133 Mdot
.504 .02139 Mdot
.504 .02144 Mdot
.504 .02149 Mdot
.504 .02155 Mdot
.504 .0216 Mdot
.504 .02166 Mdot
.504 .02171 Mdot
.504 .02177 Mdot
.504 .02182 Mdot
.504 .02188 Mdot
.504 .02194 Mdot
.504 .022 Mdot
.504 .02205 Mdot
.504 .02211 Mdot
.504 .02217 Mdot
.504 .02223 Mdot
.504 .02229 Mdot
.504 .02235 Mdot
.504 .02241 Mdot
.504 .02248 Mdot
.504 .02254 Mdot
.504 .0226 Mdot
.504 .02266 Mdot
.504 .02273 Mdot
.504 .02279 Mdot
.504 .02286 Mdot
.504 .02292 Mdot
.504 .02299 Mdot
.504 .02305 Mdot
.504 .02312 Mdot
.504 .02319 Mdot
.504 .02325 Mdot
.504 .02332 Mdot
.504 .02339 Mdot
.504 .02346 Mdot
.504 .02353 Mdot
.504 .0236 Mdot
.504 .02367 Mdot
.504 .02374 Mdot
.504 .02382 Mdot
.504 .02389 Mdot
.504 .02396 Mdot
.504 .02404 Mdot
.504 .02411 Mdot
.504 .02419 Mdot
.504 .02426 Mdot
.504 .02434 Mdot
.504 .02442 Mdot
.504 .02449 Mdot
.504 .02457 Mdot
.504 .02465 Mdot
.504 .02473 Mdot
.504 .02481 Mdot
.504 .02489 Mdot
.504 .02497 Mdot
.504 .02505 Mdot
.504 .02514 Mdot
.504 .02522 Mdot
.504 .0253 Mdot
.504 .02539 Mdot
.504 .02547 Mdot
.504 .02556 Mdot
.504 .02565 Mdot
.504 .02573 Mdot
.504 .02582 Mdot
.504 .02591 Mdot
.504 .026 Mdot
.504 .02609 Mdot
.504 .02618 Mdot
.504 .02627 Mdot
.504 .02637 Mdot
.504 .02646 Mdot
.504 .02655 Mdot
.504 .02665 Mdot
.504 .02674 Mdot
.504 .02684 Mdot
.504 .02694 Mdot
.504 .02703 Mdot
.504 .02713 Mdot
.504 .02723 Mdot
.504 .02733 Mdot
.504 .02743 Mdot
.504 .02754 Mdot
.504 .02764 Mdot
.504 .02774 Mdot
.504 .02785 Mdot
.504 .02795 Mdot
.504 .02806 Mdot
.504 .02816 Mdot
.504 .02827 Mdot
.504 .02838 Mdot
.504 .02849 Mdot
.504 .0286 Mdot
.504 .02871 Mdot
.504 .02882 Mdot
.504 .02893 Mdot
.504 .02905 Mdot
.504 .02916 Mdot
.504 .02928 Mdot
.504 .0294 Mdot
.504 .02951 Mdot
.504 .02963 Mdot
.504 .02975 Mdot
.504 .02987 Mdot
.504 .02999 Mdot
.504 .03011 Mdot
.504 .03024 Mdot
.504 .03036 Mdot
.504 .03049 Mdot
.504 .03061 Mdot
.504 .03074 Mdot
.504 .03087 Mdot
.504 .031 Mdot
.504 .03113 Mdot
.504 .03126 Mdot
.504 .03139 Mdot
.504 .03152 Mdot
.504 .03166 Mdot
.504 .03179 Mdot
.504 .03193 Mdot
.504 .03207 Mdot
.504 .03221 Mdot
.504 .03235 Mdot
.504 .03249 Mdot
.504 .03263 Mdot
.504 .03277 Mdot
.504 .03292 Mdot
.504 .03306 Mdot
.504 .03321 Mdot
.504 .03336 Mdot
.504 .03351 Mdot
.504 .03366 Mdot
.504 .03381 Mdot
.504 .03396 Mdot
.504 .03412 Mdot
.504 .03427 Mdot
.504 .03443 Mdot
.504 .03459 Mdot
.504 .03475 Mdot
.504 .03491 Mdot
.504 .03507 Mdot
.504 .03523 Mdot
.504 .03539 Mdot
.504 .03556 Mdot
.504 .03573 Mdot
.504 .03589 Mdot
.504 .03606 Mdot
.504 .03623 Mdot
.504 .03641 Mdot
.504 .03658 Mdot
.504 .03676 Mdot
.504 .03693 Mdot
.504 .03711 Mdot
.504 .03729 Mdot
.504 .03747 Mdot
.504 .03765 Mdot
.504 .03783 Mdot
.504 .03802 Mdot
.504 .03821 Mdot
.504 .03839 Mdot
.504 .03858 Mdot
.504 .03877 Mdot
.504 .03897 Mdot
.504 .03916 Mdot
.504 .03936 Mdot
.504 .03955 Mdot
.504 .03975 Mdot
.504 .03995 Mdot
.504 .04015 Mdot
.504 .04036 Mdot
.504 .04056 Mdot
.504 .04077 Mdot
.504 .04098 Mdot
.504 .04119 Mdot
.504 .0414 Mdot
.504 .04161 Mdot
.504 .04183 Mdot
.504 .04205 Mdot
.504 .04226 Mdot
.504 .04248 Mdot
.504 .04271 Mdot
.504 .04293 Mdot
.504 .04316 Mdot
.504 .04338 Mdot
.504 .04361 Mdot
.504 .04384 Mdot
.504 .04408 Mdot
.504 .04431 Mdot
.504 .04455 Mdot
.504 .04479 Mdot
.504 .04503 Mdot
.504 .04527 Mdot
.504 .04552 Mdot
.504 .04576 Mdot
.504 .04601 Mdot
.504 .04626 Mdot
.504 .04651 Mdot
.504 .04677 Mdot
.504 .04702 Mdot
.504 .04728 Mdot
.504 .04754 Mdot
.504 .04781 Mdot
.504 .04807 Mdot
.504 .04834 Mdot
.504 .04861 Mdot
.504 .04888 Mdot
.504 .04915 Mdot
.504 .04943 Mdot
.504 .0497 Mdot
.504 .04998 Mdot
.504 .05027 Mdot
.504 .05055 Mdot
.504 .05084 Mdot
.504 .05113 Mdot
.504 .05142 Mdot
.504 .05171 Mdot
.504 .05201 Mdot
.504 .0523 Mdot
.504 .05261 Mdot
.504 .05291 Mdot
.504 .05321 Mdot
.504 .05352 Mdot
.504 .05383 Mdot
.504 .05415 Mdot
.504 .05446 Mdot
.504 .05478 Mdot
.504 .0551 Mdot
.504 .05542 Mdot
.504 .05575 Mdot
.504 .05608 Mdot
.504 .05641 Mdot
.504 .05674 Mdot
.504 .05708 Mdot
.504 .05742 Mdot
.504 .05776 Mdot
.504 .0581 Mdot
.504 .05845 Mdot
.504 .0588 Mdot
.504 .05915 Mdot
.504 .05951 Mdot
.504 .05987 Mdot
.504 .06023 Mdot
.504 .06059 Mdot
.504 .06096 Mdot
.504 .06133 Mdot
.504 .0617 Mdot
.504 .06208 Mdot
.504 .06246 Mdot
.504 .06284 Mdot
.504 .06322 Mdot
.504 .06361 Mdot
.504 .064 Mdot
.504 .0644 Mdot
.504 .06479 Mdot
.504 .06519 Mdot
.504 .0656 Mdot
.504 .066 Mdot
.504 .06641 Mdot
.504 .06683 Mdot
.504 .06725 Mdot
.504 .06767 Mdot
.504 .06809 Mdot
.504 .06852 Mdot
.504 .06895 Mdot
.504 .06938 Mdot
.504 .06982 Mdot
.504 .07026 Mdot
.504 .0707 Mdot
.504 .07115 Mdot
.504 .0716 Mdot
.504 .07206 Mdot
.504 .07252 Mdot
.504 .07298 Mdot
.504 .07344 Mdot
.504 .07391 Mdot
.504 .07439 Mdot
.504 .07487 Mdot
.504 .07535 Mdot
.504 .07583 Mdot
.504 .07632 Mdot
.504 .07681 Mdot
.504 .07731 Mdot
.504 .07781 Mdot
.504 .07832 Mdot
.504 .07882 Mdot
.504 .07934 Mdot
.504 .07985 Mdot
.504 .08038 Mdot
.504 .0809 Mdot
.504 .08143 Mdot
.504 .08196 Mdot
.504 .0825 Mdot
.504 .08304 Mdot
.504 .08359 Mdot
.504 .08414 Mdot
.504 .0847 Mdot
.504 .08526 Mdot
.504 .08582 Mdot
.504 .08639 Mdot
.504 .08696 Mdot
.504 .08754 Mdot
.504 .08812 Mdot
.504 .08871 Mdot
.504 .0893 Mdot
.504 .0899 Mdot
.504 .0905 Mdot
.504 .09111 Mdot
.504 .09172 Mdot
.504 .09234 Mdot
.504 .09296 Mdot
.504 .09358 Mdot
.504 .09421 Mdot
.504 .09485 Mdot
.504 .09549 Mdot
.504 .09614 Mdot
.504 .09679 Mdot
.504 .09744 Mdot
.504 .09811 Mdot
.504 .09877 Mdot
.504 .09945 Mdot
.504 .10012 Mdot
.504 .10081 Mdot
.504 .1015 Mdot
.504 .10219 Mdot
.504 .10289 Mdot
.504 .1036 Mdot
.504 .10431 Mdot
.504 .10502 Mdot
.504 .10575 Mdot
.504 .10647 Mdot
.504 .10721 Mdot
.504 .10795 Mdot
.504 .10869 Mdot
.504 .10945 Mdot
.504 .1102 Mdot
.504 .11097 Mdot
.504 .11174 Mdot
.504 .11251 Mdot
.504 .1133 Mdot
.504 .11408 Mdot
.504 .11488 Mdot
.504 .11568 Mdot
.504 .11649 Mdot
.504 .1173 Mdot
.504 .11812 Mdot
.504 .11895 Mdot
.504 .11978 Mdot
.504 .12063 Mdot
.504 .12147 Mdot
.504 .12233 Mdot
.504 .12319 Mdot
.504 .12406 Mdot
.504 .12493 Mdot
.504 .12581 Mdot
.504 .1267 Mdot
.504 .1276 Mdot
.504 .1285 Mdot
.504 .12941 Mdot
.504 .13033 Mdot
.504 .13125 Mdot
.504 .13218 Mdot
.504 .13312 Mdot
.504 .13407 Mdot
.504 .13503 Mdot
.504 .13599 Mdot
.504 .13696 Mdot
.504 .13794 Mdot
.504 .13892 Mdot
.504 .13992 Mdot
.504 .14092 Mdot
.504 .14193 Mdot
.504 .14295 Mdot
.504 .14397 Mdot
.504 .14501 Mdot
.504 .14605 Mdot
.504 .1471 Mdot
.504 .14816 Mdot
.504 .14922 Mdot
.504 .1503 Mdot
.504 .15139 Mdot
.504 .15248 Mdot
.504 .15358 Mdot
.504 .15469 Mdot
.504 .15581 Mdot
.504 .15694 Mdot
.504 .15808 Mdot
.504 .15923 Mdot
.504 .16038 Mdot
.504 .16155 Mdot
.504 .16272 Mdot
.504 .16391 Mdot
.504 .1651 Mdot
.504 .1663 Mdot
.504 .16751 Mdot
.504 .16874 Mdot
.504 .16997 Mdot
.504 .17121 Mdot
.504 .17246 Mdot
.504 .17373 Mdot
.504 .175 Mdot
.504 .17628 Mdot
.504 .17757 Mdot
.504 .17887 Mdot
.504 .18019 Mdot
.504 .18151 Mdot
.504 .18285 Mdot
.504 .18419 Mdot
.504 .18555 Mdot
.504 .18691 Mdot
.504 .18829 Mdot
.504 .18968 Mdot
.504 .19108 Mdot
.504 .19249 Mdot
.504 .19391 Mdot
.504 .19535 Mdot
.504 .19679 Mdot
.504 .19825 Mdot
.504 .19972 Mdot
.504 .2012 Mdot
.504 .20269 Mdot
.504 .20419 Mdot
.504 .20571 Mdot
.504 .20724 Mdot
.504 .20878 Mdot
.504 .21033 Mdot
.504 .21189 Mdot
.504 .21347 Mdot
.504 .21506 Mdot
.504 .21666 Mdot
.504 .21828 Mdot
.504 .21991 Mdot
.504 .22155 Mdot
.504 .2232 Mdot
.504 .22487 Mdot
.504 .22655 Mdot
.504 .22825 Mdot
.504 .22996 Mdot
.504 .23168 Mdot
.504 .23341 Mdot
.504 .23516 Mdot
.504 .23693 Mdot
.504 .2387 Mdot
.504 .2405 Mdot
.504 .2423 Mdot
.504 .24412 Mdot
.504 .24596 Mdot
.504 .24781 Mdot
.504 .24967 Mdot
.504 .25155 Mdot
.504 .25345 Mdot
.504 .25536 Mdot
.504 .25728 Mdot
.504 .25922 Mdot
.504 .26118 Mdot
.504 .26315 Mdot
.504 .26514 Mdot
.504 .26714 Mdot
.504 .26916 Mdot
.504 .2712 Mdot
.504 .27325 Mdot
.504 .27532 Mdot
.504 .2774 Mdot
.504 .2795 Mdot
.504 .28162 Mdot
.504 .28376 Mdot
.504 .28591 Mdot
.504 .28808 Mdot
.504 .29027 Mdot
.504 .29247 Mdot
.504 .29469 Mdot
.504 .29693 Mdot
.504 .29919 Mdot
.504 .30147 Mdot
.504 .30376 Mdot
.504 .30607 Mdot
.504 .3084 Mdot
.504 .31075 Mdot
.506 .0153 Mdot
.506 .01531 Mdot
.506 .01532 Mdot
.506 .01532 Mdot
.506 .01533 Mdot
.506 .01534 Mdot
.506 .01535 Mdot
.506 .01535 Mdot
.506 .01536 Mdot
.506 .01536 Mdot
.506 .01537 Mdot
.506 .01537 Mdot
.506 .01537 Mdot
.506 .01538 Mdot
.506 .01538 Mdot
.506 .01538 Mdot
.506 .01539 Mdot
.506 .01539 Mdot
.506 .0154 Mdot
.506 .0154 Mdot
.506 .01541 Mdot
.506 .01541 Mdot
.506 .01542 Mdot
.506 .01542 Mdot
.506 .01542 Mdot
.506 .01543 Mdot
.506 .01543 Mdot
.506 .01543 Mdot
.506 .01544 Mdot
.506 .01544 Mdot
.506 .01545 Mdot
.506 .01545 Mdot
.506 .01546 Mdot
.506 .01546 Mdot
.506 .01547 Mdot
.506 .01547 Mdot
.506 .01548 Mdot
.506 .01548 Mdot
.506 .01549 Mdot
.506 .01549 Mdot
.506 .01549 Mdot
.506 .0155 Mdot
.506 .0155 Mdot
.506 .01551 Mdot
.506 .01551 Mdot
.506 .01552 Mdot
.506 .01552 Mdot
.506 .01552 Mdot
.506 .01553 Mdot
.506 .01553 Mdot
.506 .01554 Mdot
.506 .01554 Mdot
.506 .01555 Mdot
.506 .01555 Mdot
.506 .01556 Mdot
.506 .01556 Mdot
.506 .01557 Mdot
.506 .01557 Mdot
.506 .01558 Mdot
.506 .01558 Mdot
.506 .01559 Mdot
.506 .0156 Mdot
.506 .0156 Mdot
.506 .01561 Mdot
.506 .01561 Mdot
.506 .01562 Mdot
.506 .01563 Mdot
.506 .01563 Mdot
.506 .01564 Mdot
.506 .01564 Mdot
.506 .01565 Mdot
.506 .01565 Mdot
.506 .01566 Mdot
.506 .01566 Mdot
.506 .01567 Mdot
.506 .01567 Mdot
.506 .01568 Mdot
.506 .01568 Mdot
.506 .01569 Mdot
.506 .01569 Mdot
.506 .0157 Mdot
.506 .01571 Mdot
.506 .01572 Mdot
.506 .01572 Mdot
.506 .01573 Mdot
.506 .01573 Mdot
.506 .01574 Mdot
.506 .01574 Mdot
.506 .01575 Mdot
.506 .01576 Mdot
.506 .01577 Mdot
.506 .01577 Mdot
.506 .01578 Mdot
.506 .01578 Mdot
.506 .01579 Mdot
.506 .01579 Mdot
.506 .0158 Mdot
.506 .01581 Mdot
.506 .01582 Mdot
.506 .01582 Mdot
.506 .01583 Mdot
.506 .01583 Mdot
.506 .01584 Mdot
.506 .01585 Mdot
.506 .01586 Mdot
.506 .01586 Mdot
.506 .01587 Mdot
.506 .01587 Mdot
.506 .01588 Mdot
.506 .01589 Mdot
.506 .0159 Mdot
.506 .0159 Mdot
.506 .01591 Mdot
.506 .01592 Mdot
.506 .01593 Mdot
.506 .01593 Mdot
.506 .01594 Mdot
.506 .01594 Mdot
.506 .01596 Mdot
.506 .01596 Mdot
.506 .01597 Mdot
.506 .01597 Mdot
.506 .01599 Mdot
.506 .01599 Mdot
.506 .016 Mdot
.506 .016 Mdot
.506 .01602 Mdot
.506 .01602 Mdot
.506 .01603 Mdot
.506 .01604 Mdot
.506 .01605 Mdot
.506 .01605 Mdot
.506 .01606 Mdot
.506 .01607 Mdot
.506 .01608 Mdot
.506 .01608 Mdot
.506 .0161 Mdot
.506 .0161 Mdot
.506 .01611 Mdot
.506 .01612 Mdot
.506 .01613 Mdot
.506 .01613 Mdot
.506 .01615 Mdot
.506 .01615 Mdot
.506 .01616 Mdot
.506 .01617 Mdot
.506 .01618 Mdot
.506 .01618 Mdot
.506 .0162 Mdot
.506 .0162 Mdot
.506 .01622 Mdot
.506 .01622 Mdot
.506 .01624 Mdot
.506 .01624 Mdot
.506 .01625 Mdot
.506 .01626 Mdot
.506 .01627 Mdot
.506 .01628 Mdot
.506 .01629 Mdot
.506 .01629 Mdot
.506 .01631 Mdot
.506 .01631 Mdot
.506 .01633 Mdot
.506 .01633 Mdot
.506 .01635 Mdot
.506 .01635 Mdot
.506 .01637 Mdot
.506 .01637 Mdot
.506 .01639 Mdot
.506 .01639 Mdot
.506 .01641 Mdot
.506 .01641 Mdot
.506 .01643 Mdot
.506 .01643 Mdot
.506 .01645 Mdot
.506 .01645 Mdot
.506 .01647 Mdot
.506 .01647 Mdot
.506 .01649 Mdot
.506 .01649 Mdot
.506 .01651 Mdot
.506 .01652 Mdot
.506 .01653 Mdot
.506 .01654 Mdot
.506 .01655 Mdot
.506 .01656 Mdot
.506 .01658 Mdot
.506 .01658 Mdot
.506 .0166 Mdot
.506 .0166 Mdot
.506 .01662 Mdot
.506 .01663 Mdot
.506 .01664 Mdot
.506 .01665 Mdot
.506 .01667 Mdot
.506 .01667 Mdot
.506 .01669 Mdot
.506 .0167 Mdot
.506 .01672 Mdot
.506 .01672 Mdot
.506 .01674 Mdot
.506 .01674 Mdot
.506 .01676 Mdot
.506 .01677 Mdot
.506 .01679 Mdot
.506 .01679 Mdot
.506 .01681 Mdot
.506 .01682 Mdot
.506 .01684 Mdot
.506 .01684 Mdot
.506 .01686 Mdot
.506 .01687 Mdot
.506 .01689 Mdot
.506 .01689 Mdot
.506 .01692 Mdot
.506 .01692 Mdot
.506 .01694 Mdot
.506 .01695 Mdot
.506 .01697 Mdot
.506 .01697 Mdot
.506 .017 Mdot
.506 .017 Mdot
.506 .01702 Mdot
.506 .01703 Mdot
.506 .01705 Mdot
.506 .01706 Mdot
.506 .01708 Mdot
.506 .01708 Mdot
.506 .01711 Mdot
.506 .01711 Mdot
.506 .01714 Mdot
.506 .01714 Mdot
.506 .01716 Mdot
.506 .01717 Mdot
.506 .01719 Mdot
.506 .0172 Mdot
.506 .01722 Mdot
.506 .01723 Mdot
.506 .01725 Mdot
.506 .01726 Mdot
.506 .01728 Mdot
.506 .01729 Mdot
.506 .01732 Mdot
.506 .01732 Mdot
.506 .01735 Mdot
.506 .01735 Mdot
.506 .01738 Mdot
.506 .01738 Mdot
.506 .01741 Mdot
.506 .01742 Mdot
.506 .01744 Mdot
.506 .01745 Mdot
.506 .01748 Mdot
.506 .01748 Mdot
.506 .01751 Mdot
.506 .01751 Mdot
.506 .01754 Mdot
.506 .01755 Mdot
.506 .01758 Mdot
.506 .01758 Mdot
.506 .01761 Mdot
.506 .01762 Mdot
.506 .01764 Mdot
.506 .01765 Mdot
.506 .01768 Mdot
.506 .01769 Mdot
.506 .01772 Mdot
.506 .01772 Mdot
.506 .01775 Mdot
.506 .01776 Mdot
.506 .01779 Mdot
.506 .01779 Mdot
.506 .01782 Mdot
.506 .01783 Mdot
.506 .01786 Mdot
.506 .01787 Mdot
.506 .0179 Mdot
.506 .01791 Mdot
.506 .01794 Mdot
.506 .01794 Mdot
.506 .01798 Mdot
.506 .01798 Mdot
.506 .01802 Mdot
.506 .01802 Mdot
.506 .01806 Mdot
.506 .01806 Mdot
.506 .0181 Mdot
.506 .0181 Mdot
.506 .01814 Mdot
.506 .01814 Mdot
.506 .01818 Mdot
.506 .01818 Mdot
.506 .01822 Mdot
.506 .01823 Mdot
.506 .01826 Mdot
.506 .01827 Mdot
.506 .0183 Mdot
.506 .01831 Mdot
.506 .01835 Mdot
.506 .01835 Mdot
.506 .01839 Mdot
.506 .0184 Mdot
.506 .01843 Mdot
.506 .01844 Mdot
.506 .01848 Mdot
.506 .01849 Mdot
.506 .01852 Mdot
.506 .01853 Mdot
.506 .01857 Mdot
.506 .01858 Mdot
.506 .01862 Mdot
.506 .01862 Mdot
.506 .01866 Mdot
.506 .01867 Mdot
.506 .01871 Mdot
.506 .01872 Mdot
.506 .01876 Mdot
.506 .01877 Mdot
.506 .01881 Mdot
.506 .01882 Mdot
.506 .01886 Mdot
.506 .01886 Mdot
.506 .01891 Mdot
.506 .01891 Mdot
.506 .01896 Mdot
.506 .01896 Mdot
.506 .01901 Mdot
.506 .01902 Mdot
.506 .01906 Mdot
.506 .01907 Mdot
.506 .01911 Mdot
.506 .01912 Mdot
.506 .01916 Mdot
.506 .01917 Mdot
.506 .01922 Mdot
.506 .01923 Mdot
.506 .01927 Mdot
.506 .01928 Mdot
.506 .01932 Mdot
.506 .01933 Mdot
.506 .01938 Mdot
.506 .01939 Mdot
.506 .01944 Mdot
.506 .01945 Mdot
.506 .01949 Mdot
.506 .0195 Mdot
.506 .01955 Mdot
.506 .01956 Mdot
.506 .01961 Mdot
.506 .01962 Mdot
.506 .01967 Mdot
.506 .01968 Mdot
.506 .01973 Mdot
.506 .01974 Mdot
.506 .01979 Mdot
.506 .0198 Mdot
.506 .01985 Mdot
.506 .01986 Mdot
.506 .01991 Mdot
.506 .01992 Mdot
.506 .01997 Mdot
.506 .01998 Mdot
.506 .02003 Mdot
.506 .02005 Mdot
.506 .0201 Mdot
.506 .02011 Mdot
.506 .02016 Mdot
.506 .02017 Mdot
.506 .02023 Mdot
.506 .02024 Mdot
.506 .02029 Mdot
.506 .02031 Mdot
.506 .02036 Mdot
.506 .02037 Mdot
.506 .02043 Mdot
.506 .02044 Mdot
.506 .0205 Mdot
.506 .02051 Mdot
.506 .02057 Mdot
.506 .02058 Mdot
.506 .02064 Mdot
.506 .02065 Mdot
.506 .02071 Mdot
.506 .02072 Mdot
.506 .02078 Mdot
.506 .02079 Mdot
.506 .02085 Mdot
.506 .02087 Mdot
.506 .02093 Mdot
.506 .02094 Mdot
.506 .021 Mdot
.506 .02101 Mdot
.506 .02108 Mdot
.506 .02109 Mdot
.506 .02115 Mdot
.506 .02117 Mdot
.506 .02123 Mdot
.506 .02124 Mdot
.506 .02131 Mdot
.506 .02132 Mdot
.506 .02139 Mdot
.506 .0214 Mdot
.506 .02147 Mdot
.506 .02148 Mdot
.506 .02155 Mdot
.506 .02156 Mdot
.506 .02163 Mdot
.506 .02165 Mdot
.506 .02171 Mdot
.506 .02173 Mdot
.506 .0218 Mdot
.506 .02181 Mdot
.506 .02188 Mdot
.506 .0219 Mdot
.506 .02197 Mdot
.506 .02198 Mdot
.506 .02206 Mdot
.506 .02207 Mdot
.506 .02214 Mdot
.506 .02216 Mdot
.506 .02223 Mdot
.506 .02225 Mdot
.506 .02232 Mdot
.506 .02234 Mdot
.506 .02241 Mdot
.506 .02243 Mdot
.506 .02251 Mdot
.506 .02252 Mdot
.506 .0226 Mdot
.506 .02262 Mdot
.506 .02269 Mdot
.506 .02271 Mdot
.506 .02279 Mdot
.506 .02281 Mdot
.506 .02289 Mdot
.506 .0229 Mdot
.506 .02299 Mdot
.506 .023 Mdot
.506 .02308 Mdot
.506 .0231 Mdot
.506 .02319 Mdot
.506 .0232 Mdot
.506 .02329 Mdot
.506 .02331 Mdot
.506 .02339 Mdot
.506 .02341 Mdot
.506 .02349 Mdot
.506 .02351 Mdot
.506 .0236 Mdot
.506 .02362 Mdot
.506 .02371 Mdot
.506 .02372 Mdot
.506 .02381 Mdot
.506 .02383 Mdot
.506 .02392 Mdot
.506 .02394 Mdot
.506 .02403 Mdot
.506 .02405 Mdot
.506 .02414 Mdot
.506 .02417 Mdot
.506 .02426 Mdot
.506 .02428 Mdot
.506 .02437 Mdot
.506 .02439 Mdot
.506 .02449 Mdot
.506 .02451 Mdot
.506 .02461 Mdot
.506 .02463 Mdot
.506 .02472 Mdot
.506 .02475 Mdot
.506 .02484 Mdot
.506 .02487 Mdot
.506 .02497 Mdot
.506 .02499 Mdot
.506 .02509 Mdot
.506 .02511 Mdot
.506 .02521 Mdot
.506 .02524 Mdot
.506 .02534 Mdot
.506 .02536 Mdot
.506 .02547 Mdot
.506 .02549 Mdot
.506 .0256 Mdot
.506 .02562 Mdot
.506 .02573 Mdot
.506 .02575 Mdot
.506 .02586 Mdot
.506 .02588 Mdot
.506 .02599 Mdot
.506 .02602 Mdot
.506 .02613 Mdot
.506 .02615 Mdot
.506 .02626 Mdot
.506 .02629 Mdot
.506 .0264 Mdot
.506 .02643 Mdot
.506 .02654 Mdot
.506 .02657 Mdot
.506 .02669 Mdot
.506 .02671 Mdot
.506 .02683 Mdot
.506 .02686 Mdot
.506 .02697 Mdot
.506 .027 Mdot
.506 .02712 Mdot
.506 .02715 Mdot
.506 .02727 Mdot
.506 .0273 Mdot
.506 .02742 Mdot
.506 .02745 Mdot
.506 .02757 Mdot
.506 .0276 Mdot
.506 .02773 Mdot
.506 .02776 Mdot
.506 .02788 Mdot
.506 .02791 Mdot
.506 .02804 Mdot
.506 .02807 Mdot
.506 .0282 Mdot
.506 .02823 Mdot
.506 .02836 Mdot
.506 .02839 Mdot
.506 .02853 Mdot
.506 .02856 Mdot
.506 .02869 Mdot
.506 .02872 Mdot
.506 .02886 Mdot
.506 .02889 Mdot
.506 .02903 Mdot
.506 .02906 Mdot
.506 .0292 Mdot
.506 .02923 Mdot
.506 .02938 Mdot
.506 .02941 Mdot
.506 .02955 Mdot
.506 .02958 Mdot
.506 .02973 Mdot
.506 .02976 Mdot
.506 .02991 Mdot
.506 .02994 Mdot
.506 .03009 Mdot
.506 .03013 Mdot
.506 .03028 Mdot
.506 .03031 Mdot
.506 .03046 Mdot
.506 .0305 Mdot
.506 .03065 Mdot
.506 .03069 Mdot
.506 .03084 Mdot
.506 .03088 Mdot
.506 .03104 Mdot
.506 .03107 Mdot
.506 .03123 Mdot
.506 .03127 Mdot
.506 .03143 Mdot
.506 .03147 Mdot
.506 .03163 Mdot
.506 .03167 Mdot
.506 .03184 Mdot
.506 .03187 Mdot
.506 .03204 Mdot
.506 .03208 Mdot
.506 .03225 Mdot
.506 .03229 Mdot
.506 .03246 Mdot
.506 .0325 Mdot
.506 .03267 Mdot
.506 .03271 Mdot
.506 .03289 Mdot
.506 .03293 Mdot
.506 .03311 Mdot
.506 .03315 Mdot
.506 .03333 Mdot
.506 .03337 Mdot
.506 .03355 Mdot
.506 .03359 Mdot
.506 .03378 Mdot
.506 .03382 Mdot
.506 .03401 Mdot
.506 .03405 Mdot
.506 .03424 Mdot
.506 .03428 Mdot
.506 .03447 Mdot
.506 .03451 Mdot
.506 .03471 Mdot
.506 .03475 Mdot
.506 .03495 Mdot
.506 .03499 Mdot
.506 .03519 Mdot
.506 .03523 Mdot
.506 .03544 Mdot
.506 .03548 Mdot
.506 .03569 Mdot
.506 .03573 Mdot
.506 .03594 Mdot
.506 .03598 Mdot
.506 .03619 Mdot
.506 .03624 Mdot
.506 .03645 Mdot
.506 .0365 Mdot
.506 .03671 Mdot
.506 .03676 Mdot
.506 .03697 Mdot
.506 .03702 Mdot
.506 .03724 Mdot
.506 .03729 Mdot
.506 .03751 Mdot
.506 .03756 Mdot
.506 .03778 Mdot
.506 .03783 Mdot
.506 .03806 Mdot
.506 .03811 Mdot
.506 .03834 Mdot
.506 .03839 Mdot
.506 .03863 Mdot
.506 .03868 Mdot
.506 .03891 Mdot
.506 .03896 Mdot
.506 .0392 Mdot
.506 .0395 Mdot
.506 .03979 Mdot
.506 .04009 Mdot
.506 .0404 Mdot
.506 .04071 Mdot
.506 .04102 Mdot
.506 .04134 Mdot
.506 .04165 Mdot
.506 .04198 Mdot
.506 .04231 Mdot
.506 .04264 Mdot
.506 .04297 Mdot
.506 .04331 Mdot
.506 .04365 Mdot
.506 .044 Mdot
.506 .04435 Mdot
.506 .04471 Mdot
.506 .04507 Mdot
.506 .04543 Mdot
.506 .0458 Mdot
.506 .04617 Mdot
.506 .04655 Mdot
.506 .04693 Mdot
.506 .04732 Mdot
.506 .04771 Mdot
.506 .04811 Mdot
.506 .04851 Mdot
.506 .04891 Mdot
.506 .04932 Mdot
.506 .04974 Mdot
.506 .05016 Mdot
.506 .05058 Mdot
.506 .05101 Mdot
.506 .05145 Mdot
.506 .05189 Mdot
.506 .05234 Mdot
.506 .05279 Mdot
.506 .0528 Mdot
.506 .05325 Mdot
.506 .05325 Mdot
.506 .05371 Mdot
.506 .05372 Mdot
.506 .05418 Mdot
.506 .05418 Mdot
.506 .05465 Mdot
.506 .05466 Mdot
.506 .05513 Mdot
.506 .05514 Mdot
.506 .05561 Mdot
.506 .05562 Mdot
.506 .0561 Mdot
.506 .05611 Mdot
.506 .0566 Mdot
.506 .05661 Mdot
.506 .0571 Mdot
.506 .05711 Mdot
.506 .05761 Mdot
.506 .05762 Mdot
.506 .05813 Mdot
.506 .05814 Mdot
.506 .05865 Mdot
.506 .05866 Mdot
.506 .05918 Mdot
.506 .05918 Mdot
.506 .05971 Mdot
.506 .05972 Mdot
.506 .06025 Mdot
.506 .06026 Mdot
.506 .0608 Mdot
.506 .0608 Mdot
.506 .06135 Mdot
.506 .06136 Mdot
.506 .06191 Mdot
.506 .06192 Mdot
.506 .06247 Mdot
.506 .06248 Mdot
.506 .06305 Mdot
.506 .06306 Mdot
.506 .06363 Mdot
.506 .06364 Mdot
.506 .06421 Mdot
.506 .06422 Mdot
.506 .06481 Mdot
.506 .06482 Mdot
.506 .06541 Mdot
.506 .06542 Mdot
.506 .06602 Mdot
.506 .06603 Mdot
.506 .06663 Mdot
.506 .06664 Mdot
.506 .06726 Mdot
.506 .06727 Mdot
.506 .06789 Mdot
.506 .0679 Mdot
.506 .06852 Mdot
.506 .06854 Mdot
.506 .06917 Mdot
.506 .06918 Mdot
.506 .06982 Mdot
.506 .06983 Mdot
.506 .07049 Mdot
.506 .0705 Mdot
.506 .07115 Mdot
.506 .07117 Mdot
.506 .07183 Mdot
.506 .07184 Mdot
.506 .07252 Mdot
.506 .07253 Mdot
.506 .07321 Mdot
.506 .07322 Mdot
.506 .07391 Mdot
.506 .07392 Mdot
.506 .07462 Mdot
.506 .07463 Mdot
.506 .07534 Mdot
.506 .07535 Mdot
.506 .07607 Mdot
.506 .07608 Mdot
.506 .07681 Mdot
.506 .07682 Mdot
.506 .07755 Mdot
.506 .07756 Mdot
.506 .0783 Mdot
.506 .07832 Mdot
.506 .07907 Mdot
.506 .07908 Mdot
.506 .07984 Mdot
.506 .07985 Mdot
.506 .08062 Mdot
.506 .08063 Mdot
.506 .08141 Mdot
.506 .08143 Mdot
.506 .08221 Mdot
.506 .08223 Mdot
.506 .08302 Mdot
.506 .08304 Mdot
.506 .08384 Mdot
.506 .08386 Mdot
.506 .08467 Mdot
.506 .08469 Mdot
.506 .08551 Mdot
.506 .08553 Mdot
.506 .08636 Mdot
.506 .08637 Mdot
.506 .08722 Mdot
.506 .08723 Mdot
.506 .08809 Mdot
.506 .08811 Mdot
.506 .08897 Mdot
.506 .08899 Mdot
.506 .08986 Mdot
.506 .08988 Mdot
.506 .09076 Mdot
.506 .09078 Mdot
.506 .09168 Mdot
.506 .09169 Mdot
.506 .0926 Mdot
.506 .09262 Mdot
.506 .09354 Mdot
.506 .09355 Mdot
.506 .09448 Mdot
.506 .0945 Mdot
.506 .09544 Mdot
.506 .09545 Mdot
.506 .09641 Mdot
.506 .09642 Mdot
.506 .09739 Mdot
.506 .0974 Mdot
.506 .09838 Mdot
.506 .0984 Mdot
.506 .09938 Mdot
.506 .0994 Mdot
.506 .1004 Mdot
.506 .10042 Mdot
.506 .10143 Mdot
.506 .10144 Mdot
.506 .10247 Mdot
.506 .10248 Mdot
.506 .10352 Mdot
.506 .10354 Mdot
.506 .10459 Mdot
.506 .1046 Mdot
.506 .10567 Mdot
.506 .10568 Mdot
.506 .10676 Mdot
.506 .10677 Mdot
.506 .10786 Mdot
.506 .10788 Mdot
.506 .10898 Mdot
.506 .109 Mdot
.506 .11011 Mdot
.506 .11013 Mdot
.506 .11125 Mdot
.506 .11127 Mdot
.506 .11241 Mdot
.506 .11243 Mdot
.506 .11359 Mdot
.506 .1136 Mdot
.506 .11477 Mdot
.506 .11479 Mdot
.506 .11597 Mdot
.506 .11599 Mdot
.506 .11719 Mdot
.506 .11721 Mdot
.506 .11842 Mdot
.506 .11844 Mdot
.506 .11966 Mdot
.506 .11968 Mdot
.506 .12092 Mdot
.506 .12094 Mdot
.506 .1222 Mdot
.506 .12222 Mdot
.506 .12349 Mdot
.506 .12351 Mdot
.506 .12479 Mdot
.506 .12481 Mdot
.506 .12611 Mdot
.506 .12613 Mdot
.506 .12745 Mdot
.506 .12747 Mdot
.506 .1288 Mdot
.506 .12882 Mdot
.506 .13017 Mdot
.506 .13019 Mdot
.506 .13156 Mdot
.506 .13158 Mdot
.506 .13296 Mdot
.506 .13298 Mdot
.506 .13438 Mdot
.506 .1344 Mdot
.506 .13581 Mdot
.506 .13584 Mdot
.506 .13727 Mdot
.506 .13729 Mdot
.506 .13874 Mdot
.506 .13876 Mdot
.506 .14022 Mdot
.506 .14025 Mdot
.506 .14173 Mdot
.506 .14176 Mdot
.506 .14326 Mdot
.506 .14328 Mdot
.506 .1448 Mdot
.506 .14482 Mdot
.506 .14636 Mdot
.506 .14638 Mdot
.506 .14794 Mdot
.506 .14796 Mdot
.506 .14954 Mdot
.506 .14956 Mdot
.506 .15115 Mdot
.506 .15118 Mdot
.506 .15279 Mdot
.506 .15282 Mdot
.506 .15445 Mdot
.506 .15448 Mdot
.506 .15613 Mdot
.506 .15615 Mdot
.506 .15782 Mdot
.506 .15785 Mdot
.506 .15954 Mdot
.506 .15957 Mdot
.506 .16128 Mdot
.506 .16131 Mdot
.506 .16304 Mdot
.506 .16307 Mdot
.506 .16482 Mdot
.506 .16485 Mdot
.506 .16662 Mdot
.506 .16665 Mdot
.506 .16844 Mdot
.506 .16847 Mdot
.506 .17029 Mdot
.506 .17032 Mdot
.506 .17215 Mdot
.506 .17218 Mdot
.506 .17404 Mdot
.506 .17407 Mdot
.506 .17595 Mdot
.506 .17598 Mdot
.506 .17789 Mdot
.506 .17792 Mdot
.506 .17985 Mdot
.506 .17988 Mdot
.506 .18183 Mdot
.506 .18186 Mdot
.506 .18383 Mdot
.506 .18387 Mdot
.506 .18586 Mdot
.506 .1859 Mdot
.506 .18792 Mdot
.506 .18795 Mdot
.506 .18999 Mdot
.506 .19003 Mdot
.506 .1921 Mdot
.506 .19213 Mdot
.506 .19423 Mdot
.506 .19426 Mdot
.506 .19638 Mdot
.506 .19642 Mdot
.506 .19856 Mdot
.506 .1986 Mdot
.506 .20077 Mdot
.506 .2008 Mdot
.506 .203 Mdot
.506 .20304 Mdot
.506 .20526 Mdot
.506 .2053 Mdot
.506 .20755 Mdot
.506 .20758 Mdot
.506 .20986 Mdot
.506 .2099 Mdot
.506 .2122 Mdot
.506 .21224 Mdot
.506 .21457 Mdot
.506 .21461 Mdot
.506 .21697 Mdot
.506 .21701 Mdot
.506 .2194 Mdot
.506 .21944 Mdot
.506 .22185 Mdot
.506 .22189 Mdot
.506 .22434 Mdot
.506 .22438 Mdot
.506 .22685 Mdot
.506 .22689 Mdot
.506 .2294 Mdot
.506 .22944 Mdot
.506 .23198 Mdot
.506 .23202 Mdot
.506 .23458 Mdot
.506 .23462 Mdot
.506 .23722 Mdot
.506 .23726 Mdot
.506 .23989 Mdot
.506 .23993 Mdot
.506 .24259 Mdot
.506 .24264 Mdot
.506 .24533 Mdot
.506 .24537 Mdot
.506 .2481 Mdot
.506 .24814 Mdot
.506 .2509 Mdot
.506 .25094 Mdot
.506 .25373 Mdot
.506 .25378 Mdot
.506 .2566 Mdot
.506 .25664 Mdot
.506 .2595 Mdot
.506 .25955 Mdot
.506 .26244 Mdot
.506 .26249 Mdot
.506 .26541 Mdot
.506 .26546 Mdot
.506 .26842 Mdot
.506 .26847 Mdot
.506 .27146 Mdot
.506 .27151 Mdot
.506 .27454 Mdot
.506 .27459 Mdot
.506 .27766 Mdot
.506 .27771 Mdot
.506 .28082 Mdot
.506 .28087 Mdot
.506 .28401 Mdot
.506 .28406 Mdot
.506 .28724 Mdot
.506 .28729 Mdot
.506 .29051 Mdot
.506 .29057 Mdot
.506 .29382 Mdot
.506 .29388 Mdot
.506 .29717 Mdot
.506 .29723 Mdot
.506 .30056 Mdot
.506 .30062 Mdot
.506 .30399 Mdot
.506 .30405 Mdot
.506 .30746 Mdot
.506 .30752 Mdot
.506 .31098 Mdot
.506 .31103 Mdot
.508 .01493 Mdot
.508 .01493 Mdot
.508 .01494 Mdot
.508 .01494 Mdot
.508 .01495 Mdot
.508 .01495 Mdot
.508 .01495 Mdot
.508 .01496 Mdot
.508 .01496 Mdot
.508 .01496 Mdot
.508 .01497 Mdot
.508 .01497 Mdot
.508 .01498 Mdot
.508 .01498 Mdot
.508 .01498 Mdot
.508 .01499 Mdot
.508 .01499 Mdot
.508 .015 Mdot
.508 .015 Mdot
.508 .01501 Mdot
.508 .01501 Mdot
.508 .01502 Mdot
.508 .01502 Mdot
.508 .01503 Mdot
.508 .01503 Mdot
.508 .01504 Mdot
.508 .01504 Mdot
.508 .01505 Mdot
.508 .01505 Mdot
.508 .01506 Mdot
.508 .01506 Mdot
.508 .01507 Mdot
.508 .01507 Mdot
.508 .01508 Mdot
.508 .01509 Mdot
.508 .01509 Mdot
.508 .0151 Mdot
.508 .0151 Mdot
.508 .01511 Mdot
.508 .01512 Mdot
.508 .01512 Mdot
.508 .01513 Mdot
.508 .01514 Mdot
.508 .01514 Mdot
.508 .01515 Mdot
.508 .01516 Mdot
.508 .01516 Mdot
.508 .01517 Mdot
.508 .01518 Mdot
.508 .01518 Mdot
.508 .01519 Mdot
.508 .0152 Mdot
.508 .01521 Mdot
.508 .01522 Mdot
.508 .01522 Mdot
.508 .01523 Mdot
.508 .01524 Mdot
.508 .01525 Mdot
.508 .01526 Mdot
.508 .01527 Mdot
.508 .01527 Mdot
.508 .01528 Mdot
.508 .01529 Mdot
.508 .0153 Mdot
.508 .01531 Mdot
.508 .01532 Mdot
.508 .01533 Mdot
.508 .01534 Mdot
.508 .01535 Mdot
.508 .01536 Mdot
.508 .01537 Mdot
.508 .01538 Mdot
.508 .01539 Mdot
.508 .0154 Mdot
.508 .01541 Mdot
.508 .01542 Mdot
.508 .01544 Mdot
.508 .01545 Mdot
.508 .01546 Mdot
.508 .01547 Mdot
.508 .01548 Mdot
.508 .0155 Mdot
.508 .01551 Mdot
.508 .01552 Mdot
.508 .01553 Mdot
.508 .01555 Mdot
.508 .01556 Mdot
.508 .01557 Mdot
.508 .01559 Mdot
.508 .0156 Mdot
.508 .01562 Mdot
.508 .01563 Mdot
.508 .01564 Mdot
.508 .01566 Mdot
.508 .01567 Mdot
.508 .01569 Mdot
.508 .01571 Mdot
.508 .01572 Mdot
.508 .01574 Mdot
.508 .01575 Mdot
.508 .01577 Mdot
.508 .01579 Mdot
.508 .0158 Mdot
.508 .01582 Mdot
.508 .01584 Mdot
.508 .01586 Mdot
.508 .01588 Mdot
.508 .01589 Mdot
.508 .01591 Mdot
.508 .01593 Mdot
.508 .01595 Mdot
.508 .01597 Mdot
.508 .01599 Mdot
.508 .01601 Mdot
.508 .01603 Mdot
.508 .01605 Mdot
.508 .01608 Mdot
.508 .0161 Mdot
.508 .01612 Mdot
.508 .01614 Mdot
.508 .01617 Mdot
.508 .01619 Mdot
.508 .01621 Mdot
.508 .01622 Mdot
.508 .01624 Mdot
.508 .01625 Mdot
.508 .01626 Mdot
.508 .01627 Mdot
.508 .01629 Mdot
.508 .0163 Mdot
.508 .01631 Mdot
.508 .01632 Mdot
.508 .01634 Mdot
.508 .01635 Mdot
.508 .01636 Mdot
.508 .01637 Mdot
.508 .01639 Mdot
.508 .0164 Mdot
.508 .01641 Mdot
.508 .01643 Mdot
.508 .01644 Mdot
.508 .01645 Mdot
.508 .01647 Mdot
.508 .01648 Mdot
.508 .0165 Mdot
.508 .01651 Mdot
.508 .01653 Mdot
.508 .01654 Mdot
.508 .01656 Mdot
.508 .01657 Mdot
.508 .01658 Mdot
.508 .0166 Mdot
.508 .01661 Mdot
.508 .01663 Mdot
.508 .01664 Mdot
.508 .01666 Mdot
.508 .01668 Mdot
.508 .01669 Mdot
.508 .01671 Mdot
.508 .01672 Mdot
.508 .01674 Mdot
.508 .01675 Mdot
.508 .01677 Mdot
.508 .01679 Mdot
.508 .0168 Mdot
.508 .01682 Mdot
.508 .01684 Mdot
.508 .01685 Mdot
.508 .01687 Mdot
.508 .01689 Mdot
.508 .01691 Mdot
.508 .01692 Mdot
.508 .01694 Mdot
.508 .01696 Mdot
.508 .01698 Mdot
.508 .01699 Mdot
.508 .01701 Mdot
.508 .01703 Mdot
.508 .01705 Mdot
.508 .01707 Mdot
.508 .01709 Mdot
.508 .0171 Mdot
.508 .01713 Mdot
.508 .01714 Mdot
.508 .01716 Mdot
.508 .01718 Mdot
.508 .0172 Mdot
.508 .01722 Mdot
.508 .01724 Mdot
.508 .01726 Mdot
.508 .01728 Mdot
.508 .0173 Mdot
.508 .01732 Mdot
.508 .01734 Mdot
.508 .01737 Mdot
.508 .01738 Mdot
.508 .01741 Mdot
.508 .01743 Mdot
.508 .01745 Mdot
.508 .01747 Mdot
.508 .0175 Mdot
.508 .01751 Mdot
.508 .01754 Mdot
.508 .01756 Mdot
.508 .01758 Mdot
.508 .01761 Mdot
.508 .01763 Mdot
.508 .01765 Mdot
.508 .01768 Mdot
.508 .0177 Mdot
.508 .01772 Mdot
.508 .01775 Mdot
.508 .01777 Mdot
.508 .01779 Mdot
.508 .01782 Mdot
.508 .01784 Mdot
.508 .01787 Mdot
.508 .01789 Mdot
.508 .01792 Mdot
.508 .01794 Mdot
.508 .01797 Mdot
.508 .018 Mdot
.508 .01803 Mdot
.508 .01805 Mdot
.508 .01808 Mdot
.508 .0181 Mdot
.508 .01813 Mdot
.508 .01816 Mdot
.508 .01819 Mdot
.508 .01821 Mdot
.508 .01824 Mdot
.508 .01827 Mdot
.508 .0183 Mdot
.508 .01832 Mdot
.508 .01836 Mdot
.508 .01838 Mdot
.508 .01841 Mdot
.508 .01844 Mdot
.508 .01847 Mdot
.508 .0185 Mdot
.508 .01853 Mdot
.508 .01856 Mdot
.508 .0186 Mdot
.508 .01862 Mdot
.508 .01866 Mdot
.508 .01868 Mdot
.508 .01872 Mdot
.508 .01875 Mdot
.508 .01878 Mdot
.508 .01881 Mdot
.508 .01885 Mdot
.508 .01888 Mdot
.508 .01892 Mdot
.508 .01895 Mdot
.508 .01898 Mdot
.508 .01901 Mdot
.508 .01905 Mdot
.508 .01908 Mdot
.508 .01912 Mdot
.508 .01915 Mdot
.508 .01919 Mdot
.508 .01922 Mdot
.508 .01926 Mdot
.508 .01929 Mdot
.508 .01934 Mdot
.508 .01937 Mdot
.508 .01941 Mdot
.508 .01944 Mdot
.508 .01948 Mdot
.508 .01951 Mdot
.508 .01952 Mdot
.508 .01956 Mdot
.508 .01959 Mdot
.508 .01959 Mdot
.508 .01964 Mdot
.508 .01966 Mdot
.508 .01967 Mdot
.508 .01972 Mdot
.508 .01974 Mdot
.508 .01975 Mdot
.508 .0198 Mdot
.508 .01982 Mdot
.508 .01983 Mdot
.508 .01988 Mdot
.508 .0199 Mdot
.508 .01991 Mdot
.508 .01996 Mdot
.508 .01999 Mdot
.508 .02 Mdot
.508 .02004 Mdot
.508 .02007 Mdot
.508 .02008 Mdot
.508 .02013 Mdot
.508 .02016 Mdot
.508 .02017 Mdot
.508 .02022 Mdot
.508 .02024 Mdot
.508 .02026 Mdot
.508 .0203 Mdot
.508 .02033 Mdot
.508 .02034 Mdot
.508 .02039 Mdot
.508 .02042 Mdot
.508 .02043 Mdot
.508 .02048 Mdot
.508 .02051 Mdot
.508 .02053 Mdot
.508 .02058 Mdot
.508 .02061 Mdot
.508 .02062 Mdot
.508 .02067 Mdot
.508 .0207 Mdot
.508 .02071 Mdot
.508 .02077 Mdot
.508 .0208 Mdot
.508 .02081 Mdot
.508 .02086 Mdot
.508 .02089 Mdot
.508 .02091 Mdot
.508 .02096 Mdot
.508 .02099 Mdot
.508 .02101 Mdot
.508 .02106 Mdot
.508 .02109 Mdot
.508 .02111 Mdot
.508 .02116 Mdot
.508 .0212 Mdot
.508 .02121 Mdot
.508 .02127 Mdot
.508 .0213 Mdot
.508 .02131 Mdot
.508 .02137 Mdot
.508 .0214 Mdot
.508 .02142 Mdot
.508 .02148 Mdot
.508 .02151 Mdot
.508 .02153 Mdot
.508 .02159 Mdot
.508 .02162 Mdot
.508 .02163 Mdot
.508 .0217 Mdot
.508 .02173 Mdot
.508 .02174 Mdot
.508 .02181 Mdot
.508 .02184 Mdot
.508 .02186 Mdot
.508 .02192 Mdot
.508 .02196 Mdot
.508 .02197 Mdot
.508 .02204 Mdot
.508 .02207 Mdot
.508 .02209 Mdot
.508 .02215 Mdot
.508 .02219 Mdot
.508 .02221 Mdot
.508 .02227 Mdot
.508 .02231 Mdot
.508 .02233 Mdot
.508 .02239 Mdot
.508 .02243 Mdot
.508 .02245 Mdot
.508 .02252 Mdot
.508 .02256 Mdot
.508 .02257 Mdot
.508 .02264 Mdot
.508 .02268 Mdot
.508 .0227 Mdot
.508 .02277 Mdot
.508 .02281 Mdot
.508 .02282 Mdot
.508 .0229 Mdot
.508 .02294 Mdot
.508 .02295 Mdot
.508 .02303 Mdot
.508 .02307 Mdot
.508 .02309 Mdot
.508 .02316 Mdot
.508 .0232 Mdot
.508 .02322 Mdot
.508 .0233 Mdot
.508 .02334 Mdot
.508 .02336 Mdot
.508 .02343 Mdot
.508 .02348 Mdot
.508 .02349 Mdot
.508 .02357 Mdot
.508 .02362 Mdot
.508 .02363 Mdot
.508 .02371 Mdot
.508 .02376 Mdot
.508 .02378 Mdot
.508 .02386 Mdot
.508 .0239 Mdot
.508 .02392 Mdot
.508 .024 Mdot
.508 .02405 Mdot
.508 .02407 Mdot
.508 .02415 Mdot
.508 .0242 Mdot
.508 .02422 Mdot
.508 .0243 Mdot
.508 .02435 Mdot
.508 .02437 Mdot
.508 .02446 Mdot
.508 .02451 Mdot
.508 .02453 Mdot
.508 .02461 Mdot
.508 .02466 Mdot
.508 .02468 Mdot
.508 .02477 Mdot
.508 .02482 Mdot
.508 .02484 Mdot
.508 .02493 Mdot
.508 .02498 Mdot
.508 .025 Mdot
.508 .0251 Mdot
.508 .02515 Mdot
.508 .02517 Mdot
.508 .02526 Mdot
.508 .02532 Mdot
.508 .02534 Mdot
.508 .02543 Mdot
.508 .02549 Mdot
.508 .02551 Mdot
.508 .0256 Mdot
.508 .02566 Mdot
.508 .02568 Mdot
.508 .02578 Mdot
.508 .02583 Mdot
.508 .02585 Mdot
.508 .02595 Mdot
.508 .02601 Mdot
.508 .02603 Mdot
.508 .02613 Mdot
.508 .02619 Mdot
.508 .02621 Mdot
.508 .02632 Mdot
.508 .02637 Mdot
.508 .0264 Mdot
.508 .0265 Mdot
.508 .02656 Mdot
.508 .02658 Mdot
.508 .02669 Mdot
.508 .02675 Mdot
.508 .02677 Mdot
.508 .02688 Mdot
.508 .02694 Mdot
.508 .02697 Mdot
.508 .02708 Mdot
.508 .02714 Mdot
.508 .02716 Mdot
.508 .02727 Mdot
.508 .02734 Mdot
.508 .02736 Mdot
.508 .02748 Mdot
.508 .02754 Mdot
.508 .02757 Mdot
.508 .02768 Mdot
.508 .02774 Mdot
.508 .02777 Mdot
.508 .02789 Mdot
.508 .02795 Mdot
.508 .02798 Mdot
.508 .0281 Mdot
.508 .02817 Mdot
.508 .02819 Mdot
.508 .02831 Mdot
.508 .02838 Mdot
.508 .02841 Mdot
.508 .02853 Mdot
.508 .0286 Mdot
.508 .02863 Mdot
.508 .02875 Mdot
.508 .02882 Mdot
.508 .02885 Mdot
.508 .02897 Mdot
.508 .02905 Mdot
.508 .02908 Mdot
.508 .0292 Mdot
.508 .02928 Mdot
.508 .02931 Mdot
.508 .02943 Mdot
.508 .02951 Mdot
.508 .02954 Mdot
.508 .02967 Mdot
.508 .02975 Mdot
.508 .02978 Mdot
.508 .02991 Mdot
.508 .02999 Mdot
.508 .03002 Mdot
.508 .03015 Mdot
.508 .03023 Mdot
.508 .03026 Mdot
.508 .0304 Mdot
.508 .03048 Mdot
.508 .03051 Mdot
.508 .03065 Mdot
.508 .03073 Mdot
.508 .03076 Mdot
.508 .03091 Mdot
.508 .03099 Mdot
.508 .03102 Mdot
.508 .03116 Mdot
.508 .03125 Mdot
.508 .03128 Mdot
.508 .03143 Mdot
.508 .03151 Mdot
.508 .03155 Mdot
.508 .0317 Mdot
.508 .03178 Mdot
.508 .03182 Mdot
.508 .03197 Mdot
.508 .03205 Mdot
.508 .03209 Mdot
.508 .03224 Mdot
.508 .03233 Mdot
.508 .03237 Mdot
.508 .03252 Mdot
.508 .03261 Mdot
.508 .03265 Mdot
.508 .03281 Mdot
.508 .0329 Mdot
.508 .03294 Mdot
.508 .0331 Mdot
.508 .03319 Mdot
.508 .03323 Mdot
.508 .03339 Mdot
.508 .03349 Mdot
.508 .03352 Mdot
.508 .03369 Mdot
.508 .03379 Mdot
.508 .03382 Mdot
.508 .03399 Mdot
.508 .03409 Mdot
.508 .03413 Mdot
.508 .0343 Mdot
.508 .0344 Mdot
.508 .03444 Mdot
.508 .03462 Mdot
.508 .03472 Mdot
.508 .03476 Mdot
.508 .03493 Mdot
.508 .03504 Mdot
.508 .03508 Mdot
.508 .03526 Mdot
.508 .03536 Mdot
.508 .0354 Mdot
.508 .03559 Mdot
.508 .03569 Mdot
.508 .03573 Mdot
.508 .03592 Mdot
.508 .03603 Mdot
.508 .03607 Mdot
.508 .03626 Mdot
.508 .03637 Mdot
.508 .03641 Mdot
.508 .0366 Mdot
.508 .03672 Mdot
.508 .03676 Mdot
.508 .03695 Mdot
.508 .03707 Mdot
.508 .03711 Mdot
.508 .03731 Mdot
.508 .03743 Mdot
.508 .03747 Mdot
.508 .03767 Mdot
.508 .03779 Mdot
.508 .03783 Mdot
.508 .03804 Mdot
.508 .03816 Mdot
.508 .0382 Mdot
.508 .03841 Mdot
.508 .03853 Mdot
.508 .03858 Mdot
.508 .03879 Mdot
.508 .03891 Mdot
.508 .03896 Mdot
.508 .03918 Mdot
.508 .0393 Mdot
.508 .03935 Mdot
.508 .03957 Mdot
.508 .03969 Mdot
.508 .03974 Mdot
.508 .03997 Mdot
.508 .04009 Mdot
.508 .04014 Mdot
.508 .04037 Mdot
.508 .0405 Mdot
.508 .04055 Mdot
.508 .04078 Mdot
.508 .04091 Mdot
.508 .04096 Mdot
.508 .0412 Mdot
.508 .04133 Mdot
.508 .04138 Mdot
.508 .04162 Mdot
.508 .04176 Mdot
.508 .04181 Mdot
.508 .04205 Mdot
.508 .04219 Mdot
.508 .04225 Mdot
.508 .04249 Mdot
.508 .04263 Mdot
.508 .04269 Mdot
.508 .04293 Mdot
.508 .04308 Mdot
.508 .04313 Mdot
.508 .04339 Mdot
.508 .04353 Mdot
.508 .04359 Mdot
.508 .04384 Mdot
.508 .04399 Mdot
.508 .04405 Mdot
.508 .04431 Mdot
.508 .04446 Mdot
.508 .04452 Mdot
.508 .04478 Mdot
.508 .04494 Mdot
.508 .045 Mdot
.508 .04526 Mdot
.508 .04542 Mdot
.508 .04548 Mdot
.508 .04575 Mdot
.508 .04591 Mdot
.508 .04597 Mdot
.508 .04625 Mdot
.508 .04641 Mdot
.508 .04647 Mdot
.508 .04675 Mdot
.508 .04692 Mdot
.508 .04698 Mdot
.508 .04727 Mdot
.508 .04743 Mdot
.508 .0475 Mdot
.508 .04779 Mdot
.508 .04796 Mdot
.508 .04802 Mdot
.508 .04832 Mdot
.508 .04849 Mdot
.508 .04855 Mdot
.508 .04885 Mdot
.508 .04903 Mdot
.508 .0491 Mdot
.508 .0494 Mdot
.508 .04958 Mdot
.508 .04965 Mdot
.508 .04996 Mdot
.508 .05013 Mdot
.508 .05021 Mdot
.508 .05052 Mdot
.508 .0507 Mdot
.508 .05077 Mdot
.508 .05109 Mdot
.508 .05128 Mdot
.508 .05135 Mdot
.508 .05167 Mdot
.508 .05186 Mdot
.508 .05194 Mdot
.508 .05227 Mdot
.508 .05246 Mdot
.508 .05253 Mdot
.508 .05287 Mdot
.508 .05306 Mdot
.508 .05314 Mdot
.508 .05348 Mdot
.508 .05367 Mdot
.508 .05375 Mdot
.508 .0541 Mdot
.508 .0543 Mdot
.508 .05438 Mdot
.508 .05473 Mdot
.508 .05493 Mdot
.508 .05501 Mdot
.508 .05537 Mdot
.508 .05557 Mdot
.508 .05566 Mdot
.508 .05602 Mdot
.508 .05623 Mdot
.508 .05668 Mdot
.508 .05689 Mdot
.508 .05735 Mdot
.508 .05757 Mdot
.508 .05803 Mdot
.508 .05825 Mdot
.508 .05873 Mdot
.508 .05895 Mdot
.508 .05943 Mdot
.508 .05966 Mdot
.508 .06015 Mdot
.508 .06038 Mdot
.508 .06087 Mdot
.508 .06111 Mdot
.508 .06161 Mdot
.508 .06185 Mdot
.508 .06236 Mdot
.508 .0626 Mdot
.508 .06312 Mdot
.508 .06337 Mdot
.508 .0639 Mdot
.508 .06415 Mdot
.508 .06469 Mdot
.508 .06494 Mdot
.508 .06548 Mdot
.508 .06574 Mdot
.508 .0663 Mdot
.508 .06656 Mdot
.508 .06712 Mdot
.508 .06739 Mdot
.508 .06796 Mdot
.508 .06823 Mdot
.508 .06881 Mdot
.508 .06909 Mdot
.508 .06968 Mdot
.508 .06996 Mdot
.508 .07056 Mdot
.508 .07084 Mdot
.508 .07145 Mdot
.508 .07174 Mdot
.508 .07236 Mdot
.508 .07265 Mdot
.508 .07328 Mdot
.508 .07358 Mdot
.508 .07422 Mdot
.508 .07452 Mdot
.508 .07517 Mdot
.508 .07548 Mdot
.508 .07614 Mdot
.508 .07645 Mdot
.508 .07712 Mdot
.508 .07744 Mdot
.508 .07812 Mdot
.508 .07844 Mdot
.508 .07913 Mdot
.508 .07946 Mdot
.508 .08016 Mdot
.508 .0805 Mdot
.508 .08121 Mdot
.508 .08155 Mdot
.508 .08228 Mdot
.508 .08262 Mdot
.508 .08336 Mdot
.508 .0837 Mdot
.508 .08445 Mdot
.508 .08481 Mdot
.508 .08557 Mdot
.508 .08593 Mdot
.508 .0867 Mdot
.508 .08707 Mdot
.508 .08786 Mdot
.508 .08823 Mdot
.508 .08903 Mdot
.508 .0894 Mdot
.508 .09021 Mdot
.508 .0906 Mdot
.508 .09142 Mdot
.508 .09181 Mdot
.508 .09265 Mdot
.508 .09304 Mdot
.508 .0939 Mdot
.508 .0943 Mdot
.508 .09516 Mdot
.508 .09557 Mdot
.508 .09645 Mdot
.508 .09686 Mdot
.508 .09776 Mdot
.508 .09818 Mdot
.508 .09909 Mdot
.508 .09951 Mdot
.508 .10044 Mdot
.508 .10087 Mdot
.508 .10181 Mdot
.508 .10225 Mdot
.508 .1032 Mdot
.508 .10365 Mdot
.508 .10462 Mdot
.508 .10507 Mdot
.508 .10606 Mdot
.508 .10652 Mdot
.508 .10752 Mdot
.508 .10759 Mdot
.508 .10799 Mdot
.508 .109 Mdot
.508 .10908 Mdot
.508 .10948 Mdot
.508 .11051 Mdot
.508 .11058 Mdot
.508 .111 Mdot
.508 .11204 Mdot
.508 .11212 Mdot
.508 .11254 Mdot
.508 .1136 Mdot
.508 .11368 Mdot
.508 .1141 Mdot
.508 .11518 Mdot
.508 .11526 Mdot
.508 .11569 Mdot
.508 .11679 Mdot
.508 .11687 Mdot
.508 .11731 Mdot
.508 .11842 Mdot
.508 .1185 Mdot
.508 .11895 Mdot
.508 .12008 Mdot
.508 .12016 Mdot
.508 .12062 Mdot
.508 .12177 Mdot
.508 .12185 Mdot
.508 .12231 Mdot
.508 .12348 Mdot
.508 .12357 Mdot
.508 .12403 Mdot
.508 .12522 Mdot
.508 .12531 Mdot
.508 .12578 Mdot
.508 .12699 Mdot
.508 .12708 Mdot
.508 .12756 Mdot
.508 .12879 Mdot
.508 .12887 Mdot
.508 .12937 Mdot
.508 .13061 Mdot
.508 .1307 Mdot
.508 .1312 Mdot
.508 .13247 Mdot
.508 .13256 Mdot
.508 .13306 Mdot
.508 .13435 Mdot
.508 .13444 Mdot
.508 .13496 Mdot
.508 .13627 Mdot
.508 .13636 Mdot
.508 .13688 Mdot
.508 .13821 Mdot
.508 .1383 Mdot
.508 .13884 Mdot
.508 .14019 Mdot
.508 .14028 Mdot
.508 .14082 Mdot
.508 .14219 Mdot
.508 .14229 Mdot
.508 .14284 Mdot
.508 .14423 Mdot
.508 .14433 Mdot
.508 .14489 Mdot
.508 .14631 Mdot
.508 .14641 Mdot
.508 .14697 Mdot
.508 .14841 Mdot
.508 .14851 Mdot
.508 .14909 Mdot
.508 .15055 Mdot
.508 .15065 Mdot
.508 .15124 Mdot
.508 .15272 Mdot
.508 .15283 Mdot
.508 .15342 Mdot
.508 .15493 Mdot
.508 .15504 Mdot
.508 .15564 Mdot
.508 .15718 Mdot
.508 .15728 Mdot
.508 .1579 Mdot
.508 .15945 Mdot
.508 .15957 Mdot
.508 .16019 Mdot
.508 .16177 Mdot
.508 .16188 Mdot
.508 .16252 Mdot
.508 .16412 Mdot
.508 .16424 Mdot
.508 .16488 Mdot
.508 .16651 Mdot
.508 .16663 Mdot
.508 .16728 Mdot
.508 .16894 Mdot
.508 .16906 Mdot
.508 .16972 Mdot
.508 .17141 Mdot
.508 .17153 Mdot
.508 .1722 Mdot
.508 .17392 Mdot
.508 .17404 Mdot
.508 .17472 Mdot
.508 .17646 Mdot
.508 .17659 Mdot
.508 .17728 Mdot
.508 .17905 Mdot
.508 .17918 Mdot
.508 .17988 Mdot
.508 .18168 Mdot
.508 .18181 Mdot
.508 .18253 Mdot
.508 .18435 Mdot
.508 .18448 Mdot
.508 .18521 Mdot
.508 .18707 Mdot
.508 .1872 Mdot
.508 .18794 Mdot
.508 .18983 Mdot
.508 .18996 Mdot
.508 .19071 Mdot
.508 .19263 Mdot
.508 .19276 Mdot
.508 .19353 Mdot
.508 .19547 Mdot
.508 .19561 Mdot
.508 .19639 Mdot
.508 .19837 Mdot
.508 .19851 Mdot
.508 .1993 Mdot
.508 .2013 Mdot
.508 .20145 Mdot
.508 .20225 Mdot
.508 .20429 Mdot
.508 .20443 Mdot
.508 .20525 Mdot
.508 .20732 Mdot
.508 .20747 Mdot
.508 .2083 Mdot
.508 .2104 Mdot
.508 .21055 Mdot
.508 .2114 Mdot
.508 .21354 Mdot
.508 .21369 Mdot
.508 .21454 Mdot
.508 .21672 Mdot
.508 .21687 Mdot
.508 .21774 Mdot
.508 .21995 Mdot
.508 .22011 Mdot
.508 .22099 Mdot
.508 .22323 Mdot
.508 .22339 Mdot
.508 .22429 Mdot
.508 .22657 Mdot
.508 .22673 Mdot
.508 .22764 Mdot
.508 .22996 Mdot
.508 .23012 Mdot
.508 .23105 Mdot
.508 .2334 Mdot
.508 .23357 Mdot
.508 .23451 Mdot
.508 .2369 Mdot
.508 .23707 Mdot
.508 .23803 Mdot
.508 .24046 Mdot
.508 .24063 Mdot
.508 .2416 Mdot
.508 .24407 Mdot
.508 .24424 Mdot
.508 .24523 Mdot
.508 .24774 Mdot
.508 .24792 Mdot
.508 .24892 Mdot
.508 .25147 Mdot
.508 .25165 Mdot
.508 .25266 Mdot
.508 .25525 Mdot
.508 .25544 Mdot
.508 .25647 Mdot
.508 .2591 Mdot
.508 .25929 Mdot
.508 .26034 Mdot
.508 .26301 Mdot
.508 .2632 Mdot
.508 .26427 Mdot
.508 .26699 Mdot
.508 .26718 Mdot
.508 .26826 Mdot
.508 .27102 Mdot
.508 .27122 Mdot
.508 .27232 Mdot
.508 .27512 Mdot
.508 .27532 Mdot
.508 .27644 Mdot
.508 .27929 Mdot
.508 .27949 Mdot
.508 .28063 Mdot
.508 .28352 Mdot
.508 .28373 Mdot
.508 .28488 Mdot
.508 .28782 Mdot
.508 .28803 Mdot
.508 .28921 Mdot
.508 .29219 Mdot
.508 .29241 Mdot
.508 .2936 Mdot
.508 .29663 Mdot
.508 .29685 Mdot
.508 .29806 Mdot
.508 .30114 Mdot
.508 .30136 Mdot
.508 .30259 Mdot
.508 .30573 Mdot
.508 .30595 Mdot
.508 .3072 Mdot
.508 .31038 Mdot
.508 .31061 Mdot
.508 .31188 Mdot
.508 .31511 Mdot
.51 .01535 Mdot
.51 .01536 Mdot
.51 .01538 Mdot
.51 .01539 Mdot
.51 .0154 Mdot
.51 .01542 Mdot
.51 .01543 Mdot
.51 .01545 Mdot
.51 .01546 Mdot
.51 .01548 Mdot
.51 .01549 Mdot
.51 .01551 Mdot
.51 .01552 Mdot
.51 .01554 Mdot
.51 .01556 Mdot
.51 .01557 Mdot
.51 .01559 Mdot
.51 .01561 Mdot
.51 .01562 Mdot
.51 .01564 Mdot
.51 .01566 Mdot
.51 .01568 Mdot
.51 .0157 Mdot
.51 .01572 Mdot
.51 .01574 Mdot
.51 .01576 Mdot
.51 .01578 Mdot
.51 .0158 Mdot
.51 .01582 Mdot
.51 .01583 Mdot
.51 .01585 Mdot
.51 .01585 Mdot
.51 .01587 Mdot
.51 .01587 Mdot
.51 .01589 Mdot
.51 .0159 Mdot
.51 .01592 Mdot
.51 .01592 Mdot
.51 .01594 Mdot
.51 .01594 Mdot
.51 .01596 Mdot
.51 .01597 Mdot
.51 .01599 Mdot
.51 .01599 Mdot
.51 .01601 Mdot
.51 .01602 Mdot
.51 .01604 Mdot
.51 .01605 Mdot
.51 .01607 Mdot
.51 .01607 Mdot
.51 .01609 Mdot
.51 .0161 Mdot
.51 .01612 Mdot
.51 .01613 Mdot
.51 .01615 Mdot
.51 .01615 Mdot
.51 .01618 Mdot
.51 .01618 Mdot
.51 .01621 Mdot
.51 .01621 Mdot
.51 .01624 Mdot
.51 .01624 Mdot
.51 .01627 Mdot
.51 .01627 Mdot
.51 .0163 Mdot
.51 .0163 Mdot
.51 .01633 Mdot
.51 .01634 Mdot
.51 .01636 Mdot
.51 .01637 Mdot
.51 .0164 Mdot
.51 .0164 Mdot
.51 .01643 Mdot
.51 .01644 Mdot
.51 .01646 Mdot
.51 .01647 Mdot
.51 .0165 Mdot
.51 .01651 Mdot
.51 .01653 Mdot
.51 .01654 Mdot
.51 .01657 Mdot
.51 .01658 Mdot
.51 .01661 Mdot
.51 .01661 Mdot
.51 .01665 Mdot
.51 .01665 Mdot
.51 .01668 Mdot
.51 .01669 Mdot
.51 .01672 Mdot
.51 .01673 Mdot
.51 .01676 Mdot
.51 .01677 Mdot
.51 .0168 Mdot
.51 .01681 Mdot
.51 .01685 Mdot
.51 .01685 Mdot
.51 .01689 Mdot
.51 .0169 Mdot
.51 .01693 Mdot
.51 .01694 Mdot
.51 .01698 Mdot
.51 .01699 Mdot
.51 .01702 Mdot
.51 .01703 Mdot
.51 .01707 Mdot
.51 .01708 Mdot
.51 .01712 Mdot
.51 .01712 Mdot
.51 .01716 Mdot
.51 .01717 Mdot
.51 .01721 Mdot
.51 .01722 Mdot
.51 .01726 Mdot
.51 .01727 Mdot
.51 .01731 Mdot
.51 .01732 Mdot
.51 .01737 Mdot
.51 .01738 Mdot
.51 .01742 Mdot
.51 .01743 Mdot
.51 .01747 Mdot
.51 .01748 Mdot
.51 .01749 Mdot
.51 .01753 Mdot
.51 .01754 Mdot
.51 .01754 Mdot
.51 .01758 Mdot
.51 .01759 Mdot
.51 .0176 Mdot
.51 .01764 Mdot
.51 .01765 Mdot
.51 .01766 Mdot
.51 .0177 Mdot
.51 .01771 Mdot
.51 .01772 Mdot
.51 .01776 Mdot
.51 .01777 Mdot
.51 .01778 Mdot
.51 .01782 Mdot
.51 .01783 Mdot
.51 .01784 Mdot
.51 .01788 Mdot
.51 .01789 Mdot
.51 .0179 Mdot
.51 .01795 Mdot
.51 .01796 Mdot
.51 .01796 Mdot
.51 .01801 Mdot
.51 .01802 Mdot
.51 .01803 Mdot
.51 .01808 Mdot
.51 .01809 Mdot
.51 .01809 Mdot
.51 .01814 Mdot
.51 .01816 Mdot
.51 .01816 Mdot
.51 .01821 Mdot
.51 .01823 Mdot
.51 .01823 Mdot
.51 .01828 Mdot
.51 .0183 Mdot
.51 .0183 Mdot
.51 .01835 Mdot
.51 .01837 Mdot
.51 .01837 Mdot
.51 .01843 Mdot
.51 .01844 Mdot
.51 .01845 Mdot
.51 .0185 Mdot
.51 .01851 Mdot
.51 .01852 Mdot
.51 .01858 Mdot
.51 .01859 Mdot
.51 .0186 Mdot
.51 .01865 Mdot
.51 .01867 Mdot
.51 .01867 Mdot
.51 .01873 Mdot
.51 .01875 Mdot
.51 .01875 Mdot
.51 .01881 Mdot
.51 .01883 Mdot
.51 .01883 Mdot
.51 .01889 Mdot
.51 .01891 Mdot
.51 .01892 Mdot
.51 .01898 Mdot
.51 .01899 Mdot
.51 .019 Mdot
.51 .01906 Mdot
.51 .01908 Mdot
.51 .01909 Mdot
.51 .01915 Mdot
.51 .01917 Mdot
.51 .01917 Mdot
.51 .01924 Mdot
.51 .01926 Mdot
.51 .01926 Mdot
.51 .01933 Mdot
.51 .01935 Mdot
.51 .01935 Mdot
.51 .01942 Mdot
.51 .01944 Mdot
.51 .01945 Mdot
.51 .01952 Mdot
.51 .01953 Mdot
.51 .01954 Mdot
.51 .01961 Mdot
.51 .01963 Mdot
.51 .01964 Mdot
.51 .01971 Mdot
.51 .01973 Mdot
.51 .01974 Mdot
.51 .01981 Mdot
.51 .01983 Mdot
.51 .01984 Mdot
.51 .01991 Mdot
.51 .01993 Mdot
.51 .01994 Mdot
.51 .02002 Mdot
.51 .02004 Mdot
.51 .02004 Mdot
.51 .02012 Mdot
.51 .02014 Mdot
.51 .02015 Mdot
.51 .02023 Mdot
.51 .02025 Mdot
.51 .02025 Mdot
.51 .02026 Mdot
.51 .02034 Mdot
.51 .02036 Mdot
.51 .02036 Mdot
.51 .02037 Mdot
.51 .02045 Mdot
.51 .02047 Mdot
.51 .02047 Mdot
.51 .02048 Mdot
.51 .02057 Mdot
.51 .02058 Mdot
.51 .02059 Mdot
.51 .0206 Mdot
.51 .02068 Mdot
.51 .0207 Mdot
.51 .02071 Mdot
.51 .02072 Mdot
.51 .0208 Mdot
.51 .02082 Mdot
.51 .02083 Mdot
.51 .02084 Mdot
.51 .02092 Mdot
.51 .02094 Mdot
.51 .02095 Mdot
.51 .02096 Mdot
.51 .02105 Mdot
.51 .02107 Mdot
.51 .02107 Mdot
.51 .02108 Mdot
.51 .02118 Mdot
.51 .02119 Mdot
.51 .0212 Mdot
.51 .02121 Mdot
.51 .02131 Mdot
.51 .02132 Mdot
.51 .02133 Mdot
.51 .02134 Mdot
.51 .02144 Mdot
.51 .02146 Mdot
.51 .02146 Mdot
.51 .02147 Mdot
.51 .02157 Mdot
.51 .02159 Mdot
.51 .0216 Mdot
.51 .02161 Mdot
.51 .02171 Mdot
.51 .02173 Mdot
.51 .02173 Mdot
.51 .02175 Mdot
.51 .02185 Mdot
.51 .02187 Mdot
.51 .02188 Mdot
.51 .02189 Mdot
.51 .02199 Mdot
.51 .02201 Mdot
.51 .02202 Mdot
.51 .02203 Mdot
.51 .02214 Mdot
.51 .02216 Mdot
.51 .02216 Mdot
.51 .02218 Mdot
.51 .02228 Mdot
.51 .02231 Mdot
.51 .02231 Mdot
.51 .02233 Mdot
.51 .02244 Mdot
.51 .02246 Mdot
.51 .02247 Mdot
.51 .02248 Mdot
.51 .02259 Mdot
.51 .02261 Mdot
.51 .02262 Mdot
.51 .02263 Mdot
.51 .02275 Mdot
.51 .02277 Mdot
.51 .02278 Mdot
.51 .02279 Mdot
.51 .02291 Mdot
.51 .02293 Mdot
.51 .02294 Mdot
.51 .02295 Mdot
.51 .02307 Mdot
.51 .0231 Mdot
.51 .0231 Mdot
.51 .02312 Mdot
.51 .02324 Mdot
.51 .02326 Mdot
.51 .02327 Mdot
.51 .02329 Mdot
.51 .02341 Mdot
.51 .02344 Mdot
.51 .02344 Mdot
.51 .02346 Mdot
.51 .02358 Mdot
.51 .02361 Mdot
.51 .02362 Mdot
.51 .02363 Mdot
.51 .02376 Mdot
.51 .02379 Mdot
.51 .0238 Mdot
.51 .02381 Mdot
.51 .02394 Mdot
.51 .02397 Mdot
.51 .02398 Mdot
.51 .02399 Mdot
.51 .02413 Mdot
.51 .02415 Mdot
.51 .02416 Mdot
.51 .02418 Mdot
.51 .02432 Mdot
.51 .02434 Mdot
.51 .02435 Mdot
.51 .02437 Mdot
.51 .02451 Mdot
.51 .02454 Mdot
.51 .02454 Mdot
.51 .02456 Mdot
.51 .0247 Mdot
.51 .02473 Mdot
.51 .02474 Mdot
.51 .02476 Mdot
.51 .0249 Mdot
.51 .02493 Mdot
.51 .02494 Mdot
.51 .02496 Mdot
.51 .02511 Mdot
.51 .02514 Mdot
.51 .02515 Mdot
.51 .02516 Mdot
.51 .02531 Mdot
.51 .02535 Mdot
.51 .02535 Mdot
.51 .02537 Mdot
.51 .02553 Mdot
.51 .02556 Mdot
.51 .02557 Mdot
.51 .02558 Mdot
.51 .02574 Mdot
.51 .02578 Mdot
.51 .02578 Mdot
.51 .0258 Mdot
.51 .02596 Mdot
.51 .026 Mdot
.51 .02601 Mdot
.51 .02602 Mdot
.51 .02619 Mdot
.51 .02622 Mdot
.51 .02623 Mdot
.51 .02625 Mdot
.51 .02642 Mdot
.51 .02645 Mdot
.51 .02646 Mdot
.51 .02648 Mdot
.51 .02665 Mdot
.51 .02669 Mdot
.51 .0267 Mdot
.51 .02672 Mdot
.51 .02689 Mdot
.51 .02693 Mdot
.51 .02694 Mdot
.51 .02696 Mdot
.51 .02713 Mdot
.51 .02717 Mdot
.51 .02718 Mdot
.51 .0272 Mdot
.51 .02738 Mdot
.51 .02742 Mdot
.51 .02743 Mdot
.51 .02745 Mdot
.51 .02764 Mdot
.51 .02767 Mdot
.51 .02768 Mdot
.51 .0277 Mdot
.51 .02789 Mdot
.51 .02793 Mdot
.51 .02794 Mdot
.51 .02796 Mdot
.51 .02816 Mdot
.51 .0282 Mdot
.51 .02821 Mdot
.51 .02823 Mdot
.51 .02843 Mdot
.51 .02847 Mdot
.51 .02848 Mdot
.51 .0285 Mdot
.51 .0287 Mdot
.51 .02874 Mdot
.51 .02875 Mdot
.51 .02878 Mdot
.51 .02898 Mdot
.51 .02902 Mdot
.51 .02903 Mdot
.51 .02906 Mdot
.51 .02927 Mdot
.51 .02931 Mdot
.51 .02932 Mdot
.51 .02934 Mdot
.51 .02956 Mdot
.51 .0296 Mdot
.51 .02961 Mdot
.51 .02964 Mdot
.51 .02985 Mdot
.51 .0299 Mdot
.51 .02991 Mdot
.51 .02993 Mdot
.51 .03016 Mdot
.51 .0302 Mdot
.51 .03021 Mdot
.51 .03024 Mdot
.51 .03047 Mdot
.51 .03051 Mdot
.51 .03052 Mdot
.51 .03055 Mdot
.51 .03078 Mdot
.51 .03083 Mdot
.51 .03084 Mdot
.51 .03087 Mdot
.51 .0311 Mdot
.51 .03115 Mdot
.51 .03116 Mdot
.51 .03119 Mdot
.51 .03143 Mdot
.51 .03148 Mdot
.51 .03149 Mdot
.51 .03152 Mdot
.51 .03176 Mdot
.51 .03181 Mdot
.51 .03183 Mdot
.51 .03185 Mdot
.51 .0321 Mdot
.51 .03216 Mdot
.51 .03217 Mdot
.51 .0322 Mdot
.51 .03245 Mdot
.51 .0325 Mdot
.51 .03252 Mdot
.51 .03255 Mdot
.51 .03281 Mdot
.51 .03286 Mdot
.51 .03288 Mdot
.51 .0329 Mdot
.51 .03317 Mdot
.51 .03322 Mdot
.51 .03324 Mdot
.51 .03327 Mdot
.51 .03354 Mdot
.51 .03359 Mdot
.51 .03361 Mdot
.51 .03364 Mdot
.51 .03391 Mdot
.51 .03397 Mdot
.51 .03399 Mdot
.51 .03402 Mdot
.51 .0343 Mdot
.51 .03436 Mdot
.51 .03437 Mdot
.51 .0344 Mdot
.51 .03469 Mdot
.51 .03475 Mdot
.51 .03477 Mdot
.51 .0348 Mdot
.51 .03509 Mdot
.51 .03515 Mdot
.51 .03517 Mdot
.51 .0352 Mdot
.51 .0355 Mdot
.51 .03556 Mdot
.51 .03558 Mdot
.51 .03561 Mdot
.51 .03591 Mdot
.51 .03598 Mdot
.51 .03599 Mdot
.51 .03603 Mdot
.51 .03634 Mdot
.51 .0364 Mdot
.51 .03642 Mdot
.51 .03645 Mdot
.51 .03677 Mdot
.51 .03683 Mdot
.51 .03685 Mdot
.51 .03689 Mdot
.51 .03721 Mdot
.51 .03728 Mdot
.51 .03729 Mdot
.51 .03733 Mdot
.51 .03766 Mdot
.51 .03773 Mdot
.51 .03775 Mdot
.51 .03778 Mdot
.51 .03812 Mdot
.51 .03819 Mdot
.51 .03821 Mdot
.51 .03824 Mdot
.51 .03859 Mdot
.51 .03866 Mdot
.51 .03868 Mdot
.51 .03871 Mdot
.51 .03906 Mdot
.51 .03914 Mdot
.51 .03916 Mdot
.51 .03919 Mdot
.51 .03955 Mdot
.51 .03962 Mdot
.51 .03964 Mdot
.51 .03968 Mdot
.51 .04005 Mdot
.51 .04012 Mdot
.51 .04014 Mdot
.51 .04018 Mdot
.51 .04056 Mdot
.51 .04063 Mdot
.51 .04065 Mdot
.51 .04069 Mdot
.51 .04107 Mdot
.51 .04115 Mdot
.51 .04117 Mdot
.51 .04121 Mdot
.51 .0416 Mdot
.51 .04168 Mdot
.51 .0417 Mdot
.51 .04174 Mdot
.51 .04214 Mdot
.51 .04222 Mdot
.51 .04224 Mdot
.51 .04228 Mdot
.51 .04269 Mdot
.51 .04277 Mdot
.51 .04279 Mdot
.51 .04283 Mdot
.51 .04324 Mdot
.51 .04333 Mdot
.51 .04335 Mdot
.51 .0434 Mdot
.51 .04382 Mdot
.51 .0439 Mdot
.51 .04392 Mdot
.51 .04397 Mdot
.51 .0444 Mdot
.51 .04448 Mdot
.51 .04451 Mdot
.51 .04456 Mdot
.51 .04499 Mdot
.51 .04508 Mdot
.51 .0451 Mdot
.51 .04515 Mdot
.51 .0456 Mdot
.51 .04569 Mdot
.51 .04571 Mdot
.51 .04576 Mdot
.51 .04621 Mdot
.51 .04631 Mdot
.51 .04633 Mdot
.51 .04638 Mdot
.51 .04684 Mdot
.51 .04694 Mdot
.51 .04696 Mdot
.51 .04702 Mdot
.51 .04749 Mdot
.51 .04758 Mdot
.51 .04761 Mdot
.51 .04766 Mdot
.51 .04814 Mdot
.51 .04824 Mdot
.51 .04827 Mdot
.51 .04832 Mdot
.51 .04881 Mdot
.51 .04891 Mdot
.51 .04894 Mdot
.51 .04899 Mdot
.51 .04949 Mdot
.51 .04959 Mdot
.51 .04962 Mdot
.51 .04968 Mdot
.51 .05019 Mdot
.51 .05029 Mdot
.51 .05032 Mdot
.51 .05038 Mdot
.51 .0509 Mdot
.51 .051 Mdot
.51 .05103 Mdot
.51 .05109 Mdot
.51 .05162 Mdot
.51 .05173 Mdot
.51 .05176 Mdot
.51 .05182 Mdot
.51 .05236 Mdot
.51 .05247 Mdot
.51 .0525 Mdot
.51 .05256 Mdot
.51 .05311 Mdot
.51 .05322 Mdot
.51 .05326 Mdot
.51 .05332 Mdot
.51 .05388 Mdot
.51 .05399 Mdot
.51 .05403 Mdot
.51 .05409 Mdot
.51 .05466 Mdot
.51 .05478 Mdot
.51 .05481 Mdot
.51 .05488 Mdot
.51 .05546 Mdot
.51 .05558 Mdot
.51 .05562 Mdot
.51 .05568 Mdot
.51 .05628 Mdot
.51 .0564 Mdot
.51 .05643 Mdot
.51 .0565 Mdot
.51 .05711 Mdot
.51 .05727 Mdot
.51 .05733 Mdot
.51 .05796 Mdot
.51 .05812 Mdot
.51 .05819 Mdot
.51 .05882 Mdot
.51 .05899 Mdot
.51 .05906 Mdot
.51 .0597 Mdot
.51 .05987 Mdot
.51 .05994 Mdot
.51 .0606 Mdot
.51 .06078 Mdot
.51 .06085 Mdot
.51 .06152 Mdot
.51 .0617 Mdot
.51 .06177 Mdot
.51 .06246 Mdot
.51 .06264 Mdot
.51 .06271 Mdot
.51 .06341 Mdot
.51 .06359 Mdot
.51 .06367 Mdot
.51 .06439 Mdot
.51 .06457 Mdot
.51 .06465 Mdot
.51 .06538 Mdot
.51 .06557 Mdot
.51 .06565 Mdot
.51 .06639 Mdot
.51 .06659 Mdot
.51 .06667 Mdot
.51 .06743 Mdot
.51 .06762 Mdot
.51 .06771 Mdot
.51 .06848 Mdot
.51 .06868 Mdot
.51 .06877 Mdot
.51 .06956 Mdot
.51 .06976 Mdot
.51 .06985 Mdot
.51 .07065 Mdot
.51 .07086 Mdot
.51 .07095 Mdot
.51 .07177 Mdot
.51 .07198 Mdot
.51 .07208 Mdot
.51 .07291 Mdot
.51 .07313 Mdot
.51 .07322 Mdot
.51 .07408 Mdot
.51 .0743 Mdot
.51 .07439 Mdot
.51 .07526 Mdot
.51 .07549 Mdot
.51 .07559 Mdot
.51 .07647 Mdot
.51 .07671 Mdot
.51 .0768 Mdot
.51 .07771 Mdot
.51 .07795 Mdot
.51 .07805 Mdot
.51 .07897 Mdot
.51 .07921 Mdot
.51 .07931 Mdot
.51 .08025 Mdot
.51 .0805 Mdot
.51 .0806 Mdot
.51 .08157 Mdot
.51 .08182 Mdot
.51 .08192 Mdot
.51 .0829 Mdot
.51 .08316 Mdot
.51 .08327 Mdot
.51 .08427 Mdot
.51 .08453 Mdot
.51 .08464 Mdot
.51 .08566 Mdot
.51 .08592 Mdot
.51 .08604 Mdot
.51 .08708 Mdot
.51 .08735 Mdot
.51 .08746 Mdot
.51 .08852 Mdot
.51 .0888 Mdot
.51 .08892 Mdot
.51 .09 Mdot
.51 .09028 Mdot
.51 .0904 Mdot
.51 .0915 Mdot
.51 .09179 Mdot
.51 .09191 Mdot
.51 .09304 Mdot
.51 .09333 Mdot
.51 .09346 Mdot
.51 .09461 Mdot
.51 .09491 Mdot
.51 .09503 Mdot
.51 .0962 Mdot
.51 .09651 Mdot
.51 .09664 Mdot
.51 .09709 Mdot
.51 .09783 Mdot
.51 .09815 Mdot
.51 .09828 Mdot
.51 .09874 Mdot
.51 .0995 Mdot
.51 .09981 Mdot
.51 .09995 Mdot
.51 .10042 Mdot
.51 .10119 Mdot
.51 .10152 Mdot
.51 .10165 Mdot
.51 .10213 Mdot
.51 .10292 Mdot
.51 .10325 Mdot
.51 .10339 Mdot
.51 .10388 Mdot
.51 .10469 Mdot
.51 .10502 Mdot
.51 .10517 Mdot
.51 .10566 Mdot
.51 .10649 Mdot
.51 .10683 Mdot
.51 .10698 Mdot
.51 .10748 Mdot
.51 .10832 Mdot
.51 .10867 Mdot
.51 .10882 Mdot
.51 .10934 Mdot
.51 .11019 Mdot
.51 .11055 Mdot
.51 .1107 Mdot
.51 .11123 Mdot
.51 .1121 Mdot
.51 .11247 Mdot
.51 .11262 Mdot
.51 .11316 Mdot
.51 .11405 Mdot
.51 .11442 Mdot
.51 .11458 Mdot
.51 .11513 Mdot
.51 .11604 Mdot
.51 .11642 Mdot
.51 .11658 Mdot
.51 .11714 Mdot
.51 .11806 Mdot
.51 .11845 Mdot
.51 .11861 Mdot
.51 .11918 Mdot
.51 .12013 Mdot
.51 .12053 Mdot
.51 .12069 Mdot
.51 .12127 Mdot
.51 .12224 Mdot
.51 .12264 Mdot
.51 .12281 Mdot
.51 .1234 Mdot
.51 .12439 Mdot
.51 .1248 Mdot
.51 .12497 Mdot
.51 .12558 Mdot
.51 .12658 Mdot
.51 .127 Mdot
.51 .12718 Mdot
.51 .1278 Mdot
.51 .12882 Mdot
.51 .12925 Mdot
.51 .12943 Mdot
.51 .13006 Mdot
.51 .1311 Mdot
.51 .13154 Mdot
.51 .13172 Mdot
.51 .13236 Mdot
.51 .13343 Mdot
.51 .13388 Mdot
.51 .13406 Mdot
.51 .13472 Mdot
.51 .1358 Mdot
.51 .13626 Mdot
.51 .13645 Mdot
.51 .13712 Mdot
.51 .13823 Mdot
.51 .13869 Mdot
.51 .13888 Mdot
.51 .13957 Mdot
.51 .1407 Mdot
.51 .14117 Mdot
.51 .14137 Mdot
.51 .14206 Mdot
.51 .14322 Mdot
.51 .1437 Mdot
.51 .1439 Mdot
.51 .14461 Mdot
.51 .14579 Mdot
.51 .14628 Mdot
.51 .14648 Mdot
.51 .14721 Mdot
.51 .14841 Mdot
.51 .14891 Mdot
.51 .14912 Mdot
.51 .14986 Mdot
.51 .15108 Mdot
.51 .15159 Mdot
.51 .15181 Mdot
.51 .15256 Mdot
.51 .15381 Mdot
.51 .15433 Mdot
.51 .15455 Mdot
.51 .15532 Mdot
.51 .15659 Mdot
.51 .15712 Mdot
.51 .15735 Mdot
.51 .15813 Mdot
.51 .15943 Mdot
.51 .15997 Mdot
.51 .1602 Mdot
.51 .161 Mdot
.51 .16232 Mdot
.51 .16288 Mdot
.51 .16311 Mdot
.51 .16392 Mdot
.51 .16527 Mdot
.51 .16584 Mdot
.51 .16608 Mdot
.51 .16691 Mdot
.51 .16829 Mdot
.51 .16886 Mdot
.51 .1691 Mdot
.51 .16995 Mdot
.51 .17136 Mdot
.51 .17194 Mdot
.51 .17219 Mdot
.51 .17306 Mdot
.51 .17449 Mdot
.51 .17509 Mdot
.51 .17534 Mdot
.51 .17622 Mdot
.51 .17769 Mdot
.51 .1783 Mdot
.51 .17855 Mdot
.51 .17945 Mdot
.51 .18095 Mdot
.51 .18157 Mdot
.51 .18183 Mdot
.51 .18275 Mdot
.51 .18427 Mdot
.51 .18491 Mdot
.51 .18517 Mdot
.51 .18611 Mdot
.51 .18766 Mdot
.51 .18831 Mdot
.51 .18858 Mdot
.51 .18954 Mdot
.51 .19112 Mdot
.51 .19178 Mdot
.51 .19206 Mdot
.51 .19303 Mdot
.51 .19465 Mdot
.51 .19532 Mdot
.51 .19561 Mdot
.51 .1966 Mdot
.51 .19825 Mdot
.51 .19893 Mdot
.51 .19922 Mdot
.51 .20024 Mdot
.51 .20192 Mdot
.51 .20262 Mdot
.51 .20291 Mdot
.51 .20395 Mdot
.51 .20566 Mdot
.51 .20638 Mdot
.51 .20668 Mdot
.51 .20773 Mdot
.51 .20948 Mdot
.51 .21021 Mdot
.51 .21052 Mdot
.51 .21159 Mdot
.51 .21338 Mdot
.51 .21412 Mdot
.51 .21443 Mdot
.51 .21553 Mdot
.51 .21735 Mdot
.51 .21811 Mdot
.51 .21843 Mdot
.51 .21955 Mdot
.51 .2214 Mdot
.51 .22218 Mdot
.51 .2225 Mdot
.51 .22364 Mdot
.51 .22554 Mdot
.51 .22633 Mdot
.51 .22666 Mdot
.51 .22782 Mdot
.51 .22975 Mdot
.51 .23056 Mdot
.51 .2309 Mdot
.51 .23208 Mdot
.51 .23405 Mdot
.51 .23487 Mdot
.51 .23522 Mdot
.51 .23643 Mdot
.51 .23844 Mdot
.51 .23928 Mdot
.51 .23963 Mdot
.51 .24086 Mdot
.51 .24291 Mdot
.51 .24377 Mdot
.51 .24413 Mdot
.51 .24539 Mdot
.51 .24748 Mdot
.51 .24835 Mdot
.51 .24872 Mdot
.51 .25 Mdot
.51 .25213 Mdot
.51 .25302 Mdot
.51 .2534 Mdot
.51 .25471 Mdot
.51 .25688 Mdot
.51 .25779 Mdot
.51 .25817 Mdot
.51 .25951 Mdot
.51 .26172 Mdot
.51 .26265 Mdot
.51 .26304 Mdot
.51 .2644 Mdot
.51 .26666 Mdot
.51 .26761 Mdot
.51 .26801 Mdot
.51 .2694 Mdot
.51 .2717 Mdot
.51 .27267 Mdot
.51 .27307 Mdot
.51 .27449 Mdot
.51 .27684 Mdot
.51 .27783 Mdot
.51 .27824 Mdot
.51 .27968 Mdot
.51 .28209 Mdot
.51 .28309 Mdot
.51 .28351 Mdot
.51 .28498 Mdot
.51 .28743 Mdot
.51 .28846 Mdot
.51 .28889 Mdot
.51 .29039 Mdot
.51 .29289 Mdot
.51 .29393 Mdot
.51 .29437 Mdot
.51 .2959 Mdot
.51 .29845 Mdot
.51 .29951 Mdot
.51 .29996 Mdot
.51 .30153 Mdot
.51 .30413 Mdot
.51 .30521 Mdot
.51 .30567 Mdot
.51 .30726 Mdot
.51 .30991 Mdot
.51 .31102 Mdot
.51 .31149 Mdot
.51 .31311 Mdot
.51 .31582 Mdot
.512 .01605 Mdot
.512 .01608 Mdot
.512 .01611 Mdot
.512 .01613 Mdot
.512 .01615 Mdot
.512 .01617 Mdot
.512 .01618 Mdot
.512 .0162 Mdot
.512 .01622 Mdot
.512 .01624 Mdot
.512 .01625 Mdot
.512 .01627 Mdot
.512 .01629 Mdot
.512 .01631 Mdot
.512 .01633 Mdot
.512 .01634 Mdot
.512 .01635 Mdot
.512 .01636 Mdot
.512 .01638 Mdot
.512 .01639 Mdot
.512 .0164 Mdot
.512 .01642 Mdot
.512 .01643 Mdot
.512 .01645 Mdot
.512 .01646 Mdot
.512 .01649 Mdot
.512 .0165 Mdot
.512 .01653 Mdot
.512 .01654 Mdot
.512 .01657 Mdot
.512 .01659 Mdot
.512 .01662 Mdot
.512 .01663 Mdot
.512 .01666 Mdot
.512 .01668 Mdot
.512 .01671 Mdot
.512 .01673 Mdot
.512 .01676 Mdot
.512 .01677 Mdot
.512 .01681 Mdot
.512 .01682 Mdot
.512 .01686 Mdot
.512 .01688 Mdot
.512 .01691 Mdot
.512 .01693 Mdot
.512 .01696 Mdot
.512 .01698 Mdot
.512 .01701 Mdot
.512 .01703 Mdot
.512 .01707 Mdot
.512 .01709 Mdot
.512 .01713 Mdot
.512 .01715 Mdot
.512 .01718 Mdot
.512 .01721 Mdot
.512 .01724 Mdot
.512 .01727 Mdot
.512 .0173 Mdot
.512 .01733 Mdot
.512 .01737 Mdot
.512 .01739 Mdot
.512 .01743 Mdot
.512 .01745 Mdot
.512 .0175 Mdot
.512 .01752 Mdot
.512 .01756 Mdot
.512 .01759 Mdot
.512 .01763 Mdot
.512 .01763 Mdot
.512 .01766 Mdot
.512 .0177 Mdot
.512 .0177 Mdot
.512 .01773 Mdot
.512 .01777 Mdot
.512 .01777 Mdot
.512 .0178 Mdot
.512 .01784 Mdot
.512 .01785 Mdot
.512 .01787 Mdot
.512 .01792 Mdot
.512 .01792 Mdot
.512 .01795 Mdot
.512 .01799 Mdot
.512 .018 Mdot
.512 .01803 Mdot
.512 .01807 Mdot
.512 .01808 Mdot
.512 .0181 Mdot
.512 .01815 Mdot
.512 .01816 Mdot
.512 .01819 Mdot
.512 .01824 Mdot
.512 .01824 Mdot
.512 .01827 Mdot
.512 .01832 Mdot
.512 .01832 Mdot
.512 .01835 Mdot
.512 .01841 Mdot
.512 .01841 Mdot
.512 .01844 Mdot
.512 .0185 Mdot
.512 .0185 Mdot
.512 .01853 Mdot
.512 .01859 Mdot
.512 .01859 Mdot
.512 .01862 Mdot
.512 .01868 Mdot
.512 .01868 Mdot
.512 .01872 Mdot
.512 .01878 Mdot
.512 .01878 Mdot
.512 .01881 Mdot
.512 .01887 Mdot
.512 .01888 Mdot
.512 .01891 Mdot
.512 .01894 Mdot
.512 .01897 Mdot
.512 .01898 Mdot
.512 .01901 Mdot
.512 .01904 Mdot
.512 .01907 Mdot
.512 .01908 Mdot
.512 .01912 Mdot
.512 .01914 Mdot
.512 .01918 Mdot
.512 .01918 Mdot
.512 .01922 Mdot
.512 .01925 Mdot
.512 .01929 Mdot
.512 .01929 Mdot
.512 .01933 Mdot
.512 .01936 Mdot
.512 .0194 Mdot
.512 .0194 Mdot
.512 .01944 Mdot
.512 .01947 Mdot
.512 .01951 Mdot
.512 .01951 Mdot
.512 .01955 Mdot
.512 .01958 Mdot
.512 .01962 Mdot
.512 .01963 Mdot
.512 .01967 Mdot
.512 .0197 Mdot
.512 .01974 Mdot
.512 .01974 Mdot
.512 .01979 Mdot
.512 .01982 Mdot
.512 .01986 Mdot
.512 .01987 Mdot
.512 .01991 Mdot
.512 .01994 Mdot
.512 .01999 Mdot
.512 .01999 Mdot
.512 .02003 Mdot
.512 .02007 Mdot
.512 .02011 Mdot
.512 .02012 Mdot
.512 .02016 Mdot
.512 .0202 Mdot
.512 .02024 Mdot
.512 .02025 Mdot
.512 .02029 Mdot
.512 .02033 Mdot
.512 .02037 Mdot
.512 .02038 Mdot
.512 .02043 Mdot
.512 .02046 Mdot
.512 .02051 Mdot
.512 .02051 Mdot
.512 .02056 Mdot
.512 .0206 Mdot
.512 .02065 Mdot
.512 .02065 Mdot
.512 .0207 Mdot
.512 .02074 Mdot
.512 .02079 Mdot
.512 .0208 Mdot
.512 .02082 Mdot
.512 .02085 Mdot
.512 .02089 Mdot
.512 .02094 Mdot
.512 .02094 Mdot
.512 .02097 Mdot
.512 .02099 Mdot
.512 .02103 Mdot
.512 .02109 Mdot
.512 .02109 Mdot
.512 .02112 Mdot
.512 .02115 Mdot
.512 .02119 Mdot
.512 .02124 Mdot
.512 .02124 Mdot
.512 .02127 Mdot
.512 .0213 Mdot
.512 .02134 Mdot
.512 .0214 Mdot
.512 .0214 Mdot
.512 .02143 Mdot
.512 .02146 Mdot
.512 .0215 Mdot
.512 .02156 Mdot
.512 .02156 Mdot
.512 .02159 Mdot
.512 .02162 Mdot
.512 .02166 Mdot
.512 .02172 Mdot
.512 .02173 Mdot
.512 .02176 Mdot
.512 .02179 Mdot
.512 .02183 Mdot
.512 .02189 Mdot
.512 .02189 Mdot
.512 .02192 Mdot
.512 .02196 Mdot
.512 .022 Mdot
.512 .02206 Mdot
.512 .02207 Mdot
.512 .0221 Mdot
.512 .02213 Mdot
.512 .02217 Mdot
.512 .02224 Mdot
.512 .02224 Mdot
.512 .02227 Mdot
.512 .02231 Mdot
.512 .02235 Mdot
.512 .02242 Mdot
.512 .02242 Mdot
.512 .02246 Mdot
.512 .02249 Mdot
.512 .02254 Mdot
.512 .0226 Mdot
.512 .02261 Mdot
.512 .02264 Mdot
.512 .02268 Mdot
.512 .02272 Mdot
.512 .02279 Mdot
.512 .0228 Mdot
.512 .02283 Mdot
.512 .02287 Mdot
.512 .02292 Mdot
.512 .02299 Mdot
.512 .02299 Mdot
.512 .02303 Mdot
.512 .02306 Mdot
.512 .02311 Mdot
.512 .02318 Mdot
.512 .02319 Mdot
.512 .02323 Mdot
.512 .02326 Mdot
.512 .02332 Mdot
.512 .02339 Mdot
.512 .02339 Mdot
.512 .02343 Mdot
.512 .02347 Mdot
.512 .02352 Mdot
.512 .0236 Mdot
.512 .0236 Mdot
.512 .02364 Mdot
.512 .02368 Mdot
.512 .02373 Mdot
.512 .02381 Mdot
.512 .02382 Mdot
.512 .02385 Mdot
.512 .02389 Mdot
.512 .02395 Mdot
.512 .02403 Mdot
.512 .02403 Mdot
.512 .02407 Mdot
.512 .02411 Mdot
.512 .02417 Mdot
.512 .02425 Mdot
.512 .02426 Mdot
.512 .0243 Mdot
.512 .02434 Mdot
.512 .0244 Mdot
.512 .02448 Mdot
.512 .02449 Mdot
.512 .02453 Mdot
.512 .02457 Mdot
.512 .02463 Mdot
.512 .02471 Mdot
.512 .02472 Mdot
.512 .02476 Mdot
.512 .02481 Mdot
.512 .02487 Mdot
.512 .02495 Mdot
.512 .02496 Mdot
.512 .025 Mdot
.512 .02505 Mdot
.512 .02511 Mdot
.512 .0252 Mdot
.512 .02521 Mdot
.512 .02525 Mdot
.512 .0253 Mdot
.512 .02536 Mdot
.512 .02545 Mdot
.512 .02546 Mdot
.512 .0255 Mdot
.512 .02555 Mdot
.512 .02562 Mdot
.512 .02571 Mdot
.512 .02572 Mdot
.512 .02576 Mdot
.512 .02581 Mdot
.512 .02588 Mdot
.512 .02597 Mdot
.512 .02598 Mdot
.512 .02603 Mdot
.512 .02608 Mdot
.512 .02615 Mdot
.512 .02624 Mdot
.512 .02625 Mdot
.512 .0263 Mdot
.512 .02635 Mdot
.512 .02642 Mdot
.512 .02652 Mdot
.512 .02653 Mdot
.512 .02658 Mdot
.512 .02663 Mdot
.512 .0267 Mdot
.512 .0268 Mdot
.512 .02681 Mdot
.512 .02686 Mdot
.512 .02691 Mdot
.512 .02699 Mdot
.512 .02709 Mdot
.512 .0271 Mdot
.512 .02715 Mdot
.512 .02721 Mdot
.512 .02728 Mdot
.512 .02739 Mdot
.512 .0274 Mdot
.512 .02745 Mdot
.512 .02751 Mdot
.512 .02759 Mdot
.512 .02769 Mdot
.512 .0277 Mdot
.512 .02776 Mdot
.512 .02781 Mdot
.512 .02789 Mdot
.512 .02801 Mdot
.512 .02802 Mdot
.512 .02807 Mdot
.512 .02813 Mdot
.512 .02821 Mdot
.512 .02833 Mdot
.512 .02833 Mdot
.512 .02839 Mdot
.512 .02845 Mdot
.512 .02853 Mdot
.512 .02865 Mdot
.512 .02866 Mdot
.512 .02872 Mdot
.512 .02878 Mdot
.512 .02887 Mdot
.512 .02899 Mdot
.512 .029 Mdot
.512 .02906 Mdot
.512 .02912 Mdot
.512 .02921 Mdot
.512 .02933 Mdot
.512 .02934 Mdot
.512 .0294 Mdot
.512 .02946 Mdot
.512 .02955 Mdot
.512 .02968 Mdot
.512 .02969 Mdot
.512 .02975 Mdot
.512 .02982 Mdot
.512 .02991 Mdot
.512 .03004 Mdot
.512 .03005 Mdot
.512 .03011 Mdot
.512 .03018 Mdot
.512 .03027 Mdot
.512 .03041 Mdot
.512 .03042 Mdot
.512 .03048 Mdot
.512 .03055 Mdot
.512 .03065 Mdot
.512 .03078 Mdot
.512 .03079 Mdot
.512 .03086 Mdot
.512 .03093 Mdot
.512 .03103 Mdot
.512 .03117 Mdot
.512 .03118 Mdot
.512 .03125 Mdot
.512 .03132 Mdot
.512 .03142 Mdot
.512 .03156 Mdot
.512 .03157 Mdot
.512 .03165 Mdot
.512 .03172 Mdot
.512 .03182 Mdot
.512 .03197 Mdot
.512 .03198 Mdot
.512 .03205 Mdot
.512 .03213 Mdot
.512 .03223 Mdot
.512 .03238 Mdot
.512 .03239 Mdot
.512 .03247 Mdot
.512 .03254 Mdot
.512 .03265 Mdot
.512 .03281 Mdot
.512 .03282 Mdot
.512 .03289 Mdot
.512 .03297 Mdot
.512 .03308 Mdot
.512 .03324 Mdot
.512 .03325 Mdot
.512 .03333 Mdot
.512 .03341 Mdot
.512 .03353 Mdot
.512 .03368 Mdot
.512 .0337 Mdot
.512 .03378 Mdot
.512 .03386 Mdot
.512 .03398 Mdot
.512 .03414 Mdot
.512 .03415 Mdot
.512 .03424 Mdot
.512 .03432 Mdot
.512 .03444 Mdot
.512 .03461 Mdot
.512 .03462 Mdot
.512 .0347 Mdot
.512 .03479 Mdot
.512 .03491 Mdot
.512 .03508 Mdot
.512 .0351 Mdot
.512 .03518 Mdot
.512 .03527 Mdot
.512 .0354 Mdot
.512 .03557 Mdot
.512 .03559 Mdot
.512 .03567 Mdot
.512 .03576 Mdot
.512 .03589 Mdot
.512 .03607 Mdot
.512 .03609 Mdot
.512 .03618 Mdot
.512 .03627 Mdot
.512 .0364 Mdot
.512 .03659 Mdot
.512 .0366 Mdot
.512 .03669 Mdot
.512 .03679 Mdot
.512 .03692 Mdot
.512 .03711 Mdot
.512 .03713 Mdot
.512 .03722 Mdot
.512 .03732 Mdot
.512 .03746 Mdot
.512 .03765 Mdot
.512 .03766 Mdot
.512 .03776 Mdot
.512 .03786 Mdot
.512 .038 Mdot
.512 .0382 Mdot
.512 .03821 Mdot
.512 .03831 Mdot
.512 .03841 Mdot
.512 .03856 Mdot
.512 .03876 Mdot
.512 .03878 Mdot
.512 .03888 Mdot
.512 .03898 Mdot
.512 .03913 Mdot
.512 .03934 Mdot
.512 .03936 Mdot
.512 .03946 Mdot
.512 .03957 Mdot
.512 .03972 Mdot
.512 .03993 Mdot
.512 .03995 Mdot
.512 .04005 Mdot
.512 .04016 Mdot
.512 .04032 Mdot
.512 .04054 Mdot
.512 .04055 Mdot
.512 .04066 Mdot
.512 .04077 Mdot
.512 .04093 Mdot
.512 .04115 Mdot
.512 .04117 Mdot
.512 .04128 Mdot
.512 .0414 Mdot
.512 .04156 Mdot
.512 .04179 Mdot
.512 .04181 Mdot
.512 .04192 Mdot
.512 .04204 Mdot
.512 .04221 Mdot
.512 .04244 Mdot
.512 .04246 Mdot
.512 .04258 Mdot
.512 .04269 Mdot
.512 .04287 Mdot
.512 .0431 Mdot
.512 .04312 Mdot
.512 .04324 Mdot
.512 .04337 Mdot
.512 .04354 Mdot
.512 .04379 Mdot
.512 .04381 Mdot
.512 .04393 Mdot
.512 .04405 Mdot
.512 .04423 Mdot
.512 .04448 Mdot
.512 .0445 Mdot
.512 .04463 Mdot
.512 .04476 Mdot
.512 .04494 Mdot
.512 .0452 Mdot
.512 .04522 Mdot
.512 .04535 Mdot
.512 .04548 Mdot
.512 .04567 Mdot
.512 .04593 Mdot
.512 .04595 Mdot
.512 .04608 Mdot
.512 .04622 Mdot
.512 .04641 Mdot
.512 .04668 Mdot
.512 .0467 Mdot
.512 .04684 Mdot
.512 .04697 Mdot
.512 .04717 Mdot
.512 .04745 Mdot
.512 .04747 Mdot
.512 .04761 Mdot
.512 .04775 Mdot
.512 .04795 Mdot
.512 .04823 Mdot
.512 .04825 Mdot
.512 .0484 Mdot
.512 .04854 Mdot
.512 .04875 Mdot
.512 .04904 Mdot
.512 .04906 Mdot
.512 .0492 Mdot
.512 .04935 Mdot
.512 .04956 Mdot
.512 .04986 Mdot
.512 .04988 Mdot
.512 .05003 Mdot
.512 .05018 Mdot
.512 .0504 Mdot
.512 .0507 Mdot
.512 .05073 Mdot
.512 .05088 Mdot
.512 .05103 Mdot
.512 .05126 Mdot
.512 .05157 Mdot
.512 .05159 Mdot
.512 .05175 Mdot
.512 .05191 Mdot
.512 .05213 Mdot
.512 .05245 Mdot
.512 .05248 Mdot
.512 .05264 Mdot
.512 .0528 Mdot
.512 .05303 Mdot
.512 .05336 Mdot
.512 .05338 Mdot
.512 .05355 Mdot
.512 .05371 Mdot
.512 .05395 Mdot
.512 .05428 Mdot
.512 .05431 Mdot
.512 .05448 Mdot
.512 .05465 Mdot
.512 .05489 Mdot
.512 .05523 Mdot
.512 .05526 Mdot
.512 .05543 Mdot
.512 .05561 Mdot
.512 .05586 Mdot
.512 .05621 Mdot
.512 .05623 Mdot
.512 .05641 Mdot
.512 .05659 Mdot
.512 .05685 Mdot
.512 .0572 Mdot
.512 .05723 Mdot
.512 .05741 Mdot
.512 .05759 Mdot
.512 .05786 Mdot
.512 .05822 Mdot
.512 .05825 Mdot
.512 .05844 Mdot
.512 .05862 Mdot
.512 .05889 Mdot
.512 .05927 Mdot
.512 .0593 Mdot
.512 .05948 Mdot
.512 .05968 Mdot
.512 .05995 Mdot
.512 .06034 Mdot
.512 .06037 Mdot
.512 .06056 Mdot
.512 .06076 Mdot
.512 .06104 Mdot
.512 .06143 Mdot
.512 .06146 Mdot
.512 .06166 Mdot
.512 .06186 Mdot
.512 .06215 Mdot
.512 .06255 Mdot
.512 .06258 Mdot
.512 .06279 Mdot
.512 .06299 Mdot
.512 .06329 Mdot
.512 .0637 Mdot
.512 .06373 Mdot
.512 .06394 Mdot
.512 .06415 Mdot
.512 .06445 Mdot
.512 .06487 Mdot
.512 .06491 Mdot
.512 .06512 Mdot
.512 .06534 Mdot
.512 .06565 Mdot
.512 .06608 Mdot
.512 .06611 Mdot
.512 .06633 Mdot
.512 .06655 Mdot
.512 .06687 Mdot
.512 .06731 Mdot
.512 .06735 Mdot
.512 .06757 Mdot
.512 .0678 Mdot
.512 .06812 Mdot
.512 .06857 Mdot
.512 .06861 Mdot
.512 .06884 Mdot
.512 .06907 Mdot
.512 .0694 Mdot
.512 .06987 Mdot
.512 .0699 Mdot
.512 .07014 Mdot
.512 .07037 Mdot
.512 .07072 Mdot
.512 .07119 Mdot
.512 .07123 Mdot
.512 .07147 Mdot
.512 .07171 Mdot
.512 .07206 Mdot
.512 .07255 Mdot
.512 .07258 Mdot
.512 .07283 Mdot
.512 .07308 Mdot
.512 .07344 Mdot
.512 .07393 Mdot
.512 .07397 Mdot
.512 .07422 Mdot
.512 .07448 Mdot
.512 .07485 Mdot
.512 .07535 Mdot
.512 .0754 Mdot
.512 .07565 Mdot
.512 .07591 Mdot
.512 .07629 Mdot
.512 .07681 Mdot
.512 .07685 Mdot
.512 .07712 Mdot
.512 .07738 Mdot
.512 .07777 Mdot
.512 .0783 Mdot
.512 .07834 Mdot
.512 .07861 Mdot
.512 .07889 Mdot
.512 .07928 Mdot
.512 .07983 Mdot
.512 .07987 Mdot
.512 .08015 Mdot
.512 .08043 Mdot
.512 .08083 Mdot
.512 .08139 Mdot
.512 .08143 Mdot
.512 .08172 Mdot
.512 .082 Mdot
.512 .08242 Mdot
.512 .08299 Mdot
.512 .08304 Mdot
.512 .08332 Mdot
.512 .08362 Mdot
.512 .08404 Mdot
.512 .08463 Mdot
.512 .08468 Mdot
.512 .08497 Mdot
.512 .08527 Mdot
.512 .08571 Mdot
.512 .08631 Mdot
.512 .08635 Mdot
.512 .08666 Mdot
.512 .08697 Mdot
.512 .08741 Mdot
.512 .08802 Mdot
.512 .08807 Mdot
.512 .08838 Mdot
.512 .0887 Mdot
.512 .08915 Mdot
.512 .08978 Mdot
.512 .08983 Mdot
.512 .09015 Mdot
.512 .09048 Mdot
.512 .09094 Mdot
.512 .09158 Mdot
.512 .09164 Mdot
.512 .09196 Mdot
.512 .09229 Mdot
.512 .09277 Mdot
.512 .09343 Mdot
.512 .09348 Mdot
.512 .09382 Mdot
.512 .09416 Mdot
.512 .09464 Mdot
.512 .09532 Mdot
.512 .09537 Mdot
.512 .09571 Mdot
.512 .09606 Mdot
.512 .09656 Mdot
.512 .09725 Mdot
.512 .09731 Mdot
.512 .09766 Mdot
.512 .09801 Mdot
.512 .09853 Mdot
.512 .09923 Mdot
.512 .09929 Mdot
.512 .09965 Mdot
.512 .10001 Mdot
.512 .10054 Mdot
.512 .10126 Mdot
.512 .10132 Mdot
.512 .10169 Mdot
.512 .10206 Mdot
.512 .1026 Mdot
.512 .10334 Mdot
.512 .1034 Mdot
.512 .10378 Mdot
.512 .10416 Mdot
.512 .10471 Mdot
.512 .10547 Mdot
.512 .10553 Mdot
.512 .10591 Mdot
.512 .1063 Mdot
.512 .10687 Mdot
.512 .10764 Mdot
.512 .10771 Mdot
.512 .1081 Mdot
.512 .1085 Mdot
.512 .10908 Mdot
.512 .10988 Mdot
.512 .10994 Mdot
.512 .11034 Mdot
.512 .11075 Mdot
.512 .11134 Mdot
.512 .11216 Mdot
.512 .11223 Mdot
.512 .11264 Mdot
.512 .11306 Mdot
.512 .11366 Mdot
.512 .1145 Mdot
.512 .11457 Mdot
.512 .11499 Mdot
.512 .11542 Mdot
.512 .11604 Mdot
.512 .11689 Mdot
.512 .11696 Mdot
.512 .11739 Mdot
.512 .11783 Mdot
.512 .11847 Mdot
.512 .11934 Mdot
.512 .11942 Mdot
.512 .11986 Mdot
.512 .12031 Mdot
.512 .12096 Mdot
.512 .12186 Mdot
.512 .12193 Mdot
.512 .12238 Mdot
.512 .12284 Mdot
.512 .12351 Mdot
.512 .12443 Mdot
.512 .1245 Mdot
.512 .12497 Mdot
.512 .12544 Mdot
.512 .12612 Mdot
.512 .12706 Mdot
.512 .12714 Mdot
.512 .12761 Mdot
.512 .1281 Mdot
.512 .12879 Mdot
.512 .12976 Mdot
.512 .12983 Mdot
.512 .13032 Mdot
.512 .13082 Mdot
.512 .13153 Mdot
.512 .13252 Mdot
.512 .1326 Mdot
.512 .1331 Mdot
.512 .1336 Mdot
.512 .13433 Mdot
.512 .13534 Mdot
.512 .13543 Mdot
.512 .13594 Mdot
.512 .13646 Mdot
.512 .1372 Mdot
.512 .13824 Mdot
.512 .13832 Mdot
.512 .13885 Mdot
.512 .13938 Mdot
.512 .14014 Mdot
.512 .1412 Mdot
.512 .14129 Mdot
.512 .14183 Mdot
.512 .14237 Mdot
.512 .14315 Mdot
.512 .14424 Mdot
.512 .14433 Mdot
.512 .14488 Mdot
.512 .14543 Mdot
.512 .14624 Mdot
.512 .14735 Mdot
.512 .14744 Mdot
.512 .148 Mdot
.512 .14857 Mdot
.512 .14939 Mdot
.512 .15053 Mdot
.512 .15062 Mdot
.512 .1512 Mdot
.512 .15178 Mdot
.512 .15263 Mdot
.512 .15379 Mdot
.512 .15389 Mdot
.512 .15448 Mdot
.512 .15507 Mdot
.512 .15594 Mdot
.512 .15713 Mdot
.512 .15723 Mdot
.512 .15783 Mdot
.512 .15844 Mdot
.512 .15932 Mdot
.512 .16055 Mdot
.512 .16065 Mdot
.512 .16126 Mdot
.512 .16189 Mdot
.512 .1628 Mdot
.512 .16405 Mdot
.512 .16415 Mdot
.512 .16478 Mdot
.512 .16542 Mdot
.512 .16635 Mdot
.512 .16763 Mdot
.512 .16774 Mdot
.512 .16838 Mdot
.512 .16904 Mdot
.512 .16999 Mdot
.512 .1713 Mdot
.512 .17141 Mdot
.512 .17207 Mdot
.512 .17274 Mdot
.512 .17371 Mdot
.512 .17506 Mdot
.512 .17517 Mdot
.512 .17585 Mdot
.512 .17654 Mdot
.512 .17753 Mdot
.512 .17891 Mdot
.512 .17902 Mdot
.512 .17971 Mdot
.512 .18042 Mdot
.512 .18144 Mdot
.512 .18285 Mdot
.512 .18296 Mdot
.512 .18367 Mdot
.512 .1844 Mdot
.512 .18544 Mdot
.512 .18688 Mdot
.512 .187 Mdot
.512 .18773 Mdot
.512 .18847 Mdot
.512 .18954 Mdot
.512 .19102 Mdot
.512 .19114 Mdot
.512 .19188 Mdot
.512 .19264 Mdot
.512 .19373 Mdot
.512 .19525 Mdot
.512 .19537 Mdot
.512 .19613 Mdot
.512 .19691 Mdot
.512 .19803 Mdot
.512 .19958 Mdot
.512 .19971 Mdot
.512 .20049 Mdot
.512 .20128 Mdot
.512 .20243 Mdot
.512 .20402 Mdot
.512 .20415 Mdot
.512 .20495 Mdot
.512 .20576 Mdot
.512 .20693 Mdot
.512 .20856 Mdot
.512 .20869 Mdot
.512 .20951 Mdot
.512 .21035 Mdot
.512 .21155 Mdot
.512 .21321 Mdot
.512 .21335 Mdot
.512 .21419 Mdot
.512 .21504 Mdot
.512 .21627 Mdot
.512 .21798 Mdot
.512 .21811 Mdot
.512 .21897 Mdot
.512 .21985 Mdot
.512 .22111 Mdot
.512 .22285 Mdot
.512 .223 Mdot
.512 .22388 Mdot
.512 .22477 Mdot
.512 .22606 Mdot
.512 .22785 Mdot
.512 .22799 Mdot
.512 .2289 Mdot
.512 .22981 Mdot
.512 .23113 Mdot
.512 .23296 Mdot
.512 .23311 Mdot
.512 .23404 Mdot
.512 .23498 Mdot
.512 .23633 Mdot
.512 .2382 Mdot
.512 .23835 Mdot
.512 .2393 Mdot
.512 .24026 Mdot
.512 .24165 Mdot
.512 .24357 Mdot
.512 .24372 Mdot
.512 .24469 Mdot
.512 .24568 Mdot
.512 .24709 Mdot
.512 .24906 Mdot
.512 .24922 Mdot
.512 .25021 Mdot
.512 .25122 Mdot
.512 .25267 Mdot
.512 .25468 Mdot
.512 .25485 Mdot
.512 .25586 Mdot
.512 .25689 Mdot
.512 .25838 Mdot
.512 .26044 Mdot
.512 .26061 Mdot
.512 .26165 Mdot
.512 .26271 Mdot
.512 .26423 Mdot
.512 .26634 Mdot
.512 .26651 Mdot
.512 .26758 Mdot
.512 .26866 Mdot
.512 .27022 Mdot
.512 .27238 Mdot
.512 .27255 Mdot
.512 .27365 Mdot
.512 .27475 Mdot
.512 .27635 Mdot
.512 .27856 Mdot
.512 .27874 Mdot
.512 .27986 Mdot
.512 .28099 Mdot
.512 .28263 Mdot
.512 .28489 Mdot
.512 .28508 Mdot
.512 .28622 Mdot
.512 .28739 Mdot
.512 .28906 Mdot
.512 .29138 Mdot
.512 .29157 Mdot
.512 .29274 Mdot
.512 .29393 Mdot
.512 .29564 Mdot
.512 .29802 Mdot
.512 .29821 Mdot
.512 .29941 Mdot
.512 .30063 Mdot
.512 .30239 Mdot
.512 .30482 Mdot
.512 .30502 Mdot
.512 .30624 Mdot
.512 .30749 Mdot
.512 .30929 Mdot
.512 .31178 Mdot
.512 .31198 Mdot
.512 .31324 Mdot
.512 .31452 Mdot
.512 .31636 Mdot
.514 .01475 Mdot
.514 .01475 Mdot
.514 .01475 Mdot
.514 .01475 Mdot
.514 .01475 Mdot
.514 .01475 Mdot
.514 .01476 Mdot
.514 .01476 Mdot
.514 .01476 Mdot
.514 .01476 Mdot
.514 .01476 Mdot
.514 .01476 Mdot
.514 .01476 Mdot
.514 .01476 Mdot
.514 .01477 Mdot
.514 .01477 Mdot
.514 .01477 Mdot
.514 .01477 Mdot
.514 .01477 Mdot
.514 .01477 Mdot
.514 .01478 Mdot
.514 .01478 Mdot
.514 .01478 Mdot
.514 .01478 Mdot
.514 .01478 Mdot
.514 .01478 Mdot
.514 .01479 Mdot
.514 .01479 Mdot
.514 .01479 Mdot
.514 .01479 Mdot
.514 .01479 Mdot
.514 .0148 Mdot
.514 .0148 Mdot
.514 .0148 Mdot
.514 .0148 Mdot
.514 .01481 Mdot
.514 .01481 Mdot
.514 .01481 Mdot
.514 .01481 Mdot
.514 .01482 Mdot
.514 .01482 Mdot
.514 .01482 Mdot
.514 .01483 Mdot
.514 .01483 Mdot
.514 .01483 Mdot
.514 .01483 Mdot
.514 .01484 Mdot
.514 .01484 Mdot
.514 .01485 Mdot
.514 .01485 Mdot
.514 .01485 Mdot
.514 .01486 Mdot
.514 .01486 Mdot
.514 .01486 Mdot
.514 .01487 Mdot
.514 .01487 Mdot
.514 .01488 Mdot
.514 .01488 Mdot
.514 .01489 Mdot
.514 .01489 Mdot
.514 .0149 Mdot
.514 .0149 Mdot
.514 .01491 Mdot
.514 .01491 Mdot
.514 .01492 Mdot
.514 .01492 Mdot
.514 .01493 Mdot
.514 .01493 Mdot
.514 .01494 Mdot
.514 .01495 Mdot
.514 .01495 Mdot
.514 .01496 Mdot
.514 .01497 Mdot
.514 .01892 Mdot
.514 .01904 Mdot
.514 .01916 Mdot
.514 .01929 Mdot
.514 .01941 Mdot
.514 .01952 Mdot
.514 .01954 Mdot
.514 .01966 Mdot
.514 .01968 Mdot
.514 .01979 Mdot
.514 .01982 Mdot
.514 .01994 Mdot
.514 .01995 Mdot
.514 .01996 Mdot
.514 .02005 Mdot
.514 .02008 Mdot
.514 .0201 Mdot
.514 .02011 Mdot
.514 .0202 Mdot
.514 .02023 Mdot
.514 .02025 Mdot
.514 .02026 Mdot
.514 .02035 Mdot
.514 .02039 Mdot
.514 .02041 Mdot
.514 .02041 Mdot
.514 .02051 Mdot
.514 .02055 Mdot
.514 .02057 Mdot
.514 .02057 Mdot
.514 .02067 Mdot
.514 .02071 Mdot
.514 .02073 Mdot
.514 .02074 Mdot
.514 .02084 Mdot
.514 .02088 Mdot
.514 .0209 Mdot
.514 .02091 Mdot
.514 .02101 Mdot
.514 .02105 Mdot
.514 .02107 Mdot
.514 .02108 Mdot
.514 .02119 Mdot
.514 .02123 Mdot
.514 .02125 Mdot
.514 .02126 Mdot
.514 .02137 Mdot
.514 .02141 Mdot
.514 .02143 Mdot
.514 .02144 Mdot
.514 .02156 Mdot
.514 .0216 Mdot
.514 .02162 Mdot
.514 .02163 Mdot
.514 .02175 Mdot
.514 .02175 Mdot
.514 .02179 Mdot
.514 .02181 Mdot
.514 .02182 Mdot
.514 .02195 Mdot
.514 .02195 Mdot
.514 .02199 Mdot
.514 .02201 Mdot
.514 .02202 Mdot
.514 .02215 Mdot
.514 .02215 Mdot
.514 .02219 Mdot
.514 .02222 Mdot
.514 .02223 Mdot
.514 .02236 Mdot
.514 .02236 Mdot
.514 .0224 Mdot
.514 .02243 Mdot
.514 .02244 Mdot
.514 .02257 Mdot
.514 .02257 Mdot
.514 .02262 Mdot
.514 .02264 Mdot
.514 .02265 Mdot
.514 .02276 Mdot
.514 .02279 Mdot
.514 .02279 Mdot
.514 .02284 Mdot
.514 .02286 Mdot
.514 .02288 Mdot
.514 .02299 Mdot
.514 .02302 Mdot
.514 .02302 Mdot
.514 .02306 Mdot
.514 .02309 Mdot
.514 .02311 Mdot
.514 .02322 Mdot
.514 .02325 Mdot
.514 .02325 Mdot
.514 .0233 Mdot
.514 .02333 Mdot
.514 .02334 Mdot
.514 .02346 Mdot
.514 .02349 Mdot
.514 .02349 Mdot
.514 .02354 Mdot
.514 .02357 Mdot
.514 .02358 Mdot
.514 .0237 Mdot
.514 .02373 Mdot
.514 .02374 Mdot
.514 .02379 Mdot
.514 .02382 Mdot
.514 .02383 Mdot
.514 .02395 Mdot
.514 .02399 Mdot
.514 .02399 Mdot
.514 .02404 Mdot
.514 .02407 Mdot
.514 .02408 Mdot
.514 .02421 Mdot
.514 .02425 Mdot
.514 .02425 Mdot
.514 .0243 Mdot
.514 .02433 Mdot
.514 .02435 Mdot
.514 .02448 Mdot
.514 .02451 Mdot
.514 .02452 Mdot
.514 .02457 Mdot
.514 .0246 Mdot
.514 .02462 Mdot
.514 .02475 Mdot
.514 .02479 Mdot
.514 .02479 Mdot
.514 .02485 Mdot
.514 .02488 Mdot
.514 .02489 Mdot
.514 .02503 Mdot
.514 .02507 Mdot
.514 .02507 Mdot
.514 .02513 Mdot
.514 .02516 Mdot
.514 .02518 Mdot
.514 .02532 Mdot
.514 .02536 Mdot
.514 .02536 Mdot
.514 .02542 Mdot
.514 .02546 Mdot
.514 .02547 Mdot
.514 .02562 Mdot
.514 .02566 Mdot
.514 .02566 Mdot
.514 .02572 Mdot
.514 .02576 Mdot
.514 .02577 Mdot
.514 .02593 Mdot
.514 .02596 Mdot
.514 .02597 Mdot
.514 .02603 Mdot
.514 .02607 Mdot
.514 .02608 Mdot
.514 .02624 Mdot
.514 .02628 Mdot
.514 .02628 Mdot
.514 .02634 Mdot
.514 .02638 Mdot
.514 .0264 Mdot
.514 .02656 Mdot
.514 .0266 Mdot
.514 .02661 Mdot
.514 .02667 Mdot
.514 .02671 Mdot
.514 .02673 Mdot
.514 .02689 Mdot
.514 .02693 Mdot
.514 .02694 Mdot
.514 .02701 Mdot
.514 .02705 Mdot
.514 .02707 Mdot
.514 .02723 Mdot
.514 .02728 Mdot
.514 .02728 Mdot
.514 .02735 Mdot
.514 .02739 Mdot
.514 .02741 Mdot
.514 .02759 Mdot
.514 .02763 Mdot
.514 .02763 Mdot
.514 .0277 Mdot
.514 .02775 Mdot
.514 .02777 Mdot
.514 .02795 Mdot
.514 .02799 Mdot
.514 .02799 Mdot
.514 .02807 Mdot
.514 .02811 Mdot
.514 .02813 Mdot
.514 .02832 Mdot
.514 .02836 Mdot
.514 .02837 Mdot
.514 .02844 Mdot
.514 .02849 Mdot
.514 .02851 Mdot
.514 .0287 Mdot
.514 .02874 Mdot
.514 .02875 Mdot
.514 .02883 Mdot
.514 .02887 Mdot
.514 .02889 Mdot
.514 .02909 Mdot
.514 .02914 Mdot
.514 .02914 Mdot
.514 .02922 Mdot
.514 .02927 Mdot
.514 .02929 Mdot
.514 .02949 Mdot
.514 .02954 Mdot
.514 .02954 Mdot
.514 .02963 Mdot
.514 .02967 Mdot
.514 .0297 Mdot
.514 .0299 Mdot
.514 .02996 Mdot
.514 .02996 Mdot
.514 .03004 Mdot
.514 .03009 Mdot
.514 .03012 Mdot
.514 .03033 Mdot
.514 .03038 Mdot
.514 .03039 Mdot
.514 .03047 Mdot
.514 .03052 Mdot
.514 .03055 Mdot
.514 .03077 Mdot
.514 .03082 Mdot
.514 .03083 Mdot
.514 .03091 Mdot
.514 .03097 Mdot
.514 .03099 Mdot
.514 .03122 Mdot
.514 .03127 Mdot
.514 .03128 Mdot
.514 .03137 Mdot
.514 .03142 Mdot
.514 .03145 Mdot
.514 .03168 Mdot
.514 .03174 Mdot
.514 .03174 Mdot
.514 .03183 Mdot
.514 .03189 Mdot
.514 .03192 Mdot
.514 .03215 Mdot
.514 .03221 Mdot
.514 .03222 Mdot
.514 .03231 Mdot
.514 .03237 Mdot
.514 .0324 Mdot
.514 .03264 Mdot
.514 .0327 Mdot
.514 .03271 Mdot
.514 .03281 Mdot
.514 .03287 Mdot
.514 .03289 Mdot
.514 .03314 Mdot
.514 .03321 Mdot
.514 .03321 Mdot
.514 .03331 Mdot
.514 .03337 Mdot
.514 .0334 Mdot
.514 .03366 Mdot
.514 .03372 Mdot
.514 .03373 Mdot
.514 .03383 Mdot
.514 .0339 Mdot
.514 .03393 Mdot
.514 .03419 Mdot
.514 .03426 Mdot
.514 .03426 Mdot
.514 .03437 Mdot
.514 .03443 Mdot
.514 .03446 Mdot
.514 .03474 Mdot
.514 .0348 Mdot
.514 .03481 Mdot
.514 .03492 Mdot
.514 .03498 Mdot
.514 .03502 Mdot
.514 .0353 Mdot
.514 .03536 Mdot
.514 .03537 Mdot
.514 .03548 Mdot
.514 .03555 Mdot
.514 .03559 Mdot
.514 .03587 Mdot
.514 .03594 Mdot
.514 .03595 Mdot
.514 .03607 Mdot
.514 .03614 Mdot
.514 .03617 Mdot
.514 .03646 Mdot
.514 .03654 Mdot
.514 .03654 Mdot
.514 .03666 Mdot
.514 .03674 Mdot
.514 .03677 Mdot
.514 .03707 Mdot
.514 .03715 Mdot
.514 .03716 Mdot
.514 .03728 Mdot
.514 .03735 Mdot
.514 .03739 Mdot
.514 .0377 Mdot
.514 .03778 Mdot
.514 .03778 Mdot
.514 .03791 Mdot
.514 .03799 Mdot
.514 .03802 Mdot
.514 .03834 Mdot
.514 .03842 Mdot
.514 .03843 Mdot
.514 .03856 Mdot
.514 .03864 Mdot
.514 .03868 Mdot
.514 .039 Mdot
.514 .03909 Mdot
.514 .03909 Mdot
.514 .03923 Mdot
.514 .03931 Mdot
.514 .03935 Mdot
.514 .03968 Mdot
.514 .03977 Mdot
.514 .03978 Mdot
.514 .03991 Mdot
.514 .04 Mdot
.514 .04004 Mdot
.514 .04038 Mdot
.514 .04047 Mdot
.514 .04048 Mdot
.514 .04062 Mdot
.514 .0407 Mdot
.514 .04075 Mdot
.514 .0411 Mdot
.514 .04119 Mdot
.514 .0412 Mdot
.514 .04134 Mdot
.514 .04143 Mdot
.514 .04147 Mdot
.514 .04184 Mdot
.514 .04193 Mdot
.514 .04194 Mdot
.514 .04209 Mdot
.514 .04218 Mdot
.514 .04222 Mdot
.514 .0426 Mdot
.514 .04269 Mdot
.514 .0427 Mdot
.514 .04286 Mdot
.514 .04295 Mdot
.514 .04299 Mdot
.514 .04338 Mdot
.514 .04348 Mdot
.514 .04349 Mdot
.514 .04364 Mdot
.514 .04374 Mdot
.514 .04379 Mdot
.514 .04418 Mdot
.514 .04428 Mdot
.514 .04429 Mdot
.514 .04446 Mdot
.514 .04455 Mdot
.514 .0446 Mdot
.514 .04501 Mdot
.514 .04511 Mdot
.514 .04512 Mdot
.514 .04529 Mdot
.514 .04539 Mdot
.514 .04544 Mdot
.514 .04586 Mdot
.514 .04596 Mdot
.514 .04597 Mdot
.514 .04614 Mdot
.514 .04625 Mdot
.514 .0463 Mdot
.514 .04673 Mdot
.514 .04684 Mdot
.514 .04685 Mdot
.514 .04702 Mdot
.514 .04713 Mdot
.514 .04718 Mdot
.514 .04763 Mdot
.514 .04774 Mdot
.514 .04775 Mdot
.514 .04793 Mdot
.514 .04804 Mdot
.514 .04809 Mdot
.514 .04855 Mdot
.514 .04866 Mdot
.514 .04867 Mdot
.514 .04886 Mdot
.514 .04897 Mdot
.514 .04902 Mdot
.514 .0495 Mdot
.514 .04961 Mdot
.514 .04962 Mdot
.514 .04981 Mdot
.514 .04993 Mdot
.514 .04998 Mdot
.514 .05047 Mdot
.514 .05059 Mdot
.514 .0506 Mdot
.514 .0508 Mdot
.514 .05091 Mdot
.514 .05097 Mdot
.514 .05147 Mdot
.514 .05159 Mdot
.514 .0516 Mdot
.514 .05181 Mdot
.514 .05193 Mdot
.514 .05199 Mdot
.514 .0525 Mdot
.514 .05263 Mdot
.514 .05264 Mdot
.514 .05285 Mdot
.514 .05297 Mdot
.514 .05303 Mdot
.514 .05356 Mdot
.514 .05369 Mdot
.514 .0537 Mdot
.514 .05391 Mdot
.514 .05404 Mdot
.514 .0541 Mdot
.514 .05464 Mdot
.514 .05478 Mdot
.514 .05479 Mdot
.514 .05501 Mdot
.514 .05514 Mdot
.514 .05521 Mdot
.514 .05576 Mdot
.514 .0559 Mdot
.514 .05591 Mdot
.514 .05614 Mdot
.514 .05627 Mdot
.514 .05634 Mdot
.514 .05691 Mdot
.514 .05705 Mdot
.514 .05707 Mdot
.514 .0573 Mdot
.514 .05744 Mdot
.514 .05751 Mdot
.514 .05809 Mdot
.514 .05824 Mdot
.514 .05825 Mdot
.514 .05849 Mdot
.514 .05863 Mdot
.514 .0587 Mdot
.514 .05931 Mdot
.514 .05946 Mdot
.514 .05947 Mdot
.514 .05972 Mdot
.514 .05986 Mdot
.514 .05994 Mdot
.514 .06056 Mdot
.514 .06071 Mdot
.514 .06072 Mdot
.514 .06098 Mdot
.514 .06113 Mdot
.514 .0612 Mdot
.514 .06184 Mdot
.514 .062 Mdot
.514 .06201 Mdot
.514 .06227 Mdot
.514 .06243 Mdot
.514 .0625 Mdot
.514 .06316 Mdot
.514 .06332 Mdot
.514 .06334 Mdot
.514 .0636 Mdot
.514 .06376 Mdot
.514 .06384 Mdot
.514 .06452 Mdot
.514 .06468 Mdot
.514 .0647 Mdot
.514 .06497 Mdot
.514 .06514 Mdot
.514 .06522 Mdot
.514 .06591 Mdot
.514 .06608 Mdot
.514 .0661 Mdot
.514 .06638 Mdot
.514 .06655 Mdot
.514 .06663 Mdot
.514 .06734 Mdot
.514 .06752 Mdot
.514 .06754 Mdot
.514 .06783 Mdot
.514 .068 Mdot
.514 .06809 Mdot
.514 .06882 Mdot
.514 .069 Mdot
.514 .06902 Mdot
.514 .06931 Mdot
.514 .06949 Mdot
.514 .06958 Mdot
.514 .07033 Mdot
.514 .07052 Mdot
.514 .07054 Mdot
.514 .07084 Mdot
.514 .07103 Mdot
.514 .07112 Mdot
.514 .07189 Mdot
.514 .07208 Mdot
.514 .0721 Mdot
.514 .07241 Mdot
.514 .0726 Mdot
.514 .0727 Mdot
.514 .07349 Mdot
.514 .07369 Mdot
.514 .07371 Mdot
.514 .07403 Mdot
.514 .07422 Mdot
.514 .07432 Mdot
.514 .07514 Mdot
.514 .07534 Mdot
.514 .07536 Mdot
.514 .07569 Mdot
.514 .07589 Mdot
.514 .07599 Mdot
.514 .07683 Mdot
.514 .07695 Mdot
.514 .07704 Mdot
.514 .07706 Mdot
.514 .0774 Mdot
.514 .0776 Mdot
.514 .0777 Mdot
.514 .07857 Mdot
.514 .07869 Mdot
.514 .07878 Mdot
.514 .0788 Mdot
.514 .07915 Mdot
.514 .07936 Mdot
.514 .07947 Mdot
.514 .08036 Mdot
.514 .08048 Mdot
.514 .08058 Mdot
.514 .0806 Mdot
.514 .08096 Mdot
.514 .08117 Mdot
.514 .08128 Mdot
.514 .08219 Mdot
.514 .08232 Mdot
.514 .08242 Mdot
.514 .08244 Mdot
.514 .08281 Mdot
.514 .08303 Mdot
.514 .08314 Mdot
.514 .08408 Mdot
.514 .08422 Mdot
.514 .08432 Mdot
.514 .08434 Mdot
.514 .08472 Mdot
.514 .08495 Mdot
.514 .08506 Mdot
.514 .08603 Mdot
.514 .08616 Mdot
.514 .08626 Mdot
.514 .08629 Mdot
.514 .08668 Mdot
.514 .08691 Mdot
.514 .08703 Mdot
.514 .08802 Mdot
.514 .08816 Mdot
.514 .08827 Mdot
.514 .08829 Mdot
.514 .08869 Mdot
.514 .08894 Mdot
.514 .08905 Mdot
.514 .09007 Mdot
.514 .09022 Mdot
.514 .09033 Mdot
.514 .09035 Mdot
.514 .09077 Mdot
.514 .09101 Mdot
.514 .09114 Mdot
.514 .09218 Mdot
.514 .09234 Mdot
.514 .09244 Mdot
.514 .09247 Mdot
.514 .0929 Mdot
.514 .09315 Mdot
.514 .09328 Mdot
.514 .09435 Mdot
.514 .09451 Mdot
.514 .09462 Mdot
.514 .09465 Mdot
.514 .09508 Mdot
.514 .09535 Mdot
.514 .09548 Mdot
.514 .09658 Mdot
.514 .09674 Mdot
.514 .09686 Mdot
.514 .09688 Mdot
.514 .09734 Mdot
.514 .0976 Mdot
.514 .09774 Mdot
.514 .09888 Mdot
.514 .09904 Mdot
.514 .09916 Mdot
.514 .09918 Mdot
.514 .09965 Mdot
.514 .09992 Mdot
.514 .10006 Mdot
.514 .10123 Mdot
.514 .1014 Mdot
.514 .10152 Mdot
.514 .10155 Mdot
.514 .10203 Mdot
.514 .10231 Mdot
.514 .10245 Mdot
.514 .10365 Mdot
.514 .10383 Mdot
.514 .10395 Mdot
.514 .10398 Mdot
.514 .10447 Mdot
.514 .10476 Mdot
.514 .10491 Mdot
.514 .10615 Mdot
.514 .10632 Mdot
.514 .10645 Mdot
.514 .10648 Mdot
.514 .10698 Mdot
.514 .10728 Mdot
.514 .10743 Mdot
.514 .10871 Mdot
.514 .10889 Mdot
.514 .10902 Mdot
.514 .10905 Mdot
.514 .10957 Mdot
.514 .10988 Mdot
.514 .11003 Mdot
.514 .11134 Mdot
.514 .11152 Mdot
.514 .11166 Mdot
.514 .11169 Mdot
.514 .11222 Mdot
.514 .11254 Mdot
.514 .1127 Mdot
.514 .11404 Mdot
.514 .11424 Mdot
.514 .11437 Mdot
.514 .11441 Mdot
.514 .11495 Mdot
.514 .11528 Mdot
.514 .11544 Mdot
.514 .11682 Mdot
.514 .11702 Mdot
.514 .11717 Mdot
.514 .1172 Mdot
.514 .11776 Mdot
.514 .1181 Mdot
.514 .11826 Mdot
.514 .11968 Mdot
.514 .11989 Mdot
.514 .12003 Mdot
.514 .12007 Mdot
.514 .12065 Mdot
.514 .12099 Mdot
.514 .12116 Mdot
.514 .12262 Mdot
.514 .12283 Mdot
.514 .12298 Mdot
.514 .12302 Mdot
.514 .12361 Mdot
.514 .12397 Mdot
.514 .12414 Mdot
.514 .12564 Mdot
.514 .12586 Mdot
.514 .12601 Mdot
.514 .12605 Mdot
.514 .12666 Mdot
.514 .12703 Mdot
.514 .12721 Mdot
.514 .12875 Mdot
.514 .12897 Mdot
.514 .12913 Mdot
.514 .12917 Mdot
.514 .1298 Mdot
.514 .13017 Mdot
.514 .13035 Mdot
.514 .13194 Mdot
.514 .13217 Mdot
.514 .13233 Mdot
.514 .13237 Mdot
.514 .13302 Mdot
.514 .1334 Mdot
.514 .13359 Mdot
.514 .13522 Mdot
.514 .13546 Mdot
.514 .13563 Mdot
.514 .13567 Mdot
.514 .13633 Mdot
.514 .13673 Mdot
.514 .13692 Mdot
.514 .1386 Mdot
.514 .13884 Mdot
.514 .13901 Mdot
.514 .13905 Mdot
.514 .13974 Mdot
.514 .14014 Mdot
.514 .14034 Mdot
.514 .14207 Mdot
.514 .14231 Mdot
.514 .14249 Mdot
.514 .14253 Mdot
.514 .14324 Mdot
.514 .14365 Mdot
.514 .14386 Mdot
.514 .14563 Mdot
.514 .14589 Mdot
.514 .14607 Mdot
.514 .14611 Mdot
.514 .14683 Mdot
.514 .14727 Mdot
.514 .14748 Mdot
.514 .1493 Mdot
.514 .14956 Mdot
.514 .14975 Mdot
.514 .14979 Mdot
.514 .15053 Mdot
.514 .15098 Mdot
.514 .15119 Mdot
.514 .15307 Mdot
.514 .15334 Mdot
.514 .15353 Mdot
.514 .15357 Mdot
.514 .15434 Mdot
.514 .15479 Mdot
.514 .15502 Mdot
.514 .15694 Mdot
.514 .15722 Mdot
.514 .15742 Mdot
.514 .15746 Mdot
.514 .15825 Mdot
.514 .15871 Mdot
.514 .15894 Mdot
.514 .16092 Mdot
.514 .16121 Mdot
.514 .16141 Mdot
.514 .16146 Mdot
.514 .16227 Mdot
.514 .16275 Mdot
.514 .16298 Mdot
.514 .16502 Mdot
.514 .16531 Mdot
.514 .16552 Mdot
.514 .16557 Mdot
.514 .1664 Mdot
.514 .16689 Mdot
.514 .16713 Mdot
.514 .16923 Mdot
.514 .16953 Mdot
.514 .16974 Mdot
.514 .16979 Mdot
.514 .17064 Mdot
.514 .17115 Mdot
.514 .1714 Mdot
.514 .17355 Mdot
.514 .17386 Mdot
.514 .17408 Mdot
.514 .17413 Mdot
.514 .17501 Mdot
.514 .17553 Mdot
.514 .17579 Mdot
.514 .178 Mdot
.514 .17832 Mdot
.514 .17855 Mdot
.514 .1786 Mdot
.514 .1795 Mdot
.514 .18003 Mdot
.514 .1803 Mdot
.514 .18257 Mdot
.514 .1829 Mdot
.514 .18313 Mdot
.514 .18319 Mdot
.514 .18411 Mdot
.514 .18466 Mdot
.514 .18494 Mdot
.514 .18727 Mdot
.514 .18761 Mdot
.514 .18785 Mdot
.514 .1879 Mdot
.514 .18886 Mdot
.514 .18942 Mdot
.514 .1897 Mdot
.514 .1921 Mdot
.514 .19245 Mdot
.514 .1927 Mdot
.514 .19275 Mdot
.514 .19373 Mdot
.514 .19431 Mdot
.514 .1946 Mdot
.514 .19707 Mdot
.514 .19742 Mdot
.514 .19768 Mdot
.514 .19774 Mdot
.514 .19874 Mdot
.514 .19934 Mdot
.514 .19964 Mdot
.514 .20218 Mdot
.514 .20254 Mdot
.514 .2028 Mdot
.514 .20286 Mdot
.514 .2039 Mdot
.514 .20451 Mdot
.514 .20482 Mdot
.514 .20742 Mdot
.514 .2078 Mdot
.514 .20807 Mdot
.514 .20813 Mdot
.514 .20919 Mdot
.514 .20983 Mdot
.514 .21014 Mdot
.514 .21282 Mdot
.514 .21321 Mdot
.514 .21348 Mdot
.514 .21355 Mdot
.514 .21464 Mdot
.514 .21529 Mdot
.514 .21561 Mdot
.514 .21837 Mdot
.514 .21876 Mdot
.514 .21905 Mdot
.514 .21911 Mdot
.514 .22024 Mdot
.514 .22091 Mdot
.514 .22124 Mdot
.514 .22407 Mdot
.514 .22448 Mdot
.514 .22477 Mdot
.514 .22484 Mdot
.514 .22599 Mdot
.514 .22668 Mdot
.514 .22702 Mdot
.514 .22993 Mdot
.514 .23035 Mdot
.514 .23065 Mdot
.514 .23072 Mdot
.514 .23191 Mdot
.514 .23261 Mdot
.514 .23296 Mdot
.514 .23596 Mdot
.514 .23639 Mdot
.514 .2367 Mdot
.514 .23677 Mdot
.514 .23799 Mdot
.514 .23872 Mdot
.514 .23907 Mdot
.514 .24215 Mdot
.514 .24259 Mdot
.514 .24291 Mdot
.514 .24299 Mdot
.514 .24424 Mdot
.514 .24499 Mdot
.514 .24536 Mdot
.514 .24852 Mdot
.514 .24898 Mdot
.514 .2493 Mdot
.514 .24938 Mdot
.514 .25067 Mdot
.514 .25144 Mdot
.514 .25181 Mdot
.514 .25507 Mdot
.514 .25553 Mdot
.514 .25587 Mdot
.514 .25595 Mdot
.514 .25727 Mdot
.514 .25806 Mdot
.514 .25845 Mdot
.514 .2618 Mdot
.514 .26228 Mdot
.514 .26262 Mdot
.514 .2627 Mdot
.514 .26407 Mdot
.514 .26488 Mdot
.514 .26528 Mdot
.514 .26872 Mdot
.514 .26921 Mdot
.514 .26957 Mdot
.514 .26965 Mdot
.514 .27105 Mdot
.514 .27188 Mdot
.514 .27229 Mdot
.514 .27583 Mdot
.514 .27634 Mdot
.514 .2767 Mdot
.514 .27678 Mdot
.514 .27822 Mdot
.514 .27908 Mdot
.514 .2795 Mdot
.514 .28314 Mdot
.514 .28366 Mdot
.514 .28404 Mdot
.514 .28412 Mdot
.514 .2856 Mdot
.514 .28648 Mdot
.514 .28692 Mdot
.514 .29065 Mdot
.514 .29119 Mdot
.514 .29158 Mdot
.514 .29167 Mdot
.514 .29319 Mdot
.514 .29409 Mdot
.514 .29454 Mdot
.514 .29838 Mdot
.514 .29893 Mdot
.514 .29933 Mdot
.514 .29942 Mdot
.514 .30098 Mdot
.514 .30192 Mdot
.514 .30238 Mdot
.514 .30632 Mdot
.514 .30689 Mdot
.514 .3073 Mdot
.514 .30739 Mdot
.514 .309 Mdot
.514 .30996 Mdot
.514 .31043 Mdot
.514 .31449 Mdot
.514 .31507 Mdot
.514 .31549 Mdot
.514 .31559 Mdot
.514 .31724 Mdot
.514 .31823 Mdot
.516 .01777 Mdot
.516 .01787 Mdot
.516 .01797 Mdot
.516 .01808 Mdot
.516 .01818 Mdot
.516 .0183 Mdot
.516 .01841 Mdot
.516 .01853 Mdot
.516 .01865 Mdot
.516 .01878 Mdot
.516 .01891 Mdot
.516 .01904 Mdot
.516 .01918 Mdot
.516 .01932 Mdot
.516 .01947 Mdot
.516 .01962 Mdot
.516 .01963 Mdot
.516 .01978 Mdot
.516 .01979 Mdot
.516 .01994 Mdot
.516 .01995 Mdot
.516 .02011 Mdot
.516 .02012 Mdot
.516 .02028 Mdot
.516 .02029 Mdot
.516 .02046 Mdot
.516 .02047 Mdot
.516 .02064 Mdot
.516 .02066 Mdot
.516 .02083 Mdot
.516 .02085 Mdot
.516 .02103 Mdot
.516 .02104 Mdot
.516 .02112 Mdot
.516 .02123 Mdot
.516 .02124 Mdot
.516 .02132 Mdot
.516 .02144 Mdot
.516 .02145 Mdot
.516 .02153 Mdot
.516 .02165 Mdot
.516 .02167 Mdot
.516 .02175 Mdot
.516 .02187 Mdot
.516 .02189 Mdot
.516 .02198 Mdot
.516 .0221 Mdot
.516 .02212 Mdot
.516 .02221 Mdot
.516 .02234 Mdot
.516 .02236 Mdot
.516 .02245 Mdot
.516 .02258 Mdot
.516 .0226 Mdot
.516 .02269 Mdot
.516 .02284 Mdot
.516 .02285 Mdot
.516 .02295 Mdot
.516 .0231 Mdot
.516 .02312 Mdot
.516 .02321 Mdot
.516 .02326 Mdot
.516 .02336 Mdot
.516 .02338 Mdot
.516 .02339 Mdot
.516 .02349 Mdot
.516 .02354 Mdot
.516 .02364 Mdot
.516 .02366 Mdot
.516 .02367 Mdot
.516 .02377 Mdot
.516 .02382 Mdot
.516 .02393 Mdot
.516 .02395 Mdot
.516 .02395 Mdot
.516 .02396 Mdot
.516 .02406 Mdot
.516 .02411 Mdot
.516 .02416 Mdot
.516 .02422 Mdot
.516 .02422 Mdot
.516 .02424 Mdot
.516 .02425 Mdot
.516 .02425 Mdot
.516 .02425 Mdot
.516 .02435 Mdot
.516 .02441 Mdot
.516 .02446 Mdot
.516 .02452 Mdot
.516 .02453 Mdot
.516 .02455 Mdot
.516 .02455 Mdot
.516 .02456 Mdot
.516 .02456 Mdot
.516 .02466 Mdot
.516 .02472 Mdot
.516 .02477 Mdot
.516 .02484 Mdot
.516 .02484 Mdot
.516 .02486 Mdot
.516 .02487 Mdot
.516 .02487 Mdot
.516 .02487 Mdot
.516 .02498 Mdot
.516 .02504 Mdot
.516 .02509 Mdot
.516 .02516 Mdot
.516 .02516 Mdot
.516 .02519 Mdot
.516 .02519 Mdot
.516 .0252 Mdot
.516 .0252 Mdot
.516 .02531 Mdot
.516 .02537 Mdot
.516 .02543 Mdot
.516 .0255 Mdot
.516 .0255 Mdot
.516 .02552 Mdot
.516 .02553 Mdot
.516 .02553 Mdot
.516 .02553 Mdot
.516 .02565 Mdot
.516 .02572 Mdot
.516 .02577 Mdot
.516 .02584 Mdot
.516 .02584 Mdot
.516 .02587 Mdot
.516 .02588 Mdot
.516 .02588 Mdot
.516 .02588 Mdot
.516 .026 Mdot
.516 .02607 Mdot
.516 .02612 Mdot
.516 .0262 Mdot
.516 .0262 Mdot
.516 .02623 Mdot
.516 .02623 Mdot
.516 .02624 Mdot
.516 .02624 Mdot
.516 .02636 Mdot
.516 .02643 Mdot
.516 .02649 Mdot
.516 .02657 Mdot
.516 .02657 Mdot
.516 .02659 Mdot
.516 .0266 Mdot
.516 .0266 Mdot
.516 .02661 Mdot
.516 .02673 Mdot
.516 .02681 Mdot
.516 .02686 Mdot
.516 .02694 Mdot
.516 .02695 Mdot
.516 .02697 Mdot
.516 .02698 Mdot
.516 .02698 Mdot
.516 .02699 Mdot
.516 .02712 Mdot
.516 .02719 Mdot
.516 .02725 Mdot
.516 .02734 Mdot
.516 .02734 Mdot
.516 .02737 Mdot
.516 .02737 Mdot
.516 .02738 Mdot
.516 .02738 Mdot
.516 .02751 Mdot
.516 .02759 Mdot
.516 .02765 Mdot
.516 .02774 Mdot
.516 .02774 Mdot
.516 .02777 Mdot
.516 .02778 Mdot
.516 .02778 Mdot
.516 .02778 Mdot
.516 .02792 Mdot
.516 .028 Mdot
.516 .02807 Mdot
.516 .02816 Mdot
.516 .02816 Mdot
.516 .02819 Mdot
.516 .0282 Mdot
.516 .0282 Mdot
.516 .0282 Mdot
.516 .02835 Mdot
.516 .02843 Mdot
.516 .02849 Mdot
.516 .02859 Mdot
.516 .02859 Mdot
.516 .02862 Mdot
.516 .02863 Mdot
.516 .02863 Mdot
.516 .02863 Mdot
.516 .02878 Mdot
.516 .02887 Mdot
.516 .02894 Mdot
.516 .02903 Mdot
.516 .02903 Mdot
.516 .02906 Mdot
.516 .02907 Mdot
.516 .02908 Mdot
.516 .02908 Mdot
.516 .02923 Mdot
.516 .02932 Mdot
.516 .02939 Mdot
.516 .02949 Mdot
.516 .02949 Mdot
.516 .02952 Mdot
.516 .02953 Mdot
.516 .02954 Mdot
.516 .02954 Mdot
.516 .0297 Mdot
.516 .02979 Mdot
.516 .02986 Mdot
.516 .02996 Mdot
.516 .02996 Mdot
.516 .03 Mdot
.516 .03001 Mdot
.516 .03001 Mdot
.516 .03001 Mdot
.516 .03018 Mdot
.516 .03027 Mdot
.516 .03034 Mdot
.516 .03045 Mdot
.516 .03045 Mdot
.516 .03049 Mdot
.516 .0305 Mdot
.516 .0305 Mdot
.516 .0305 Mdot
.516 .03067 Mdot
.516 .03077 Mdot
.516 .03084 Mdot
.516 .03095 Mdot
.516 .03096 Mdot
.516 .03099 Mdot
.516 .031 Mdot
.516 .03101 Mdot
.516 .03101 Mdot
.516 .03118 Mdot
.516 .03128 Mdot
.516 .03136 Mdot
.516 .03147 Mdot
.516 .03148 Mdot
.516 .03151 Mdot
.516 .03152 Mdot
.516 .03153 Mdot
.516 .03153 Mdot
.516 .03171 Mdot
.516 .03181 Mdot
.516 .03189 Mdot
.516 .03201 Mdot
.516 .03201 Mdot
.516 .03205 Mdot
.516 .03206 Mdot
.516 .03206 Mdot
.516 .03207 Mdot
.516 .03225 Mdot
.516 .03236 Mdot
.516 .03244 Mdot
.516 .03256 Mdot
.516 .03257 Mdot
.516 .0326 Mdot
.516 .03262 Mdot
.516 .03262 Mdot
.516 .03262 Mdot
.516 .03281 Mdot
.516 .03292 Mdot
.516 .03301 Mdot
.516 .03313 Mdot
.516 .03314 Mdot
.516 .03318 Mdot
.516 .03319 Mdot
.516 .03319 Mdot
.516 .03319 Mdot
.516 .03339 Mdot
.516 .03351 Mdot
.516 .0336 Mdot
.516 .03372 Mdot
.516 .03373 Mdot
.516 .03377 Mdot
.516 .03378 Mdot
.516 .03378 Mdot
.516 .03379 Mdot
.516 .03399 Mdot
.516 .03411 Mdot
.516 .0342 Mdot
.516 .03433 Mdot
.516 .03433 Mdot
.516 .03438 Mdot
.516 .03439 Mdot
.516 .03439 Mdot
.516 .0344 Mdot
.516 .03461 Mdot
.516 .03473 Mdot
.516 .03482 Mdot
.516 .03496 Mdot
.516 .03496 Mdot
.516 .03501 Mdot
.516 .03502 Mdot
.516 .03502 Mdot
.516 .03503 Mdot
.516 .03524 Mdot
.516 .03537 Mdot
.516 .03547 Mdot
.516 .03561 Mdot
.516 .03561 Mdot
.516 .03566 Mdot
.516 .03567 Mdot
.516 .03567 Mdot
.516 .03568 Mdot
.516 .0359 Mdot
.516 .03603 Mdot
.516 .03613 Mdot
.516 .03627 Mdot
.516 .03628 Mdot
.516 .03633 Mdot
.516 .03634 Mdot
.516 .03634 Mdot
.516 .03635 Mdot
.516 .03658 Mdot
.516 .03671 Mdot
.516 .03682 Mdot
.516 .03696 Mdot
.516 .03697 Mdot
.516 .03702 Mdot
.516 .03703 Mdot
.516 .03704 Mdot
.516 .03704 Mdot
.516 .03728 Mdot
.516 .03742 Mdot
.516 .03752 Mdot
.516 .03768 Mdot
.516 .03768 Mdot
.516 .03773 Mdot
.516 .03775 Mdot
.516 .03775 Mdot
.516 .03775 Mdot
.516 .038 Mdot
.516 .03814 Mdot
.516 .03825 Mdot
.516 .03841 Mdot
.516 .03842 Mdot
.516 .03847 Mdot
.516 .03848 Mdot
.516 .03849 Mdot
.516 .03849 Mdot
.516 .03875 Mdot
.516 .03889 Mdot
.516 .03901 Mdot
.516 .03917 Mdot
.516 .03917 Mdot
.516 .03923 Mdot
.516 .03924 Mdot
.516 .03925 Mdot
.516 .03925 Mdot
.516 .03952 Mdot
.516 .03967 Mdot
.516 .03978 Mdot
.516 .03995 Mdot
.516 .03996 Mdot
.516 .04001 Mdot
.516 .04003 Mdot
.516 .04003 Mdot
.516 .04004 Mdot
.516 .04031 Mdot
.516 .04046 Mdot
.516 .04059 Mdot
.516 .04076 Mdot
.516 .04077 Mdot
.516 .04082 Mdot
.516 .04084 Mdot
.516 .04084 Mdot
.516 .04085 Mdot
.516 .04113 Mdot
.516 .04129 Mdot
.516 .04141 Mdot
.516 .04159 Mdot
.516 .0416 Mdot
.516 .04166 Mdot
.516 .04168 Mdot
.516 .04168 Mdot
.516 .04168 Mdot
.516 .04197 Mdot
.516 .04214 Mdot
.516 .04227 Mdot
.516 .04245 Mdot
.516 .04246 Mdot
.516 .04252 Mdot
.516 .04254 Mdot
.516 .04254 Mdot
.516 .04255 Mdot
.516 .04285 Mdot
.516 .04302 Mdot
.516 .04315 Mdot
.516 .04334 Mdot
.516 .04335 Mdot
.516 .04341 Mdot
.516 .04343 Mdot
.516 .04343 Mdot
.516 .04344 Mdot
.516 .04375 Mdot
.516 .04392 Mdot
.516 .04406 Mdot
.516 .04426 Mdot
.516 .04426 Mdot
.516 .04433 Mdot
.516 .04435 Mdot
.516 .04435 Mdot
.516 .04436 Mdot
.516 .04467 Mdot
.516 .04486 Mdot
.516 .045 Mdot
.516 .04521 Mdot
.516 .04528 Mdot
.516 .0453 Mdot
.516 .0453 Mdot
.516 .0453 Mdot
.516 .04563 Mdot
.516 .04582 Mdot
.516 .04597 Mdot
.516 .04618 Mdot
.516 .04625 Mdot
.516 .04627 Mdot
.516 .04628 Mdot
.516 .04628 Mdot
.516 .04662 Mdot
.516 .04682 Mdot
.516 .04697 Mdot
.516 .04719 Mdot
.516 .04726 Mdot
.516 .04728 Mdot
.516 .04729 Mdot
.516 .04729 Mdot
.516 .04764 Mdot
.516 .04784 Mdot
.516 .048 Mdot
.516 .04823 Mdot
.516 .0483 Mdot
.516 .04833 Mdot
.516 .04833 Mdot
.516 .04834 Mdot
.516 .0487 Mdot
.516 .0489 Mdot
.516 .04907 Mdot
.516 .0493 Mdot
.516 .04938 Mdot
.516 .0494 Mdot
.516 .04941 Mdot
.516 .04941 Mdot
.516 .04979 Mdot
.516 .05 Mdot
.516 .05017 Mdot
.516 .05041 Mdot
.516 .05049 Mdot
.516 .05051 Mdot
.516 .05052 Mdot
.516 .05052 Mdot
.516 .05091 Mdot
.516 .05113 Mdot
.516 .0513 Mdot
.516 .05155 Mdot
.516 .05163 Mdot
.516 .05166 Mdot
.516 .05166 Mdot
.516 .05167 Mdot
.516 .05207 Mdot
.516 .05229 Mdot
.516 .05247 Mdot
.516 .05273 Mdot
.516 .05281 Mdot
.516 .05284 Mdot
.516 .05285 Mdot
.516 .05285 Mdot
.516 .05326 Mdot
.516 .05349 Mdot
.516 .05368 Mdot
.516 .05395 Mdot
.516 .05403 Mdot
.516 .05406 Mdot
.516 .05407 Mdot
.516 .05407 Mdot
.516 .05449 Mdot
.516 .05473 Mdot
.516 .05493 Mdot
.516 .0552 Mdot
.516 .05529 Mdot
.516 .05532 Mdot
.516 .05533 Mdot
.516 .05533 Mdot
.516 .05577 Mdot
.516 .05601 Mdot
.516 .05621 Mdot
.516 .0565 Mdot
.516 .05659 Mdot
.516 .05662 Mdot
.516 .05663 Mdot
.516 .05663 Mdot
.516 .05708 Mdot
.516 .05734 Mdot
.516 .05754 Mdot
.516 .05784 Mdot
.516 .05793 Mdot
.516 .05796 Mdot
.516 .05797 Mdot
.516 .05797 Mdot
.516 .05844 Mdot
.516 .0587 Mdot
.516 .05891 Mdot
.516 .05922 Mdot
.516 .05931 Mdot
.516 .05934 Mdot
.516 .05935 Mdot
.516 .05936 Mdot
.516 .05984 Mdot
.516 .06011 Mdot
.516 .06032 Mdot
.516 .06064 Mdot
.516 .06074 Mdot
.516 .06077 Mdot
.516 .06078 Mdot
.516 .06078 Mdot
.516 .06128 Mdot
.516 .06156 Mdot
.516 .06178 Mdot
.516 .06211 Mdot
.516 .06221 Mdot
.516 .06224 Mdot
.516 .06225 Mdot
.516 .06226 Mdot
.516 .06277 Mdot
.516 .06306 Mdot
.516 .06329 Mdot
.516 .06363 Mdot
.516 .06373 Mdot
.516 .06376 Mdot
.516 .06377 Mdot
.516 .06378 Mdot
.516 .06431 Mdot
.516 .06461 Mdot
.516 .06484 Mdot
.516 .06519 Mdot
.516 .0653 Mdot
.516 .06533 Mdot
.516 .06534 Mdot
.516 .06535 Mdot
.516 .06589 Mdot
.516 .0662 Mdot
.516 .06645 Mdot
.516 .06681 Mdot
.516 .06692 Mdot
.516 .06695 Mdot
.516 .06696 Mdot
.516 .06697 Mdot
.516 .06753 Mdot
.516 .06785 Mdot
.516 .0681 Mdot
.516 .06847 Mdot
.516 .06859 Mdot
.516 .06863 Mdot
.516 .06864 Mdot
.516 .06864 Mdot
.516 .06922 Mdot
.516 .06955 Mdot
.516 .06981 Mdot
.516 .07019 Mdot
.516 .07031 Mdot
.516 .07035 Mdot
.516 .07036 Mdot
.516 .07037 Mdot
.516 .07097 Mdot
.516 .07131 Mdot
.516 .07158 Mdot
.516 .07197 Mdot
.516 .07209 Mdot
.516 .07213 Mdot
.516 .07214 Mdot
.516 .07215 Mdot
.516 .07277 Mdot
.516 .07312 Mdot
.516 .0734 Mdot
.516 .0738 Mdot
.516 .07393 Mdot
.516 .07397 Mdot
.516 .07398 Mdot
.516 .07399 Mdot
.516 .07462 Mdot
.516 .07499 Mdot
.516 .07527 Mdot
.516 .07569 Mdot
.516 .07583 Mdot
.516 .07586 Mdot
.516 .07588 Mdot
.516 .07588 Mdot
.516 .07654 Mdot
.516 .07691 Mdot
.516 .07721 Mdot
.516 .07764 Mdot
.516 .07778 Mdot
.516 .07782 Mdot
.516 .07783 Mdot
.516 .07784 Mdot
.516 .07852 Mdot
.516 .0789 Mdot
.516 .07921 Mdot
.516 .07966 Mdot
.516 .0798 Mdot
.516 .07984 Mdot
.516 .07985 Mdot
.516 .07986 Mdot
.516 .08056 Mdot
.516 .08096 Mdot
.516 .08128 Mdot
.516 .08173 Mdot
.516 .08188 Mdot
.516 .08192 Mdot
.516 .08194 Mdot
.516 .08195 Mdot
.516 .08267 Mdot
.516 .08308 Mdot
.516 .08341 Mdot
.516 .08388 Mdot
.516 .08403 Mdot
.516 .08408 Mdot
.516 .08409 Mdot
.516 .0841 Mdot
.516 .08484 Mdot
.516 .08527 Mdot
.516 .0856 Mdot
.516 .08609 Mdot
.516 .08625 Mdot
.516 .0863 Mdot
.516 .08631 Mdot
.516 .08632 Mdot
.516 .08709 Mdot
.516 .08752 Mdot
.516 .08787 Mdot
.516 .08838 Mdot
.516 .08854 Mdot
.516 .08859 Mdot
.516 .0886 Mdot
.516 .08861 Mdot
.516 .0894 Mdot
.516 .08985 Mdot
.516 .09021 Mdot
.516 .09073 Mdot
.516 .0909 Mdot
.516 .09095 Mdot
.516 .09097 Mdot
.516 .09097 Mdot
.516 .09179 Mdot
.516 .09226 Mdot
.516 .09263 Mdot
.516 .09317 Mdot
.516 .09334 Mdot
.516 .09339 Mdot
.516 .09341 Mdot
.516 .09341 Mdot
.516 .09426 Mdot
.516 .09474 Mdot
.516 .09512 Mdot
.516 .09568 Mdot
.516 .09585 Mdot
.516 .09591 Mdot
.516 .09592 Mdot
.516 .09593 Mdot
.516 .0968 Mdot
.516 .0973 Mdot
.516 .09769 Mdot
.516 .09827 Mdot
.516 .09845 Mdot
.516 .0985 Mdot
.516 .09852 Mdot
.516 .09853 Mdot
.516 .09943 Mdot
.516 .09994 Mdot
.516 .10035 Mdot
.516 .10094 Mdot
.516 .10113 Mdot
.516 .10119 Mdot
.516 .1012 Mdot
.516 .10121 Mdot
.516 .10214 Mdot
.516 .10267 Mdot
.516 .10309 Mdot
.516 .1037 Mdot
.516 .1039 Mdot
.516 .10395 Mdot
.516 .10397 Mdot
.516 .10398 Mdot
.516 .10494 Mdot
.516 .10548 Mdot
.516 .10592 Mdot
.516 .10655 Mdot
.516 .10675 Mdot
.516 .10681 Mdot
.516 .10683 Mdot
.516 .10684 Mdot
.516 .10783 Mdot
.516 .10839 Mdot
.516 .10884 Mdot
.516 .10949 Mdot
.516 .10969 Mdot
.516 .10976 Mdot
.516 .10978 Mdot
.516 .10978 Mdot
.516 .11081 Mdot
.516 .11139 Mdot
.516 .11185 Mdot
.516 .11252 Mdot
.516 .11273 Mdot
.516 .1128 Mdot
.516 .11282 Mdot
.516 .11283 Mdot
.516 .11388 Mdot
.516 .11448 Mdot
.516 .11496 Mdot
.516 .11565 Mdot
.516 .11587 Mdot
.516 .11594 Mdot
.516 .11596 Mdot
.516 .11597 Mdot
.516 .11705 Mdot
.516 .11767 Mdot
.516 .11816 Mdot
.516 .11888 Mdot
.516 .11911 Mdot
.516 .11917 Mdot
.516 .1192 Mdot
.516 .11921 Mdot
.516 .12033 Mdot
.516 .12097 Mdot
.516 .12148 Mdot
.516 .12221 Mdot
.516 .12245 Mdot
.516 .12252 Mdot
.516 .12254 Mdot
.516 .12255 Mdot
.516 .12371 Mdot
.516 .12437 Mdot
.516 .12489 Mdot
.516 .12565 Mdot
.516 .1259 Mdot
.516 .12597 Mdot
.516 .12599 Mdot
.516 .126 Mdot
.516 .1272 Mdot
.516 .12788 Mdot
.516 .12842 Mdot
.516 .1292 Mdot
.516 .12945 Mdot
.516 .12953 Mdot
.516 .12955 Mdot
.516 .12956 Mdot
.516 .1308 Mdot
.516 .1315 Mdot
.516 .13206 Mdot
.516 .13287 Mdot
.516 .13312 Mdot
.516 .1332 Mdot
.516 .13323 Mdot
.516 .13324 Mdot
.516 .13451 Mdot
.516 .13523 Mdot
.516 .13581 Mdot
.516 .13665 Mdot
.516 .13691 Mdot
.516 .13699 Mdot
.516 .13702 Mdot
.516 .13703 Mdot
.516 .13834 Mdot
.516 .13909 Mdot
.516 .13969 Mdot
.516 .14055 Mdot
.516 .14082 Mdot
.516 .14091 Mdot
.516 .14093 Mdot
.516 .14094 Mdot
.516 .1423 Mdot
.516 .14307 Mdot
.516 .14368 Mdot
.516 .14457 Mdot
.516 .14486 Mdot
.516 .14494 Mdot
.516 .14497 Mdot
.516 .14498 Mdot
.516 .14638 Mdot
.516 .14718 Mdot
.516 .14781 Mdot
.516 .14873 Mdot
.516 .14902 Mdot
.516 .14911 Mdot
.516 .14914 Mdot
.516 .14915 Mdot
.516 .1506 Mdot
.516 .15142 Mdot
.516 .15207 Mdot
.516 .15302 Mdot
.516 .15332 Mdot
.516 .15341 Mdot
.516 .15344 Mdot
.516 .15345 Mdot
.516 .15495 Mdot
.516 .15579 Mdot
.516 .15647 Mdot
.516 .15744 Mdot
.516 .15776 Mdot
.516 .15785 Mdot
.516 .15788 Mdot
.516 .15789 Mdot
.516 .15943 Mdot
.516 .16031 Mdot
.516 .161 Mdot
.516 .16201 Mdot
.516 .16233 Mdot
.516 .16243 Mdot
.516 .16246 Mdot
.516 .16247 Mdot
.516 .16406 Mdot
.516 .16496 Mdot
.516 .16568 Mdot
.516 .16672 Mdot
.516 .16706 Mdot
.516 .16716 Mdot
.516 .16719 Mdot
.516 .1672 Mdot
.516 .16884 Mdot
.516 .16977 Mdot
.516 .17051 Mdot
.516 .17159 Mdot
.516 .17193 Mdot
.516 .17204 Mdot
.516 .17207 Mdot
.516 .17208 Mdot
.516 .17378 Mdot
.516 .17473 Mdot
.516 .1755 Mdot
.516 .17661 Mdot
.516 .17696 Mdot
.516 .17707 Mdot
.516 .1771 Mdot
.516 .17712 Mdot
.516 .17886 Mdot
.516 .17986 Mdot
.516 .18065 Mdot
.516 .18179 Mdot
.516 .18216 Mdot
.516 .18226 Mdot
.516 .1823 Mdot
.516 .18232 Mdot
.516 .18412 Mdot
.516 .18514 Mdot
.516 .18595 Mdot
.516 .18714 Mdot
.516 .18751 Mdot
.516 .18763 Mdot
.516 .18766 Mdot
.516 .18768 Mdot
.516 .18954 Mdot
.516 .19059 Mdot
.516 .19143 Mdot
.516 .19265 Mdot
.516 .19304 Mdot
.516 .19316 Mdot
.516 .1932 Mdot
.516 .19321 Mdot
.516 .19513 Mdot
.516 .19622 Mdot
.516 .19709 Mdot
.516 .19835 Mdot
.516 .19875 Mdot
.516 .19887 Mdot
.516 .19891 Mdot
.516 .19893 Mdot
.516 .20091 Mdot
.516 .20203 Mdot
.516 .20293 Mdot
.516 .20422 Mdot
.516 .20464 Mdot
.516 .20476 Mdot
.516 .2048 Mdot
.516 .20482 Mdot
.516 .20686 Mdot
.516 .20802 Mdot
.516 .20895 Mdot
.516 .21029 Mdot
.516 .21072 Mdot
.516 .21084 Mdot
.516 .21089 Mdot
.516 .2109 Mdot
.516 .21301 Mdot
.516 .21421 Mdot
.516 .21516 Mdot
.516 .21655 Mdot
.516 .21699 Mdot
.516 .21712 Mdot
.516 .21716 Mdot
.516 .21718 Mdot
.516 .21936 Mdot
.516 .22059 Mdot
.516 .22158 Mdot
.516 .22301 Mdot
.516 .22346 Mdot
.516 .2236 Mdot
.516 .22364 Mdot
.516 .22366 Mdot
.516 .22591 Mdot
.516 .22718 Mdot
.516 .2282 Mdot
.516 .22967 Mdot
.516 .23014 Mdot
.516 .23028 Mdot
.516 .23033 Mdot
.516 .23035 Mdot
.516 .23267 Mdot
.516 .23398 Mdot
.516 .23503 Mdot
.516 .23655 Mdot
.516 .23704 Mdot
.516 .23718 Mdot
.516 .23723 Mdot
.516 .23725 Mdot
.516 .23964 Mdot
.516 .241 Mdot
.516 .24208 Mdot
.516 .24365 Mdot
.516 .24415 Mdot
.516 .2443 Mdot
.516 .24435 Mdot
.516 .24437 Mdot
.516 .24684 Mdot
.516 .24824 Mdot
.516 .24935 Mdot
.516 .25097 Mdot
.516 .25149 Mdot
.516 .25165 Mdot
.516 .25169 Mdot
.516 .25172 Mdot
.516 .25427 Mdot
.516 .25571 Mdot
.516 .25686 Mdot
.516 .25853 Mdot
.516 .25907 Mdot
.516 .25923 Mdot
.516 .25928 Mdot
.516 .2593 Mdot
.516 .26193 Mdot
.516 .26342 Mdot
.516 .26461 Mdot
.516 .26634 Mdot
.516 .26689 Mdot
.516 .26705 Mdot
.516 .2671 Mdot
.516 .26713 Mdot
.516 .26984 Mdot
.516 .27138 Mdot
.516 .27261 Mdot
.516 .27439 Mdot
.516 .27496 Mdot
.516 .27513 Mdot
.516 .27518 Mdot
.516 .2752 Mdot
.516 .27801 Mdot
.516 .27959 Mdot
.516 .28086 Mdot
.516 .2827 Mdot
.516 .28329 Mdot
.516 .28346 Mdot
.516 .28352 Mdot
.516 .28354 Mdot
.516 .28643 Mdot
.516 .28807 Mdot
.516 .28938 Mdot
.516 .29127 Mdot
.516 .29188 Mdot
.516 .29206 Mdot
.516 .29212 Mdot
.516 .29214 Mdot
.516 .29513 Mdot
.516 .29682 Mdot
.516 .29817 Mdot
.516 .30012 Mdot
.516 .30075 Mdot
.516 .30093 Mdot
.516 .30099 Mdot
.516 .30102 Mdot
.516 .3041 Mdot
.516 .30584 Mdot
.516 .30724 Mdot
.516 .30926 Mdot
.516 .3099 Mdot
.516 .31009 Mdot
.516 .31015 Mdot
.516 .31018 Mdot
.516 .31336 Mdot
.516 .31516 Mdot
.516 .3166 Mdot
.516 .31868 Mdot
.516 .31935 Mdot
.516 .31955 Mdot
.516 .31961 Mdot
.516 .31964 Mdot
.518 .01608 Mdot
.518 .01613 Mdot
.518 .01618 Mdot
.518 .01624 Mdot
.518 .01629 Mdot
.518 .01635 Mdot
.518 .01641 Mdot
.518 .01647 Mdot
.518 .01653 Mdot
.518 .0166 Mdot
.518 .01666 Mdot
.518 .01673 Mdot
.518 .01681 Mdot
.518 .01688 Mdot
.518 .01696 Mdot
.518 .01704 Mdot
.518 .01712 Mdot
.518 .01721 Mdot
.518 .0173 Mdot
.518 .01739 Mdot
.518 .01749 Mdot
.518 .01759 Mdot
.518 .01769 Mdot
.518 .01778 Mdot
.518 .0178 Mdot
.518 .01789 Mdot
.518 .01791 Mdot
.518 .018 Mdot
.518 .01803 Mdot
.518 .01812 Mdot
.518 .01815 Mdot
.518 .01824 Mdot
.518 .01827 Mdot
.518 .01837 Mdot
.518 .01837 Mdot
.518 .0184 Mdot
.518 .0185 Mdot
.518 .01851 Mdot
.518 .01853 Mdot
.518 .01864 Mdot
.518 .01864 Mdot
.518 .01867 Mdot
.518 .01878 Mdot
.518 .01878 Mdot
.518 .01881 Mdot
.518 .01893 Mdot
.518 .01893 Mdot
.518 .01896 Mdot
.518 .01908 Mdot
.518 .01908 Mdot
.518 .01911 Mdot
.518 .01923 Mdot
.518 .01924 Mdot
.518 .01927 Mdot
.518 .0194 Mdot
.518 .0194 Mdot
.518 .01943 Mdot
.518 .01957 Mdot
.518 .01957 Mdot
.518 .0196 Mdot
.518 .01974 Mdot
.518 .01974 Mdot
.518 .01978 Mdot
.518 .01992 Mdot
.518 .01993 Mdot
.518 .01996 Mdot
.518 .02011 Mdot
.518 .02011 Mdot
.518 .02015 Mdot
.518 .0203 Mdot
.518 .02031 Mdot
.518 .02034 Mdot
.518 .0205 Mdot
.518 .02051 Mdot
.518 .02055 Mdot
.518 .02071 Mdot
.518 .02072 Mdot
.518 .02076 Mdot
.518 .02082 Mdot
.518 .02093 Mdot
.518 .02093 Mdot
.518 .02097 Mdot
.518 .02104 Mdot
.518 .02115 Mdot
.518 .02116 Mdot
.518 .0212 Mdot
.518 .02127 Mdot
.518 .02138 Mdot
.518 .02139 Mdot
.518 .02143 Mdot
.518 .0215 Mdot
.518 .02162 Mdot
.518 .02163 Mdot
.518 .02168 Mdot
.518 .02175 Mdot
.518 .02187 Mdot
.518 .02188 Mdot
.518 .02193 Mdot
.518 .022 Mdot
.518 .02213 Mdot
.518 .02214 Mdot
.518 .02219 Mdot
.518 .02226 Mdot
.518 .0224 Mdot
.518 .0224 Mdot
.518 .02245 Mdot
.518 .02253 Mdot
.518 .02267 Mdot
.518 .02268 Mdot
.518 .02273 Mdot
.518 .02281 Mdot
.518 .02296 Mdot
.518 .02297 Mdot
.518 .02302 Mdot
.518 .02311 Mdot
.518 .02319 Mdot
.518 .02326 Mdot
.518 .02326 Mdot
.518 .02332 Mdot
.518 .02336 Mdot
.518 .02341 Mdot
.518 .02349 Mdot
.518 .02356 Mdot
.518 .02357 Mdot
.518 .0236 Mdot
.518 .02363 Mdot
.518 .02367 Mdot
.518 .02372 Mdot
.518 .02381 Mdot
.518 .02388 Mdot
.518 .02389 Mdot
.518 .02392 Mdot
.518 .02395 Mdot
.518 .02399 Mdot
.518 .02405 Mdot
.518 .02414 Mdot
.518 .02421 Mdot
.518 .02422 Mdot
.518 .02425 Mdot
.518 .02428 Mdot
.518 .02433 Mdot
.518 .02438 Mdot
.518 .02448 Mdot
.518 .02456 Mdot
.518 .02456 Mdot
.518 .0246 Mdot
.518 .02463 Mdot
.518 .02463 Mdot
.518 .02467 Mdot
.518 .02473 Mdot
.518 .02483 Mdot
.518 .02491 Mdot
.518 .02492 Mdot
.518 .02495 Mdot
.518 .02498 Mdot
.518 .02499 Mdot
.518 .02503 Mdot
.518 .02509 Mdot
.518 .02519 Mdot
.518 .02528 Mdot
.518 .02528 Mdot
.518 .02532 Mdot
.518 .02535 Mdot
.518 .02536 Mdot
.518 .0254 Mdot
.518 .02546 Mdot
.518 .02557 Mdot
.518 .02565 Mdot
.518 .02566 Mdot
.518 .02567 Mdot
.518 .0257 Mdot
.518 .02574 Mdot
.518 .02574 Mdot
.518 .02579 Mdot
.518 .02585 Mdot
.518 .02596 Mdot
.518 .02604 Mdot
.518 .02605 Mdot
.518 .02606 Mdot
.518 .0261 Mdot
.518 .02613 Mdot
.518 .02614 Mdot
.518 .02619 Mdot
.518 .02625 Mdot
.518 .02636 Mdot
.518 .02645 Mdot
.518 .02646 Mdot
.518 .02647 Mdot
.518 .02651 Mdot
.518 .02654 Mdot
.518 .02655 Mdot
.518 .0266 Mdot
.518 .02667 Mdot
.518 .02678 Mdot
.518 .02688 Mdot
.518 .02688 Mdot
.518 .02689 Mdot
.518 .02693 Mdot
.518 .02697 Mdot
.518 .02697 Mdot
.518 .02703 Mdot
.518 .0271 Mdot
.518 .02722 Mdot
.518 .02731 Mdot
.518 .02732 Mdot
.518 .02733 Mdot
.518 .02737 Mdot
.518 .02741 Mdot
.518 .02741 Mdot
.518 .02747 Mdot
.518 .02754 Mdot
.518 .02767 Mdot
.518 .02777 Mdot
.518 .02777 Mdot
.518 .02778 Mdot
.518 .02783 Mdot
.518 .02787 Mdot
.518 .02787 Mdot
.518 .02793 Mdot
.518 .028 Mdot
.518 .02813 Mdot
.518 .02824 Mdot
.518 .02824 Mdot
.518 .02825 Mdot
.518 .0283 Mdot
.518 .02834 Mdot
.518 .02834 Mdot
.518 .02841 Mdot
.518 .02848 Mdot
.518 .02862 Mdot
.518 .02872 Mdot
.518 .02873 Mdot
.518 .02874 Mdot
.518 .02879 Mdot
.518 .02883 Mdot
.518 .02883 Mdot
.518 .0289 Mdot
.518 .02898 Mdot
.518 .02912 Mdot
.518 .02923 Mdot
.518 .02924 Mdot
.518 .02925 Mdot
.518 .02929 Mdot
.518 .02934 Mdot
.518 .02934 Mdot
.518 .02941 Mdot
.518 .02949 Mdot
.518 .02964 Mdot
.518 .02975 Mdot
.518 .02976 Mdot
.518 .02977 Mdot
.518 .02982 Mdot
.518 .02987 Mdot
.518 .02987 Mdot
.518 .02994 Mdot
.518 .03002 Mdot
.518 .03017 Mdot
.518 .03029 Mdot
.518 .0303 Mdot
.518 .03031 Mdot
.518 .03036 Mdot
.518 .03041 Mdot
.518 .03042 Mdot
.518 .03049 Mdot
.518 .03057 Mdot
.518 .03073 Mdot
.518 .03085 Mdot
.518 .03086 Mdot
.518 .03087 Mdot
.518 .03093 Mdot
.518 .03098 Mdot
.518 .03098 Mdot
.518 .03106 Mdot
.518 .03115 Mdot
.518 .03131 Mdot
.518 .03143 Mdot
.518 .03144 Mdot
.518 .03145 Mdot
.518 .03151 Mdot
.518 .03156 Mdot
.518 .03157 Mdot
.518 .03164 Mdot
.518 .03174 Mdot
.518 .0319 Mdot
.518 .03203 Mdot
.518 .03204 Mdot
.518 .03206 Mdot
.518 .03211 Mdot
.518 .03217 Mdot
.518 .03217 Mdot
.518 .03225 Mdot
.518 .03235 Mdot
.518 .03252 Mdot
.518 .03266 Mdot
.518 .03267 Mdot
.518 .03268 Mdot
.518 .03274 Mdot
.518 .0328 Mdot
.518 .0328 Mdot
.518 .03288 Mdot
.518 .03298 Mdot
.518 .03316 Mdot
.518 .0333 Mdot
.518 .03331 Mdot
.518 .03333 Mdot
.518 .03339 Mdot
.518 .03345 Mdot
.518 .03345 Mdot
.518 .03354 Mdot
.518 .03364 Mdot
.518 .03383 Mdot
.518 .03397 Mdot
.518 .03398 Mdot
.518 .034 Mdot
.518 .03406 Mdot
.518 .03412 Mdot
.518 .03413 Mdot
.518 .03422 Mdot
.518 .03432 Mdot
.518 .03452 Mdot
.518 .03467 Mdot
.518 .03468 Mdot
.518 .03469 Mdot
.518 .03476 Mdot
.518 .03482 Mdot
.518 .03483 Mdot
.518 .03492 Mdot
.518 .03503 Mdot
.518 .03523 Mdot
.518 .03538 Mdot
.518 .0354 Mdot
.518 .03541 Mdot
.518 .03548 Mdot
.518 .03555 Mdot
.518 .03555 Mdot
.518 .03565 Mdot
.518 .03576 Mdot
.518 .03597 Mdot
.518 .03613 Mdot
.518 .03614 Mdot
.518 .03616 Mdot
.518 .03623 Mdot
.518 .0363 Mdot
.518 .0363 Mdot
.518 .0364 Mdot
.518 .03652 Mdot
.518 .03673 Mdot
.518 .0369 Mdot
.518 .03691 Mdot
.518 .03693 Mdot
.518 .037 Mdot
.518 .03707 Mdot
.518 .03708 Mdot
.518 .03718 Mdot
.518 .0373 Mdot
.518 .03753 Mdot
.518 .0377 Mdot
.518 .03771 Mdot
.518 .03773 Mdot
.518 .0378 Mdot
.518 .03788 Mdot
.518 .03788 Mdot
.518 .03799 Mdot
.518 .03812 Mdot
.518 .03835 Mdot
.518 .03853 Mdot
.518 .03854 Mdot
.518 .03856 Mdot
.518 .03863 Mdot
.518 .03871 Mdot
.518 .03872 Mdot
.518 .03883 Mdot
.518 .03896 Mdot
.518 .0392 Mdot
.518 .03938 Mdot
.518 .0394 Mdot
.518 .03942 Mdot
.518 .0395 Mdot
.518 .03958 Mdot
.518 .03958 Mdot
.518 .03969 Mdot
.518 .03983 Mdot
.518 .04008 Mdot
.518 .04027 Mdot
.518 .04028 Mdot
.518 .0403 Mdot
.518 .04039 Mdot
.518 .04047 Mdot
.518 .04047 Mdot
.518 .04059 Mdot
.518 .04074 Mdot
.518 .04099 Mdot
.518 .04119 Mdot
.518 .04121 Mdot
.518 .04123 Mdot
.518 .04131 Mdot
.518 .0414 Mdot
.518 .0414 Mdot
.518 .04152 Mdot
.518 .04167 Mdot
.518 .04194 Mdot
.518 .04214 Mdot
.518 .04216 Mdot
.518 .04218 Mdot
.518 .04227 Mdot
.518 .04236 Mdot
.518 .04236 Mdot
.518 .04249 Mdot
.518 .04264 Mdot
.518 .04292 Mdot
.518 .04313 Mdot
.518 .04315 Mdot
.518 .04317 Mdot
.518 .04326 Mdot
.518 .04335 Mdot
.518 .04336 Mdot
.518 .04349 Mdot
.518 .04365 Mdot
.518 .04393 Mdot
.518 .04415 Mdot
.518 .04417 Mdot
.518 .04419 Mdot
.518 .04429 Mdot
.518 .04438 Mdot
.518 .04439 Mdot
.518 .04453 Mdot
.518 .04469 Mdot
.518 .04498 Mdot
.518 .04521 Mdot
.518 .04523 Mdot
.518 .04525 Mdot
.518 .04535 Mdot
.518 .04545 Mdot
.518 .04546 Mdot
.518 .0456 Mdot
.518 .04577 Mdot
.518 .04607 Mdot
.518 .04631 Mdot
.518 .04633 Mdot
.518 .04635 Mdot
.518 .04646 Mdot
.518 .04656 Mdot
.518 .04656 Mdot
.518 .04671 Mdot
.518 .04689 Mdot
.518 .0472 Mdot
.518 .04745 Mdot
.518 .04747 Mdot
.518 .04749 Mdot
.518 .0476 Mdot
.518 .04771 Mdot
.518 .04771 Mdot
.518 .04786 Mdot
.518 .04805 Mdot
.518 .04837 Mdot
.518 .04863 Mdot
.518 .04865 Mdot
.518 .04867 Mdot
.518 .04878 Mdot
.518 .04889 Mdot
.518 .0489 Mdot
.518 .04906 Mdot
.518 .04925 Mdot
.518 .04958 Mdot
.518 .04985 Mdot
.518 .04987 Mdot
.518 .0499 Mdot
.518 .05001 Mdot
.518 .05012 Mdot
.518 .05013 Mdot
.518 .05029 Mdot
.518 .05049 Mdot
.518 .05084 Mdot
.518 .05111 Mdot
.518 .05113 Mdot
.518 .05116 Mdot
.518 .05128 Mdot
.518 .0514 Mdot
.518 .0514 Mdot
.518 .05157 Mdot
.518 .05178 Mdot
.518 .05214 Mdot
.518 .05242 Mdot
.518 .05244 Mdot
.518 .05247 Mdot
.518 .0526 Mdot
.518 .05272 Mdot
.518 .05273 Mdot
.518 .0529 Mdot
.518 .05311 Mdot
.518 .05349 Mdot
.518 .05378 Mdot
.518 .0538 Mdot
.518 .05383 Mdot
.518 .05396 Mdot
.518 .05409 Mdot
.518 .05409 Mdot
.518 .05427 Mdot
.518 .05449 Mdot
.518 .05488 Mdot
.518 .05519 Mdot
.518 .05521 Mdot
.518 .05524 Mdot
.518 .05537 Mdot
.518 .0555 Mdot
.518 .05551 Mdot
.518 .0557 Mdot
.518 .05592 Mdot
.518 .05633 Mdot
.518 .05665 Mdot
.518 .05667 Mdot
.518 .0567 Mdot
.518 .05684 Mdot
.518 .05697 Mdot
.518 .05698 Mdot
.518 .05717 Mdot
.518 .05741 Mdot
.518 .05783 Mdot
.518 .05815 Mdot
.518 .05818 Mdot
.518 .05821 Mdot
.518 .05835 Mdot
.518 .05849 Mdot
.518 .0585 Mdot
.518 .0587 Mdot
.518 .05895 Mdot
.518 .05938 Mdot
.518 .05972 Mdot
.518 .05974 Mdot
.518 .05978 Mdot
.518 .05992 Mdot
.518 .06007 Mdot
.518 .06008 Mdot
.518 .06029 Mdot
.518 .06054 Mdot
.518 .06099 Mdot
.518 .06134 Mdot
.518 .06136 Mdot
.518 .0614 Mdot
.518 .06155 Mdot
.518 .0617 Mdot
.518 .06171 Mdot
.518 .06193 Mdot
.518 .06219 Mdot
.518 .06265 Mdot
.518 .06302 Mdot
.518 .06304 Mdot
.518 .06308 Mdot
.518 .06324 Mdot
.518 .0634 Mdot
.518 .0634 Mdot
.518 .06363 Mdot
.518 .0639 Mdot
.518 .06438 Mdot
.518 .06476 Mdot
.518 .06478 Mdot
.518 .06482 Mdot
.518 .06498 Mdot
.518 .06515 Mdot
.518 .06516 Mdot
.518 .06539 Mdot
.518 .06567 Mdot
.518 .06617 Mdot
.518 .06656 Mdot
.518 .06659 Mdot
.518 .06663 Mdot
.518 .06679 Mdot
.518 .06696 Mdot
.518 .06697 Mdot
.518 .06721 Mdot
.518 .0675 Mdot
.518 .06802 Mdot
.518 .06842 Mdot
.518 .06845 Mdot
.518 .06849 Mdot
.518 .06867 Mdot
.518 .06884 Mdot
.518 .06885 Mdot
.518 .0691 Mdot
.518 .0694 Mdot
.518 .06994 Mdot
.518 .07036 Mdot
.518 .07039 Mdot
.518 .07043 Mdot
.518 .07061 Mdot
.518 .07079 Mdot
.518 .0708 Mdot
.518 .07106 Mdot
.518 .07137 Mdot
.518 .07193 Mdot
.518 .07236 Mdot
.518 .07239 Mdot
.518 .07244 Mdot
.518 .07262 Mdot
.518 .07281 Mdot
.518 .07282 Mdot
.518 .07309 Mdot
.518 .07341 Mdot
.518 .07399 Mdot
.518 .07444 Mdot
.518 .07447 Mdot
.518 .07451 Mdot
.518 .07471 Mdot
.518 .0749 Mdot
.518 .07491 Mdot
.518 .07519 Mdot
.518 .07552 Mdot
.518 .07612 Mdot
.518 .07659 Mdot
.518 .07662 Mdot
.518 .07667 Mdot
.518 .07687 Mdot
.518 .07707 Mdot
.518 .07737 Mdot
.518 .07771 Mdot
.518 .07833 Mdot
.518 .07881 Mdot
.518 .07885 Mdot
.518 .0789 Mdot
.518 .07911 Mdot
.518 .07931 Mdot
.518 .07962 Mdot
.518 .07998 Mdot
.518 .08062 Mdot
.518 .08112 Mdot
.518 .08116 Mdot
.518 .08121 Mdot
.518 .08142 Mdot
.518 .08164 Mdot
.518 .08196 Mdot
.518 .08233 Mdot
.518 .08299 Mdot
.518 .08351 Mdot
.518 .08355 Mdot
.518 .0836 Mdot
.518 .08383 Mdot
.518 .08405 Mdot
.518 .08438 Mdot
.518 .08476 Mdot
.518 .08545 Mdot
.518 .08599 Mdot
.518 .08603 Mdot
.518 .08608 Mdot
.518 .08631 Mdot
.518 .08655 Mdot
.518 .08689 Mdot
.518 .08728 Mdot
.518 .088 Mdot
.518 .08855 Mdot
.518 .08859 Mdot
.518 .08865 Mdot
.518 .08889 Mdot
.518 .08913 Mdot
.518 .08949 Mdot
.518 .0899 Mdot
.518 .09064 Mdot
.518 .09121 Mdot
.518 .09125 Mdot
.518 .09131 Mdot
.518 .09156 Mdot
.518 .09181 Mdot
.518 .09218 Mdot
.518 .0926 Mdot
.518 .09337 Mdot
.518 .09397 Mdot
.518 .09401 Mdot
.518 .09407 Mdot
.518 .09433 Mdot
.518 .09459 Mdot
.518 .09497 Mdot
.518 .09541 Mdot
.518 .0962 Mdot
.518 .09682 Mdot
.518 .09686 Mdot
.518 .09693 Mdot
.518 .09719 Mdot
.518 .09746 Mdot
.518 .09785 Mdot
.518 .09831 Mdot
.518 .09913 Mdot
.518 .09977 Mdot
.518 .09982 Mdot
.518 .09989 Mdot
.518 .10016 Mdot
.518 .10044 Mdot
.518 .10085 Mdot
.518 .10132 Mdot
.518 .10217 Mdot
.518 .10284 Mdot
.518 .10288 Mdot
.518 .10295 Mdot
.518 .10324 Mdot
.518 .10353 Mdot
.518 .10395 Mdot
.518 .10444 Mdot
.518 .10532 Mdot
.518 .10601 Mdot
.518 .10606 Mdot
.518 .10613 Mdot
.518 .10643 Mdot
.518 .10672 Mdot
.518 .10716 Mdot
.518 .10767 Mdot
.518 .10858 Mdot
.518 .1093 Mdot
.518 .10935 Mdot
.518 .10942 Mdot
.518 .10973 Mdot
.518 .11004 Mdot
.518 .11049 Mdot
.518 .11102 Mdot
.518 .11196 Mdot
.518 .1127 Mdot
.518 .11275 Mdot
.518 .11283 Mdot
.518 .11315 Mdot
.518 .11347 Mdot
.518 .11394 Mdot
.518 .11448 Mdot
.518 .11546 Mdot
.518 .11623 Mdot
.518 .11628 Mdot
.518 .11636 Mdot
.518 .11669 Mdot
.518 .11702 Mdot
.518 .11751 Mdot
.518 .11807 Mdot
.518 .11909 Mdot
.518 .11988 Mdot
.518 .11994 Mdot
.518 .12002 Mdot
.518 .12036 Mdot
.518 .12071 Mdot
.518 .12121 Mdot
.518 .1218 Mdot
.518 .12285 Mdot
.518 .12367 Mdot
.518 .12373 Mdot
.518 .12381 Mdot
.518 .12417 Mdot
.518 .12452 Mdot
.518 .12504 Mdot
.518 .12565 Mdot
.518 .12674 Mdot
.518 .12759 Mdot
.518 .12765 Mdot
.518 .12774 Mdot
.518 .12811 Mdot
.518 .12847 Mdot
.518 .12901 Mdot
.518 .12964 Mdot
.518 .12987 Mdot
.518 .13077 Mdot
.518 .13165 Mdot
.518 .13172 Mdot
.518 .13181 Mdot
.518 .13219 Mdot
.518 .13257 Mdot
.518 .13313 Mdot
.518 .13378 Mdot
.518 .13401 Mdot
.518 .13495 Mdot
.518 .13586 Mdot
.518 .13593 Mdot
.518 .13602 Mdot
.518 .13642 Mdot
.518 .13681 Mdot
.518 .13739 Mdot
.518 .13807 Mdot
.518 .13831 Mdot
.518 .13928 Mdot
.518 .14023 Mdot
.518 .14029 Mdot
.518 .14039 Mdot
.518 .1408 Mdot
.518 .14121 Mdot
.518 .14181 Mdot
.518 .14251 Mdot
.518 .14275 Mdot
.518 .14376 Mdot
.518 .14474 Mdot
.518 .14481 Mdot
.518 .14491 Mdot
.518 .14534 Mdot
.518 .14576 Mdot
.518 .14638 Mdot
.518 .14711 Mdot
.518 .14736 Mdot
.518 .14841 Mdot
.518 .14942 Mdot
.518 .1495 Mdot
.518 .1496 Mdot
.518 .15004 Mdot
.518 .15048 Mdot
.518 .15112 Mdot
.518 .15188 Mdot
.518 .15214 Mdot
.518 .15322 Mdot
.518 .15427 Mdot
.518 .15435 Mdot
.518 .15446 Mdot
.518 .15491 Mdot
.518 .15537 Mdot
.518 .15604 Mdot
.518 .15681 Mdot
.518 .15709 Mdot
.518 .15821 Mdot
.518 .1593 Mdot
.518 .15938 Mdot
.518 .15949 Mdot
.518 .15996 Mdot
.518 .16043 Mdot
.518 .16112 Mdot
.518 .16193 Mdot
.518 .16221 Mdot
.518 .16338 Mdot
.518 .1645 Mdot
.518 .16459 Mdot
.518 .1647 Mdot
.518 .16519 Mdot
.518 .16568 Mdot
.518 .16639 Mdot
.518 .16723 Mdot
.518 .16752 Mdot
.518 .16873 Mdot
.518 .1699 Mdot
.518 .16998 Mdot
.518 .1701 Mdot
.518 .17061 Mdot
.518 .17111 Mdot
.518 .17185 Mdot
.518 .17272 Mdot
.518 .17302 Mdot
.518 .17427 Mdot
.518 .17548 Mdot
.518 .17557 Mdot
.518 .17569 Mdot
.518 .17622 Mdot
.518 .17674 Mdot
.518 .17751 Mdot
.518 .17841 Mdot
.518 .17872 Mdot
.518 .18002 Mdot
.518 .18127 Mdot
.518 .18136 Mdot
.518 .18149 Mdot
.518 .18203 Mdot
.518 .18257 Mdot
.518 .18337 Mdot
.518 .1843 Mdot
.518 .18463 Mdot
.518 .18597 Mdot
.518 .18727 Mdot
.518 .18736 Mdot
.518 .18749 Mdot
.518 .18805 Mdot
.518 .18862 Mdot
.518 .18944 Mdot
.518 .19041 Mdot
.518 .19074 Mdot
.518 .19213 Mdot
.518 .19348 Mdot
.518 .19358 Mdot
.518 .19371 Mdot
.518 .19429 Mdot
.518 .19488 Mdot
.518 .19573 Mdot
.518 .19673 Mdot
.518 .19708 Mdot
.518 .19852 Mdot
.518 .19991 Mdot
.518 .20001 Mdot
.518 .20016 Mdot
.518 .20076 Mdot
.518 .20136 Mdot
.518 .20225 Mdot
.518 .20328 Mdot
.518 .20365 Mdot
.518 .20514 Mdot
.518 .20658 Mdot
.518 .20669 Mdot
.518 .20683 Mdot
.518 .20746 Mdot
.518 .20808 Mdot
.518 .209 Mdot
.518 .21007 Mdot
.518 .21045 Mdot
.518 .21199 Mdot
.518 .21349 Mdot
.518 .2136 Mdot
.518 .21375 Mdot
.518 .2144 Mdot
.518 .21504 Mdot
.518 .216 Mdot
.518 .2171 Mdot
.518 .21749 Mdot
.518 .21909 Mdot
.518 .22064 Mdot
.518 .22076 Mdot
.518 .22091 Mdot
.518 .22158 Mdot
.518 .22225 Mdot
.518 .22324 Mdot
.518 .22439 Mdot
.518 .22479 Mdot
.518 .22645 Mdot
.518 .22806 Mdot
.518 .22817 Mdot
.518 .22834 Mdot
.518 .22903 Mdot
.518 .22973 Mdot
.518 .23075 Mdot
.518 .23194 Mdot
.518 .23236 Mdot
.518 .23407 Mdot
.518 .23574 Mdot
.518 .23586 Mdot
.518 .23603 Mdot
.518 .23675 Mdot
.518 .23747 Mdot
.518 .23853 Mdot
.518 .23976 Mdot
.518 .24019 Mdot
.518 .24197 Mdot
.518 .24369 Mdot
.518 .24382 Mdot
.518 .24399 Mdot
.518 .24474 Mdot
.518 .24549 Mdot
.518 .24658 Mdot
.518 .24786 Mdot
.518 .24831 Mdot
.518 .25015 Mdot
.518 .25194 Mdot
.518 .25207 Mdot
.518 .25225 Mdot
.518 .25302 Mdot
.518 .25379 Mdot
.518 .25493 Mdot
.518 .25625 Mdot
.518 .25672 Mdot
.518 .25863 Mdot
.518 .26048 Mdot
.518 .26061 Mdot
.518 .2608 Mdot
.518 .2616 Mdot
.518 .2624 Mdot
.518 .26358 Mdot
.518 .26495 Mdot
.518 .26543 Mdot
.518 .26741 Mdot
.518 .26932 Mdot
.518 .26946 Mdot
.518 .26966 Mdot
.518 .27049 Mdot
.518 .27132 Mdot
.518 .27254 Mdot
.518 .27396 Mdot
.518 .27446 Mdot
.518 .2765 Mdot
.518 .27849 Mdot
.518 .27863 Mdot
.518 .27884 Mdot
.518 .2797 Mdot
.518 .28055 Mdot
.518 .28182 Mdot
.518 .28329 Mdot
.518 .28381 Mdot
.518 .28593 Mdot
.518 .28799 Mdot
.518 .28814 Mdot
.518 .28834 Mdot
.518 .28924 Mdot
.518 .29012 Mdot
.518 .29143 Mdot
.518 .29296 Mdot
.518 .29349 Mdot
.518 .29569 Mdot
.518 .29782 Mdot
.518 .29798 Mdot
.518 .29819 Mdot
.518 .29912 Mdot
.518 .30004 Mdot
.518 .3014 Mdot
.518 .30298 Mdot
.518 .30353 Mdot
.518 .30581 Mdot
.518 .30802 Mdot
.518 .30818 Mdot
.518 .3084 Mdot
.518 .30936 Mdot
.518 .31031 Mdot
.518 .31172 Mdot
.518 .31335 Mdot
.518 .31393 Mdot
.518 .31629 Mdot
.518 .31858 Mdot
.518 .31874 Mdot
.518 .31897 Mdot
.518 .31996 Mdot
.518 .32095 Mdot
.52 .01492 Mdot
.52 .01493 Mdot
.52 .01494 Mdot
.52 .01495 Mdot
.52 .01496 Mdot
.52 .01497 Mdot
.52 .01498 Mdot
.52 .01499 Mdot
.52 .015 Mdot
.52 .01501 Mdot
.52 .01502 Mdot
.52 .01504 Mdot
.52 .01505 Mdot
.52 .01506 Mdot
.52 .01508 Mdot
.52 .01509 Mdot
.52 .01511 Mdot
.52 .01512 Mdot
.52 .01514 Mdot
.52 .01515 Mdot
.52 .01517 Mdot
.52 .01519 Mdot
.52 .01521 Mdot
.52 .01523 Mdot
.52 .01525 Mdot
.52 .01527 Mdot
.52 .01529 Mdot
.52 .01532 Mdot
.52 .01534 Mdot
.52 .01536 Mdot
.52 .01539 Mdot
.52 .01542 Mdot
.52 .01545 Mdot
.52 .01548 Mdot
.52 .01551 Mdot
.52 .01554 Mdot
.52 .01557 Mdot
.52 .0156 Mdot
.52 .01564 Mdot
.52 .01568 Mdot
.52 .01572 Mdot
.52 .01576 Mdot
.52 .0158 Mdot
.52 .01584 Mdot
.52 .01589 Mdot
.52 .01593 Mdot
.52 .01598 Mdot
.52 .01603 Mdot
.52 .01608 Mdot
.52 .01614 Mdot
.52 .0162 Mdot
.52 .01625 Mdot
.52 .01632 Mdot
.52 .01638 Mdot
.52 .01645 Mdot
.52 .01652 Mdot
.52 .01659 Mdot
.52 .01666 Mdot
.52 .01674 Mdot
.52 .01682 Mdot
.52 .01691 Mdot
.52 .01699 Mdot
.52 .01709 Mdot
.52 .01718 Mdot
.52 .01728 Mdot
.52 .01738 Mdot
.52 .01749 Mdot
.52 .0176 Mdot
.52 .0177 Mdot
.52 .01771 Mdot
.52 .01782 Mdot
.52 .01783 Mdot
.52 .01791 Mdot
.52 .01795 Mdot
.52 .01796 Mdot
.52 .01804 Mdot
.52 .01808 Mdot
.52 .01809 Mdot
.52 .01817 Mdot
.52 .01821 Mdot
.52 .01822 Mdot
.52 .01831 Mdot
.52 .01835 Mdot
.52 .01836 Mdot
.52 .01845 Mdot
.52 .0185 Mdot
.52 .01851 Mdot
.52 .0186 Mdot
.52 .01865 Mdot
.52 .01866 Mdot
.52 .01876 Mdot
.52 .01881 Mdot
.52 .01882 Mdot
.52 .01892 Mdot
.52 .01897 Mdot
.52 .01898 Mdot
.52 .01909 Mdot
.52 .01914 Mdot
.52 .01915 Mdot
.52 .01926 Mdot
.52 .01932 Mdot
.52 .01933 Mdot
.52 .01945 Mdot
.52 .0195 Mdot
.52 .01952 Mdot
.52 .01963 Mdot
.52 .01969 Mdot
.52 .01971 Mdot
.52 .01983 Mdot
.52 .01989 Mdot
.52 .01991 Mdot
.52 .02004 Mdot
.52 .0201 Mdot
.52 .02012 Mdot
.52 .02025 Mdot
.52 .02031 Mdot
.52 .02033 Mdot
.52 .02047 Mdot
.52 .02054 Mdot
.52 .02056 Mdot
.52 .0207 Mdot
.52 .02077 Mdot
.52 .02079 Mdot
.52 .02094 Mdot
.52 .02099 Mdot
.52 .02101 Mdot
.52 .02103 Mdot
.52 .02119 Mdot
.52 .02124 Mdot
.52 .02126 Mdot
.52 .02129 Mdot
.52 .02145 Mdot
.52 .02151 Mdot
.52 .02153 Mdot
.52 .02155 Mdot
.52 .02157 Mdot
.52 .02163 Mdot
.52 .02172 Mdot
.52 .02178 Mdot
.52 .0218 Mdot
.52 .02182 Mdot
.52 .02184 Mdot
.52 .02191 Mdot
.52 .022 Mdot
.52 .02206 Mdot
.52 .02208 Mdot
.52 .02211 Mdot
.52 .02213 Mdot
.52 .02219 Mdot
.52 .02229 Mdot
.52 .02235 Mdot
.52 .02238 Mdot
.52 .0224 Mdot
.52 .02242 Mdot
.52 .02249 Mdot
.52 .02259 Mdot
.52 .02266 Mdot
.52 .02268 Mdot
.52 .02271 Mdot
.52 .02273 Mdot
.52 .02281 Mdot
.52 .02291 Mdot
.52 .02298 Mdot
.52 .023 Mdot
.52 .02303 Mdot
.52 .02305 Mdot
.52 .02313 Mdot
.52 .02323 Mdot
.52 .02331 Mdot
.52 .02333 Mdot
.52 .02336 Mdot
.52 .02339 Mdot
.52 .02347 Mdot
.52 .02357 Mdot
.52 .02365 Mdot
.52 .02368 Mdot
.52 .02371 Mdot
.52 .02373 Mdot
.52 .02382 Mdot
.52 .02393 Mdot
.52 .02401 Mdot
.52 .02404 Mdot
.52 .02407 Mdot
.52 .02409 Mdot
.52 .02418 Mdot
.52 .0243 Mdot
.52 .0243 Mdot
.52 .02438 Mdot
.52 .02441 Mdot
.52 .02444 Mdot
.52 .02447 Mdot
.52 .02456 Mdot
.52 .02468 Mdot
.52 .02468 Mdot
.52 .02477 Mdot
.52 .0248 Mdot
.52 .02483 Mdot
.52 .02486 Mdot
.52 .02495 Mdot
.52 .02508 Mdot
.52 .02508 Mdot
.52 .02517 Mdot
.52 .0252 Mdot
.52 .02524 Mdot
.52 .02527 Mdot
.52 .02527 Mdot
.52 .02536 Mdot
.52 .02549 Mdot
.52 .0255 Mdot
.52 .02559 Mdot
.52 .02562 Mdot
.52 .02566 Mdot
.52 .02569 Mdot
.52 .02569 Mdot
.52 .02579 Mdot
.52 .02592 Mdot
.52 .02593 Mdot
.52 .02602 Mdot
.52 .02606 Mdot
.52 .0261 Mdot
.52 .02613 Mdot
.52 .02613 Mdot
.52 .02623 Mdot
.52 .02635 Mdot
.52 .02637 Mdot
.52 .02638 Mdot
.52 .02647 Mdot
.52 .02651 Mdot
.52 .02655 Mdot
.52 .02658 Mdot
.52 .02658 Mdot
.52 .02669 Mdot
.52 .02682 Mdot
.52 .02684 Mdot
.52 .02684 Mdot
.52 .02694 Mdot
.52 .02698 Mdot
.52 .02702 Mdot
.52 .02706 Mdot
.52 .02706 Mdot
.52 .02717 Mdot
.52 .0273 Mdot
.52 .02732 Mdot
.52 .02733 Mdot
.52 .02743 Mdot
.52 .02747 Mdot
.52 .02752 Mdot
.52 .02755 Mdot
.52 .02755 Mdot
.52 .02767 Mdot
.52 .0278 Mdot
.52 .02783 Mdot
.52 .02783 Mdot
.52 .02794 Mdot
.52 .02798 Mdot
.52 .02803 Mdot
.52 .02806 Mdot
.52 .02807 Mdot
.52 .02819 Mdot
.52 .02833 Mdot
.52 .02835 Mdot
.52 .02836 Mdot
.52 .02847 Mdot
.52 .02851 Mdot
.52 .02856 Mdot
.52 .0286 Mdot
.52 .0286 Mdot
.52 .02872 Mdot
.52 .02887 Mdot
.52 .0289 Mdot
.52 .0289 Mdot
.52 .02902 Mdot
.52 .02907 Mdot
.52 .02911 Mdot
.52 .02915 Mdot
.52 .02915 Mdot
.52 .02929 Mdot
.52 .02944 Mdot
.52 .02947 Mdot
.52 .02947 Mdot
.52 .02959 Mdot
.52 .02964 Mdot
.52 .02969 Mdot
.52 .02973 Mdot
.52 .02973 Mdot
.52 .02987 Mdot
.52 .03003 Mdot
.52 .03006 Mdot
.52 .03006 Mdot
.52 .03019 Mdot
.52 .03024 Mdot
.52 .03029 Mdot
.52 .03033 Mdot
.52 .03033 Mdot
.52 .03047 Mdot
.52 .03064 Mdot
.52 .03067 Mdot
.52 .03067 Mdot
.52 .03081 Mdot
.52 .03086 Mdot
.52 .03091 Mdot
.52 .03096 Mdot
.52 .03096 Mdot
.52 .0311 Mdot
.52 .03128 Mdot
.52 .03131 Mdot
.52 .03131 Mdot
.52 .03145 Mdot
.52 .0315 Mdot
.52 .03156 Mdot
.52 .03161 Mdot
.52 .03161 Mdot
.52 .03176 Mdot
.52 .03194 Mdot
.52 .03197 Mdot
.52 .03198 Mdot
.52 .03212 Mdot
.52 .03217 Mdot
.52 .03223 Mdot
.52 .03228 Mdot
.52 .03228 Mdot
.52 .03244 Mdot
.52 .03263 Mdot
.52 .03266 Mdot
.52 .03267 Mdot
.52 .03282 Mdot
.52 .03287 Mdot
.52 .03294 Mdot
.52 .03298 Mdot
.52 .03299 Mdot
.52 .03315 Mdot
.52 .03335 Mdot
.52 .03338 Mdot
.52 .03338 Mdot
.52 .03354 Mdot
.52 .0336 Mdot
.52 .03366 Mdot
.52 .03372 Mdot
.52 .03372 Mdot
.52 .03389 Mdot
.52 .03409 Mdot
.52 .03413 Mdot
.52 .03413 Mdot
.52 .0343 Mdot
.52 .03436 Mdot
.52 .03442 Mdot
.52 .03448 Mdot
.52 .03448 Mdot
.52 .03466 Mdot
.52 .03487 Mdot
.52 .0349 Mdot
.52 .03491 Mdot
.52 .03508 Mdot
.52 .03514 Mdot
.52 .03521 Mdot
.52 .03527 Mdot
.52 .03527 Mdot
.52 .03545 Mdot
.52 .03567 Mdot
.52 .03571 Mdot
.52 .03571 Mdot
.52 .03589 Mdot
.52 .03596 Mdot
.52 .03603 Mdot
.52 .03609 Mdot
.52 .03609 Mdot
.52 .03628 Mdot
.52 .03651 Mdot
.52 .03655 Mdot
.52 .03655 Mdot
.52 .03674 Mdot
.52 .03681 Mdot
.52 .03688 Mdot
.52 .03694 Mdot
.52 .03694 Mdot
.52 .03714 Mdot
.52 .03738 Mdot
.52 .03742 Mdot
.52 .03743 Mdot
.52 .03762 Mdot
.52 .03769 Mdot
.52 .03777 Mdot
.52 .03783 Mdot
.52 .03783 Mdot
.52 .03804 Mdot
.52 .03829 Mdot
.52 .03833 Mdot
.52 .03834 Mdot
.52 .03854 Mdot
.52 .03861 Mdot
.52 .03869 Mdot
.52 .03876 Mdot
.52 .03876 Mdot
.52 .03898 Mdot
.52 .03923 Mdot
.52 .03928 Mdot
.52 .03928 Mdot
.52 .03949 Mdot
.52 .03957 Mdot
.52 .03965 Mdot
.52 .03972 Mdot
.52 .03972 Mdot
.52 .03995 Mdot
.52 .04021 Mdot
.52 .04026 Mdot
.52 .04026 Mdot
.52 .04048 Mdot
.52 .04056 Mdot
.52 .04065 Mdot
.52 .04072 Mdot
.52 .04072 Mdot
.52 .04095 Mdot
.52 .04123 Mdot
.52 .04128 Mdot
.52 .04129 Mdot
.52 .04151 Mdot
.52 .04159 Mdot
.52 .04169 Mdot
.52 .04176 Mdot
.52 .04176 Mdot
.52 .042 Mdot
.52 .04229 Mdot
.52 .04234 Mdot
.52 .04235 Mdot
.52 .04258 Mdot
.52 .04267 Mdot
.52 .04276 Mdot
.52 .04284 Mdot
.52 .04284 Mdot
.52 .0431 Mdot
.52 .0434 Mdot
.52 .04345 Mdot
.52 .04345 Mdot
.52 .0437 Mdot
.52 .04379 Mdot
.52 .04389 Mdot
.52 .04396 Mdot
.52 .04397 Mdot
.52 .04423 Mdot
.52 .04454 Mdot
.52 .0446 Mdot
.52 .0446 Mdot
.52 .04486 Mdot
.52 .04495 Mdot
.52 .04505 Mdot
.52 .04513 Mdot
.52 .04514 Mdot
.52 .04541 Mdot
.52 .04574 Mdot
.52 .04579 Mdot
.52 .0458 Mdot
.52 .04606 Mdot
.52 .04616 Mdot
.52 .04627 Mdot
.52 .04635 Mdot
.52 .04635 Mdot
.52 .04664 Mdot
.52 .04698 Mdot
.52 .04704 Mdot
.52 .04704 Mdot
.52 .04732 Mdot
.52 .04742 Mdot
.52 .04753 Mdot
.52 .04762 Mdot
.52 .04762 Mdot
.52 .04792 Mdot
.52 .04827 Mdot
.52 .04833 Mdot
.52 .04834 Mdot
.52 .04862 Mdot
.52 .04873 Mdot
.52 .04884 Mdot
.52 .04893 Mdot
.52 .04894 Mdot
.52 .04924 Mdot
.52 .04961 Mdot
.52 .04967 Mdot
.52 .04968 Mdot
.52 .04998 Mdot
.52 .05009 Mdot
.52 .05021 Mdot
.52 .0503 Mdot
.52 .0503 Mdot
.52 .05063 Mdot
.52 .05101 Mdot
.52 .05107 Mdot
.52 .05108 Mdot
.52 .05139 Mdot
.52 .0515 Mdot
.52 .05163 Mdot
.52 .05173 Mdot
.52 .05173 Mdot
.52 .05206 Mdot
.52 .05246 Mdot
.52 .05253 Mdot
.52 .05253 Mdot
.52 .05286 Mdot
.52 .05297 Mdot
.52 .0531 Mdot
.52 .05321 Mdot
.52 .05321 Mdot
.52 .05356 Mdot
.52 .05397 Mdot
.52 .05404 Mdot
.52 .05405 Mdot
.52 .05438 Mdot
.52 .0545 Mdot
.52 .05464 Mdot
.52 .05475 Mdot
.52 .05475 Mdot
.52 .05511 Mdot
.52 .05554 Mdot
.52 .05561 Mdot
.52 .05562 Mdot
.52 .05597 Mdot
.52 .05609 Mdot
.52 .05623 Mdot
.52 .05635 Mdot
.52 .05635 Mdot
.52 .05673 Mdot
.52 .05717 Mdot
.52 .05725 Mdot
.52 .05726 Mdot
.52 .05762 Mdot
.52 .05775 Mdot
.52 .0579 Mdot
.52 .05801 Mdot
.52 .05801 Mdot
.52 .05841 Mdot
.52 .05887 Mdot
.52 .05895 Mdot
.52 .05896 Mdot
.52 .05933 Mdot
.52 .05947 Mdot
.52 .05962 Mdot
.52 .05974 Mdot
.52 .05975 Mdot
.52 .06015 Mdot
.52 .06018 Mdot
.52 .06063 Mdot
.52 .06072 Mdot
.52 .06073 Mdot
.52 .06112 Mdot
.52 .06126 Mdot
.52 .06142 Mdot
.52 .06154 Mdot
.52 .06155 Mdot
.52 .06197 Mdot
.52 .062 Mdot
.52 .06247 Mdot
.52 .06256 Mdot
.52 .06257 Mdot
.52 .06297 Mdot
.52 .06312 Mdot
.52 .06329 Mdot
.52 .06342 Mdot
.52 .06342 Mdot
.52 .06386 Mdot
.52 .06389 Mdot
.52 .06438 Mdot
.52 .06447 Mdot
.52 .06448 Mdot
.52 .06491 Mdot
.52 .06506 Mdot
.52 .06523 Mdot
.52 .06537 Mdot
.52 .06537 Mdot
.52 .06583 Mdot
.52 .06586 Mdot
.52 .06637 Mdot
.52 .06646 Mdot
.52 .06647 Mdot
.52 .06691 Mdot
.52 .06707 Mdot
.52 .06725 Mdot
.52 .06739 Mdot
.52 .0674 Mdot
.52 .06787 Mdot
.52 .06791 Mdot
.52 .06843 Mdot
.52 .06853 Mdot
.52 .06854 Mdot
.52 .069 Mdot
.52 .06917 Mdot
.52 .06935 Mdot
.52 .0695 Mdot
.52 .0695 Mdot
.52 .07 Mdot
.52 .07003 Mdot
.52 .07058 Mdot
.52 .07069 Mdot
.52 .0707 Mdot
.52 .07117 Mdot
.52 .07134 Mdot
.52 .07154 Mdot
.52 .07169 Mdot
.52 .07169 Mdot
.52 .07221 Mdot
.52 .07225 Mdot
.52 .07282 Mdot
.52 .07292 Mdot
.52 .07294 Mdot
.52 .07343 Mdot
.52 .07361 Mdot
.52 .07381 Mdot
.52 .07397 Mdot
.52 .07397 Mdot
.52 .07451 Mdot
.52 .07455 Mdot
.52 .07514 Mdot
.52 .07525 Mdot
.52 .07527 Mdot
.52 .07578 Mdot
.52 .07597 Mdot
.52 .07617 Mdot
.52 .07634 Mdot
.52 .07634 Mdot
.52 .0769 Mdot
.52 .07694 Mdot
.52 .07756 Mdot
.52 .07767 Mdot
.52 .07769 Mdot
.52 .07822 Mdot
.52 .07842 Mdot
.52 .07863 Mdot
.52 .07881 Mdot
.52 .07881 Mdot
.52 .07939 Mdot
.52 .07943 Mdot
.52 .08007 Mdot
.52 .08019 Mdot
.52 .08021 Mdot
.52 .08076 Mdot
.52 .08096 Mdot
.52 .08119 Mdot
.52 .08137 Mdot
.52 .08137 Mdot
.52 .08198 Mdot
.52 .08202 Mdot
.52 .08269 Mdot
.52 .08281 Mdot
.52 .08283 Mdot
.52 .0834 Mdot
.52 .08361 Mdot
.52 .08385 Mdot
.52 .08403 Mdot
.52 .08404 Mdot
.52 .08467 Mdot
.52 .08471 Mdot
.52 .08541 Mdot
.52 .08554 Mdot
.52 .08555 Mdot
.52 .08615 Mdot
.52 .08637 Mdot
.52 .08661 Mdot
.52 .08681 Mdot
.52 .08681 Mdot
.52 .08746 Mdot
.52 .08751 Mdot
.52 .08823 Mdot
.52 .08837 Mdot
.52 .08838 Mdot
.52 .08901 Mdot
.52 .08924 Mdot
.52 .08949 Mdot
.52 .08969 Mdot
.52 .0897 Mdot
.52 .09037 Mdot
.52 .09042 Mdot
.52 .09118 Mdot
.52 .09132 Mdot
.52 .09133 Mdot
.52 .09198 Mdot
.52 .09222 Mdot
.52 .09248 Mdot
.52 .09269 Mdot
.52 .0927 Mdot
.52 .0934 Mdot
.52 .09345 Mdot
.52 .09423 Mdot
.52 .09438 Mdot
.52 .09439 Mdot
.52 .09507 Mdot
.52 .09532 Mdot
.52 .09559 Mdot
.52 .09581 Mdot
.52 .09581 Mdot
.52 .09655 Mdot
.52 .0966 Mdot
.52 .09741 Mdot
.52 .09757 Mdot
.52 .09758 Mdot
.52 .09829 Mdot
.52 .09854 Mdot
.52 .09883 Mdot
.52 .09905 Mdot
.52 .09906 Mdot
.52 .09982 Mdot
.52 .09988 Mdot
.52 .10072 Mdot
.52 .10088 Mdot
.52 .1009 Mdot
.52 .10163 Mdot
.52 .10189 Mdot
.52 .10219 Mdot
.52 .10243 Mdot
.52 .10243 Mdot
.52 .10322 Mdot
.52 .10328 Mdot
.52 .10416 Mdot
.52 .10433 Mdot
.52 .10434 Mdot
.52 .1051 Mdot
.52 .10538 Mdot
.52 .10569 Mdot
.52 .10594 Mdot
.52 .10594 Mdot
.52 .10677 Mdot
.52 .10683 Mdot
.52 .10774 Mdot
.52 .10791 Mdot
.52 .10793 Mdot
.52 .10872 Mdot
.52 .10901 Mdot
.52 .10933 Mdot
.52 .10958 Mdot
.52 .10959 Mdot
.52 .11045 Mdot
.52 .11051 Mdot
.52 .11146 Mdot
.52 .11164 Mdot
.52 .11166 Mdot
.52 .11248 Mdot
.52 .11278 Mdot
.52 .11311 Mdot
.52 .11338 Mdot
.52 .11338 Mdot
.52 .11428 Mdot
.52 .11434 Mdot
.52 .11533 Mdot
.52 .11552 Mdot
.52 .11554 Mdot
.52 .11639 Mdot
.52 .1167 Mdot
.52 .11705 Mdot
.52 .11733 Mdot
.52 .11733 Mdot
.52 .11826 Mdot
.52 .11833 Mdot
.52 .11936 Mdot
.52 .11955 Mdot
.52 .11957 Mdot
.52 .12046 Mdot
.52 .12078 Mdot
.52 .12114 Mdot
.52 .12143 Mdot
.52 .12144 Mdot
.52 .1224 Mdot
.52 .12247 Mdot
.52 .12354 Mdot
.52 .12374 Mdot
.52 .12376 Mdot
.52 .12469 Mdot
.52 .12502 Mdot
.52 .1254 Mdot
.52 .1257 Mdot
.52 .12571 Mdot
.52 .12671 Mdot
.52 .12678 Mdot
.52 .12789 Mdot
.52 .1281 Mdot
.52 .12812 Mdot
.52 .12909 Mdot
.52 .12944 Mdot
.52 .12983 Mdot
.52 .13014 Mdot
.52 .13014 Mdot
.52 .13119 Mdot
.52 .13127 Mdot
.52 .13242 Mdot
.52 .13264 Mdot
.52 .13266 Mdot
.52 .13366 Mdot
.52 .13402 Mdot
.52 .13443 Mdot
.52 .13476 Mdot
.52 .13585 Mdot
.52 .13593 Mdot
.52 .13713 Mdot
.52 .13735 Mdot
.52 .13738 Mdot
.52 .13842 Mdot
.52 .1388 Mdot
.52 .13922 Mdot
.52 .13956 Mdot
.52 .14069 Mdot
.52 .14078 Mdot
.52 .14203 Mdot
.52 .14226 Mdot
.52 .14229 Mdot
.52 .14337 Mdot
.52 .14376 Mdot
.52 .1442 Mdot
.52 .14456 Mdot
.52 .14573 Mdot
.52 .14582 Mdot
.52 .14712 Mdot
.52 .14736 Mdot
.52 .14739 Mdot
.52 .14851 Mdot
.52 .14892 Mdot
.52 .14938 Mdot
.52 .14975 Mdot
.52 .15097 Mdot
.52 .15106 Mdot
.52 .15242 Mdot
.52 .15267 Mdot
.52 .15269 Mdot
.52 .15387 Mdot
.52 .15429 Mdot
.52 .15477 Mdot
.52 .15515 Mdot
.52 .15642 Mdot
.52 .15652 Mdot
.52 .15792 Mdot
.52 .15819 Mdot
.52 .15821 Mdot
.52 .15943 Mdot
.52 .15987 Mdot
.52 .16037 Mdot
.52 .16077 Mdot
.52 .16209 Mdot
.52 .16219 Mdot
.52 .16365 Mdot
.52 .16392 Mdot
.52 .16395 Mdot
.52 .16522 Mdot
.52 .16568 Mdot
.52 .16619 Mdot
.52 .16661 Mdot
.52 .16799 Mdot
.52 .16809 Mdot
.52 .16961 Mdot
.52 .16989 Mdot
.52 .16992 Mdot
.52 .17124 Mdot
.52 .17172 Mdot
.52 .17225 Mdot
.52 .17269 Mdot
.52 .17412 Mdot
.52 .17422 Mdot
.52 .1758 Mdot
.52 .1761 Mdot
.52 .17613 Mdot
.52 .1775 Mdot
.52 .178 Mdot
.52 .17856 Mdot
.52 .17901 Mdot
.52 .18049 Mdot
.52 .1806 Mdot
.52 .18225 Mdot
.52 .18256 Mdot
.52 .18259 Mdot
.52 .18401 Mdot
.52 .18453 Mdot
.52 .18511 Mdot
.52 .18558 Mdot
.52 .18712 Mdot
.52 .18724 Mdot
.52 .18895 Mdot
.52 .18927 Mdot
.52 .1893 Mdot
.52 .19079 Mdot
.52 .19132 Mdot
.52 .19193 Mdot
.52 .19241 Mdot
.52 .19402 Mdot
.52 .19414 Mdot
.52 .19592 Mdot
.52 .19625 Mdot
.52 .19629 Mdot
.52 .19783 Mdot
.52 .19839 Mdot
.52 .19901 Mdot
.52 .19952 Mdot
.52 .20119 Mdot
.52 .20132 Mdot
.52 .20317 Mdot
.52 .20351 Mdot
.52 .20355 Mdot
.52 .20515 Mdot
.52 .20573 Mdot
.52 .20639 Mdot
.52 .20691 Mdot
.52 .20865 Mdot
.52 .20878 Mdot
.52 .21071 Mdot
.52 .21106 Mdot
.52 .2111 Mdot
.52 .21277 Mdot
.52 .21337 Mdot
.52 .21405 Mdot
.52 .2146 Mdot
.52 .21641 Mdot
.52 .21654 Mdot
.52 .21854 Mdot
.52 .21892 Mdot
.52 .21896 Mdot
.52 .22069 Mdot
.52 .22132 Mdot
.52 .22203 Mdot
.52 .2226 Mdot
.52 .22448 Mdot
.52 .22462 Mdot
.52 .2267 Mdot
.52 .22709 Mdot
.52 .22713 Mdot
.52 .22893 Mdot
.52 .22958 Mdot
.52 .23032 Mdot
.52 .23091 Mdot
.52 .23287 Mdot
.52 .23301 Mdot
.52 .23518 Mdot
.52 .23558 Mdot
.52 .23563 Mdot
.52 .2375 Mdot
.52 .23818 Mdot
.52 .23894 Mdot
.52 .23956 Mdot
.52 .24159 Mdot
.52 .24174 Mdot
.52 .244 Mdot
.52 .24442 Mdot
.52 .24446 Mdot
.52 .24641 Mdot
.52 .24712 Mdot
.52 .24791 Mdot
.52 .24855 Mdot
.52 .25067 Mdot
.52 .25082 Mdot
.52 .25317 Mdot
.52 .2536 Mdot
.52 .25365 Mdot
.52 .25568 Mdot
.52 .25641 Mdot
.52 .25724 Mdot
.52 .25791 Mdot
.52 .26011 Mdot
.52 .26027 Mdot
.52 .26271 Mdot
.52 .26316 Mdot
.52 .26321 Mdot
.52 .26532 Mdot
.52 .26608 Mdot
.52 .26694 Mdot
.52 .26764 Mdot
.52 .26992 Mdot
.52 .27009 Mdot
.52 .27262 Mdot
.52 .2731 Mdot
.52 .27315 Mdot
.52 .27534 Mdot
.52 .27614 Mdot
.52 .27703 Mdot
.52 .27775 Mdot
.52 .28013 Mdot
.52 .28031 Mdot
.52 .28294 Mdot
.52 .28343 Mdot
.52 .28349 Mdot
.52 .28577 Mdot
.52 .28659 Mdot
.52 .28752 Mdot
.52 .28827 Mdot
.52 .29075 Mdot
.52 .29093 Mdot
.52 .29367 Mdot
.52 .29418 Mdot
.52 .29424 Mdot
.52 .29661 Mdot
.52 .29747 Mdot
.52 .29843 Mdot
.52 .29922 Mdot
.52 .30179 Mdot
.52 .30198 Mdot
.52 .30483 Mdot
.52 .30536 Mdot
.52 .30542 Mdot
.52 .30788 Mdot
.52 .30878 Mdot
.52 .30978 Mdot
.52 .3106 Mdot
.52 .31327 Mdot
.52 .31347 Mdot
.52 .31643 Mdot
.52 .31699 Mdot
.52 .31705 Mdot
.52 .31961 Mdot
.52 .32054 Mdot
.52 .32159 Mdot
.522 .01505 Mdot
.522 .01506 Mdot
.522 .01508 Mdot
.522 .01509 Mdot
.522 .01511 Mdot
.522 .01512 Mdot
.522 .01514 Mdot
.522 .01516 Mdot
.522 .01518 Mdot
.522 .0152 Mdot
.522 .01522 Mdot
.522 .01525 Mdot
.522 .01527 Mdot
.522 .01529 Mdot
.522 .01532 Mdot
.522 .01535 Mdot
.522 .01537 Mdot
.522 .0154 Mdot
.522 .01543 Mdot
.522 .01546 Mdot
.522 .0155 Mdot
.522 .01553 Mdot
.522 .01557 Mdot
.522 .0156 Mdot
.522 .01564 Mdot
.522 .01568 Mdot
.522 .01573 Mdot
.522 .01577 Mdot
.522 .01582 Mdot
.522 .01587 Mdot
.522 .01592 Mdot
.522 .01597 Mdot
.522 .01603 Mdot
.522 .01608 Mdot
.522 .01614 Mdot
.522 .01621 Mdot
.522 .01627 Mdot
.522 .01634 Mdot
.522 .01641 Mdot
.522 .01649 Mdot
.522 .01656 Mdot
.522 .01665 Mdot
.522 .0167 Mdot
.522 .01673 Mdot
.522 .01679 Mdot
.522 .01682 Mdot
.522 .01688 Mdot
.522 .01691 Mdot
.522 .01698 Mdot
.522 .01701 Mdot
.522 .01708 Mdot
.522 .01711 Mdot
.522 .01718 Mdot
.522 .01721 Mdot
.522 .01729 Mdot
.522 .01732 Mdot
.522 .0174 Mdot
.522 .01744 Mdot
.522 .01752 Mdot
.522 .01756 Mdot
.522 .01764 Mdot
.522 .01768 Mdot
.522 .01777 Mdot
.522 .01782 Mdot
.522 .01791 Mdot
.522 .01795 Mdot
.522 .01805 Mdot
.522 .01809 Mdot
.522 .01819 Mdot
.522 .01824 Mdot
.522 .01835 Mdot
.522 .0184 Mdot
.522 .0185 Mdot
.522 .01856 Mdot
.522 .01867 Mdot
.522 .01873 Mdot
.522 .01885 Mdot
.522 .01891 Mdot
.522 .01903 Mdot
.522 .01909 Mdot
.522 .01922 Mdot
.522 .01928 Mdot
.522 .01942 Mdot
.522 .01948 Mdot
.522 .01962 Mdot
.522 .01969 Mdot
.522 .01984 Mdot
.522 .01991 Mdot
.522 .02006 Mdot
.522 .02014 Mdot
.522 .0203 Mdot
.522 .02038 Mdot
.522 .02048 Mdot
.522 .02054 Mdot
.522 .02063 Mdot
.522 .02073 Mdot
.522 .0208 Mdot
.522 .02089 Mdot
.522 .021 Mdot
.522 .02107 Mdot
.522 .02116 Mdot
.522 .02127 Mdot
.522 .02135 Mdot
.522 .02144 Mdot
.522 .02156 Mdot
.522 .02164 Mdot
.522 .02174 Mdot
.522 .02186 Mdot
.522 .02195 Mdot
.522 .02205 Mdot
.522 .02218 Mdot
.522 .02218 Mdot
.522 .02226 Mdot
.522 .02226 Mdot
.522 .02237 Mdot
.522 .02251 Mdot
.522 .02251 Mdot
.522 .0226 Mdot
.522 .0226 Mdot
.522 .02271 Mdot
.522 .02285 Mdot
.522 .02285 Mdot
.522 .02294 Mdot
.522 .02294 Mdot
.522 .02306 Mdot
.522 .02321 Mdot
.522 .02321 Mdot
.522 .0233 Mdot
.522 .02331 Mdot
.522 .02331 Mdot
.522 .02343 Mdot
.522 .02358 Mdot
.522 .02358 Mdot
.522 .02368 Mdot
.522 .02368 Mdot
.522 .02369 Mdot
.522 .02381 Mdot
.522 .02397 Mdot
.522 .02397 Mdot
.522 .02408 Mdot
.522 .02408 Mdot
.522 .02408 Mdot
.522 .02421 Mdot
.522 .02438 Mdot
.522 .02438 Mdot
.522 .02449 Mdot
.522 .02449 Mdot
.522 .02449 Mdot
.522 .02463 Mdot
.522 .0248 Mdot
.522 .02481 Mdot
.522 .02492 Mdot
.522 .02492 Mdot
.522 .02492 Mdot
.522 .02507 Mdot
.522 .02525 Mdot
.522 .02525 Mdot
.522 .02537 Mdot
.522 .02537 Mdot
.522 .02537 Mdot
.522 .02552 Mdot
.522 .02571 Mdot
.522 .02571 Mdot
.522 .02575 Mdot
.522 .02584 Mdot
.522 .02584 Mdot
.522 .02584 Mdot
.522 .02589 Mdot
.522 .0259 Mdot
.522 .026 Mdot
.522 .0262 Mdot
.522 .0262 Mdot
.522 .02624 Mdot
.522 .02633 Mdot
.522 .02633 Mdot
.522 .02633 Mdot
.522 .02638 Mdot
.522 .0264 Mdot
.522 .02649 Mdot
.522 .0267 Mdot
.522 .0267 Mdot
.522 .02674 Mdot
.522 .02684 Mdot
.522 .02684 Mdot
.522 .02684 Mdot
.522 .0269 Mdot
.522 .02691 Mdot
.522 .02701 Mdot
.522 .02723 Mdot
.522 .02723 Mdot
.522 .02727 Mdot
.522 .02737 Mdot
.522 .02737 Mdot
.522 .02738 Mdot
.522 .02738 Mdot
.522 .02743 Mdot
.522 .02745 Mdot
.522 .02755 Mdot
.522 .02771 Mdot
.522 .02778 Mdot
.522 .02778 Mdot
.522 .02783 Mdot
.522 .02793 Mdot
.522 .02793 Mdot
.522 .02793 Mdot
.522 .02793 Mdot
.522 .02799 Mdot
.522 .02801 Mdot
.522 .02812 Mdot
.522 .02828 Mdot
.522 .02835 Mdot
.522 .02836 Mdot
.522 .0284 Mdot
.522 .02851 Mdot
.522 .02851 Mdot
.522 .02851 Mdot
.522 .02851 Mdot
.522 .02858 Mdot
.522 .02859 Mdot
.522 .02871 Mdot
.522 .02888 Mdot
.522 .02895 Mdot
.522 .02896 Mdot
.522 .029 Mdot
.522 .02911 Mdot
.522 .02912 Mdot
.522 .02912 Mdot
.522 .02912 Mdot
.522 .02919 Mdot
.522 .0292 Mdot
.522 .02932 Mdot
.522 .0295 Mdot
.522 .02958 Mdot
.522 .02958 Mdot
.522 .02963 Mdot
.522 .02975 Mdot
.522 .02975 Mdot
.522 .02975 Mdot
.522 .02976 Mdot
.522 .02982 Mdot
.522 .02984 Mdot
.522 .02997 Mdot
.522 .03015 Mdot
.522 .03023 Mdot
.522 .03024 Mdot
.522 .03029 Mdot
.522 .03041 Mdot
.522 .03041 Mdot
.522 .03042 Mdot
.522 .03042 Mdot
.522 .03049 Mdot
.522 .03051 Mdot
.522 .03064 Mdot
.522 .03083 Mdot
.522 .03092 Mdot
.522 .03092 Mdot
.522 .03097 Mdot
.522 .0311 Mdot
.522 .0311 Mdot
.522 .03111 Mdot
.522 .03111 Mdot
.522 .03118 Mdot
.522 .0312 Mdot
.522 .03134 Mdot
.522 .03154 Mdot
.522 .03163 Mdot
.522 .03163 Mdot
.522 .03169 Mdot
.522 .03182 Mdot
.522 .03182 Mdot
.522 .03183 Mdot
.522 .03183 Mdot
.522 .03191 Mdot
.522 .03193 Mdot
.522 .03207 Mdot
.522 .03228 Mdot
.522 .03237 Mdot
.522 .03238 Mdot
.522 .03244 Mdot
.522 .03257 Mdot
.522 .03258 Mdot
.522 .03258 Mdot
.522 .03258 Mdot
.522 .03266 Mdot
.522 .03268 Mdot
.522 .03283 Mdot
.522 .03305 Mdot
.522 .03315 Mdot
.522 .03316 Mdot
.522 .03322 Mdot
.522 .03336 Mdot
.522 .03337 Mdot
.522 .03337 Mdot
.522 .03345 Mdot
.522 .03347 Mdot
.522 .03363 Mdot
.522 .03386 Mdot
.522 .03396 Mdot
.522 .03397 Mdot
.522 .03403 Mdot
.522 .03418 Mdot
.522 .03419 Mdot
.522 .03419 Mdot
.522 .03428 Mdot
.522 .0343 Mdot
.522 .03446 Mdot
.522 .0347 Mdot
.522 .03481 Mdot
.522 .03481 Mdot
.522 .03488 Mdot
.522 .03504 Mdot
.522 .03505 Mdot
.522 .03505 Mdot
.522 .03514 Mdot
.522 .03516 Mdot
.522 .03533 Mdot
.522 .03558 Mdot
.522 .03569 Mdot
.522 .0357 Mdot
.522 .03577 Mdot
.522 .03593 Mdot
.522 .03594 Mdot
.522 .03594 Mdot
.522 .03604 Mdot
.522 .03606 Mdot
.522 .03624 Mdot
.522 .0365 Mdot
.522 .03662 Mdot
.522 .03662 Mdot
.522 .03669 Mdot
.522 .03686 Mdot
.522 .03687 Mdot
.522 .03687 Mdot
.522 .03698 Mdot
.522 .037 Mdot
.522 .03718 Mdot
.522 .03746 Mdot
.522 .03758 Mdot
.522 .03759 Mdot
.522 .03766 Mdot
.522 .03784 Mdot
.522 .03785 Mdot
.522 .03785 Mdot
.522 .03796 Mdot
.522 .03798 Mdot
.522 .03817 Mdot
.522 .03846 Mdot
.522 .03859 Mdot
.522 .03859 Mdot
.522 .03867 Mdot
.522 .03886 Mdot
.522 .03887 Mdot
.522 .03887 Mdot
.522 .03898 Mdot
.522 .039 Mdot
.522 .0392 Mdot
.522 .0395 Mdot
.522 .03964 Mdot
.522 .03964 Mdot
.522 .03973 Mdot
.522 .03992 Mdot
.522 .03993 Mdot
.522 .03993 Mdot
.522 .04005 Mdot
.522 .04007 Mdot
.522 .04028 Mdot
.522 .04059 Mdot
.522 .04073 Mdot
.522 .04074 Mdot
.522 .04083 Mdot
.522 .04103 Mdot
.522 .04104 Mdot
.522 .04104 Mdot
.522 .04116 Mdot
.522 .04119 Mdot
.522 .04141 Mdot
.522 .04173 Mdot
.522 .04188 Mdot
.522 .04189 Mdot
.522 .04197 Mdot
.522 .04218 Mdot
.522 .0422 Mdot
.522 .0422 Mdot
.522 .04232 Mdot
.522 .04235 Mdot
.522 .04243 Mdot
.522 .04258 Mdot
.522 .04292 Mdot
.522 .04307 Mdot
.522 .04308 Mdot
.522 .04317 Mdot
.522 .04339 Mdot
.522 .04341 Mdot
.522 .04341 Mdot
.522 .04354 Mdot
.522 .04357 Mdot
.522 .04365 Mdot
.522 .04381 Mdot
.522 .04416 Mdot
.522 .04432 Mdot
.522 .04433 Mdot
.522 .04443 Mdot
.522 .04466 Mdot
.522 .04467 Mdot
.522 .04467 Mdot
.522 .04481 Mdot
.522 .04484 Mdot
.522 .04493 Mdot
.522 .04509 Mdot
.522 .04546 Mdot
.522 .04562 Mdot
.522 .04563 Mdot
.522 .04573 Mdot
.522 .04597 Mdot
.522 .04599 Mdot
.522 .04599 Mdot
.522 .04613 Mdot
.522 .04616 Mdot
.522 .04626 Mdot
.522 .04642 Mdot
.522 .04681 Mdot
.522 .04698 Mdot
.522 .04699 Mdot
.522 .0471 Mdot
.522 .04735 Mdot
.522 .04736 Mdot
.522 .04736 Mdot
.522 .04751 Mdot
.522 .04755 Mdot
.522 .04764 Mdot
.522 .04782 Mdot
.522 .04822 Mdot
.522 .0484 Mdot
.522 .04841 Mdot
.522 .04852 Mdot
.522 .04878 Mdot
.522 .0488 Mdot
.522 .0488 Mdot
.522 .04896 Mdot
.522 .04899 Mdot
.522 .04909 Mdot
.522 .04928 Mdot
.522 .0497 Mdot
.522 .04989 Mdot
.522 .04989 Mdot
.522 .05001 Mdot
.522 .05028 Mdot
.522 .0503 Mdot
.522 .0503 Mdot
.522 .05046 Mdot
.522 .0505 Mdot
.522 .0506 Mdot
.522 .0508 Mdot
.522 .05124 Mdot
.522 .05143 Mdot
.522 .05144 Mdot
.522 .05156 Mdot
.522 .05185 Mdot
.522 .05186 Mdot
.522 .05187 Mdot
.522 .05204 Mdot
.522 .05207 Mdot
.522 .05218 Mdot
.522 .05238 Mdot
.522 .05284 Mdot
.522 .05305 Mdot
.522 .05306 Mdot
.522 .05319 Mdot
.522 .05348 Mdot
.522 .0535 Mdot
.522 .0535 Mdot
.522 .05368 Mdot
.522 .05372 Mdot
.522 .05383 Mdot
.522 .05404 Mdot
.522 .05452 Mdot
.522 .05474 Mdot
.522 .05475 Mdot
.522 .05488 Mdot
.522 .05519 Mdot
.522 .05521 Mdot
.522 .05521 Mdot
.522 .05539 Mdot
.522 .05543 Mdot
.522 .05555 Mdot
.522 .05577 Mdot
.522 .05627 Mdot
.522 .0565 Mdot
.522 .05651 Mdot
.522 .05665 Mdot
.522 .05697 Mdot
.522 .05699 Mdot
.522 .05699 Mdot
.522 .05718 Mdot
.522 .05723 Mdot
.522 .05735 Mdot
.522 .05758 Mdot
.522 .0581 Mdot
.522 .05833 Mdot
.522 .05835 Mdot
.522 .05849 Mdot
.522 .05883 Mdot
.522 .05885 Mdot
.522 .05885 Mdot
.522 .05905 Mdot
.522 .0591 Mdot
.522 .05923 Mdot
.522 .05946 Mdot
.522 .06001 Mdot
.522 .06025 Mdot
.522 .06027 Mdot
.522 .06042 Mdot
.522 .06077 Mdot
.522 .06079 Mdot
.522 .06079 Mdot
.522 .061 Mdot
.522 .06105 Mdot
.522 .06118 Mdot
.522 .06143 Mdot
.522 .062 Mdot
.522 .06226 Mdot
.522 .06227 Mdot
.522 .06243 Mdot
.522 .06279 Mdot
.522 .06282 Mdot
.522 .06282 Mdot
.522 .06304 Mdot
.522 .06309 Mdot
.522 .06323 Mdot
.522 .06349 Mdot
.522 .06408 Mdot
.522 .06435 Mdot
.522 .06436 Mdot
.522 .06453 Mdot
.522 .06491 Mdot
.522 .06493 Mdot
.522 .06493 Mdot
.522 .06516 Mdot
.522 .06522 Mdot
.522 .06536 Mdot
.522 .06564 Mdot
.522 .06625 Mdot
.522 .06653 Mdot
.522 .06655 Mdot
.522 .06672 Mdot
.522 .06712 Mdot
.522 .06714 Mdot
.522 .06714 Mdot
.522 .06738 Mdot
.522 .06744 Mdot
.522 .06759 Mdot
.522 .06788 Mdot
.522 .06852 Mdot
.522 .06881 Mdot
.522 .06883 Mdot
.522 .06901 Mdot
.522 .06942 Mdot
.522 .06945 Mdot
.522 .06945 Mdot
.522 .0697 Mdot
.522 .06976 Mdot
.522 .06992 Mdot
.522 .07021 Mdot
.522 .07089 Mdot
.522 .07119 Mdot
.522 .07121 Mdot
.522 .07139 Mdot
.522 .07183 Mdot
.522 .07186 Mdot
.522 .07186 Mdot
.522 .07212 Mdot
.522 .07218 Mdot
.522 .07235 Mdot
.522 .07266 Mdot
.522 .07336 Mdot
.522 .07368 Mdot
.522 .07369 Mdot
.522 .07389 Mdot
.522 .07434 Mdot
.522 .07437 Mdot
.522 .07437 Mdot
.522 .07465 Mdot
.522 .07471 Mdot
.522 .07488 Mdot
.522 .07521 Mdot
.522 .07594 Mdot
.522 .07627 Mdot
.522 .07629 Mdot
.522 .07649 Mdot
.522 .07697 Mdot
.522 .077 Mdot
.522 .077 Mdot
.522 .07728 Mdot
.522 .07735 Mdot
.522 .07753 Mdot
.522 .07787 Mdot
.522 .07864 Mdot
.522 .07898 Mdot
.522 .079 Mdot
.522 .07921 Mdot
.522 .07971 Mdot
.522 .07974 Mdot
.522 .07974 Mdot
.522 .08004 Mdot
.522 .08011 Mdot
.522 .08029 Mdot
.522 .08065 Mdot
.522 .08145 Mdot
.522 .08181 Mdot
.522 .08183 Mdot
.522 .08205 Mdot
.522 .08257 Mdot
.522 .0826 Mdot
.522 .0826 Mdot
.522 .08291 Mdot
.522 .08298 Mdot
.522 .08318 Mdot
.522 .08355 Mdot
.522 .08438 Mdot
.522 .08476 Mdot
.522 .08478 Mdot
.522 .08501 Mdot
.522 .08555 Mdot
.522 .08558 Mdot
.522 .08559 Mdot
.522 .08591 Mdot
.522 .08599 Mdot
.522 .08619 Mdot
.522 .08658 Mdot
.522 .08745 Mdot
.522 .08784 Mdot
.522 .08786 Mdot
.522 .0881 Mdot
.522 .08867 Mdot
.522 .0887 Mdot
.522 .0887 Mdot
.522 .08904 Mdot
.522 .08912 Mdot
.522 .08934 Mdot
.522 .08974 Mdot
.522 .09065 Mdot
.522 .09106 Mdot
.522 .09108 Mdot
.522 .09133 Mdot
.522 .09192 Mdot
.522 .09196 Mdot
.522 .09196 Mdot
.522 .09232 Mdot
.522 .0924 Mdot
.522 .09262 Mdot
.522 .09304 Mdot
.522 .09399 Mdot
.522 .09442 Mdot
.522 .09444 Mdot
.522 .0947 Mdot
.522 .09532 Mdot
.522 .09536 Mdot
.522 .09536 Mdot
.522 .09573 Mdot
.522 .09581 Mdot
.522 .09605 Mdot
.522 .09649 Mdot
.522 .09748 Mdot
.522 .09793 Mdot
.522 .09795 Mdot
.522 .09822 Mdot
.522 .09887 Mdot
.522 .0989 Mdot
.522 .09891 Mdot
.522 .09929 Mdot
.522 .09938 Mdot
.522 .09963 Mdot
.522 .10008 Mdot
.522 .10112 Mdot
.522 .10159 Mdot
.522 .10161 Mdot
.522 .1019 Mdot
.522 .10257 Mdot
.522 .10261 Mdot
.522 .10261 Mdot
.522 .10302 Mdot
.522 .10311 Mdot
.522 .10336 Mdot
.522 .10384 Mdot
.522 .10492 Mdot
.522 .10541 Mdot
.522 .10544 Mdot
.522 .10573 Mdot
.522 .10644 Mdot
.522 .10648 Mdot
.522 .10648 Mdot
.522 .1069 Mdot
.522 .107 Mdot
.522 .10726 Mdot
.522 .10776 Mdot
.522 .10889 Mdot
.522 .1094 Mdot
.522 .10943 Mdot
.522 .10974 Mdot
.522 .11047 Mdot
.522 .11051 Mdot
.522 .11052 Mdot
.522 .11096 Mdot
.522 .11106 Mdot
.522 .11134 Mdot
.522 .11185 Mdot
.522 .11304 Mdot
.522 .11357 Mdot
.522 .11359 Mdot
.522 .11392 Mdot
.522 .11468 Mdot
.522 .11473 Mdot
.522 .11473 Mdot
.522 .11519 Mdot
.522 .1153 Mdot
.522 .11559 Mdot
.522 .11613 Mdot
.522 .11736 Mdot
.522 .11792 Mdot
.522 .11794 Mdot
.522 .11829 Mdot
.522 .11908 Mdot
.522 .11913 Mdot
.522 .11913 Mdot
.522 .11961 Mdot
.522 .11972 Mdot
.522 .12003 Mdot
.522 .12059 Mdot
.522 .12188 Mdot
.522 .12246 Mdot
.522 .12249 Mdot
.522 .12284 Mdot
.522 .12368 Mdot
.522 .12372 Mdot
.522 .12373 Mdot
.522 .12423 Mdot
.522 .12434 Mdot
.522 .12466 Mdot
.522 .12525 Mdot
.522 .12659 Mdot
.522 .1272 Mdot
.522 .12723 Mdot
.522 .1276 Mdot
.522 .12847 Mdot
.522 .12852 Mdot
.522 .12852 Mdot
.522 .12905 Mdot
.522 .12917 Mdot
.522 .1295 Mdot
.522 .13011 Mdot
.522 .13152 Mdot
.522 .13215 Mdot
.522 .13218 Mdot
.522 .13257 Mdot
.522 .13347 Mdot
.522 .13353 Mdot
.522 .13353 Mdot
.522 .13408 Mdot
.522 .1342 Mdot
.522 .13455 Mdot
.522 .13519 Mdot
.522 .13666 Mdot
.522 .13732 Mdot
.522 .13735 Mdot
.522 .13775 Mdot
.522 .1387 Mdot
.522 .13875 Mdot
.522 .13876 Mdot
.522 .13933 Mdot
.522 .13946 Mdot
.522 .13982 Mdot
.522 .14049 Mdot
.522 .14202 Mdot
.522 .14271 Mdot
.522 .14274 Mdot
.522 .14317 Mdot
.522 .14416 Mdot
.522 .14421 Mdot
.522 .14422 Mdot
.522 .14481 Mdot
.522 .14495 Mdot
.522 .14533 Mdot
.522 .14603 Mdot
.522 .14762 Mdot
.522 .14834 Mdot
.522 .14838 Mdot
.522 .14882 Mdot
.522 .14985 Mdot
.522 .14991 Mdot
.522 .14992 Mdot
.522 .15054 Mdot
.522 .15068 Mdot
.522 .15107 Mdot
.522 .1518 Mdot
.522 .15347 Mdot
.522 .15422 Mdot
.522 .15426 Mdot
.522 .15472 Mdot
.522 .1558 Mdot
.522 .15586 Mdot
.522 .15586 Mdot
.522 .15651 Mdot
.522 .15666 Mdot
.522 .15707 Mdot
.522 .15784 Mdot
.522 .15958 Mdot
.522 .16036 Mdot
.522 .1604 Mdot
.522 .16088 Mdot
.522 .162 Mdot
.522 .16207 Mdot
.522 .16207 Mdot
.522 .16275 Mdot
.522 .16291 Mdot
.522 .16334 Mdot
.522 .16413 Mdot
.522 .16595 Mdot
.522 .16677 Mdot
.522 .16681 Mdot
.522 .16731 Mdot
.522 .16848 Mdot
.522 .16855 Mdot
.522 .16856 Mdot
.522 .16927 Mdot
.522 .16943 Mdot
.522 .16988 Mdot
.522 .17071 Mdot
.522 .1726 Mdot
.522 .17346 Mdot
.522 .1735 Mdot
.522 .17402 Mdot
.522 .17525 Mdot
.522 .17532 Mdot
.522 .17533 Mdot
.522 .17607 Mdot
.522 .17623 Mdot
.522 .1767 Mdot
.522 .17757 Mdot
.522 .17955 Mdot
.522 .18044 Mdot
.522 .18049 Mdot
.522 .18103 Mdot
.522 .18231 Mdot
.522 .18239 Mdot
.522 .18239 Mdot
.522 .18317 Mdot
.522 .18334 Mdot
.522 .18383 Mdot
.522 .18474 Mdot
.522 .1868 Mdot
.522 .18773 Mdot
.522 .18778 Mdot
.522 .18835 Mdot
.522 .18969 Mdot
.522 .18977 Mdot
.522 .18977 Mdot
.522 .19058 Mdot
.522 .19076 Mdot
.522 .19127 Mdot
.522 .19222 Mdot
.522 .19438 Mdot
.522 .19535 Mdot
.522 .1954 Mdot
.522 .19599 Mdot
.522 .19739 Mdot
.522 .19747 Mdot
.522 .19747 Mdot
.522 .19832 Mdot
.522 .19851 Mdot
.522 .19904 Mdot
.522 .20003 Mdot
.522 .20228 Mdot
.522 .2033 Mdot
.522 .20335 Mdot
.522 .20397 Mdot
.522 .20543 Mdot
.522 .20551 Mdot
.522 .20552 Mdot
.522 .20639 Mdot
.522 .20659 Mdot
.522 .20715 Mdot
.522 .20818 Mdot
.522 .21053 Mdot
.522 .21159 Mdot
.522 .21164 Mdot
.522 .21229 Mdot
.522 .21382 Mdot
.522 .2139 Mdot
.522 .21391 Mdot
.522 .21483 Mdot
.522 .21504 Mdot
.522 .21562 Mdot
.522 .21669 Mdot
.522 .21915 Mdot
.522 .22026 Mdot
.522 .22031 Mdot
.522 .22099 Mdot
.522 .22258 Mdot
.522 .22267 Mdot
.522 .22268 Mdot
.522 .22363 Mdot
.522 .22385 Mdot
.522 .22446 Mdot
.522 .22558 Mdot
.522 .22814 Mdot
.522 .2293 Mdot
.522 .22936 Mdot
.522 .23006 Mdot
.522 .23172 Mdot
.522 .23182 Mdot
.522 .23183 Mdot
.522 .23283 Mdot
.522 .23305 Mdot
.522 .23369 Mdot
.522 .23486 Mdot
.522 .23754 Mdot
.522 .23874 Mdot
.522 .2388 Mdot
.522 .23954 Mdot
.522 .24127 Mdot
.522 .24137 Mdot
.522 .24138 Mdot
.522 .24242 Mdot
.522 .24266 Mdot
.522 .24332 Mdot
.522 .24454 Mdot
.522 .24734 Mdot
.522 .2486 Mdot
.522 .24866 Mdot
.522 .24943 Mdot
.522 .25124 Mdot
.522 .25134 Mdot
.522 .25135 Mdot
.522 .25244 Mdot
.522 .25269 Mdot
.522 .25338 Mdot
.522 .25466 Mdot
.522 .25758 Mdot
.522 .25889 Mdot
.522 .25895 Mdot
.522 .25976 Mdot
.522 .26165 Mdot
.522 .26176 Mdot
.522 .26176 Mdot
.522 .2629 Mdot
.522 .26316 Mdot
.522 .26388 Mdot
.522 .26521 Mdot
.522 .26826 Mdot
.522 .26963 Mdot
.522 .2697 Mdot
.522 .27054 Mdot
.522 .27251 Mdot
.522 .27263 Mdot
.522 .27263 Mdot
.522 .27382 Mdot
.522 .27409 Mdot
.522 .27484 Mdot
.522 .27624 Mdot
.522 .27942 Mdot
.522 .28085 Mdot
.522 .28092 Mdot
.522 .2818 Mdot
.522 .28385 Mdot
.522 .28397 Mdot
.522 .28398 Mdot
.522 .28522 Mdot
.522 .2855 Mdot
.522 .28629 Mdot
.522 .28774 Mdot
.522 .29106 Mdot
.522 .29256 Mdot
.522 .29263 Mdot
.522 .29355 Mdot
.522 .2957 Mdot
.522 .29582 Mdot
.522 .29583 Mdot
.522 .29712 Mdot
.522 .29742 Mdot
.522 .29824 Mdot
.522 .29976 Mdot
.522 .30322 Mdot
.522 .30478 Mdot
.522 .30486 Mdot
.522 .30582 Mdot
.522 .30806 Mdot
.522 .30819 Mdot
.522 .3082 Mdot
.522 .30955 Mdot
.522 .30986 Mdot
.522 .31071 Mdot
.522 .3123 Mdot
.522 .31592 Mdot
.522 .31755 Mdot
.522 .31763 Mdot
.522 .31863 Mdot
.522 .32097 Mdot
.522 .3211 Mdot
.522 .32111 Mdot
.522 .32252 Mdot
.522 .32284 Mdot
.524 .01477 Mdot
.524 .01477 Mdot
.524 .01477 Mdot
.524 .01477 Mdot
.524 .01478 Mdot
.524 .01478 Mdot
.524 .01478 Mdot
.524 .01479 Mdot
.524 .01479 Mdot
.524 .01479 Mdot
.524 .0148 Mdot
.524 .0148 Mdot
.524 .0148 Mdot
.524 .01481 Mdot
.524 .01481 Mdot
.524 .01482 Mdot
.524 .01482 Mdot
.524 .01483 Mdot
.524 .01483 Mdot
.524 .01484 Mdot
.524 .01484 Mdot
.524 .01485 Mdot
.524 .01486 Mdot
.524 .01486 Mdot
.524 .01487 Mdot
.524 .01488 Mdot
.524 .01489 Mdot
.524 .0149 Mdot
.524 .0149 Mdot
.524 .01491 Mdot
.524 .01492 Mdot
.524 .01493 Mdot
.524 .01494 Mdot
.524 .01495 Mdot
.524 .01496 Mdot
.524 .01498 Mdot
.524 .01499 Mdot
.524 .015 Mdot
.524 .01502 Mdot
.524 .01503 Mdot
.524 .01505 Mdot
.524 .01506 Mdot
.524 .01508 Mdot
.524 .0151 Mdot
.524 .01511 Mdot
.524 .01513 Mdot
.524 .01515 Mdot
.524 .01517 Mdot
.524 .0152 Mdot
.524 .01522 Mdot
.524 .01524 Mdot
.524 .01527 Mdot
.524 .01529 Mdot
.524 .0153 Mdot
.524 .01532 Mdot
.524 .01532 Mdot
.524 .01535 Mdot
.524 .01535 Mdot
.524 .01538 Mdot
.524 .01538 Mdot
.524 .01541 Mdot
.524 .01542 Mdot
.524 .01544 Mdot
.524 .01545 Mdot
.524 .01548 Mdot
.524 .01548 Mdot
.524 .01552 Mdot
.524 .01552 Mdot
.524 .01556 Mdot
.524 .01556 Mdot
.524 .0156 Mdot
.524 .0156 Mdot
.524 .01564 Mdot
.524 .01564 Mdot
.524 .01568 Mdot
.524 .01569 Mdot
.524 .01573 Mdot
.524 .01574 Mdot
.524 .01576 Mdot
.524 .01578 Mdot
.524 .01578 Mdot
.524 .01581 Mdot
.524 .01581 Mdot
.524 .01583 Mdot
.524 .01584 Mdot
.524 .01586 Mdot
.524 .01586 Mdot
.524 .01588 Mdot
.524 .01589 Mdot
.524 .01592 Mdot
.524 .01592 Mdot
.524 .01594 Mdot
.524 .01595 Mdot
.524 .01597 Mdot
.524 .01598 Mdot
.524 .016 Mdot
.524 .016 Mdot
.524 .01604 Mdot
.524 .01604 Mdot
.524 .01606 Mdot
.524 .01607 Mdot
.524 .0161 Mdot
.524 .0161 Mdot
.524 .01612 Mdot
.524 .01613 Mdot
.524 .01616 Mdot
.524 .01617 Mdot
.524 .01619 Mdot
.524 .0162 Mdot
.524 .01623 Mdot
.524 .01624 Mdot
.524 .01626 Mdot
.524 .01627 Mdot
.524 .01631 Mdot
.524 .01631 Mdot
.524 .01633 Mdot
.524 .01635 Mdot
.524 .01638 Mdot
.524 .01639 Mdot
.524 .01641 Mdot
.524 .01642 Mdot
.524 .01646 Mdot
.524 .01647 Mdot
.524 .01649 Mdot
.524 .01651 Mdot
.524 .01655 Mdot
.524 .01655 Mdot
.524 .01658 Mdot
.524 .01659 Mdot
.524 .01664 Mdot
.524 .01664 Mdot
.524 .01667 Mdot
.524 .01668 Mdot
.524 .01673 Mdot
.524 .01673 Mdot
.524 .01676 Mdot
.524 .01678 Mdot
.524 .01682 Mdot
.524 .01683 Mdot
.524 .01686 Mdot
.524 .01687 Mdot
.524 .01693 Mdot
.524 .01693 Mdot
.524 .01696 Mdot
.524 .01698 Mdot
.524 .01703 Mdot
.524 .01704 Mdot
.524 .01707 Mdot
.524 .01709 Mdot
.524 .01714 Mdot
.524 .01715 Mdot
.524 .01718 Mdot
.524 .0172 Mdot
.524 .01726 Mdot
.524 .01727 Mdot
.524 .0173 Mdot
.524 .01732 Mdot
.524 .01738 Mdot
.524 .01739 Mdot
.524 .01743 Mdot
.524 .01745 Mdot
.524 .01751 Mdot
.524 .01752 Mdot
.524 .01756 Mdot
.524 .01758 Mdot
.524 .01764 Mdot
.524 .01765 Mdot
.524 .01769 Mdot
.524 .01771 Mdot
.524 .01778 Mdot
.524 .01779 Mdot
.524 .01784 Mdot
.524 .01786 Mdot
.524 .01793 Mdot
.524 .01794 Mdot
.524 .01799 Mdot
.524 .01801 Mdot
.524 .01809 Mdot
.524 .01809 Mdot
.524 .01814 Mdot
.524 .01817 Mdot
.524 .01825 Mdot
.524 .01826 Mdot
.524 .01831 Mdot
.524 .01833 Mdot
.524 .01842 Mdot
.524 .01843 Mdot
.524 .01848 Mdot
.524 .01851 Mdot
.524 .0186 Mdot
.524 .01861 Mdot
.524 .01866 Mdot
.524 .01869 Mdot
.524 .01878 Mdot
.524 .01879 Mdot
.524 .01885 Mdot
.524 .01888 Mdot
.524 .01898 Mdot
.524 .01899 Mdot
.524 .01905 Mdot
.524 .01908 Mdot
.524 .01918 Mdot
.524 .01919 Mdot
.524 .01926 Mdot
.524 .01929 Mdot
.524 .0194 Mdot
.524 .01941 Mdot
.524 .01948 Mdot
.524 .01951 Mdot
.524 .01962 Mdot
.524 .01963 Mdot
.524 .0197 Mdot
.524 .01974 Mdot
.524 .01986 Mdot
.524 .01987 Mdot
.524 .01994 Mdot
.524 .01998 Mdot
.524 .0201 Mdot
.524 .02012 Mdot
.524 .02019 Mdot
.524 .02023 Mdot
.524 .02036 Mdot
.524 .02038 Mdot
.524 .02046 Mdot
.524 .0205 Mdot
.524 .02063 Mdot
.524 .02065 Mdot
.524 .02072 Mdot
.524 .02073 Mdot
.524 .02077 Mdot
.524 .02092 Mdot
.524 .02093 Mdot
.524 .02101 Mdot
.524 .02102 Mdot
.524 .02106 Mdot
.524 .02121 Mdot
.524 .02123 Mdot
.524 .02131 Mdot
.524 .02132 Mdot
.524 .02137 Mdot
.524 .02153 Mdot
.524 .02154 Mdot
.524 .02162 Mdot
.524 .02164 Mdot
.524 .02169 Mdot
.524 .02185 Mdot
.524 .02187 Mdot
.524 .02196 Mdot
.524 .02197 Mdot
.524 .02202 Mdot
.524 .0222 Mdot
.524 .02221 Mdot
.524 .0223 Mdot
.524 .02232 Mdot
.524 .02237 Mdot
.524 .02255 Mdot
.524 .02257 Mdot
.524 .02267 Mdot
.524 .02269 Mdot
.524 .02274 Mdot
.524 .02293 Mdot
.524 .02295 Mdot
.524 .02305 Mdot
.524 .02307 Mdot
.524 .02313 Mdot
.524 .02313 Mdot
.524 .02333 Mdot
.524 .02335 Mdot
.524 .02345 Mdot
.524 .02347 Mdot
.524 .02353 Mdot
.524 .02353 Mdot
.524 .02374 Mdot
.524 .02376 Mdot
.524 .02387 Mdot
.524 .02389 Mdot
.524 .02394 Mdot
.524 .02395 Mdot
.524 .02395 Mdot
.524 .02417 Mdot
.524 .0242 Mdot
.524 .02431 Mdot
.524 .02433 Mdot
.524 .02438 Mdot
.524 .0244 Mdot
.524 .0244 Mdot
.524 .02455 Mdot
.524 .02463 Mdot
.524 .02465 Mdot
.524 .02477 Mdot
.524 .02479 Mdot
.524 .02485 Mdot
.524 .02486 Mdot
.524 .02486 Mdot
.524 .02502 Mdot
.524 .0251 Mdot
.524 .02513 Mdot
.524 .02525 Mdot
.524 .02528 Mdot
.524 .02533 Mdot
.524 .02535 Mdot
.524 .02535 Mdot
.524 .02552 Mdot
.524 .0256 Mdot
.524 .02563 Mdot
.524 .02576 Mdot
.524 .02578 Mdot
.524 .02584 Mdot
.524 .02586 Mdot
.524 .02586 Mdot
.524 .02604 Mdot
.524 .02612 Mdot
.524 .02615 Mdot
.524 .02629 Mdot
.524 .02632 Mdot
.524 .02638 Mdot
.524 .02639 Mdot
.524 .02639 Mdot
.524 .02658 Mdot
.524 .02667 Mdot
.524 .0267 Mdot
.524 .02684 Mdot
.524 .02687 Mdot
.524 .02693 Mdot
.524 .02695 Mdot
.524 .02696 Mdot
.524 .02715 Mdot
.524 .02724 Mdot
.524 .02728 Mdot
.524 .02743 Mdot
.524 .02746 Mdot
.524 .02752 Mdot
.524 .02754 Mdot
.524 .02754 Mdot
.524 .02775 Mdot
.524 .02776 Mdot
.524 .02784 Mdot
.524 .02788 Mdot
.524 .02804 Mdot
.524 .02807 Mdot
.524 .02814 Mdot
.524 .02816 Mdot
.524 .02816 Mdot
.524 .02837 Mdot
.524 .02839 Mdot
.524 .02847 Mdot
.524 .02851 Mdot
.524 .02854 Mdot
.524 .02868 Mdot
.524 .02871 Mdot
.524 .02878 Mdot
.524 .0288 Mdot
.524 .0288 Mdot
.524 .02903 Mdot
.524 .02904 Mdot
.524 .02914 Mdot
.524 .02917 Mdot
.524 .0292 Mdot
.524 .02935 Mdot
.524 .02938 Mdot
.524 .02946 Mdot
.524 .02948 Mdot
.524 .02948 Mdot
.524 .02971 Mdot
.524 .02973 Mdot
.524 .02983 Mdot
.524 .02987 Mdot
.524 .0299 Mdot
.524 .03005 Mdot
.524 .03008 Mdot
.524 .03016 Mdot
.524 .03019 Mdot
.524 .03019 Mdot
.524 .03043 Mdot
.524 .03045 Mdot
.524 .03055 Mdot
.524 .03059 Mdot
.524 .03062 Mdot
.524 .03078 Mdot
.524 .03082 Mdot
.524 .0309 Mdot
.524 .03093 Mdot
.524 .03093 Mdot
.524 .03119 Mdot
.524 .03121 Mdot
.524 .03131 Mdot
.524 .03136 Mdot
.524 .03139 Mdot
.524 .03155 Mdot
.524 .0316 Mdot
.524 .03168 Mdot
.524 .03171 Mdot
.524 .03171 Mdot
.524 .03198 Mdot
.524 .032 Mdot
.524 .03211 Mdot
.524 .03215 Mdot
.524 .03219 Mdot
.524 .03236 Mdot
.524 .03241 Mdot
.524 .0325 Mdot
.524 .03252 Mdot
.524 .03253 Mdot
.524 .03281 Mdot
.524 .03283 Mdot
.524 .03294 Mdot
.524 .03299 Mdot
.524 .03303 Mdot
.524 .03321 Mdot
.524 .03325 Mdot
.524 .03335 Mdot
.524 .03338 Mdot
.524 .03338 Mdot
.524 .03368 Mdot
.524 .0337 Mdot
.524 .03382 Mdot
.524 .03387 Mdot
.524 .03391 Mdot
.524 .0341 Mdot
.524 .03414 Mdot
.524 .03424 Mdot
.524 .03427 Mdot
.524 .03428 Mdot
.524 .03459 Mdot
.524 .03461 Mdot
.524 .03474 Mdot
.524 .03479 Mdot
.524 .03483 Mdot
.524 .03503 Mdot
.524 .03508 Mdot
.524 .03518 Mdot
.524 .03521 Mdot
.524 .03522 Mdot
.524 .03554 Mdot
.524 .03557 Mdot
.524 .0357 Mdot
.524 .03575 Mdot
.524 .03579 Mdot
.524 .036 Mdot
.524 .03605 Mdot
.524 .03616 Mdot
.524 .0362 Mdot
.524 .0362 Mdot
.524 .03654 Mdot
.524 .03657 Mdot
.524 .03671 Mdot
.524 .03676 Mdot
.524 .0368 Mdot
.524 .03703 Mdot
.524 .03708 Mdot
.524 .03719 Mdot
.524 .03723 Mdot
.524 .03723 Mdot
.524 .03759 Mdot
.524 .03762 Mdot
.524 .03776 Mdot
.524 .03782 Mdot
.524 .03786 Mdot
.524 .0381 Mdot
.524 .03815 Mdot
.524 .03827 Mdot
.524 .03831 Mdot
.524 .03831 Mdot
.524 .03868 Mdot
.524 .03872 Mdot
.524 .03887 Mdot
.524 .03893 Mdot
.524 .03897 Mdot
.524 .03922 Mdot
.524 .03928 Mdot
.524 .0394 Mdot
.524 .03944 Mdot
.524 .03944 Mdot
.524 .03983 Mdot
.524 .03987 Mdot
.524 .04003 Mdot
.524 .04009 Mdot
.524 .04014 Mdot
.524 .04039 Mdot
.524 .04046 Mdot
.524 .04059 Mdot
.524 .04063 Mdot
.524 .04063 Mdot
.524 .04104 Mdot
.524 .04107 Mdot
.524 .04124 Mdot
.524 .04131 Mdot
.524 .04136 Mdot
.524 .04163 Mdot
.524 .04169 Mdot
.524 .04183 Mdot
.524 .04187 Mdot
.524 .04188 Mdot
.524 .0423 Mdot
.524 .04234 Mdot
.524 .04251 Mdot
.524 .04259 Mdot
.524 .04264 Mdot
.524 .04292 Mdot
.524 .04299 Mdot
.524 .04313 Mdot
.524 .04317 Mdot
.524 .04318 Mdot
.524 .04363 Mdot
.524 .04367 Mdot
.524 .04385 Mdot
.524 .04392 Mdot
.524 .04398 Mdot
.524 .04427 Mdot
.524 .04434 Mdot
.524 .0445 Mdot
.524 .04454 Mdot
.524 .04455 Mdot
.524 .04502 Mdot
.524 .04506 Mdot
.524 .04525 Mdot
.524 .04532 Mdot
.524 .04538 Mdot
.524 .04569 Mdot
.524 .04577 Mdot
.524 .04592 Mdot
.524 .04597 Mdot
.524 .04598 Mdot
.524 .04647 Mdot
.524 .04651 Mdot
.524 .04671 Mdot
.524 .04679 Mdot
.524 .04686 Mdot
.524 .04718 Mdot
.524 .04726 Mdot
.524 .04742 Mdot
.524 .04747 Mdot
.524 .04748 Mdot
.524 .04799 Mdot
.524 .04804 Mdot
.524 .04825 Mdot
.524 .04833 Mdot
.524 .0484 Mdot
.524 .04874 Mdot
.524 .04882 Mdot
.524 .04899 Mdot
.524 .04904 Mdot
.524 .04905 Mdot
.524 .04959 Mdot
.524 .04964 Mdot
.524 .04986 Mdot
.524 .04995 Mdot
.524 .05002 Mdot
.524 .05037 Mdot
.524 .05046 Mdot
.524 .05064 Mdot
.524 .05069 Mdot
.524 .0507 Mdot
.524 .05127 Mdot
.524 .05131 Mdot
.524 .05154 Mdot
.524 .05164 Mdot
.524 .05171 Mdot
.524 .05208 Mdot
.524 .05217 Mdot
.524 .05236 Mdot
.524 .05242 Mdot
.524 .05243 Mdot
.524 .05302 Mdot
.524 .05307 Mdot
.524 .05331 Mdot
.524 .05341 Mdot
.524 .05349 Mdot
.524 .05387 Mdot
.524 .05397 Mdot
.524 .05417 Mdot
.524 .05423 Mdot
.524 .05424 Mdot
.524 .05486 Mdot
.524 .05491 Mdot
.524 .05517 Mdot
.524 .05527 Mdot
.524 .05535 Mdot
.524 .05575 Mdot
.524 .05585 Mdot
.524 .05606 Mdot
.524 .05613 Mdot
.524 .05613 Mdot
.524 .05679 Mdot
.524 .05684 Mdot
.524 .05711 Mdot
.524 .05721 Mdot
.524 .0573 Mdot
.524 .05772 Mdot
.524 .05783 Mdot
.524 .05805 Mdot
.524 .05811 Mdot
.524 .05812 Mdot
.524 .05881 Mdot
.524 .05886 Mdot
.524 .05914 Mdot
.524 .05925 Mdot
.524 .05934 Mdot
.524 .05979 Mdot
.524 .0599 Mdot
.524 .06013 Mdot
.524 .0602 Mdot
.524 .0602 Mdot
.524 .06092 Mdot
.524 .06098 Mdot
.524 .06127 Mdot
.524 .06139 Mdot
.524 .06148 Mdot
.524 .06195 Mdot
.524 .06207 Mdot
.524 .06231 Mdot
.524 .06238 Mdot
.524 .06239 Mdot
.524 .06314 Mdot
.524 .0632 Mdot
.524 .06351 Mdot
.524 .06363 Mdot
.524 .06373 Mdot
.524 .06422 Mdot
.524 .06434 Mdot
.524 .06459 Mdot
.524 .06467 Mdot
.524 .06468 Mdot
.524 .06546 Mdot
.524 .06553 Mdot
.524 .06585 Mdot
.524 .06598 Mdot
.524 .06608 Mdot
.524 .0666 Mdot
.524 .06672 Mdot
.524 .06699 Mdot
.524 .06707 Mdot
.524 .06707 Mdot
.524 .0679 Mdot
.524 .06797 Mdot
.524 .06831 Mdot
.524 .06844 Mdot
.524 .06855 Mdot
.524 .06909 Mdot
.524 .06922 Mdot
.524 .0695 Mdot
.524 .06958 Mdot
.524 .06959 Mdot
.524 .07045 Mdot
.524 .07053 Mdot
.524 .07088 Mdot
.524 .07102 Mdot
.524 .07113 Mdot
.524 .0717 Mdot
.524 .07183 Mdot
.524 .07213 Mdot
.524 .07221 Mdot
.524 .07222 Mdot
.524 .07313 Mdot
.524 .0732 Mdot
.524 .07357 Mdot
.524 .07372 Mdot
.524 .07384 Mdot
.524 .07443 Mdot
.524 .07457 Mdot
.524 .07488 Mdot
.524 .07497 Mdot
.524 .07498 Mdot
.524 .07593 Mdot
.524 .07601 Mdot
.524 .0764 Mdot
.524 .07656 Mdot
.524 .07667 Mdot
.524 .0773 Mdot
.524 .07745 Mdot
.524 .07777 Mdot
.524 .07786 Mdot
.524 .07787 Mdot
.524 .07887 Mdot
.524 .07895 Mdot
.524 .07936 Mdot
.524 .07952 Mdot
.524 .07965 Mdot
.524 .0803 Mdot
.524 .08046 Mdot
.524 .0808 Mdot
.524 .08089 Mdot
.524 .08091 Mdot
.524 .08195 Mdot
.524 .08204 Mdot
.524 .08246 Mdot
.524 .08264 Mdot
.524 .08277 Mdot
.524 .08345 Mdot
.524 .08361 Mdot
.524 .08397 Mdot
.524 .08407 Mdot
.524 .08408 Mdot
.524 .08518 Mdot
.524 .08527 Mdot
.524 .08571 Mdot
.524 .0859 Mdot
.524 .08603 Mdot
.524 .08675 Mdot
.524 .08692 Mdot
.524 .08729 Mdot
.524 .0874 Mdot
.524 .08741 Mdot
.524 .08856 Mdot
.524 .08866 Mdot
.524 .08912 Mdot
.524 .08931 Mdot
.524 .08946 Mdot
.524 .09021 Mdot
.524 .09039 Mdot
.524 .09077 Mdot
.524 .09089 Mdot
.524 .0909 Mdot
.524 .0921 Mdot
.524 .09221 Mdot
.524 .09269 Mdot
.524 .09289 Mdot
.524 .09304 Mdot
.524 .09383 Mdot
.524 .09402 Mdot
.524 .09443 Mdot
.524 .09455 Mdot
.524 .09456 Mdot
.524 .09582 Mdot
.524 .09644 Mdot
.524 .09665 Mdot
.524 .0968 Mdot
.524 .09763 Mdot
.524 .09783 Mdot
.524 .09825 Mdot
.524 .09838 Mdot
.524 .09839 Mdot
.524 .09971 Mdot
.524 .10036 Mdot
.524 .10058 Mdot
.524 .10074 Mdot
.524 .10161 Mdot
.524 .10182 Mdot
.524 .10226 Mdot
.524 .10239 Mdot
.524 .10241 Mdot
.524 .10379 Mdot
.524 .10447 Mdot
.524 .1047 Mdot
.524 .10487 Mdot
.524 .10578 Mdot
.524 .106 Mdot
.524 .10646 Mdot
.524 .1066 Mdot
.524 .10662 Mdot
.524 .10807 Mdot
.524 .10878 Mdot
.524 .10902 Mdot
.524 .1092 Mdot
.524 .11015 Mdot
.524 .11038 Mdot
.524 .11087 Mdot
.524 .11101 Mdot
.524 .11103 Mdot
.524 .11255 Mdot
.524 .11329 Mdot
.524 .11355 Mdot
.524 .11374 Mdot
.524 .11473 Mdot
.524 .11497 Mdot
.524 .11548 Mdot
.524 .11563 Mdot
.524 .11565 Mdot
.524 .11724 Mdot
.524 .11803 Mdot
.524 .11829 Mdot
.524 .11849 Mdot
.524 .11953 Mdot
.524 .11978 Mdot
.524 .12032 Mdot
.524 .12048 Mdot
.524 .1205 Mdot
.524 .12217 Mdot
.524 .12298 Mdot
.524 .12326 Mdot
.524 .12347 Mdot
.524 .12456 Mdot
.524 .12483 Mdot
.524 .12539 Mdot
.524 .12556 Mdot
.524 .12557 Mdot
.524 .12732 Mdot
.524 .12818 Mdot
.524 .12847 Mdot
.524 .12869 Mdot
.524 .12983 Mdot
.524 .13011 Mdot
.524 .1307 Mdot
.524 .13088 Mdot
.524 .1309 Mdot
.524 .13273 Mdot
.524 .13363 Mdot
.524 .13393 Mdot
.524 .13416 Mdot
.524 .13536 Mdot
.524 .13565 Mdot
.524 .13606 Mdot
.524 .13627 Mdot
.524 .13645 Mdot
.524 .13647 Mdot
.524 .13839 Mdot
.524 .13934 Mdot
.524 .13965 Mdot
.524 .13989 Mdot
.524 .14115 Mdot
.524 .14145 Mdot
.524 .14189 Mdot
.524 .1421 Mdot
.524 .14229 Mdot
.524 .14232 Mdot
.524 .14433 Mdot
.524 .14532 Mdot
.524 .14565 Mdot
.524 .1459 Mdot
.524 .14722 Mdot
.524 .14754 Mdot
.524 .14799 Mdot
.524 .14822 Mdot
.524 .14842 Mdot
.524 .14844 Mdot
.524 .15055 Mdot
.524 .15159 Mdot
.524 .15194 Mdot
.524 .1522 Mdot
.524 .15358 Mdot
.524 .15391 Mdot
.524 .15439 Mdot
.524 .15463 Mdot
.524 .15484 Mdot
.524 .15486 Mdot
.524 .15707 Mdot
.524 .15816 Mdot
.524 .15852 Mdot
.524 .1588 Mdot
.524 .16025 Mdot
.524 .16059 Mdot
.524 .16109 Mdot
.524 .16134 Mdot
.524 .16156 Mdot
.524 .16159 Mdot
.524 .1639 Mdot
.524 .16504 Mdot
.524 .16543 Mdot
.524 .16571 Mdot
.524 .16723 Mdot
.524 .1676 Mdot
.524 .16812 Mdot
.524 .16838 Mdot
.524 .16861 Mdot
.524 .16864 Mdot
.524 .17107 Mdot
.524 .17226 Mdot
.524 .17266 Mdot
.524 .17296 Mdot
.524 .17455 Mdot
.524 .17494 Mdot
.524 .17548 Mdot
.524 .17576 Mdot
.524 .176 Mdot
.524 .17603 Mdot
.524 .17857 Mdot
.524 .17982 Mdot
.524 .18024 Mdot
.524 .18056 Mdot
.524 .18222 Mdot
.524 .18263 Mdot
.524 .1832 Mdot
.524 .18349 Mdot
.524 .18374 Mdot
.524 .18377 Mdot
.524 .18644 Mdot
.524 .18774 Mdot
.524 .18819 Mdot
.524 .18852 Mdot
.524 .19026 Mdot
.524 .19069 Mdot
.524 .19129 Mdot
.524 .19159 Mdot
.524 .19185 Mdot
.524 .19188 Mdot
.524 .19468 Mdot
.524 .19605 Mdot
.524 .19651 Mdot
.524 .19686 Mdot
.524 .19869 Mdot
.524 .19913 Mdot
.524 .19976 Mdot
.524 .20008 Mdot
.524 .20036 Mdot
.524 .20039 Mdot
.524 .20332 Mdot
.524 .20475 Mdot
.524 .20524 Mdot
.524 .2056 Mdot
.524 .20752 Mdot
.524 .20798 Mdot
.524 .20864 Mdot
.524 .20897 Mdot
.524 .20927 Mdot
.524 .2093 Mdot
.524 .21237 Mdot
.524 .21388 Mdot
.524 .21438 Mdot
.524 .21477 Mdot
.524 .21678 Mdot
.524 .21726 Mdot
.524 .21795 Mdot
.524 .2183 Mdot
.524 .2186 Mdot
.524 .21864 Mdot
.524 .22186 Mdot
.524 .22344 Mdot
.524 .22397 Mdot
.524 .22437 Mdot
.524 .22648 Mdot
.524 .22698 Mdot
.524 .22771 Mdot
.524 .22807 Mdot
.524 .22839 Mdot
.524 .22843 Mdot
.524 .2318 Mdot
.524 .23345 Mdot
.524 .23401 Mdot
.524 .23443 Mdot
.524 .23664 Mdot
.524 .23717 Mdot
.524 .23793 Mdot
.524 .23831 Mdot
.524 .23865 Mdot
.524 .23869 Mdot
.524 .24222 Mdot
.524 .24395 Mdot
.524 .24454 Mdot
.524 .24498 Mdot
.524 .24729 Mdot
.524 .24785 Mdot
.524 .24865 Mdot
.524 .24904 Mdot
.524 .2494 Mdot
.524 .24944 Mdot
.524 .25314 Mdot
.524 .25496 Mdot
.524 .25557 Mdot
.524 .25603 Mdot
.524 .25846 Mdot
.524 .25904 Mdot
.524 .25988 Mdot
.524 .26029 Mdot
.524 .26066 Mdot
.524 .2607 Mdot
.524 .26458 Mdot
.524 .26649 Mdot
.524 .26713 Mdot
.524 .26761 Mdot
.524 .27016 Mdot
.524 .27077 Mdot
.524 .27164 Mdot
.524 .27208 Mdot
.524 .27247 Mdot
.524 .27251 Mdot
.524 .27658 Mdot
.524 .27857 Mdot
.524 .27925 Mdot
.524 .27975 Mdot
.524 .28242 Mdot
.524 .28306 Mdot
.524 .28398 Mdot
.524 .28443 Mdot
.524 .28484 Mdot
.524 .28488 Mdot
.524 .28915 Mdot
.524 .29124 Mdot
.524 .29194 Mdot
.524 .29248 Mdot
.524 .29527 Mdot
.524 .29594 Mdot
.524 .2969 Mdot
.524 .29738 Mdot
.524 .2978 Mdot
.524 .29785 Mdot
.524 .30232 Mdot
.524 .30451 Mdot
.524 .30525 Mdot
.524 .30581 Mdot
.524 .30873 Mdot
.524 .30944 Mdot
.524 .31044 Mdot
.524 .31095 Mdot
.524 .31139 Mdot
.524 .31144 Mdot
.524 .31612 Mdot
.524 .31842 Mdot
.524 .3192 Mdot
.524 .31978 Mdot
.524 .32285 Mdot
.524 .32358 Mdot
.526 .0155 Mdot
.526 .01554 Mdot
.526 .01559 Mdot
.526 .01563 Mdot
.526 .01568 Mdot
.526 .01573 Mdot
.526 .01578 Mdot
.526 .01584 Mdot
.526 .0159 Mdot
.526 .01596 Mdot
.526 .01602 Mdot
.526 .01606 Mdot
.526 .01609 Mdot
.526 .01613 Mdot
.526 .01616 Mdot
.526 .0162 Mdot
.526 .01624 Mdot
.526 .01628 Mdot
.526 .01632 Mdot
.526 .01636 Mdot
.526 .0164 Mdot
.526 .01645 Mdot
.526 .01649 Mdot
.526 .01654 Mdot
.526 .01658 Mdot
.526 .01663 Mdot
.526 .01668 Mdot
.526 .01673 Mdot
.526 .01678 Mdot
.526 .01682 Mdot
.526 .01684 Mdot
.526 .01689 Mdot
.526 .01693 Mdot
.526 .01695 Mdot
.526 .017 Mdot
.526 .01705 Mdot
.526 .01707 Mdot
.526 .01712 Mdot
.526 .01717 Mdot
.526 .01719 Mdot
.526 .01725 Mdot
.526 .01729 Mdot
.526 .01732 Mdot
.526 .01738 Mdot
.526 .01743 Mdot
.526 .01745 Mdot
.526 .01752 Mdot
.526 .01757 Mdot
.526 .01759 Mdot
.526 .01766 Mdot
.526 .01772 Mdot
.526 .01774 Mdot
.526 .01781 Mdot
.526 .01787 Mdot
.526 .0179 Mdot
.526 .01798 Mdot
.526 .01804 Mdot
.526 .01807 Mdot
.526 .01815 Mdot
.526 .01821 Mdot
.526 .01824 Mdot
.526 .01832 Mdot
.526 .01839 Mdot
.526 .01842 Mdot
.526 .01847 Mdot
.526 .01851 Mdot
.526 .01858 Mdot
.526 .01862 Mdot
.526 .01866 Mdot
.526 .01871 Mdot
.526 .01879 Mdot
.526 .01882 Mdot
.526 .01887 Mdot
.526 .01892 Mdot
.526 .019 Mdot
.526 .01903 Mdot
.526 .01908 Mdot
.526 .01913 Mdot
.526 .01922 Mdot
.526 .01926 Mdot
.526 .01929 Mdot
.526 .01931 Mdot
.526 .01936 Mdot
.526 .01945 Mdot
.526 .01949 Mdot
.526 .01953 Mdot
.526 .01955 Mdot
.526 .01961 Mdot
.526 .0197 Mdot
.526 .01974 Mdot
.526 .01978 Mdot
.526 .0198 Mdot
.526 .01986 Mdot
.526 .01996 Mdot
.526 .02 Mdot
.526 .02004 Mdot
.526 .02006 Mdot
.526 .02013 Mdot
.526 .02023 Mdot
.526 .02028 Mdot
.526 .02032 Mdot
.526 .02034 Mdot
.526 .02041 Mdot
.526 .02052 Mdot
.526 .02053 Mdot
.526 .02057 Mdot
.526 .02061 Mdot
.526 .02063 Mdot
.526 .02071 Mdot
.526 .02082 Mdot
.526 .02083 Mdot
.526 .02087 Mdot
.526 .02092 Mdot
.526 .02094 Mdot
.526 .02102 Mdot
.526 .02114 Mdot
.526 .02115 Mdot
.526 .02119 Mdot
.526 .02124 Mdot
.526 .02126 Mdot
.526 .02135 Mdot
.526 .02147 Mdot
.526 .02149 Mdot
.526 .02153 Mdot
.526 .02158 Mdot
.526 .0216 Mdot
.526 .02169 Mdot
.526 .02183 Mdot
.526 .02184 Mdot
.526 .02189 Mdot
.526 .02193 Mdot
.526 .02196 Mdot
.526 .02205 Mdot
.526 .02213 Mdot
.526 .0222 Mdot
.526 .02221 Mdot
.526 .02226 Mdot
.526 .02231 Mdot
.526 .02234 Mdot
.526 .02243 Mdot
.526 .02251 Mdot
.526 .02258 Mdot
.526 .0226 Mdot
.526 .02265 Mdot
.526 .0227 Mdot
.526 .02274 Mdot
.526 .02277 Mdot
.526 .02284 Mdot
.526 .02292 Mdot
.526 .02299 Mdot
.526 .02301 Mdot
.526 .02306 Mdot
.526 .02312 Mdot
.526 .02315 Mdot
.526 .02319 Mdot
.526 .02326 Mdot
.526 .02335 Mdot
.526 .02342 Mdot
.526 .02344 Mdot
.526 .0235 Mdot
.526 .02356 Mdot
.526 .02359 Mdot
.526 .02363 Mdot
.526 .0237 Mdot
.526 .02379 Mdot
.526 .02388 Mdot
.526 .02389 Mdot
.526 .02395 Mdot
.526 .02402 Mdot
.526 .02405 Mdot
.526 .02409 Mdot
.526 .02417 Mdot
.526 .02427 Mdot
.526 .02435 Mdot
.526 .02437 Mdot
.526 .02443 Mdot
.526 .0245 Mdot
.526 .02454 Mdot
.526 .02458 Mdot
.526 .02466 Mdot
.526 .02476 Mdot
.526 .0248 Mdot
.526 .02485 Mdot
.526 .02487 Mdot
.526 .02494 Mdot
.526 .02501 Mdot
.526 .02505 Mdot
.526 .02509 Mdot
.526 .02518 Mdot
.526 .02529 Mdot
.526 .02533 Mdot
.526 .02538 Mdot
.526 .0254 Mdot
.526 .02547 Mdot
.526 .02554 Mdot
.526 .02559 Mdot
.526 .02563 Mdot
.526 .02572 Mdot
.526 .02584 Mdot
.526 .02588 Mdot
.526 .02594 Mdot
.526 .02596 Mdot
.526 .02603 Mdot
.526 .02611 Mdot
.526 .02615 Mdot
.526 .0262 Mdot
.526 .02629 Mdot
.526 .02641 Mdot
.526 .02646 Mdot
.526 .02652 Mdot
.526 .02654 Mdot
.526 .02662 Mdot
.526 .0267 Mdot
.526 .02675 Mdot
.526 .02679 Mdot
.526 .0269 Mdot
.526 .02699 Mdot
.526 .02702 Mdot
.526 .02707 Mdot
.526 .02713 Mdot
.526 .02716 Mdot
.526 .02724 Mdot
.526 .02732 Mdot
.526 .02737 Mdot
.526 .02742 Mdot
.526 .02753 Mdot
.526 .02763 Mdot
.526 .02766 Mdot
.526 .02771 Mdot
.526 .02778 Mdot
.526 .02781 Mdot
.526 .02789 Mdot
.526 .02798 Mdot
.526 .02803 Mdot
.526 .02808 Mdot
.526 .0282 Mdot
.526 .0283 Mdot
.526 .0283 Mdot
.526 .02834 Mdot
.526 .02839 Mdot
.526 .02846 Mdot
.526 .02849 Mdot
.526 .02857 Mdot
.526 .02867 Mdot
.526 .02872 Mdot
.526 .02878 Mdot
.526 .0289 Mdot
.526 .02901 Mdot
.526 .02901 Mdot
.526 .02904 Mdot
.526 .0291 Mdot
.526 .02917 Mdot
.526 .0292 Mdot
.526 .02929 Mdot
.526 .02939 Mdot
.526 .02945 Mdot
.526 .02951 Mdot
.526 .02955 Mdot
.526 .02964 Mdot
.526 .02975 Mdot
.526 .02975 Mdot
.526 .02979 Mdot
.526 .02985 Mdot
.526 .02992 Mdot
.526 .02996 Mdot
.526 .03005 Mdot
.526 .03016 Mdot
.526 .03022 Mdot
.526 .03028 Mdot
.526 .03032 Mdot
.526 .03041 Mdot
.526 .03045 Mdot
.526 .03053 Mdot
.526 .03054 Mdot
.526 .03057 Mdot
.526 .03064 Mdot
.526 .03072 Mdot
.526 .03075 Mdot
.526 .03085 Mdot
.526 .03096 Mdot
.526 .03103 Mdot
.526 .03109 Mdot
.526 .03113 Mdot
.526 .03123 Mdot
.526 .03127 Mdot
.526 .03135 Mdot
.526 .03136 Mdot
.526 .0314 Mdot
.526 .03146 Mdot
.526 .03155 Mdot
.526 .03158 Mdot
.526 .03169 Mdot
.526 .0318 Mdot
.526 .03187 Mdot
.526 .03194 Mdot
.526 .03199 Mdot
.526 .03209 Mdot
.526 .03213 Mdot
.526 .03222 Mdot
.526 .03222 Mdot
.526 .03227 Mdot
.526 .03233 Mdot
.526 .03242 Mdot
.526 .03246 Mdot
.526 .03257 Mdot
.526 .03269 Mdot
.526 .03277 Mdot
.526 .03284 Mdot
.526 .03289 Mdot
.526 .03299 Mdot
.526 .03303 Mdot
.526 .03313 Mdot
.526 .03313 Mdot
.526 .03318 Mdot
.526 .03325 Mdot
.526 .03334 Mdot
.526 .03338 Mdot
.526 .0335 Mdot
.526 .03363 Mdot
.526 .03371 Mdot
.526 .03378 Mdot
.526 .03383 Mdot
.526 .03394 Mdot
.526 .03399 Mdot
.526 .03409 Mdot
.526 .03409 Mdot
.526 .03414 Mdot
.526 .03421 Mdot
.526 .03431 Mdot
.526 .03435 Mdot
.526 .03448 Mdot
.526 .03461 Mdot
.526 .03469 Mdot
.526 .03477 Mdot
.526 .03482 Mdot
.526 .03494 Mdot
.526 .03499 Mdot
.526 .03509 Mdot
.526 .0351 Mdot
.526 .03515 Mdot
.526 .03523 Mdot
.526 .03533 Mdot
.526 .03537 Mdot
.526 .0355 Mdot
.526 .03565 Mdot
.526 .03573 Mdot
.526 .03581 Mdot
.526 .03587 Mdot
.526 .03599 Mdot
.526 .03604 Mdot
.526 .03615 Mdot
.526 .03616 Mdot
.526 .03621 Mdot
.526 .0363 Mdot
.526 .0364 Mdot
.526 .03645 Mdot
.526 .03659 Mdot
.526 .03673 Mdot
.526 .03682 Mdot
.526 .03691 Mdot
.526 .03697 Mdot
.526 .0371 Mdot
.526 .03715 Mdot
.526 .03727 Mdot
.526 .03727 Mdot
.526 .03733 Mdot
.526 .03742 Mdot
.526 .03753 Mdot
.526 .03758 Mdot
.526 .03772 Mdot
.526 .03788 Mdot
.526 .03797 Mdot
.526 .03806 Mdot
.526 .03813 Mdot
.526 .03826 Mdot
.526 .03832 Mdot
.526 .03844 Mdot
.526 .03845 Mdot
.526 .0385 Mdot
.526 .0386 Mdot
.526 .03872 Mdot
.526 .03877 Mdot
.526 .03892 Mdot
.526 .03908 Mdot
.526 .03918 Mdot
.526 .03928 Mdot
.526 .03935 Mdot
.526 .03949 Mdot
.526 .03955 Mdot
.526 .03968 Mdot
.526 .03968 Mdot
.526 .03974 Mdot
.526 .03984 Mdot
.526 .03997 Mdot
.526 .04002 Mdot
.526 .04018 Mdot
.526 .04035 Mdot
.526 .04046 Mdot
.526 .04055 Mdot
.526 .04063 Mdot
.526 .04077 Mdot
.526 .04084 Mdot
.526 .04097 Mdot
.526 .04098 Mdot
.526 .04104 Mdot
.526 .04115 Mdot
.526 .04128 Mdot
.526 .04133 Mdot
.526 .0415 Mdot
.526 .04168 Mdot
.526 .04179 Mdot
.526 .0419 Mdot
.526 .04197 Mdot
.526 .04213 Mdot
.526 .04219 Mdot
.526 .04234 Mdot
.526 .04235 Mdot
.526 .04241 Mdot
.526 .04252 Mdot
.526 .04266 Mdot
.526 .04272 Mdot
.526 .0429 Mdot
.526 .04309 Mdot
.526 .0432 Mdot
.526 .04331 Mdot
.526 .04339 Mdot
.526 .04355 Mdot
.526 .04362 Mdot
.526 .04378 Mdot
.526 .04378 Mdot
.526 .04385 Mdot
.526 .04397 Mdot
.526 .04411 Mdot
.526 .04417 Mdot
.526 .04436 Mdot
.526 .04456 Mdot
.526 .04468 Mdot
.526 .0448 Mdot
.526 .04488 Mdot
.526 .04505 Mdot
.526 .04513 Mdot
.526 .04529 Mdot
.526 .04529 Mdot
.526 .04537 Mdot
.526 .04549 Mdot
.526 .04564 Mdot
.526 .0457 Mdot
.526 .0459 Mdot
.526 .04611 Mdot
.526 .04624 Mdot
.526 .04636 Mdot
.526 .04645 Mdot
.526 .04663 Mdot
.526 .04671 Mdot
.526 .04688 Mdot
.526 .04688 Mdot
.526 .04696 Mdot
.526 .04709 Mdot
.526 .04725 Mdot
.526 .04732 Mdot
.526 .04752 Mdot
.526 .04775 Mdot
.526 .04788 Mdot
.526 .04801 Mdot
.526 .0481 Mdot
.526 .04829 Mdot
.526 .04837 Mdot
.526 .04855 Mdot
.526 .04856 Mdot
.526 .04864 Mdot
.526 .04877 Mdot
.526 .04894 Mdot
.526 .04901 Mdot
.526 .04923 Mdot
.526 .04947 Mdot
.526 .04961 Mdot
.526 .04974 Mdot
.526 .04984 Mdot
.526 .05004 Mdot
.526 .05012 Mdot
.526 .05031 Mdot
.526 .05032 Mdot
.526 .0504 Mdot
.526 .05054 Mdot
.526 .05072 Mdot
.526 .05079 Mdot
.526 .05102 Mdot
.526 .05127 Mdot
.526 .05142 Mdot
.526 .05156 Mdot
.526 .05166 Mdot
.526 .05187 Mdot
.526 .05196 Mdot
.526 .05216 Mdot
.526 .05217 Mdot
.526 .05226 Mdot
.526 .0524 Mdot
.526 .05259 Mdot
.526 .05267 Mdot
.526 .05291 Mdot
.526 .05317 Mdot
.526 .05333 Mdot
.526 .05348 Mdot
.526 .05358 Mdot
.526 .05381 Mdot
.526 .0539 Mdot
.526 .05411 Mdot
.526 .05412 Mdot
.526 .05421 Mdot
.526 .05436 Mdot
.526 .05456 Mdot
.526 .05464 Mdot
.526 .0549 Mdot
.526 .05517 Mdot
.526 .05534 Mdot
.526 .05549 Mdot
.526 .05561 Mdot
.526 .05584 Mdot
.526 .05594 Mdot
.526 .05615 Mdot
.526 .05616 Mdot
.526 .05626 Mdot
.526 .05643 Mdot
.526 .05664 Mdot
.526 .05672 Mdot
.526 .05699 Mdot
.526 .05728 Mdot
.526 .05745 Mdot
.526 .05761 Mdot
.526 .05773 Mdot
.526 .05798 Mdot
.526 .05808 Mdot
.526 .05831 Mdot
.526 .05832 Mdot
.526 .05842 Mdot
.526 .0586 Mdot
.526 .05882 Mdot
.526 .05891 Mdot
.526 .05919 Mdot
.526 .05949 Mdot
.526 .05967 Mdot
.526 .05984 Mdot
.526 .05997 Mdot
.526 .06023 Mdot
.526 .06034 Mdot
.526 .06058 Mdot
.526 .06059 Mdot
.526 .0607 Mdot
.526 .06088 Mdot
.526 .06111 Mdot
.526 .0612 Mdot
.526 .0615 Mdot
.526 .06182 Mdot
.526 .06201 Mdot
.526 .06219 Mdot
.526 .06232 Mdot
.526 .06259 Mdot
.526 .06271 Mdot
.526 .06296 Mdot
.526 .06297 Mdot
.526 .06309 Mdot
.526 .06328 Mdot
.526 .06352 Mdot
.526 .06362 Mdot
.526 .06393 Mdot
.526 .06427 Mdot
.526 .06447 Mdot
.526 .06466 Mdot
.526 .0648 Mdot
.526 .06508 Mdot
.526 .0652 Mdot
.526 .06547 Mdot
.526 .0656 Mdot
.526 .0658 Mdot
.526 .06606 Mdot
.526 .06616 Mdot
.526 .06649 Mdot
.526 .06684 Mdot
.526 .06706 Mdot
.526 .06726 Mdot
.526 .0674 Mdot
.526 .0677 Mdot
.526 .06783 Mdot
.526 .06811 Mdot
.526 .06825 Mdot
.526 .06846 Mdot
.526 .06873 Mdot
.526 .06884 Mdot
.526 .06918 Mdot
.526 .06956 Mdot
.526 .06978 Mdot
.526 .06999 Mdot
.526 .07014 Mdot
.526 .07046 Mdot
.526 .07059 Mdot
.526 .07089 Mdot
.526 .07103 Mdot
.526 .07125 Mdot
.526 .07154 Mdot
.526 .07165 Mdot
.526 .07202 Mdot
.526 .07241 Mdot
.526 .07264 Mdot
.526 .07286 Mdot
.526 .07302 Mdot
.526 .07336 Mdot
.526 .0735 Mdot
.526 .07381 Mdot
.526 .07396 Mdot
.526 .07419 Mdot
.526 .07449 Mdot
.526 .07461 Mdot
.526 .075 Mdot
.526 .07541 Mdot
.526 .07565 Mdot
.526 .07589 Mdot
.526 .07606 Mdot
.526 .0764 Mdot
.526 .07655 Mdot
.526 .07688 Mdot
.526 .07704 Mdot
.526 .07729 Mdot
.526 .0776 Mdot
.526 .07773 Mdot
.526 .07813 Mdot
.526 .07856 Mdot
.526 .07882 Mdot
.526 .07907 Mdot
.526 .07925 Mdot
.526 .07961 Mdot
.526 .07977 Mdot
.526 .08011 Mdot
.526 .08028 Mdot
.526 .08054 Mdot
.526 .08087 Mdot
.526 .08101 Mdot
.526 .08143 Mdot
.526 .08188 Mdot
.526 .08216 Mdot
.526 .08241 Mdot
.526 .0826 Mdot
.526 .08299 Mdot
.526 .08315 Mdot
.526 .08351 Mdot
.526 .08369 Mdot
.526 .08396 Mdot
.526 .08431 Mdot
.526 .08445 Mdot
.526 .0849 Mdot
.526 .08538 Mdot
.526 .08566 Mdot
.526 .08594 Mdot
.526 .08613 Mdot
.526 .08654 Mdot
.526 .08671 Mdot
.526 .08709 Mdot
.526 .08728 Mdot
.526 .08757 Mdot
.526 .08793 Mdot
.526 .08808 Mdot
.526 .08855 Mdot
.526 .08905 Mdot
.526 .08935 Mdot
.526 .08964 Mdot
.526 .08985 Mdot
.526 .09027 Mdot
.526 .09046 Mdot
.526 .09085 Mdot
.526 .09105 Mdot
.526 .09135 Mdot
.526 .09174 Mdot
.526 .09189 Mdot
.526 .09239 Mdot
.526 .09292 Mdot
.526 .09323 Mdot
.526 .09353 Mdot
.526 .09375 Mdot
.526 .0942 Mdot
.526 .09439 Mdot
.526 .09481 Mdot
.526 .09502 Mdot
.526 .09534 Mdot
.526 .09574 Mdot
.526 .09591 Mdot
.526 .09643 Mdot
.526 .09698 Mdot
.526 .09732 Mdot
.526 .09763 Mdot
.526 .09786 Mdot
.526 .09833 Mdot
.526 .09854 Mdot
.526 .09898 Mdot
.526 .0992 Mdot
.526 .09953 Mdot
.526 .09996 Mdot
.526 .10013 Mdot
.526 .10067 Mdot
.526 .10126 Mdot
.526 .10161 Mdot
.526 .10194 Mdot
.526 .10219 Mdot
.526 .10268 Mdot
.526 .1029 Mdot
.526 .10336 Mdot
.526 .10359 Mdot
.526 .10394 Mdot
.526 .10439 Mdot
.526 .10457 Mdot
.526 .10514 Mdot
.526 .10576 Mdot
.526 .10613 Mdot
.526 .10648 Mdot
.526 .10673 Mdot
.526 .10726 Mdot
.526 .10748 Mdot
.526 .10797 Mdot
.526 .10821 Mdot
.526 .10858 Mdot
.526 .10905 Mdot
.526 .10924 Mdot
.526 .10985 Mdot
.526 .11049 Mdot
.526 .11088 Mdot
.526 .11125 Mdot
.526 .11152 Mdot
.526 .11207 Mdot
.526 .11231 Mdot
.526 .11282 Mdot
.526 .11307 Mdot
.526 .11346 Mdot
.526 .11396 Mdot
.526 .11416 Mdot
.526 .11479 Mdot
.526 .11547 Mdot
.526 .11588 Mdot
.526 .11627 Mdot
.526 .11655 Mdot
.526 .11713 Mdot
.526 .11738 Mdot
.526 .11792 Mdot
.526 .11819 Mdot
.526 .1186 Mdot
.526 .11912 Mdot
.526 .11933 Mdot
.526 .12 Mdot
.526 .12071 Mdot
.526 .12114 Mdot
.526 .12155 Mdot
.526 .12185 Mdot
.526 .12246 Mdot
.526 .12272 Mdot
.526 .12329 Mdot
.526 .12357 Mdot
.526 .124 Mdot
.526 .12455 Mdot
.526 .12477 Mdot
.526 .12547 Mdot
.526 .12623 Mdot
.526 .12668 Mdot
.526 .12711 Mdot
.526 .12742 Mdot
.526 .12806 Mdot
.526 .12834 Mdot
.526 .12893 Mdot
.526 .12923 Mdot
.526 .12968 Mdot
.526 .13026 Mdot
.526 .13049 Mdot
.526 .13123 Mdot
.526 .13202 Mdot
.526 .1325 Mdot
.526 .13295 Mdot
.526 .13328 Mdot
.526 .13395 Mdot
.526 .13424 Mdot
.526 .13487 Mdot
.526 .13519 Mdot
.526 .13566 Mdot
.526 .13627 Mdot
.526 .13651 Mdot
.526 .13729 Mdot
.526 .13812 Mdot
.526 .13863 Mdot
.526 .1391 Mdot
.526 .13944 Mdot
.526 .14015 Mdot
.526 .14046 Mdot
.526 .14112 Mdot
.526 .14145 Mdot
.526 .14195 Mdot
.526 .14259 Mdot
.526 .14285 Mdot
.526 .14366 Mdot
.526 .14454 Mdot
.526 .14507 Mdot
.526 .14557 Mdot
.526 .14593 Mdot
.526 .14668 Mdot
.526 .147 Mdot
.526 .14769 Mdot
.526 .14804 Mdot
.526 .14857 Mdot
.526 .14924 Mdot
.526 .14951 Mdot
.526 .15037 Mdot
.526 .15129 Mdot
.526 .15185 Mdot
.526 .15237 Mdot
.526 .15275 Mdot
.526 .15354 Mdot
.526 .15388 Mdot
.526 .15461 Mdot
.526 .15497 Mdot
.526 .15553 Mdot
.526 .15623 Mdot
.526 .15652 Mdot
.526 .15742 Mdot
.526 .1584 Mdot
.526 .15898 Mdot
.526 .15953 Mdot
.526 .15993 Mdot
.526 .16076 Mdot
.526 .16111 Mdot
.526 .16188 Mdot
.526 .16227 Mdot
.526 .16285 Mdot
.526 .16359 Mdot
.526 .16389 Mdot
.526 .16484 Mdot
.526 .16587 Mdot
.526 .16648 Mdot
.526 .16706 Mdot
.526 .16748 Mdot
.526 .16835 Mdot
.526 .16873 Mdot
.526 .16953 Mdot
.526 .16994 Mdot
.526 .17055 Mdot
.526 .17134 Mdot
.526 .17165 Mdot
.526 .17265 Mdot
.526 .17373 Mdot
.526 .17437 Mdot
.526 .17499 Mdot
.526 .17543 Mdot
.526 .17634 Mdot
.526 .17673 Mdot
.526 .17758 Mdot
.526 .17801 Mdot
.526 .17865 Mdot
.526 .17948 Mdot
.526 .17981 Mdot
.526 .18086 Mdot
.526 .182 Mdot
.526 .18267 Mdot
.526 .18332 Mdot
.526 .18378 Mdot
.526 .18475 Mdot
.526 .18516 Mdot
.526 .18605 Mdot
.526 .1865 Mdot
.526 .18718 Mdot
.526 .18805 Mdot
.526 .1884 Mdot
.526 .1895 Mdot
.526 .19069 Mdot
.526 .19141 Mdot
.526 .19209 Mdot
.526 .19258 Mdot
.526 .19359 Mdot
.526 .19402 Mdot
.526 .19496 Mdot
.526 .19544 Mdot
.526 .19615 Mdot
.526 .19706 Mdot
.526 .19743 Mdot
.526 .19859 Mdot
.526 .19984 Mdot
.526 .2006 Mdot
.526 .20131 Mdot
.526 .20182 Mdot
.526 .20289 Mdot
.526 .20335 Mdot
.526 .20434 Mdot
.526 .20483 Mdot
.526 .20558 Mdot
.526 .20654 Mdot
.526 .20693 Mdot
.526 .20815 Mdot
.526 .20947 Mdot
.526 .21026 Mdot
.526 .21101 Mdot
.526 .21155 Mdot
.526 .21267 Mdot
.526 .21315 Mdot
.526 .2142 Mdot
.526 .21472 Mdot
.526 .21551 Mdot
.526 .21652 Mdot
.526 .21692 Mdot
.526 .21821 Mdot
.526 .2196 Mdot
.526 .22043 Mdot
.526 .22122 Mdot
.526 .22179 Mdot
.526 .22297 Mdot
.526 .22347 Mdot
.526 .22457 Mdot
.526 .22512 Mdot
.526 .22595 Mdot
.526 .22701 Mdot
.526 .22744 Mdot
.526 .22879 Mdot
.526 .23025 Mdot
.526 .23113 Mdot
.526 .23196 Mdot
.526 .23256 Mdot
.526 .2338 Mdot
.526 .23433 Mdot
.526 .23548 Mdot
.526 .23606 Mdot
.526 .23693 Mdot
.526 .23805 Mdot
.526 .2385 Mdot
.526 .23993 Mdot
.526 .24146 Mdot
.526 .24238 Mdot
.526 .24326 Mdot
.526 .24389 Mdot
.526 .24519 Mdot
.526 .24575 Mdot
.526 .24696 Mdot
.526 .24757 Mdot
.526 .24849 Mdot
.526 .24966 Mdot
.526 .25014 Mdot
.526 .25164 Mdot
.526 .25325 Mdot
.526 .25422 Mdot
.526 .25514 Mdot
.526 .2558 Mdot
.526 .25717 Mdot
.526 .25776 Mdot
.526 .25904 Mdot
.526 .25968 Mdot
.526 .26064 Mdot
.526 .26188 Mdot
.526 .26238 Mdot
.526 .26396 Mdot
.526 .26566 Mdot
.526 .26667 Mdot
.526 .26764 Mdot
.526 .26834 Mdot
.526 .26978 Mdot
.526 .2704 Mdot
.526 .27174 Mdot
.526 .27242 Mdot
.526 .27343 Mdot
.526 .27473 Mdot
.526 .27526 Mdot
.526 .27692 Mdot
.526 .2787 Mdot
.526 .27978 Mdot
.526 .28079 Mdot
.526 .28153 Mdot
.526 .28304 Mdot
.526 .2837 Mdot
.526 .28511 Mdot
.526 .28582 Mdot
.526 .28688 Mdot
.526 .28826 Mdot
.526 .2888 Mdot
.526 .29055 Mdot
.526 .29243 Mdot
.526 .29356 Mdot
.526 .29463 Mdot
.526 .2954 Mdot
.526 .297 Mdot
.526 .29768 Mdot
.526 .29917 Mdot
.526 .29991 Mdot
.526 .30104 Mdot
.526 .30248 Mdot
.526 .30306 Mdot
.526 .3049 Mdot
.526 .30687 Mdot
.526 .30806 Mdot
.526 .30919 Mdot
.526 .31 Mdot
.526 .31168 Mdot
.526 .3124 Mdot
.526 .31396 Mdot
.526 .31474 Mdot
.526 .31593 Mdot
.526 .31744 Mdot
.526 .31805 Mdot
.526 .31999 Mdot
.526 .32206 Mdot
.526 .32331 Mdot
.526 .3245 Mdot
.526 .32535 Mdot
.528 .01508 Mdot
.528 .0151 Mdot
.528 .01512 Mdot
.528 .01514 Mdot
.528 .01517 Mdot
.528 .01519 Mdot
.528 .01522 Mdot
.528 .01525 Mdot
.528 .01528 Mdot
.528 .01531 Mdot
.528 .01534 Mdot
.528 .01538 Mdot
.528 .01542 Mdot
.528 .01545 Mdot
.528 .0155 Mdot
.528 .01552 Mdot
.528 .01554 Mdot
.528 .01557 Mdot
.528 .01559 Mdot
.528 .01562 Mdot
.528 .01563 Mdot
.528 .01567 Mdot
.528 .01569 Mdot
.528 .01572 Mdot
.528 .01574 Mdot
.528 .01577 Mdot
.528 .0158 Mdot
.528 .01582 Mdot
.528 .01583 Mdot
.528 .01586 Mdot
.528 .01588 Mdot
.528 .0159 Mdot
.528 .01592 Mdot
.528 .01594 Mdot
.528 .01596 Mdot
.528 .01599 Mdot
.528 .01599 Mdot
.528 .01601 Mdot
.528 .01603 Mdot
.528 .01606 Mdot
.528 .01606 Mdot
.528 .01608 Mdot
.528 .01611 Mdot
.528 .01614 Mdot
.528 .01614 Mdot
.528 .01616 Mdot
.528 .01618 Mdot
.528 .01621 Mdot
.528 .01622 Mdot
.528 .01624 Mdot
.528 .01627 Mdot
.528 .0163 Mdot
.528 .0163 Mdot
.528 .01633 Mdot
.528 .01635 Mdot
.528 .01639 Mdot
.528 .01639 Mdot
.528 .01642 Mdot
.528 .01645 Mdot
.528 .01648 Mdot
.528 .01648 Mdot
.528 .01651 Mdot
.528 .01654 Mdot
.528 .01658 Mdot
.528 .01658 Mdot
.528 .01661 Mdot
.528 .01665 Mdot
.528 .01668 Mdot
.528 .01669 Mdot
.528 .01672 Mdot
.528 .01675 Mdot
.528 .01679 Mdot
.528 .0168 Mdot
.528 .01683 Mdot
.528 .01687 Mdot
.528 .01691 Mdot
.528 .01691 Mdot
.528 .01695 Mdot
.528 .01699 Mdot
.528 .01703 Mdot
.528 .01704 Mdot
.528 .01708 Mdot
.528 .01712 Mdot
.528 .01715 Mdot
.528 .01716 Mdot
.528 .01717 Mdot
.528 .01721 Mdot
.528 .01725 Mdot
.528 .01729 Mdot
.528 .0173 Mdot
.528 .0173 Mdot
.528 .01735 Mdot
.528 .01739 Mdot
.528 .01743 Mdot
.528 .01745 Mdot
.528 .01745 Mdot
.528 .0175 Mdot
.528 .01754 Mdot
.528 .01759 Mdot
.528 .0176 Mdot
.528 .0176 Mdot
.528 .01765 Mdot
.528 .0177 Mdot
.528 .01775 Mdot
.528 .01776 Mdot
.528 .01776 Mdot
.528 .01782 Mdot
.528 .01787 Mdot
.528 .01792 Mdot
.528 .01793 Mdot
.528 .01793 Mdot
.528 .01799 Mdot
.528 .01804 Mdot
.528 .0181 Mdot
.528 .01811 Mdot
.528 .01812 Mdot
.528 .01817 Mdot
.528 .01823 Mdot
.528 .01829 Mdot
.528 .0183 Mdot
.528 .01831 Mdot
.528 .01837 Mdot
.528 .01843 Mdot
.528 .01849 Mdot
.528 .0185 Mdot
.528 .01851 Mdot
.528 .01857 Mdot
.528 .01863 Mdot
.528 .0187 Mdot
.528 .01871 Mdot
.528 .01872 Mdot
.528 .01879 Mdot
.528 .01885 Mdot
.528 .01892 Mdot
.528 .01894 Mdot
.528 .01894 Mdot
.528 .01901 Mdot
.528 .01909 Mdot
.528 .01915 Mdot
.528 .01917 Mdot
.528 .01918 Mdot
.528 .01925 Mdot
.528 .01933 Mdot
.528 .0194 Mdot
.528 .01942 Mdot
.528 .01943 Mdot
.528 .01951 Mdot
.528 .01959 Mdot
.528 .01967 Mdot
.528 .01969 Mdot
.528 .01969 Mdot
.528 .01978 Mdot
.528 .01986 Mdot
.528 .01994 Mdot
.528 .01997 Mdot
.528 .01997 Mdot
.528 .02006 Mdot
.528 .02015 Mdot
.528 .02024 Mdot
.528 .02026 Mdot
.528 .02027 Mdot
.528 .02036 Mdot
.528 .02045 Mdot
.528 .02055 Mdot
.528 .02057 Mdot
.528 .02058 Mdot
.528 .02068 Mdot
.528 .02076 Mdot
.528 .02078 Mdot
.528 .02087 Mdot
.528 .0209 Mdot
.528 .02091 Mdot
.528 .02101 Mdot
.528 .02109 Mdot
.528 .02111 Mdot
.528 .02122 Mdot
.528 .02124 Mdot
.528 .02125 Mdot
.528 .02136 Mdot
.528 .02145 Mdot
.528 .02147 Mdot
.528 .02158 Mdot
.528 .02161 Mdot
.528 .02162 Mdot
.528 .02174 Mdot
.528 .02183 Mdot
.528 .02185 Mdot
.528 .02196 Mdot
.528 .022 Mdot
.528 .02201 Mdot
.528 .02213 Mdot
.528 .02223 Mdot
.528 .02225 Mdot
.528 .02237 Mdot
.528 .0224 Mdot
.528 .02241 Mdot
.528 .02254 Mdot
.528 .02265 Mdot
.528 .02267 Mdot
.528 .0228 Mdot
.528 .02283 Mdot
.528 .02285 Mdot
.528 .02298 Mdot
.528 .02309 Mdot
.528 .02312 Mdot
.528 .02325 Mdot
.528 .02329 Mdot
.528 .0233 Mdot
.528 .02344 Mdot
.528 .02356 Mdot
.528 .02359 Mdot
.528 .02373 Mdot
.528 .02377 Mdot
.528 .02378 Mdot
.528 .02393 Mdot
.528 .02406 Mdot
.528 .02409 Mdot
.528 .02424 Mdot
.528 .02428 Mdot
.528 .02429 Mdot
.528 .02445 Mdot
.528 .02458 Mdot
.528 .02461 Mdot
.528 .02477 Mdot
.528 .02481 Mdot
.528 .02483 Mdot
.528 .02499 Mdot
.528 .02499 Mdot
.528 .02513 Mdot
.528 .02517 Mdot
.528 .02533 Mdot
.528 .02538 Mdot
.528 .02539 Mdot
.528 .02557 Mdot
.528 .02557 Mdot
.528 .02572 Mdot
.528 .02575 Mdot
.528 .02593 Mdot
.528 .02597 Mdot
.528 .02599 Mdot
.528 .02605 Mdot
.528 .02618 Mdot
.528 .02618 Mdot
.528 .02633 Mdot
.528 .02637 Mdot
.528 .02655 Mdot
.528 .0266 Mdot
.528 .02662 Mdot
.528 .02668 Mdot
.528 .02682 Mdot
.528 .02682 Mdot
.528 .02698 Mdot
.528 .02702 Mdot
.528 .02722 Mdot
.528 .02727 Mdot
.528 .02729 Mdot
.528 .0273 Mdot
.528 .02731 Mdot
.528 .02735 Mdot
.528 .0275 Mdot
.528 .0275 Mdot
.528 .02767 Mdot
.528 .02771 Mdot
.528 .02792 Mdot
.528 .02797 Mdot
.528 .02799 Mdot
.528 .028 Mdot
.528 .02801 Mdot
.528 .02806 Mdot
.528 .02821 Mdot
.528 .02821 Mdot
.528 .02839 Mdot
.528 .02844 Mdot
.528 .02866 Mdot
.528 .02872 Mdot
.528 .02874 Mdot
.528 .02875 Mdot
.528 .02876 Mdot
.528 .02881 Mdot
.528 .02897 Mdot
.528 .02897 Mdot
.528 .02916 Mdot
.528 .02921 Mdot
.528 .02944 Mdot
.528 .0295 Mdot
.528 .02952 Mdot
.528 .02953 Mdot
.528 .02954 Mdot
.528 .0296 Mdot
.528 .02977 Mdot
.528 .02977 Mdot
.528 .02997 Mdot
.528 .03002 Mdot
.528 .03008 Mdot
.528 .03026 Mdot
.528 .03033 Mdot
.528 .03035 Mdot
.528 .03036 Mdot
.528 .03037 Mdot
.528 .03043 Mdot
.528 .03061 Mdot
.528 .03061 Mdot
.528 .03082 Mdot
.528 .03088 Mdot
.528 .03094 Mdot
.528 .03113 Mdot
.528 .03117 Mdot
.528 .0312 Mdot
.528 .03123 Mdot
.528 .03124 Mdot
.528 .03125 Mdot
.528 .03131 Mdot
.528 .0315 Mdot
.528 .0315 Mdot
.528 .03173 Mdot
.528 .03178 Mdot
.528 .03185 Mdot
.528 .03199 Mdot
.528 .03205 Mdot
.528 .03209 Mdot
.528 .03213 Mdot
.528 .03215 Mdot
.528 .03217 Mdot
.528 .03218 Mdot
.528 .03224 Mdot
.528 .03244 Mdot
.528 .03244 Mdot
.528 .03268 Mdot
.528 .03274 Mdot
.528 .03281 Mdot
.528 .03296 Mdot
.528 .03302 Mdot
.528 .03307 Mdot
.528 .0331 Mdot
.528 .03313 Mdot
.528 .03314 Mdot
.528 .03315 Mdot
.528 .03322 Mdot
.528 .03343 Mdot
.528 .03343 Mdot
.528 .03368 Mdot
.528 .03375 Mdot
.528 .03382 Mdot
.528 .03398 Mdot
.528 .03405 Mdot
.528 .0341 Mdot
.528 .03413 Mdot
.528 .03416 Mdot
.528 .03418 Mdot
.528 .03419 Mdot
.528 .03426 Mdot
.528 .03448 Mdot
.528 .03448 Mdot
.528 .03475 Mdot
.528 .03481 Mdot
.528 .03489 Mdot
.528 .03506 Mdot
.528 .03513 Mdot
.528 .03518 Mdot
.528 .03522 Mdot
.528 .03525 Mdot
.528 .03527 Mdot
.528 .03528 Mdot
.528 .03535 Mdot
.528 .03559 Mdot
.528 .03587 Mdot
.528 .03594 Mdot
.528 .03602 Mdot
.528 .0362 Mdot
.528 .03627 Mdot
.528 .03633 Mdot
.528 .03637 Mdot
.528 .0364 Mdot
.528 .03642 Mdot
.528 .03643 Mdot
.528 .03651 Mdot
.528 .03676 Mdot
.528 .03705 Mdot
.528 .03712 Mdot
.528 .03721 Mdot
.528 .0374 Mdot
.528 .03748 Mdot
.528 .03754 Mdot
.528 .03758 Mdot
.528 .03761 Mdot
.528 .03763 Mdot
.528 .03764 Mdot
.528 .03773 Mdot
.528 .03799 Mdot
.528 .0383 Mdot
.528 .03838 Mdot
.528 .03847 Mdot
.528 .03867 Mdot
.528 .03875 Mdot
.528 .03881 Mdot
.528 .03886 Mdot
.528 .03889 Mdot
.528 .03891 Mdot
.528 .03893 Mdot
.528 .03902 Mdot
.528 .0393 Mdot
.528 .03962 Mdot
.528 .03971 Mdot
.528 .0398 Mdot
.528 .04002 Mdot
.528 .0401 Mdot
.528 .04016 Mdot
.528 .04021 Mdot
.528 .04025 Mdot
.528 .04027 Mdot
.528 .04028 Mdot
.528 .04038 Mdot
.528 .04067 Mdot
.528 .04102 Mdot
.528 .0411 Mdot
.528 .04121 Mdot
.528 .04143 Mdot
.528 .04152 Mdot
.528 .04159 Mdot
.528 .04164 Mdot
.528 .04168 Mdot
.528 .0417 Mdot
.528 .04172 Mdot
.528 .04182 Mdot
.528 .04213 Mdot
.528 .04249 Mdot
.528 .04258 Mdot
.528 .04269 Mdot
.528 .04293 Mdot
.528 .04302 Mdot
.528 .04309 Mdot
.528 .04315 Mdot
.528 .04319 Mdot
.528 .04321 Mdot
.528 .04323 Mdot
.528 .04333 Mdot
.528 .04366 Mdot
.528 .04405 Mdot
.528 .04414 Mdot
.528 .04426 Mdot
.528 .04451 Mdot
.528 .04461 Mdot
.528 .04468 Mdot
.528 .04474 Mdot
.528 .04478 Mdot
.528 .04481 Mdot
.528 .04482 Mdot
.528 .04494 Mdot
.528 .04528 Mdot
.528 .04569 Mdot
.528 .04579 Mdot
.528 .04591 Mdot
.528 .04618 Mdot
.528 .04628 Mdot
.528 .04636 Mdot
.528 .04642 Mdot
.528 .04646 Mdot
.528 .04649 Mdot
.528 .04651 Mdot
.528 .04663 Mdot
.528 .04699 Mdot
.528 .04742 Mdot
.528 .04753 Mdot
.528 .04766 Mdot
.528 .04766 Mdot
.528 .04794 Mdot
.528 .04805 Mdot
.528 .04813 Mdot
.528 .04819 Mdot
.528 .04824 Mdot
.528 .04827 Mdot
.528 .04829 Mdot
.528 .04842 Mdot
.528 .0488 Mdot
.528 .04926 Mdot
.528 .04937 Mdot
.528 .0495 Mdot
.528 .0495 Mdot
.528 .0498 Mdot
.528 .04992 Mdot
.528 .05001 Mdot
.528 .05007 Mdot
.528 .05012 Mdot
.528 .05015 Mdot
.528 .05017 Mdot
.528 .0503 Mdot
.528 .05071 Mdot
.528 .05119 Mdot
.528 .05131 Mdot
.528 .05145 Mdot
.528 .05145 Mdot
.528 .05177 Mdot
.528 .05189 Mdot
.528 .05198 Mdot
.528 .05205 Mdot
.528 .0521 Mdot
.528 .05214 Mdot
.528 .05216 Mdot
.528 .0523 Mdot
.528 .05273 Mdot
.528 .05323 Mdot
.528 .05336 Mdot
.528 .05351 Mdot
.528 .05351 Mdot
.528 .05384 Mdot
.528 .05397 Mdot
.528 .05407 Mdot
.528 .05414 Mdot
.528 .0542 Mdot
.528 .05423 Mdot
.528 .05425 Mdot
.528 .0544 Mdot
.528 .05486 Mdot
.528 .05539 Mdot
.528 .05552 Mdot
.528 .05568 Mdot
.528 .05568 Mdot
.528 .05603 Mdot
.528 .05617 Mdot
.528 .05627 Mdot
.528 .05635 Mdot
.528 .05641 Mdot
.528 .05645 Mdot
.528 .05647 Mdot
.528 .05662 Mdot
.528 .0571 Mdot
.528 .05767 Mdot
.528 .05781 Mdot
.528 .05797 Mdot
.528 .05798 Mdot
.528 .05834 Mdot
.528 .05849 Mdot
.528 .0586 Mdot
.528 .05868 Mdot
.528 .05874 Mdot
.528 .05878 Mdot
.528 .05881 Mdot
.528 .05897 Mdot
.528 .05948 Mdot
.528 .06007 Mdot
.528 .06022 Mdot
.528 .0604 Mdot
.528 .0604 Mdot
.528 .06079 Mdot
.528 .06094 Mdot
.528 .06106 Mdot
.528 .06114 Mdot
.528 .06121 Mdot
.528 .06125 Mdot
.528 .06128 Mdot
.528 .06145 Mdot
.528 .06198 Mdot
.528 .06261 Mdot
.528 .06277 Mdot
.528 .06296 Mdot
.528 .06296 Mdot
.528 .06337 Mdot
.528 .06353 Mdot
.528 .06365 Mdot
.528 .06374 Mdot
.528 .06381 Mdot
.528 .06386 Mdot
.528 .06388 Mdot
.528 .06407 Mdot
.528 .06463 Mdot
.528 .0653 Mdot
.528 .06546 Mdot
.528 .06566 Mdot
.528 .06566 Mdot
.528 .06609 Mdot
.528 .06626 Mdot
.528 .06639 Mdot
.528 .06649 Mdot
.528 .06656 Mdot
.528 .06661 Mdot
.528 .06664 Mdot
.528 .06683 Mdot
.528 .06743 Mdot
.528 .06813 Mdot
.528 .0683 Mdot
.528 .06851 Mdot
.528 .06851 Mdot
.528 .06897 Mdot
.528 .06915 Mdot
.528 .06929 Mdot
.528 .06938 Mdot
.528 .06946 Mdot
.528 .06951 Mdot
.528 .06954 Mdot
.528 .06975 Mdot
.528 .07038 Mdot
.528 .07112 Mdot
.528 .0713 Mdot
.528 .07152 Mdot
.528 .07152 Mdot
.528 .07201 Mdot
.528 .0722 Mdot
.528 .07234 Mdot
.528 .07245 Mdot
.528 .07253 Mdot
.528 .07258 Mdot
.528 .07261 Mdot
.528 .07283 Mdot
.528 .07349 Mdot
.528 .07428 Mdot
.528 .07447 Mdot
.528 .0747 Mdot
.528 .0747 Mdot
.528 .07522 Mdot
.528 .07542 Mdot
.528 .07557 Mdot
.528 .07568 Mdot
.528 .07577 Mdot
.528 .07582 Mdot
.528 .07586 Mdot
.528 .07608 Mdot
.528 .07679 Mdot
.528 .07761 Mdot
.528 .07782 Mdot
.528 .07806 Mdot
.528 .07806 Mdot
.528 .0786 Mdot
.528 .07882 Mdot
.528 .07898 Mdot
.528 .07909 Mdot
.528 .07918 Mdot
.528 .07925 Mdot
.528 .07928 Mdot
.528 .07952 Mdot
.528 .08026 Mdot
.528 .08114 Mdot
.528 .08135 Mdot
.528 .08161 Mdot
.528 .08161 Mdot
.528 .08218 Mdot
.528 .08241 Mdot
.528 .08258 Mdot
.528 .0827 Mdot
.528 .08279 Mdot
.528 .08286 Mdot
.528 .0829 Mdot
.528 .08315 Mdot
.528 .08393 Mdot
.528 .08485 Mdot
.528 .08508 Mdot
.528 .08536 Mdot
.528 .08536 Mdot
.528 .08596 Mdot
.528 .0862 Mdot
.528 .08638 Mdot
.528 .08651 Mdot
.528 .08661 Mdot
.528 .08667 Mdot
.528 .08671 Mdot
.528 .08698 Mdot
.528 .08781 Mdot
.528 .08878 Mdot
.528 .08902 Mdot
.528 .08931 Mdot
.528 .08931 Mdot
.528 .08995 Mdot
.528 .0902 Mdot
.528 .09039 Mdot
.528 .09053 Mdot
.528 .09063 Mdot
.528 .0907 Mdot
.528 .09075 Mdot
.528 .09103 Mdot
.528 .0919 Mdot
.528 .09293 Mdot
.528 .09319 Mdot
.528 .09349 Mdot
.528 .09349 Mdot
.528 .09416 Mdot
.528 .09443 Mdot
.528 .09463 Mdot
.528 .09477 Mdot
.528 .09488 Mdot
.528 .09496 Mdot
.528 .095 Mdot
.528 .0953 Mdot
.528 .09623 Mdot
.528 .09731 Mdot
.528 .09758 Mdot
.528 .0979 Mdot
.528 .0979 Mdot
.528 .09861 Mdot
.528 .09889 Mdot
.528 .0991 Mdot
.528 .09925 Mdot
.528 .09937 Mdot
.528 .09945 Mdot
.528 .0995 Mdot
.528 .09982 Mdot
.528 .10079 Mdot
.528 .10194 Mdot
.528 .10222 Mdot
.528 .10256 Mdot
.528 .10256 Mdot
.528 .10331 Mdot
.528 .10361 Mdot
.528 .10383 Mdot
.528 .10399 Mdot
.528 .10412 Mdot
.528 .1042 Mdot
.528 .10425 Mdot
.528 .10458 Mdot
.528 .10561 Mdot
.528 .10682 Mdot
.528 .10712 Mdot
.528 .10748 Mdot
.528 .10748 Mdot
.528 .10827 Mdot
.528 .10858 Mdot
.528 .10882 Mdot
.528 .10899 Mdot
.528 .10912 Mdot
.528 .10921 Mdot
.528 .10926 Mdot
.528 .10961 Mdot
.528 .1107 Mdot
.528 .11198 Mdot
.528 .1123 Mdot
.528 .11267 Mdot
.528 .11268 Mdot
.528 .11351 Mdot
.528 .11384 Mdot
.528 .11409 Mdot
.528 .11427 Mdot
.528 .11441 Mdot
.528 .1145 Mdot
.528 .11456 Mdot
.528 .11493 Mdot
.528 .11608 Mdot
.528 .11742 Mdot
.528 .11776 Mdot
.528 .11816 Mdot
.528 .11816 Mdot
.528 .11904 Mdot
.528 .11939 Mdot
.528 .11965 Mdot
.528 .11984 Mdot
.528 .11999 Mdot
.528 .12009 Mdot
.528 .12015 Mdot
.528 .12054 Mdot
.528 .12175 Mdot
.528 .12318 Mdot
.528 .12353 Mdot
.528 .12395 Mdot
.528 .12395 Mdot
.528 .12489 Mdot
.528 .12525 Mdot
.528 .12553 Mdot
.528 .12573 Mdot
.528 .12589 Mdot
.528 .12599 Mdot
.528 .12605 Mdot
.528 .12647 Mdot
.528 .12775 Mdot
.528 .12925 Mdot
.528 .12963 Mdot
.528 .13007 Mdot
.528 .13007 Mdot
.528 .13106 Mdot
.528 .13144 Mdot
.528 .13174 Mdot
.528 .13195 Mdot
.528 .13211 Mdot
.528 .13222 Mdot
.528 .13229 Mdot
.528 .13272 Mdot
.528 .13408 Mdot
.528 .13566 Mdot
.528 .13606 Mdot
.528 .13653 Mdot
.528 .13653 Mdot
.528 .13757 Mdot
.528 .13798 Mdot
.528 .13829 Mdot
.528 .13851 Mdot
.528 .13869 Mdot
.528 .1388 Mdot
.528 .13887 Mdot
.528 .13933 Mdot
.528 .14076 Mdot
.528 .14244 Mdot
.528 .14286 Mdot
.528 .14335 Mdot
.528 .14335 Mdot
.528 .14445 Mdot
.528 .14488 Mdot
.528 .14521 Mdot
.528 .14544 Mdot
.528 .14563 Mdot
.528 .14575 Mdot
.528 .14582 Mdot
.528 .14631 Mdot
.528 .14782 Mdot
.528 .14959 Mdot
.528 .15003 Mdot
.528 .15055 Mdot
.528 .15056 Mdot
.528 .15172 Mdot
.528 .15217 Mdot
.528 .15252 Mdot
.528 .15276 Mdot
.528 .15296 Mdot
.528 .15309 Mdot
.528 .15317 Mdot
.528 .15368 Mdot
.528 .15527 Mdot
.528 .15714 Mdot
.528 .15761 Mdot
.528 .15816 Mdot
.528 .15816 Mdot
.528 .15939 Mdot
.528 .15987 Mdot
.528 .16023 Mdot
.528 .1605 Mdot
.528 .1607 Mdot
.528 .16084 Mdot
.528 .16092 Mdot
.528 .16146 Mdot
.528 .16314 Mdot
.528 .16512 Mdot
.528 .16561 Mdot
.528 .16619 Mdot
.528 .1662 Mdot
.528 .16749 Mdot
.528 .168 Mdot
.528 .16838 Mdot
.528 .16866 Mdot
.528 .16888 Mdot
.528 .16902 Mdot
.528 .16911 Mdot
.528 .16968 Mdot
.528 .17145 Mdot
.528 .17354 Mdot
.528 .17406 Mdot
.528 .17468 Mdot
.528 .17468 Mdot
.528 .17605 Mdot
.528 .17658 Mdot
.528 .17699 Mdot
.528 .17728 Mdot
.528 .17751 Mdot
.528 .17766 Mdot
.528 .17775 Mdot
.528 .17836 Mdot
.528 .18023 Mdot
.528 .18244 Mdot
.528 .18298 Mdot
.528 .18364 Mdot
.528 .18364 Mdot
.528 .18508 Mdot
.528 .18565 Mdot
.528 .18608 Mdot
.528 .18638 Mdot
.528 .18663 Mdot
.528 .18679 Mdot
.528 .18688 Mdot
.528 .18752 Mdot
.528 .1895 Mdot
.528 .19183 Mdot
.528 .19241 Mdot
.528 .19309 Mdot
.528 .1931 Mdot
.528 .19462 Mdot
.528 .19522 Mdot
.528 .19567 Mdot
.528 .196 Mdot
.528 .19625 Mdot
.528 .19642 Mdot
.528 .19652 Mdot
.528 .1972 Mdot
.528 .19929 Mdot
.528 .20175 Mdot
.528 .20236 Mdot
.528 .20308 Mdot
.528 .20309 Mdot
.528 .20469 Mdot
.528 .20533 Mdot
.528 .20581 Mdot
.528 .20615 Mdot
.528 .20642 Mdot
.528 .2066 Mdot
.528 .20671 Mdot
.528 .20742 Mdot
.528 .20963 Mdot
.528 .21222 Mdot
.528 .21287 Mdot
.528 .21363 Mdot
.528 .21364 Mdot
.528 .21533 Mdot
.528 .216 Mdot
.528 .21651 Mdot
.528 .21687 Mdot
.528 .21716 Mdot
.528 .21735 Mdot
.528 .21746 Mdot
.528 .21821 Mdot
.528 .22054 Mdot
.528 .22328 Mdot
.528 .22396 Mdot
.528 .22477 Mdot
.528 .22478 Mdot
.528 .22657 Mdot
.528 .22728 Mdot
.528 .22781 Mdot
.528 .22819 Mdot
.528 .22849 Mdot
.528 .22869 Mdot
.528 .22881 Mdot
.528 .22961 Mdot
.528 .23207 Mdot
.528 .23496 Mdot
.528 .23568 Mdot
.528 .23654 Mdot
.528 .23654 Mdot
.528 .23843 Mdot
.528 .23918 Mdot
.528 .23974 Mdot
.528 .24014 Mdot
.528 .24046 Mdot
.528 .24068 Mdot
.528 .2408 Mdot
.528 .24164 Mdot
.528 .24424 Mdot
.528 .24729 Mdot
.528 .24805 Mdot
.528 .24896 Mdot
.528 .24896 Mdot
.528 .25096 Mdot
.528 .25175 Mdot
.528 .25234 Mdot
.528 .25277 Mdot
.528 .25311 Mdot
.528 .25333 Mdot
.528 .25346 Mdot
.528 .25435 Mdot
.528 .25709 Mdot
.528 .26032 Mdot
.528 .26112 Mdot
.528 .26207 Mdot
.528 .26208 Mdot
.528 .26419 Mdot
.528 .26502 Mdot
.528 .26565 Mdot
.528 .2661 Mdot
.528 .26646 Mdot
.528 .26669 Mdot
.528 .26683 Mdot
.528 .26777 Mdot
.528 .27066 Mdot
.528 .27407 Mdot
.528 .27492 Mdot
.528 .27593 Mdot
.528 .27593 Mdot
.528 .27816 Mdot
.528 .27904 Mdot
.528 .2797 Mdot
.528 .28018 Mdot
.528 .28055 Mdot
.528 .2808 Mdot
.528 .28095 Mdot
.528 .28194 Mdot
.528 .285 Mdot
.528 .2886 Mdot
.528 .28949 Mdot
.528 .29055 Mdot
.528 .29056 Mdot
.528 .29291 Mdot
.528 .29384 Mdot
.528 .29454 Mdot
.528 .29504 Mdot
.528 .29544 Mdot
.528 .2957 Mdot
.528 .29586 Mdot
.528 .2969 Mdot
.528 .30013 Mdot
.528 .30393 Mdot
.528 .30488 Mdot
.528 .306 Mdot
.528 .30601 Mdot
.528 .30849 Mdot
.528 .30947 Mdot
.528 .31021 Mdot
.528 .31074 Mdot
.528 .31116 Mdot
.528 .31144 Mdot
.528 .3116 Mdot
.528 .3127 Mdot
.528 .31612 Mdot
.528 .32013 Mdot
.528 .32113 Mdot
.528 .32231 Mdot
.528 .32232 Mdot
.528 .32494 Mdot
.528 .32598 Mdot
.528 .32676 Mdot
.53 .01499 Mdot
.53 .01501 Mdot
.53 .01503 Mdot
.53 .01505 Mdot
.53 .01506 Mdot
.53 .01509 Mdot
.53 .01511 Mdot
.53 .01512 Mdot
.53 .01513 Mdot
.53 .01515 Mdot
.53 .01516 Mdot
.53 .01517 Mdot
.53 .01518 Mdot
.53 .0152 Mdot
.53 .01521 Mdot
.53 .01523 Mdot
.53 .01524 Mdot
.53 .01526 Mdot
.53 .01527 Mdot
.53 .0153 Mdot
.53 .01531 Mdot
.53 .01533 Mdot
.53 .01534 Mdot
.53 .01537 Mdot
.53 .01538 Mdot
.53 .01541 Mdot
.53 .01542 Mdot
.53 .01545 Mdot
.53 .01546 Mdot
.53 .01549 Mdot
.53 .01551 Mdot
.53 .01554 Mdot
.53 .01555 Mdot
.53 .01559 Mdot
.53 .0156 Mdot
.53 .01564 Mdot
.53 .01566 Mdot
.53 .0157 Mdot
.53 .01571 Mdot
.53 .01575 Mdot
.53 .01577 Mdot
.53 .01582 Mdot
.53 .01584 Mdot
.53 .01588 Mdot
.53 .0159 Mdot
.53 .01595 Mdot
.53 .01598 Mdot
.53 .01603 Mdot
.53 .01605 Mdot
.53 .01611 Mdot
.53 .01613 Mdot
.53 .01619 Mdot
.53 .01622 Mdot
.53 .01628 Mdot
.53 .01631 Mdot
.53 .01637 Mdot
.53 .0164 Mdot
.53 .01647 Mdot
.53 .0165 Mdot
.53 .01658 Mdot
.53 .01661 Mdot
.53 .01669 Mdot
.53 .01672 Mdot
.53 .01681 Mdot
.53 .01684 Mdot
.53 .01693 Mdot
.53 .01697 Mdot
.53 .01706 Mdot
.53 .01711 Mdot
.53 .0172 Mdot
.53 .01725 Mdot
.53 .01735 Mdot
.53 .0174 Mdot
.53 .01751 Mdot
.53 .01756 Mdot
.53 .01768 Mdot
.53 .01774 Mdot
.53 .01786 Mdot
.53 .01792 Mdot
.53 .01805 Mdot
.53 .01811 Mdot
.53 .01825 Mdot
.53 .01831 Mdot
.53 .01846 Mdot
.53 .01853 Mdot
.53 .01868 Mdot
.53 .01876 Mdot
.53 .01887 Mdot
.53 .01892 Mdot
.53 .019 Mdot
.53 .01912 Mdot
.53 .01917 Mdot
.53 .01926 Mdot
.53 .01934 Mdot
.53 .01938 Mdot
.53 .01944 Mdot
.53 .01953 Mdot
.53 .01962 Mdot
.53 .01966 Mdot
.53 .01972 Mdot
.53 .01982 Mdot
.53 .01985 Mdot
.53 .01991 Mdot
.53 .01996 Mdot
.53 .02003 Mdot
.53 .02012 Mdot
.53 .02015 Mdot
.53 .02023 Mdot
.53 .02027 Mdot
.53 .02034 Mdot
.53 .02045 Mdot
.53 .02048 Mdot
.53 .02056 Mdot
.53 .02061 Mdot
.53 .02068 Mdot
.53 .02079 Mdot
.53 .02083 Mdot
.53 .02083 Mdot
.53 .02091 Mdot
.53 .02096 Mdot
.53 .02104 Mdot
.53 .02116 Mdot
.53 .02119 Mdot
.53 .02119 Mdot
.53 .02128 Mdot
.53 .02133 Mdot
.53 .02142 Mdot
.53 .02154 Mdot
.53 .02158 Mdot
.53 .02158 Mdot
.53 .02167 Mdot
.53 .02173 Mdot
.53 .02182 Mdot
.53 .02195 Mdot
.53 .02199 Mdot
.53 .02199 Mdot
.53 .02209 Mdot
.53 .02215 Mdot
.53 .02225 Mdot
.53 .02239 Mdot
.53 .02243 Mdot
.53 .02243 Mdot
.53 .02253 Mdot
.53 .02255 Mdot
.53 .0226 Mdot
.53 .02264 Mdot
.53 .0227 Mdot
.53 .02285 Mdot
.53 .02289 Mdot
.53 .02289 Mdot
.53 .023 Mdot
.53 .02302 Mdot
.53 .02307 Mdot
.53 .02312 Mdot
.53 .02318 Mdot
.53 .02334 Mdot
.53 .02338 Mdot
.53 .02339 Mdot
.53 .0235 Mdot
.53 .02352 Mdot
.53 .02357 Mdot
.53 .02362 Mdot
.53 .02369 Mdot
.53 .02385 Mdot
.53 .0239 Mdot
.53 .02391 Mdot
.53 .02403 Mdot
.53 .02405 Mdot
.53 .0241 Mdot
.53 .02416 Mdot
.53 .02422 Mdot
.53 .0244 Mdot
.53 .02445 Mdot
.53 .02446 Mdot
.53 .02459 Mdot
.53 .02461 Mdot
.53 .02467 Mdot
.53 .02472 Mdot
.53 .0248 Mdot
.53 .02498 Mdot
.53 .02504 Mdot
.53 .02504 Mdot
.53 .02518 Mdot
.53 .0252 Mdot
.53 .02526 Mdot
.53 .02533 Mdot
.53 .0254 Mdot
.53 .0256 Mdot
.53 .02566 Mdot
.53 .02566 Mdot
.53 .02581 Mdot
.53 .02583 Mdot
.53 .0259 Mdot
.53 .02596 Mdot
.53 .02604 Mdot
.53 .02618 Mdot
.53 .02625 Mdot
.53 .02631 Mdot
.53 .02632 Mdot
.53 .02647 Mdot
.53 .0265 Mdot
.53 .02657 Mdot
.53 .02664 Mdot
.53 .02672 Mdot
.53 .02687 Mdot
.53 .02691 Mdot
.53 .02694 Mdot
.53 .02701 Mdot
.53 .02701 Mdot
.53 .02718 Mdot
.53 .0272 Mdot
.53 .02728 Mdot
.53 .02735 Mdot
.53 .02744 Mdot
.53 .0276 Mdot
.53 .02762 Mdot
.53 .02764 Mdot
.53 .02768 Mdot
.53 .02775 Mdot
.53 .02775 Mdot
.53 .02792 Mdot
.53 .02795 Mdot
.53 .02803 Mdot
.53 .02811 Mdot
.53 .0282 Mdot
.53 .02837 Mdot
.53 .02839 Mdot
.53 .02841 Mdot
.53 .02846 Mdot
.53 .02853 Mdot
.53 .02853 Mdot
.53 .02869 Mdot
.53 .02872 Mdot
.53 .02875 Mdot
.53 .02883 Mdot
.53 .02891 Mdot
.53 .02901 Mdot
.53 .02919 Mdot
.53 .02921 Mdot
.53 .02924 Mdot
.53 .02928 Mdot
.53 .02936 Mdot
.53 .02936 Mdot
.53 .02952 Mdot
.53 .02956 Mdot
.53 .02957 Mdot
.53 .02959 Mdot
.53 .02968 Mdot
.53 .02977 Mdot
.53 .02987 Mdot
.53 .03006 Mdot
.53 .03008 Mdot
.53 .03011 Mdot
.53 .03015 Mdot
.53 .03024 Mdot
.53 .03024 Mdot
.53 .03041 Mdot
.53 .03045 Mdot
.53 .03046 Mdot
.53 .03048 Mdot
.53 .03058 Mdot
.53 .03067 Mdot
.53 .03078 Mdot
.53 .03098 Mdot
.53 .031 Mdot
.53 .03103 Mdot
.53 .03108 Mdot
.53 .03117 Mdot
.53 .03117 Mdot
.53 .03135 Mdot
.53 .03139 Mdot
.53 .03141 Mdot
.53 .03143 Mdot
.53 .03148 Mdot
.53 .03153 Mdot
.53 .03163 Mdot
.53 .03175 Mdot
.53 .03196 Mdot
.53 .03198 Mdot
.53 .03201 Mdot
.53 .03206 Mdot
.53 .03216 Mdot
.53 .03216 Mdot
.53 .03235 Mdot
.53 .03239 Mdot
.53 .03241 Mdot
.53 .03243 Mdot
.53 .03249 Mdot
.53 .03254 Mdot
.53 .03264 Mdot
.53 .03277 Mdot
.53 .03299 Mdot
.53 .03302 Mdot
.53 .03305 Mdot
.53 .0331 Mdot
.53 .0332 Mdot
.53 .03321 Mdot
.53 .03341 Mdot
.53 .03345 Mdot
.53 .03347 Mdot
.53 .03349 Mdot
.53 .03356 Mdot
.53 .03361 Mdot
.53 .03372 Mdot
.53 .03385 Mdot
.53 .03409 Mdot
.53 .03412 Mdot
.53 .03415 Mdot
.53 .03421 Mdot
.53 .03431 Mdot
.53 .03432 Mdot
.53 .03453 Mdot
.53 .03458 Mdot
.53 .0346 Mdot
.53 .03462 Mdot
.53 .03469 Mdot
.53 .03474 Mdot
.53 .03486 Mdot
.53 .035 Mdot
.53 .03525 Mdot
.53 .03528 Mdot
.53 .03531 Mdot
.53 .03538 Mdot
.53 .03549 Mdot
.53 .03549 Mdot
.53 .03572 Mdot
.53 .03577 Mdot
.53 .03579 Mdot
.53 .03581 Mdot
.53 .03588 Mdot
.53 .03594 Mdot
.53 .03606 Mdot
.53 .03622 Mdot
.53 .03622 Mdot
.53 .03648 Mdot
.53 .03651 Mdot
.53 .03655 Mdot
.53 .03662 Mdot
.53 .03673 Mdot
.53 .03674 Mdot
.53 .03698 Mdot
.53 .03703 Mdot
.53 .03705 Mdot
.53 .03708 Mdot
.53 .03715 Mdot
.53 .03721 Mdot
.53 .03735 Mdot
.53 .03751 Mdot
.53 .03751 Mdot
.53 .03779 Mdot
.53 .03782 Mdot
.53 .03786 Mdot
.53 .03793 Mdot
.53 .03805 Mdot
.53 .03806 Mdot
.53 .03832 Mdot
.53 .03837 Mdot
.53 .03839 Mdot
.53 .03842 Mdot
.53 .0385 Mdot
.53 .03856 Mdot
.53 .0387 Mdot
.53 .03887 Mdot
.53 .03888 Mdot
.53 .03917 Mdot
.53 .03921 Mdot
.53 .03925 Mdot
.53 .03932 Mdot
.53 .03945 Mdot
.53 .03946 Mdot
.53 .03973 Mdot
.53 .03979 Mdot
.53 .03981 Mdot
.53 .03985 Mdot
.53 .03993 Mdot
.53 .04 Mdot
.53 .04014 Mdot
.53 .04032 Mdot
.53 .04033 Mdot
.53 .04064 Mdot
.53 .04068 Mdot
.53 .04072 Mdot
.53 .0408 Mdot
.53 .04094 Mdot
.53 .04095 Mdot
.53 .04124 Mdot
.53 .04129 Mdot
.53 .04132 Mdot
.53 .04135 Mdot
.53 .04144 Mdot
.53 .04151 Mdot
.53 .04167 Mdot
.53 .04186 Mdot
.53 .04187 Mdot
.53 .04219 Mdot
.53 .04224 Mdot
.53 .04228 Mdot
.53 .04236 Mdot
.53 .04251 Mdot
.53 .04252 Mdot
.53 .04283 Mdot
.53 .04289 Mdot
.53 .04292 Mdot
.53 .04295 Mdot
.53 .04304 Mdot
.53 .04312 Mdot
.53 .04329 Mdot
.53 .04349 Mdot
.53 .0435 Mdot
.53 .04384 Mdot
.53 .04389 Mdot
.53 .04393 Mdot
.53 .04402 Mdot
.53 .04418 Mdot
.53 .04419 Mdot
.53 .04451 Mdot
.53 .04458 Mdot
.53 .04461 Mdot
.53 .04465 Mdot
.53 .04474 Mdot
.53 .04482 Mdot
.53 .045 Mdot
.53 .04521 Mdot
.53 .04523 Mdot
.53 .04559 Mdot
.53 .04564 Mdot
.53 .04569 Mdot
.53 .04578 Mdot
.53 .04595 Mdot
.53 .04596 Mdot
.53 .0463 Mdot
.53 .04637 Mdot
.53 .0464 Mdot
.53 .04644 Mdot
.53 .04654 Mdot
.53 .04663 Mdot
.53 .04682 Mdot
.53 .04704 Mdot
.53 .04706 Mdot
.53 .04744 Mdot
.53 .04749 Mdot
.53 .04754 Mdot
.53 .04764 Mdot
.53 .04782 Mdot
.53 .04783 Mdot
.53 .0482 Mdot
.53 .04827 Mdot
.53 .0483 Mdot
.53 .04834 Mdot
.53 .04845 Mdot
.53 .04855 Mdot
.53 .04874 Mdot
.53 .04898 Mdot
.53 .049 Mdot
.53 .04941 Mdot
.53 .04946 Mdot
.53 .04951 Mdot
.53 .04962 Mdot
.53 .04981 Mdot
.53 .04982 Mdot
.53 .05021 Mdot
.53 .05028 Mdot
.53 .05032 Mdot
.53 .05036 Mdot
.53 .05048 Mdot
.53 .05058 Mdot
.53 .05078 Mdot
.53 .05104 Mdot
.53 .05105 Mdot
.53 .05149 Mdot
.53 .05154 Mdot
.53 .0516 Mdot
.53 .05171 Mdot
.53 .05191 Mdot
.53 .05193 Mdot
.53 .05233 Mdot
.53 .05242 Mdot
.53 .05245 Mdot
.53 .0525 Mdot
.53 .05262 Mdot
.53 .05273 Mdot
.53 .05295 Mdot
.53 .05322 Mdot
.53 .05323 Mdot
.53 .05369 Mdot
.53 .05375 Mdot
.53 .05381 Mdot
.53 .05393 Mdot
.53 .05415 Mdot
.53 .05416 Mdot
.53 .05459 Mdot
.53 .05468 Mdot
.53 .05472 Mdot
.53 .05477 Mdot
.53 .0549 Mdot
.53 .05501 Mdot
.53 .05524 Mdot
.53 .05553 Mdot
.53 .05555 Mdot
.53 .05603 Mdot
.53 .0561 Mdot
.53 .05616 Mdot
.53 .05629 Mdot
.53 .05651 Mdot
.53 .05652 Mdot
.53 .05698 Mdot
.53 .05708 Mdot
.53 .05712 Mdot
.53 .05717 Mdot
.53 .05731 Mdot
.53 .05743 Mdot
.53 .05767 Mdot
.53 .05798 Mdot
.53 .058 Mdot
.53 .05851 Mdot
.53 .05858 Mdot
.53 .05865 Mdot
.53 .05878 Mdot
.53 .05902 Mdot
.53 .05903 Mdot
.53 .05952 Mdot
.53 .05962 Mdot
.53 .05966 Mdot
.53 .05972 Mdot
.53 .05987 Mdot
.53 .05999 Mdot
.53 .06025 Mdot
.53 .06057 Mdot
.53 .06059 Mdot
.53 .06114 Mdot
.53 .06121 Mdot
.53 .06128 Mdot
.53 .06143 Mdot
.53 .06168 Mdot
.53 .06169 Mdot
.53 .06221 Mdot
.53 .06232 Mdot
.53 .06236 Mdot
.53 .06242 Mdot
.53 .06258 Mdot
.53 .0627 Mdot
.53 .06298 Mdot
.53 .06333 Mdot
.53 .06335 Mdot
.53 .06393 Mdot
.53 .064 Mdot
.53 .06408 Mdot
.53 .06423 Mdot
.53 .0645 Mdot
.53 .06451 Mdot
.53 .06506 Mdot
.53 .06517 Mdot
.53 .06522 Mdot
.53 .06528 Mdot
.53 .06545 Mdot
.53 .06558 Mdot
.53 .06588 Mdot
.53 .06624 Mdot
.53 .06626 Mdot
.53 .06688 Mdot
.53 .06696 Mdot
.53 .06704 Mdot
.53 .0672 Mdot
.53 .06748 Mdot
.53 .0675 Mdot
.53 .06808 Mdot
.53 .0682 Mdot
.53 .06825 Mdot
.53 .06832 Mdot
.53 .06849 Mdot
.53 .06864 Mdot
.53 .06895 Mdot
.53 .06933 Mdot
.53 .06936 Mdot
.53 .07001 Mdot
.53 .07009 Mdot
.53 .07018 Mdot
.53 .07035 Mdot
.53 .07065 Mdot
.53 .07067 Mdot
.53 .07128 Mdot
.53 .07141 Mdot
.53 .07146 Mdot
.53 .07153 Mdot
.53 .07172 Mdot
.53 .07187 Mdot
.53 .0722 Mdot
.53 .07261 Mdot
.53 .07263 Mdot
.53 .07333 Mdot
.53 .07341 Mdot
.53 .07351 Mdot
.53 .07369 Mdot
.53 .07401 Mdot
.53 .07402 Mdot
.53 .07468 Mdot
.53 .07481 Mdot
.53 .07487 Mdot
.53 .07494 Mdot
.53 .07514 Mdot
.53 .0753 Mdot
.53 .07565 Mdot
.53 .07608 Mdot
.53 .07611 Mdot
.53 .07684 Mdot
.53 .07694 Mdot
.53 .07703 Mdot
.53 .07723 Mdot
.53 .07756 Mdot
.53 .07758 Mdot
.53 .07827 Mdot
.53 .07841 Mdot
.53 .07847 Mdot
.53 .07855 Mdot
.53 .07876 Mdot
.53 .07894 Mdot
.53 .07931 Mdot
.53 .07977 Mdot
.53 .07979 Mdot
.53 .08057 Mdot
.53 .08067 Mdot
.53 .08077 Mdot
.53 .08098 Mdot
.53 .08133 Mdot
.53 .08135 Mdot
.53 .08209 Mdot
.53 .08224 Mdot
.53 .0823 Mdot
.53 .08238 Mdot
.53 .08261 Mdot
.53 .08279 Mdot
.53 .08319 Mdot
.53 .08367 Mdot
.53 .0837 Mdot
.53 .08452 Mdot
.53 .08463 Mdot
.53 .08474 Mdot
.53 .08495 Mdot
.53 .08533 Mdot
.53 .08535 Mdot
.53 .08613 Mdot
.53 .08629 Mdot
.53 .08635 Mdot
.53 .08644 Mdot
.53 .08668 Mdot
.53 .08687 Mdot
.53 .08729 Mdot
.53 .08781 Mdot
.53 .08784 Mdot
.53 .08871 Mdot
.53 .08882 Mdot
.53 .08894 Mdot
.53 .08917 Mdot
.53 .08957 Mdot
.53 .08959 Mdot
.53 .09041 Mdot
.53 .09058 Mdot
.53 .09065 Mdot
.53 .09075 Mdot
.53 .091 Mdot
.53 .0912 Mdot
.53 .09165 Mdot
.53 .09219 Mdot
.53 .09222 Mdot
.53 .09315 Mdot
.53 .09327 Mdot
.53 .09339 Mdot
.53 .09363 Mdot
.53 .09406 Mdot
.53 .09408 Mdot
.53 .09496 Mdot
.53 .09513 Mdot
.53 .09521 Mdot
.53 .09531 Mdot
.53 .09557 Mdot
.53 .09579 Mdot
.53 .09626 Mdot
.53 .09684 Mdot
.53 .09688 Mdot
.53 .09786 Mdot
.53 .09798 Mdot
.53 .09811 Mdot
.53 .09837 Mdot
.53 .09882 Mdot
.53 .09884 Mdot
.53 .09977 Mdot
.53 .09996 Mdot
.53 .10004 Mdot
.53 .10015 Mdot
.53 .10043 Mdot
.53 .10066 Mdot
.53 .10116 Mdot
.53 .10177 Mdot
.53 .1018 Mdot
.53 .10284 Mdot
.53 .10298 Mdot
.53 .10312 Mdot
.53 .10339 Mdot
.53 .10387 Mdot
.53 .10389 Mdot
.53 .10487 Mdot
.53 .10507 Mdot
.53 .10516 Mdot
.53 .10527 Mdot
.53 .10557 Mdot
.53 .10581 Mdot
.53 .10634 Mdot
.53 .10699 Mdot
.53 .10703 Mdot
.53 .10813 Mdot
.53 .10827 Mdot
.53 .10842 Mdot
.53 .10871 Mdot
.53 .10921 Mdot
.53 .10924 Mdot
.53 .11028 Mdot
.53 .1105 Mdot
.53 .11071 Mdot
.53 .11102 Mdot
.53 .11128 Mdot
.53 .11184 Mdot
.53 .11253 Mdot
.53 .11257 Mdot
.53 .11374 Mdot
.53 .11388 Mdot
.53 .11404 Mdot
.53 .11435 Mdot
.53 .11488 Mdot
.53 .11491 Mdot
.53 .11602 Mdot
.53 .11624 Mdot
.53 .11646 Mdot
.53 .1168 Mdot
.53 .11707 Mdot
.53 .11767 Mdot
.53 .1184 Mdot
.53 .11844 Mdot
.53 .11968 Mdot
.53 .11983 Mdot
.53 .12 Mdot
.53 .12032 Mdot
.53 .12089 Mdot
.53 .12093 Mdot
.53 .12209 Mdot
.53 .12233 Mdot
.53 .12257 Mdot
.53 .12292 Mdot
.53 .12322 Mdot
.53 .12385 Mdot
.53 .12462 Mdot
.53 .12466 Mdot
.53 .12598 Mdot
.53 .12614 Mdot
.53 .12632 Mdot
.53 .12666 Mdot
.53 .12727 Mdot
.53 .1273 Mdot
.53 .12854 Mdot
.53 .12879 Mdot
.53 .12904 Mdot
.53 .12942 Mdot
.53 .12973 Mdot
.53 .13039 Mdot
.53 .13121 Mdot
.53 .13126 Mdot
.53 .13265 Mdot
.53 .13283 Mdot
.53 .13301 Mdot
.53 .13338 Mdot
.53 .13402 Mdot
.53 .13405 Mdot
.53 .13537 Mdot
.53 .13564 Mdot
.53 .1359 Mdot
.53 .1363 Mdot
.53 .13663 Mdot
.53 .13734 Mdot
.53 .1382 Mdot
.53 .13825 Mdot
.53 .13973 Mdot
.53 .13991 Mdot
.53 .14011 Mdot
.53 .1405 Mdot
.53 .14118 Mdot
.53 .14121 Mdot
.53 .14261 Mdot
.53 .14289 Mdot
.53 .14317 Mdot
.53 .14359 Mdot
.53 .14394 Mdot
.53 .14469 Mdot
.53 .14561 Mdot
.53 .14567 Mdot
.53 .14723 Mdot
.53 .14743 Mdot
.53 .14764 Mdot
.53 .14804 Mdot
.53 .14876 Mdot
.53 .1488 Mdot
.53 .15028 Mdot
.53 .15058 Mdot
.53 .15088 Mdot
.53 .15132 Mdot
.53 .15169 Mdot
.53 .15249 Mdot
.53 .15346 Mdot
.53 .15352 Mdot
.53 .15518 Mdot
.53 .15539 Mdot
.53 .15561 Mdot
.53 .15604 Mdot
.53 .15681 Mdot
.53 .15685 Mdot
.53 .15841 Mdot
.53 .15873 Mdot
.53 .15905 Mdot
.53 .15952 Mdot
.53 .15991 Mdot
.53 .16076 Mdot
.53 .16179 Mdot
.53 .16185 Mdot
.53 .16361 Mdot
.53 .16383 Mdot
.53 .16407 Mdot
.53 .16452 Mdot
.53 .16533 Mdot
.53 .16538 Mdot
.53 .16704 Mdot
.53 .16738 Mdot
.53 .16771 Mdot
.53 .16821 Mdot
.53 .16862 Mdot
.53 .16952 Mdot
.53 .17061 Mdot
.53 .17068 Mdot
.53 .17254 Mdot
.53 .17278 Mdot
.53 .17303 Mdot
.53 .17351 Mdot
.53 .17437 Mdot
.53 .17442 Mdot
.53 .17617 Mdot
.53 .17653 Mdot
.53 .17689 Mdot
.53 .17742 Mdot
.53 .17786 Mdot
.53 .17881 Mdot
.53 .17997 Mdot
.53 .18004 Mdot
.53 .18201 Mdot
.53 .18226 Mdot
.53 .18253 Mdot
.53 .18304 Mdot
.53 .18395 Mdot
.53 .184 Mdot
.53 .18586 Mdot
.53 .18624 Mdot
.53 .18662 Mdot
.53 .18718 Mdot
.53 .18765 Mdot
.53 .18865 Mdot
.53 .18988 Mdot
.53 .18996 Mdot
.53 .19205 Mdot
.53 .19231 Mdot
.53 .19259 Mdot
.53 .19314 Mdot
.53 .1941 Mdot
.53 .19416 Mdot
.53 .19613 Mdot
.53 .19654 Mdot
.53 .19693 Mdot
.53 .19753 Mdot
.53 .19802 Mdot
.53 .19909 Mdot
.53 .20039 Mdot
.53 .20047 Mdot
.53 .20269 Mdot
.53 .20297 Mdot
.53 .20327 Mdot
.53 .20385 Mdot
.53 .20487 Mdot
.53 .20492 Mdot
.53 .20702 Mdot
.53 .20745 Mdot
.53 .20787 Mdot
.53 .2085 Mdot
.53 .20902 Mdot
.53 .21015 Mdot
.53 .21153 Mdot
.53 .21162 Mdot
.53 .21397 Mdot
.53 .21426 Mdot
.53 .21458 Mdot
.53 .21519 Mdot
.53 .21628 Mdot
.53 .21633 Mdot
.53 .21855 Mdot
.53 .21901 Mdot
.53 .21946 Mdot
.53 .22013 Mdot
.53 .22068 Mdot
.53 .22188 Mdot
.53 .22334 Mdot
.53 .22343 Mdot
.53 .22592 Mdot
.53 .22624 Mdot
.53 .22657 Mdot
.53 .22722 Mdot
.53 .22837 Mdot
.53 .22843 Mdot
.53 .23078 Mdot
.53 .23127 Mdot
.53 .23174 Mdot
.53 .23245 Mdot
.53 .23304 Mdot
.53 .23431 Mdot
.53 .23586 Mdot
.53 .23595 Mdot
.53 .23859 Mdot
.53 .23893 Mdot
.53 .23928 Mdot
.53 .23997 Mdot
.53 .24119 Mdot
.53 .24125 Mdot
.53 .24375 Mdot
.53 .24426 Mdot
.53 .24476 Mdot
.53 .24551 Mdot
.53 .24614 Mdot
.53 .24749 Mdot
.53 .24913 Mdot
.53 .24923 Mdot
.53 .25203 Mdot
.53 .25238 Mdot
.53 .25276 Mdot
.53 .25349 Mdot
.53 .25478 Mdot
.53 .25485 Mdot
.53 .25749 Mdot
.53 .25803 Mdot
.53 .25856 Mdot
.53 .25936 Mdot
.53 .26002 Mdot
.53 .26145 Mdot
.53 .26319 Mdot
.53 .2633 Mdot
.53 .26626 Mdot
.53 .26664 Mdot
.53 .26704 Mdot
.53 .26781 Mdot
.53 .26918 Mdot
.53 .26925 Mdot
.53 .27206 Mdot
.53 .27263 Mdot
.53 .27319 Mdot
.53 .27404 Mdot
.53 .27474 Mdot
.53 .27626 Mdot
.53 .2781 Mdot
.53 .27821 Mdot
.53 .28136 Mdot
.53 .28176 Mdot
.53 .28218 Mdot
.53 .283 Mdot
.53 .28445 Mdot
.53 .28453 Mdot
.53 .2875 Mdot
.53 .28811 Mdot
.53 .2887 Mdot
.53 .2896 Mdot
.53 .29034 Mdot
.53 .29195 Mdot
.53 .29391 Mdot
.53 .29402 Mdot
.53 .29736 Mdot
.53 .29778 Mdot
.53 .29823 Mdot
.53 .2991 Mdot
.53 .30063 Mdot
.53 .30072 Mdot
.53 .30386 Mdot
.53 .30451 Mdot
.53 .30514 Mdot
.53 .30609 Mdot
.53 .30688 Mdot
.53 .30858 Mdot
.53 .31066 Mdot
.53 .31078 Mdot
.53 .31431 Mdot
.53 .31476 Mdot
.53 .31524 Mdot
.53 .31616 Mdot
.53 .31779 Mdot
.53 .31788 Mdot
.53 .32121 Mdot
.53 .3219 Mdot
.53 .32257 Mdot
.53 .32358 Mdot
.53 .32441 Mdot
.53 .32621 Mdot
.532 .01918 Mdot
.532 .01947 Mdot
.532 .01953 Mdot
.532 .01955 Mdot
.532 .01972 Mdot
.532 .01977 Mdot
.532 .01984 Mdot
.532 .01986 Mdot
.532 .02004 Mdot
.532 .0201 Mdot
.532 .02017 Mdot
.532 .02019 Mdot
.532 .02038 Mdot
.532 .02044 Mdot
.532 .02051 Mdot
.532 .02054 Mdot
.532 .02074 Mdot
.532 .02074 Mdot
.532 .02081 Mdot
.532 .02089 Mdot
.532 .02091 Mdot
.532 .02113 Mdot
.532 .02113 Mdot
.532 .0212 Mdot
.532 .02128 Mdot
.532 .02131 Mdot
.532 .02154 Mdot
.532 .02154 Mdot
.532 .02162 Mdot
.532 .0217 Mdot
.532 .02173 Mdot
.532 .02197 Mdot
.532 .02197 Mdot
.532 .02198 Mdot
.532 .02206 Mdot
.532 .02212 Mdot
.532 .02215 Mdot
.532 .02218 Mdot
.532 .02243 Mdot
.532 .02244 Mdot
.532 .02244 Mdot
.532 .02253 Mdot
.532 .02259 Mdot
.532 .02262 Mdot
.532 .02266 Mdot
.532 .02292 Mdot
.532 .02293 Mdot
.532 .02293 Mdot
.532 .02303 Mdot
.532 .02309 Mdot
.532 .02313 Mdot
.532 .02313 Mdot
.532 .02317 Mdot
.532 .02345 Mdot
.532 .02346 Mdot
.532 .02346 Mdot
.532 .02356 Mdot
.532 .02363 Mdot
.532 .02367 Mdot
.532 .02367 Mdot
.532 .02371 Mdot
.532 .02401 Mdot
.532 .02402 Mdot
.532 .02402 Mdot
.532 .02412 Mdot
.532 .0242 Mdot
.532 .02424 Mdot
.532 .02424 Mdot
.532 .02428 Mdot
.532 .0246 Mdot
.532 .02461 Mdot
.532 .02462 Mdot
.532 .02473 Mdot
.532 .02481 Mdot
.532 .02485 Mdot
.532 .02485 Mdot
.532 .0249 Mdot
.532 .02524 Mdot
.532 .02525 Mdot
.532 .02525 Mdot
.532 .02537 Mdot
.532 .02545 Mdot
.532 .0255 Mdot
.532 .0255 Mdot
.532 .02555 Mdot
.532 .02576 Mdot
.532 .02591 Mdot
.532 .02592 Mdot
.532 .02592 Mdot
.532 .02605 Mdot
.532 .02614 Mdot
.532 .02619 Mdot
.532 .02619 Mdot
.532 .02624 Mdot
.532 .02647 Mdot
.532 .02663 Mdot
.532 .02664 Mdot
.532 .02664 Mdot
.532 .02677 Mdot
.532 .02687 Mdot
.532 .02693 Mdot
.532 .02693 Mdot
.532 .02698 Mdot
.532 .02717 Mdot
.532 .0272 Mdot
.532 .02722 Mdot
.532 .02739 Mdot
.532 .0274 Mdot
.532 .0274 Mdot
.532 .02755 Mdot
.532 .02765 Mdot
.532 .02771 Mdot
.532 .02771 Mdot
.532 .02776 Mdot
.532 .0279 Mdot
.532 .02794 Mdot
.532 .02796 Mdot
.532 .028 Mdot
.532 .02802 Mdot
.532 .0282 Mdot
.532 .02822 Mdot
.532 .02822 Mdot
.532 .02837 Mdot
.532 .02848 Mdot
.532 .02854 Mdot
.532 .02854 Mdot
.532 .02857 Mdot
.532 .0286 Mdot
.532 .02875 Mdot
.532 .02879 Mdot
.532 .02881 Mdot
.532 .02885 Mdot
.532 .02887 Mdot
.532 .02906 Mdot
.532 .02908 Mdot
.532 .02908 Mdot
.532 .02924 Mdot
.532 .02936 Mdot
.532 .02942 Mdot
.532 .02942 Mdot
.532 .02946 Mdot
.532 .02949 Mdot
.532 .02965 Mdot
.532 .02969 Mdot
.532 .02971 Mdot
.532 .02975 Mdot
.532 .02978 Mdot
.532 .02998 Mdot
.532 .03 Mdot
.532 .03 Mdot
.532 .03017 Mdot
.532 .0303 Mdot
.532 .03036 Mdot
.532 .03037 Mdot
.532 .0304 Mdot
.532 .03043 Mdot
.532 .0306 Mdot
.532 .03065 Mdot
.532 .03067 Mdot
.532 .03071 Mdot
.532 .03074 Mdot
.532 .03096 Mdot
.532 .03098 Mdot
.532 .03098 Mdot
.532 .03116 Mdot
.532 .03129 Mdot
.532 .03137 Mdot
.532 .03137 Mdot
.532 .03141 Mdot
.532 .03144 Mdot
.532 .03162 Mdot
.532 .03167 Mdot
.532 .03169 Mdot
.532 .03174 Mdot
.532 .03177 Mdot
.532 .032 Mdot
.532 .03202 Mdot
.532 .03202 Mdot
.532 .03215 Mdot
.532 .03221 Mdot
.532 .03236 Mdot
.532 .03243 Mdot
.532 .03243 Mdot
.532 .03247 Mdot
.532 .03251 Mdot
.532 .0327 Mdot
.532 .03275 Mdot
.532 .03278 Mdot
.532 .03283 Mdot
.532 .03286 Mdot
.532 .0331 Mdot
.532 .03312 Mdot
.532 .03313 Mdot
.532 .03314 Mdot
.532 .03327 Mdot
.532 .03333 Mdot
.532 .03348 Mdot
.532 .03356 Mdot
.532 .03357 Mdot
.532 .03361 Mdot
.532 .03361 Mdot
.532 .03365 Mdot
.532 .03385 Mdot
.532 .03391 Mdot
.532 .03394 Mdot
.532 .03399 Mdot
.532 .03402 Mdot
.532 .03428 Mdot
.532 .0343 Mdot
.532 .0343 Mdot
.532 .03431 Mdot
.532 .03445 Mdot
.532 .03446 Mdot
.532 .03452 Mdot
.532 .03469 Mdot
.532 .03477 Mdot
.532 .03477 Mdot
.532 .03482 Mdot
.532 .03482 Mdot
.532 .03486 Mdot
.532 .03508 Mdot
.532 .03514 Mdot
.532 .03517 Mdot
.532 .03522 Mdot
.532 .03526 Mdot
.532 .03553 Mdot
.532 .03556 Mdot
.532 .03556 Mdot
.532 .03557 Mdot
.532 .03572 Mdot
.532 .03573 Mdot
.532 .03579 Mdot
.532 .03596 Mdot
.532 .03605 Mdot
.532 .03606 Mdot
.532 .0361 Mdot
.532 .03611 Mdot
.532 .03615 Mdot
.532 .03638 Mdot
.532 .03644 Mdot
.532 .03648 Mdot
.532 .03653 Mdot
.532 .03657 Mdot
.532 .03687 Mdot
.532 .03689 Mdot
.532 .03689 Mdot
.532 .0369 Mdot
.532 .03706 Mdot
.532 .03707 Mdot
.532 .03714 Mdot
.532 .03732 Mdot
.532 .03742 Mdot
.532 .03742 Mdot
.532 .03747 Mdot
.532 .03747 Mdot
.532 .03752 Mdot
.532 .03777 Mdot
.532 .03784 Mdot
.532 .03787 Mdot
.532 .03793 Mdot
.532 .03797 Mdot
.532 .03828 Mdot
.532 .03831 Mdot
.532 .03831 Mdot
.532 .03832 Mdot
.532 .03849 Mdot
.532 .0385 Mdot
.532 .03858 Mdot
.532 .03877 Mdot
.532 .03887 Mdot
.532 .03888 Mdot
.532 .03893 Mdot
.532 .03893 Mdot
.532 .03898 Mdot
.532 .03924 Mdot
.532 .03931 Mdot
.532 .03935 Mdot
.532 .03941 Mdot
.532 .03946 Mdot
.532 .03979 Mdot
.532 .03982 Mdot
.532 .03982 Mdot
.532 .03983 Mdot
.532 .04001 Mdot
.532 .04002 Mdot
.532 .0401 Mdot
.532 .04031 Mdot
.532 .04042 Mdot
.532 .04042 Mdot
.532 .04048 Mdot
.532 .04048 Mdot
.532 .04053 Mdot
.532 .04081 Mdot
.532 .04089 Mdot
.532 .04093 Mdot
.532 .04099 Mdot
.532 .04104 Mdot
.532 .0414 Mdot
.532 .04143 Mdot
.532 .04143 Mdot
.532 .04144 Mdot
.532 .04163 Mdot
.532 .04164 Mdot
.532 .04173 Mdot
.532 .04195 Mdot
.532 .04206 Mdot
.532 .04207 Mdot
.532 .04213 Mdot
.532 .04213 Mdot
.532 .04218 Mdot
.532 .04248 Mdot
.532 .04256 Mdot
.532 .0426 Mdot
.532 .04268 Mdot
.532 .04273 Mdot
.532 .04311 Mdot
.532 .04314 Mdot
.532 .04314 Mdot
.532 .04315 Mdot
.532 .04335 Mdot
.532 .04337 Mdot
.532 .04346 Mdot
.532 .04369 Mdot
.532 .04382 Mdot
.532 .04382 Mdot
.532 .04388 Mdot
.532 .04388 Mdot
.532 .04394 Mdot
.532 .04426 Mdot
.532 .04435 Mdot
.532 .04439 Mdot
.532 .04446 Mdot
.532 .04452 Mdot
.532 .04492 Mdot
.532 .04495 Mdot
.532 .04496 Mdot
.532 .04497 Mdot
.532 .04519 Mdot
.532 .0452 Mdot
.532 .0453 Mdot
.532 .04554 Mdot
.532 .04568 Mdot
.532 .04568 Mdot
.532 .04575 Mdot
.532 .04575 Mdot
.532 .04581 Mdot
.532 .04615 Mdot
.532 .04624 Mdot
.532 .04629 Mdot
.532 .04637 Mdot
.532 .04643 Mdot
.532 .04686 Mdot
.532 .04689 Mdot
.532 .04689 Mdot
.532 .04691 Mdot
.532 .04714 Mdot
.532 .04715 Mdot
.532 .04725 Mdot
.532 .04752 Mdot
.532 .04766 Mdot
.532 .04766 Mdot
.532 .04773 Mdot
.532 .04774 Mdot
.532 .0478 Mdot
.532 .04816 Mdot
.532 .04826 Mdot
.532 .04831 Mdot
.532 .04839 Mdot
.532 .04846 Mdot
.532 .04891 Mdot
.532 .04895 Mdot
.532 .04895 Mdot
.532 .04897 Mdot
.532 .04921 Mdot
.532 .04923 Mdot
.532 .04934 Mdot
.532 .04962 Mdot
.532 .04977 Mdot
.532 .04977 Mdot
.532 .04985 Mdot
.532 .04985 Mdot
.532 .04992 Mdot
.532 .0503 Mdot
.532 .05041 Mdot
.532 .05046 Mdot
.532 .05055 Mdot
.532 .05062 Mdot
.532 .0511 Mdot
.532 .05114 Mdot
.532 .05114 Mdot
.532 .05116 Mdot
.532 .05142 Mdot
.532 .05144 Mdot
.532 .05155 Mdot
.532 .05185 Mdot
.532 .05201 Mdot
.532 .05201 Mdot
.532 .0521 Mdot
.532 .0521 Mdot
.532 .05217 Mdot
.532 .05258 Mdot
.532 .05269 Mdot
.532 .05275 Mdot
.532 .05284 Mdot
.532 .05292 Mdot
.532 .05343 Mdot
.532 .05347 Mdot
.532 .05347 Mdot
.532 .05349 Mdot
.532 .05377 Mdot
.532 .05379 Mdot
.532 .05391 Mdot
.532 .05423 Mdot
.532 .0544 Mdot
.532 .0544 Mdot
.532 .05449 Mdot
.532 .05449 Mdot
.532 .05457 Mdot
.532 .055 Mdot
.532 .05512 Mdot
.532 .05518 Mdot
.532 .05528 Mdot
.532 .05536 Mdot
.532 .05591 Mdot
.532 .05595 Mdot
.532 .05595 Mdot
.532 .05598 Mdot
.532 .05627 Mdot
.532 .05629 Mdot
.532 .05642 Mdot
.532 .05676 Mdot
.532 .05694 Mdot
.532 .05694 Mdot
.532 .05703 Mdot
.532 .05704 Mdot
.532 .05712 Mdot
.532 .05758 Mdot
.532 .05771 Mdot
.532 .05777 Mdot
.532 .05788 Mdot
.532 .05796 Mdot
.532 .05854 Mdot
.532 .05859 Mdot
.532 .05859 Mdot
.532 .05862 Mdot
.532 .05893 Mdot
.532 .05895 Mdot
.532 .05909 Mdot
.532 .05945 Mdot
.532 .05964 Mdot
.532 .05964 Mdot
.532 .05974 Mdot
.532 .05975 Mdot
.532 .05983 Mdot
.532 .06032 Mdot
.532 .06046 Mdot
.532 .06053 Mdot
.532 .06064 Mdot
.532 .06073 Mdot
.532 .06135 Mdot
.532 .0614 Mdot
.532 .0614 Mdot
.532 .06143 Mdot
.532 .06176 Mdot
.532 .06178 Mdot
.532 .06193 Mdot
.532 .06231 Mdot
.532 .06252 Mdot
.532 .06252 Mdot
.532 .06262 Mdot
.532 .06263 Mdot
.532 .06272 Mdot
.532 .06324 Mdot
.532 .06339 Mdot
.532 .06346 Mdot
.532 .06358 Mdot
.532 .06368 Mdot
.532 .06433 Mdot
.532 .06439 Mdot
.532 .06439 Mdot
.532 .06442 Mdot
.532 .06477 Mdot
.532 .06479 Mdot
.532 .06495 Mdot
.532 .06536 Mdot
.532 .06557 Mdot
.532 .06558 Mdot
.532 .06569 Mdot
.532 .0657 Mdot
.532 .06579 Mdot
.532 .06635 Mdot
.532 .0665 Mdot
.532 .06658 Mdot
.532 .06671 Mdot
.532 .06681 Mdot
.532 .06751 Mdot
.532 .06757 Mdot
.532 .06757 Mdot
.532 .0676 Mdot
.532 .06797 Mdot
.532 .06799 Mdot
.532 .06816 Mdot
.532 .0686 Mdot
.532 .06883 Mdot
.532 .06883 Mdot
.532 .06895 Mdot
.532 .06896 Mdot
.532 .06906 Mdot
.532 .06965 Mdot
.532 .06982 Mdot
.532 .0699 Mdot
.532 .07004 Mdot
.532 .07014 Mdot
.532 .07089 Mdot
.532 .07095 Mdot
.532 .07095 Mdot
.532 .07098 Mdot
.532 .07138 Mdot
.532 .0714 Mdot
.532 .07158 Mdot
.532 .07205 Mdot
.532 .07229 Mdot
.532 .0723 Mdot
.532 .07242 Mdot
.532 .07243 Mdot
.532 .07254 Mdot
.532 .07317 Mdot
.532 .07334 Mdot
.532 .07343 Mdot
.532 .07358 Mdot
.532 .07369 Mdot
.532 .07448 Mdot
.532 .07455 Mdot
.532 .07455 Mdot
.532 .07458 Mdot
.532 .075 Mdot
.532 .07503 Mdot
.532 .07522 Mdot
.532 .07572 Mdot
.532 .07598 Mdot
.532 .07598 Mdot
.532 .07612 Mdot
.532 .07612 Mdot
.532 .07624 Mdot
.532 .07691 Mdot
.532 .0771 Mdot
.532 .07718 Mdot
.532 .07734 Mdot
.532 .07747 Mdot
.532 .07831 Mdot
.532 .07838 Mdot
.532 .07838 Mdot
.532 .07841 Mdot
.532 .07886 Mdot
.532 .07889 Mdot
.532 .07909 Mdot
.532 .07962 Mdot
.532 .0799 Mdot
.532 .07991 Mdot
.532 .08005 Mdot
.532 .08005 Mdot
.532 .08018 Mdot
.532 .08089 Mdot
.532 .08109 Mdot
.532 .08118 Mdot
.532 .08135 Mdot
.532 .08148 Mdot
.532 .08238 Mdot
.532 .08245 Mdot
.532 .08246 Mdot
.532 .08249 Mdot
.532 .08297 Mdot
.532 .083 Mdot
.532 .08321 Mdot
.532 .08377 Mdot
.532 .08407 Mdot
.532 .08408 Mdot
.532 .08423 Mdot
.532 .08424 Mdot
.532 .08437 Mdot
.532 .08513 Mdot
.532 .08534 Mdot
.532 .08544 Mdot
.532 .08562 Mdot
.532 .08575 Mdot
.532 .08671 Mdot
.532 .08679 Mdot
.532 .08679 Mdot
.532 .08683 Mdot
.532 .08734 Mdot
.532 .08737 Mdot
.532 .0876 Mdot
.532 .08819 Mdot
.532 .08851 Mdot
.532 .08852 Mdot
.532 .08868 Mdot
.532 .08868 Mdot
.532 .08883 Mdot
.532 .08963 Mdot
.532 .08986 Mdot
.532 .08996 Mdot
.532 .09016 Mdot
.532 .0903 Mdot
.532 .09132 Mdot
.532 .0914 Mdot
.532 .0914 Mdot
.532 .09144 Mdot
.532 .09198 Mdot
.532 .09202 Mdot
.532 .09226 Mdot
.532 .0929 Mdot
.532 .09323 Mdot
.532 .09324 Mdot
.532 .09341 Mdot
.532 .09342 Mdot
.532 .09357 Mdot
.532 .09443 Mdot
.532 .09467 Mdot
.532 .09478 Mdot
.532 .09498 Mdot
.532 .09514 Mdot
.532 .09622 Mdot
.532 .09631 Mdot
.532 .09631 Mdot
.532 .09635 Mdot
.532 .09693 Mdot
.532 .09697 Mdot
.532 .09723 Mdot
.532 .0979 Mdot
.532 .09826 Mdot
.532 .09827 Mdot
.532 .09845 Mdot
.532 .09846 Mdot
.532 .09862 Mdot
.532 .09953 Mdot
.532 .09978 Mdot
.532 .0999 Mdot
.532 .10012 Mdot
.532 .10029 Mdot
.532 .10143 Mdot
.532 .10153 Mdot
.532 .10153 Mdot
.532 .10158 Mdot
.532 .10219 Mdot
.532 .10223 Mdot
.532 .10251 Mdot
.532 .10322 Mdot
.532 .1036 Mdot
.532 .10361 Mdot
.532 .1038 Mdot
.532 .10382 Mdot
.532 .10399 Mdot
.532 .10496 Mdot
.532 .10523 Mdot
.532 .10535 Mdot
.532 .10559 Mdot
.532 .10576 Mdot
.532 .10698 Mdot
.532 .10708 Mdot
.532 .10709 Mdot
.532 .10714 Mdot
.532 .10779 Mdot
.532 .10783 Mdot
.532 .10813 Mdot
.532 .10889 Mdot
.532 .10929 Mdot
.532 .1093 Mdot
.532 .10951 Mdot
.532 .10952 Mdot
.532 .1097 Mdot
.532 .11073 Mdot
.532 .11102 Mdot
.532 .11116 Mdot
.532 .1114 Mdot
.532 .11159 Mdot
.532 .11289 Mdot
.532 .113 Mdot
.532 .113 Mdot
.532 .11305 Mdot
.532 .11375 Mdot
.532 .11379 Mdot
.532 .1141 Mdot
.532 .11491 Mdot
.532 .11535 Mdot
.532 .11536 Mdot
.532 .11557 Mdot
.532 .11559 Mdot
.532 .11578 Mdot
.532 .11688 Mdot
.532 .11718 Mdot
.532 .11733 Mdot
.532 .11759 Mdot
.532 .11779 Mdot
.532 .11917 Mdot
.532 .11929 Mdot
.532 .11929 Mdot
.532 .11935 Mdot
.532 .12008 Mdot
.532 .12013 Mdot
.532 .12047 Mdot
.532 .12133 Mdot
.532 .12179 Mdot
.532 .1218 Mdot
.532 .12203 Mdot
.532 .12204 Mdot
.532 .12225 Mdot
.532 .12342 Mdot
.532 .12374 Mdot
.532 .12389 Mdot
.532 .12417 Mdot
.532 .12439 Mdot
.532 .12586 Mdot
.532 .12598 Mdot
.532 .12599 Mdot
.532 .12604 Mdot
.532 .12683 Mdot
.532 .12688 Mdot
.532 .12723 Mdot
.532 .12815 Mdot
.532 .12864 Mdot
.532 .12865 Mdot
.532 .1289 Mdot
.532 .12891 Mdot
.532 .12913 Mdot
.532 .13037 Mdot
.532 .13072 Mdot
.532 .13088 Mdot
.532 .13118 Mdot
.532 .13141 Mdot
.532 .13297 Mdot
.532 .1331 Mdot
.532 .13311 Mdot
.532 .13317 Mdot
.532 .134 Mdot
.532 .13406 Mdot
.532 .13443 Mdot
.532 .13541 Mdot
.532 .13593 Mdot
.532 .13594 Mdot
.532 .1362 Mdot
.532 .13622 Mdot
.532 .13645 Mdot
.532 .13778 Mdot
.532 .13814 Mdot
.532 .13832 Mdot
.532 .13863 Mdot
.532 .14054 Mdot
.532 .14068 Mdot
.532 .14068 Mdot
.532 .14075 Mdot
.532 .14164 Mdot
.532 .1417 Mdot
.532 .1421 Mdot
.532 .14313 Mdot
.532 .14369 Mdot
.532 .1437 Mdot
.532 .14398 Mdot
.532 .14399 Mdot
.532 .14424 Mdot
.532 .14565 Mdot
.532 .14604 Mdot
.532 .14623 Mdot
.532 .14656 Mdot
.532 .14859 Mdot
.532 .14874 Mdot
.532 .14875 Mdot
.532 .14882 Mdot
.532 .14976 Mdot
.532 .14982 Mdot
.532 .15025 Mdot
.532 .15135 Mdot
.532 .15194 Mdot
.532 .15196 Mdot
.532 .15225 Mdot
.532 .15227 Mdot
.532 .15253 Mdot
.532 .15403 Mdot
.532 .15445 Mdot
.532 .15464 Mdot
.532 .155 Mdot
.532 .15716 Mdot
.532 .15732 Mdot
.532 .15732 Mdot
.532 .1574 Mdot
.532 .1584 Mdot
.532 .15847 Mdot
.532 .15892 Mdot
.532 .1601 Mdot
.532 .16072 Mdot
.532 .16074 Mdot
.532 .16105 Mdot
.532 .16107 Mdot
.532 .16135 Mdot
.532 .16295 Mdot
.532 .16339 Mdot
.532 .1636 Mdot
.532 .16398 Mdot
.532 .16628 Mdot
.532 .16644 Mdot
.532 .16645 Mdot
.532 .16653 Mdot
.532 .1676 Mdot
.532 .16767 Mdot
.532 .16815 Mdot
.532 .1694 Mdot
.532 .17007 Mdot
.532 .17008 Mdot
.532 .17042 Mdot
.532 .17044 Mdot
.532 .17074 Mdot
.532 .17244 Mdot
.532 .1729 Mdot
.532 .17313 Mdot
.532 .17353 Mdot
.532 .17598 Mdot
.532 .17615 Mdot
.532 .17616 Mdot
.532 .17625 Mdot
.532 .17738 Mdot
.532 .17746 Mdot
.532 .17797 Mdot
.532 .1793 Mdot
.532 .18001 Mdot
.532 .18003 Mdot
.532 .18038 Mdot
.532 .1804 Mdot
.532 .18072 Mdot
.532 .18253 Mdot
.532 .18303 Mdot
.532 .18327 Mdot
.532 .1837 Mdot
.532 .1863 Mdot
.532 .18648 Mdot
.532 .1865 Mdot
.532 .18659 Mdot
.532 .18779 Mdot
.532 .18788 Mdot
.532 .18842 Mdot
.532 .18984 Mdot
.532 .19059 Mdot
.532 .19061 Mdot
.532 .19099 Mdot
.532 .19101 Mdot
.532 .19135 Mdot
.532 .19327 Mdot
.532 .1938 Mdot
.532 .19405 Mdot
.532 .19451 Mdot
.532 .19728 Mdot
.532 .19748 Mdot
.532 .19749 Mdot
.532 .19759 Mdot
.532 .19887 Mdot
.532 .19896 Mdot
.532 .19954 Mdot
.532 .20104 Mdot
.532 .20185 Mdot
.532 .20186 Mdot
.532 .20227 Mdot
.532 .20229 Mdot
.532 .20265 Mdot
.532 .2047 Mdot
.532 .20526 Mdot
.532 .20553 Mdot
.532 .20602 Mdot
.532 .20896 Mdot
.532 .20917 Mdot
.532 .20919 Mdot
.532 .20929 Mdot
.532 .21066 Mdot
.532 .21075 Mdot
.532 .21137 Mdot
.532 .21297 Mdot
.532 .21382 Mdot
.532 .21384 Mdot
.532 .21427 Mdot
.532 .2143 Mdot
.532 .21468 Mdot
.532 .21686 Mdot
.532 .21746 Mdot
.532 .21774 Mdot
.532 .21826 Mdot
.532 .2214 Mdot
.532 .22162 Mdot
.532 .22163 Mdot
.532 .22174 Mdot
.532 .2232 Mdot
.532 .2233 Mdot
.532 .22395 Mdot
.532 .22566 Mdot
.532 .22657 Mdot
.532 .22659 Mdot
.532 .22704 Mdot
.532 .22707 Mdot
.532 .22748 Mdot
.532 .22979 Mdot
.532 .23043 Mdot
.532 .23074 Mdot
.532 .23129 Mdot
.532 .23462 Mdot
.532 .23486 Mdot
.532 .23488 Mdot
.532 .23499 Mdot
.532 .23654 Mdot
.532 .23664 Mdot
.532 .23734 Mdot
.532 .23916 Mdot
.532 .24012 Mdot
.532 .24015 Mdot
.532 .24063 Mdot
.532 .24066 Mdot
.532 .24109 Mdot
.532 .24356 Mdot
.532 .24424 Mdot
.532 .24456 Mdot
.532 .24515 Mdot
.532 .2487 Mdot
.532 .24895 Mdot
.532 .24897 Mdot
.532 .24909 Mdot
.532 .25074 Mdot
.532 .25085 Mdot
.532 .25159 Mdot
.532 .25352 Mdot
.532 .25455 Mdot
.532 .25457 Mdot
.532 .25509 Mdot
.532 .25512 Mdot
.532 .25558 Mdot
.532 .2582 Mdot
.532 .25893 Mdot
.532 .25927 Mdot
.532 .2599 Mdot
.532 .26367 Mdot
.532 .26394 Mdot
.532 .26396 Mdot
.532 .26409 Mdot
.532 .26584 Mdot
.532 .26596 Mdot
.532 .26675 Mdot
.532 .2688 Mdot
.532 .2699 Mdot
.532 .26992 Mdot
.532 .27048 Mdot
.532 .27051 Mdot
.532 .271 Mdot
.532 .27379 Mdot
.532 .27456 Mdot
.532 .27493 Mdot
.532 .27559 Mdot
.532 .27961 Mdot
.532 .27989 Mdot
.532 .27991 Mdot
.532 .28005 Mdot
.532 .28192 Mdot
.532 .28204 Mdot
.532 .28288 Mdot
.532 .28507 Mdot
.532 .28623 Mdot
.532 .28626 Mdot
.532 .28684 Mdot
.532 .28688 Mdot
.532 .2874 Mdot
.532 .29037 Mdot
.532 .29119 Mdot
.532 .29158 Mdot
.532 .29229 Mdot
.532 .29656 Mdot
.532 .29686 Mdot
.532 .29688 Mdot
.532 .29703 Mdot
.532 .29902 Mdot
.532 .29915 Mdot
.532 .30004 Mdot
.532 .30237 Mdot
.532 .30361 Mdot
.532 .30364 Mdot
.532 .30426 Mdot
.532 .3043 Mdot
.532 .30485 Mdot
.532 .30801 Mdot
.532 .30888 Mdot
.532 .3093 Mdot
.532 .31005 Mdot
.532 .3146 Mdot
.532 .31492 Mdot
.532 .31494 Mdot
.532 .3151 Mdot
.532 .31721 Mdot
.532 .31735 Mdot
.532 .31831 Mdot
.532 .32078 Mdot
.532 .3221 Mdot
.532 .32213 Mdot
.532 .32279 Mdot
.532 .32283 Mdot
.532 .32342 Mdot
.532 .32678 Mdot
.532 .32771 Mdot
.532 .32815 Mdot
.532 .32895 Mdot
.534 .01527 Mdot
.534 .01531 Mdot
.534 .01535 Mdot
.534 .0154 Mdot
.534 .01544 Mdot
.534 .01549 Mdot
.534 .01554 Mdot
.534 .0156 Mdot
.534 .01566 Mdot
.534 .01573 Mdot
.534 .01579 Mdot
.534 .01587 Mdot
.534 .01595 Mdot
.534 .01603 Mdot
.534 .01612 Mdot
.534 .01622 Mdot
.534 .01632 Mdot
.534 .01643 Mdot
.534 .01654 Mdot
.534 .01667 Mdot
.534 .0168 Mdot
.534 .01694 Mdot
.534 .01709 Mdot
.534 .01725 Mdot
.534 .01743 Mdot
.534 .01761 Mdot
.534 .01781 Mdot
.534 .01802 Mdot
.534 .01824 Mdot
.534 .01832 Mdot
.534 .01848 Mdot
.534 .01857 Mdot
.534 .01874 Mdot
.534 .01883 Mdot
.534 .01901 Mdot
.534 .01911 Mdot
.534 .01931 Mdot
.534 .01941 Mdot
.534 .01962 Mdot
.534 .01973 Mdot
.534 .01985 Mdot
.534 .01992 Mdot
.534 .01995 Mdot
.534 .01996 Mdot
.534 .02007 Mdot
.534 .0202 Mdot
.534 .02028 Mdot
.534 .02031 Mdot
.534 .02032 Mdot
.534 .02043 Mdot
.534 .02057 Mdot
.534 .02065 Mdot
.534 .02069 Mdot
.534 .0207 Mdot
.534 .02082 Mdot
.534 .02097 Mdot
.534 .02106 Mdot
.534 .02109 Mdot
.534 .02111 Mdot
.534 .02123 Mdot
.534 .0214 Mdot
.534 .02149 Mdot
.534 .02153 Mdot
.534 .02154 Mdot
.534 .02168 Mdot
.534 .02185 Mdot
.534 .02195 Mdot
.534 .02199 Mdot
.534 .022 Mdot
.534 .02215 Mdot
.534 .02234 Mdot
.534 .02244 Mdot
.534 .02249 Mdot
.534 .0225 Mdot
.534 .02266 Mdot
.534 .02285 Mdot
.534 .0229 Mdot
.534 .02297 Mdot
.534 .02301 Mdot
.534 .02303 Mdot
.534 .0232 Mdot
.534 .02341 Mdot
.534 .02346 Mdot
.534 .02353 Mdot
.534 .02358 Mdot
.534 .0236 Mdot
.534 .02377 Mdot
.534 .024 Mdot
.534 .02405 Mdot
.534 .02413 Mdot
.534 .02418 Mdot
.534 .0242 Mdot
.534 .02439 Mdot
.534 .02463 Mdot
.534 .02469 Mdot
.534 .02477 Mdot
.534 .02482 Mdot
.534 .02484 Mdot
.534 .02487 Mdot
.534 .02505 Mdot
.534 .0253 Mdot
.534 .02537 Mdot
.534 .02545 Mdot
.534 .02551 Mdot
.534 .02553 Mdot
.534 .02557 Mdot
.534 .02575 Mdot
.534 .02602 Mdot
.534 .02609 Mdot
.534 .02618 Mdot
.534 .02625 Mdot
.534 .02627 Mdot
.534 .0263 Mdot
.534 .0265 Mdot
.534 .02679 Mdot
.534 .02687 Mdot
.534 .02696 Mdot
.534 .02703 Mdot
.534 .02705 Mdot
.534 .02709 Mdot
.534 .0273 Mdot
.534 .02743 Mdot
.534 .02761 Mdot
.534 .02769 Mdot
.534 .02779 Mdot
.534 .02787 Mdot
.534 .02789 Mdot
.534 .02793 Mdot
.534 .02793 Mdot
.534 .02816 Mdot
.534 .0283 Mdot
.534 .02849 Mdot
.534 .02857 Mdot
.534 .02868 Mdot
.534 .02876 Mdot
.534 .02879 Mdot
.534 .02883 Mdot
.534 .02883 Mdot
.534 .02907 Mdot
.534 .02922 Mdot
.534 .02929 Mdot
.534 .02929 Mdot
.534 .02943 Mdot
.534 .02952 Mdot
.534 .02963 Mdot
.534 .02972 Mdot
.534 .02975 Mdot
.534 .02979 Mdot
.534 .02979 Mdot
.534 .02994 Mdot
.534 .03005 Mdot
.534 .0302 Mdot
.534 .03028 Mdot
.534 .03028 Mdot
.534 .03043 Mdot
.534 .03052 Mdot
.534 .03065 Mdot
.534 .03074 Mdot
.534 .03077 Mdot
.534 .03081 Mdot
.534 .03082 Mdot
.534 .03084 Mdot
.534 .03094 Mdot
.534 .03098 Mdot
.534 .03109 Mdot
.534 .03126 Mdot
.534 .03134 Mdot
.534 .03134 Mdot
.534 .03134 Mdot
.534 .0315 Mdot
.534 .0316 Mdot
.534 .03173 Mdot
.534 .03183 Mdot
.534 .03186 Mdot
.534 .03191 Mdot
.534 .03191 Mdot
.534 .03193 Mdot
.534 .03204 Mdot
.534 .03208 Mdot
.534 .0322 Mdot
.534 .03238 Mdot
.534 .03247 Mdot
.534 .03247 Mdot
.534 .03247 Mdot
.534 .03264 Mdot
.534 .03275 Mdot
.534 .03289 Mdot
.534 .03299 Mdot
.534 .03303 Mdot
.534 .03308 Mdot
.534 .03308 Mdot
.534 .0331 Mdot
.534 .03322 Mdot
.534 .03326 Mdot
.534 .03339 Mdot
.534 .0334 Mdot
.534 .03358 Mdot
.534 .03367 Mdot
.534 .03368 Mdot
.534 .03368 Mdot
.534 .03386 Mdot
.534 .03397 Mdot
.534 .03412 Mdot
.534 .03423 Mdot
.534 .03423 Mdot
.534 .03427 Mdot
.534 .03432 Mdot
.534 .03433 Mdot
.534 .03435 Mdot
.534 .03448 Mdot
.534 .03452 Mdot
.534 .03466 Mdot
.534 .03468 Mdot
.534 .03487 Mdot
.534 .03496 Mdot
.534 .03497 Mdot
.534 .03497 Mdot
.534 .03516 Mdot
.534 .03528 Mdot
.534 .03544 Mdot
.534 .03547 Mdot
.534 .03556 Mdot
.534 .03556 Mdot
.534 .0356 Mdot
.534 .03566 Mdot
.534 .03566 Mdot
.534 .03569 Mdot
.534 .03582 Mdot
.534 .03587 Mdot
.534 .03602 Mdot
.534 .03603 Mdot
.534 .03624 Mdot
.534 .03634 Mdot
.534 .03635 Mdot
.534 .03635 Mdot
.534 .03655 Mdot
.534 .03668 Mdot
.534 .03685 Mdot
.534 .03689 Mdot
.534 .03698 Mdot
.534 .03698 Mdot
.534 .03702 Mdot
.534 .03708 Mdot
.534 .03709 Mdot
.534 .03712 Mdot
.534 .03725 Mdot
.534 .03731 Mdot
.534 .03747 Mdot
.534 .03748 Mdot
.534 .0377 Mdot
.534 .03781 Mdot
.534 .03782 Mdot
.534 .03782 Mdot
.534 .03803 Mdot
.534 .03817 Mdot
.534 .03836 Mdot
.534 .03839 Mdot
.534 .03849 Mdot
.534 .03849 Mdot
.534 .03854 Mdot
.534 .0386 Mdot
.534 .03861 Mdot
.534 .03864 Mdot
.534 .03879 Mdot
.534 .03885 Mdot
.534 .03901 Mdot
.534 .03903 Mdot
.534 .03926 Mdot
.534 .03938 Mdot
.534 .03939 Mdot
.534 .03939 Mdot
.534 .03962 Mdot
.534 .03977 Mdot
.534 .03997 Mdot
.534 .04 Mdot
.534 .04011 Mdot
.534 .04011 Mdot
.534 .04016 Mdot
.534 .04023 Mdot
.534 .04023 Mdot
.534 .04027 Mdot
.534 .04042 Mdot
.534 .04049 Mdot
.534 .04058 Mdot
.534 .04066 Mdot
.534 .04068 Mdot
.534 .04093 Mdot
.534 .04106 Mdot
.534 .04107 Mdot
.534 .04107 Mdot
.534 .04131 Mdot
.534 .04147 Mdot
.534 .04168 Mdot
.534 .04172 Mdot
.534 .04183 Mdot
.534 .04183 Mdot
.534 .04189 Mdot
.534 .04196 Mdot
.534 .04197 Mdot
.534 .042 Mdot
.534 .04217 Mdot
.534 .04224 Mdot
.534 .04234 Mdot
.534 .04243 Mdot
.534 .04245 Mdot
.534 .04272 Mdot
.534 .04285 Mdot
.534 .04286 Mdot
.534 .04286 Mdot
.534 .04312 Mdot
.534 .04329 Mdot
.534 .04352 Mdot
.534 .04356 Mdot
.534 .04368 Mdot
.534 .04368 Mdot
.534 .04374 Mdot
.534 .04381 Mdot
.534 .04382 Mdot
.534 .04386 Mdot
.534 .04404 Mdot
.534 .04411 Mdot
.534 .04422 Mdot
.534 .04431 Mdot
.534 .04434 Mdot
.534 .04462 Mdot
.534 .04476 Mdot
.534 .04477 Mdot
.534 .04477 Mdot
.534 .04505 Mdot
.534 .04523 Mdot
.534 .04547 Mdot
.534 .04552 Mdot
.534 .04565 Mdot
.534 .04565 Mdot
.534 .04571 Mdot
.534 .04579 Mdot
.534 .0458 Mdot
.534 .04584 Mdot
.534 .04603 Mdot
.534 .04611 Mdot
.534 .04623 Mdot
.534 .04633 Mdot
.534 .04635 Mdot
.534 .04665 Mdot
.534 .04681 Mdot
.534 .04681 Mdot
.534 .04682 Mdot
.534 .04711 Mdot
.534 .04731 Mdot
.534 .04757 Mdot
.534 .04762 Mdot
.534 .04775 Mdot
.534 .04775 Mdot
.534 .04782 Mdot
.534 .04791 Mdot
.534 .04792 Mdot
.534 .04796 Mdot
.534 .04816 Mdot
.534 .04825 Mdot
.534 .04837 Mdot
.534 .04848 Mdot
.534 .0485 Mdot
.534 .04883 Mdot
.534 .04899 Mdot
.534 .049 Mdot
.534 .049 Mdot
.534 .04932 Mdot
.534 .04953 Mdot
.534 .0498 Mdot
.534 .04985 Mdot
.534 .05 Mdot
.534 .05 Mdot
.534 .05007 Mdot
.534 .05016 Mdot
.534 .05017 Mdot
.534 .05022 Mdot
.534 .05044 Mdot
.534 .05053 Mdot
.534 .05066 Mdot
.534 .05077 Mdot
.534 .0508 Mdot
.534 .05115 Mdot
.534 .05132 Mdot
.534 .05133 Mdot
.534 .05133 Mdot
.534 .05167 Mdot
.534 .05189 Mdot
.534 .05219 Mdot
.534 .05224 Mdot
.534 .0524 Mdot
.534 .0524 Mdot
.534 .05247 Mdot
.534 .05257 Mdot
.534 .05259 Mdot
.534 .05263 Mdot
.534 .05287 Mdot
.534 .05296 Mdot
.534 .0531 Mdot
.534 .05322 Mdot
.534 .05325 Mdot
.534 .05362 Mdot
.534 .05381 Mdot
.534 .05382 Mdot
.534 .05382 Mdot
.534 .05418 Mdot
.534 .05442 Mdot
.534 .05473 Mdot
.534 .05479 Mdot
.534 .05496 Mdot
.534 .05496 Mdot
.534 .05504 Mdot
.534 .05515 Mdot
.534 .05516 Mdot
.534 .05521 Mdot
.534 .05546 Mdot
.534 .05556 Mdot
.534 .05571 Mdot
.534 .05584 Mdot
.534 .05587 Mdot
.534 .05627 Mdot
.534 .05647 Mdot
.534 .05648 Mdot
.534 .05648 Mdot
.534 .05687 Mdot
.534 .05712 Mdot
.534 .05745 Mdot
.534 .05752 Mdot
.534 .0577 Mdot
.534 .0577 Mdot
.534 .05778 Mdot
.534 .0579 Mdot
.534 .05791 Mdot
.534 .05796 Mdot
.534 .05823 Mdot
.534 .05834 Mdot
.534 .0585 Mdot
.534 .05864 Mdot
.534 .05867 Mdot
.534 .0591 Mdot
.534 .05931 Mdot
.534 .05932 Mdot
.534 .05932 Mdot
.534 .05973 Mdot
.534 .06001 Mdot
.534 .06036 Mdot
.534 .06043 Mdot
.534 .06062 Mdot
.534 .06062 Mdot
.534 .06071 Mdot
.534 .06083 Mdot
.534 .06085 Mdot
.534 .0609 Mdot
.534 .06119 Mdot
.534 .06131 Mdot
.534 .06148 Mdot
.534 .06163 Mdot
.534 .06166 Mdot
.534 .06211 Mdot
.534 .06234 Mdot
.534 .06235 Mdot
.534 .06236 Mdot
.534 .06279 Mdot
.534 .06309 Mdot
.534 .06346 Mdot
.534 .06354 Mdot
.534 .06374 Mdot
.534 .06374 Mdot
.534 .06384 Mdot
.534 .06397 Mdot
.534 .06399 Mdot
.534 .06405 Mdot
.534 .06435 Mdot
.534 .06447 Mdot
.534 .06466 Mdot
.534 .06482 Mdot
.534 .06485 Mdot
.534 .06534 Mdot
.534 .06558 Mdot
.534 .06559 Mdot
.534 .0656 Mdot
.534 .06606 Mdot
.534 .06637 Mdot
.534 .06678 Mdot
.534 .06686 Mdot
.534 .06707 Mdot
.534 .06707 Mdot
.534 .06718 Mdot
.534 .06732 Mdot
.534 .06734 Mdot
.534 .0674 Mdot
.534 .06773 Mdot
.534 .06786 Mdot
.534 .06805 Mdot
.534 .06822 Mdot
.534 .06826 Mdot
.534 .06878 Mdot
.534 .06904 Mdot
.534 .06905 Mdot
.534 .06906 Mdot
.534 .06955 Mdot
.534 .06989 Mdot
.534 .07032 Mdot
.534 .0704 Mdot
.534 .07063 Mdot
.534 .07064 Mdot
.534 .07075 Mdot
.534 .0709 Mdot
.534 .07091 Mdot
.534 .07098 Mdot
.534 .07133 Mdot
.534 .07147 Mdot
.534 .07168 Mdot
.534 .07186 Mdot
.534 .0719 Mdot
.534 .07245 Mdot
.534 .07273 Mdot
.534 .07274 Mdot
.534 .07275 Mdot
.534 .07328 Mdot
.534 .07364 Mdot
.534 .0741 Mdot
.534 .07419 Mdot
.534 .07444 Mdot
.534 .07444 Mdot
.534 .07456 Mdot
.534 .07472 Mdot
.534 .07474 Mdot
.534 .07481 Mdot
.534 .07518 Mdot
.534 .07533 Mdot
.534 .07556 Mdot
.534 .07575 Mdot
.534 .07579 Mdot
.534 .07638 Mdot
.534 .07668 Mdot
.534 .07669 Mdot
.534 .0767 Mdot
.534 .07727 Mdot
.534 .07765 Mdot
.534 .07814 Mdot
.534 .07824 Mdot
.534 .0785 Mdot
.534 .0785 Mdot
.534 .07862 Mdot
.534 .0788 Mdot
.534 .07882 Mdot
.534 .0789 Mdot
.534 .07929 Mdot
.534 .07945 Mdot
.534 .07969 Mdot
.534 .0799 Mdot
.534 .07995 Mdot
.534 .08057 Mdot
.534 .08089 Mdot
.534 .0809 Mdot
.534 .08091 Mdot
.534 .08152 Mdot
.534 .08193 Mdot
.534 .08245 Mdot
.534 .08256 Mdot
.534 .08284 Mdot
.534 .08284 Mdot
.534 .08297 Mdot
.534 .08315 Mdot
.534 .08318 Mdot
.534 .08326 Mdot
.534 .08368 Mdot
.534 .08386 Mdot
.534 .08411 Mdot
.534 .08433 Mdot
.534 .08438 Mdot
.534 .08505 Mdot
.534 .08539 Mdot
.534 .08541 Mdot
.534 .08541 Mdot
.534 .08606 Mdot
.534 .0865 Mdot
.534 .08706 Mdot
.534 .08717 Mdot
.534 .08747 Mdot
.534 .08747 Mdot
.534 .08761 Mdot
.534 .08781 Mdot
.534 .08783 Mdot
.534 .08792 Mdot
.534 .08837 Mdot
.534 .08856 Mdot
.534 .08883 Mdot
.534 .08906 Mdot
.534 .08912 Mdot
.534 .08984 Mdot
.534 .0902 Mdot
.534 .09021 Mdot
.534 .09022 Mdot
.534 .09091 Mdot
.534 .09138 Mdot
.534 .09198 Mdot
.534 .0921 Mdot
.534 .09241 Mdot
.534 .09242 Mdot
.534 .09257 Mdot
.534 .09278 Mdot
.534 .0928 Mdot
.534 .0929 Mdot
.534 .09338 Mdot
.534 .09358 Mdot
.534 .09387 Mdot
.534 .09412 Mdot
.534 .09418 Mdot
.534 .09494 Mdot
.534 .09533 Mdot
.534 .09535 Mdot
.534 .09536 Mdot
.534 .09609 Mdot
.534 .09659 Mdot
.534 .09723 Mdot
.534 .09736 Mdot
.534 .0977 Mdot
.534 .0977 Mdot
.534 .09786 Mdot
.534 .09809 Mdot
.534 .09811 Mdot
.534 .09821 Mdot
.534 .09873 Mdot
.534 .09894 Mdot
.534 .09925 Mdot
.534 .09952 Mdot
.534 .09958 Mdot
.534 .1004 Mdot
.534 .10081 Mdot
.534 .10083 Mdot
.534 .10084 Mdot
.534 .10163 Mdot
.534 .10216 Mdot
.534 .10284 Mdot
.534 .10298 Mdot
.534 .10334 Mdot
.534 .10334 Mdot
.534 .10352 Mdot
.534 .10376 Mdot
.534 .10378 Mdot
.534 .10389 Mdot
.534 .10445 Mdot
.534 .10467 Mdot
.534 .105 Mdot
.534 .10529 Mdot
.534 .10535 Mdot
.534 .10623 Mdot
.534 .10666 Mdot
.534 .10668 Mdot
.534 .1067 Mdot
.534 .10754 Mdot
.534 .1081 Mdot
.534 .10884 Mdot
.534 .10898 Mdot
.534 .10937 Mdot
.534 .10937 Mdot
.534 .10956 Mdot
.534 .10981 Mdot
.534 .10984 Mdot
.534 .10996 Mdot
.534 .11055 Mdot
.534 .11078 Mdot
.534 .11114 Mdot
.534 .11144 Mdot
.534 .11152 Mdot
.534 .11245 Mdot
.534 .11292 Mdot
.534 .11294 Mdot
.534 .11295 Mdot
.534 .11385 Mdot
.534 .11445 Mdot
.534 .11524 Mdot
.534 .11539 Mdot
.534 .1158 Mdot
.534 .11581 Mdot
.534 .116 Mdot
.534 .11628 Mdot
.534 .11631 Mdot
.534 .11643 Mdot
.534 .11706 Mdot
.534 .11732 Mdot
.534 .1177 Mdot
.534 .11802 Mdot
.534 .1181 Mdot
.534 .11909 Mdot
.534 .11959 Mdot
.534 .11962 Mdot
.534 .11963 Mdot
.534 .12059 Mdot
.534 .12124 Mdot
.534 .12207 Mdot
.534 .12223 Mdot
.534 .12268 Mdot
.534 .12268 Mdot
.534 .12289 Mdot
.534 .12318 Mdot
.534 .12322 Mdot
.534 .12335 Mdot
.534 .12402 Mdot
.534 .12429 Mdot
.534 .1247 Mdot
.534 .12505 Mdot
.534 .12513 Mdot
.534 .12619 Mdot
.534 .12673 Mdot
.534 .12675 Mdot
.534 .12676 Mdot
.534 .12779 Mdot
.534 .12848 Mdot
.534 .12937 Mdot
.534 .12955 Mdot
.534 .13002 Mdot
.534 .13002 Mdot
.534 .13025 Mdot
.534 .13056 Mdot
.534 .1306 Mdot
.534 .13074 Mdot
.534 .13146 Mdot
.534 .13175 Mdot
.534 .13218 Mdot
.534 .13255 Mdot
.534 .13264 Mdot
.534 .13377 Mdot
.534 .13434 Mdot
.534 .13437 Mdot
.534 .13438 Mdot
.534 .13548 Mdot
.534 .13622 Mdot
.534 .13717 Mdot
.534 .13735 Mdot
.534 .13786 Mdot
.534 .13786 Mdot
.534 .1381 Mdot
.534 .13844 Mdot
.534 .13848 Mdot
.534 .13863 Mdot
.534 .1394 Mdot
.534 .1397 Mdot
.534 .14017 Mdot
.534 .14056 Mdot
.534 .14066 Mdot
.534 .14187 Mdot
.534 .14248 Mdot
.534 .14251 Mdot
.534 .14252 Mdot
.534 .14369 Mdot
.534 .14448 Mdot
.534 .1455 Mdot
.534 .14569 Mdot
.534 .14623 Mdot
.534 .14624 Mdot
.534 .14649 Mdot
.534 .14685 Mdot
.534 .14689 Mdot
.534 .14705 Mdot
.534 .14787 Mdot
.534 .1482 Mdot
.534 .1487 Mdot
.534 .14912 Mdot
.534 .14922 Mdot
.534 .15051 Mdot
.534 .15117 Mdot
.534 .1512 Mdot
.534 .15121 Mdot
.534 .15246 Mdot
.534 .1533 Mdot
.534 .15439 Mdot
.534 .1546 Mdot
.534 .15518 Mdot
.534 .15518 Mdot
.534 .15546 Mdot
.534 .15584 Mdot
.534 .15588 Mdot
.534 .15605 Mdot
.534 .15693 Mdot
.534 .15728 Mdot
.534 .15781 Mdot
.534 .15826 Mdot
.534 .15837 Mdot
.534 .15975 Mdot
.534 .16044 Mdot
.534 .16048 Mdot
.534 .16049 Mdot
.534 .16183 Mdot
.534 .16273 Mdot
.534 .16389 Mdot
.534 .16411 Mdot
.534 .16473 Mdot
.534 .16473 Mdot
.534 .16503 Mdot
.534 .16543 Mdot
.534 .16548 Mdot
.534 .16566 Mdot
.534 .1666 Mdot
.534 .16697 Mdot
.534 .16754 Mdot
.534 .16802 Mdot
.534 .16813 Mdot
.534 .16961 Mdot
.534 .17035 Mdot
.534 .17039 Mdot
.534 .17041 Mdot
.534 .17183 Mdot
.534 .17279 Mdot
.534 .17403 Mdot
.534 .17427 Mdot
.534 .17493 Mdot
.534 .17493 Mdot
.534 .17525 Mdot
.534 .17568 Mdot
.534 .17573 Mdot
.534 .17593 Mdot
.534 .17693 Mdot
.534 .17733 Mdot
.534 .17793 Mdot
.534 .17844 Mdot
.534 .17857 Mdot
.534 .18014 Mdot
.534 .18094 Mdot
.534 .18097 Mdot
.534 .18099 Mdot
.534 .18252 Mdot
.534 .18354 Mdot
.534 .18486 Mdot
.534 .18512 Mdot
.534 .18583 Mdot
.534 .18583 Mdot
.534 .18616 Mdot
.534 .18663 Mdot
.534 .18668 Mdot
.534 .18689 Mdot
.534 .18796 Mdot
.534 .18839 Mdot
.534 .18903 Mdot
.534 .18958 Mdot
.534 .18971 Mdot
.534 .19139 Mdot
.534 .19224 Mdot
.534 .19228 Mdot
.534 .1923 Mdot
.534 .19393 Mdot
.534 .19502 Mdot
.534 .19643 Mdot
.534 .19671 Mdot
.534 .19746 Mdot
.534 .19746 Mdot
.534 .19782 Mdot
.534 .19832 Mdot
.534 .19837 Mdot
.534 .1986 Mdot
.534 .19974 Mdot
.534 .2002 Mdot
.534 .20088 Mdot
.534 .20147 Mdot
.534 .20161 Mdot
.534 .20341 Mdot
.534 .20431 Mdot
.534 .20435 Mdot
.534 .20438 Mdot
.534 .20611 Mdot
.534 .20728 Mdot
.534 .20879 Mdot
.534 .20908 Mdot
.534 .20989 Mdot
.534 .20989 Mdot
.534 .21027 Mdot
.534 .2108 Mdot
.534 .21086 Mdot
.534 .2111 Mdot
.534 .21232 Mdot
.534 .21281 Mdot
.534 .21354 Mdot
.534 .21417 Mdot
.534 .21432 Mdot
.534 .21624 Mdot
.534 .2172 Mdot
.534 .21725 Mdot
.534 .21727 Mdot
.534 .21913 Mdot
.534 .22037 Mdot
.534 .22199 Mdot
.534 .2223 Mdot
.534 .22316 Mdot
.534 .22316 Mdot
.534 .22357 Mdot
.534 .22414 Mdot
.534 .2242 Mdot
.534 .22446 Mdot
.534 .22576 Mdot
.534 .22628 Mdot
.534 .22706 Mdot
.534 .22773 Mdot
.534 .22789 Mdot
.534 .22994 Mdot
.534 .23097 Mdot
.534 .23102 Mdot
.534 .23105 Mdot
.534 .23303 Mdot
.534 .23436 Mdot
.534 .23608 Mdot
.534 .23642 Mdot
.534 .23733 Mdot
.534 .23734 Mdot
.534 .23777 Mdot
.534 .23838 Mdot
.534 .23844 Mdot
.534 .23872 Mdot
.534 .24011 Mdot
.534 .24067 Mdot
.534 .2415 Mdot
.534 .24239 Mdot
.534 .24458 Mdot
.534 .24568 Mdot
.534 .24573 Mdot
.534 .24576 Mdot
.534 .24788 Mdot
.534 .24929 Mdot
.534 .25113 Mdot
.534 .25149 Mdot
.534 .25247 Mdot
.534 .25247 Mdot
.534 .25294 Mdot
.534 .25359 Mdot
.534 .25366 Mdot
.534 .25395 Mdot
.534 .25543 Mdot
.534 .25603 Mdot
.534 .25692 Mdot
.534 .25787 Mdot
.534 .26021 Mdot
.534 .26138 Mdot
.534 .26144 Mdot
.534 .26147 Mdot
.534 .26373 Mdot
.534 .26525 Mdot
.534 .26721 Mdot
.534 .26759 Mdot
.534 .26864 Mdot
.534 .26864 Mdot
.534 .26914 Mdot
.534 .26983 Mdot
.534 .26991 Mdot
.534 .27022 Mdot
.534 .2718 Mdot
.534 .27244 Mdot
.534 .27339 Mdot
.534 .2744 Mdot
.534 .2769 Mdot
.534 .27816 Mdot
.534 .27822 Mdot
.534 .27825 Mdot
.534 .28066 Mdot
.534 .28228 Mdot
.534 .28438 Mdot
.534 .28479 Mdot
.534 .28591 Mdot
.534 .28591 Mdot
.534 .28644 Mdot
.534 .28718 Mdot
.534 .28726 Mdot
.534 .28759 Mdot
.534 .28928 Mdot
.534 .28996 Mdot
.534 .29098 Mdot
.534 .29206 Mdot
.534 .29473 Mdot
.534 .29607 Mdot
.534 .29613 Mdot
.534 .29617 Mdot
.534 .29875 Mdot
.534 .30048 Mdot
.534 .30272 Mdot
.534 .30315 Mdot
.534 .30435 Mdot
.534 .30435 Mdot
.534 .30492 Mdot
.534 .3057 Mdot
.534 .30579 Mdot
.534 .30615 Mdot
.534 .30796 Mdot
.534 .30868 Mdot
.534 .30977 Mdot
.534 .31092 Mdot
.534 .31377 Mdot
.534 .3152 Mdot
.534 .31527 Mdot
.534 .31531 Mdot
.534 .31806 Mdot
.534 .31991 Mdot
.534 .3223 Mdot
.534 .32277 Mdot
.534 .32404 Mdot
.534 .32404 Mdot
.534 .32465 Mdot
.534 .32549 Mdot
.534 .32558 Mdot
.534 .32597 Mdot
.534 .3279 Mdot
.534 .32867 Mdot
.534 .32983 Mdot
.536 .01634 Mdot
.536 .01646 Mdot
.536 .01658 Mdot
.536 .01672 Mdot
.536 .01686 Mdot
.536 .01702 Mdot
.536 .01718 Mdot
.536 .01736 Mdot
.536 .01755 Mdot
.536 .01775 Mdot
.536 .01797 Mdot
.536 .01804 Mdot
.536 .01821 Mdot
.536 .01828 Mdot
.536 .01846 Mdot
.536 .01853 Mdot
.536 .01873 Mdot
.536 .01881 Mdot
.536 .01902 Mdot
.536 .01905 Mdot
.536 .0191 Mdot
.536 .01932 Mdot
.536 .01936 Mdot
.536 .01941 Mdot
.536 .01942 Mdot
.536 .01966 Mdot
.536 .0197 Mdot
.536 .01974 Mdot
.536 .01976 Mdot
.536 .01996 Mdot
.536 .02001 Mdot
.536 .02005 Mdot
.536 .02011 Mdot
.536 .02012 Mdot
.536 .02034 Mdot
.536 .02039 Mdot
.536 .02044 Mdot
.536 .02046 Mdot
.536 .02049 Mdot
.536 .02051 Mdot
.536 .02053 Mdot
.536 .02074 Mdot
.536 .0208 Mdot
.536 .02085 Mdot
.536 .02088 Mdot
.536 .02091 Mdot
.536 .02093 Mdot
.536 .02095 Mdot
.536 .02117 Mdot
.536 .02124 Mdot
.536 .02129 Mdot
.536 .02132 Mdot
.536 .02136 Mdot
.536 .02138 Mdot
.536 .0214 Mdot
.536 .02164 Mdot
.536 .02171 Mdot
.536 .02177 Mdot
.536 .02179 Mdot
.536 .02184 Mdot
.536 .02186 Mdot
.536 .02186 Mdot
.536 .02188 Mdot
.536 .02214 Mdot
.536 .02221 Mdot
.536 .02227 Mdot
.536 .0223 Mdot
.536 .02235 Mdot
.536 .02237 Mdot
.536 .02238 Mdot
.536 .02239 Mdot
.536 .02267 Mdot
.536 .02275 Mdot
.536 .02282 Mdot
.536 .02285 Mdot
.536 .0229 Mdot
.536 .02292 Mdot
.536 .02293 Mdot
.536 .02295 Mdot
.536 .02324 Mdot
.536 .02333 Mdot
.536 .0234 Mdot
.536 .02344 Mdot
.536 .02349 Mdot
.536 .02351 Mdot
.536 .02352 Mdot
.536 .02353 Mdot
.536 .02354 Mdot
.536 .02372 Mdot
.536 .02386 Mdot
.536 .02395 Mdot
.536 .02403 Mdot
.536 .02406 Mdot
.536 .02412 Mdot
.536 .02415 Mdot
.536 .02415 Mdot
.536 .02417 Mdot
.536 .02418 Mdot
.536 .02437 Mdot
.536 .02452 Mdot
.536 .02462 Mdot
.536 .02468 Mdot
.536 .0247 Mdot
.536 .02474 Mdot
.536 .02479 Mdot
.536 .02482 Mdot
.536 .02483 Mdot
.536 .02485 Mdot
.536 .02486 Mdot
.536 .025 Mdot
.536 .02507 Mdot
.536 .02522 Mdot
.536 .02533 Mdot
.536 .02537 Mdot
.536 .0254 Mdot
.536 .02541 Mdot
.536 .02546 Mdot
.536 .02552 Mdot
.536 .02555 Mdot
.536 .02556 Mdot
.536 .02558 Mdot
.536 .02559 Mdot
.536 .02572 Mdot
.536 .02574 Mdot
.536 .02581 Mdot
.536 .02598 Mdot
.536 .0261 Mdot
.536 .02613 Mdot
.536 .02616 Mdot
.536 .02619 Mdot
.536 .02623 Mdot
.536 .0263 Mdot
.536 .02633 Mdot
.536 .02634 Mdot
.536 .02636 Mdot
.536 .02637 Mdot
.536 .02651 Mdot
.536 .02654 Mdot
.536 .02661 Mdot
.536 .02679 Mdot
.536 .02692 Mdot
.536 .02695 Mdot
.536 .02699 Mdot
.536 .02701 Mdot
.536 .02706 Mdot
.536 .02713 Mdot
.536 .02717 Mdot
.536 .02718 Mdot
.536 .0272 Mdot
.536 .02721 Mdot
.536 .02736 Mdot
.536 .02739 Mdot
.536 .02747 Mdot
.536 .02766 Mdot
.536 .02779 Mdot
.536 .02784 Mdot
.536 .02787 Mdot
.536 .0279 Mdot
.536 .02795 Mdot
.536 .02803 Mdot
.536 .02807 Mdot
.536 .02808 Mdot
.536 .02809 Mdot
.536 .02811 Mdot
.536 .02827 Mdot
.536 .0283 Mdot
.536 .02839 Mdot
.536 .02859 Mdot
.536 .02874 Mdot
.536 .02878 Mdot
.536 .02882 Mdot
.536 .02884 Mdot
.536 .02885 Mdot
.536 .0289 Mdot
.536 .02899 Mdot
.536 .02903 Mdot
.536 .02904 Mdot
.536 .02906 Mdot
.536 .02907 Mdot
.536 .02925 Mdot
.536 .02928 Mdot
.536 .02937 Mdot
.536 .02959 Mdot
.536 .02967 Mdot
.536 .02975 Mdot
.536 .02979 Mdot
.536 .02984 Mdot
.536 .02986 Mdot
.536 .02986 Mdot
.536 .02993 Mdot
.536 .03001 Mdot
.536 .03006 Mdot
.536 .03007 Mdot
.536 .03009 Mdot
.536 .03011 Mdot
.536 .03029 Mdot
.536 .03033 Mdot
.536 .03043 Mdot
.536 .03047 Mdot
.536 .03066 Mdot
.536 .03074 Mdot
.536 .03083 Mdot
.536 .03088 Mdot
.536 .03092 Mdot
.536 .03095 Mdot
.536 .03095 Mdot
.536 .03102 Mdot
.536 .03111 Mdot
.536 .03116 Mdot
.536 .03118 Mdot
.536 .0312 Mdot
.536 .03121 Mdot
.536 .03141 Mdot
.536 .03145 Mdot
.536 .03156 Mdot
.536 .03161 Mdot
.536 .03181 Mdot
.536 .0319 Mdot
.536 .03199 Mdot
.536 .03204 Mdot
.536 .03209 Mdot
.536 .03212 Mdot
.536 .03212 Mdot
.536 .03219 Mdot
.536 .03229 Mdot
.536 .03235 Mdot
.536 .03236 Mdot
.536 .03238 Mdot
.536 .0324 Mdot
.536 .03257 Mdot
.536 .03262 Mdot
.536 .03266 Mdot
.536 .03277 Mdot
.536 .03282 Mdot
.536 .03304 Mdot
.536 .03313 Mdot
.536 .03323 Mdot
.536 .03329 Mdot
.536 .03334 Mdot
.536 .03337 Mdot
.536 .03338 Mdot
.536 .03345 Mdot
.536 .03355 Mdot
.536 .03356 Mdot
.536 .03362 Mdot
.536 .03363 Mdot
.536 .03366 Mdot
.536 .03368 Mdot
.536 .03386 Mdot
.536 .0339 Mdot
.536 .03395 Mdot
.536 .03407 Mdot
.536 .03413 Mdot
.536 .03436 Mdot
.536 .03446 Mdot
.536 .03456 Mdot
.536 .03463 Mdot
.536 .03468 Mdot
.536 .03472 Mdot
.536 .03472 Mdot
.536 .0348 Mdot
.536 .03491 Mdot
.536 .03492 Mdot
.536 .03498 Mdot
.536 .035 Mdot
.536 .03502 Mdot
.536 .03504 Mdot
.536 .03523 Mdot
.536 .03529 Mdot
.536 .03534 Mdot
.536 .03547 Mdot
.536 .03553 Mdot
.536 .03577 Mdot
.536 .03588 Mdot
.536 .03599 Mdot
.536 .03606 Mdot
.536 .03612 Mdot
.536 .03616 Mdot
.536 .03616 Mdot
.536 .03625 Mdot
.536 .03636 Mdot
.536 .03637 Mdot
.536 .03644 Mdot
.536 .03646 Mdot
.536 .03648 Mdot
.536 .0365 Mdot
.536 .03671 Mdot
.536 .03677 Mdot
.536 .03682 Mdot
.536 .03696 Mdot
.536 .03702 Mdot
.536 .03729 Mdot
.536 .03741 Mdot
.536 .03753 Mdot
.536 .0376 Mdot
.536 .03766 Mdot
.536 .0377 Mdot
.536 .0377 Mdot
.536 .0378 Mdot
.536 .03792 Mdot
.536 .03793 Mdot
.536 .038 Mdot
.536 .03802 Mdot
.536 .03805 Mdot
.536 .03807 Mdot
.536 .0383 Mdot
.536 .03835 Mdot
.536 .03841 Mdot
.536 .03856 Mdot
.536 .03863 Mdot
.536 .03892 Mdot
.536 .03904 Mdot
.536 .03917 Mdot
.536 .03925 Mdot
.536 .03932 Mdot
.536 .03935 Mdot
.536 .03936 Mdot
.536 .03946 Mdot
.536 .03959 Mdot
.536 .0396 Mdot
.536 .03968 Mdot
.536 .0397 Mdot
.536 .03973 Mdot
.536 .03975 Mdot
.536 .03999 Mdot
.536 .04006 Mdot
.536 .04012 Mdot
.536 .04028 Mdot
.536 .04035 Mdot
.536 .04066 Mdot
.536 .04079 Mdot
.536 .04093 Mdot
.536 .04101 Mdot
.536 .04109 Mdot
.536 .04113 Mdot
.536 .04113 Mdot
.536 .04124 Mdot
.536 .04138 Mdot
.536 .04139 Mdot
.536 .04147 Mdot
.536 .0415 Mdot
.536 .04153 Mdot
.536 .04156 Mdot
.536 .04181 Mdot
.536 .04188 Mdot
.536 .04195 Mdot
.536 .04212 Mdot
.536 .0422 Mdot
.536 .04253 Mdot
.536 .04267 Mdot
.536 .04282 Mdot
.536 .04291 Mdot
.536 .04299 Mdot
.536 .04303 Mdot
.536 .04304 Mdot
.536 .04315 Mdot
.536 .0433 Mdot
.536 .04332 Mdot
.536 .0434 Mdot
.536 .04343 Mdot
.536 .04346 Mdot
.536 .04349 Mdot
.536 .04376 Mdot
.536 .04384 Mdot
.536 .04391 Mdot
.536 .04409 Mdot
.536 .04418 Mdot
.536 .04453 Mdot
.536 .04468 Mdot
.536 .04484 Mdot
.536 .04493 Mdot
.536 .04502 Mdot
.536 .04507 Mdot
.536 .04507 Mdot
.536 .0452 Mdot
.536 .04536 Mdot
.536 .04537 Mdot
.536 .04546 Mdot
.536 .0455 Mdot
.536 .04553 Mdot
.536 .04556 Mdot
.536 .04586 Mdot
.536 .04593 Mdot
.536 .04601 Mdot
.536 .04621 Mdot
.536 .0463 Mdot
.536 .04668 Mdot
.536 .04684 Mdot
.536 .04701 Mdot
.536 .04711 Mdot
.536 .0472 Mdot
.536 .04725 Mdot
.536 .04726 Mdot
.536 .04739 Mdot
.536 .04756 Mdot
.536 .04758 Mdot
.536 .04768 Mdot
.536 .04771 Mdot
.536 .04775 Mdot
.536 .04778 Mdot
.536 .0481 Mdot
.536 .04818 Mdot
.536 .04826 Mdot
.536 .04847 Mdot
.536 .04857 Mdot
.536 .04898 Mdot
.536 .04915 Mdot
.536 .04933 Mdot
.536 .04944 Mdot
.536 .04954 Mdot
.536 .0496 Mdot
.536 .0496 Mdot
.536 .04975 Mdot
.536 .04993 Mdot
.536 .04995 Mdot
.536 .05005 Mdot
.536 .05009 Mdot
.536 .05013 Mdot
.536 .05016 Mdot
.536 .0505 Mdot
.536 .05059 Mdot
.536 .05068 Mdot
.536 .0509 Mdot
.536 .05101 Mdot
.536 .05144 Mdot
.536 .05163 Mdot
.536 .05183 Mdot
.536 .05194 Mdot
.536 .05205 Mdot
.536 .05211 Mdot
.536 .05212 Mdot
.536 .05227 Mdot
.536 .05246 Mdot
.536 .05249 Mdot
.536 .0526 Mdot
.536 .05263 Mdot
.536 .05268 Mdot
.536 .05272 Mdot
.536 .05308 Mdot
.536 .05317 Mdot
.536 .05327 Mdot
.536 .05351 Mdot
.536 .05362 Mdot
.536 .05409 Mdot
.536 .05429 Mdot
.536 .0545 Mdot
.536 .05462 Mdot
.536 .05474 Mdot
.536 .0548 Mdot
.536 .05481 Mdot
.536 .05497 Mdot
.536 .05518 Mdot
.536 .0552 Mdot
.536 .05532 Mdot
.536 .05536 Mdot
.536 .05541 Mdot
.536 .05545 Mdot
.536 .05584 Mdot
.536 .05594 Mdot
.536 .05604 Mdot
.536 .0563 Mdot
.536 .05643 Mdot
.536 .05692 Mdot
.536 .05714 Mdot
.536 .05736 Mdot
.536 .0575 Mdot
.536 .05762 Mdot
.536 .05769 Mdot
.536 .05769 Mdot
.536 .05787 Mdot
.536 .05809 Mdot
.536 .05812 Mdot
.536 .05825 Mdot
.536 .05829 Mdot
.536 .05834 Mdot
.536 .05839 Mdot
.536 .0588 Mdot
.536 .05891 Mdot
.536 .05902 Mdot
.536 .0593 Mdot
.536 .05943 Mdot
.536 .05996 Mdot
.536 .06019 Mdot
.536 .06043 Mdot
.536 .06058 Mdot
.536 .06071 Mdot
.536 .06078 Mdot
.536 .06079 Mdot
.536 .06098 Mdot
.536 .06122 Mdot
.536 .06125 Mdot
.536 .06138 Mdot
.536 .06143 Mdot
.536 .06148 Mdot
.536 .06153 Mdot
.536 .06198 Mdot
.536 .06209 Mdot
.536 .06221 Mdot
.536 .06251 Mdot
.536 .06265 Mdot
.536 .06322 Mdot
.536 .06347 Mdot
.536 .06373 Mdot
.536 .06388 Mdot
.536 .06402 Mdot
.536 .0641 Mdot
.536 .06411 Mdot
.536 .06431 Mdot
.536 .06457 Mdot
.536 .0646 Mdot
.536 .06474 Mdot
.536 .06479 Mdot
.536 .06485 Mdot
.536 .0649 Mdot
.536 .06538 Mdot
.536 .0655 Mdot
.536 .06563 Mdot
.536 .06595 Mdot
.536 .0661 Mdot
.536 .06671 Mdot
.536 .06698 Mdot
.536 .06725 Mdot
.536 .06742 Mdot
.536 .06757 Mdot
.536 .06765 Mdot
.536 .06766 Mdot
.536 .06788 Mdot
.536 .06816 Mdot
.536 .06819 Mdot
.536 .06834 Mdot
.536 .0684 Mdot
.536 .06846 Mdot
.536 .06851 Mdot
.536 .06903 Mdot
.536 .06916 Mdot
.536 .06929 Mdot
.536 .06964 Mdot
.536 .0698 Mdot
.536 .07046 Mdot
.536 .07074 Mdot
.536 .07104 Mdot
.536 .07121 Mdot
.536 .07137 Mdot
.536 .07146 Mdot
.536 .07148 Mdot
.536 .07171 Mdot
.536 .072 Mdot
.536 .07204 Mdot
.536 .0722 Mdot
.536 .07226 Mdot
.536 .07233 Mdot
.536 .07239 Mdot
.536 .07294 Mdot
.536 .07308 Mdot
.536 .07322 Mdot
.536 .07359 Mdot
.536 .07376 Mdot
.536 .07447 Mdot
.536 .07477 Mdot
.536 .07509 Mdot
.536 .07528 Mdot
.536 .07545 Mdot
.536 .07555 Mdot
.536 .07556 Mdot
.536 .07581 Mdot
.536 .07613 Mdot
.536 .07616 Mdot
.536 .07634 Mdot
.536 .07641 Mdot
.536 .07647 Mdot
.536 .07654 Mdot
.536 .07713 Mdot
.536 .07728 Mdot
.536 .07744 Mdot
.536 .07783 Mdot
.536 .07802 Mdot
.536 .07877 Mdot
.536 .0791 Mdot
.536 .07944 Mdot
.536 .07964 Mdot
.536 .07983 Mdot
.536 .07993 Mdot
.536 .07994 Mdot
.536 .08021 Mdot
.536 .08055 Mdot
.536 .08059 Mdot
.536 .08078 Mdot
.536 .08085 Mdot
.536 .08092 Mdot
.536 .08099 Mdot
.536 .08162 Mdot
.536 .08179 Mdot
.536 .08195 Mdot
.536 .08238 Mdot
.536 .08257 Mdot
.536 .08338 Mdot
.536 .08373 Mdot
.536 .0841 Mdot
.536 .08432 Mdot
.536 .08452 Mdot
.536 .08462 Mdot
.536 .08464 Mdot
.536 .08493 Mdot
.536 .08529 Mdot
.536 .08533 Mdot
.536 .08554 Mdot
.536 .08561 Mdot
.536 .08569 Mdot
.536 .08576 Mdot
.536 .08644 Mdot
.536 .08662 Mdot
.536 .08679 Mdot
.536 .08725 Mdot
.536 .08746 Mdot
.536 .08833 Mdot
.536 .0887 Mdot
.536 .0891 Mdot
.536 .08933 Mdot
.536 .08954 Mdot
.536 .08966 Mdot
.536 .08967 Mdot
.536 .08998 Mdot
.536 .09037 Mdot
.536 .09042 Mdot
.536 .09064 Mdot
.536 .09071 Mdot
.536 .0908 Mdot
.536 .09088 Mdot
.536 .0916 Mdot
.536 .0918 Mdot
.536 .09198 Mdot
.536 .09247 Mdot
.536 .0927 Mdot
.536 .09363 Mdot
.536 .09403 Mdot
.536 .09445 Mdot
.536 .0947 Mdot
.536 .09493 Mdot
.536 .09505 Mdot
.536 .09507 Mdot
.536 .0954 Mdot
.536 .09582 Mdot
.536 .09587 Mdot
.536 .0961 Mdot
.536 .09618 Mdot
.536 .09627 Mdot
.536 .09636 Mdot
.536 .09714 Mdot
.536 .09735 Mdot
.536 .09755 Mdot
.536 .09807 Mdot
.536 .09831 Mdot
.536 .09931 Mdot
.536 .09974 Mdot
.536 .10019 Mdot
.536 .10046 Mdot
.536 .1007 Mdot
.536 .10084 Mdot
.536 .10086 Mdot
.536 .10121 Mdot
.536 .10166 Mdot
.536 .10171 Mdot
.536 .10196 Mdot
.536 .10205 Mdot
.536 .10215 Mdot
.536 .10224 Mdot
.536 .10307 Mdot
.536 .10329 Mdot
.536 .10351 Mdot
.536 .10407 Mdot
.536 .10433 Mdot
.536 .1054 Mdot
.536 .10586 Mdot
.536 .10635 Mdot
.536 .10663 Mdot
.536 .1069 Mdot
.536 .10704 Mdot
.536 .10706 Mdot
.536 .10744 Mdot
.536 .10792 Mdot
.536 .10797 Mdot
.536 .10825 Mdot
.536 .10834 Mdot
.536 .10844 Mdot
.536 .10854 Mdot
.536 .10944 Mdot
.536 .10967 Mdot
.536 .1099 Mdot
.536 .1105 Mdot
.536 .11078 Mdot
.536 .11193 Mdot
.536 .11242 Mdot
.536 .11294 Mdot
.536 .11325 Mdot
.536 .11353 Mdot
.536 .11369 Mdot
.536 .11371 Mdot
.536 .11412 Mdot
.536 .11463 Mdot
.536 .11469 Mdot
.536 .11498 Mdot
.536 .11508 Mdot
.536 .11519 Mdot
.536 .1153 Mdot
.536 .11626 Mdot
.536 .11651 Mdot
.536 .11676 Mdot
.536 .1174 Mdot
.536 .1177 Mdot
.536 .11893 Mdot
.536 .11946 Mdot
.536 .12002 Mdot
.536 .12035 Mdot
.536 .12065 Mdot
.536 .12081 Mdot
.536 .12083 Mdot
.536 .12127 Mdot
.536 .12182 Mdot
.536 .12189 Mdot
.536 .1222 Mdot
.536 .12231 Mdot
.536 .12242 Mdot
.536 .12254 Mdot
.536 .12357 Mdot
.536 .12384 Mdot
.536 .1241 Mdot
.536 .12479 Mdot
.536 .12512 Mdot
.536 .12643 Mdot
.536 .127 Mdot
.536 .1276 Mdot
.536 .12795 Mdot
.536 .12827 Mdot
.536 .12845 Mdot
.536 .12848 Mdot
.536 .12895 Mdot
.536 .12953 Mdot
.536 .1296 Mdot
.536 .12994 Mdot
.536 .13005 Mdot
.536 .13018 Mdot
.536 .1303 Mdot
.536 .13141 Mdot
.536 .1317 Mdot
.536 .13198 Mdot
.536 .13272 Mdot
.536 .13306 Mdot
.536 .13448 Mdot
.536 .13508 Mdot
.536 .13573 Mdot
.536 .13611 Mdot
.536 .13645 Mdot
.536 .13664 Mdot
.536 .13667 Mdot
.536 .13717 Mdot
.536 .1378 Mdot
.536 .13787 Mdot
.536 .13823 Mdot
.536 .13836 Mdot
.536 .13849 Mdot
.536 .13863 Mdot
.536 .13981 Mdot
.536 .14012 Mdot
.536 .14042 Mdot
.536 .14122 Mdot
.536 .14159 Mdot
.536 .1431 Mdot
.536 .14375 Mdot
.536 .14444 Mdot
.536 .14485 Mdot
.536 .14522 Mdot
.536 .14542 Mdot
.536 .14545 Mdot
.536 .14599 Mdot
.536 .14666 Mdot
.536 .14674 Mdot
.536 .14713 Mdot
.536 .14726 Mdot
.536 .14741 Mdot
.536 .14755 Mdot
.536 .14881 Mdot
.536 .14915 Mdot
.536 .14947 Mdot
.536 .15032 Mdot
.536 .15072 Mdot
.536 .15304 Mdot
.536 .15378 Mdot
.536 .15422 Mdot
.536 .15461 Mdot
.536 .15483 Mdot
.536 .15486 Mdot
.536 .15544 Mdot
.536 .15616 Mdot
.536 .15625 Mdot
.536 .15666 Mdot
.536 .1568 Mdot
.536 .15696 Mdot
.536 .15711 Mdot
.536 .15847 Mdot
.536 .15883 Mdot
.536 .15918 Mdot
.536 .16009 Mdot
.536 .16051 Mdot
.536 .163 Mdot
.536 .16379 Mdot
.536 .16426 Mdot
.536 .16468 Mdot
.536 .16492 Mdot
.536 .16495 Mdot
.536 .16557 Mdot
.536 .16635 Mdot
.536 .16644 Mdot
.536 .16688 Mdot
.536 .16703 Mdot
.536 .1672 Mdot
.536 .16736 Mdot
.536 .16882 Mdot
.536 .1692 Mdot
.536 .16958 Mdot
.536 .17055 Mdot
.536 .17101 Mdot
.536 .17368 Mdot
.536 .17452 Mdot
.536 .17503 Mdot
.536 .17548 Mdot
.536 .17573 Mdot
.536 .17577 Mdot
.536 .17643 Mdot
.536 .17726 Mdot
.536 .17736 Mdot
.536 .17784 Mdot
.536 .178 Mdot
.536 .17818 Mdot
.536 .17836 Mdot
.536 .17991 Mdot
.536 .18033 Mdot
.536 .18073 Mdot
.536 .18177 Mdot
.536 .18226 Mdot
.536 .18512 Mdot
.536 .18603 Mdot
.536 .18657 Mdot
.536 .18706 Mdot
.536 .18733 Mdot
.536 .18736 Mdot
.536 .18808 Mdot
.536 .18897 Mdot
.536 .18907 Mdot
.536 .18958 Mdot
.536 .18976 Mdot
.536 .18995 Mdot
.536 .19014 Mdot
.536 .19181 Mdot
.536 .19225 Mdot
.536 .19268 Mdot
.536 .1938 Mdot
.536 .19433 Mdot
.536 .19739 Mdot
.536 .19836 Mdot
.536 .19894 Mdot
.536 .19947 Mdot
.536 .19975 Mdot
.536 .19979 Mdot
.536 .20056 Mdot
.536 .20151 Mdot
.536 .20162 Mdot
.536 .20217 Mdot
.536 .20236 Mdot
.536 .20257 Mdot
.536 .20277 Mdot
.536 .20456 Mdot
.536 .20503 Mdot
.536 .20549 Mdot
.536 .2067 Mdot
.536 .20726 Mdot
.536 .21054 Mdot
.536 .21159 Mdot
.536 .21221 Mdot
.536 .21277 Mdot
.536 .21308 Mdot
.536 .21312 Mdot
.536 .21394 Mdot
.536 .21496 Mdot
.536 .21508 Mdot
.536 .21567 Mdot
.536 .21587 Mdot
.536 .21609 Mdot
.536 .21631 Mdot
.536 .21823 Mdot
.536 .21873 Mdot
.536 .21923 Mdot
.536 .22052 Mdot
.536 .22112 Mdot
.536 .22464 Mdot
.536 .22576 Mdot
.536 .22643 Mdot
.536 .22703 Mdot
.536 .22736 Mdot
.536 .2274 Mdot
.536 .22828 Mdot
.536 .22938 Mdot
.536 .22951 Mdot
.536 .23014 Mdot
.536 .23035 Mdot
.536 .23059 Mdot
.536 .23082 Mdot
.536 .23288 Mdot
.536 .23342 Mdot
.536 .23396 Mdot
.536 .23534 Mdot
.536 .23598 Mdot
.536 .23976 Mdot
.536 .24096 Mdot
.536 .24167 Mdot
.536 .24231 Mdot
.536 .24267 Mdot
.536 .24272 Mdot
.536 .24366 Mdot
.536 .24484 Mdot
.536 .24497 Mdot
.536 .24565 Mdot
.536 .24588 Mdot
.536 .24613 Mdot
.536 .24638 Mdot
.536 .24859 Mdot
.536 .24917 Mdot
.536 .24974 Mdot
.536 .25122 Mdot
.536 .25191 Mdot
.536 .25596 Mdot
.536 .25725 Mdot
.536 .25801 Mdot
.536 .2587 Mdot
.536 .25908 Mdot
.536 .25913 Mdot
.536 .26014 Mdot
.536 .26141 Mdot
.536 .26155 Mdot
.536 .26227 Mdot
.536 .26252 Mdot
.536 .2628 Mdot
.536 .26306 Mdot
.536 .26543 Mdot
.536 .26605 Mdot
.536 .26666 Mdot
.536 .26825 Mdot
.536 .26899 Mdot
.536 .27333 Mdot
.536 .27471 Mdot
.536 .27553 Mdot
.536 .27627 Mdot
.536 .27668 Mdot
.536 .27673 Mdot
.536 .27781 Mdot
.536 .27917 Mdot
.536 .27932 Mdot
.536 .2801 Mdot
.536 .28036 Mdot
.536 .28066 Mdot
.536 .28094 Mdot
.536 .28348 Mdot
.536 .28415 Mdot
.536 .2848 Mdot
.536 .28651 Mdot
.536 .2873 Mdot
.536 .29195 Mdot
.536 .29343 Mdot
.536 .29431 Mdot
.536 .2951 Mdot
.536 .29554 Mdot
.536 .2956 Mdot
.536 .29676 Mdot
.536 .29821 Mdot
.536 .29838 Mdot
.536 .29921 Mdot
.536 .29949 Mdot
.536 .2998 Mdot
.536 .30011 Mdot
.536 .30283 Mdot
.536 .30355 Mdot
.536 .30425 Mdot
.536 .30607 Mdot
.536 .30693 Mdot
.536 .31191 Mdot
.536 .3135 Mdot
.536 .31444 Mdot
.536 .31529 Mdot
.536 .31576 Mdot
.536 .31582 Mdot
.536 .31706 Mdot
.536 .31862 Mdot
.536 .3188 Mdot
.536 .31969 Mdot
.536 .31999 Mdot
.536 .32033 Mdot
.536 .32066 Mdot
.536 .32357 Mdot
.536 .32434 Mdot
.536 .3251 Mdot
.536 .32705 Mdot
.536 .32797 Mdot
.538 .01476 Mdot
.538 .01476 Mdot
.538 .01477 Mdot
.538 .01477 Mdot
.538 .01477 Mdot
.538 .01478 Mdot
.538 .01478 Mdot
.538 .01479 Mdot
.538 .01479 Mdot
.538 .0148 Mdot
.538 .01481 Mdot
.538 .01481 Mdot
.538 .01482 Mdot
.538 .01483 Mdot
.538 .01484 Mdot
.538 .01485 Mdot
.538 .01486 Mdot
.538 .01487 Mdot
.538 .01488 Mdot
.538 .01489 Mdot
.538 .01491 Mdot
.538 .01492 Mdot
.538 .01494 Mdot
.538 .01495 Mdot
.538 .01497 Mdot
.538 .01499 Mdot
.538 .01501 Mdot
.538 .01504 Mdot
.538 .01506 Mdot
.538 .01509 Mdot
.538 .01511 Mdot
.538 .01514 Mdot
.538 .01518 Mdot
.538 .01521 Mdot
.538 .01525 Mdot
.538 .01525 Mdot
.538 .01529 Mdot
.538 .01529 Mdot
.538 .01533 Mdot
.538 .01533 Mdot
.538 .01538 Mdot
.538 .01538 Mdot
.538 .01543 Mdot
.538 .01543 Mdot
.538 .01549 Mdot
.538 .01549 Mdot
.538 .01554 Mdot
.538 .01554 Mdot
.538 .01561 Mdot
.538 .01561 Mdot
.538 .01567 Mdot
.538 .01568 Mdot
.538 .01575 Mdot
.538 .01575 Mdot
.538 .0158 Mdot
.538 .01583 Mdot
.538 .01583 Mdot
.538 .01588 Mdot
.538 .01591 Mdot
.538 .01591 Mdot
.538 .01597 Mdot
.538 .01598 Mdot
.538 .016 Mdot
.538 .016 Mdot
.538 .01607 Mdot
.538 .01607 Mdot
.538 .0161 Mdot
.538 .0161 Mdot
.538 .01617 Mdot
.538 .01617 Mdot
.538 .0162 Mdot
.538 .01621 Mdot
.538 .01628 Mdot
.538 .01628 Mdot
.538 .01632 Mdot
.538 .01632 Mdot
.538 .0164 Mdot
.538 .0164 Mdot
.538 .01644 Mdot
.538 .01644 Mdot
.538 .01653 Mdot
.538 .01653 Mdot
.538 .01657 Mdot
.538 .01657 Mdot
.538 .01666 Mdot
.538 .01667 Mdot
.538 .01671 Mdot
.538 .01671 Mdot
.538 .01681 Mdot
.538 .01682 Mdot
.538 .01686 Mdot
.538 .01686 Mdot
.538 .01697 Mdot
.538 .01698 Mdot
.538 .01703 Mdot
.538 .01703 Mdot
.538 .01714 Mdot
.538 .01715 Mdot
.538 .0172 Mdot
.538 .0172 Mdot
.538 .01733 Mdot
.538 .01734 Mdot
.538 .01739 Mdot
.538 .01739 Mdot
.538 .01753 Mdot
.538 .01754 Mdot
.538 .01759 Mdot
.538 .0176 Mdot
.538 .01764 Mdot
.538 .01774 Mdot
.538 .01775 Mdot
.538 .01781 Mdot
.538 .01782 Mdot
.538 .01787 Mdot
.538 .01797 Mdot
.538 .01798 Mdot
.538 .01805 Mdot
.538 .01805 Mdot
.538 .01811 Mdot
.538 .01822 Mdot
.538 .01823 Mdot
.538 .0183 Mdot
.538 .0183 Mdot
.538 .01836 Mdot
.538 .01848 Mdot
.538 .0185 Mdot
.538 .01857 Mdot
.538 .01858 Mdot
.538 .01864 Mdot
.538 .01877 Mdot
.538 .01878 Mdot
.538 .01887 Mdot
.538 .01887 Mdot
.538 .01894 Mdot
.538 .01908 Mdot
.538 .01909 Mdot
.538 .01918 Mdot
.538 .01919 Mdot
.538 .01925 Mdot
.538 .01926 Mdot
.538 .01941 Mdot
.538 .01942 Mdot
.538 .01952 Mdot
.538 .01953 Mdot
.538 .01959 Mdot
.538 .01961 Mdot
.538 .01977 Mdot
.538 .01978 Mdot
.538 .01989 Mdot
.538 .01989 Mdot
.538 .01996 Mdot
.538 .01998 Mdot
.538 .02015 Mdot
.538 .02017 Mdot
.538 .02028 Mdot
.538 .02029 Mdot
.538 .02036 Mdot
.538 .02038 Mdot
.538 .02056 Mdot
.538 .02058 Mdot
.538 .0207 Mdot
.538 .02071 Mdot
.538 .02079 Mdot
.538 .02081 Mdot
.538 .02101 Mdot
.538 .02103 Mdot
.538 .02116 Mdot
.538 .02116 Mdot
.538 .02125 Mdot
.538 .02127 Mdot
.538 .02128 Mdot
.538 .02149 Mdot
.538 .02151 Mdot
.538 .02158 Mdot
.538 .02165 Mdot
.538 .02165 Mdot
.538 .02167 Mdot
.538 .02175 Mdot
.538 .02177 Mdot
.538 .02178 Mdot
.538 .022 Mdot
.538 .02202 Mdot
.538 .0221 Mdot
.538 .02218 Mdot
.538 .02218 Mdot
.538 .0222 Mdot
.538 .02229 Mdot
.538 .02231 Mdot
.538 .02232 Mdot
.538 .02247 Mdot
.538 .02255 Mdot
.538 .02258 Mdot
.538 .02266 Mdot
.538 .02274 Mdot
.538 .02275 Mdot
.538 .02277 Mdot
.538 .02286 Mdot
.538 .02288 Mdot
.538 .0229 Mdot
.538 .02306 Mdot
.538 .02315 Mdot
.538 .02318 Mdot
.538 .02326 Mdot
.538 .02335 Mdot
.538 .02336 Mdot
.538 .02338 Mdot
.538 .02348 Mdot
.538 .0235 Mdot
.538 .02352 Mdot
.538 .02369 Mdot
.538 .02379 Mdot
.538 .02382 Mdot
.538 .02391 Mdot
.538 .02401 Mdot
.538 .02402 Mdot
.538 .02404 Mdot
.538 .02415 Mdot
.538 .02417 Mdot
.538 .02419 Mdot
.538 .02437 Mdot
.538 .02448 Mdot
.538 .02451 Mdot
.538 .02461 Mdot
.538 .02472 Mdot
.538 .02472 Mdot
.538 .02474 Mdot
.538 .02486 Mdot
.538 .02489 Mdot
.538 .02491 Mdot
.538 .02511 Mdot
.538 .02522 Mdot
.538 .02526 Mdot
.538 .02536 Mdot
.538 .02548 Mdot
.538 .02548 Mdot
.538 .02551 Mdot
.538 .02563 Mdot
.538 .02566 Mdot
.538 .02568 Mdot
.538 .0259 Mdot
.538 .02602 Mdot
.538 .02606 Mdot
.538 .02617 Mdot
.538 .02625 Mdot
.538 .02629 Mdot
.538 .0263 Mdot
.538 .02633 Mdot
.538 .02646 Mdot
.538 .0265 Mdot
.538 .02651 Mdot
.538 .02675 Mdot
.538 .02688 Mdot
.538 .02692 Mdot
.538 .02704 Mdot
.538 .02712 Mdot
.538 .02717 Mdot
.538 .02718 Mdot
.538 .02721 Mdot
.538 .02736 Mdot
.538 .02739 Mdot
.538 .02741 Mdot
.538 .02766 Mdot
.538 .02781 Mdot
.538 .02785 Mdot
.538 .02798 Mdot
.538 .02807 Mdot
.538 .02812 Mdot
.538 .02813 Mdot
.538 .02816 Mdot
.538 .02832 Mdot
.538 .02835 Mdot
.538 .02837 Mdot
.538 .02865 Mdot
.538 .0288 Mdot
.538 .02885 Mdot
.538 .02899 Mdot
.538 .02908 Mdot
.538 .02914 Mdot
.538 .02915 Mdot
.538 .02918 Mdot
.538 .02935 Mdot
.538 .02939 Mdot
.538 .02941 Mdot
.538 .02952 Mdot
.538 .0297 Mdot
.538 .02987 Mdot
.538 .02992 Mdot
.538 .03007 Mdot
.538 .03017 Mdot
.538 .03023 Mdot
.538 .03025 Mdot
.538 .03028 Mdot
.538 .03046 Mdot
.538 .03051 Mdot
.538 .03053 Mdot
.538 .03065 Mdot
.538 .03084 Mdot
.538 .03102 Mdot
.538 .03108 Mdot
.538 .03124 Mdot
.538 .03135 Mdot
.538 .03141 Mdot
.538 .03143 Mdot
.538 .03146 Mdot
.538 .03166 Mdot
.538 .03171 Mdot
.538 .03173 Mdot
.538 .03176 Mdot
.538 .03186 Mdot
.538 .03207 Mdot
.538 .03226 Mdot
.538 .03232 Mdot
.538 .03249 Mdot
.538 .03261 Mdot
.538 .03268 Mdot
.538 .0327 Mdot
.538 .03274 Mdot
.538 .03295 Mdot
.538 .033 Mdot
.538 .03302 Mdot
.538 .03306 Mdot
.538 .03307 Mdot
.538 .03316 Mdot
.538 .03325 Mdot
.538 .03337 Mdot
.538 .03339 Mdot
.538 .0336 Mdot
.538 .03366 Mdot
.538 .03385 Mdot
.538 .03397 Mdot
.538 .03405 Mdot
.538 .03406 Mdot
.538 .03407 Mdot
.538 .03411 Mdot
.538 .03433 Mdot
.538 .03439 Mdot
.538 .03442 Mdot
.538 .03445 Mdot
.538 .03446 Mdot
.538 .03456 Mdot
.538 .03466 Mdot
.538 .03479 Mdot
.538 .03481 Mdot
.538 .03503 Mdot
.538 .0351 Mdot
.538 .0353 Mdot
.538 .03544 Mdot
.538 .03552 Mdot
.538 .03553 Mdot
.538 .03554 Mdot
.538 .03558 Mdot
.538 .03583 Mdot
.538 .03588 Mdot
.538 .03591 Mdot
.538 .03595 Mdot
.538 .03596 Mdot
.538 .03607 Mdot
.538 .03618 Mdot
.538 .03632 Mdot
.538 .03633 Mdot
.538 .03658 Mdot
.538 .03665 Mdot
.538 .03686 Mdot
.538 .03701 Mdot
.538 .0371 Mdot
.538 .03711 Mdot
.538 .03712 Mdot
.538 .03717 Mdot
.538 .03743 Mdot
.538 .03749 Mdot
.538 .03752 Mdot
.538 .03756 Mdot
.538 .03758 Mdot
.538 .0377 Mdot
.538 .03781 Mdot
.538 .03796 Mdot
.538 .03798 Mdot
.538 .03804 Mdot
.538 .03824 Mdot
.538 .03831 Mdot
.538 .03855 Mdot
.538 .03871 Mdot
.538 .0388 Mdot
.538 .03881 Mdot
.538 .03882 Mdot
.538 .03887 Mdot
.538 .03916 Mdot
.538 .03922 Mdot
.538 .03926 Mdot
.538 .0393 Mdot
.538 .03931 Mdot
.538 .03944 Mdot
.538 .03957 Mdot
.538 .03972 Mdot
.538 .03975 Mdot
.538 .03981 Mdot
.538 .04003 Mdot
.538 .04011 Mdot
.538 .04036 Mdot
.538 .04053 Mdot
.538 .04063 Mdot
.538 .04065 Mdot
.538 .04065 Mdot
.538 .04071 Mdot
.538 .04101 Mdot
.538 .04108 Mdot
.538 .04112 Mdot
.538 .04117 Mdot
.538 .04118 Mdot
.538 .04132 Mdot
.538 .04146 Mdot
.538 .04162 Mdot
.538 .04165 Mdot
.538 .04172 Mdot
.538 .04195 Mdot
.538 .04204 Mdot
.538 .04231 Mdot
.538 .04249 Mdot
.538 .0426 Mdot
.538 .04262 Mdot
.538 .04263 Mdot
.538 .04268 Mdot
.538 .04301 Mdot
.538 .04309 Mdot
.538 .04313 Mdot
.538 .04318 Mdot
.538 .0432 Mdot
.538 .04334 Mdot
.538 .04349 Mdot
.538 .04367 Mdot
.538 .04369 Mdot
.538 .04377 Mdot
.538 .04402 Mdot
.538 .04411 Mdot
.538 .0444 Mdot
.538 .0446 Mdot
.538 .04472 Mdot
.538 .04474 Mdot
.538 .04475 Mdot
.538 .04481 Mdot
.538 .04516 Mdot
.538 .04524 Mdot
.538 .04529 Mdot
.538 .04534 Mdot
.538 .04536 Mdot
.538 .04552 Mdot
.538 .04567 Mdot
.538 .04587 Mdot
.538 .0459 Mdot
.538 .04598 Mdot
.538 .04625 Mdot
.538 .04635 Mdot
.538 .04666 Mdot
.538 .04687 Mdot
.538 .047 Mdot
.538 .04702 Mdot
.538 .04703 Mdot
.538 .0471 Mdot
.538 .04748 Mdot
.538 .04756 Mdot
.538 .04761 Mdot
.538 .04767 Mdot
.538 .04769 Mdot
.538 .04786 Mdot
.538 .04803 Mdot
.538 .04824 Mdot
.538 .04827 Mdot
.538 .04836 Mdot
.538 .04864 Mdot
.538 .04875 Mdot
.538 .04909 Mdot
.538 .04932 Mdot
.538 .04945 Mdot
.538 .04947 Mdot
.538 .04949 Mdot
.538 .04956 Mdot
.538 .04997 Mdot
.538 .05006 Mdot
.538 .05011 Mdot
.538 .05018 Mdot
.538 .0502 Mdot
.538 .05038 Mdot
.538 .05056 Mdot
.538 .05078 Mdot
.538 .05082 Mdot
.538 .05092 Mdot
.538 .05122 Mdot
.538 .05134 Mdot
.538 .0517 Mdot
.538 .05195 Mdot
.538 .05209 Mdot
.538 .05211 Mdot
.538 .05213 Mdot
.538 .0522 Mdot
.538 .05265 Mdot
.538 .05275 Mdot
.538 .0528 Mdot
.538 .05287 Mdot
.538 .05289 Mdot
.538 .05309 Mdot
.538 .05328 Mdot
.538 .05353 Mdot
.538 .05356 Mdot
.538 .05367 Mdot
.538 .054 Mdot
.538 .05412 Mdot
.538 .05451 Mdot
.538 .05478 Mdot
.538 .05493 Mdot
.538 .05496 Mdot
.538 .05497 Mdot
.538 .05505 Mdot
.538 .05553 Mdot
.538 .05564 Mdot
.538 .0557 Mdot
.538 .05577 Mdot
.538 .05579 Mdot
.538 .05601 Mdot
.538 .05621 Mdot
.538 .05648 Mdot
.538 .05651 Mdot
.538 .05663 Mdot
.538 .05698 Mdot
.538 .05711 Mdot
.538 .05754 Mdot
.538 .05782 Mdot
.538 .05799 Mdot
.538 .05802 Mdot
.538 .05803 Mdot
.538 .05812 Mdot
.538 .05863 Mdot
.538 .05875 Mdot
.538 .05881 Mdot
.538 .05889 Mdot
.538 .05891 Mdot
.538 .05915 Mdot
.538 .05937 Mdot
.538 .05965 Mdot
.538 .05969 Mdot
.538 .05981 Mdot
.538 .06019 Mdot
.538 .06034 Mdot
.538 .06079 Mdot
.538 .0611 Mdot
.538 .06128 Mdot
.538 .06131 Mdot
.538 .06132 Mdot
.538 .06142 Mdot
.538 .06197 Mdot
.538 .06209 Mdot
.538 .06217 Mdot
.538 .06225 Mdot
.538 .06227 Mdot
.538 .06252 Mdot
.538 .06276 Mdot
.538 .06306 Mdot
.538 .06311 Mdot
.538 .06324 Mdot
.538 .0638 Mdot
.538 .06429 Mdot
.538 .06462 Mdot
.538 .06482 Mdot
.538 .06485 Mdot
.538 .06486 Mdot
.538 .06497 Mdot
.538 .06556 Mdot
.538 .06569 Mdot
.538 .06577 Mdot
.538 .06586 Mdot
.538 .06589 Mdot
.538 .06616 Mdot
.538 .06641 Mdot
.538 .06674 Mdot
.538 .06679 Mdot
.538 .06693 Mdot
.538 .06753 Mdot
.538 .06806 Mdot
.538 .06842 Mdot
.538 .06863 Mdot
.538 .06866 Mdot
.538 .06868 Mdot
.538 .06879 Mdot
.538 .06942 Mdot
.538 .06957 Mdot
.538 .06965 Mdot
.538 .06975 Mdot
.538 .06978 Mdot
.538 .07007 Mdot
.538 .07034 Mdot
.538 .07069 Mdot
.538 .07074 Mdot
.538 .0709 Mdot
.538 .07155 Mdot
.538 .07211 Mdot
.538 .0725 Mdot
.538 .07272 Mdot
.538 .07276 Mdot
.538 .07278 Mdot
.538 .0729 Mdot
.538 .07358 Mdot
.538 .07374 Mdot
.538 .07383 Mdot
.538 .07393 Mdot
.538 .07396 Mdot
.538 .07427 Mdot
.538 .07457 Mdot
.538 .07495 Mdot
.538 .075 Mdot
.538 .07517 Mdot
.538 .07587 Mdot
.538 .07648 Mdot
.538 .07689 Mdot
.538 .07713 Mdot
.538 .07717 Mdot
.538 .07719 Mdot
.538 .07732 Mdot
.538 .07806 Mdot
.538 .07822 Mdot
.538 .07832 Mdot
.538 .07843 Mdot
.538 .07847 Mdot
.538 .0788 Mdot
.538 .07912 Mdot
.538 .07952 Mdot
.538 .07958 Mdot
.538 .07976 Mdot
.538 .08052 Mdot
.538 .08117 Mdot
.538 .08162 Mdot
.538 .08188 Mdot
.538 .08191 Mdot
.538 .08194 Mdot
.538 .08207 Mdot
.538 .08287 Mdot
.538 .08305 Mdot
.538 .08315 Mdot
.538 .08327 Mdot
.538 .08331 Mdot
.538 .08367 Mdot
.538 .08401 Mdot
.538 .08445 Mdot
.538 .08451 Mdot
.538 .0847 Mdot
.538 .08552 Mdot
.538 .08622 Mdot
.538 .0867 Mdot
.538 .08698 Mdot
.538 .08702 Mdot
.538 .08705 Mdot
.538 .08719 Mdot
.538 .08805 Mdot
.538 .08824 Mdot
.538 .08836 Mdot
.538 .08848 Mdot
.538 .08852 Mdot
.538 .08891 Mdot
.538 .08928 Mdot
.538 .08975 Mdot
.538 .08982 Mdot
.538 .09002 Mdot
.538 .0909 Mdot
.538 .09165 Mdot
.538 .09217 Mdot
.538 .09247 Mdot
.538 .09252 Mdot
.538 .09254 Mdot
.538 .0927 Mdot
.538 .09362 Mdot
.538 .09383 Mdot
.538 .09395 Mdot
.538 .09409 Mdot
.538 .09413 Mdot
.538 .09455 Mdot
.538 .09495 Mdot
.538 .09545 Mdot
.538 .09553 Mdot
.538 .09575 Mdot
.538 .09669 Mdot
.538 .0975 Mdot
.538 .09806 Mdot
.538 .09838 Mdot
.538 .09843 Mdot
.538 .09846 Mdot
.538 .09863 Mdot
.538 .09962 Mdot
.538 .09984 Mdot
.538 .09997 Mdot
.538 .10012 Mdot
.538 .10017 Mdot
.538 .10062 Mdot
.538 .10104 Mdot
.538 .10159 Mdot
.538 .10167 Mdot
.538 .10191 Mdot
.538 .10292 Mdot
.538 .10379 Mdot
.538 .10439 Mdot
.538 .10474 Mdot
.538 .10479 Mdot
.538 .10482 Mdot
.538 .10501 Mdot
.538 .10607 Mdot
.538 .10631 Mdot
.538 .10645 Mdot
.538 .10661 Mdot
.538 .10666 Mdot
.538 .10714 Mdot
.538 .10761 Mdot
.538 .10819 Mdot
.538 .10828 Mdot
.538 .10853 Mdot
.538 .10962 Mdot
.538 .11056 Mdot
.538 .11121 Mdot
.538 .11158 Mdot
.538 .11164 Mdot
.538 .11167 Mdot
.538 .11187 Mdot
.538 .11302 Mdot
.538 .11327 Mdot
.538 .11343 Mdot
.538 .1136 Mdot
.538 .11365 Mdot
.538 .11417 Mdot
.538 .11467 Mdot
.538 .1153 Mdot
.538 .11539 Mdot
.538 .11566 Mdot
.538 .11683 Mdot
.538 .11785 Mdot
.538 .11854 Mdot
.538 .11895 Mdot
.538 .119 Mdot
.538 .11904 Mdot
.538 .11925 Mdot
.538 .12049 Mdot
.538 .12077 Mdot
.538 .12093 Mdot
.538 .12111 Mdot
.538 .12117 Mdot
.538 .12173 Mdot
.538 .12226 Mdot
.538 .12294 Mdot
.538 .12304 Mdot
.538 .12333 Mdot
.538 .12459 Mdot
.538 .12569 Mdot
.538 .12643 Mdot
.538 .12687 Mdot
.538 .12693 Mdot
.538 .12697 Mdot
.538 .1272 Mdot
.538 .12853 Mdot
.538 .12883 Mdot
.538 .129 Mdot
.538 .1292 Mdot
.538 .12926 Mdot
.538 .12986 Mdot
.538 .13044 Mdot
.538 .13116 Mdot
.538 .13127 Mdot
.538 .13159 Mdot
.538 .13295 Mdot
.538 .13412 Mdot
.538 .13492 Mdot
.538 .13539 Mdot
.538 .13546 Mdot
.538 .1355 Mdot
.538 .13575 Mdot
.538 .13717 Mdot
.538 .1375 Mdot
.538 .13769 Mdot
.538 .1379 Mdot
.538 .13797 Mdot
.538 .13861 Mdot
.538 .13923 Mdot
.538 .14001 Mdot
.538 .14013 Mdot
.538 .14047 Mdot
.538 .14193 Mdot
.538 .14319 Mdot
.538 .14406 Mdot
.538 .14456 Mdot
.538 .14463 Mdot
.538 .14468 Mdot
.538 .14494 Mdot
.538 .14648 Mdot
.538 .14683 Mdot
.538 .14703 Mdot
.538 .14726 Mdot
.538 .14733 Mdot
.538 .14803 Mdot
.538 .14869 Mdot
.538 .14954 Mdot
.538 .14966 Mdot
.538 .15003 Mdot
.538 .1516 Mdot
.538 .15296 Mdot
.538 .15389 Mdot
.538 .15443 Mdot
.538 .15451 Mdot
.538 .15456 Mdot
.538 .15484 Mdot
.538 .1565 Mdot
.538 .15687 Mdot
.538 .15709 Mdot
.538 .15733 Mdot
.538 .15741 Mdot
.538 .15816 Mdot
.538 .15888 Mdot
.538 .15978 Mdot
.538 .15991 Mdot
.538 .16031 Mdot
.538 .162 Mdot
.538 .16347 Mdot
.538 .16447 Mdot
.538 .16505 Mdot
.538 .16513 Mdot
.538 .16518 Mdot
.538 .16549 Mdot
.538 .16727 Mdot
.538 .16767 Mdot
.538 .16791 Mdot
.538 .16817 Mdot
.538 .16826 Mdot
.538 .16906 Mdot
.538 .16983 Mdot
.538 .17081 Mdot
.538 .17095 Mdot
.538 .17099 Mdot
.538 .17138 Mdot
.538 .1732 Mdot
.538 .17477 Mdot
.538 .17585 Mdot
.538 .17647 Mdot
.538 .17656 Mdot
.538 .17662 Mdot
.538 .17695 Mdot
.538 .17887 Mdot
.538 .1793 Mdot
.538 .17955 Mdot
.538 .17984 Mdot
.538 .17993 Mdot
.538 .18079 Mdot
.538 .18162 Mdot
.538 .18267 Mdot
.538 .18282 Mdot
.538 .18287 Mdot
.538 .18329 Mdot
.538 .18524 Mdot
.538 .18693 Mdot
.538 .18809 Mdot
.538 .18877 Mdot
.538 .18886 Mdot
.538 .18893 Mdot
.538 .18928 Mdot
.538 .19134 Mdot
.538 .19181 Mdot
.538 .19208 Mdot
.538 .19239 Mdot
.538 .19248 Mdot
.538 .19341 Mdot
.538 .19431 Mdot
.538 .19544 Mdot
.538 .1956 Mdot
.538 .19565 Mdot
.538 .1961 Mdot
.538 .1982 Mdot
.538 .20002 Mdot
.538 .20127 Mdot
.538 .202 Mdot
.538 .2021 Mdot
.538 .20217 Mdot
.538 .20255 Mdot
.538 .20476 Mdot
.538 .20527 Mdot
.538 .20556 Mdot
.538 .20589 Mdot
.538 .20599 Mdot
.538 .20699 Mdot
.538 .20795 Mdot
.538 .20917 Mdot
.538 .20935 Mdot
.538 .2094 Mdot
.538 .20988 Mdot
.538 .21215 Mdot
.538 .21411 Mdot
.538 .21545 Mdot
.538 .21623 Mdot
.538 .21634 Mdot
.538 .21641 Mdot
.538 .21682 Mdot
.538 .21921 Mdot
.538 .21975 Mdot
.538 .22006 Mdot
.538 .22042 Mdot
.538 .22053 Mdot
.538 .22161 Mdot
.538 .22264 Mdot
.538 .22395 Mdot
.538 .22414 Mdot
.538 .2242 Mdot
.538 .22471 Mdot
.538 .22715 Mdot
.538 .22926 Mdot
.538 .2307 Mdot
.538 .23154 Mdot
.538 .23167 Mdot
.538 .23174 Mdot
.538 .23218 Mdot
.538 .23475 Mdot
.538 .23533 Mdot
.538 .23567 Mdot
.538 .23605 Mdot
.538 .23617 Mdot
.538 .23733 Mdot
.538 .23844 Mdot
.538 .23985 Mdot
.538 .24006 Mdot
.538 .24012 Mdot
.538 .24067 Mdot
.538 .2433 Mdot
.538 .24557 Mdot
.538 .24712 Mdot
.538 .24802 Mdot
.538 .24815 Mdot
.538 .24823 Mdot
.538 .24871 Mdot
.538 .25147 Mdot
.538 .2521 Mdot
.538 .25246 Mdot
.538 .25287 Mdot
.538 .253 Mdot
.538 .25425 Mdot
.538 .25545 Mdot
.538 .25696 Mdot
.538 .25718 Mdot
.538 .25725 Mdot
.538 .25785 Mdot
.538 .26067 Mdot
.538 .26311 Mdot
.538 .26478 Mdot
.538 .26575 Mdot
.538 .26589 Mdot
.538 .26598 Mdot
.538 .2665 Mdot
.538 .26947 Mdot
.538 .27014 Mdot
.538 .27053 Mdot
.538 .27097 Mdot
.538 .27111 Mdot
.538 .27245 Mdot
.538 .27374 Mdot
.538 .27537 Mdot
.538 .27561 Mdot
.538 .27568 Mdot
.538 .27633 Mdot
.538 .27936 Mdot
.538 .28199 Mdot
.538 .28379 Mdot
.538 .28483 Mdot
.538 .28498 Mdot
.538 .28508 Mdot
.538 .28563 Mdot
.538 .28883 Mdot
.538 .28955 Mdot
.538 .28997 Mdot
.538 .29045 Mdot
.538 .2906 Mdot
.538 .29204 Mdot
.538 .29343 Mdot
.538 .29518 Mdot
.538 .29544 Mdot
.538 .29552 Mdot
.538 .29621 Mdot
.538 .29947 Mdot
.538 .3023 Mdot
.538 .30423 Mdot
.538 .30536 Mdot
.538 .30552 Mdot
.538 .30563 Mdot
.538 .30622 Mdot
.538 .30966 Mdot
.538 .31044 Mdot
.538 .31089 Mdot
.538 .3114 Mdot
.538 .31157 Mdot
.538 .31312 Mdot
.538 .31461 Mdot
.538 .3165 Mdot
.538 .31677 Mdot
.538 .31686 Mdot
.538 .3176 Mdot
.538 .32111 Mdot
.538 .32416 Mdot
.538 .32624 Mdot
.538 .32745 Mdot
.538 .32763 Mdot
.538 .32773 Mdot
.538 .32837 Mdot
.538 .33208 Mdot
.54 .01487 Mdot
.54 .01488 Mdot
.54 .01489 Mdot
.54 .01491 Mdot
.54 .01492 Mdot
.54 .01494 Mdot
.54 .01495 Mdot
.54 .01497 Mdot
.54 .01499 Mdot
.54 .01502 Mdot
.54 .01504 Mdot
.54 .01507 Mdot
.54 .0151 Mdot
.54 .01513 Mdot
.54 .01516 Mdot
.54 .01519 Mdot
.54 .0152 Mdot
.54 .01523 Mdot
.54 .01524 Mdot
.54 .01527 Mdot
.54 .01528 Mdot
.54 .01532 Mdot
.54 .01532 Mdot
.54 .01537 Mdot
.54 .01537 Mdot
.54 .01542 Mdot
.54 .01542 Mdot
.54 .01548 Mdot
.54 .01548 Mdot
.54 .01554 Mdot
.54 .01554 Mdot
.54 .0156 Mdot
.54 .01561 Mdot
.54 .01567 Mdot
.54 .01568 Mdot
.54 .01575 Mdot
.54 .01576 Mdot
.54 .01583 Mdot
.54 .01584 Mdot
.54 .01586 Mdot
.54 .01592 Mdot
.54 .01593 Mdot
.54 .01595 Mdot
.54 .01602 Mdot
.54 .01603 Mdot
.54 .01605 Mdot
.54 .01612 Mdot
.54 .01613 Mdot
.54 .01616 Mdot
.54 .01623 Mdot
.54 .01625 Mdot
.54 .01627 Mdot
.54 .01636 Mdot
.54 .01637 Mdot
.54 .0164 Mdot
.54 .01649 Mdot
.54 .0165 Mdot
.54 .01653 Mdot
.54 .01663 Mdot
.54 .01664 Mdot
.54 .01668 Mdot
.54 .01678 Mdot
.54 .0168 Mdot
.54 .01683 Mdot
.54 .01695 Mdot
.54 .01696 Mdot
.54 .017 Mdot
.54 .01713 Mdot
.54 .01714 Mdot
.54 .01719 Mdot
.54 .01732 Mdot
.54 .01734 Mdot
.54 .01739 Mdot
.54 .01753 Mdot
.54 .01755 Mdot
.54 .0176 Mdot
.54 .01775 Mdot
.54 .01777 Mdot
.54 .01783 Mdot
.54 .018 Mdot
.54 .01802 Mdot
.54 .01808 Mdot
.54 .01826 Mdot
.54 .01828 Mdot
.54 .01835 Mdot
.54 .01854 Mdot
.54 .01857 Mdot
.54 .01861 Mdot
.54 .01864 Mdot
.54 .01885 Mdot
.54 .01888 Mdot
.54 .01892 Mdot
.54 .01895 Mdot
.54 .01918 Mdot
.54 .01921 Mdot
.54 .01925 Mdot
.54 .01929 Mdot
.54 .01934 Mdot
.54 .01954 Mdot
.54 .01957 Mdot
.54 .01962 Mdot
.54 .01966 Mdot
.54 .01971 Mdot
.54 .01992 Mdot
.54 .01996 Mdot
.54 .02001 Mdot
.54 .02005 Mdot
.54 .02011 Mdot
.54 .02034 Mdot
.54 .02038 Mdot
.54 .02043 Mdot
.54 .02048 Mdot
.54 .0205 Mdot
.54 .02054 Mdot
.54 .02079 Mdot
.54 .02083 Mdot
.54 .02089 Mdot
.54 .02094 Mdot
.54 .02096 Mdot
.54 .02101 Mdot
.54 .02127 Mdot
.54 .02132 Mdot
.54 .02139 Mdot
.54 .02144 Mdot
.54 .02146 Mdot
.54 .02151 Mdot
.54 .0218 Mdot
.54 .02185 Mdot
.54 .02192 Mdot
.54 .02198 Mdot
.54 .022 Mdot
.54 .02206 Mdot
.54 .02237 Mdot
.54 .02242 Mdot
.54 .02249 Mdot
.54 .02256 Mdot
.54 .02258 Mdot
.54 .02264 Mdot
.54 .02298 Mdot
.54 .02303 Mdot
.54 .02312 Mdot
.54 .02319 Mdot
.54 .02321 Mdot
.54 .02328 Mdot
.54 .02364 Mdot
.54 .0237 Mdot
.54 .02379 Mdot
.54 .02386 Mdot
.54 .02389 Mdot
.54 .02396 Mdot
.54 .02435 Mdot
.54 .02442 Mdot
.54 .02452 Mdot
.54 .0246 Mdot
.54 .02463 Mdot
.54 .0247 Mdot
.54 .02512 Mdot
.54 .0252 Mdot
.54 .02522 Mdot
.54 .0253 Mdot
.54 .02539 Mdot
.54 .02539 Mdot
.54 .02542 Mdot
.54 .0255 Mdot
.54 .02596 Mdot
.54 .02603 Mdot
.54 .02606 Mdot
.54 .02615 Mdot
.54 .02624 Mdot
.54 .02624 Mdot
.54 .02627 Mdot
.54 .02636 Mdot
.54 .02686 Mdot
.54 .02694 Mdot
.54 .02697 Mdot
.54 .02706 Mdot
.54 .02716 Mdot
.54 .02716 Mdot
.54 .0272 Mdot
.54 .0273 Mdot
.54 .02736 Mdot
.54 .02761 Mdot
.54 .02783 Mdot
.54 .02792 Mdot
.54 .02795 Mdot
.54 .02805 Mdot
.54 .02816 Mdot
.54 .02816 Mdot
.54 .0282 Mdot
.54 .0283 Mdot
.54 .02837 Mdot
.54 .02864 Mdot
.54 .02888 Mdot
.54 .02897 Mdot
.54 .02901 Mdot
.54 .02912 Mdot
.54 .02923 Mdot
.54 .02923 Mdot
.54 .02928 Mdot
.54 .02939 Mdot
.54 .02947 Mdot
.54 .02968 Mdot
.54 .02976 Mdot
.54 .02991 Mdot
.54 .03001 Mdot
.54 .03011 Mdot
.54 .03015 Mdot
.54 .03027 Mdot
.54 .03039 Mdot
.54 .03039 Mdot
.54 .03044 Mdot
.54 .03056 Mdot
.54 .03065 Mdot
.54 .03078 Mdot
.54 .03088 Mdot
.54 .03112 Mdot
.54 .03123 Mdot
.54 .03135 Mdot
.54 .03139 Mdot
.54 .03151 Mdot
.54 .03165 Mdot
.54 .03165 Mdot
.54 .0317 Mdot
.54 .03183 Mdot
.54 .03192 Mdot
.54 .03207 Mdot
.54 .03217 Mdot
.54 .03243 Mdot
.54 .03255 Mdot
.54 .03268 Mdot
.54 .03272 Mdot
.54 .03286 Mdot
.54 .033 Mdot
.54 .033 Mdot
.54 .03306 Mdot
.54 .0332 Mdot
.54 .03324 Mdot
.54 .0333 Mdot
.54 .03346 Mdot
.54 .03357 Mdot
.54 .03385 Mdot
.54 .03398 Mdot
.54 .03411 Mdot
.54 .03416 Mdot
.54 .03431 Mdot
.54 .03447 Mdot
.54 .03447 Mdot
.54 .03453 Mdot
.54 .03468 Mdot
.54 .03472 Mdot
.54 .03474 Mdot
.54 .03479 Mdot
.54 .03496 Mdot
.54 .035 Mdot
.54 .03508 Mdot
.54 .03538 Mdot
.54 .03551 Mdot
.54 .03552 Mdot
.54 .03566 Mdot
.54 .03572 Mdot
.54 .03587 Mdot
.54 .03598 Mdot
.54 .03602 Mdot
.54 .03605 Mdot
.54 .03605 Mdot
.54 .03611 Mdot
.54 .03628 Mdot
.54 .03632 Mdot
.54 .03635 Mdot
.54 .03639 Mdot
.54 .03658 Mdot
.54 .03663 Mdot
.54 .0367 Mdot
.54 .03702 Mdot
.54 .03703 Mdot
.54 .03717 Mdot
.54 .03719 Mdot
.54 .03733 Mdot
.54 .03734 Mdot
.54 .0374 Mdot
.54 .03757 Mdot
.54 .03769 Mdot
.54 .03772 Mdot
.54 .03775 Mdot
.54 .03775 Mdot
.54 .03782 Mdot
.54 .038 Mdot
.54 .03805 Mdot
.54 .03808 Mdot
.54 .03812 Mdot
.54 .03833 Mdot
.54 .03838 Mdot
.54 .03846 Mdot
.54 .03881 Mdot
.54 .03882 Mdot
.54 .03896 Mdot
.54 .03898 Mdot
.54 .03913 Mdot
.54 .03915 Mdot
.54 .03921 Mdot
.54 .03939 Mdot
.54 .03952 Mdot
.54 .03956 Mdot
.54 .03959 Mdot
.54 .0396 Mdot
.54 .03967 Mdot
.54 .03969 Mdot
.54 .03987 Mdot
.54 .03992 Mdot
.54 .03995 Mdot
.54 .04 Mdot
.54 .04021 Mdot
.54 .04027 Mdot
.54 .04036 Mdot
.54 .04074 Mdot
.54 .04075 Mdot
.54 .0409 Mdot
.54 .04092 Mdot
.54 .04109 Mdot
.54 .04111 Mdot
.54 .04117 Mdot
.54 .04137 Mdot
.54 .04151 Mdot
.54 .04155 Mdot
.54 .04159 Mdot
.54 .04159 Mdot
.54 .04167 Mdot
.54 .04169 Mdot
.54 .04188 Mdot
.54 .04194 Mdot
.54 .04196 Mdot
.54 .04202 Mdot
.54 .04225 Mdot
.54 .04232 Mdot
.54 .04242 Mdot
.54 .04282 Mdot
.54 .04283 Mdot
.54 .043 Mdot
.54 .04302 Mdot
.54 .0432 Mdot
.54 .04322 Mdot
.54 .04329 Mdot
.54 .0435 Mdot
.54 .04365 Mdot
.54 .04369 Mdot
.54 .04373 Mdot
.54 .04374 Mdot
.54 .04382 Mdot
.54 .04385 Mdot
.54 .04405 Mdot
.54 .04411 Mdot
.54 .04414 Mdot
.54 .0442 Mdot
.54 .04446 Mdot
.54 .04452 Mdot
.54 .04463 Mdot
.54 .04507 Mdot
.54 .04508 Mdot
.54 .04526 Mdot
.54 .04529 Mdot
.54 .04548 Mdot
.54 .0455 Mdot
.54 .04558 Mdot
.54 .0458 Mdot
.54 .04597 Mdot
.54 .04601 Mdot
.54 .04606 Mdot
.54 .04606 Mdot
.54 .04615 Mdot
.54 .04618 Mdot
.54 .0464 Mdot
.54 .04646 Mdot
.54 .0465 Mdot
.54 .04656 Mdot
.54 .04684 Mdot
.54 .04691 Mdot
.54 .04702 Mdot
.54 .04749 Mdot
.54 .04751 Mdot
.54 .04771 Mdot
.54 .04773 Mdot
.54 .04794 Mdot
.54 .04796 Mdot
.54 .04805 Mdot
.54 .04829 Mdot
.54 .04847 Mdot
.54 .04852 Mdot
.54 .04856 Mdot
.54 .04857 Mdot
.54 .04867 Mdot
.54 .0487 Mdot
.54 .04893 Mdot
.54 .049 Mdot
.54 .04904 Mdot
.54 .04911 Mdot
.54 .04941 Mdot
.54 .04949 Mdot
.54 .04961 Mdot
.54 .05012 Mdot
.54 .05013 Mdot
.54 .05035 Mdot
.54 .05037 Mdot
.54 .05059 Mdot
.54 .05062 Mdot
.54 .05071 Mdot
.54 .05098 Mdot
.54 .05117 Mdot
.54 .05122 Mdot
.54 .05127 Mdot
.54 .05127 Mdot
.54 .05138 Mdot
.54 .05142 Mdot
.54 .05167 Mdot
.54 .05175 Mdot
.54 .05179 Mdot
.54 .05186 Mdot
.54 .05218 Mdot
.54 .05227 Mdot
.54 .0524 Mdot
.54 .05295 Mdot
.54 .05297 Mdot
.54 .0532 Mdot
.54 .05323 Mdot
.54 .05347 Mdot
.54 .05349 Mdot
.54 .05359 Mdot
.54 .05388 Mdot
.54 .05408 Mdot
.54 .05414 Mdot
.54 .0542 Mdot
.54 .0542 Mdot
.54 .05432 Mdot
.54 .05435 Mdot
.54 .05463 Mdot
.54 .05471 Mdot
.54 .05475 Mdot
.54 .05484 Mdot
.54 .05518 Mdot
.54 .05527 Mdot
.54 .05542 Mdot
.54 .05601 Mdot
.54 .05603 Mdot
.54 .05627 Mdot
.54 .05631 Mdot
.54 .05657 Mdot
.54 .05659 Mdot
.54 .0567 Mdot
.54 .05701 Mdot
.54 .05723 Mdot
.54 .05729 Mdot
.54 .05735 Mdot
.54 .05736 Mdot
.54 .05748 Mdot
.54 .05752 Mdot
.54 .05782 Mdot
.54 .05791 Mdot
.54 .05796 Mdot
.54 .05804 Mdot
.54 .05842 Mdot
.54 .05852 Mdot
.54 .05867 Mdot
.54 .05931 Mdot
.54 .05933 Mdot
.54 .0596 Mdot
.54 .05963 Mdot
.54 .05991 Mdot
.54 .05994 Mdot
.54 .06006 Mdot
.54 .06039 Mdot
.54 .06063 Mdot
.54 .0607 Mdot
.54 .06077 Mdot
.54 .06077 Mdot
.54 .06091 Mdot
.54 .06095 Mdot
.54 .06127 Mdot
.54 .06137 Mdot
.54 .06141 Mdot
.54 .06151 Mdot
.54 .06191 Mdot
.54 .06202 Mdot
.54 .06219 Mdot
.54 .06288 Mdot
.54 .0629 Mdot
.54 .06319 Mdot
.54 .06323 Mdot
.54 .06353 Mdot
.54 .06356 Mdot
.54 .06369 Mdot
.54 .06405 Mdot
.54 .06431 Mdot
.54 .06438 Mdot
.54 .06445 Mdot
.54 .06445 Mdot
.54 .0646 Mdot
.54 .06465 Mdot
.54 .06499 Mdot
.54 .0651 Mdot
.54 .06515 Mdot
.54 .06525 Mdot
.54 .06569 Mdot
.54 .0658 Mdot
.54 .06599 Mdot
.54 .06673 Mdot
.54 .06676 Mdot
.54 .06707 Mdot
.54 .06711 Mdot
.54 .06743 Mdot
.54 .06747 Mdot
.54 .06761 Mdot
.54 .068 Mdot
.54 .06827 Mdot
.54 .06835 Mdot
.54 .06843 Mdot
.54 .06843 Mdot
.54 .06859 Mdot
.54 .06864 Mdot
.54 .06901 Mdot
.54 .06913 Mdot
.54 .06918 Mdot
.54 .0693 Mdot
.54 .06977 Mdot
.54 .06989 Mdot
.54 .07009 Mdot
.54 .07089 Mdot
.54 .07092 Mdot
.54 .07126 Mdot
.54 .0713 Mdot
.54 .07165 Mdot
.54 .07169 Mdot
.54 .07184 Mdot
.54 .07226 Mdot
.54 .07256 Mdot
.54 .07264 Mdot
.54 .07273 Mdot
.54 .07273 Mdot
.54 .0729 Mdot
.54 .07295 Mdot
.54 .07336 Mdot
.54 .07348 Mdot
.54 .07354 Mdot
.54 .07366 Mdot
.54 .07417 Mdot
.54 .0743 Mdot
.54 .07452 Mdot
.54 .07539 Mdot
.54 .07542 Mdot
.54 .07578 Mdot
.54 .07583 Mdot
.54 .07621 Mdot
.54 .07625 Mdot
.54 .07641 Mdot
.54 .07686 Mdot
.54 .07719 Mdot
.54 .07728 Mdot
.54 .07737 Mdot
.54 .07737 Mdot
.54 .07756 Mdot
.54 .07761 Mdot
.54 .07805 Mdot
.54 .07818 Mdot
.54 .07825 Mdot
.54 .07838 Mdot
.54 .07893 Mdot
.54 .07907 Mdot
.54 .0793 Mdot
.54 .08024 Mdot
.54 .08027 Mdot
.54 .08067 Mdot
.54 .08071 Mdot
.54 .08113 Mdot
.54 .08117 Mdot
.54 .08135 Mdot
.54 .08183 Mdot
.54 .08218 Mdot
.54 .08228 Mdot
.54 .08238 Mdot
.54 .08238 Mdot
.54 .08258 Mdot
.54 .08264 Mdot
.54 .08311 Mdot
.54 .08326 Mdot
.54 .08333 Mdot
.54 .08347 Mdot
.54 .08406 Mdot
.54 .08422 Mdot
.54 .08447 Mdot
.54 .08548 Mdot
.54 .08552 Mdot
.54 .08594 Mdot
.54 .08599 Mdot
.54 .08644 Mdot
.54 .08649 Mdot
.54 .08668 Mdot
.54 .0872 Mdot
.54 .08758 Mdot
.54 .08769 Mdot
.54 .08779 Mdot
.54 .0878 Mdot
.54 .08801 Mdot
.54 .08808 Mdot
.54 .08859 Mdot
.54 .08874 Mdot
.54 .08882 Mdot
.54 .08897 Mdot
.54 .08961 Mdot
.54 .08978 Mdot
.54 .09005 Mdot
.54 .09114 Mdot
.54 .09118 Mdot
.54 .09164 Mdot
.54 .0917 Mdot
.54 .09218 Mdot
.54 .09223 Mdot
.54 .09243 Mdot
.54 .093 Mdot
.54 .09341 Mdot
.54 .09353 Mdot
.54 .09364 Mdot
.54 .09364 Mdot
.54 .09388 Mdot
.54 .09395 Mdot
.54 .0945 Mdot
.54 .09467 Mdot
.54 .09475 Mdot
.54 .09492 Mdot
.54 .0956 Mdot
.54 .09579 Mdot
.54 .09608 Mdot
.54 .09726 Mdot
.54 .0973 Mdot
.54 .09779 Mdot
.54 .09786 Mdot
.54 .09837 Mdot
.54 .09843 Mdot
.54 .09865 Mdot
.54 .09926 Mdot
.54 .09971 Mdot
.54 .09983 Mdot
.54 .09995 Mdot
.54 .09996 Mdot
.54 .10021 Mdot
.54 .10029 Mdot
.54 .10088 Mdot
.54 .10106 Mdot
.54 .10115 Mdot
.54 .10133 Mdot
.54 .10207 Mdot
.54 .10227 Mdot
.54 .10258 Mdot
.54 .10386 Mdot
.54 .10391 Mdot
.54 .10444 Mdot
.54 .10451 Mdot
.54 .10507 Mdot
.54 .10513 Mdot
.54 .10536 Mdot
.54 .10603 Mdot
.54 .1065 Mdot
.54 .10664 Mdot
.54 .10677 Mdot
.54 .10678 Mdot
.54 .10705 Mdot
.54 .10713 Mdot
.54 .10777 Mdot
.54 .10797 Mdot
.54 .10807 Mdot
.54 .10826 Mdot
.54 .10906 Mdot
.54 .10928 Mdot
.54 .10961 Mdot
.54 .11099 Mdot
.54 .11104 Mdot
.54 .11162 Mdot
.54 .11169 Mdot
.54 .11229 Mdot
.54 .11236 Mdot
.54 .11262 Mdot
.54 .11333 Mdot
.54 .11385 Mdot
.54 .11399 Mdot
.54 .11413 Mdot
.54 .11414 Mdot
.54 .11444 Mdot
.54 .11453 Mdot
.54 .11522 Mdot
.54 .11543 Mdot
.54 .11554 Mdot
.54 .11574 Mdot
.54 .11661 Mdot
.54 .11684 Mdot
.54 .11721 Mdot
.54 .1187 Mdot
.54 .11875 Mdot
.54 .11937 Mdot
.54 .11945 Mdot
.54 .1201 Mdot
.54 .12017 Mdot
.54 .12045 Mdot
.54 .12122 Mdot
.54 .12178 Mdot
.54 .12194 Mdot
.54 .12209 Mdot
.54 .1221 Mdot
.54 .12242 Mdot
.54 .12251 Mdot
.54 .12326 Mdot
.54 .12349 Mdot
.54 .1236 Mdot
.54 .12383 Mdot
.54 .12476 Mdot
.54 .12501 Mdot
.54 .12541 Mdot
.54 .12701 Mdot
.54 .12707 Mdot
.54 .12774 Mdot
.54 .12783 Mdot
.54 .12853 Mdot
.54 .12861 Mdot
.54 .12891 Mdot
.54 .12974 Mdot
.54 .13034 Mdot
.54 .13051 Mdot
.54 .13068 Mdot
.54 .13069 Mdot
.54 .13103 Mdot
.54 .13113 Mdot
.54 .13194 Mdot
.54 .13219 Mdot
.54 .13231 Mdot
.54 .13256 Mdot
.54 .13357 Mdot
.54 .13384 Mdot
.54 .13426 Mdot
.54 .136 Mdot
.54 .13606 Mdot
.54 .13678 Mdot
.54 .13688 Mdot
.54 .13764 Mdot
.54 .13772 Mdot
.54 .13804 Mdot
.54 .13895 Mdot
.54 .13959 Mdot
.54 .13978 Mdot
.54 .13995 Mdot
.54 .13997 Mdot
.54 .14034 Mdot
.54 .14045 Mdot
.54 .14132 Mdot
.54 .14159 Mdot
.54 .14172 Mdot
.54 .14198 Mdot
.54 .14307 Mdot
.54 .14336 Mdot
.54 .14382 Mdot
.54 .1457 Mdot
.54 .14577 Mdot
.54 .14655 Mdot
.54 .14665 Mdot
.54 .14747 Mdot
.54 .14756 Mdot
.54 .14791 Mdot
.54 .14888 Mdot
.54 .14958 Mdot
.54 .14978 Mdot
.54 .14997 Mdot
.54 .14999 Mdot
.54 .15039 Mdot
.54 .15051 Mdot
.54 .15145 Mdot
.54 .15174 Mdot
.54 .15188 Mdot
.54 .15216 Mdot
.54 .15334 Mdot
.54 .15366 Mdot
.54 .15415 Mdot
.54 .15618 Mdot
.54 .15625 Mdot
.54 .1571 Mdot
.54 .1572 Mdot
.54 .15809 Mdot
.54 .15819 Mdot
.54 .15856 Mdot
.54 .15962 Mdot
.54 .16037 Mdot
.54 .16059 Mdot
.54 .16079 Mdot
.54 .16081 Mdot
.54 .16124 Mdot
.54 .16137 Mdot
.54 .16239 Mdot
.54 .1627 Mdot
.54 .16285 Mdot
.54 .16316 Mdot
.54 .16443 Mdot
.54 .16477 Mdot
.54 .16531 Mdot
.54 .1675 Mdot
.54 .16757 Mdot
.54 .16849 Mdot
.54 .1686 Mdot
.54 .16956 Mdot
.54 .16967 Mdot
.54 .17007 Mdot
.54 .17121 Mdot
.54 .17203 Mdot
.54 .17226 Mdot
.54 .17248 Mdot
.54 .1725 Mdot
.54 .17296 Mdot
.54 .1731 Mdot
.54 .1742 Mdot
.54 .17454 Mdot
.54 .1747 Mdot
.54 .17504 Mdot
.54 .17641 Mdot
.54 .17678 Mdot
.54 .17736 Mdot
.54 .17972 Mdot
.54 .1798 Mdot
.54 .18079 Mdot
.54 .18091 Mdot
.54 .18195 Mdot
.54 .18206 Mdot
.54 .1825 Mdot
.54 .18373 Mdot
.54 .18461 Mdot
.54 .18486 Mdot
.54 .1851 Mdot
.54 .18512 Mdot
.54 .18562 Mdot
.54 .18577 Mdot
.54 .18696 Mdot
.54 .18732 Mdot
.54 .1875 Mdot
.54 .18786 Mdot
.54 .18934 Mdot
.54 .18974 Mdot
.54 .19037 Mdot
.54 .19292 Mdot
.54 .19301 Mdot
.54 .19408 Mdot
.54 .19421 Mdot
.54 .19533 Mdot
.54 .19545 Mdot
.54 .19592 Mdot
.54 .19725 Mdot
.54 .1982 Mdot
.54 .19847 Mdot
.54 .19873 Mdot
.54 .19875 Mdot
.54 .19929 Mdot
.54 .19946 Mdot
.54 .20074 Mdot
.54 .20113 Mdot
.54 .20133 Mdot
.54 .20171 Mdot
.54 .20332 Mdot
.54 .20374 Mdot
.54 .20442 Mdot
.54 .20718 Mdot
.54 .20727 Mdot
.54 .20842 Mdot
.54 .20857 Mdot
.54 .20978 Mdot
.54 .20991 Mdot
.54 .21042 Mdot
.54 .21185 Mdot
.54 .21288 Mdot
.54 .21318 Mdot
.54 .21345 Mdot
.54 .21347 Mdot
.54 .21406 Mdot
.54 .21424 Mdot
.54 .21562 Mdot
.54 .21605 Mdot
.54 .21625 Mdot
.54 .21667 Mdot
.54 .2184 Mdot
.54 .21887 Mdot
.54 .21959 Mdot
.54 .22257 Mdot
.54 .22268 Mdot
.54 .22392 Mdot
.54 .22408 Mdot
.54 .22538 Mdot
.54 .22552 Mdot
.54 .22608 Mdot
.54 .22762 Mdot
.54 .22874 Mdot
.54 .22905 Mdot
.54 .22935 Mdot
.54 .22937 Mdot
.54 .23001 Mdot
.54 .2302 Mdot
.54 .23169 Mdot
.54 .23215 Mdot
.54 .23238 Mdot
.54 .23283 Mdot
.54 .2347 Mdot
.54 .2352 Mdot
.54 .23598 Mdot
.54 .2392 Mdot
.54 .23931 Mdot
.54 .24066 Mdot
.54 .24083 Mdot
.54 .24223 Mdot
.54 .24239 Mdot
.54 .24299 Mdot
.54 .24466 Mdot
.54 .24586 Mdot
.54 .2462 Mdot
.54 .24652 Mdot
.54 .24655 Mdot
.54 .24723 Mdot
.54 .24744 Mdot
.54 .24905 Mdot
.54 .24955 Mdot
.54 .24979 Mdot
.54 .25028 Mdot
.54 .2523 Mdot
.54 .25284 Mdot
.54 .25369 Mdot
.54 .25716 Mdot
.54 .25728 Mdot
.54 .25873 Mdot
.54 .25891 Mdot
.54 .26044 Mdot
.54 .2606 Mdot
.54 .26125 Mdot
.54 .26305 Mdot
.54 .26435 Mdot
.54 .26472 Mdot
.54 .26507 Mdot
.54 .26509 Mdot
.54 .26583 Mdot
.54 .26606 Mdot
.54 .2678 Mdot
.54 .26833 Mdot
.54 .2686 Mdot
.54 .26912 Mdot
.54 .2713 Mdot
.54 .27189 Mdot
.54 .2728 Mdot
.54 .27656 Mdot
.54 .27669 Mdot
.54 .27825 Mdot
.54 .27845 Mdot
.54 .28009 Mdot
.54 .28027 Mdot
.54 .28097 Mdot
.54 .28292 Mdot
.54 .28432 Mdot
.54 .28472 Mdot
.54 .2851 Mdot
.54 .28512 Mdot
.54 .28592 Mdot
.54 .28616 Mdot
.54 .28804 Mdot
.54 .28862 Mdot
.54 .28891 Mdot
.54 .28948 Mdot
.54 .29183 Mdot
.54 .29246 Mdot
.54 .29345 Mdot
.54 .2975 Mdot
.54 .29764 Mdot
.54 .29934 Mdot
.54 .29955 Mdot
.54 .30132 Mdot
.54 .30152 Mdot
.54 .30227 Mdot
.54 .30438 Mdot
.54 .30589 Mdot
.54 .30632 Mdot
.54 .30673 Mdot
.54 .30676 Mdot
.54 .30762 Mdot
.54 .30788 Mdot
.54 .30991 Mdot
.54 .31054 Mdot
.54 .31084 Mdot
.54 .31146 Mdot
.54 .314 Mdot
.54 .31468 Mdot
.54 .31575 Mdot
.54 .32013 Mdot
.54 .32028 Mdot
.54 .32211 Mdot
.54 .32234 Mdot
.54 .32425 Mdot
.54 .32446 Mdot
.54 .32527 Mdot
.54 .32755 Mdot
.54 .32918 Mdot
.54 .32965 Mdot
.54 .33009 Mdot
.54 .33012 Mdot
.54 .33105 Mdot
.54 .33133 Mdot
.54 .33352 Mdot
.542 .01627 Mdot
.542 .0164 Mdot
.542 .01655 Mdot
.542 .0167 Mdot
.542 .01687 Mdot
.542 .01705 Mdot
.542 .01705 Mdot
.542 .01724 Mdot
.542 .01725 Mdot
.542 .01729 Mdot
.542 .01746 Mdot
.542 .01746 Mdot
.542 .0175 Mdot
.542 .01769 Mdot
.542 .01769 Mdot
.542 .01774 Mdot
.542 .01794 Mdot
.542 .01794 Mdot
.542 .01799 Mdot
.542 .01809 Mdot
.542 .01821 Mdot
.542 .01821 Mdot
.542 .01827 Mdot
.542 .01837 Mdot
.542 .0185 Mdot
.542 .01851 Mdot
.542 .01857 Mdot
.542 .01868 Mdot
.542 .01882 Mdot
.542 .01883 Mdot
.542 .01889 Mdot
.542 .01901 Mdot
.542 .01908 Mdot
.542 .01916 Mdot
.542 .01917 Mdot
.542 .01924 Mdot
.542 .01937 Mdot
.542 .01944 Mdot
.542 .01946 Mdot
.542 .01954 Mdot
.542 .01955 Mdot
.542 .01962 Mdot
.542 .01976 Mdot
.542 .01984 Mdot
.542 .01986 Mdot
.542 .01994 Mdot
.542 .01995 Mdot
.542 .02003 Mdot
.542 .0201 Mdot
.542 .02019 Mdot
.542 .02027 Mdot
.542 .0203 Mdot
.542 .02038 Mdot
.542 .02039 Mdot
.542 .02048 Mdot
.542 .02056 Mdot
.542 .02065 Mdot
.542 .02074 Mdot
.542 .02076 Mdot
.542 .02076 Mdot
.542 .02086 Mdot
.542 .02087 Mdot
.542 .02096 Mdot
.542 .02105 Mdot
.542 .02115 Mdot
.542 .02124 Mdot
.542 .02127 Mdot
.542 .02127 Mdot
.542 .02137 Mdot
.542 .02139 Mdot
.542 .02149 Mdot
.542 .02158 Mdot
.542 .02169 Mdot
.542 .02179 Mdot
.542 .02182 Mdot
.542 .02182 Mdot
.542 .02193 Mdot
.542 .02195 Mdot
.542 .02206 Mdot
.542 .02216 Mdot
.542 .02227 Mdot
.542 .02239 Mdot
.542 .02242 Mdot
.542 .02242 Mdot
.542 .02254 Mdot
.542 .02255 Mdot
.542 .02267 Mdot
.542 .02278 Mdot
.542 .02291 Mdot
.542 .02303 Mdot
.542 .02307 Mdot
.542 .02307 Mdot
.542 .0232 Mdot
.542 .02321 Mdot
.542 .02334 Mdot
.542 .02346 Mdot
.542 .02359 Mdot
.542 .02373 Mdot
.542 .02377 Mdot
.542 .02377 Mdot
.542 .02377 Mdot
.542 .02391 Mdot
.542 .02392 Mdot
.542 .02407 Mdot
.542 .02419 Mdot
.542 .02434 Mdot
.542 .02449 Mdot
.542 .02453 Mdot
.542 .02453 Mdot
.542 .02453 Mdot
.542 .02468 Mdot
.542 .0247 Mdot
.542 .02484 Mdot
.542 .02485 Mdot
.542 .02499 Mdot
.542 .02515 Mdot
.542 .02531 Mdot
.542 .02535 Mdot
.542 .02535 Mdot
.542 .02535 Mdot
.542 .02552 Mdot
.542 .02554 Mdot
.542 .02569 Mdot
.542 .02571 Mdot
.542 .02585 Mdot
.542 .02603 Mdot
.542 .0262 Mdot
.542 .02625 Mdot
.542 .02625 Mdot
.542 .02625 Mdot
.542 .02643 Mdot
.542 .02645 Mdot
.542 .02661 Mdot
.542 .02663 Mdot
.542 .02679 Mdot
.542 .02698 Mdot
.542 .02716 Mdot
.542 .02721 Mdot
.542 .02722 Mdot
.542 .02722 Mdot
.542 .02741 Mdot
.542 .02743 Mdot
.542 .02761 Mdot
.542 .02763 Mdot
.542 .0278 Mdot
.542 .02801 Mdot
.542 .02821 Mdot
.542 .02826 Mdot
.542 .02827 Mdot
.542 .02827 Mdot
.542 .02847 Mdot
.542 .0285 Mdot
.542 .0287 Mdot
.542 .02871 Mdot
.542 .0289 Mdot
.542 .02895 Mdot
.542 .02912 Mdot
.542 .02934 Mdot
.542 .0294 Mdot
.542 .0294 Mdot
.542 .02941 Mdot
.542 .02963 Mdot
.542 .02966 Mdot
.542 .02987 Mdot
.542 .02989 Mdot
.542 .03009 Mdot
.542 .03014 Mdot
.542 .03033 Mdot
.542 .03057 Mdot
.542 .03064 Mdot
.542 .03064 Mdot
.542 .03064 Mdot
.542 .03065 Mdot
.542 .03088 Mdot
.542 .03091 Mdot
.542 .03115 Mdot
.542 .03116 Mdot
.542 .03138 Mdot
.542 .03144 Mdot
.542 .03164 Mdot
.542 .03173 Mdot
.542 .03189 Mdot
.542 .0319 Mdot
.542 .03197 Mdot
.542 .03198 Mdot
.542 .03198 Mdot
.542 .03199 Mdot
.542 .03224 Mdot
.542 .03227 Mdot
.542 .03253 Mdot
.542 .03255 Mdot
.542 .03278 Mdot
.542 .03284 Mdot
.542 .03307 Mdot
.542 .03316 Mdot
.542 .03333 Mdot
.542 .03335 Mdot
.542 .03342 Mdot
.542 .03343 Mdot
.542 .03343 Mdot
.542 .03344 Mdot
.542 .03371 Mdot
.542 .03374 Mdot
.542 .03375 Mdot
.542 .03402 Mdot
.542 .03404 Mdot
.542 .03408 Mdot
.542 .0343 Mdot
.542 .03436 Mdot
.542 .03461 Mdot
.542 .03471 Mdot
.542 .03489 Mdot
.542 .03491 Mdot
.542 .035 Mdot
.542 .035 Mdot
.542 .035 Mdot
.542 .03501 Mdot
.542 .03531 Mdot
.542 .03534 Mdot
.542 .03535 Mdot
.542 .03546 Mdot
.542 .03551 Mdot
.542 .03553 Mdot
.542 .03564 Mdot
.542 .03567 Mdot
.542 .03571 Mdot
.542 .03575 Mdot
.542 .03595 Mdot
.542 .03601 Mdot
.542 .03628 Mdot
.542 .03639 Mdot
.542 .03659 Mdot
.542 .03661 Mdot
.542 .0367 Mdot
.542 .0367 Mdot
.542 .0367 Mdot
.542 .03672 Mdot
.542 .03704 Mdot
.542 .03707 Mdot
.542 .03708 Mdot
.542 .03721 Mdot
.542 .03726 Mdot
.542 .03728 Mdot
.542 .0374 Mdot
.542 .03743 Mdot
.542 .03747 Mdot
.542 .03752 Mdot
.542 .03773 Mdot
.542 .0378 Mdot
.542 .03809 Mdot
.542 .03821 Mdot
.542 .0383 Mdot
.542 .03843 Mdot
.542 .03845 Mdot
.542 .03855 Mdot
.542 .03855 Mdot
.542 .03855 Mdot
.542 .03857 Mdot
.542 .03892 Mdot
.542 .03895 Mdot
.542 .03896 Mdot
.542 .03909 Mdot
.542 .03915 Mdot
.542 .03917 Mdot
.542 .03931 Mdot
.542 .03934 Mdot
.542 .03938 Mdot
.542 .03943 Mdot
.542 .03966 Mdot
.542 .03974 Mdot
.542 .04005 Mdot
.542 .04018 Mdot
.542 .04028 Mdot
.542 .04042 Mdot
.542 .04044 Mdot
.542 .04055 Mdot
.542 .04055 Mdot
.542 .04055 Mdot
.542 .04057 Mdot
.542 .04076 Mdot
.542 .04095 Mdot
.542 .04099 Mdot
.542 .041 Mdot
.542 .04114 Mdot
.542 .04121 Mdot
.542 .04123 Mdot
.542 .04129 Mdot
.542 .04137 Mdot
.542 .04139 Mdot
.542 .0414 Mdot
.542 .04146 Mdot
.542 .04151 Mdot
.542 .04176 Mdot
.542 .04185 Mdot
.542 .04218 Mdot
.542 .04232 Mdot
.542 .04242 Mdot
.542 .04258 Mdot
.542 .0426 Mdot
.542 .04272 Mdot
.542 .04272 Mdot
.542 .04272 Mdot
.542 .04274 Mdot
.542 .04295 Mdot
.542 .04315 Mdot
.542 .0432 Mdot
.542 .0432 Mdot
.542 .04336 Mdot
.542 .04343 Mdot
.542 .04345 Mdot
.542 .04352 Mdot
.542 .04361 Mdot
.542 .04363 Mdot
.542 .04365 Mdot
.542 .0437 Mdot
.542 .04376 Mdot
.542 .04403 Mdot
.542 .04412 Mdot
.542 .04449 Mdot
.542 .04464 Mdot
.542 .04475 Mdot
.542 .04492 Mdot
.542 .04495 Mdot
.542 .04507 Mdot
.542 .04507 Mdot
.542 .04507 Mdot
.542 .04509 Mdot
.542 .04532 Mdot
.542 .04554 Mdot
.542 .04559 Mdot
.542 .0456 Mdot
.542 .04577 Mdot
.542 .04584 Mdot
.542 .04587 Mdot
.542 .04594 Mdot
.542 .04604 Mdot
.542 .04605 Mdot
.542 .04608 Mdot
.542 .04614 Mdot
.542 .0462 Mdot
.542 .04649 Mdot
.542 .04659 Mdot
.542 .04699 Mdot
.542 .04715 Mdot
.542 .04727 Mdot
.542 .04745 Mdot
.542 .04749 Mdot
.542 .04762 Mdot
.542 .04762 Mdot
.542 .04762 Mdot
.542 .04765 Mdot
.542 .04789 Mdot
.542 .04813 Mdot
.542 .04818 Mdot
.542 .04819 Mdot
.542 .04838 Mdot
.542 .04846 Mdot
.542 .04848 Mdot
.542 .04857 Mdot
.542 .04867 Mdot
.542 .04869 Mdot
.542 .04871 Mdot
.542 .04878 Mdot
.542 .04885 Mdot
.542 .04916 Mdot
.542 .04927 Mdot
.542 .0497 Mdot
.542 .04988 Mdot
.542 .05001 Mdot
.542 .0502 Mdot
.542 .05024 Mdot
.542 .05038 Mdot
.542 .05039 Mdot
.542 .05039 Mdot
.542 .05041 Mdot
.542 .05068 Mdot
.542 .05094 Mdot
.542 .05099 Mdot
.542 .051 Mdot
.542 .0512 Mdot
.542 .05129 Mdot
.542 .05132 Mdot
.542 .05141 Mdot
.542 .05152 Mdot
.542 .05154 Mdot
.542 .05157 Mdot
.542 .05164 Mdot
.542 .05171 Mdot
.542 .05205 Mdot
.542 .05218 Mdot
.542 .05264 Mdot
.542 .05283 Mdot
.542 .05297 Mdot
.542 .05318 Mdot
.542 .05322 Mdot
.542 .05338 Mdot
.542 .05338 Mdot
.542 .05339 Mdot
.542 .05341 Mdot
.542 .0537 Mdot
.542 .05398 Mdot
.542 .05404 Mdot
.542 .05405 Mdot
.542 .05427 Mdot
.542 .05437 Mdot
.542 .05439 Mdot
.542 .05449 Mdot
.542 .05461 Mdot
.542 .05466 Mdot
.542 .05474 Mdot
.542 .05482 Mdot
.542 .05519 Mdot
.542 .05532 Mdot
.542 .05583 Mdot
.542 .05604 Mdot
.542 .05619 Mdot
.542 .05642 Mdot
.542 .05646 Mdot
.542 .05663 Mdot
.542 .05663 Mdot
.542 .05663 Mdot
.542 .05666 Mdot
.542 .05697 Mdot
.542 .05728 Mdot
.542 .05734 Mdot
.542 .05735 Mdot
.542 .05759 Mdot
.542 .0577 Mdot
.542 .05773 Mdot
.542 .05783 Mdot
.542 .05797 Mdot
.542 .05802 Mdot
.542 .0581 Mdot
.542 .05819 Mdot
.542 .05859 Mdot
.542 .05873 Mdot
.542 .05928 Mdot
.542 .05951 Mdot
.542 .05967 Mdot
.542 .05992 Mdot
.542 .05996 Mdot
.542 .06015 Mdot
.542 .06015 Mdot
.542 .06016 Mdot
.542 .06019 Mdot
.542 .06052 Mdot
.542 .06085 Mdot
.542 .06092 Mdot
.542 .06094 Mdot
.542 .06119 Mdot
.542 .06131 Mdot
.542 .06134 Mdot
.542 .06146 Mdot
.542 .0616 Mdot
.542 .06165 Mdot
.542 .06175 Mdot
.542 .06184 Mdot
.542 .06228 Mdot
.542 .06243 Mdot
.542 .06302 Mdot
.542 .06327 Mdot
.542 .06345 Mdot
.542 .06372 Mdot
.542 .06376 Mdot
.542 .06396 Mdot
.542 .06397 Mdot
.542 .06397 Mdot
.542 .064 Mdot
.542 .06437 Mdot
.542 .06473 Mdot
.542 .0648 Mdot
.542 .06482 Mdot
.542 .0651 Mdot
.542 .06522 Mdot
.542 .06526 Mdot
.542 .06538 Mdot
.542 .06554 Mdot
.542 .0656 Mdot
.542 .0657 Mdot
.542 .0658 Mdot
.542 .06627 Mdot
.542 .06644 Mdot
.542 .06708 Mdot
.542 .06735 Mdot
.542 .06754 Mdot
.542 .06783 Mdot
.542 .06788 Mdot
.542 .0681 Mdot
.542 .06811 Mdot
.542 .06811 Mdot
.542 .06815 Mdot
.542 .06854 Mdot
.542 .06893 Mdot
.542 .06901 Mdot
.542 .06903 Mdot
.542 .06933 Mdot
.542 .06946 Mdot
.542 .0695 Mdot
.542 .06964 Mdot
.542 .06981 Mdot
.542 .06987 Mdot
.542 .06998 Mdot
.542 .07009 Mdot
.542 .0706 Mdot
.542 .07078 Mdot
.542 .07148 Mdot
.542 .07177 Mdot
.542 .07198 Mdot
.542 .07229 Mdot
.542 .07235 Mdot
.542 .07258 Mdot
.542 .07259 Mdot
.542 .0726 Mdot
.542 .07263 Mdot
.542 .07306 Mdot
.542 .07348 Mdot
.542 .07357 Mdot
.542 .07359 Mdot
.542 .07392 Mdot
.542 .07406 Mdot
.542 .0741 Mdot
.542 .07425 Mdot
.542 .07443 Mdot
.542 .0745 Mdot
.542 .07462 Mdot
.542 .07474 Mdot
.542 .0753 Mdot
.542 .07549 Mdot
.542 .07625 Mdot
.542 .07656 Mdot
.542 .07679 Mdot
.542 .07713 Mdot
.542 .07719 Mdot
.542 .07745 Mdot
.542 .07745 Mdot
.542 .07746 Mdot
.542 .0775 Mdot
.542 .07797 Mdot
.542 .07842 Mdot
.542 .07852 Mdot
.542 .07853 Mdot
.542 .07889 Mdot
.542 .07905 Mdot
.542 .07909 Mdot
.542 .07925 Mdot
.542 .07945 Mdot
.542 .07953 Mdot
.542 .07965 Mdot
.542 .07979 Mdot
.542 .08038 Mdot
.542 .0806 Mdot
.542 .08142 Mdot
.542 .08176 Mdot
.542 .082 Mdot
.542 .08237 Mdot
.542 .08244 Mdot
.542 .08271 Mdot
.542 .08272 Mdot
.542 .08273 Mdot
.542 .08277 Mdot
.542 .08328 Mdot
.542 .08377 Mdot
.542 .08388 Mdot
.542 .08389 Mdot
.542 .08428 Mdot
.542 .08445 Mdot
.542 .0845 Mdot
.542 .08467 Mdot
.542 .08489 Mdot
.542 .08497 Mdot
.542 .08511 Mdot
.542 .08525 Mdot
.542 .0859 Mdot
.542 .08613 Mdot
.542 .08702 Mdot
.542 .08739 Mdot
.542 .08765 Mdot
.542 .08806 Mdot
.542 .08813 Mdot
.542 .08843 Mdot
.542 .08844 Mdot
.542 .08844 Mdot
.542 .08849 Mdot
.542 .08904 Mdot
.542 .08957 Mdot
.542 .08969 Mdot
.542 .08971 Mdot
.542 .09013 Mdot
.542 .09031 Mdot
.542 .09036 Mdot
.542 .09055 Mdot
.542 .09078 Mdot
.542 .09087 Mdot
.542 .09102 Mdot
.542 .09118 Mdot
.542 .09188 Mdot
.542 .09213 Mdot
.542 .09309 Mdot
.542 .09349 Mdot
.542 .09378 Mdot
.542 .09422 Mdot
.542 .0943 Mdot
.542 .09462 Mdot
.542 .09463 Mdot
.542 .09463 Mdot
.542 .09469 Mdot
.542 .09528 Mdot
.542 .09586 Mdot
.542 .09598 Mdot
.542 .09601 Mdot
.542 .09646 Mdot
.542 .09666 Mdot
.542 .09672 Mdot
.542 .09692 Mdot
.542 .09717 Mdot
.542 .09727 Mdot
.542 .09743 Mdot
.542 .0976 Mdot
.542 .09836 Mdot
.542 .09863 Mdot
.542 .09968 Mdot
.542 .10011 Mdot
.542 .10042 Mdot
.542 .10089 Mdot
.542 .10098 Mdot
.542 .10133 Mdot
.542 .10134 Mdot
.542 .10135 Mdot
.542 .1014 Mdot
.542 .10205 Mdot
.542 .10268 Mdot
.542 .10281 Mdot
.542 .10283 Mdot
.542 .10333 Mdot
.542 .10354 Mdot
.542 .10361 Mdot
.542 .10383 Mdot
.542 .1041 Mdot
.542 .1042 Mdot
.542 .10438 Mdot
.542 .10456 Mdot
.542 .10539 Mdot
.542 .10568 Mdot
.542 .10681 Mdot
.542 .10728 Mdot
.542 .10762 Mdot
.542 .10813 Mdot
.542 .10823 Mdot
.542 .10861 Mdot
.542 .10862 Mdot
.542 .10862 Mdot
.542 .10869 Mdot
.542 .10939 Mdot
.542 .11006 Mdot
.542 .11021 Mdot
.542 .11024 Mdot
.542 .11077 Mdot
.542 .111 Mdot
.542 .11107 Mdot
.542 .11131 Mdot
.542 .11161 Mdot
.542 .11172 Mdot
.542 .11191 Mdot
.542 .11211 Mdot
.542 .11301 Mdot
.542 .11333 Mdot
.542 .11455 Mdot
.542 .11506 Mdot
.542 .11543 Mdot
.542 .11598 Mdot
.542 .11608 Mdot
.542 .11649 Mdot
.542 .11651 Mdot
.542 .11651 Mdot
.542 .11658 Mdot
.542 .11734 Mdot
.542 .11807 Mdot
.542 .11823 Mdot
.542 .11826 Mdot
.542 .11884 Mdot
.542 .11909 Mdot
.542 .11917 Mdot
.542 .11943 Mdot
.542 .11975 Mdot
.542 .11987 Mdot
.542 .12008 Mdot
.542 .12029 Mdot
.542 .12126 Mdot
.542 .12161 Mdot
.542 .12294 Mdot
.542 .12349 Mdot
.542 .12389 Mdot
.542 .12449 Mdot
.542 .1246 Mdot
.542 .12504 Mdot
.542 .12506 Mdot
.542 .12506 Mdot
.542 .12514 Mdot
.542 .12596 Mdot
.542 .12676 Mdot
.542 .12693 Mdot
.542 .12696 Mdot
.542 .12759 Mdot
.542 .12786 Mdot
.542 .12794 Mdot
.542 .12822 Mdot
.542 .12857 Mdot
.542 .1287 Mdot
.542 .12893 Mdot
.542 .12916 Mdot
.542 .13021 Mdot
.542 .13059 Mdot
.542 .13203 Mdot
.542 .13262 Mdot
.542 .13306 Mdot
.542 .13371 Mdot
.542 .13383 Mdot
.542 .13431 Mdot
.542 .13433 Mdot
.542 .13433 Mdot
.542 .13441 Mdot
.542 .1353 Mdot
.542 .13617 Mdot
.542 .13635 Mdot
.542 .13639 Mdot
.542 .13707 Mdot
.542 .13736 Mdot
.542 .13745 Mdot
.542 .13776 Mdot
.542 .13813 Mdot
.542 .13828 Mdot
.542 .13852 Mdot
.542 .13877 Mdot
.542 .13991 Mdot
.542 .14032 Mdot
.542 .14188 Mdot
.542 .14253 Mdot
.542 .143 Mdot
.542 .1437 Mdot
.542 .14383 Mdot
.542 .14436 Mdot
.542 .14437 Mdot
.542 .14438 Mdot
.542 .14447 Mdot
.542 .14543 Mdot
.542 .14637 Mdot
.542 .14657 Mdot
.542 .14661 Mdot
.542 .14734 Mdot
.542 .14766 Mdot
.542 .14776 Mdot
.542 .14809 Mdot
.542 .1485 Mdot
.542 .14866 Mdot
.542 .14892 Mdot
.542 .14919 Mdot
.542 .15043 Mdot
.542 .15087 Mdot
.542 .15256 Mdot
.542 .15326 Mdot
.542 .15377 Mdot
.542 .15454 Mdot
.542 .15468 Mdot
.542 .15525 Mdot
.542 .15527 Mdot
.542 .15527 Mdot
.542 .15536 Mdot
.542 .15641 Mdot
.542 .15743 Mdot
.542 .15765 Mdot
.542 .15768 Mdot
.542 .15848 Mdot
.542 .15883 Mdot
.542 .15894 Mdot
.542 .15929 Mdot
.542 .15974 Mdot
.542 .15991 Mdot
.542 .16019 Mdot
.542 .16049 Mdot
.542 .16183 Mdot
.542 .16231 Mdot
.542 .16414 Mdot
.542 .1649 Mdot
.542 .16545 Mdot
.542 .16628 Mdot
.542 .16643 Mdot
.542 .16705 Mdot
.542 .16707 Mdot
.542 .16708 Mdot
.542 .16718 Mdot
.542 .16831 Mdot
.542 .16942 Mdot
.542 .16965 Mdot
.542 .16969 Mdot
.542 .17056 Mdot
.542 .17094 Mdot
.542 .17105 Mdot
.542 .17144 Mdot
.542 .17192 Mdot
.542 .1721 Mdot
.542 .17241 Mdot
.542 .17273 Mdot
.542 .17419 Mdot
.542 .17471 Mdot
.542 .17669 Mdot
.542 .17752 Mdot
.542 .17812 Mdot
.542 .17901 Mdot
.542 .17918 Mdot
.542 .17985 Mdot
.542 .17987 Mdot
.542 .17988 Mdot
.542 .17999 Mdot
.542 .18122 Mdot
.542 .18241 Mdot
.542 .18267 Mdot
.542 .18271 Mdot
.542 .18365 Mdot
.542 .18406 Mdot
.542 .18418 Mdot
.542 .1846 Mdot
.542 .18512 Mdot
.542 .18533 Mdot
.542 .18566 Mdot
.542 .18601 Mdot
.542 .18758 Mdot
.542 .18815 Mdot
.542 .1903 Mdot
.542 .19119 Mdot
.542 .19184 Mdot
.542 .19282 Mdot
.542 .19299 Mdot
.542 .19372 Mdot
.542 .19374 Mdot
.542 .19375 Mdot
.542 .19387 Mdot
.542 .1952 Mdot
.542 .1965 Mdot
.542 .19677 Mdot
.542 .19682 Mdot
.542 .19784 Mdot
.542 .19829 Mdot
.542 .19842 Mdot
.542 .19887 Mdot
.542 .19944 Mdot
.542 .19966 Mdot
.542 .20002 Mdot
.542 .2004 Mdot
.542 .2021 Mdot
.542 .20271 Mdot
.542 .20505 Mdot
.542 .20602 Mdot
.542 .20672 Mdot
.542 .20778 Mdot
.542 .20797 Mdot
.542 .20875 Mdot
.542 .20878 Mdot
.542 .20879 Mdot
.542 .20892 Mdot
.542 .21036 Mdot
.542 .21177 Mdot
.542 .21207 Mdot
.542 .21212 Mdot
.542 .21323 Mdot
.542 .21371 Mdot
.542 .21385 Mdot
.542 .21434 Mdot
.542 .21495 Mdot
.542 .21519 Mdot
.542 .21559 Mdot
.542 .21599 Mdot
.542 .21785 Mdot
.542 .21851 Mdot
.542 .22104 Mdot
.542 .22209 Mdot
.542 .22285 Mdot
.542 .22399 Mdot
.542 .2242 Mdot
.542 .22505 Mdot
.542 .22508 Mdot
.542 .22509 Mdot
.542 .22523 Mdot
.542 .2268 Mdot
.542 .22832 Mdot
.542 .22865 Mdot
.542 .2287 Mdot
.542 .2299 Mdot
.542 .23042 Mdot
.542 .23058 Mdot
.542 .23111 Mdot
.542 .23177 Mdot
.542 .23203 Mdot
.542 .23246 Mdot
.542 .2329 Mdot
.542 .23491 Mdot
.542 .23563 Mdot
.542 .23837 Mdot
.542 .23951 Mdot
.542 .24033 Mdot
.542 .24157 Mdot
.542 .2418 Mdot
.542 .24272 Mdot
.542 .24275 Mdot
.542 .24276 Mdot
.542 .24291 Mdot
.542 .24461 Mdot
.542 .24626 Mdot
.542 .24662 Mdot
.542 .24668 Mdot
.542 .24798 Mdot
.542 .24854 Mdot
.542 .24871 Mdot
.542 .24929 Mdot
.542 .25001 Mdot
.542 .25029 Mdot
.542 .25075 Mdot
.542 .25123 Mdot
.542 .2534 Mdot
.542 .25418 Mdot
.542 .25715 Mdot
.542 .25839 Mdot
.542 .25928 Mdot
.542 .26063 Mdot
.542 .26087 Mdot
.542 .26187 Mdot
.542 .26191 Mdot
.542 .26192 Mdot
.542 .26208 Mdot
.542 .26393 Mdot
.542 .26571 Mdot
.542 .26609 Mdot
.542 .26616 Mdot
.542 .26757 Mdot
.542 .26818 Mdot
.542 .26837 Mdot
.542 .26899 Mdot
.542 .26977 Mdot
.542 .27007 Mdot
.542 .27058 Mdot
.542 .27109 Mdot
.542 .27345 Mdot
.542 .2743 Mdot
.542 .27752 Mdot
.542 .27886 Mdot
.542 .27983 Mdot
.542 .28128 Mdot
.542 .28155 Mdot
.542 .28263 Mdot
.542 .28267 Mdot
.542 .28269 Mdot
.542 .28286 Mdot
.542 .28486 Mdot
.542 .28679 Mdot
.542 .28721 Mdot
.542 .28728 Mdot
.542 .28881 Mdot
.542 .28947 Mdot
.542 .28967 Mdot
.542 .29035 Mdot
.542 .2912 Mdot
.542 .29153 Mdot
.542 .29207 Mdot
.542 .29263 Mdot
.542 .29519 Mdot
.542 .2961 Mdot
.542 .29959 Mdot
.542 .30104 Mdot
.542 .3021 Mdot
.542 .30368 Mdot
.542 .30397 Mdot
.542 .30514 Mdot
.542 .30518 Mdot
.542 .3052 Mdot
.542 .30539 Mdot
.542 .30755 Mdot
.542 .30965 Mdot
.542 .3101 Mdot
.542 .31018 Mdot
.542 .31183 Mdot
.542 .31255 Mdot
.542 .31277 Mdot
.542 .31351 Mdot
.542 .31442 Mdot
.542 .31478 Mdot
.542 .31537 Mdot
.542 .31598 Mdot
.542 .31875 Mdot
.542 .31974 Mdot
.542 .32352 Mdot
.542 .3251 Mdot
.542 .32624 Mdot
.542 .32795 Mdot
.542 .32826 Mdot
.542 .32954 Mdot
.542 .32958 Mdot
.542 .3296 Mdot
.542 .3298 Mdot
.542 .33215 Mdot
.542 .33442 Mdot
.542 .33491 Mdot
.542 .335 Mdot
.544 .01489 Mdot
.544 .01491 Mdot
.544 .01492 Mdot
.544 .01494 Mdot
.544 .01496 Mdot
.544 .01498 Mdot
.544 .01501 Mdot
.544 .01503 Mdot
.544 .01506 Mdot
.544 .01509 Mdot
.544 .01513 Mdot
.544 .01516 Mdot
.544 .0152 Mdot
.544 .01524 Mdot
.544 .01529 Mdot
.544 .01534 Mdot
.544 .0154 Mdot
.544 .01546 Mdot
.544 .01552 Mdot
.544 .01559 Mdot
.544 .01567 Mdot
.544 .01575 Mdot
.544 .01585 Mdot
.544 .01595 Mdot
.544 .01605 Mdot
.544 .01617 Mdot
.544 .0163 Mdot
.544 .01644 Mdot
.544 .01659 Mdot
.544 .01676 Mdot
.544 .01693 Mdot
.544 .01713 Mdot
.544 .01734 Mdot
.544 .01757 Mdot
.544 .01783 Mdot
.544 .01805 Mdot
.544 .0181 Mdot
.544 .01816 Mdot
.544 .01834 Mdot
.544 .0184 Mdot
.544 .01846 Mdot
.544 .01866 Mdot
.544 .01872 Mdot
.544 .01879 Mdot
.544 .01901 Mdot
.544 .01907 Mdot
.544 .01915 Mdot
.544 .01939 Mdot
.544 .01941 Mdot
.544 .01946 Mdot
.544 .01954 Mdot
.544 .0198 Mdot
.544 .01982 Mdot
.544 .01987 Mdot
.544 .01996 Mdot
.544 .02011 Mdot
.544 .02025 Mdot
.544 .02027 Mdot
.544 .02033 Mdot
.544 .02042 Mdot
.544 .02059 Mdot
.544 .02074 Mdot
.544 .02076 Mdot
.544 .02082 Mdot
.544 .02093 Mdot
.544 .02111 Mdot
.544 .02127 Mdot
.544 .02129 Mdot
.544 .02136 Mdot
.544 .02147 Mdot
.544 .02167 Mdot
.544 .02184 Mdot
.544 .02187 Mdot
.544 .02194 Mdot
.544 .02207 Mdot
.544 .02228 Mdot
.544 .02247 Mdot
.544 .0225 Mdot
.544 .02257 Mdot
.544 .02258 Mdot
.544 .02271 Mdot
.544 .02294 Mdot
.544 .02315 Mdot
.544 .02319 Mdot
.544 .02326 Mdot
.544 .02327 Mdot
.544 .02342 Mdot
.544 .02367 Mdot
.544 .02389 Mdot
.544 .02393 Mdot
.544 .02402 Mdot
.544 .02403 Mdot
.544 .02418 Mdot
.544 .02446 Mdot
.544 .0247 Mdot
.544 .02474 Mdot
.544 .02483 Mdot
.544 .02485 Mdot
.544 .02495 Mdot
.544 .02502 Mdot
.544 .02531 Mdot
.544 .02558 Mdot
.544 .02563 Mdot
.544 .02572 Mdot
.544 .02574 Mdot
.544 .02585 Mdot
.544 .02592 Mdot
.544 .02625 Mdot
.544 .02652 Mdot
.544 .02654 Mdot
.544 .02659 Mdot
.544 .02669 Mdot
.544 .02671 Mdot
.544 .02683 Mdot
.544 .02691 Mdot
.544 .02726 Mdot
.544 .02756 Mdot
.544 .02758 Mdot
.544 .02763 Mdot
.544 .02775 Mdot
.544 .02776 Mdot
.544 .0279 Mdot
.544 .02798 Mdot
.544 .02837 Mdot
.544 .02869 Mdot
.544 .02871 Mdot
.544 .02877 Mdot
.544 .02889 Mdot
.544 .02891 Mdot
.544 .02906 Mdot
.544 .02915 Mdot
.544 .02957 Mdot
.544 .02958 Mdot
.544 .02969 Mdot
.544 .02977 Mdot
.544 .02992 Mdot
.544 .02994 Mdot
.544 .03001 Mdot
.544 .03014 Mdot
.544 .03016 Mdot
.544 .03032 Mdot
.544 .03042 Mdot
.544 .03087 Mdot
.544 .03088 Mdot
.544 .03101 Mdot
.544 .0311 Mdot
.544 .03115 Mdot
.544 .03125 Mdot
.544 .03128 Mdot
.544 .03135 Mdot
.544 .03145 Mdot
.544 .0315 Mdot
.544 .03152 Mdot
.544 .03169 Mdot
.544 .0317 Mdot
.544 .0318 Mdot
.544 .0323 Mdot
.544 .03231 Mdot
.544 .03238 Mdot
.544 .03244 Mdot
.544 .03254 Mdot
.544 .03259 Mdot
.544 .03271 Mdot
.544 .03274 Mdot
.544 .03282 Mdot
.544 .03292 Mdot
.544 .03298 Mdot
.544 .033 Mdot
.544 .03319 Mdot
.544 .03319 Mdot
.544 .03331 Mdot
.544 .03384 Mdot
.544 .03385 Mdot
.544 .03393 Mdot
.544 .034 Mdot
.544 .03411 Mdot
.544 .03417 Mdot
.544 .03426 Mdot
.544 .03429 Mdot
.544 .03432 Mdot
.544 .03441 Mdot
.544 .03452 Mdot
.544 .03458 Mdot
.544 .03461 Mdot
.544 .03481 Mdot
.544 .03482 Mdot
.544 .03494 Mdot
.544 .03524 Mdot
.544 .03553 Mdot
.544 .03554 Mdot
.544 .03562 Mdot
.544 .0357 Mdot
.544 .03582 Mdot
.544 .03588 Mdot
.544 .03598 Mdot
.544 .03602 Mdot
.544 .03605 Mdot
.544 .03614 Mdot
.544 .03627 Mdot
.544 .03633 Mdot
.544 .03636 Mdot
.544 .03658 Mdot
.544 .03659 Mdot
.544 .03672 Mdot
.544 .03689 Mdot
.544 .03705 Mdot
.544 .03736 Mdot
.544 .03737 Mdot
.544 .03746 Mdot
.544 .0375 Mdot
.544 .03755 Mdot
.544 .03767 Mdot
.544 .03774 Mdot
.544 .03785 Mdot
.544 .03789 Mdot
.544 .03793 Mdot
.544 .038 Mdot
.544 .03803 Mdot
.544 .03816 Mdot
.544 .03824 Mdot
.544 .03826 Mdot
.544 .03851 Mdot
.544 .03852 Mdot
.544 .03866 Mdot
.544 .03884 Mdot
.544 .03901 Mdot
.544 .03913 Mdot
.544 .03935 Mdot
.544 .03937 Mdot
.544 .03947 Mdot
.544 .03951 Mdot
.544 .03956 Mdot
.544 .03969 Mdot
.544 .03977 Mdot
.544 .03989 Mdot
.544 .03993 Mdot
.544 .03997 Mdot
.544 .04005 Mdot
.544 .04008 Mdot
.544 .04023 Mdot
.544 .0403 Mdot
.544 .04033 Mdot
.544 .0406 Mdot
.544 .04061 Mdot
.544 .04077 Mdot
.544 .04096 Mdot
.544 .04115 Mdot
.544 .04128 Mdot
.544 .04152 Mdot
.544 .04153 Mdot
.544 .04153 Mdot
.544 .04164 Mdot
.544 .04167 Mdot
.544 .04169 Mdot
.544 .04174 Mdot
.544 .04189 Mdot
.544 .04197 Mdot
.544 .0421 Mdot
.544 .04215 Mdot
.544 .04219 Mdot
.544 .04228 Mdot
.544 .04231 Mdot
.544 .04247 Mdot
.544 .04256 Mdot
.544 .04259 Mdot
.544 .04261 Mdot
.544 .04288 Mdot
.544 .04289 Mdot
.544 .043 Mdot
.544 .04306 Mdot
.544 .04327 Mdot
.544 .04348 Mdot
.544 .04361 Mdot
.544 .04388 Mdot
.544 .04389 Mdot
.544 .04389 Mdot
.544 .04401 Mdot
.544 .04404 Mdot
.544 .04406 Mdot
.544 .04412 Mdot
.544 .04428 Mdot
.544 .04437 Mdot
.544 .04451 Mdot
.544 .04456 Mdot
.544 .04461 Mdot
.544 .04471 Mdot
.544 .04474 Mdot
.544 .04491 Mdot
.544 .04501 Mdot
.544 .04504 Mdot
.544 .04506 Mdot
.544 .04536 Mdot
.544 .04537 Mdot
.544 .04549 Mdot
.544 .04555 Mdot
.544 .04578 Mdot
.544 .04601 Mdot
.544 .04616 Mdot
.544 .04644 Mdot
.544 .04645 Mdot
.544 .04646 Mdot
.544 .04659 Mdot
.544 .04662 Mdot
.544 .04664 Mdot
.544 .04671 Mdot
.544 .04689 Mdot
.544 .04698 Mdot
.544 .04713 Mdot
.544 .04719 Mdot
.544 .04724 Mdot
.544 .04734 Mdot
.544 .04738 Mdot
.544 .04757 Mdot
.544 .04767 Mdot
.544 .04771 Mdot
.544 .04773 Mdot
.544 .04805 Mdot
.544 .04806 Mdot
.544 .04819 Mdot
.544 .04827 Mdot
.544 .04852 Mdot
.544 .04876 Mdot
.544 .04892 Mdot
.544 .04924 Mdot
.544 .04925 Mdot
.544 .04926 Mdot
.544 .0494 Mdot
.544 .04943 Mdot
.544 .04945 Mdot
.544 .04952 Mdot
.544 .04972 Mdot
.544 .04982 Mdot
.544 .04999 Mdot
.544 .05005 Mdot
.544 .0501 Mdot
.544 .05022 Mdot
.544 .05026 Mdot
.544 .05046 Mdot
.544 .05057 Mdot
.544 .05061 Mdot
.544 .05064 Mdot
.544 .05099 Mdot
.544 .051 Mdot
.544 .05114 Mdot
.544 .05122 Mdot
.544 .05149 Mdot
.544 .05176 Mdot
.544 .05193 Mdot
.544 .05227 Mdot
.544 .05229 Mdot
.544 .0523 Mdot
.544 .05245 Mdot
.544 .05248 Mdot
.544 .05251 Mdot
.544 .05259 Mdot
.544 .0528 Mdot
.544 .05291 Mdot
.544 .05309 Mdot
.544 .05316 Mdot
.544 .05321 Mdot
.544 .05334 Mdot
.544 .05338 Mdot
.544 .05361 Mdot
.544 .05373 Mdot
.544 .05377 Mdot
.544 .0538 Mdot
.544 .05418 Mdot
.544 .05419 Mdot
.544 .05434 Mdot
.544 .05443 Mdot
.544 .05473 Mdot
.544 .05502 Mdot
.544 .05521 Mdot
.544 .05558 Mdot
.544 .05559 Mdot
.544 .0556 Mdot
.544 .05577 Mdot
.544 .05581 Mdot
.544 .05584 Mdot
.544 .05592 Mdot
.544 .05615 Mdot
.544 .05627 Mdot
.544 .05647 Mdot
.544 .05654 Mdot
.544 .0566 Mdot
.544 .05674 Mdot
.544 .05679 Mdot
.544 .05703 Mdot
.544 .05716 Mdot
.544 .05721 Mdot
.544 .05724 Mdot
.544 .05765 Mdot
.544 .05767 Mdot
.544 .05783 Mdot
.544 .05793 Mdot
.544 .05825 Mdot
.544 .05856 Mdot
.544 .05877 Mdot
.544 .05918 Mdot
.544 .05919 Mdot
.544 .0592 Mdot
.544 .05938 Mdot
.544 .05942 Mdot
.544 .05946 Mdot
.544 .05955 Mdot
.544 .05979 Mdot
.544 .05992 Mdot
.544 .06014 Mdot
.544 .06022 Mdot
.544 .06029 Mdot
.544 .06044 Mdot
.544 .06049 Mdot
.544 .06075 Mdot
.544 .0609 Mdot
.544 .06095 Mdot
.544 .06098 Mdot
.544 .06143 Mdot
.544 .06145 Mdot
.544 .06163 Mdot
.544 .06173 Mdot
.544 .06208 Mdot
.544 .06242 Mdot
.544 .06265 Mdot
.544 .06309 Mdot
.544 .0631 Mdot
.544 .06312 Mdot
.544 .06331 Mdot
.544 .06336 Mdot
.544 .06339 Mdot
.544 .06349 Mdot
.544 .06376 Mdot
.544 .0639 Mdot
.544 .06414 Mdot
.544 .06423 Mdot
.544 .0643 Mdot
.544 .06446 Mdot
.544 .06452 Mdot
.544 .06481 Mdot
.544 .06496 Mdot
.544 .06502 Mdot
.544 .06505 Mdot
.544 .06554 Mdot
.544 .06556 Mdot
.544 .06575 Mdot
.544 .06586 Mdot
.544 .06625 Mdot
.544 .06662 Mdot
.544 .06687 Mdot
.544 .06734 Mdot
.544 .06736 Mdot
.544 .06738 Mdot
.544 .06759 Mdot
.544 .06764 Mdot
.544 .06768 Mdot
.544 .06778 Mdot
.544 .06808 Mdot
.544 .06823 Mdot
.544 .06849 Mdot
.544 .06858 Mdot
.544 .06866 Mdot
.544 .06884 Mdot
.544 .0689 Mdot
.544 .06921 Mdot
.544 .06938 Mdot
.544 .06944 Mdot
.544 .06948 Mdot
.544 .07002 Mdot
.544 .07003 Mdot
.544 .07025 Mdot
.544 .07037 Mdot
.544 .07078 Mdot
.544 .07119 Mdot
.544 .07146 Mdot
.544 .07198 Mdot
.544 .072 Mdot
.544 .07201 Mdot
.544 .07224 Mdot
.544 .07229 Mdot
.544 .07234 Mdot
.544 .07245 Mdot
.544 .07277 Mdot
.544 .07294 Mdot
.544 .07322 Mdot
.544 .07332 Mdot
.544 .07341 Mdot
.544 .0736 Mdot
.544 .07367 Mdot
.544 .07401 Mdot
.544 .07419 Mdot
.544 .07426 Mdot
.544 .0743 Mdot
.544 .07488 Mdot
.544 .0749 Mdot
.544 .07513 Mdot
.544 .07526 Mdot
.544 .07572 Mdot
.544 .07616 Mdot
.544 .07645 Mdot
.544 .07701 Mdot
.544 .07704 Mdot
.544 .07705 Mdot
.544 .07731 Mdot
.544 .07736 Mdot
.544 .07741 Mdot
.544 .07753 Mdot
.544 .07788 Mdot
.544 .07806 Mdot
.544 .07837 Mdot
.544 .07848 Mdot
.544 .07857 Mdot
.544 .07878 Mdot
.544 .07885 Mdot
.544 .07923 Mdot
.544 .07943 Mdot
.544 .0795 Mdot
.544 .07954 Mdot
.544 .08018 Mdot
.544 .0802 Mdot
.544 .08045 Mdot
.544 .08059 Mdot
.544 .08109 Mdot
.544 .08157 Mdot
.544 .08188 Mdot
.544 .0825 Mdot
.544 .08252 Mdot
.544 .08254 Mdot
.544 .08281 Mdot
.544 .08287 Mdot
.544 .08293 Mdot
.544 .08306 Mdot
.544 .08344 Mdot
.544 .08364 Mdot
.544 .08397 Mdot
.544 .08409 Mdot
.544 .08419 Mdot
.544 .08442 Mdot
.544 .0845 Mdot
.544 .0849 Mdot
.544 .08512 Mdot
.544 .0852 Mdot
.544 .08524 Mdot
.544 .08594 Mdot
.544 .08596 Mdot
.544 .08623 Mdot
.544 .08639 Mdot
.544 .08693 Mdot
.544 .08745 Mdot
.544 .08779 Mdot
.544 .08846 Mdot
.544 .08849 Mdot
.544 .08851 Mdot
.544 .08881 Mdot
.544 .08887 Mdot
.544 .08893 Mdot
.544 .08908 Mdot
.544 .08949 Mdot
.544 .0897 Mdot
.544 .09006 Mdot
.544 .0902 Mdot
.544 .09031 Mdot
.544 .09056 Mdot
.544 .09064 Mdot
.544 .09108 Mdot
.544 .09132 Mdot
.544 .0914 Mdot
.544 .09145 Mdot
.544 .0922 Mdot
.544 .09223 Mdot
.544 .09253 Mdot
.544 .0927 Mdot
.544 .09328 Mdot
.544 .09385 Mdot
.544 .09422 Mdot
.544 .09495 Mdot
.544 .09498 Mdot
.544 .095 Mdot
.544 .09533 Mdot
.544 .0954 Mdot
.544 .09546 Mdot
.544 .09562 Mdot
.544 .09607 Mdot
.544 .0963 Mdot
.544 .09669 Mdot
.544 .09684 Mdot
.544 .09696 Mdot
.544 .09723 Mdot
.544 .09732 Mdot
.544 .0978 Mdot
.544 .09806 Mdot
.544 .09815 Mdot
.544 .0982 Mdot
.544 .09902 Mdot
.544 .09905 Mdot
.544 .09938 Mdot
.544 .09956 Mdot
.544 .1002 Mdot
.544 .10081 Mdot
.544 .10122 Mdot
.544 .10201 Mdot
.544 .10204 Mdot
.544 .10206 Mdot
.544 .10242 Mdot
.544 .1025 Mdot
.544 .10256 Mdot
.544 .10274 Mdot
.544 .10323 Mdot
.544 .10348 Mdot
.544 .10391 Mdot
.544 .10407 Mdot
.544 .1042 Mdot
.544 .10449 Mdot
.544 .10459 Mdot
.544 .10511 Mdot
.544 .10539 Mdot
.544 .10549 Mdot
.544 .10555 Mdot
.544 .10644 Mdot
.544 .10647 Mdot
.544 .10683 Mdot
.544 .10702 Mdot
.544 .10772 Mdot
.544 .10839 Mdot
.544 .10883 Mdot
.544 .1097 Mdot
.544 .10973 Mdot
.544 .10975 Mdot
.544 .11014 Mdot
.544 .11022 Mdot
.544 .11029 Mdot
.544 .11049 Mdot
.544 .11102 Mdot
.544 .11129 Mdot
.544 .11176 Mdot
.544 .11193 Mdot
.544 .11207 Mdot
.544 .11239 Mdot
.544 .1125 Mdot
.544 .11307 Mdot
.544 .11337 Mdot
.544 .11348 Mdot
.544 .11354 Mdot
.544 .11451 Mdot
.544 .11455 Mdot
.544 .11493 Mdot
.544 .11515 Mdot
.544 .1159 Mdot
.544 .11663 Mdot
.544 .11711 Mdot
.544 .11805 Mdot
.544 .11809 Mdot
.544 .11811 Mdot
.544 .11854 Mdot
.544 .11863 Mdot
.544 .11871 Mdot
.544 .11891 Mdot
.544 .11949 Mdot
.544 .11979 Mdot
.544 .1203 Mdot
.544 .12049 Mdot
.544 .12064 Mdot
.544 .12099 Mdot
.544 .1211 Mdot
.544 .12172 Mdot
.544 .12205 Mdot
.544 .12217 Mdot
.544 .12224 Mdot
.544 .1233 Mdot
.544 .12333 Mdot
.544 .12375 Mdot
.544 .12399 Mdot
.544 .12481 Mdot
.544 .1256 Mdot
.544 .12613 Mdot
.544 .12715 Mdot
.544 .12719 Mdot
.544 .12721 Mdot
.544 .12767 Mdot
.544 .12777 Mdot
.544 .12786 Mdot
.544 .12808 Mdot
.544 .12871 Mdot
.544 .12904 Mdot
.544 .12959 Mdot
.544 .12979 Mdot
.544 .12996 Mdot
.544 .13034 Mdot
.544 .13047 Mdot
.544 .13114 Mdot
.544 .13119 Mdot
.544 .1315 Mdot
.544 .13163 Mdot
.544 .1317 Mdot
.544 .13285 Mdot
.544 .13289 Mdot
.544 .13335 Mdot
.544 .1336 Mdot
.544 .1345 Mdot
.544 .13536 Mdot
.544 .13593 Mdot
.544 .13704 Mdot
.544 .13708 Mdot
.544 .13711 Mdot
.544 .13761 Mdot
.544 .13772 Mdot
.544 .13781 Mdot
.544 .13806 Mdot
.544 .13874 Mdot
.544 .1391 Mdot
.544 .1397 Mdot
.544 .13992 Mdot
.544 .1401 Mdot
.544 .14051 Mdot
.544 .14065 Mdot
.544 .14139 Mdot
.544 .14144 Mdot
.544 .14178 Mdot
.544 .14192 Mdot
.544 .142 Mdot
.544 .14325 Mdot
.544 .14329 Mdot
.544 .14379 Mdot
.544 .14406 Mdot
.544 .14504 Mdot
.544 .14598 Mdot
.544 .1466 Mdot
.544 .14781 Mdot
.544 .14785 Mdot
.544 .14788 Mdot
.544 .14843 Mdot
.544 .14855 Mdot
.544 .14865 Mdot
.544 .14891 Mdot
.544 .14966 Mdot
.544 .15005 Mdot
.544 .1507 Mdot
.544 .15094 Mdot
.544 .15114 Mdot
.544 .15158 Mdot
.544 .15173 Mdot
.544 .15253 Mdot
.544 .15259 Mdot
.544 .15296 Mdot
.544 .15311 Mdot
.544 .1532 Mdot
.544 .15456 Mdot
.544 .1546 Mdot
.544 .15514 Mdot
.544 .15545 Mdot
.544 .1565 Mdot
.544 .15753 Mdot
.544 .1582 Mdot
.544 .15952 Mdot
.544 .15957 Mdot
.544 .1596 Mdot
.544 .16019 Mdot
.544 .16032 Mdot
.544 .16043 Mdot
.544 .16072 Mdot
.544 .16153 Mdot
.544 .16195 Mdot
.544 .16266 Mdot
.544 .16293 Mdot
.544 .16314 Mdot
.544 .16363 Mdot
.544 .16379 Mdot
.544 .16466 Mdot
.544 .16472 Mdot
.544 .16512 Mdot
.544 .16529 Mdot
.544 .16539 Mdot
.544 .16687 Mdot
.544 .16691 Mdot
.544 .1675 Mdot
.544 .16783 Mdot
.544 .16898 Mdot
.544 .1701 Mdot
.544 .17083 Mdot
.544 .17226 Mdot
.544 .17231 Mdot
.544 .17235 Mdot
.544 .173 Mdot
.544 .17314 Mdot
.544 .17325 Mdot
.544 .17357 Mdot
.544 .17445 Mdot
.544 .17491 Mdot
.544 .17568 Mdot
.544 .17597 Mdot
.544 .1762 Mdot
.544 .17673 Mdot
.544 .17691 Mdot
.544 .17786 Mdot
.544 .17792 Mdot
.544 .17836 Mdot
.544 .17854 Mdot
.544 .17865 Mdot
.544 .18025 Mdot
.544 .18031 Mdot
.544 .18095 Mdot
.544 .1813 Mdot
.544 .18256 Mdot
.544 .18377 Mdot
.544 .18457 Mdot
.544 .18612 Mdot
.544 .18618 Mdot
.544 .18623 Mdot
.544 .18692 Mdot
.544 .18708 Mdot
.544 .18721 Mdot
.544 .18755 Mdot
.544 .18851 Mdot
.544 .18901 Mdot
.544 .18985 Mdot
.544 .19016 Mdot
.544 .19041 Mdot
.544 .19099 Mdot
.544 .19118 Mdot
.544 .19221 Mdot
.544 .19228 Mdot
.544 .19276 Mdot
.544 .19296 Mdot
.544 .19307 Mdot
.544 .19482 Mdot
.544 .19488 Mdot
.544 .19558 Mdot
.544 .19596 Mdot
.544 .19733 Mdot
.544 .19865 Mdot
.544 .19951 Mdot
.544 .20121 Mdot
.544 .20127 Mdot
.544 .20132 Mdot
.544 .20208 Mdot
.544 .20225 Mdot
.544 .20239 Mdot
.544 .20276 Mdot
.544 .2038 Mdot
.544 .20435 Mdot
.544 .20526 Mdot
.544 .2056 Mdot
.544 .20588 Mdot
.544 .2065 Mdot
.544 .20671 Mdot
.544 .20783 Mdot
.544 .20791 Mdot
.544 .20843 Mdot
.544 .20864 Mdot
.544 .20877 Mdot
.544 .21067 Mdot
.544 .21073 Mdot
.544 .21149 Mdot
.544 .21191 Mdot
.544 .2134 Mdot
.544 .21483 Mdot
.544 .21578 Mdot
.544 .21762 Mdot
.544 .21769 Mdot
.544 .21774 Mdot
.544 .21857 Mdot
.544 .21875 Mdot
.544 .2189 Mdot
.544 .21931 Mdot
.544 .22044 Mdot
.544 .22103 Mdot
.544 .22203 Mdot
.544 .2224 Mdot
.544 .2227 Mdot
.544 .22338 Mdot
.544 .22361 Mdot
.544 .22483 Mdot
.544 .22491 Mdot
.544 .22547 Mdot
.544 .22571 Mdot
.544 .22584 Mdot
.544 .22792 Mdot
.544 .22798 Mdot
.544 .22881 Mdot
.544 .22927 Mdot
.544 .23088 Mdot
.544 .23244 Mdot
.544 .23347 Mdot
.544 .23548 Mdot
.544 .23555 Mdot
.544 .23561 Mdot
.544 .23651 Mdot
.544 .2367 Mdot
.544 .23687 Mdot
.544 .23731 Mdot
.544 .23855 Mdot
.544 .23919 Mdot
.544 .24027 Mdot
.544 .24067 Mdot
.544 .241 Mdot
.544 .24174 Mdot
.544 .24199 Mdot
.544 .24331 Mdot
.544 .24341 Mdot
.544 .24402 Mdot
.544 .24428 Mdot
.544 .24442 Mdot
.544 .24668 Mdot
.544 .24675 Mdot
.544 .24765 Mdot
.544 .24815 Mdot
.544 .2499 Mdot
.544 .2516 Mdot
.544 .25272 Mdot
.544 .2549 Mdot
.544 .25498 Mdot
.544 .25504 Mdot
.544 .25602 Mdot
.544 .25624 Mdot
.544 .25642 Mdot
.544 .2569 Mdot
.544 .25824 Mdot
.544 .25894 Mdot
.544 .26012 Mdot
.544 .26056 Mdot
.544 .26091 Mdot
.544 .26172 Mdot
.544 .26199 Mdot
.544 .26343 Mdot
.544 .26353 Mdot
.544 .2642 Mdot
.544 .26448 Mdot
.544 .26464 Mdot
.544 .26709 Mdot
.544 .26717 Mdot
.544 .26815 Mdot
.544 .26869 Mdot
.544 .2706 Mdot
.544 .27245 Mdot
.544 .27366 Mdot
.544 .27604 Mdot
.544 .27613 Mdot
.544 .27619 Mdot
.544 .27726 Mdot
.544 .27749 Mdot
.544 .27769 Mdot
.544 .27821 Mdot
.544 .27967 Mdot
.544 .28044 Mdot
.544 .28172 Mdot
.544 .28219 Mdot
.544 .28258 Mdot
.544 .28345 Mdot
.544 .28375 Mdot
.544 .28532 Mdot
.544 .28543 Mdot
.544 .28616 Mdot
.544 .28646 Mdot
.544 .28663 Mdot
.544 .2893 Mdot
.544 .28939 Mdot
.544 .29045 Mdot
.544 .29104 Mdot
.544 .29312 Mdot
.544 .29513 Mdot
.544 .29645 Mdot
.544 .29904 Mdot
.544 .29913 Mdot
.544 .2992 Mdot
.544 .30036 Mdot
.544 .30062 Mdot
.544 .30083 Mdot
.544 .3014 Mdot
.544 .30299 Mdot
.544 .30382 Mdot
.544 .30521 Mdot
.544 .30573 Mdot
.544 .30615 Mdot
.544 .3071 Mdot
.544 .30913 Mdot
.544 .30925 Mdot
.544 .31004 Mdot
.544 .31037 Mdot
.544 .31056 Mdot
.544 .31346 Mdot
.544 .31356 Mdot
.544 .31471 Mdot
.544 .31536 Mdot
.544 .31762 Mdot
.544 .3198 Mdot
.544 .32125 Mdot
.544 .32406 Mdot
.544 .32416 Mdot
.544 .32424 Mdot
.544 .3255 Mdot
.544 .32578 Mdot
.544 .32601 Mdot
.544 .32663 Mdot
.544 .32836 Mdot
.544 .32926 Mdot
.544 .33077 Mdot
.544 .33134 Mdot
.544 .3318 Mdot
.544 .33283 Mdot
.544 .33504 Mdot
.544 .33517 Mdot
.544 .33603 Mdot
.544 .33639 Mdot
.546 .01648 Mdot
.546 .01665 Mdot
.546 .01682 Mdot
.546 .01702 Mdot
.546 .01723 Mdot
.546 .01746 Mdot
.546 .0176 Mdot
.546 .01772 Mdot
.546 .01787 Mdot
.546 .01799 Mdot
.546 .01816 Mdot
.546 .01829 Mdot
.546 .01848 Mdot
.546 .01862 Mdot
.546 .01882 Mdot
.546 .01886 Mdot
.546 .01898 Mdot
.546 .01903 Mdot
.546 .01905 Mdot
.546 .0192 Mdot
.546 .01924 Mdot
.546 .01937 Mdot
.546 .01943 Mdot
.546 .01945 Mdot
.546 .01961 Mdot
.546 .01966 Mdot
.546 .0198 Mdot
.546 .01986 Mdot
.546 .01988 Mdot
.546 .02006 Mdot
.546 .02012 Mdot
.546 .02027 Mdot
.546 .02033 Mdot
.546 .02036 Mdot
.546 .02055 Mdot
.546 .02061 Mdot
.546 .02078 Mdot
.546 .02085 Mdot
.546 .02088 Mdot
.546 .02109 Mdot
.546 .02116 Mdot
.546 .02134 Mdot
.546 .02141 Mdot
.546 .02144 Mdot
.546 .02152 Mdot
.546 .02168 Mdot
.546 .02175 Mdot
.546 .02195 Mdot
.546 .02203 Mdot
.546 .02206 Mdot
.546 .02215 Mdot
.546 .02232 Mdot
.546 .0224 Mdot
.546 .02261 Mdot
.546 .0227 Mdot
.546 .02274 Mdot
.546 .02283 Mdot
.546 .02302 Mdot
.546 .0231 Mdot
.546 .02313 Mdot
.546 .02334 Mdot
.546 .02344 Mdot
.546 .02348 Mdot
.546 .02358 Mdot
.546 .02378 Mdot
.546 .02387 Mdot
.546 .0239 Mdot
.546 .02413 Mdot
.546 .02424 Mdot
.546 .02428 Mdot
.546 .0244 Mdot
.546 .0244 Mdot
.546 .02462 Mdot
.546 .02472 Mdot
.546 .02475 Mdot
.546 .025 Mdot
.546 .02512 Mdot
.546 .02516 Mdot
.546 .02529 Mdot
.546 .02529 Mdot
.546 .02553 Mdot
.546 .02564 Mdot
.546 .02567 Mdot
.546 .02595 Mdot
.546 .02607 Mdot
.546 .02613 Mdot
.546 .02626 Mdot
.546 .02626 Mdot
.546 .02645 Mdot
.546 .02652 Mdot
.546 .02664 Mdot
.546 .02668 Mdot
.546 .02687 Mdot
.546 .02698 Mdot
.546 .02712 Mdot
.546 .02718 Mdot
.546 .02727 Mdot
.546 .02732 Mdot
.546 .02732 Mdot
.546 .02753 Mdot
.546 .02761 Mdot
.546 .02774 Mdot
.546 .02778 Mdot
.546 .02799 Mdot
.546 .02811 Mdot
.546 .02826 Mdot
.546 .02832 Mdot
.546 .02837 Mdot
.546 .02842 Mdot
.546 .02848 Mdot
.546 .02848 Mdot
.546 .02871 Mdot
.546 .02879 Mdot
.546 .02894 Mdot
.546 .02898 Mdot
.546 .02921 Mdot
.546 .02932 Mdot
.546 .02934 Mdot
.546 .02951 Mdot
.546 .02957 Mdot
.546 .02963 Mdot
.546 .02968 Mdot
.546 .02975 Mdot
.546 .02975 Mdot
.546 .02986 Mdot
.546 .02999 Mdot
.546 .03009 Mdot
.546 .03024 Mdot
.546 .03029 Mdot
.546 .03054 Mdot
.546 .03066 Mdot
.546 .03069 Mdot
.546 .03087 Mdot
.546 .03089 Mdot
.546 .03094 Mdot
.546 .031 Mdot
.546 .03106 Mdot
.546 .03113 Mdot
.546 .03113 Mdot
.546 .03126 Mdot
.546 .0314 Mdot
.546 .0315 Mdot
.546 .03154 Mdot
.546 .03167 Mdot
.546 .03173 Mdot
.546 .032 Mdot
.546 .03213 Mdot
.546 .03216 Mdot
.546 .03235 Mdot
.546 .03238 Mdot
.546 .03243 Mdot
.546 .0325 Mdot
.546 .03256 Mdot
.546 .03264 Mdot
.546 .03264 Mdot
.546 .03278 Mdot
.546 .03293 Mdot
.546 .03305 Mdot
.546 .03309 Mdot
.546 .03323 Mdot
.546 .03329 Mdot
.546 .03359 Mdot
.546 .03373 Mdot
.546 .03376 Mdot
.546 .03387 Mdot
.546 .03398 Mdot
.546 .03401 Mdot
.546 .03406 Mdot
.546 .03414 Mdot
.546 .0342 Mdot
.546 .03429 Mdot
.546 .03429 Mdot
.546 .03444 Mdot
.546 .03461 Mdot
.546 .03473 Mdot
.546 .03476 Mdot
.546 .03478 Mdot
.546 .03494 Mdot
.546 .035 Mdot
.546 .03523 Mdot
.546 .03533 Mdot
.546 .03548 Mdot
.546 .03551 Mdot
.546 .03563 Mdot
.546 .03575 Mdot
.546 .03578 Mdot
.546 .03592 Mdot
.546 .036 Mdot
.546 .03608 Mdot
.546 .03609 Mdot
.546 .03609 Mdot
.546 .03625 Mdot
.546 .03636 Mdot
.546 .03644 Mdot
.546 .03657 Mdot
.546 .0366 Mdot
.546 .03663 Mdot
.546 .0368 Mdot
.546 .03687 Mdot
.546 .03712 Mdot
.546 .03722 Mdot
.546 .03739 Mdot
.546 .03743 Mdot
.546 .03756 Mdot
.546 .03768 Mdot
.546 .03772 Mdot
.546 .03788 Mdot
.546 .03795 Mdot
.546 .03804 Mdot
.546 .03806 Mdot
.546 .03806 Mdot
.546 .03823 Mdot
.546 .03835 Mdot
.546 .03844 Mdot
.546 .03859 Mdot
.546 .03862 Mdot
.546 .03864 Mdot
.546 .03883 Mdot
.546 .0389 Mdot
.546 .03895 Mdot
.546 .03912 Mdot
.546 .03918 Mdot
.546 .03929 Mdot
.546 .03948 Mdot
.546 .03949 Mdot
.546 .03952 Mdot
.546 .03966 Mdot
.546 .0398 Mdot
.546 .03984 Mdot
.546 .04001 Mdot
.546 .04009 Mdot
.546 .04019 Mdot
.546 .0402 Mdot
.546 .04021 Mdot
.546 .0404 Mdot
.546 .04052 Mdot
.546 .04062 Mdot
.546 .04078 Mdot
.546 .04081 Mdot
.546 .04085 Mdot
.546 .04105 Mdot
.546 .04113 Mdot
.546 .04118 Mdot
.546 .04136 Mdot
.546 .04143 Mdot
.546 .04147 Mdot
.546 .04155 Mdot
.546 .04176 Mdot
.546 .04177 Mdot
.546 .0418 Mdot
.546 .04195 Mdot
.546 .0421 Mdot
.546 .04215 Mdot
.546 .04233 Mdot
.546 .04243 Mdot
.546 .04254 Mdot
.546 .04255 Mdot
.546 .04255 Mdot
.546 .04276 Mdot
.546 .0429 Mdot
.546 .04301 Mdot
.546 .04318 Mdot
.546 .04322 Mdot
.546 .04325 Mdot
.546 .04342 Mdot
.546 .04347 Mdot
.546 .04356 Mdot
.546 .04361 Mdot
.546 .04381 Mdot
.546 .04389 Mdot
.546 .04393 Mdot
.546 .044 Mdot
.546 .04402 Mdot
.546 .04424 Mdot
.546 .04426 Mdot
.546 .04429 Mdot
.546 .04446 Mdot
.546 .04462 Mdot
.546 .04467 Mdot
.546 .04487 Mdot
.546 .04498 Mdot
.546 .04509 Mdot
.546 .04511 Mdot
.546 .04511 Mdot
.546 .04534 Mdot
.546 .04549 Mdot
.546 .04561 Mdot
.546 .0458 Mdot
.546 .04584 Mdot
.546 .04588 Mdot
.546 .04607 Mdot
.546 .04612 Mdot
.546 .04621 Mdot
.546 .04627 Mdot
.546 .04649 Mdot
.546 .04657 Mdot
.546 .04661 Mdot
.546 .04669 Mdot
.546 .04672 Mdot
.546 .04696 Mdot
.546 .04698 Mdot
.546 .04701 Mdot
.546 .04719 Mdot
.546 .04738 Mdot
.546 .04743 Mdot
.546 .04765 Mdot
.546 .04776 Mdot
.546 .04789 Mdot
.546 .04791 Mdot
.546 .04791 Mdot
.546 .04816 Mdot
.546 .04832 Mdot
.546 .04845 Mdot
.546 .04866 Mdot
.546 .0487 Mdot
.546 .04874 Mdot
.546 .04895 Mdot
.546 .04901 Mdot
.546 .04911 Mdot
.546 .04918 Mdot
.546 .04941 Mdot
.546 .0495 Mdot
.546 .04955 Mdot
.546 .04964 Mdot
.546 .04966 Mdot
.546 .04993 Mdot
.546 .04994 Mdot
.546 .04998 Mdot
.546 .05018 Mdot
.546 .05038 Mdot
.546 .05044 Mdot
.546 .05068 Mdot
.546 .0508 Mdot
.546 .05094 Mdot
.546 .05096 Mdot
.546 .05096 Mdot
.546 .05124 Mdot
.546 .05141 Mdot
.546 .05155 Mdot
.546 .05178 Mdot
.546 .05183 Mdot
.546 .05187 Mdot
.546 .0521 Mdot
.546 .05216 Mdot
.546 .05227 Mdot
.546 .05235 Mdot
.546 .0526 Mdot
.546 .0527 Mdot
.546 .05275 Mdot
.546 .05285 Mdot
.546 .05288 Mdot
.546 .05317 Mdot
.546 .05318 Mdot
.546 .05323 Mdot
.546 .05345 Mdot
.546 .05366 Mdot
.546 .05373 Mdot
.546 .05399 Mdot
.546 .05412 Mdot
.546 .05427 Mdot
.546 .05429 Mdot
.546 .0543 Mdot
.546 .0546 Mdot
.546 .05479 Mdot
.546 .05494 Mdot
.546 .05519 Mdot
.546 .05524 Mdot
.546 .05529 Mdot
.546 .05554 Mdot
.546 .0556 Mdot
.546 .05573 Mdot
.546 .05581 Mdot
.546 .05609 Mdot
.546 .0562 Mdot
.546 .05625 Mdot
.546 .05636 Mdot
.546 .05639 Mdot
.546 .0567 Mdot
.546 .05672 Mdot
.546 .05677 Mdot
.546 .05701 Mdot
.546 .05725 Mdot
.546 .05731 Mdot
.546 .0576 Mdot
.546 .05775 Mdot
.546 .05791 Mdot
.546 .05794 Mdot
.546 .05794 Mdot
.546 .05827 Mdot
.546 .05848 Mdot
.546 .05864 Mdot
.546 .05892 Mdot
.546 .05897 Mdot
.546 .05902 Mdot
.546 .05929 Mdot
.546 .05937 Mdot
.546 .0595 Mdot
.546 .05959 Mdot
.546 .0599 Mdot
.546 .06001 Mdot
.546 .06008 Mdot
.546 .06019 Mdot
.546 .06022 Mdot
.546 .06057 Mdot
.546 .06059 Mdot
.546 .06064 Mdot
.546 .0609 Mdot
.546 .06116 Mdot
.546 .06123 Mdot
.546 .06154 Mdot
.546 .06171 Mdot
.546 .06189 Mdot
.546 .06191 Mdot
.546 .06191 Mdot
.546 .06227 Mdot
.546 .0625 Mdot
.546 .06269 Mdot
.546 .06298 Mdot
.546 .06304 Mdot
.546 .0631 Mdot
.546 .0634 Mdot
.546 .06347 Mdot
.546 .06362 Mdot
.546 .06372 Mdot
.546 .06405 Mdot
.546 .06418 Mdot
.546 .06425 Mdot
.546 .06437 Mdot
.546 .06441 Mdot
.546 .06479 Mdot
.546 .06481 Mdot
.546 .06486 Mdot
.546 .06515 Mdot
.546 .06543 Mdot
.546 .06551 Mdot
.546 .06585 Mdot
.546 .06603 Mdot
.546 .06623 Mdot
.546 .06625 Mdot
.546 .06626 Mdot
.546 .06665 Mdot
.546 .0669 Mdot
.546 .0671 Mdot
.546 .06742 Mdot
.546 .06749 Mdot
.546 .06755 Mdot
.546 .06787 Mdot
.546 .06796 Mdot
.546 .06812 Mdot
.546 .06823 Mdot
.546 .06859 Mdot
.546 .06873 Mdot
.546 .06881 Mdot
.546 .06894 Mdot
.546 .06898 Mdot
.546 .06939 Mdot
.546 .06942 Mdot
.546 .06948 Mdot
.546 .06979 Mdot
.546 .0701 Mdot
.546 .07019 Mdot
.546 .07056 Mdot
.546 .07075 Mdot
.546 .07097 Mdot
.546 .071 Mdot
.546 .071 Mdot
.546 .07142 Mdot
.546 .0717 Mdot
.546 .07192 Mdot
.546 .07227 Mdot
.546 .07234 Mdot
.546 .07241 Mdot
.546 .0726 Mdot
.546 .07277 Mdot
.546 .07286 Mdot
.546 .07304 Mdot
.546 .07315 Mdot
.546 .07355 Mdot
.546 .0737 Mdot
.546 .07378 Mdot
.546 .07393 Mdot
.546 .07398 Mdot
.546 .07442 Mdot
.546 .07445 Mdot
.546 .07451 Mdot
.546 .07485 Mdot
.546 .07519 Mdot
.546 .07529 Mdot
.546 .0757 Mdot
.546 .07591 Mdot
.546 .07614 Mdot
.546 .07617 Mdot
.546 .07618 Mdot
.546 .07664 Mdot
.546 .07694 Mdot
.546 .07718 Mdot
.546 .07757 Mdot
.546 .07765 Mdot
.546 .07772 Mdot
.546 .07793 Mdot
.546 .07811 Mdot
.546 .07821 Mdot
.546 .0784 Mdot
.546 .07852 Mdot
.546 .07896 Mdot
.546 .07913 Mdot
.546 .07922 Mdot
.546 .07938 Mdot
.546 .07943 Mdot
.546 .07992 Mdot
.546 .07995 Mdot
.546 .08002 Mdot
.546 .08039 Mdot
.546 .08076 Mdot
.546 .08086 Mdot
.546 .08131 Mdot
.546 .08153 Mdot
.546 .08179 Mdot
.546 .08183 Mdot
.546 .08183 Mdot
.546 .08234 Mdot
.546 .08267 Mdot
.546 .08293 Mdot
.546 .08335 Mdot
.546 .08344 Mdot
.546 .08352 Mdot
.546 .08374 Mdot
.546 .08394 Mdot
.546 .08405 Mdot
.546 .08426 Mdot
.546 .08439 Mdot
.546 .08487 Mdot
.546 .08505 Mdot
.546 .08515 Mdot
.546 .08532 Mdot
.546 .08538 Mdot
.546 .08591 Mdot
.546 .08595 Mdot
.546 .08602 Mdot
.546 .08643 Mdot
.546 .08683 Mdot
.546 .08695 Mdot
.546 .08743 Mdot
.546 .08768 Mdot
.546 .08796 Mdot
.546 .088 Mdot
.546 .08801 Mdot
.546 .08856 Mdot
.546 .08892 Mdot
.546 .0892 Mdot
.546 .08966 Mdot
.546 .08976 Mdot
.546 .08985 Mdot
.546 .09009 Mdot
.546 .09031 Mdot
.546 .09043 Mdot
.546 .09066 Mdot
.546 .0908 Mdot
.546 .09133 Mdot
.546 .09152 Mdot
.546 .09163 Mdot
.546 .09182 Mdot
.546 .09188 Mdot
.546 .09246 Mdot
.546 .0925 Mdot
.546 .09258 Mdot
.546 .09303 Mdot
.546 .09347 Mdot
.546 .09359 Mdot
.546 .09412 Mdot
.546 .0944 Mdot
.546 .0947 Mdot
.546 .09474 Mdot
.546 .09475 Mdot
.546 .09535 Mdot
.546 .09575 Mdot
.546 .09606 Mdot
.546 .09656 Mdot
.546 .09666 Mdot
.546 .09676 Mdot
.546 .09703 Mdot
.546 .09726 Mdot
.546 .09739 Mdot
.546 .09765 Mdot
.546 .09781 Mdot
.546 .09837 Mdot
.546 .09859 Mdot
.546 .09871 Mdot
.546 .09891 Mdot
.546 .09898 Mdot
.546 .09962 Mdot
.546 .09966 Mdot
.546 .09975 Mdot
.546 .10023 Mdot
.546 .10071 Mdot
.546 .10085 Mdot
.546 .10143 Mdot
.546 .10173 Mdot
.546 .10206 Mdot
.546 .10211 Mdot
.546 .10211 Mdot
.546 .10277 Mdot
.546 .1032 Mdot
.546 .10354 Mdot
.546 .10409 Mdot
.546 .1042 Mdot
.546 .10431 Mdot
.546 .1046 Mdot
.546 .10486 Mdot
.546 .105 Mdot
.546 .10528 Mdot
.546 .10545 Mdot
.546 .10607 Mdot
.546 .10631 Mdot
.546 .10643 Mdot
.546 .10666 Mdot
.546 .10674 Mdot
.546 .10743 Mdot
.546 .10747 Mdot
.546 .10757 Mdot
.546 .1081 Mdot
.546 .10862 Mdot
.546 .10878 Mdot
.546 .1094 Mdot
.546 .10973 Mdot
.546 .1101 Mdot
.546 .11015 Mdot
.546 .11015 Mdot
.546 .11087 Mdot
.546 .11134 Mdot
.546 .11171 Mdot
.546 .11231 Mdot
.546 .11243 Mdot
.546 .11255 Mdot
.546 .11287 Mdot
.546 .11315 Mdot
.546 .11331 Mdot
.546 .11361 Mdot
.546 .1138 Mdot
.546 .11448 Mdot
.546 .11473 Mdot
.546 .11487 Mdot
.546 .11512 Mdot
.546 .1152 Mdot
.546 .11596 Mdot
.546 .11601 Mdot
.546 .11611 Mdot
.546 .11669 Mdot
.546 .11726 Mdot
.546 .11743 Mdot
.546 .11812 Mdot
.546 .11847 Mdot
.546 .11887 Mdot
.546 .11893 Mdot
.546 .11893 Mdot
.546 .11972 Mdot
.546 .12023 Mdot
.546 .12064 Mdot
.546 .12129 Mdot
.546 .12142 Mdot
.546 .12155 Mdot
.546 .1219 Mdot
.546 .1222 Mdot
.546 .12238 Mdot
.546 .12271 Mdot
.546 .12291 Mdot
.546 .12365 Mdot
.546 .12394 Mdot
.546 .12409 Mdot
.546 .12436 Mdot
.546 .12445 Mdot
.546 .12527 Mdot
.546 .12532 Mdot
.546 .12544 Mdot
.546 .12607 Mdot
.546 .1267 Mdot
.546 .12688 Mdot
.546 .12763 Mdot
.546 .12802 Mdot
.546 .12846 Mdot
.546 .12851 Mdot
.546 .12852 Mdot
.546 .12938 Mdot
.546 .12994 Mdot
.546 .13038 Mdot
.546 .13109 Mdot
.546 .13124 Mdot
.546 .13138 Mdot
.546 .13176 Mdot
.546 .13209 Mdot
.546 .13228 Mdot
.546 .13264 Mdot
.546 .13287 Mdot
.546 .13368 Mdot
.546 .13398 Mdot
.546 .13415 Mdot
.546 .13444 Mdot
.546 .13454 Mdot
.546 .13544 Mdot
.546 .1355 Mdot
.546 .13563 Mdot
.546 .13632 Mdot
.546 .137 Mdot
.546 .1372 Mdot
.546 .13802 Mdot
.546 .13844 Mdot
.546 .13892 Mdot
.546 .13898 Mdot
.546 .13899 Mdot
.546 .13993 Mdot
.546 .14054 Mdot
.546 .14102 Mdot
.546 .1418 Mdot
.546 .14196 Mdot
.546 .14211 Mdot
.546 .14253 Mdot
.546 .14289 Mdot
.546 .1431 Mdot
.546 .14349 Mdot
.546 .14374 Mdot
.546 .14462 Mdot
.546 .14496 Mdot
.546 .14514 Mdot
.546 .14546 Mdot
.546 .14557 Mdot
.546 .14655 Mdot
.546 .14661 Mdot
.546 .14675 Mdot
.546 .14751 Mdot
.546 .14825 Mdot
.546 .14847 Mdot
.546 .14936 Mdot
.546 .14982 Mdot
.546 .15035 Mdot
.546 .15042 Mdot
.546 .15042 Mdot
.546 .15145 Mdot
.546 .15212 Mdot
.546 .15264 Mdot
.546 .15349 Mdot
.546 .15367 Mdot
.546 .15383 Mdot
.546 .15429 Mdot
.546 .15468 Mdot
.546 .15491 Mdot
.546 .15534 Mdot
.546 .15561 Mdot
.546 .15657 Mdot
.546 .15694 Mdot
.546 .15714 Mdot
.546 .15749 Mdot
.546 .1576 Mdot
.546 .15868 Mdot
.546 .15875 Mdot
.546 .1589 Mdot
.546 .15972 Mdot
.546 .16053 Mdot
.546 .16077 Mdot
.546 .16175 Mdot
.546 .16225 Mdot
.546 .16283 Mdot
.546 .1629 Mdot
.546 .16291 Mdot
.546 .16403 Mdot
.546 .16476 Mdot
.546 .16533 Mdot
.546 .16626 Mdot
.546 .16645 Mdot
.546 .16663 Mdot
.546 .16713 Mdot
.546 .16756 Mdot
.546 .16781 Mdot
.546 .16827 Mdot
.546 .16857 Mdot
.546 .16962 Mdot
.546 .17002 Mdot
.546 .17024 Mdot
.546 .17062 Mdot
.546 .17075 Mdot
.546 .17192 Mdot
.546 .172 Mdot
.546 .17217 Mdot
.546 .17306 Mdot
.546 .17395 Mdot
.546 .17421 Mdot
.546 .17528 Mdot
.546 .17583 Mdot
.546 .17645 Mdot
.546 .17653 Mdot
.546 .17654 Mdot
.546 .17777 Mdot
.546 .17856 Mdot
.546 .17919 Mdot
.546 .1802 Mdot
.546 .18041 Mdot
.546 .18061 Mdot
.546 .18116 Mdot
.546 .18162 Mdot
.546 .18189 Mdot
.546 .1824 Mdot
.546 .18272 Mdot
.546 .18387 Mdot
.546 .18431 Mdot
.546 .18455 Mdot
.546 .18497 Mdot
.546 .1851 Mdot
.546 .18639 Mdot
.546 .18647 Mdot
.546 .18665 Mdot
.546 .18763 Mdot
.546 .1886 Mdot
.546 .18888 Mdot
.546 .19005 Mdot
.546 .19065 Mdot
.546 .19133 Mdot
.546 .19142 Mdot
.546 .19143 Mdot
.546 .19277 Mdot
.546 .19363 Mdot
.546 .19432 Mdot
.546 .19543 Mdot
.546 .19566 Mdot
.546 .19587 Mdot
.546 .19647 Mdot
.546 .19698 Mdot
.546 .19727 Mdot
.546 .19783 Mdot
.546 .19818 Mdot
.546 .19944 Mdot
.546 .19992 Mdot
.546 .20017 Mdot
.546 .20063 Mdot
.546 .20078 Mdot
.546 .20218 Mdot
.546 .20227 Mdot
.546 .20247 Mdot
.546 .20354 Mdot
.546 .2046 Mdot
.546 .20491 Mdot
.546 .20618 Mdot
.546 .20684 Mdot
.546 .20758 Mdot
.546 .20768 Mdot
.546 .20769 Mdot
.546 .20915 Mdot
.546 .2101 Mdot
.546 .21084 Mdot
.546 .21205 Mdot
.546 .2123 Mdot
.546 .21254 Mdot
.546 .21319 Mdot
.546 .21375 Mdot
.546 .21407 Mdot
.546 .21468 Mdot
.546 .21506 Mdot
.546 .21643 Mdot
.546 .21695 Mdot
.546 .21723 Mdot
.546 .21773 Mdot
.546 .2179 Mdot
.546 .21943 Mdot
.546 .21952 Mdot
.546 .21974 Mdot
.546 .22091 Mdot
.546 .22207 Mdot
.546 .2224 Mdot
.546 .22379 Mdot
.546 .22451 Mdot
.546 .22532 Mdot
.546 .22543 Mdot
.546 .22544 Mdot
.546 .22704 Mdot
.546 .22807 Mdot
.546 .22889 Mdot
.546 .23021 Mdot
.546 .23048 Mdot
.546 .23074 Mdot
.546 .23145 Mdot
.546 .23206 Mdot
.546 .23241 Mdot
.546 .23307 Mdot
.546 .23349 Mdot
.546 .23499 Mdot
.546 .23556 Mdot
.546 .23586 Mdot
.546 .23641 Mdot
.546 .23659 Mdot
.546 .23826 Mdot
.546 .23837 Mdot
.546 .23861 Mdot
.546 .23988 Mdot
.546 .24114 Mdot
.546 .24151 Mdot
.546 .24303 Mdot
.546 .24381 Mdot
.546 .2447 Mdot
.546 .24482 Mdot
.546 .24483 Mdot
.546 .24657 Mdot
.546 .2477 Mdot
.546 .24859 Mdot
.546 .25003 Mdot
.546 .25033 Mdot
.546 .25061 Mdot
.546 .25139 Mdot
.546 .25205 Mdot
.546 .25243 Mdot
.546 .25316 Mdot
.546 .25362 Mdot
.546 .25525 Mdot
.546 .25588 Mdot
.546 .25621 Mdot
.546 .25681 Mdot
.546 .257 Mdot
.546 .25883 Mdot
.546 .25894 Mdot
.546 .25921 Mdot
.546 .2606 Mdot
.546 .26197 Mdot
.546 .26238 Mdot
.546 .26403 Mdot
.546 .26489 Mdot
.546 .26586 Mdot
.546 .26599 Mdot
.546 .266 Mdot
.546 .2679 Mdot
.546 .26913 Mdot
.546 .27011 Mdot
.546 .27168 Mdot
.546 .27201 Mdot
.546 .27231 Mdot
.546 .27316 Mdot
.546 .27389 Mdot
.546 .2743 Mdot
.546 .2751 Mdot
.546 .2756 Mdot
.546 .27738 Mdot
.546 .27807 Mdot
.546 .27843 Mdot
.546 .27908 Mdot
.546 .27929 Mdot
.546 .28128 Mdot
.546 .28141 Mdot
.546 .2817 Mdot
.546 .28322 Mdot
.546 .28472 Mdot
.546 .28516 Mdot
.546 .28697 Mdot
.546 .28791 Mdot
.546 .28896 Mdot
.546 .2891 Mdot
.546 .28912 Mdot
.546 .29119 Mdot
.546 .29254 Mdot
.546 .2936 Mdot
.546 .29532 Mdot
.546 .29568 Mdot
.546 .29601 Mdot
.546 .29694 Mdot
.546 .29773 Mdot
.546 .29819 Mdot
.546 .29905 Mdot
.546 .2996 Mdot
.546 .30155 Mdot
.546 .30229 Mdot
.546 .30269 Mdot
.546 .3034 Mdot
.546 .30363 Mdot
.546 .30581 Mdot
.546 .30595 Mdot
.546 .30626 Mdot
.546 .30792 Mdot
.546 .30956 Mdot
.546 .31004 Mdot
.546 .31202 Mdot
.546 .31304 Mdot
.546 .31419 Mdot
.546 .31435 Mdot
.546 .31436 Mdot
.546 .31663 Mdot
.546 .3181 Mdot
.546 .31926 Mdot
.546 .32114 Mdot
.546 .32153 Mdot
.546 .32189 Mdot
.546 .3229 Mdot
.546 .32377 Mdot
.546 .32427 Mdot
.546 .32521 Mdot
.546 .32581 Mdot
.546 .32794 Mdot
.546 .32875 Mdot
.546 .32918 Mdot
.546 .32996 Mdot
.546 .33022 Mdot
.546 .33259 Mdot
.546 .33274 Mdot
.546 .33308 Mdot
.546 .33489 Mdot
.546 .33669 Mdot
.546 .33721 Mdot
.548 .01491 Mdot
.548 .01493 Mdot
.548 .01495 Mdot
.548 .01497 Mdot
.548 .015 Mdot
.548 .01503 Mdot
.548 .01506 Mdot
.548 .01509 Mdot
.548 .01512 Mdot
.548 .01516 Mdot
.548 .01521 Mdot
.548 .01525 Mdot
.548 .01531 Mdot
.548 .01536 Mdot
.548 .01543 Mdot
.548 .01549 Mdot
.548 .01557 Mdot
.548 .01565 Mdot
.548 .01574 Mdot
.548 .01584 Mdot
.548 .01595 Mdot
.548 .01606 Mdot
.548 .01619 Mdot
.548 .01634 Mdot
.548 .01649 Mdot
.548 .01666 Mdot
.548 .01685 Mdot
.548 .01701 Mdot
.548 .01705 Mdot
.548 .01723 Mdot
.548 .01726 Mdot
.548 .01728 Mdot
.548 .01747 Mdot
.548 .0175 Mdot
.548 .01752 Mdot
.548 .01774 Mdot
.548 .01777 Mdot
.548 .01779 Mdot
.548 .01803 Mdot
.548 .01806 Mdot
.548 .01809 Mdot
.548 .01819 Mdot
.548 .01835 Mdot
.548 .01838 Mdot
.548 .01841 Mdot
.548 .01853 Mdot
.548 .01865 Mdot
.548 .01866 Mdot
.548 .0187 Mdot
.548 .01874 Mdot
.548 .01877 Mdot
.548 .01889 Mdot
.548 .01902 Mdot
.548 .01903 Mdot
.548 .01908 Mdot
.548 .01912 Mdot
.548 .01916 Mdot
.548 .01929 Mdot
.548 .01944 Mdot
.548 .01945 Mdot
.548 .0195 Mdot
.548 .01955 Mdot
.548 .01958 Mdot
.548 .01973 Mdot
.548 .01989 Mdot
.548 .0199 Mdot
.548 .01996 Mdot
.548 .01999 Mdot
.548 .02001 Mdot
.548 .02005 Mdot
.548 .02022 Mdot
.548 .02039 Mdot
.548 .0204 Mdot
.548 .02046 Mdot
.548 .0205 Mdot
.548 .02052 Mdot
.548 .02056 Mdot
.548 .02074 Mdot
.548 .02093 Mdot
.548 .02095 Mdot
.548 .02101 Mdot
.548 .02105 Mdot
.548 .02107 Mdot
.548 .02113 Mdot
.548 .02132 Mdot
.548 .02153 Mdot
.548 .02155 Mdot
.548 .02162 Mdot
.548 .02166 Mdot
.548 .02168 Mdot
.548 .02174 Mdot
.548 .02179 Mdot
.548 .02196 Mdot
.548 .02218 Mdot
.548 .0222 Mdot
.548 .02228 Mdot
.548 .02233 Mdot
.548 .02235 Mdot
.548 .02242 Mdot
.548 .02246 Mdot
.548 .02265 Mdot
.548 .0229 Mdot
.548 .02292 Mdot
.548 .02293 Mdot
.548 .023 Mdot
.548 .02306 Mdot
.548 .02309 Mdot
.548 .02316 Mdot
.548 .02321 Mdot
.548 .02341 Mdot
.548 .02369 Mdot
.548 .02371 Mdot
.548 .02372 Mdot
.548 .0238 Mdot
.548 .02386 Mdot
.548 .02389 Mdot
.548 .02397 Mdot
.548 .02402 Mdot
.548 .02425 Mdot
.548 .02455 Mdot
.548 .02457 Mdot
.548 .02459 Mdot
.548 .02462 Mdot
.548 .02467 Mdot
.548 .02474 Mdot
.548 .02477 Mdot
.548 .02485 Mdot
.548 .02492 Mdot
.548 .02516 Mdot
.548 .02549 Mdot
.548 .02552 Mdot
.548 .02553 Mdot
.548 .02557 Mdot
.548 .02563 Mdot
.548 .0257 Mdot
.548 .02574 Mdot
.548 .02583 Mdot
.548 .0259 Mdot
.548 .02607 Mdot
.548 .02617 Mdot
.548 .02628 Mdot
.548 .02634 Mdot
.548 .02653 Mdot
.548 .02655 Mdot
.548 .02657 Mdot
.548 .02661 Mdot
.548 .02667 Mdot
.548 .02675 Mdot
.548 .0268 Mdot
.548 .02681 Mdot
.548 .02689 Mdot
.548 .02697 Mdot
.548 .02716 Mdot
.548 .02727 Mdot
.548 .02739 Mdot
.548 .02746 Mdot
.548 .02766 Mdot
.548 .02769 Mdot
.548 .02771 Mdot
.548 .02775 Mdot
.548 .02782 Mdot
.548 .02791 Mdot
.548 .02796 Mdot
.548 .02797 Mdot
.548 .02797 Mdot
.548 .02806 Mdot
.548 .02815 Mdot
.548 .02835 Mdot
.548 .02847 Mdot
.548 .02861 Mdot
.548 .02868 Mdot
.548 .0289 Mdot
.548 .02894 Mdot
.548 .02896 Mdot
.548 .02901 Mdot
.548 .02908 Mdot
.548 .02917 Mdot
.548 .02923 Mdot
.548 .02925 Mdot
.548 .02925 Mdot
.548 .02934 Mdot
.548 .02944 Mdot
.548 .02966 Mdot
.548 .02979 Mdot
.548 .02994 Mdot
.548 .03002 Mdot
.548 .0301 Mdot
.548 .03027 Mdot
.548 .0303 Mdot
.548 .03032 Mdot
.548 .03038 Mdot
.548 .03046 Mdot
.548 .03056 Mdot
.548 .03062 Mdot
.548 .03064 Mdot
.548 .03064 Mdot
.548 .03085 Mdot
.548 .03093 Mdot
.548 .03109 Mdot
.548 .03124 Mdot
.548 .0314 Mdot
.548 .03149 Mdot
.548 .03158 Mdot
.548 .03176 Mdot
.548 .0318 Mdot
.548 .03182 Mdot
.548 .03188 Mdot
.548 .03197 Mdot
.548 .03208 Mdot
.548 .03215 Mdot
.548 .03217 Mdot
.548 .03217 Mdot
.548 .0324 Mdot
.548 .03249 Mdot
.548 .03267 Mdot
.548 .03282 Mdot
.548 .033 Mdot
.548 .0331 Mdot
.548 .0332 Mdot
.548 .0334 Mdot
.548 .03344 Mdot
.548 .03346 Mdot
.548 .03353 Mdot
.548 .03363 Mdot
.548 .03375 Mdot
.548 .03382 Mdot
.548 .03385 Mdot
.548 .03385 Mdot
.548 .0341 Mdot
.548 .03419 Mdot
.548 .0343 Mdot
.548 .03439 Mdot
.548 .03456 Mdot
.548 .03476 Mdot
.548 .03487 Mdot
.548 .03497 Mdot
.548 .03519 Mdot
.548 .03523 Mdot
.548 .03526 Mdot
.548 .03534 Mdot
.548 .03544 Mdot
.548 .03558 Mdot
.548 .03565 Mdot
.548 .03568 Mdot
.548 .03568 Mdot
.548 .03596 Mdot
.548 .03606 Mdot
.548 .03616 Mdot
.548 .03617 Mdot
.548 .03628 Mdot
.548 .03647 Mdot
.548 .03668 Mdot
.548 .0368 Mdot
.548 .03691 Mdot
.548 .03716 Mdot
.548 .0372 Mdot
.548 .03724 Mdot
.548 .03732 Mdot
.548 .03743 Mdot
.548 .03758 Mdot
.548 .03766 Mdot
.548 .0377 Mdot
.548 .0377 Mdot
.548 .03792 Mdot
.548 .038 Mdot
.548 .03811 Mdot
.548 .03822 Mdot
.548 .03824 Mdot
.548 .03835 Mdot
.548 .03856 Mdot
.548 .03879 Mdot
.548 .03892 Mdot
.548 .03905 Mdot
.548 .03931 Mdot
.548 .03936 Mdot
.548 .0394 Mdot
.548 .03949 Mdot
.548 .03962 Mdot
.548 .03978 Mdot
.548 .03987 Mdot
.548 .0399 Mdot
.548 .0399 Mdot
.548 .04014 Mdot
.548 .04023 Mdot
.548 .04036 Mdot
.548 .04047 Mdot
.548 .04049 Mdot
.548 .04062 Mdot
.548 .04078 Mdot
.548 .04085 Mdot
.548 .0411 Mdot
.548 .04125 Mdot
.548 .04138 Mdot
.548 .04167 Mdot
.548 .04168 Mdot
.548 .04173 Mdot
.548 .04177 Mdot
.548 .04177 Mdot
.548 .04186 Mdot
.548 .04201 Mdot
.548 .04218 Mdot
.548 .04228 Mdot
.548 .04232 Mdot
.548 .04232 Mdot
.548 .04243 Mdot
.548 .04258 Mdot
.548 .04268 Mdot
.548 .04282 Mdot
.548 .04294 Mdot
.548 .04296 Mdot
.548 .04297 Mdot
.548 .04301 Mdot
.548 .0431 Mdot
.548 .04328 Mdot
.548 .04335 Mdot
.548 .04364 Mdot
.548 .04379 Mdot
.548 .04394 Mdot
.548 .04418 Mdot
.548 .04426 Mdot
.548 .04427 Mdot
.548 .04432 Mdot
.548 .04437 Mdot
.548 .04437 Mdot
.548 .04447 Mdot
.548 .04463 Mdot
.548 .04482 Mdot
.548 .04493 Mdot
.548 .04497 Mdot
.548 .04497 Mdot
.548 .04509 Mdot
.548 .04526 Mdot
.548 .04537 Mdot
.548 .04552 Mdot
.548 .04565 Mdot
.548 .04567 Mdot
.548 .04568 Mdot
.548 .04572 Mdot
.548 .04583 Mdot
.548 .04603 Mdot
.548 .0461 Mdot
.548 .04641 Mdot
.548 .04659 Mdot
.548 .04675 Mdot
.548 .04701 Mdot
.548 .04709 Mdot
.548 .0471 Mdot
.548 .04716 Mdot
.548 .04721 Mdot
.548 .04722 Mdot
.548 .04733 Mdot
.548 .0475 Mdot
.548 .04771 Mdot
.548 .04783 Mdot
.548 .04787 Mdot
.548 .04788 Mdot
.548 .04801 Mdot
.548 .04819 Mdot
.548 .04831 Mdot
.548 .04848 Mdot
.548 .04862 Mdot
.548 .04865 Mdot
.548 .04865 Mdot
.548 .0487 Mdot
.548 .04882 Mdot
.548 .04903 Mdot
.548 .04912 Mdot
.548 .04946 Mdot
.548 .04964 Mdot
.548 .04982 Mdot
.548 .05011 Mdot
.548 .0502 Mdot
.548 .05021 Mdot
.548 .05028 Mdot
.548 .05033 Mdot
.548 .05034 Mdot
.548 .05046 Mdot
.548 .05064 Mdot
.548 .05088 Mdot
.548 .05101 Mdot
.548 .05106 Mdot
.548 .05106 Mdot
.548 .05121 Mdot
.548 .05141 Mdot
.548 .05153 Mdot
.548 .05172 Mdot
.548 .05188 Mdot
.548 .0519 Mdot
.548 .05191 Mdot
.548 .05196 Mdot
.548 .05209 Mdot
.548 .05233 Mdot
.548 .05242 Mdot
.548 .05279 Mdot
.548 .053 Mdot
.548 .05319 Mdot
.548 .05351 Mdot
.548 .05361 Mdot
.548 .05362 Mdot
.548 .05369 Mdot
.548 .05375 Mdot
.548 .05376 Mdot
.548 .05389 Mdot
.548 .05409 Mdot
.548 .05435 Mdot
.548 .05449 Mdot
.548 .05455 Mdot
.548 .05455 Mdot
.548 .05471 Mdot
.548 .05493 Mdot
.548 .05507 Mdot
.548 .05527 Mdot
.548 .05545 Mdot
.548 .05547 Mdot
.548 .05548 Mdot
.548 .05554 Mdot
.548 .05568 Mdot
.548 .05594 Mdot
.548 .05604 Mdot
.548 .05645 Mdot
.548 .05667 Mdot
.548 .05689 Mdot
.548 .05723 Mdot
.548 .05734 Mdot
.548 .05736 Mdot
.548 .05744 Mdot
.548 .0575 Mdot
.548 .05751 Mdot
.548 .05765 Mdot
.548 .05787 Mdot
.548 .05815 Mdot
.548 .05831 Mdot
.548 .05837 Mdot
.548 .05837 Mdot
.548 .05855 Mdot
.548 .05879 Mdot
.548 .05894 Mdot
.548 .05917 Mdot
.548 .05936 Mdot
.548 .05939 Mdot
.548 .05939 Mdot
.548 .05946 Mdot
.548 .05961 Mdot
.548 .0599 Mdot
.548 .06001 Mdot
.548 .06045 Mdot
.548 .0607 Mdot
.548 .06094 Mdot
.548 .06132 Mdot
.548 .06144 Mdot
.548 .06145 Mdot
.548 .06154 Mdot
.548 .06161 Mdot
.548 .06161 Mdot
.548 .06177 Mdot
.548 .06202 Mdot
.548 .06232 Mdot
.548 .0625 Mdot
.548 .06256 Mdot
.548 .06256 Mdot
.548 .06276 Mdot
.548 .06302 Mdot
.548 .06319 Mdot
.548 .06343 Mdot
.548 .06364 Mdot
.548 .06367 Mdot
.548 .06368 Mdot
.548 .06375 Mdot
.548 .06392 Mdot
.548 .06423 Mdot
.548 .06435 Mdot
.548 .06484 Mdot
.548 .06512 Mdot
.548 .06537 Mdot
.548 .06579 Mdot
.548 .06592 Mdot
.548 .06594 Mdot
.548 .06603 Mdot
.548 .06611 Mdot
.548 .06612 Mdot
.548 .06629 Mdot
.548 .06656 Mdot
.548 .06689 Mdot
.548 .06708 Mdot
.548 .06715 Mdot
.548 .06716 Mdot
.548 .06737 Mdot
.548 .06766 Mdot
.548 .06784 Mdot
.548 .06811 Mdot
.548 .06834 Mdot
.548 .06838 Mdot
.548 .06839 Mdot
.548 .06846 Mdot
.548 .06865 Mdot
.548 .06899 Mdot
.548 .06912 Mdot
.548 .06966 Mdot
.548 .06995 Mdot
.548 .07024 Mdot
.548 .07069 Mdot
.548 .07084 Mdot
.548 .07085 Mdot
.548 .07096 Mdot
.548 .07104 Mdot
.548 .07105 Mdot
.548 .07124 Mdot
.548 .07153 Mdot
.548 .0719 Mdot
.548 .07211 Mdot
.548 .07219 Mdot
.548 .07219 Mdot
.548 .07242 Mdot
.548 .07274 Mdot
.548 .07294 Mdot
.548 .07324 Mdot
.548 .07349 Mdot
.548 .07353 Mdot
.548 .07354 Mdot
.548 .07362 Mdot
.548 .07382 Mdot
.548 .0742 Mdot
.548 .07434 Mdot
.548 .07493 Mdot
.548 .07526 Mdot
.548 .07557 Mdot
.548 .07607 Mdot
.548 .07622 Mdot
.548 .07624 Mdot
.548 .07636 Mdot
.548 .07645 Mdot
.548 .07646 Mdot
.548 .07666 Mdot
.548 .07699 Mdot
.548 .07739 Mdot
.548 .07762 Mdot
.548 .07771 Mdot
.548 .07771 Mdot
.548 .07796 Mdot
.548 .07831 Mdot
.548 .07853 Mdot
.548 .07885 Mdot
.548 .07913 Mdot
.548 .07917 Mdot
.548 .07918 Mdot
.548 .07927 Mdot
.548 .0795 Mdot
.548 .07991 Mdot
.548 .08007 Mdot
.548 .08071 Mdot
.548 .08107 Mdot
.548 .08141 Mdot
.548 .08196 Mdot
.548 .08213 Mdot
.548 .08215 Mdot
.548 .08227 Mdot
.548 .08238 Mdot
.548 .08238 Mdot
.548 .08261 Mdot
.548 .08297 Mdot
.548 .08341 Mdot
.548 .08366 Mdot
.548 .08375 Mdot
.548 .08376 Mdot
.548 .08404 Mdot
.548 .08441 Mdot
.548 .08466 Mdot
.548 .08501 Mdot
.548 .08532 Mdot
.548 .08536 Mdot
.548 .08537 Mdot
.548 .08547 Mdot
.548 .08572 Mdot
.548 .08616 Mdot
.548 .08634 Mdot
.548 .08705 Mdot
.548 .08744 Mdot
.548 .08781 Mdot
.548 .08841 Mdot
.548 .0886 Mdot
.548 .08862 Mdot
.548 .08876 Mdot
.548 .08887 Mdot
.548 .08888 Mdot
.548 .08913 Mdot
.548 .08952 Mdot
.548 .09 Mdot
.548 .09028 Mdot
.548 .09038 Mdot
.548 .09038 Mdot
.548 .09069 Mdot
.548 .09111 Mdot
.548 .09137 Mdot
.548 .09176 Mdot
.548 .09209 Mdot
.548 .09214 Mdot
.548 .09216 Mdot
.548 .09227 Mdot
.548 .09253 Mdot
.548 .09302 Mdot
.548 .09322 Mdot
.548 .09399 Mdot
.548 .09442 Mdot
.548 .09483 Mdot
.548 .09549 Mdot
.548 .09569 Mdot
.548 .09572 Mdot
.548 .09587 Mdot
.548 .09599 Mdot
.548 .096 Mdot
.548 .09627 Mdot
.548 .0967 Mdot
.548 .09723 Mdot
.548 .09753 Mdot
.548 .09765 Mdot
.548 .09765 Mdot
.548 .09799 Mdot
.548 .09844 Mdot
.548 .09873 Mdot
.548 .09916 Mdot
.548 .09952 Mdot
.548 .09958 Mdot
.548 .09959 Mdot
.548 .09971 Mdot
.548 .1 Mdot
.548 .10054 Mdot
.548 .10075 Mdot
.548 .1016 Mdot
.548 .10207 Mdot
.548 .10252 Mdot
.548 .10324 Mdot
.548 .10347 Mdot
.548 .10349 Mdot
.548 .10366 Mdot
.548 .10379 Mdot
.548 .1038 Mdot
.548 .1041 Mdot
.548 .10457 Mdot
.548 .10515 Mdot
.548 .10548 Mdot
.548 .10561 Mdot
.548 .10561 Mdot
.548 .10598 Mdot
.548 .10648 Mdot
.548 .10679 Mdot
.548 .10726 Mdot
.548 .10766 Mdot
.548 .10772 Mdot
.548 .10774 Mdot
.548 .10787 Mdot
.548 .10819 Mdot
.548 .10878 Mdot
.548 .10901 Mdot
.548 .10994 Mdot
.548 .11046 Mdot
.548 .11095 Mdot
.548 .11174 Mdot
.548 .11199 Mdot
.548 .11202 Mdot
.548 .1122 Mdot
.548 .11234 Mdot
.548 .11236 Mdot
.548 .11268 Mdot
.548 .1132 Mdot
.548 .11384 Mdot
.548 .11419 Mdot
.548 .11433 Mdot
.548 .11433 Mdot
.548 .11474 Mdot
.548 .11529 Mdot
.548 .11563 Mdot
.548 .11615 Mdot
.548 .11659 Mdot
.548 .11665 Mdot
.548 .11667 Mdot
.548 .11681 Mdot
.548 .11716 Mdot
.548 .11781 Mdot
.548 .11806 Mdot
.548 .11908 Mdot
.548 .11965 Mdot
.548 .12018 Mdot
.548 .12105 Mdot
.548 .12133 Mdot
.548 .12136 Mdot
.548 .12156 Mdot
.548 .12172 Mdot
.548 .12173 Mdot
.548 .12209 Mdot
.548 .12265 Mdot
.548 .12335 Mdot
.548 .12374 Mdot
.548 .1239 Mdot
.548 .1239 Mdot
.548 .12434 Mdot
.548 .12494 Mdot
.548 .12532 Mdot
.548 .12588 Mdot
.548 .12637 Mdot
.548 .12644 Mdot
.548 .12646 Mdot
.548 .12661 Mdot
.548 .127 Mdot
.548 .12771 Mdot
.548 .12798 Mdot
.548 .1291 Mdot
.548 .12972 Mdot
.548 .13031 Mdot
.548 .13126 Mdot
.548 .13156 Mdot
.548 .13159 Mdot
.548 .13181 Mdot
.548 .13199 Mdot
.548 .132 Mdot
.548 .1324 Mdot
.548 .13301 Mdot
.548 .13378 Mdot
.548 .13421 Mdot
.548 .13438 Mdot
.548 .13438 Mdot
.548 .13487 Mdot
.548 .13552 Mdot
.548 .13594 Mdot
.548 .13656 Mdot
.548 .13708 Mdot
.548 .13716 Mdot
.548 .13718 Mdot
.548 .13736 Mdot
.548 .13778 Mdot
.548 .13856 Mdot
.548 .13886 Mdot
.548 .14009 Mdot
.548 .14077 Mdot
.548 .14141 Mdot
.548 .14245 Mdot
.548 .14278 Mdot
.548 .14281 Mdot
.548 .14305 Mdot
.548 .14325 Mdot
.548 .14326 Mdot
.548 .14369 Mdot
.548 .14437 Mdot
.548 .14521 Mdot
.548 .14568 Mdot
.548 .14586 Mdot
.548 .14587 Mdot
.548 .1464 Mdot
.548 .14712 Mdot
.548 .14758 Mdot
.548 .14825 Mdot
.548 .14883 Mdot
.548 .14892 Mdot
.548 .14894 Mdot
.548 .14913 Mdot
.548 .14959 Mdot
.548 .15044 Mdot
.548 .15078 Mdot
.548 .15212 Mdot
.548 .15287 Mdot
.548 .15357 Mdot
.548 .15471 Mdot
.548 .15507 Mdot
.548 .15511 Mdot
.548 .15538 Mdot
.548 .15559 Mdot
.548 .1556 Mdot
.548 .15607 Mdot
.548 .15682 Mdot
.548 .15774 Mdot
.548 .15826 Mdot
.548 .15845 Mdot
.548 .15846 Mdot
.548 .15904 Mdot
.548 .15983 Mdot
.548 .16033 Mdot
.548 .16107 Mdot
.548 .16171 Mdot
.548 .1618 Mdot
.548 .16183 Mdot
.548 .16203 Mdot
.548 .16254 Mdot
.548 .16347 Mdot
.548 .16384 Mdot
.548 .16531 Mdot
.548 .16613 Mdot
.548 .1669 Mdot
.548 .16815 Mdot
.548 .16855 Mdot
.548 .16859 Mdot
.548 .16888 Mdot
.548 .16911 Mdot
.548 .16913 Mdot
.548 .16965 Mdot
.548 .17046 Mdot
.548 .17147 Mdot
.548 .17204 Mdot
.548 .17225 Mdot
.548 .17226 Mdot
.548 .1729 Mdot
.548 .17376 Mdot
.548 .17431 Mdot
.548 .17512 Mdot
.548 .17582 Mdot
.548 .17592 Mdot
.548 .17595 Mdot
.548 .17618 Mdot
.548 .17673 Mdot
.548 .17775 Mdot
.548 .17815 Mdot
.548 .17977 Mdot
.548 .18066 Mdot
.548 .18151 Mdot
.548 .18289 Mdot
.548 .18332 Mdot
.548 .18336 Mdot
.548 .18368 Mdot
.548 .18393 Mdot
.548 .18395 Mdot
.548 .18452 Mdot
.548 .18541 Mdot
.548 .18652 Mdot
.548 .18714 Mdot
.548 .18738 Mdot
.548 .18738 Mdot
.548 .18808 Mdot
.548 .18903 Mdot
.548 .18963 Mdot
.548 .19052 Mdot
.548 .19128 Mdot
.548 .1914 Mdot
.548 .19143 Mdot
.548 .19168 Mdot
.548 .19229 Mdot
.548 .19341 Mdot
.548 .19384 Mdot
.548 .19561 Mdot
.548 .1966 Mdot
.548 .19752 Mdot
.548 .19903 Mdot
.548 .1995 Mdot
.548 .19955 Mdot
.548 .1999 Mdot
.548 .20018 Mdot
.548 .2002 Mdot
.548 .20082 Mdot
.548 .2018 Mdot
.548 .20301 Mdot
.548 .20369 Mdot
.548 .20395 Mdot
.548 .20396 Mdot
.548 .20473 Mdot
.548 .20576 Mdot
.548 .20643 Mdot
.548 .2074 Mdot
.548 .20823 Mdot
.548 .20836 Mdot
.548 .20839 Mdot
.548 .20866 Mdot
.548 .20933 Mdot
.548 .21056 Mdot
.548 .21104 Mdot
.548 .21298 Mdot
.548 .21406 Mdot
.548 .21507 Mdot
.548 .21672 Mdot
.548 .21724 Mdot
.548 .2173 Mdot
.548 .21768 Mdot
.548 .21798 Mdot
.548 .21801 Mdot
.548 .21869 Mdot
.548 .21976 Mdot
.548 .22109 Mdot
.548 .22183 Mdot
.548 .22212 Mdot
.548 .22213 Mdot
.548 .22297 Mdot
.548 .2241 Mdot
.548 .22483 Mdot
.548 .2259 Mdot
.548 .22681 Mdot
.548 .22695 Mdot
.548 .22699 Mdot
.548 .22728 Mdot
.548 .22802 Mdot
.548 .22936 Mdot
.548 .22989 Mdot
.548 .23201 Mdot
.548 .23319 Mdot
.548 .2343 Mdot
.548 .23612 Mdot
.548 .23668 Mdot
.548 .23674 Mdot
.548 .23716 Mdot
.548 .2375 Mdot
.548 .23752 Mdot
.548 .23827 Mdot
.548 .23944 Mdot
.548 .2409 Mdot
.548 .24172 Mdot
.548 .24203 Mdot
.548 .24204 Mdot
.548 .24296 Mdot
.548 .24421 Mdot
.548 .245 Mdot
.548 .24617 Mdot
.548 .24717 Mdot
.548 .24732 Mdot
.548 .24736 Mdot
.548 .24769 Mdot
.548 .24849 Mdot
.548 .24997 Mdot
.548 .25054 Mdot
.548 .25288 Mdot
.548 .25417 Mdot
.548 .25538 Mdot
.548 .25737 Mdot
.548 .25799 Mdot
.548 .25806 Mdot
.548 .25852 Mdot
.548 .25888 Mdot
.548 .25891 Mdot
.548 .25973 Mdot
.548 .26102 Mdot
.548 .26261 Mdot
.548 .26351 Mdot
.548 .26385 Mdot
.548 .26386 Mdot
.548 .26487 Mdot
.548 .26624 Mdot
.548 .26711 Mdot
.548 .26839 Mdot
.548 .26949 Mdot
.548 .26965 Mdot
.548 .2697 Mdot
.548 .27006 Mdot
.548 .27094 Mdot
.548 .27255 Mdot
.548 .27318 Mdot
.548 .27574 Mdot
.548 .27715 Mdot
.548 .27849 Mdot
.548 .28067 Mdot
.548 .28135 Mdot
.548 .28142 Mdot
.548 .28192 Mdot
.548 .28232 Mdot
.548 .28236 Mdot
.548 .28325 Mdot
.548 .28466 Mdot
.548 .28641 Mdot
.548 .28739 Mdot
.548 .28777 Mdot
.548 .28778 Mdot
.548 .28889 Mdot
.548 .29038 Mdot
.548 .29134 Mdot
.548 .29274 Mdot
.548 .29395 Mdot
.548 .29412 Mdot
.548 .29418 Mdot
.548 .29457 Mdot
.548 .29553 Mdot
.548 .29731 Mdot
.548 .298 Mdot
.548 .3008 Mdot
.548 .30235 Mdot
.548 .30381 Mdot
.548 .3062 Mdot
.548 .30694 Mdot
.548 .30702 Mdot
.548 .30757 Mdot
.548 .30801 Mdot
.548 .30805 Mdot
.548 .30903 Mdot
.548 .31058 Mdot
.548 .31249 Mdot
.548 .31357 Mdot
.548 .31398 Mdot
.548 .31399 Mdot
.548 .31521 Mdot
.548 .31685 Mdot
.548 .31789 Mdot
.548 .31943 Mdot
.548 .32075 Mdot
.548 .32095 Mdot
.548 .321 Mdot
.548 .32143 Mdot
.548 .32249 Mdot
.548 .32443 Mdot
.548 .32519 Mdot
.548 .32826 Mdot
.548 .32996 Mdot
.548 .33156 Mdot
.548 .33418 Mdot
.548 .335 Mdot
.548 .33508 Mdot
.548 .33569 Mdot
.548 .33617 Mdot
.548 .33621 Mdot
.548 .33728 Mdot
.55 .01748 Mdot
.55 .01775 Mdot
.55 .01803 Mdot
.55 .01806 Mdot
.55 .0181 Mdot
.55 .01836 Mdot
.55 .01839 Mdot
.55 .01844 Mdot
.55 .01873 Mdot
.55 .01876 Mdot
.55 .01881 Mdot
.55 .01913 Mdot
.55 .01916 Mdot
.55 .01922 Mdot
.55 .01957 Mdot
.55 .01961 Mdot
.55 .01967 Mdot
.55 .01978 Mdot
.55 .02006 Mdot
.55 .02006 Mdot
.55 .0201 Mdot
.55 .02017 Mdot
.55 .0202 Mdot
.55 .02028 Mdot
.55 .02059 Mdot
.55 .0206 Mdot
.55 .02063 Mdot
.55 .02071 Mdot
.55 .02075 Mdot
.55 .02084 Mdot
.55 .02118 Mdot
.55 .02119 Mdot
.55 .02123 Mdot
.55 .02131 Mdot
.55 .02136 Mdot
.55 .02145 Mdot
.55 .02182 Mdot
.55 .02183 Mdot
.55 .02188 Mdot
.55 .02197 Mdot
.55 .02202 Mdot
.55 .02213 Mdot
.55 .02253 Mdot
.55 .02255 Mdot
.55 .02259 Mdot
.55 .0227 Mdot
.55 .02275 Mdot
.55 .02287 Mdot
.55 .02332 Mdot
.55 .02333 Mdot
.55 .02338 Mdot
.55 .0235 Mdot
.55 .02355 Mdot
.55 .02368 Mdot
.55 .0239 Mdot
.55 .02418 Mdot
.55 .02419 Mdot
.55 .02425 Mdot
.55 .02436 Mdot
.55 .02438 Mdot
.55 .02443 Mdot
.55 .02444 Mdot
.55 .02458 Mdot
.55 .02482 Mdot
.55 .02496 Mdot
.55 .02512 Mdot
.55 .02514 Mdot
.55 .0252 Mdot
.55 .02533 Mdot
.55 .02534 Mdot
.55 .0254 Mdot
.55 .02541 Mdot
.55 .02557 Mdot
.55 .02564 Mdot
.55 .02583 Mdot
.55 .02599 Mdot
.55 .02616 Mdot
.55 .02618 Mdot
.55 .02625 Mdot
.55 .02639 Mdot
.55 .02641 Mdot
.55 .02647 Mdot
.55 .02648 Mdot
.55 .02665 Mdot
.55 .02674 Mdot
.55 .02694 Mdot
.55 .02712 Mdot
.55 .02731 Mdot
.55 .02733 Mdot
.55 .02733 Mdot
.55 .0274 Mdot
.55 .02755 Mdot
.55 .02758 Mdot
.55 .02758 Mdot
.55 .02764 Mdot
.55 .02766 Mdot
.55 .02785 Mdot
.55 .02794 Mdot
.55 .02816 Mdot
.55 .02836 Mdot
.55 .02845 Mdot
.55 .02857 Mdot
.55 .02859 Mdot
.55 .02859 Mdot
.55 .02867 Mdot
.55 .02884 Mdot
.55 .02886 Mdot
.55 .02887 Mdot
.55 .02894 Mdot
.55 .02895 Mdot
.55 .02916 Mdot
.55 .02926 Mdot
.55 .02951 Mdot
.55 .02972 Mdot
.55 .02982 Mdot
.55 .02995 Mdot
.55 .02997 Mdot
.55 .02998 Mdot
.55 .03007 Mdot
.55 .03025 Mdot
.55 .03028 Mdot
.55 .03028 Mdot
.55 .03036 Mdot
.55 .03037 Mdot
.55 .03061 Mdot
.55 .03072 Mdot
.55 .03098 Mdot
.55 .03117 Mdot
.55 .03122 Mdot
.55 .03133 Mdot
.55 .03148 Mdot
.55 .0315 Mdot
.55 .0315 Mdot
.55 .0316 Mdot
.55 .0318 Mdot
.55 .03183 Mdot
.55 .03184 Mdot
.55 .03192 Mdot
.55 .03194 Mdot
.55 .03219 Mdot
.55 .03232 Mdot
.55 .03261 Mdot
.55 .03281 Mdot
.55 .03287 Mdot
.55 .03297 Mdot
.55 .033 Mdot
.55 .03315 Mdot
.55 .03318 Mdot
.55 .03318 Mdot
.55 .03329 Mdot
.55 .03351 Mdot
.55 .03354 Mdot
.55 .03355 Mdot
.55 .03364 Mdot
.55 .03366 Mdot
.55 .03394 Mdot
.55 .03408 Mdot
.55 .0344 Mdot
.55 .03462 Mdot
.55 .03469 Mdot
.55 .0348 Mdot
.55 .03482 Mdot
.55 .035 Mdot
.55 .03503 Mdot
.55 .03503 Mdot
.55 .03515 Mdot
.55 .03539 Mdot
.55 .03543 Mdot
.55 .03543 Mdot
.55 .03554 Mdot
.55 .03556 Mdot
.55 .03586 Mdot
.55 .03601 Mdot
.55 .03637 Mdot
.55 .03661 Mdot
.55 .03668 Mdot
.55 .03681 Mdot
.55 .03682 Mdot
.55 .03684 Mdot
.55 .03691 Mdot
.55 .03703 Mdot
.55 .03706 Mdot
.55 .03706 Mdot
.55 .03719 Mdot
.55 .03746 Mdot
.55 .0375 Mdot
.55 .0375 Mdot
.55 .03762 Mdot
.55 .03764 Mdot
.55 .03791 Mdot
.55 .03794 Mdot
.55 .03798 Mdot
.55 .03814 Mdot
.55 .03854 Mdot
.55 .0388 Mdot
.55 .03888 Mdot
.55 .03902 Mdot
.55 .03903 Mdot
.55 .03905 Mdot
.55 .03913 Mdot
.55 .03926 Mdot
.55 .03929 Mdot
.55 .0393 Mdot
.55 .03944 Mdot
.55 .03973 Mdot
.55 .03978 Mdot
.55 .03978 Mdot
.55 .03991 Mdot
.55 .03993 Mdot
.55 .03994 Mdot
.55 .04022 Mdot
.55 .04026 Mdot
.55 .04027 Mdot
.55 .04031 Mdot
.55 .04036 Mdot
.55 .04049 Mdot
.55 .04051 Mdot
.55 .04092 Mdot
.55 .04121 Mdot
.55 .0413 Mdot
.55 .04145 Mdot
.55 .04146 Mdot
.55 .04148 Mdot
.55 .04149 Mdot
.55 .04157 Mdot
.55 .04171 Mdot
.55 .04175 Mdot
.55 .04175 Mdot
.55 .04191 Mdot
.55 .04224 Mdot
.55 .04228 Mdot
.55 .04229 Mdot
.55 .04243 Mdot
.55 .04245 Mdot
.55 .04247 Mdot
.55 .04278 Mdot
.55 .04281 Mdot
.55 .04282 Mdot
.55 .04287 Mdot
.55 .04292 Mdot
.55 .04306 Mdot
.55 .04308 Mdot
.55 .04339 Mdot
.55 .04354 Mdot
.55 .04386 Mdot
.55 .04387 Mdot
.55 .04395 Mdot
.55 .04395 Mdot
.55 .04412 Mdot
.55 .04413 Mdot
.55 .04415 Mdot
.55 .04416 Mdot
.55 .04417 Mdot
.55 .04425 Mdot
.55 .04441 Mdot
.55 .04445 Mdot
.55 .04446 Mdot
.55 .04463 Mdot
.55 .04499 Mdot
.55 .04504 Mdot
.55 .04505 Mdot
.55 .0452 Mdot
.55 .04523 Mdot
.55 .04524 Mdot
.55 .04558 Mdot
.55 .04562 Mdot
.55 .04563 Mdot
.55 .04568 Mdot
.55 .04574 Mdot
.55 .0459 Mdot
.55 .04592 Mdot
.55 .046 Mdot
.55 .04625 Mdot
.55 .04642 Mdot
.55 .04677 Mdot
.55 .04678 Mdot
.55 .04687 Mdot
.55 .04688 Mdot
.55 .04706 Mdot
.55 .04707 Mdot
.55 .04709 Mdot
.55 .0471 Mdot
.55 .04711 Mdot
.55 .04721 Mdot
.55 .04738 Mdot
.55 .04742 Mdot
.55 .04743 Mdot
.55 .04762 Mdot
.55 .04802 Mdot
.55 .04807 Mdot
.55 .04808 Mdot
.55 .04825 Mdot
.55 .04828 Mdot
.55 .04829 Mdot
.55 .04867 Mdot
.55 .04872 Mdot
.55 .04872 Mdot
.55 .04878 Mdot
.55 .04885 Mdot
.55 .04902 Mdot
.55 .04904 Mdot
.55 .04913 Mdot
.55 .04941 Mdot
.55 .04959 Mdot
.55 .04998 Mdot
.55 .04999 Mdot
.55 .05009 Mdot
.55 .05009 Mdot
.55 .0503 Mdot
.55 .05031 Mdot
.55 .05033 Mdot
.55 .05034 Mdot
.55 .05035 Mdot
.55 .05045 Mdot
.55 .05065 Mdot
.55 .0507 Mdot
.55 .0507 Mdot
.55 .05091 Mdot
.55 .05135 Mdot
.55 .05141 Mdot
.55 .05142 Mdot
.55 .0516 Mdot
.55 .05164 Mdot
.55 .05165 Mdot
.55 .05206 Mdot
.55 .05212 Mdot
.55 .05212 Mdot
.55 .05218 Mdot
.55 .05226 Mdot
.55 .05245 Mdot
.55 .05247 Mdot
.55 .05257 Mdot
.55 .05288 Mdot
.55 .05308 Mdot
.55 .05351 Mdot
.55 .05352 Mdot
.55 .05363 Mdot
.55 .05363 Mdot
.55 .05386 Mdot
.55 .05387 Mdot
.55 .05389 Mdot
.55 .0539 Mdot
.55 .05392 Mdot
.55 .05403 Mdot
.55 .05424 Mdot
.55 .05429 Mdot
.55 .0543 Mdot
.55 .05453 Mdot
.55 .05501 Mdot
.55 .05508 Mdot
.55 .05509 Mdot
.55 .05529 Mdot
.55 .05533 Mdot
.55 .05534 Mdot
.55 .0558 Mdot
.55 .05586 Mdot
.55 .05586 Mdot
.55 .05593 Mdot
.55 .05601 Mdot
.55 .05622 Mdot
.55 .05625 Mdot
.55 .05636 Mdot
.55 .05669 Mdot
.55 .05691 Mdot
.55 .05739 Mdot
.55 .0574 Mdot
.55 .05752 Mdot
.55 .05752 Mdot
.55 .05777 Mdot
.55 .05778 Mdot
.55 .05781 Mdot
.55 .05782 Mdot
.55 .05784 Mdot
.55 .05796 Mdot
.55 .05819 Mdot
.55 .05825 Mdot
.55 .05826 Mdot
.55 .05851 Mdot
.55 .05904 Mdot
.55 .05911 Mdot
.55 .05912 Mdot
.55 .05935 Mdot
.55 .05939 Mdot
.55 .05941 Mdot
.55 .05991 Mdot
.55 .05997 Mdot
.55 .05998 Mdot
.55 .06005 Mdot
.55 .06014 Mdot
.55 .06037 Mdot
.55 .0604 Mdot
.55 .06052 Mdot
.55 .06089 Mdot
.55 .06113 Mdot
.55 .06165 Mdot
.55 .06166 Mdot
.55 .0618 Mdot
.55 .0618 Mdot
.55 .06208 Mdot
.55 .06209 Mdot
.55 .06212 Mdot
.55 .06213 Mdot
.55 .06215 Mdot
.55 .06228 Mdot
.55 .06254 Mdot
.55 .06261 Mdot
.55 .06262 Mdot
.55 .06289 Mdot
.55 .06347 Mdot
.55 .06355 Mdot
.55 .06356 Mdot
.55 .06381 Mdot
.55 .06386 Mdot
.55 .06388 Mdot
.55 .06443 Mdot
.55 .0645 Mdot
.55 .06451 Mdot
.55 .06458 Mdot
.55 .06469 Mdot
.55 .06494 Mdot
.55 .06497 Mdot
.55 .0651 Mdot
.55 .06551 Mdot
.55 .06578 Mdot
.55 .06635 Mdot
.55 .06636 Mdot
.55 .06651 Mdot
.55 .06651 Mdot
.55 .06681 Mdot
.55 .06686 Mdot
.55 .06687 Mdot
.55 .06689 Mdot
.55 .06704 Mdot
.55 .06732 Mdot
.55 .06739 Mdot
.55 .06741 Mdot
.55 .06771 Mdot
.55 .06835 Mdot
.55 .06844 Mdot
.55 .06845 Mdot
.55 .06872 Mdot
.55 .06877 Mdot
.55 .06879 Mdot
.55 .0694 Mdot
.55 .06947 Mdot
.55 .06948 Mdot
.55 .06957 Mdot
.55 .06968 Mdot
.55 .06996 Mdot
.55 .07 Mdot
.55 .07014 Mdot
.55 .07059 Mdot
.55 .07088 Mdot
.55 .07151 Mdot
.55 .07152 Mdot
.55 .07169 Mdot
.55 .07169 Mdot
.55 .07202 Mdot
.55 .07207 Mdot
.55 .07209 Mdot
.55 .07211 Mdot
.55 .07227 Mdot
.55 .07258 Mdot
.55 .07266 Mdot
.55 .07268 Mdot
.55 .07301 Mdot
.55 .07371 Mdot
.55 .07381 Mdot
.55 .07382 Mdot
.55 .07412 Mdot
.55 .07418 Mdot
.55 .0742 Mdot
.55 .07487 Mdot
.55 .07495 Mdot
.55 .07496 Mdot
.55 .07506 Mdot
.55 .07518 Mdot
.55 .07548 Mdot
.55 .07553 Mdot
.55 .07568 Mdot
.55 .07617 Mdot
.55 .0765 Mdot
.55 .07719 Mdot
.55 .07721 Mdot
.55 .07739 Mdot
.55 .07739 Mdot
.55 .07775 Mdot
.55 .07781 Mdot
.55 .07783 Mdot
.55 .07785 Mdot
.55 .07803 Mdot
.55 .07837 Mdot
.55 .07846 Mdot
.55 .07847 Mdot
.55 .07884 Mdot
.55 .07961 Mdot
.55 .07972 Mdot
.55 .07973 Mdot
.55 .08007 Mdot
.55 .08012 Mdot
.55 .08015 Mdot
.55 .08088 Mdot
.55 .08097 Mdot
.55 .08099 Mdot
.55 .08109 Mdot
.55 .08123 Mdot
.55 .08156 Mdot
.55 .08161 Mdot
.55 .08178 Mdot
.55 .08232 Mdot
.55 .08268 Mdot
.55 .08344 Mdot
.55 .08345 Mdot
.55 .08365 Mdot
.55 .08366 Mdot
.55 .08406 Mdot
.55 .08412 Mdot
.55 .08414 Mdot
.55 .08417 Mdot
.55 .08436 Mdot
.55 .08474 Mdot
.55 .08483 Mdot
.55 .08485 Mdot
.55 .08525 Mdot
.55 .0861 Mdot
.55 .08622 Mdot
.55 .08624 Mdot
.55 .0866 Mdot
.55 .08666 Mdot
.55 .08669 Mdot
.55 .0875 Mdot
.55 .0876 Mdot
.55 .08761 Mdot
.55 .08773 Mdot
.55 .08788 Mdot
.55 .08824 Mdot
.55 .0883 Mdot
.55 .08849 Mdot
.55 .08908 Mdot
.55 .08947 Mdot
.55 .09031 Mdot
.55 .09033 Mdot
.55 .09055 Mdot
.55 .09055 Mdot
.55 .09099 Mdot
.55 .09106 Mdot
.55 .09108 Mdot
.55 .09111 Mdot
.55 .09133 Mdot
.55 .09174 Mdot
.55 .09184 Mdot
.55 .09186 Mdot
.55 .09231 Mdot
.55 .09324 Mdot
.55 .09337 Mdot
.55 .09339 Mdot
.55 .09379 Mdot
.55 .09386 Mdot
.55 .09389 Mdot
.55 .09478 Mdot
.55 .09489 Mdot
.55 .0949 Mdot
.55 .09503 Mdot
.55 .09519 Mdot
.55 .0956 Mdot
.55 .09566 Mdot
.55 .09587 Mdot
.55 .09652 Mdot
.55 .09695 Mdot
.55 .09787 Mdot
.55 .09789 Mdot
.55 .09813 Mdot
.55 .09814 Mdot
.55 .09862 Mdot
.55 .09869 Mdot
.55 .09872 Mdot
.55 .09875 Mdot
.55 .09899 Mdot
.55 .09944 Mdot
.55 .09956 Mdot
.55 .09958 Mdot
.55 .10007 Mdot
.55 .10109 Mdot
.55 .10124 Mdot
.55 .10126 Mdot
.55 .1017 Mdot
.55 .10177 Mdot
.55 .10181 Mdot
.55 .10278 Mdot
.55 .1029 Mdot
.55 .10292 Mdot
.55 .10306 Mdot
.55 .10324 Mdot
.55 .10369 Mdot
.55 .10375 Mdot
.55 .10398 Mdot
.55 .1047 Mdot
.55 .10517 Mdot
.55 .10618 Mdot
.55 .10621 Mdot
.55 .10647 Mdot
.55 .10648 Mdot
.55 .10701 Mdot
.55 .10709 Mdot
.55 .10712 Mdot
.55 .10715 Mdot
.55 .10741 Mdot
.55 .10791 Mdot
.55 .10804 Mdot
.55 .10806 Mdot
.55 .1086 Mdot
.55 .10973 Mdot
.55 .10989 Mdot
.55 .10991 Mdot
.55 .11039 Mdot
.55 .11048 Mdot
.55 .11052 Mdot
.55 .11159 Mdot
.55 .11172 Mdot
.55 .11174 Mdot
.55 .1119 Mdot
.55 .11209 Mdot
.55 .11258 Mdot
.55 .11265 Mdot
.55 .11291 Mdot
.55 .11369 Mdot
.55 .11422 Mdot
.55 .11533 Mdot
.55 .11536 Mdot
.55 .11565 Mdot
.55 .11565 Mdot
.55 .11624 Mdot
.55 .11633 Mdot
.55 .11636 Mdot
.55 .1164 Mdot
.55 .11668 Mdot
.55 .11723 Mdot
.55 .11737 Mdot
.55 .1174 Mdot
.55 .11745 Mdot
.55 .11799 Mdot
.55 .11923 Mdot
.55 .11941 Mdot
.55 .11943 Mdot
.55 .11996 Mdot
.55 .12005 Mdot
.55 .1201 Mdot
.55 .12128 Mdot
.55 .12142 Mdot
.55 .12144 Mdot
.55 .12161 Mdot
.55 .12183 Mdot
.55 .12237 Mdot
.55 .12245 Mdot
.55 .12273 Mdot
.55 .12359 Mdot
.55 .12417 Mdot
.55 .12539 Mdot
.55 .12542 Mdot
.55 .12574 Mdot
.55 .12575 Mdot
.55 .12639 Mdot
.55 .12649 Mdot
.55 .12652 Mdot
.55 .12657 Mdot
.55 .12688 Mdot
.55 .12748 Mdot
.55 .12764 Mdot
.55 .12766 Mdot
.55 .12773 Mdot
.55 .12832 Mdot
.55 .12968 Mdot
.55 .12988 Mdot
.55 .1299 Mdot
.55 .13049 Mdot
.55 .13059 Mdot
.55 .13064 Mdot
.55 .13193 Mdot
.55 .13209 Mdot
.55 .13212 Mdot
.55 .1323 Mdot
.55 .13254 Mdot
.55 .13313 Mdot
.55 .13322 Mdot
.55 .13353 Mdot
.55 .13448 Mdot
.55 .13511 Mdot
.55 .13646 Mdot
.55 .13649 Mdot
.55 .13684 Mdot
.55 .13685 Mdot
.55 .13756 Mdot
.55 .13767 Mdot
.55 .1377 Mdot
.55 .13775 Mdot
.55 .1381 Mdot
.55 .13876 Mdot
.55 .13893 Mdot
.55 .13896 Mdot
.55 .13903 Mdot
.55 .13968 Mdot
.55 .14118 Mdot
.55 .14139 Mdot
.55 .14142 Mdot
.55 .14206 Mdot
.55 .14217 Mdot
.55 .14223 Mdot
.55 .14365 Mdot
.55 .14383 Mdot
.55 .14386 Mdot
.55 .14406 Mdot
.55 .14433 Mdot
.55 .14498 Mdot
.55 .14507 Mdot
.55 .14541 Mdot
.55 .14646 Mdot
.55 .14715 Mdot
.55 .14863 Mdot
.55 .14867 Mdot
.55 .14905 Mdot
.55 .14907 Mdot
.55 .14984 Mdot
.55 .14996 Mdot
.55 .15 Mdot
.55 .15006 Mdot
.55 .15044 Mdot
.55 .15117 Mdot
.55 .15135 Mdot
.55 .15138 Mdot
.55 .15146 Mdot
.55 .15218 Mdot
.55 .15382 Mdot
.55 .15406 Mdot
.55 .15409 Mdot
.55 .1548 Mdot
.55 .15492 Mdot
.55 .15498 Mdot
.55 .15655 Mdot
.55 .15674 Mdot
.55 .15677 Mdot
.55 .157 Mdot
.55 .15729 Mdot
.55 .158 Mdot
.55 .15811 Mdot
.55 .15848 Mdot
.55 .15963 Mdot
.55 .1604 Mdot
.55 .16203 Mdot
.55 .16206 Mdot
.55 .16249 Mdot
.55 .1625 Mdot
.55 .16335 Mdot
.55 .16349 Mdot
.55 .16353 Mdot
.55 .16359 Mdot
.55 .16401 Mdot
.55 .16481 Mdot
.55 .16502 Mdot
.55 .16505 Mdot
.55 .16514 Mdot
.55 .16592 Mdot
.55 .16773 Mdot
.55 .16799 Mdot
.55 .16803 Mdot
.55 .16881 Mdot
.55 .16894 Mdot
.55 .16901 Mdot
.55 .17073 Mdot
.55 .17095 Mdot
.55 .17098 Mdot
.55 .17123 Mdot
.55 .17154 Mdot
.55 .17233 Mdot
.55 .17245 Mdot
.55 .17285 Mdot
.55 .17412 Mdot
.55 .17496 Mdot
.55 .17676 Mdot
.55 .1768 Mdot
.55 .17726 Mdot
.55 .17728 Mdot
.55 .17822 Mdot
.55 .17837 Mdot
.55 .17841 Mdot
.55 .17848 Mdot
.55 .17894 Mdot
.55 .17982 Mdot
.55 .18005 Mdot
.55 .18009 Mdot
.55 .18018 Mdot
.55 .18104 Mdot
.55 .18304 Mdot
.55 .18332 Mdot
.55 .18336 Mdot
.55 .18422 Mdot
.55 .18436 Mdot
.55 .18444 Mdot
.55 .18633 Mdot
.55 .18657 Mdot
.55 .1866 Mdot
.55 .18688 Mdot
.55 .18723 Mdot
.55 .18809 Mdot
.55 .18822 Mdot
.55 .18867 Mdot
.55 .19006 Mdot
.55 .19099 Mdot
.55 .19296 Mdot
.55 .19301 Mdot
.55 .19352 Mdot
.55 .19354 Mdot
.55 .19457 Mdot
.55 .19473 Mdot
.55 .19478 Mdot
.55 .19485 Mdot
.55 .19536 Mdot
.55 .19633 Mdot
.55 .19658 Mdot
.55 .19662 Mdot
.55 .19672 Mdot
.55 .19767 Mdot
.55 .19987 Mdot
.55 .20018 Mdot
.55 .20022 Mdot
.55 .20117 Mdot
.55 .20133 Mdot
.55 .20141 Mdot
.55 .20349 Mdot
.55 .20375 Mdot
.55 .20379 Mdot
.55 .20409 Mdot
.55 .20448 Mdot
.55 .20543 Mdot
.55 .20557 Mdot
.55 .20606 Mdot
.55 .2076 Mdot
.55 .20862 Mdot
.55 .21078 Mdot
.55 .21084 Mdot
.55 .2114 Mdot
.55 .21142 Mdot
.55 .21255 Mdot
.55 .21273 Mdot
.55 .21278 Mdot
.55 .21287 Mdot
.55 .21342 Mdot
.55 .21449 Mdot
.55 .21477 Mdot
.55 .21481 Mdot
.55 .21492 Mdot
.55 .21597 Mdot
.55 .21838 Mdot
.55 .21873 Mdot
.55 .21877 Mdot
.55 .21981 Mdot
.55 .21999 Mdot
.55 .22008 Mdot
.55 .22237 Mdot
.55 .22266 Mdot
.55 .2227 Mdot
.55 .22303 Mdot
.55 .22346 Mdot
.55 .2245 Mdot
.55 .22466 Mdot
.55 .2252 Mdot
.55 .22688 Mdot
.55 .22801 Mdot
.55 .23039 Mdot
.55 .23045 Mdot
.55 .23107 Mdot
.55 .23109 Mdot
.55 .23233 Mdot
.55 .23253 Mdot
.55 .23259 Mdot
.55 .23268 Mdot
.55 .2333 Mdot
.55 .23447 Mdot
.55 .23477 Mdot
.55 .23482 Mdot
.55 .23495 Mdot
.55 .2361 Mdot
.55 .23875 Mdot
.55 .23913 Mdot
.55 .23918 Mdot
.55 .24032 Mdot
.55 .24052 Mdot
.55 .24061 Mdot
.55 .24314 Mdot
.55 .24345 Mdot
.55 .2435 Mdot
.55 .24386 Mdot
.55 .24433 Mdot
.55 .24548 Mdot
.55 .24565 Mdot
.55 .24625 Mdot
.55 .2481 Mdot
.55 .24934 Mdot
.55 .25196 Mdot
.55 .25202 Mdot
.55 .2527 Mdot
.55 .25273 Mdot
.55 .2541 Mdot
.55 .25432 Mdot
.55 .25438 Mdot
.55 .25448 Mdot
.55 .25515 Mdot
.55 .25645 Mdot
.55 .25678 Mdot
.55 .25683 Mdot
.55 .25697 Mdot
.55 .25823 Mdot
.55 .26115 Mdot
.55 .26157 Mdot
.55 .26162 Mdot
.55 .26288 Mdot
.55 .2631 Mdot
.55 .2632 Mdot
.55 .26598 Mdot
.55 .26633 Mdot
.55 .26638 Mdot
.55 .26678 Mdot
.55 .26729 Mdot
.55 .26856 Mdot
.55 .26874 Mdot
.55 .2694 Mdot
.55 .27144 Mdot
.55 .2728 Mdot
.55 .27568 Mdot
.55 .27575 Mdot
.55 .2765 Mdot
.55 .27653 Mdot
.55 .27803 Mdot
.55 .27828 Mdot
.55 .27835 Mdot
.55 .27846 Mdot
.55 .2792 Mdot
.55 .28062 Mdot
.55 .28098 Mdot
.55 .28105 Mdot
.55 .28119 Mdot
.55 .28259 Mdot
.55 .2858 Mdot
.55 .28626 Mdot
.55 .28631 Mdot
.55 .2877 Mdot
.55 .28794 Mdot
.55 .28805 Mdot
.55 .29111 Mdot
.55 .29149 Mdot
.55 .29154 Mdot
.55 .29199 Mdot
.55 .29255 Mdot
.55 .29394 Mdot
.55 .29415 Mdot
.55 .29487 Mdot
.55 .29711 Mdot
.55 .29861 Mdot
.55 .30178 Mdot
.55 .30186 Mdot
.55 .30268 Mdot
.55 .30271 Mdot
.55 .30437 Mdot
.55 .30463 Mdot
.55 .30471 Mdot
.55 .30483 Mdot
.55 .30565 Mdot
.55 .30721 Mdot
.55 .30761 Mdot
.55 .30768 Mdot
.55 .30784 Mdot
.55 .30937 Mdot
.55 .31291 Mdot
.55 .31341 Mdot
.55 .31347 Mdot
.55 .315 Mdot
.55 .31526 Mdot
.55 .31539 Mdot
.55 .31874 Mdot
.55 .31917 Mdot
.55 .31923 Mdot
.55 .31971 Mdot
.55 .32033 Mdot
.55 .32186 Mdot
.55 .32209 Mdot
.55 .32288 Mdot
.55 .32535 Mdot
.55 .327 Mdot
.55 .33049 Mdot
.55 .33057 Mdot
.55 .33148 Mdot
.55 .33151 Mdot
.55 .33333 Mdot
.55 .33362 Mdot
.55 .33371 Mdot
.55 .33384 Mdot
.55 .33474 Mdot
.55 .33646 Mdot
.55 .3369 Mdot
.55 .33697 Mdot
.55 .33715 Mdot
.55 .33884 Mdot
.552 .01672 Mdot
.552 .01693 Mdot
.552 .01716 Mdot
.552 .01741 Mdot
.552 .01769 Mdot
.552 .018 Mdot
.552 .01827 Mdot
.552 .01834 Mdot
.552 .01864 Mdot
.552 .01872 Mdot
.552 .01905 Mdot
.552 .01914 Mdot
.552 .0195 Mdot
.552 .01959 Mdot
.552 .02 Mdot
.552 .0201 Mdot
.552 .02028 Mdot
.552 .02046 Mdot
.552 .02055 Mdot
.552 .02066 Mdot
.552 .02086 Mdot
.552 .02106 Mdot
.552 .02116 Mdot
.552 .02128 Mdot
.552 .0215 Mdot
.552 .02172 Mdot
.552 .02183 Mdot
.552 .02196 Mdot
.552 .02206 Mdot
.552 .0222 Mdot
.552 .02245 Mdot
.552 .02257 Mdot
.552 .02272 Mdot
.552 .02283 Mdot
.552 .0229 Mdot
.552 .02296 Mdot
.552 .02298 Mdot
.552 .02325 Mdot
.552 .02339 Mdot
.552 .02355 Mdot
.552 .02367 Mdot
.552 .02376 Mdot
.552 .02381 Mdot
.552 .02384 Mdot
.552 .02414 Mdot
.552 .02429 Mdot
.552 .02447 Mdot
.552 .0246 Mdot
.552 .0247 Mdot
.552 .02476 Mdot
.552 .02479 Mdot
.552 .02512 Mdot
.552 .02528 Mdot
.552 .02548 Mdot
.552 .02556 Mdot
.552 .02563 Mdot
.552 .02573 Mdot
.552 .0258 Mdot
.552 .02583 Mdot
.552 .02584 Mdot
.552 .0262 Mdot
.552 .02638 Mdot
.552 .02658 Mdot
.552 .0266 Mdot
.552 .02668 Mdot
.552 .02677 Mdot
.552 .02688 Mdot
.552 .02696 Mdot
.552 .02698 Mdot
.552 .02699 Mdot
.552 .0274 Mdot
.552 .0276 Mdot
.552 .02781 Mdot
.552 .02784 Mdot
.552 .02793 Mdot
.552 .02802 Mdot
.552 .02815 Mdot
.552 .02823 Mdot
.552 .02826 Mdot
.552 .02827 Mdot
.552 .02871 Mdot
.552 .02894 Mdot
.552 .02917 Mdot
.552 .0292 Mdot
.552 .02922 Mdot
.552 .0293 Mdot
.552 .0294 Mdot
.552 .02954 Mdot
.552 .02963 Mdot
.552 .02967 Mdot
.552 .02968 Mdot
.552 .02985 Mdot
.552 .03017 Mdot
.552 .03042 Mdot
.552 .03068 Mdot
.552 .03073 Mdot
.552 .03082 Mdot
.552 .03093 Mdot
.552 .03108 Mdot
.552 .03119 Mdot
.552 .03119 Mdot
.552 .03123 Mdot
.552 .03124 Mdot
.552 .03142 Mdot
.552 .0316 Mdot
.552 .03178 Mdot
.552 .03187 Mdot
.552 .03205 Mdot
.552 .03227 Mdot
.552 .03234 Mdot
.552 .03239 Mdot
.552 .03249 Mdot
.552 .03262 Mdot
.552 .03279 Mdot
.552 .0329 Mdot
.552 .0329 Mdot
.552 .03294 Mdot
.552 .03295 Mdot
.552 .03316 Mdot
.552 .03335 Mdot
.552 .03355 Mdot
.552 .03365 Mdot
.552 .03385 Mdot
.552 .0341 Mdot
.552 .03417 Mdot
.552 .03419 Mdot
.552 .03423 Mdot
.552 .03434 Mdot
.552 .03448 Mdot
.552 .03458 Mdot
.552 .03467 Mdot
.552 .03479 Mdot
.552 .03479 Mdot
.552 .03484 Mdot
.552 .03485 Mdot
.552 .03502 Mdot
.552 .03508 Mdot
.552 .03529 Mdot
.552 .03551 Mdot
.552 .03562 Mdot
.552 .03584 Mdot
.552 .03611 Mdot
.552 .0362 Mdot
.552 .03622 Mdot
.552 .03626 Mdot
.552 .03638 Mdot
.552 .03653 Mdot
.552 .0366 Mdot
.552 .03664 Mdot
.552 .03674 Mdot
.552 .03688 Mdot
.552 .03688 Mdot
.552 .03693 Mdot
.552 .03693 Mdot
.552 .03695 Mdot
.552 .03714 Mdot
.552 .0372 Mdot
.552 .03743 Mdot
.552 .03767 Mdot
.552 .03769 Mdot
.552 .0378 Mdot
.552 .03804 Mdot
.552 .03829 Mdot
.552 .03834 Mdot
.552 .03843 Mdot
.552 .03846 Mdot
.552 .0385 Mdot
.552 .03864 Mdot
.552 .0388 Mdot
.552 .03888 Mdot
.552 .03892 Mdot
.552 .03903 Mdot
.552 .03918 Mdot
.552 .03918 Mdot
.552 .03924 Mdot
.552 .03924 Mdot
.552 .03926 Mdot
.552 .03947 Mdot
.552 .03953 Mdot
.552 .03979 Mdot
.552 .03991 Mdot
.552 .04006 Mdot
.552 .04008 Mdot
.552 .0402 Mdot
.552 .04047 Mdot
.552 .04075 Mdot
.552 .04079 Mdot
.552 .0409 Mdot
.552 .04093 Mdot
.552 .04098 Mdot
.552 .04113 Mdot
.552 .04131 Mdot
.552 .04139 Mdot
.552 .04144 Mdot
.552 .04156 Mdot
.552 .04173 Mdot
.552 .04173 Mdot
.552 .04179 Mdot
.552 .04179 Mdot
.552 .04181 Mdot
.552 .04204 Mdot
.552 .04208 Mdot
.552 .0421 Mdot
.552 .04211 Mdot
.552 .0424 Mdot
.552 .04253 Mdot
.552 .0427 Mdot
.552 .04271 Mdot
.552 .04285 Mdot
.552 .04292 Mdot
.552 .04292 Mdot
.552 .04314 Mdot
.552 .04317 Mdot
.552 .04345 Mdot
.552 .04351 Mdot
.552 .04362 Mdot
.552 .04365 Mdot
.552 .04371 Mdot
.552 .04387 Mdot
.552 .04407 Mdot
.552 .04417 Mdot
.552 .04422 Mdot
.552 .04435 Mdot
.552 .04454 Mdot
.552 .04454 Mdot
.552 .04461 Mdot
.552 .04461 Mdot
.552 .04463 Mdot
.552 .04488 Mdot
.552 .04492 Mdot
.552 .04495 Mdot
.552 .04496 Mdot
.552 .04528 Mdot
.552 .04542 Mdot
.552 .04561 Mdot
.552 .04563 Mdot
.552 .04578 Mdot
.552 .04585 Mdot
.552 .04586 Mdot
.552 .0461 Mdot
.552 .04613 Mdot
.552 .0462 Mdot
.552 .04644 Mdot
.552 .0465 Mdot
.552 .04662 Mdot
.552 .04666 Mdot
.552 .04669 Mdot
.552 .04672 Mdot
.552 .0469 Mdot
.552 .04694 Mdot
.552 .04713 Mdot
.552 .04716 Mdot
.552 .04723 Mdot
.552 .04729 Mdot
.552 .04744 Mdot
.552 .04764 Mdot
.552 .04764 Mdot
.552 .04772 Mdot
.552 .04772 Mdot
.552 .04774 Mdot
.552 .04802 Mdot
.552 .04807 Mdot
.552 .04809 Mdot
.552 .04811 Mdot
.552 .04846 Mdot
.552 .04862 Mdot
.552 .04882 Mdot
.552 .04884 Mdot
.552 .04901 Mdot
.552 .04909 Mdot
.552 .0491 Mdot
.552 .04936 Mdot
.552 .04939 Mdot
.552 .04947 Mdot
.552 .04974 Mdot
.552 .04981 Mdot
.552 .04994 Mdot
.552 .04998 Mdot
.552 .05001 Mdot
.552 .05005 Mdot
.552 .05025 Mdot
.552 .05029 Mdot
.552 .0505 Mdot
.552 .05053 Mdot
.552 .05061 Mdot
.552 .05067 Mdot
.552 .05084 Mdot
.552 .05106 Mdot
.552 .05106 Mdot
.552 .05115 Mdot
.552 .05115 Mdot
.552 .05117 Mdot
.552 .05148 Mdot
.552 .05154 Mdot
.552 .05156 Mdot
.552 .05158 Mdot
.552 .05197 Mdot
.552 .05214 Mdot
.552 .05237 Mdot
.552 .05239 Mdot
.552 .05257 Mdot
.552 .05267 Mdot
.552 .05267 Mdot
.552 .05297 Mdot
.552 .053 Mdot
.552 .05308 Mdot
.552 .05338 Mdot
.552 .05345 Mdot
.552 .05361 Mdot
.552 .05365 Mdot
.552 .05368 Mdot
.552 .05373 Mdot
.552 .05395 Mdot
.552 .05399 Mdot
.552 .05422 Mdot
.552 .05426 Mdot
.552 .05434 Mdot
.552 .05441 Mdot
.552 .0546 Mdot
.552 .05484 Mdot
.552 .05484 Mdot
.552 .05494 Mdot
.552 .05494 Mdot
.552 .05497 Mdot
.552 .05531 Mdot
.552 .05536 Mdot
.552 .05539 Mdot
.552 .05542 Mdot
.552 .05584 Mdot
.552 .05603 Mdot
.552 .05629 Mdot
.552 .05631 Mdot
.552 .05651 Mdot
.552 .05661 Mdot
.552 .05662 Mdot
.552 .05695 Mdot
.552 .05698 Mdot
.552 .05707 Mdot
.552 .0574 Mdot
.552 .05748 Mdot
.552 .05765 Mdot
.552 .0577 Mdot
.552 .05774 Mdot
.552 .05779 Mdot
.552 .05803 Mdot
.552 .05808 Mdot
.552 .05833 Mdot
.552 .05837 Mdot
.552 .05847 Mdot
.552 .05854 Mdot
.552 .05874 Mdot
.552 .05901 Mdot
.552 .05902 Mdot
.552 .05912 Mdot
.552 .05912 Mdot
.552 .05915 Mdot
.552 .05953 Mdot
.552 .05959 Mdot
.552 .05962 Mdot
.552 .05965 Mdot
.552 .06012 Mdot
.552 .06033 Mdot
.552 .06061 Mdot
.552 .06063 Mdot
.552 .06086 Mdot
.552 .06097 Mdot
.552 .06098 Mdot
.552 .06134 Mdot
.552 .06138 Mdot
.552 .06148 Mdot
.552 .06184 Mdot
.552 .06193 Mdot
.552 .06212 Mdot
.552 .06217 Mdot
.552 .06221 Mdot
.552 .06227 Mdot
.552 .06253 Mdot
.552 .06258 Mdot
.552 .06287 Mdot
.552 .06291 Mdot
.552 .06302 Mdot
.552 .0631 Mdot
.552 .06332 Mdot
.552 .06362 Mdot
.552 .06362 Mdot
.552 .06374 Mdot
.552 .06374 Mdot
.552 .06377 Mdot
.552 .06419 Mdot
.552 .06426 Mdot
.552 .06429 Mdot
.552 .06432 Mdot
.552 .06484 Mdot
.552 .06508 Mdot
.552 .06538 Mdot
.552 .06541 Mdot
.552 .06565 Mdot
.552 .06578 Mdot
.552 .06579 Mdot
.552 .06619 Mdot
.552 .06623 Mdot
.552 .06634 Mdot
.552 .06675 Mdot
.552 .06684 Mdot
.552 .06705 Mdot
.552 .06711 Mdot
.552 .06715 Mdot
.552 .06721 Mdot
.552 .06751 Mdot
.552 .06756 Mdot
.552 .06787 Mdot
.552 .06792 Mdot
.552 .06804 Mdot
.552 .06813 Mdot
.552 .06838 Mdot
.552 .06871 Mdot
.552 .06871 Mdot
.552 .06884 Mdot
.552 .06884 Mdot
.552 .06887 Mdot
.552 .06934 Mdot
.552 .06941 Mdot
.552 .06945 Mdot
.552 .06948 Mdot
.552 .07005 Mdot
.552 .07031 Mdot
.552 .07065 Mdot
.552 .07068 Mdot
.552 .07095 Mdot
.552 .07109 Mdot
.552 .0711 Mdot
.552 .07154 Mdot
.552 .07159 Mdot
.552 .07171 Mdot
.552 .07216 Mdot
.552 .07226 Mdot
.552 .07249 Mdot
.552 .07256 Mdot
.552 .0726 Mdot
.552 .07267 Mdot
.552 .073 Mdot
.552 .07306 Mdot
.552 .0734 Mdot
.552 .07346 Mdot
.552 .07358 Mdot
.552 .07369 Mdot
.552 .07396 Mdot
.552 .07432 Mdot
.552 .07433 Mdot
.552 .07447 Mdot
.552 .07447 Mdot
.552 .07451 Mdot
.552 .07502 Mdot
.552 .0751 Mdot
.552 .07514 Mdot
.552 .07518 Mdot
.552 .07581 Mdot
.552 .0761 Mdot
.552 .07647 Mdot
.552 .0765 Mdot
.552 .0768 Mdot
.552 .07696 Mdot
.552 .07697 Mdot
.552 .07745 Mdot
.552 .0775 Mdot
.552 .07764 Mdot
.552 .07813 Mdot
.552 .07825 Mdot
.552 .0785 Mdot
.552 .07857 Mdot
.552 .07862 Mdot
.552 .0787 Mdot
.552 .07906 Mdot
.552 .07913 Mdot
.552 .0795 Mdot
.552 .07957 Mdot
.552 .07971 Mdot
.552 .07982 Mdot
.552 .08012 Mdot
.552 .08052 Mdot
.552 .08053 Mdot
.552 .08068 Mdot
.552 .08068 Mdot
.552 .08073 Mdot
.552 .08129 Mdot
.552 .08138 Mdot
.552 .08143 Mdot
.552 .08147 Mdot
.552 .08216 Mdot
.552 .08248 Mdot
.552 .08289 Mdot
.552 .08293 Mdot
.552 .08326 Mdot
.552 .08343 Mdot
.552 .08344 Mdot
.552 .08397 Mdot
.552 .08403 Mdot
.552 .08418 Mdot
.552 .08473 Mdot
.552 .08486 Mdot
.552 .08513 Mdot
.552 .08521 Mdot
.552 .08527 Mdot
.552 .08535 Mdot
.552 .08575 Mdot
.552 .08583 Mdot
.552 .08624 Mdot
.552 .08631 Mdot
.552 .08647 Mdot
.552 .08659 Mdot
.552 .08692 Mdot
.552 .08737 Mdot
.552 .08737 Mdot
.552 .08754 Mdot
.552 .08754 Mdot
.552 .08759 Mdot
.552 .08821 Mdot
.552 .08831 Mdot
.552 .08837 Mdot
.552 .08841 Mdot
.552 .08917 Mdot
.552 .08953 Mdot
.552 .08998 Mdot
.552 .09002 Mdot
.552 .09039 Mdot
.552 .09058 Mdot
.552 .09059 Mdot
.552 .09118 Mdot
.552 .09124 Mdot
.552 .09141 Mdot
.552 .09201 Mdot
.552 .09215 Mdot
.552 .09245 Mdot
.552 .09255 Mdot
.552 .09261 Mdot
.552 .0927 Mdot
.552 .09314 Mdot
.552 .09322 Mdot
.552 .09368 Mdot
.552 .09376 Mdot
.552 .09393 Mdot
.552 .09406 Mdot
.552 .09443 Mdot
.552 .09492 Mdot
.552 .09493 Mdot
.552 .09511 Mdot
.552 .09511 Mdot
.552 .09517 Mdot
.552 .09586 Mdot
.552 .09597 Mdot
.552 .09602 Mdot
.552 .09607 Mdot
.552 .09692 Mdot
.552 .09731 Mdot
.552 .09781 Mdot
.552 .09785 Mdot
.552 .09825 Mdot
.552 .09847 Mdot
.552 .09848 Mdot
.552 .09913 Mdot
.552 .0992 Mdot
.552 .09939 Mdot
.552 .10005 Mdot
.552 .1002 Mdot
.552 .10054 Mdot
.552 .10064 Mdot
.552 .10071 Mdot
.552 .10081 Mdot
.552 .10129 Mdot
.552 .10139 Mdot
.552 .10189 Mdot
.552 .10198 Mdot
.552 .10217 Mdot
.552 .10232 Mdot
.552 .10272 Mdot
.552 .10326 Mdot
.552 .10327 Mdot
.552 .10348 Mdot
.552 .10348 Mdot
.552 .10354 Mdot
.552 .10429 Mdot
.552 .10442 Mdot
.552 .10448 Mdot
.552 .10454 Mdot
.552 .10547 Mdot
.552 .1059 Mdot
.552 .10645 Mdot
.552 .1065 Mdot
.552 .10694 Mdot
.552 .10718 Mdot
.552 .10719 Mdot
.552 .10791 Mdot
.552 .10798 Mdot
.552 .10819 Mdot
.552 .10892 Mdot
.552 .10909 Mdot
.552 .10946 Mdot
.552 .10958 Mdot
.552 .10965 Mdot
.552 .10976 Mdot
.552 .1103 Mdot
.552 .1104 Mdot
.552 .11096 Mdot
.552 .11105 Mdot
.552 .11126 Mdot
.552 .11143 Mdot
.552 .11187 Mdot
.552 .11247 Mdot
.552 .11248 Mdot
.552 .11271 Mdot
.552 .11271 Mdot
.552 .11277 Mdot
.552 .11361 Mdot
.552 .11375 Mdot
.552 .11382 Mdot
.552 .11388 Mdot
.552 .1149 Mdot
.552 .11538 Mdot
.552 .11599 Mdot
.552 .11605 Mdot
.552 .11653 Mdot
.552 .11679 Mdot
.552 .11681 Mdot
.552 .1176 Mdot
.552 .11768 Mdot
.552 .11791 Mdot
.552 .11872 Mdot
.552 .11891 Mdot
.552 .11932 Mdot
.552 .11944 Mdot
.552 .11953 Mdot
.552 .11965 Mdot
.552 .12024 Mdot
.552 .12035 Mdot
.552 .12097 Mdot
.552 .12107 Mdot
.552 .1213 Mdot
.552 .12149 Mdot
.552 .12198 Mdot
.552 .12264 Mdot
.552 .12265 Mdot
.552 .1229 Mdot
.552 .1229 Mdot
.552 .12297 Mdot
.552 .1239 Mdot
.552 .12405 Mdot
.552 .12412 Mdot
.552 .12419 Mdot
.552 .12532 Mdot
.552 .12585 Mdot
.552 .12652 Mdot
.552 .12658 Mdot
.552 .12712 Mdot
.552 .12741 Mdot
.552 .12742 Mdot
.552 .1283 Mdot
.552 .12839 Mdot
.552 .12864 Mdot
.552 .12953 Mdot
.552 .12975 Mdot
.552 .1302 Mdot
.552 .13033 Mdot
.552 .13043 Mdot
.552 .13056 Mdot
.552 .13121 Mdot
.552 .13134 Mdot
.552 .13202 Mdot
.552 .13213 Mdot
.552 .13239 Mdot
.552 .13259 Mdot
.552 .13313 Mdot
.552 .13386 Mdot
.552 .13387 Mdot
.552 .13415 Mdot
.552 .13415 Mdot
.552 .13423 Mdot
.552 .13525 Mdot
.552 .13542 Mdot
.552 .1355 Mdot
.552 .13558 Mdot
.552 .13683 Mdot
.552 .13741 Mdot
.552 .13815 Mdot
.552 .13822 Mdot
.552 .13881 Mdot
.552 .13913 Mdot
.552 .13915 Mdot
.552 .14011 Mdot
.552 .14021 Mdot
.552 .14049 Mdot
.552 .14148 Mdot
.552 .14171 Mdot
.552 .14221 Mdot
.552 .14236 Mdot
.552 .14246 Mdot
.552 .14261 Mdot
.552 .14333 Mdot
.552 .14347 Mdot
.552 .14422 Mdot
.552 .14434 Mdot
.552 .14462 Mdot
.552 .14485 Mdot
.552 .14545 Mdot
.552 .14626 Mdot
.552 .14626 Mdot
.552 .14657 Mdot
.552 .14657 Mdot
.552 .14666 Mdot
.552 .14779 Mdot
.552 .14797 Mdot
.552 .14806 Mdot
.552 .14814 Mdot
.552 .14953 Mdot
.552 .15017 Mdot
.552 .15099 Mdot
.552 .15106 Mdot
.552 .15172 Mdot
.552 .15207 Mdot
.552 .15209 Mdot
.552 .15315 Mdot
.552 .15327 Mdot
.552 .15357 Mdot
.552 .15466 Mdot
.552 .15492 Mdot
.552 .15547 Mdot
.552 .15563 Mdot
.552 .15575 Mdot
.552 .15591 Mdot
.552 .1567 Mdot
.552 .15686 Mdot
.552 .15769 Mdot
.552 .15782 Mdot
.552 .15813 Mdot
.552 .15838 Mdot
.552 .15905 Mdot
.552 .15994 Mdot
.552 .15994 Mdot
.552 .16028 Mdot
.552 .16028 Mdot
.552 .16038 Mdot
.552 .16163 Mdot
.552 .16183 Mdot
.552 .16193 Mdot
.552 .16202 Mdot
.552 .16355 Mdot
.552 .16425 Mdot
.552 .16516 Mdot
.552 .16524 Mdot
.552 .16597 Mdot
.552 .16635 Mdot
.552 .16637 Mdot
.552 .16755 Mdot
.552 .16768 Mdot
.552 .16802 Mdot
.552 .16921 Mdot
.552 .1695 Mdot
.552 .1701 Mdot
.552 .17029 Mdot
.552 .17041 Mdot
.552 .17059 Mdot
.552 .17147 Mdot
.552 .17164 Mdot
.552 .17256 Mdot
.552 .17271 Mdot
.552 .17305 Mdot
.552 .17332 Mdot
.552 .17406 Mdot
.552 .17504 Mdot
.552 .17505 Mdot
.552 .17542 Mdot
.552 .17542 Mdot
.552 .17553 Mdot
.552 .17691 Mdot
.552 .17713 Mdot
.552 .17724 Mdot
.552 .17734 Mdot
.552 .17903 Mdot
.552 .1798 Mdot
.552 .18081 Mdot
.552 .1809 Mdot
.552 .1817 Mdot
.552 .18212 Mdot
.552 .18215 Mdot
.552 .18345 Mdot
.552 .18358 Mdot
.552 .18396 Mdot
.552 .18528 Mdot
.552 .18559 Mdot
.552 .18626 Mdot
.552 .18647 Mdot
.552 .18661 Mdot
.552 .18681 Mdot
.552 .18777 Mdot
.552 .18796 Mdot
.552 .18897 Mdot
.552 .18914 Mdot
.552 .18952 Mdot
.552 .18982 Mdot
.552 .19063 Mdot
.552 .19171 Mdot
.552 .19172 Mdot
.552 .19213 Mdot
.552 .19214 Mdot
.552 .19226 Mdot
.552 .19377 Mdot
.552 .19402 Mdot
.552 .19415 Mdot
.552 .19425 Mdot
.552 .19611 Mdot
.552 .19697 Mdot
.552 .19808 Mdot
.552 .19818 Mdot
.552 .19907 Mdot
.552 .19953 Mdot
.552 .19956 Mdot
.552 .201 Mdot
.552 .20115 Mdot
.552 .20156 Mdot
.552 .20302 Mdot
.552 .20337 Mdot
.552 .2041 Mdot
.552 .20433 Mdot
.552 .20448 Mdot
.552 .2047 Mdot
.552 .20577 Mdot
.552 .20598 Mdot
.552 .2071 Mdot
.552 .20728 Mdot
.552 .2077 Mdot
.552 .20803 Mdot
.552 .20892 Mdot
.552 .21012 Mdot
.552 .21013 Mdot
.552 .21059 Mdot
.552 .21059 Mdot
.552 .21072 Mdot
.552 .21239 Mdot
.552 .21267 Mdot
.552 .21281 Mdot
.552 .21293 Mdot
.552 .21498 Mdot
.552 .21593 Mdot
.552 .21715 Mdot
.552 .21726 Mdot
.552 .21824 Mdot
.552 .21875 Mdot
.552 .21878 Mdot
.552 .22037 Mdot
.552 .22054 Mdot
.552 .22099 Mdot
.552 .2226 Mdot
.552 .22299 Mdot
.552 .2238 Mdot
.552 .22405 Mdot
.552 .22422 Mdot
.552 .22446 Mdot
.552 .22564 Mdot
.552 .22587 Mdot
.552 .2271 Mdot
.552 .2273 Mdot
.552 .22777 Mdot
.552 .22814 Mdot
.552 .22912 Mdot
.552 .23044 Mdot
.552 .23046 Mdot
.552 .23096 Mdot
.552 .23096 Mdot
.552 .23111 Mdot
.552 .23295 Mdot
.552 .23325 Mdot
.552 .23341 Mdot
.552 .23354 Mdot
.552 .23581 Mdot
.552 .23685 Mdot
.552 .2382 Mdot
.552 .23833 Mdot
.552 .23941 Mdot
.552 .23997 Mdot
.552 .24001 Mdot
.552 .24176 Mdot
.552 .24194 Mdot
.552 .24245 Mdot
.552 .24422 Mdot
.552 .24465 Mdot
.552 .24555 Mdot
.552 .24582 Mdot
.552 .24601 Mdot
.552 .24628 Mdot
.552 .24757 Mdot
.552 .24783 Mdot
.552 .24919 Mdot
.552 .24941 Mdot
.552 .24992 Mdot
.552 .25033 Mdot
.552 .25142 Mdot
.552 .25288 Mdot
.552 .25289 Mdot
.552 .25345 Mdot
.552 .25345 Mdot
.552 .25361 Mdot
.552 .25565 Mdot
.552 .25598 Mdot
.552 .25615 Mdot
.552 .2563 Mdot
.552 .2588 Mdot
.552 .25996 Mdot
.552 .26145 Mdot
.552 .26158 Mdot
.552 .26277 Mdot
.552 .2634 Mdot
.552 .26344 Mdot
.552 .26537 Mdot
.552 .26557 Mdot
.552 .26613 Mdot
.552 .26809 Mdot
.552 .26856 Mdot
.552 .26955 Mdot
.552 .26986 Mdot
.552 .27006 Mdot
.552 .27036 Mdot
.552 .27179 Mdot
.552 .27207 Mdot
.552 .27358 Mdot
.552 .27382 Mdot
.552 .27438 Mdot
.552 .27483 Mdot
.552 .27604 Mdot
.552 .27765 Mdot
.552 .27766 Mdot
.552 .27827 Mdot
.552 .27828 Mdot
.552 .27846 Mdot
.552 .28071 Mdot
.552 .28107 Mdot
.552 .28126 Mdot
.552 .28142 Mdot
.552 .28419 Mdot
.552 .28546 Mdot
.552 .28711 Mdot
.552 .28726 Mdot
.552 .28857 Mdot
.552 .28926 Mdot
.552 .2893 Mdot
.552 .29144 Mdot
.552 .29166 Mdot
.552 .29228 Mdot
.552 .29444 Mdot
.552 .29496 Mdot
.552 .29606 Mdot
.552 .29639 Mdot
.552 .29662 Mdot
.552 .29695 Mdot
.552 .29852 Mdot
.552 .29884 Mdot
.552 .3005 Mdot
.552 .30077 Mdot
.552 .30139 Mdot
.552 .30189 Mdot
.552 .30321 Mdot
.552 .30499 Mdot
.552 .30501 Mdot
.552 .30568 Mdot
.552 .30569 Mdot
.552 .30589 Mdot
.552 .30837 Mdot
.552 .30877 Mdot
.552 .30898 Mdot
.552 .30916 Mdot
.552 .31221 Mdot
.552 .31362 Mdot
.552 .31544 Mdot
.552 .3156 Mdot
.552 .31705 Mdot
.552 .31781 Mdot
.552 .31786 Mdot
.552 .32022 Mdot
.552 .32046 Mdot
.552 .32114 Mdot
.552 .32354 Mdot
.552 .3241 Mdot
.552 .32532 Mdot
.552 .32569 Mdot
.552 .32594 Mdot
.552 .3263 Mdot
.552 .32804 Mdot
.552 .32839 Mdot
.552 .32879 Mdot
.552 .33022 Mdot
.552 .33052 Mdot
.552 .3312 Mdot
.552 .33175 Mdot
.552 .33322 Mdot
.552 .33518 Mdot
.552 .3352 Mdot
.552 .33594 Mdot
.552 .33595 Mdot
.552 .33617 Mdot
.552 .33891 Mdot
.552 .33936 Mdot
.552 .33958 Mdot
.552 .33978 Mdot
.554 .01488 Mdot
.554 .0149 Mdot
.554 .01492 Mdot
.554 .01494 Mdot
.554 .01496 Mdot
.554 .01499 Mdot
.554 .01502 Mdot
.554 .01505 Mdot
.554 .01509 Mdot
.554 .01513 Mdot
.554 .01517 Mdot
.554 .01522 Mdot
.554 .01528 Mdot
.554 .01534 Mdot
.554 .0154 Mdot
.554 .01548 Mdot
.554 .01556 Mdot
.554 .01565 Mdot
.554 .01575 Mdot
.554 .01586 Mdot
.554 .01599 Mdot
.554 .01612 Mdot
.554 .01628 Mdot
.554 .01645 Mdot
.554 .01663 Mdot
.554 .01684 Mdot
.554 .01707 Mdot
.554 .0171 Mdot
.554 .01732 Mdot
.554 .01736 Mdot
.554 .0176 Mdot
.554 .01764 Mdot
.554 .01782 Mdot
.554 .01792 Mdot
.554 .01796 Mdot
.554 .01816 Mdot
.554 .01826 Mdot
.554 .01831 Mdot
.554 .01853 Mdot
.554 .01865 Mdot
.554 .0187 Mdot
.554 .01894 Mdot
.554 .01907 Mdot
.554 .01913 Mdot
.554 .0194 Mdot
.554 .01954 Mdot
.554 .0196 Mdot
.554 .0199 Mdot
.554 .02006 Mdot
.554 .02013 Mdot
.554 .02042 Mdot
.554 .02046 Mdot
.554 .02064 Mdot
.554 .02072 Mdot
.554 .02103 Mdot
.554 .02108 Mdot
.554 .02128 Mdot
.554 .02136 Mdot
.554 .02172 Mdot
.554 .02177 Mdot
.554 .02199 Mdot
.554 .02208 Mdot
.554 .02247 Mdot
.554 .0225 Mdot
.554 .02253 Mdot
.554 .02277 Mdot
.554 .02288 Mdot
.554 .02318 Mdot
.554 .02331 Mdot
.554 .02334 Mdot
.554 .02338 Mdot
.554 .02364 Mdot
.554 .02376 Mdot
.554 .0241 Mdot
.554 .02424 Mdot
.554 .02427 Mdot
.554 .02431 Mdot
.554 .02431 Mdot
.554 .02461 Mdot
.554 .02474 Mdot
.554 .02481 Mdot
.554 .02511 Mdot
.554 .02527 Mdot
.554 .0253 Mdot
.554 .02535 Mdot
.554 .02535 Mdot
.554 .02568 Mdot
.554 .02582 Mdot
.554 .0259 Mdot
.554 .02623 Mdot
.554 .02641 Mdot
.554 .02644 Mdot
.554 .0265 Mdot
.554 .0265 Mdot
.554 .02686 Mdot
.554 .02686 Mdot
.554 .02702 Mdot
.554 .02711 Mdot
.554 .02748 Mdot
.554 .02767 Mdot
.554 .02771 Mdot
.554 .02777 Mdot
.554 .02777 Mdot
.554 .02817 Mdot
.554 .02817 Mdot
.554 .02835 Mdot
.554 .02845 Mdot
.554 .02885 Mdot
.554 .02907 Mdot
.554 .02912 Mdot
.554 .02918 Mdot
.554 .02918 Mdot
.554 .02962 Mdot
.554 .02963 Mdot
.554 .02982 Mdot
.554 .02993 Mdot
.554 .03038 Mdot
.554 .03062 Mdot
.554 .03067 Mdot
.554 .03074 Mdot
.554 .03074 Mdot
.554 .03087 Mdot
.554 .03104 Mdot
.554 .03123 Mdot
.554 .03124 Mdot
.554 .03145 Mdot
.554 .03158 Mdot
.554 .03189 Mdot
.554 .03197 Mdot
.554 .03207 Mdot
.554 .03233 Mdot
.554 .03239 Mdot
.554 .03247 Mdot
.554 .03247 Mdot
.554 .03262 Mdot
.554 .03281 Mdot
.554 .03281 Mdot
.554 .03302 Mdot
.554 .03302 Mdot
.554 .03312 Mdot
.554 .03326 Mdot
.554 .0334 Mdot
.554 .03374 Mdot
.554 .03383 Mdot
.554 .03395 Mdot
.554 .03424 Mdot
.554 .0343 Mdot
.554 .03439 Mdot
.554 .03439 Mdot
.554 .03455 Mdot
.554 .03467 Mdot
.554 .03468 Mdot
.554 .03476 Mdot
.554 .03476 Mdot
.554 .03499 Mdot
.554 .035 Mdot
.554 .03511 Mdot
.554 .03526 Mdot
.554 .03541 Mdot
.554 .03547 Mdot
.554 .0358 Mdot
.554 .0359 Mdot
.554 .03603 Mdot
.554 .03635 Mdot
.554 .03642 Mdot
.554 .03652 Mdot
.554 .03652 Mdot
.554 .03669 Mdot
.554 .03682 Mdot
.554 .03684 Mdot
.554 .03692 Mdot
.554 .03693 Mdot
.554 .03718 Mdot
.554 .03719 Mdot
.554 .03731 Mdot
.554 .03748 Mdot
.554 .03749 Mdot
.554 .03765 Mdot
.554 .03771 Mdot
.554 .03807 Mdot
.554 .03818 Mdot
.554 .03833 Mdot
.554 .03868 Mdot
.554 .03876 Mdot
.554 .03887 Mdot
.554 .03887 Mdot
.554 .03893 Mdot
.554 .03907 Mdot
.554 .03921 Mdot
.554 .03923 Mdot
.554 .03932 Mdot
.554 .03932 Mdot
.554 .03953 Mdot
.554 .03961 Mdot
.554 .03961 Mdot
.554 .03975 Mdot
.554 .03979 Mdot
.554 .03994 Mdot
.554 .03995 Mdot
.554 .04013 Mdot
.554 .0402 Mdot
.554 .04059 Mdot
.554 .04072 Mdot
.554 .04088 Mdot
.554 .04119 Mdot
.554 .0412 Mdot
.554 .04127 Mdot
.554 .04136 Mdot
.554 .04148 Mdot
.554 .04148 Mdot
.554 .04154 Mdot
.554 .0417 Mdot
.554 .04185 Mdot
.554 .04187 Mdot
.554 .04198 Mdot
.554 .04198 Mdot
.554 .04221 Mdot
.554 .0423 Mdot
.554 .0423 Mdot
.554 .04246 Mdot
.554 .0425 Mdot
.554 .04266 Mdot
.554 .04268 Mdot
.554 .04287 Mdot
.554 .04295 Mdot
.554 .04339 Mdot
.554 .04353 Mdot
.554 .0437 Mdot
.554 .04405 Mdot
.554 .04406 Mdot
.554 .04413 Mdot
.554 .04414 Mdot
.554 .04424 Mdot
.554 .04437 Mdot
.554 .04437 Mdot
.554 .04444 Mdot
.554 .04461 Mdot
.554 .04478 Mdot
.554 .04481 Mdot
.554 .04493 Mdot
.554 .04493 Mdot
.554 .04518 Mdot
.554 .04528 Mdot
.554 .04528 Mdot
.554 .04533 Mdot
.554 .04537 Mdot
.554 .04546 Mdot
.554 .0455 Mdot
.554 .04568 Mdot
.554 .0457 Mdot
.554 .04591 Mdot
.554 .04598 Mdot
.554 .046 Mdot
.554 .04642 Mdot
.554 .04649 Mdot
.554 .04664 Mdot
.554 .04683 Mdot
.554 .04721 Mdot
.554 .04723 Mdot
.554 .04731 Mdot
.554 .04732 Mdot
.554 .0474 Mdot
.554 .04743 Mdot
.554 .04757 Mdot
.554 .04757 Mdot
.554 .04765 Mdot
.554 .04784 Mdot
.554 .04797 Mdot
.554 .04803 Mdot
.554 .04806 Mdot
.554 .04819 Mdot
.554 .04819 Mdot
.554 .04847 Mdot
.554 .04858 Mdot
.554 .04858 Mdot
.554 .04864 Mdot
.554 .04868 Mdot
.554 .04878 Mdot
.554 .04883 Mdot
.554 .04902 Mdot
.554 .04905 Mdot
.554 .04928 Mdot
.554 .04936 Mdot
.554 .04937 Mdot
.554 .04963 Mdot
.554 .04985 Mdot
.554 .04992 Mdot
.554 .05004 Mdot
.554 .05009 Mdot
.554 .0503 Mdot
.554 .05072 Mdot
.554 .05074 Mdot
.554 .05083 Mdot
.554 .05084 Mdot
.554 .05093 Mdot
.554 .05096 Mdot
.554 .05112 Mdot
.554 .05112 Mdot
.554 .0512 Mdot
.554 .05142 Mdot
.554 .05157 Mdot
.554 .05163 Mdot
.554 .05166 Mdot
.554 .0518 Mdot
.554 .0518 Mdot
.554 .05211 Mdot
.554 .05224 Mdot
.554 .05224 Mdot
.554 .05231 Mdot
.554 .05235 Mdot
.554 .05245 Mdot
.554 .05251 Mdot
.554 .05273 Mdot
.554 .05276 Mdot
.554 .05301 Mdot
.554 .0531 Mdot
.554 .05312 Mdot
.554 .0534 Mdot
.554 .05364 Mdot
.554 .05372 Mdot
.554 .05385 Mdot
.554 .05391 Mdot
.554 .05415 Mdot
.554 .05461 Mdot
.554 .05463 Mdot
.554 .05473 Mdot
.554 .05474 Mdot
.554 .05484 Mdot
.554 .05487 Mdot
.554 .05505 Mdot
.554 .05505 Mdot
.554 .05515 Mdot
.554 .05538 Mdot
.554 .05555 Mdot
.554 .05562 Mdot
.554 .05565 Mdot
.554 .05581 Mdot
.554 .05581 Mdot
.554 .05615 Mdot
.554 .05629 Mdot
.554 .05629 Mdot
.554 .05636 Mdot
.554 .05642 Mdot
.554 .05653 Mdot
.554 .0566 Mdot
.554 .05684 Mdot
.554 .05686 Mdot
.554 .05715 Mdot
.554 .05724 Mdot
.554 .05727 Mdot
.554 .05758 Mdot
.554 .05784 Mdot
.554 .05793 Mdot
.554 .05808 Mdot
.554 .05814 Mdot
.554 .0584 Mdot
.554 .05892 Mdot
.554 .05894 Mdot
.554 .05905 Mdot
.554 .05906 Mdot
.554 .05917 Mdot
.554 .05921 Mdot
.554 .05941 Mdot
.554 .05941 Mdot
.554 .05951 Mdot
.554 .05977 Mdot
.554 .05996 Mdot
.554 .06003 Mdot
.554 .06007 Mdot
.554 .06025 Mdot
.554 .06025 Mdot
.554 .06063 Mdot
.554 .06078 Mdot
.554 .06078 Mdot
.554 .06086 Mdot
.554 .06092 Mdot
.554 .06105 Mdot
.554 .06112 Mdot
.554 .06138 Mdot
.554 .06142 Mdot
.554 .06173 Mdot
.554 .06184 Mdot
.554 .06186 Mdot
.554 .06221 Mdot
.554 .0625 Mdot
.554 .0626 Mdot
.554 .06276 Mdot
.554 .06283 Mdot
.554 .06312 Mdot
.554 .06369 Mdot
.554 .06372 Mdot
.554 .06384 Mdot
.554 .06385 Mdot
.554 .06397 Mdot
.554 .06402 Mdot
.554 .06424 Mdot
.554 .06424 Mdot
.554 .06435 Mdot
.554 .06464 Mdot
.554 .06484 Mdot
.554 .06493 Mdot
.554 .06497 Mdot
.554 .06516 Mdot
.554 .06517 Mdot
.554 .06558 Mdot
.554 .06576 Mdot
.554 .06576 Mdot
.554 .06585 Mdot
.554 .06591 Mdot
.554 .06605 Mdot
.554 .06613 Mdot
.554 .06642 Mdot
.554 .06646 Mdot
.554 .06681 Mdot
.554 .06692 Mdot
.554 .06695 Mdot
.554 .06733 Mdot
.554 .06766 Mdot
.554 .06777 Mdot
.554 .06795 Mdot
.554 .06803 Mdot
.554 .06835 Mdot
.554 .06898 Mdot
.554 .06901 Mdot
.554 .06914 Mdot
.554 .06916 Mdot
.554 .06929 Mdot
.554 .06934 Mdot
.554 .06958 Mdot
.554 .06959 Mdot
.554 .06971 Mdot
.554 .07003 Mdot
.554 .07026 Mdot
.554 .07035 Mdot
.554 .07039 Mdot
.554 .07061 Mdot
.554 .07061 Mdot
.554 .07108 Mdot
.554 .07127 Mdot
.554 .07127 Mdot
.554 .07137 Mdot
.554 .07144 Mdot
.554 .07159 Mdot
.554 .07168 Mdot
.554 .07201 Mdot
.554 .07205 Mdot
.554 .07244 Mdot
.554 .07256 Mdot
.554 .07259 Mdot
.554 .07302 Mdot
.554 .07338 Mdot
.554 .0735 Mdot
.554 .0737 Mdot
.554 .07379 Mdot
.554 .07414 Mdot
.554 .07485 Mdot
.554 .07488 Mdot
.554 .07502 Mdot
.554 .07504 Mdot
.554 .07518 Mdot
.554 .07524 Mdot
.554 .07551 Mdot
.554 .07551 Mdot
.554 .07565 Mdot
.554 .076 Mdot
.554 .07625 Mdot
.554 .07636 Mdot
.554 .07641 Mdot
.554 .07665 Mdot
.554 .07665 Mdot
.554 .07716 Mdot
.554 .07738 Mdot
.554 .07738 Mdot
.554 .07749 Mdot
.554 .07757 Mdot
.554 .07774 Mdot
.554 .07784 Mdot
.554 .0782 Mdot
.554 .07824 Mdot
.554 .07867 Mdot
.554 .07881 Mdot
.554 .07884 Mdot
.554 .07931 Mdot
.554 .07972 Mdot
.554 .07985 Mdot
.554 .08007 Mdot
.554 .08016 Mdot
.554 .08056 Mdot
.554 .08134 Mdot
.554 .08137 Mdot
.554 .08154 Mdot
.554 .08155 Mdot
.554 .08171 Mdot
.554 .08178 Mdot
.554 .08207 Mdot
.554 .08208 Mdot
.554 .08223 Mdot
.554 .08262 Mdot
.554 .0829 Mdot
.554 .08302 Mdot
.554 .08307 Mdot
.554 .08334 Mdot
.554 .08334 Mdot
.554 .08391 Mdot
.554 .08414 Mdot
.554 .08415 Mdot
.554 .08427 Mdot
.554 .08435 Mdot
.554 .08454 Mdot
.554 .08465 Mdot
.554 .08505 Mdot
.554 .0851 Mdot
.554 .08558 Mdot
.554 .08573 Mdot
.554 .08577 Mdot
.554 .08629 Mdot
.554 .08674 Mdot
.554 .08688 Mdot
.554 .08713 Mdot
.554 .08723 Mdot
.554 .08767 Mdot
.554 .08854 Mdot
.554 .08857 Mdot
.554 .08875 Mdot
.554 .08877 Mdot
.554 .08895 Mdot
.554 .08902 Mdot
.554 .08935 Mdot
.554 .08935 Mdot
.554 .08952 Mdot
.554 .08996 Mdot
.554 .09026 Mdot
.554 .09039 Mdot
.554 .09045 Mdot
.554 .09075 Mdot
.554 .09075 Mdot
.554 .09138 Mdot
.554 .09164 Mdot
.554 .09165 Mdot
.554 .09178 Mdot
.554 .09187 Mdot
.554 .09208 Mdot
.554 .09221 Mdot
.554 .09265 Mdot
.554 .0927 Mdot
.554 .09323 Mdot
.554 .0934 Mdot
.554 .09344 Mdot
.554 .09402 Mdot
.554 .09452 Mdot
.554 .09468 Mdot
.554 .09495 Mdot
.554 .09507 Mdot
.554 .09555 Mdot
.554 .09651 Mdot
.554 .09655 Mdot
.554 .09675 Mdot
.554 .09677 Mdot
.554 .09697 Mdot
.554 .09704 Mdot
.554 .09741 Mdot
.554 .09741 Mdot
.554 .0976 Mdot
.554 .09808 Mdot
.554 .09842 Mdot
.554 .09857 Mdot
.554 .09863 Mdot
.554 .09896 Mdot
.554 .09896 Mdot
.554 .09966 Mdot
.554 .09995 Mdot
.554 .09996 Mdot
.554 .1001 Mdot
.554 .10021 Mdot
.554 .10044 Mdot
.554 .10058 Mdot
.554 .10107 Mdot
.554 .10112 Mdot
.554 .10171 Mdot
.554 .1019 Mdot
.554 .10195 Mdot
.554 .10259 Mdot
.554 .10313 Mdot
.554 .10331 Mdot
.554 .10361 Mdot
.554 .10374 Mdot
.554 .10428 Mdot
.554 .10534 Mdot
.554 .10539 Mdot
.554 .10561 Mdot
.554 .10563 Mdot
.554 .10585 Mdot
.554 .10593 Mdot
.554 .10634 Mdot
.554 .10635 Mdot
.554 .10655 Mdot
.554 .10709 Mdot
.554 .10746 Mdot
.554 .10762 Mdot
.554 .10769 Mdot
.554 .10806 Mdot
.554 .10806 Mdot
.554 .10884 Mdot
.554 .10915 Mdot
.554 .10916 Mdot
.554 .10932 Mdot
.554 .10944 Mdot
.554 .1097 Mdot
.554 .10985 Mdot
.554 .11039 Mdot
.554 .11046 Mdot
.554 .11111 Mdot
.554 .11132 Mdot
.554 .11137 Mdot
.554 .11208 Mdot
.554 .11268 Mdot
.554 .11288 Mdot
.554 .11321 Mdot
.554 .11336 Mdot
.554 .11396 Mdot
.554 .11513 Mdot
.554 .11518 Mdot
.554 .11542 Mdot
.554 .11545 Mdot
.554 .11569 Mdot
.554 .11579 Mdot
.554 .11624 Mdot
.554 .11624 Mdot
.554 .11647 Mdot
.554 .11706 Mdot
.554 .11748 Mdot
.554 .11766 Mdot
.554 .11774 Mdot
.554 .11814 Mdot
.554 .11815 Mdot
.554 .119 Mdot
.554 .11935 Mdot
.554 .11936 Mdot
.554 .11954 Mdot
.554 .11967 Mdot
.554 .11996 Mdot
.554 .12012 Mdot
.554 .12073 Mdot
.554 .1208 Mdot
.554 .12152 Mdot
.554 .12175 Mdot
.554 .12181 Mdot
.554 .12259 Mdot
.554 .12326 Mdot
.554 .12348 Mdot
.554 .12385 Mdot
.554 .12401 Mdot
.554 .12468 Mdot
.554 .12597 Mdot
.554 .12603 Mdot
.554 .1263 Mdot
.554 .12633 Mdot
.554 .1266 Mdot
.554 .1267 Mdot
.554 .1272 Mdot
.554 .12721 Mdot
.554 .12746 Mdot
.554 .12812 Mdot
.554 .12858 Mdot
.554 .12877 Mdot
.554 .12886 Mdot
.554 .12931 Mdot
.554 .12932 Mdot
.554 .13026 Mdot
.554 .13065 Mdot
.554 .13067 Mdot
.554 .13086 Mdot
.554 .13101 Mdot
.554 .13132 Mdot
.554 .13151 Mdot
.554 .13218 Mdot
.554 .13225 Mdot
.554 .13305 Mdot
.554 .13331 Mdot
.554 .13337 Mdot
.554 .13424 Mdot
.554 .13499 Mdot
.554 .13523 Mdot
.554 .13564 Mdot
.554 .13582 Mdot
.554 .13655 Mdot
.554 .13799 Mdot
.554 .13805 Mdot
.554 .13835 Mdot
.554 .13838 Mdot
.554 .13868 Mdot
.554 .1388 Mdot
.554 .13935 Mdot
.554 .13936 Mdot
.554 .13964 Mdot
.554 .14036 Mdot
.554 .14088 Mdot
.554 .14109 Mdot
.554 .14119 Mdot
.554 .14169 Mdot
.554 .14169 Mdot
.554 .14274 Mdot
.554 .14318 Mdot
.554 .14319 Mdot
.554 .14341 Mdot
.554 .14357 Mdot
.554 .14391 Mdot
.554 .14412 Mdot
.554 .14486 Mdot
.554 .14495 Mdot
.554 .14583 Mdot
.554 .14612 Mdot
.554 .14619 Mdot
.554 .14715 Mdot
.554 .14798 Mdot
.554 .14825 Mdot
.554 .1487 Mdot
.554 .14889 Mdot
.554 .14971 Mdot
.554 .1513 Mdot
.554 .15137 Mdot
.554 .15171 Mdot
.554 .15174 Mdot
.554 .15207 Mdot
.554 .1522 Mdot
.554 .15281 Mdot
.554 .15282 Mdot
.554 .15313 Mdot
.554 .15393 Mdot
.554 .1545 Mdot
.554 .15474 Mdot
.554 .15485 Mdot
.554 .1554 Mdot
.554 .15541 Mdot
.554 .15657 Mdot
.554 .15705 Mdot
.554 .15706 Mdot
.554 .15731 Mdot
.554 .15748 Mdot
.554 .15787 Mdot
.554 .1581 Mdot
.554 .15892 Mdot
.554 .15901 Mdot
.554 .15999 Mdot
.554 .16031 Mdot
.554 .16039 Mdot
.554 .16145 Mdot
.554 .16237 Mdot
.554 .16267 Mdot
.554 .16317 Mdot
.554 .16339 Mdot
.554 .16429 Mdot
.554 .16605 Mdot
.554 .16613 Mdot
.554 .1665 Mdot
.554 .16654 Mdot
.554 .16691 Mdot
.554 .16705 Mdot
.554 .16772 Mdot
.554 .16773 Mdot
.554 .16808 Mdot
.554 .16897 Mdot
.554 .1696 Mdot
.554 .16986 Mdot
.554 .16998 Mdot
.554 .1706 Mdot
.554 .1706 Mdot
.554 .17189 Mdot
.554 .17242 Mdot
.554 .17244 Mdot
.554 .17271 Mdot
.554 .1729 Mdot
.554 .17333 Mdot
.554 .17358 Mdot
.554 .17449 Mdot
.554 .1746 Mdot
.554 .17568 Mdot
.554 .17603 Mdot
.554 .17612 Mdot
.554 .1773 Mdot
.554 .17831 Mdot
.554 .17865 Mdot
.554 .1792 Mdot
.554 .17944 Mdot
.554 .18044 Mdot
.554 .1824 Mdot
.554 .18248 Mdot
.554 .18289 Mdot
.554 .18293 Mdot
.554 .18334 Mdot
.554 .1835 Mdot
.554 .18425 Mdot
.554 .18426 Mdot
.554 .18464 Mdot
.554 .18563 Mdot
.554 .18633 Mdot
.554 .18662 Mdot
.554 .18675 Mdot
.554 .18743 Mdot
.554 .18744 Mdot
.554 .18887 Mdot
.554 .18945 Mdot
.554 .18947 Mdot
.554 .18977 Mdot
.554 .18998 Mdot
.554 .19046 Mdot
.554 .19074 Mdot
.554 .19175 Mdot
.554 .19187 Mdot
.554 .19307 Mdot
.554 .19346 Mdot
.554 .19355 Mdot
.554 .19486 Mdot
.554 .19598 Mdot
.554 .19635 Mdot
.554 .19696 Mdot
.554 .19723 Mdot
.554 .19834 Mdot
.554 .20051 Mdot
.554 .2006 Mdot
.554 .20106 Mdot
.554 .2011 Mdot
.554 .20155 Mdot
.554 .20173 Mdot
.554 .20256 Mdot
.554 .20257 Mdot
.554 .20299 Mdot
.554 .20409 Mdot
.554 .20486 Mdot
.554 .20519 Mdot
.554 .20533 Mdot
.554 .20608 Mdot
.554 .20609 Mdot
.554 .20768 Mdot
.554 .20833 Mdot
.554 .20835 Mdot
.554 .20867 Mdot
.554 .20891 Mdot
.554 .20944 Mdot
.554 .20975 Mdot
.554 .21087 Mdot
.554 .211 Mdot
.554 .21233 Mdot
.554 .21276 Mdot
.554 .21431 Mdot
.554 .21556 Mdot
.554 .21597 Mdot
.554 .21665 Mdot
.554 .21695 Mdot
.554 .21817 Mdot
.554 .22057 Mdot
.554 .22068 Mdot
.554 .22118 Mdot
.554 .22123 Mdot
.554 .22173 Mdot
.554 .22192 Mdot
.554 .22285 Mdot
.554 .22286 Mdot
.554 .22333 Mdot
.554 .22454 Mdot
.554 .2254 Mdot
.554 .22576 Mdot
.554 .22592 Mdot
.554 .22675 Mdot
.554 .22676 Mdot
.554 .22852 Mdot
.554 .22924 Mdot
.554 .22926 Mdot
.554 .22962 Mdot
.554 .22989 Mdot
.554 .23047 Mdot
.554 .23082 Mdot
.554 .23205 Mdot
.554 .2322 Mdot
.554 .23367 Mdot
.554 .23415 Mdot
.554 .23587 Mdot
.554 .23725 Mdot
.554 .23771 Mdot
.554 .23846 Mdot
.554 .23879 Mdot
.554 .24015 Mdot
.554 .24281 Mdot
.554 .24292 Mdot
.554 .24348 Mdot
.554 .24354 Mdot
.554 .24409 Mdot
.554 .2443 Mdot
.554 .24532 Mdot
.554 .24533 Mdot
.554 .24586 Mdot
.554 .2472 Mdot
.554 .24815 Mdot
.554 .24855 Mdot
.554 .24873 Mdot
.554 .24965 Mdot
.554 .24966 Mdot
.554 .25161 Mdot
.554 .2524 Mdot
.554 .25243 Mdot
.554 .25283 Mdot
.554 .25312 Mdot
.554 .25377 Mdot
.554 .25415 Mdot
.554 .25552 Mdot
.554 .25568 Mdot
.554 .25732 Mdot
.554 .25785 Mdot
.554 .25976 Mdot
.554 .26129 Mdot
.554 .26179 Mdot
.554 .26262 Mdot
.554 .26299 Mdot
.554 .26449 Mdot
.554 .26744 Mdot
.554 .26757 Mdot
.554 .26819 Mdot
.554 .26825 Mdot
.554 .26886 Mdot
.554 .2691 Mdot
.554 .27023 Mdot
.554 .27024 Mdot
.554 .27082 Mdot
.554 .27231 Mdot
.554 .27336 Mdot
.554 .2738 Mdot
.554 .274 Mdot
.554 .27502 Mdot
.554 .27503 Mdot
.554 .27719 Mdot
.554 .27807 Mdot
.554 .2781 Mdot
.554 .27855 Mdot
.554 .27887 Mdot
.554 .27959 Mdot
.554 .28001 Mdot
.554 .28153 Mdot
.554 .28171 Mdot
.554 .28352 Mdot
.554 .28411 Mdot
.554 .28622 Mdot
.554 .28791 Mdot
.554 .28847 Mdot
.554 .28939 Mdot
.554 .2898 Mdot
.554 .29147 Mdot
.554 .29474 Mdot
.554 .29487 Mdot
.554 .29556 Mdot
.554 .29563 Mdot
.554 .29631 Mdot
.554 .29657 Mdot
.554 .29783 Mdot
.554 .29784 Mdot
.554 .29848 Mdot
.554 .30013 Mdot
.554 .3013 Mdot
.554 .30179 Mdot
.554 .302 Mdot
.554 .30314 Mdot
.554 .30315 Mdot
.554 .30554 Mdot
.554 .30652 Mdot
.554 .30655 Mdot
.554 .30704 Mdot
.554 .3074 Mdot
.554 .3082 Mdot
.554 .30867 Mdot
.554 .31035 Mdot
.554 .31054 Mdot
.554 .31255 Mdot
.554 .3132 Mdot
.554 .31554 Mdot
.554 .31742 Mdot
.554 .31804 Mdot
.554 .31906 Mdot
.554 .31951 Mdot
.554 .32136 Mdot
.554 .32498 Mdot
.554 .32513 Mdot
.554 .32589 Mdot
.554 .32597 Mdot
.554 .32672 Mdot
.554 .32701 Mdot
.554 .3284 Mdot
.554 .32842 Mdot
.554 .32913 Mdot
.554 .33096 Mdot
.554 .33225 Mdot
.554 .33279 Mdot
.554 .33303 Mdot
.554 .33429 Mdot
.554 .3343 Mdot
.554 .33695 Mdot
.554 .33803 Mdot
.554 .33806 Mdot
.554 .33861 Mdot
.554 .33901 Mdot
.554 .33989 Mdot
.554 .34041 Mdot
.554 .34227 Mdot
.556 .01524 Mdot
.556 .01529 Mdot
.556 .01536 Mdot
.556 .01543 Mdot
.556 .01551 Mdot
.556 .0156 Mdot
.556 .0157 Mdot
.556 .01581 Mdot
.556 .01593 Mdot
.556 .01607 Mdot
.556 .01622 Mdot
.556 .01639 Mdot
.556 .01649 Mdot
.556 .01658 Mdot
.556 .01669 Mdot
.556 .01679 Mdot
.556 .01691 Mdot
.556 .01702 Mdot
.556 .01716 Mdot
.556 .01728 Mdot
.556 .01743 Mdot
.556 .01757 Mdot
.556 .01774 Mdot
.556 .01788 Mdot
.556 .01808 Mdot
.556 .01824 Mdot
.556 .01845 Mdot
.556 .01863 Mdot
.556 .01887 Mdot
.556 .01907 Mdot
.556 .01934 Mdot
.556 .01956 Mdot
.556 .01986 Mdot
.556 .0201 Mdot
.556 .02043 Mdot
.556 .02071 Mdot
.556 .02091 Mdot
.556 .02095 Mdot
.556 .02107 Mdot
.556 .02138 Mdot
.556 .02161 Mdot
.556 .02164 Mdot
.556 .02167 Mdot
.556 .02178 Mdot
.556 .02212 Mdot
.556 .02226 Mdot
.556 .02232 Mdot
.556 .02238 Mdot
.556 .02242 Mdot
.556 .02245 Mdot
.556 .02245 Mdot
.556 .02257 Mdot
.556 .02295 Mdot
.556 .02311 Mdot
.556 .02312 Mdot
.556 .02317 Mdot
.556 .02324 Mdot
.556 .02328 Mdot
.556 .02332 Mdot
.556 .02332 Mdot
.556 .02346 Mdot
.556 .02388 Mdot
.556 .02405 Mdot
.556 .02406 Mdot
.556 .02412 Mdot
.556 .02419 Mdot
.556 .02424 Mdot
.556 .02428 Mdot
.556 .02428 Mdot
.556 .02433 Mdot
.556 .02441 Mdot
.556 .02443 Mdot
.556 .0249 Mdot
.556 .02509 Mdot
.556 .02511 Mdot
.556 .02517 Mdot
.556 .02525 Mdot
.556 .02531 Mdot
.556 .02535 Mdot
.556 .02535 Mdot
.556 .0254 Mdot
.556 .0255 Mdot
.556 .02552 Mdot
.556 .02593 Mdot
.556 .02604 Mdot
.556 .02626 Mdot
.556 .02627 Mdot
.556 .02635 Mdot
.556 .02643 Mdot
.556 .0265 Mdot
.556 .02654 Mdot
.556 .02654 Mdot
.556 .0266 Mdot
.556 .02671 Mdot
.556 .02673 Mdot
.556 .02718 Mdot
.556 .02731 Mdot
.556 .02755 Mdot
.556 .02757 Mdot
.556 .02765 Mdot
.556 .02775 Mdot
.556 .02781 Mdot
.556 .02787 Mdot
.556 .02787 Mdot
.556 .02793 Mdot
.556 .02805 Mdot
.556 .02808 Mdot
.556 .02858 Mdot
.556 .02858 Mdot
.556 .02872 Mdot
.556 .02899 Mdot
.556 .02901 Mdot
.556 .0291 Mdot
.556 .02921 Mdot
.556 .02928 Mdot
.556 .02934 Mdot
.556 .02934 Mdot
.556 .02941 Mdot
.556 .02954 Mdot
.556 .02958 Mdot
.556 .03013 Mdot
.556 .03013 Mdot
.556 .0302 Mdot
.556 .03029 Mdot
.556 .03058 Mdot
.556 .03061 Mdot
.556 .03075 Mdot
.556 .03083 Mdot
.556 .03091 Mdot
.556 .03098 Mdot
.556 .03098 Mdot
.556 .03106 Mdot
.556 .0312 Mdot
.556 .03123 Mdot
.556 .03124 Mdot
.556 .03186 Mdot
.556 .03186 Mdot
.556 .03193 Mdot
.556 .03194 Mdot
.556 .03204 Mdot
.556 .03236 Mdot
.556 .03239 Mdot
.556 .03254 Mdot
.556 .03263 Mdot
.556 .03273 Mdot
.556 .0328 Mdot
.556 .0328 Mdot
.556 .03289 Mdot
.556 .03305 Mdot
.556 .03308 Mdot
.556 .03309 Mdot
.556 .03378 Mdot
.556 .03378 Mdot
.556 .03382 Mdot
.556 .03386 Mdot
.556 .03387 Mdot
.556 .03398 Mdot
.556 .03422 Mdot
.556 .03431 Mdot
.556 .03434 Mdot
.556 .03437 Mdot
.556 .03454 Mdot
.556 .03464 Mdot
.556 .03474 Mdot
.556 .03483 Mdot
.556 .03483 Mdot
.556 .03492 Mdot
.556 .03504 Mdot
.556 .0351 Mdot
.556 .03514 Mdot
.556 .03515 Mdot
.556 .03563 Mdot
.556 .03591 Mdot
.556 .03592 Mdot
.556 .03596 Mdot
.556 .036 Mdot
.556 .03601 Mdot
.556 .03605 Mdot
.556 .03614 Mdot
.556 .03623 Mdot
.556 .0364 Mdot
.556 .0365 Mdot
.556 .03654 Mdot
.556 .03657 Mdot
.556 .03676 Mdot
.556 .03687 Mdot
.556 .03699 Mdot
.556 .03708 Mdot
.556 .03708 Mdot
.556 .03719 Mdot
.556 .03732 Mdot
.556 .03739 Mdot
.556 .03743 Mdot
.556 .03744 Mdot
.556 .03789 Mdot
.556 .03798 Mdot
.556 .03829 Mdot
.556 .03829 Mdot
.556 .03834 Mdot
.556 .03839 Mdot
.556 .0384 Mdot
.556 .03844 Mdot
.556 .03853 Mdot
.556 .03864 Mdot
.556 .03883 Mdot
.556 .03894 Mdot
.556 .03898 Mdot
.556 .03901 Mdot
.556 .03923 Mdot
.556 .03932 Mdot
.556 .03935 Mdot
.556 .03937 Mdot
.556 .03948 Mdot
.556 .03958 Mdot
.556 .03959 Mdot
.556 .0397 Mdot
.556 .03985 Mdot
.556 .03992 Mdot
.556 .03997 Mdot
.556 .03998 Mdot
.556 .04048 Mdot
.556 .04058 Mdot
.556 .04093 Mdot
.556 .04093 Mdot
.556 .04099 Mdot
.556 .04103 Mdot
.556 .04104 Mdot
.556 .04105 Mdot
.556 .0411 Mdot
.556 .0412 Mdot
.556 .04132 Mdot
.556 .04153 Mdot
.556 .04165 Mdot
.556 .0417 Mdot
.556 .04174 Mdot
.556 .04198 Mdot
.556 .04208 Mdot
.556 .04211 Mdot
.556 .04213 Mdot
.556 .04226 Mdot
.556 .04237 Mdot
.556 .04237 Mdot
.556 .0425 Mdot
.556 .04266 Mdot
.556 .04275 Mdot
.556 .0428 Mdot
.556 .04281 Mdot
.556 .04308 Mdot
.556 .04337 Mdot
.556 .04348 Mdot
.556 .04386 Mdot
.556 .04387 Mdot
.556 .04393 Mdot
.556 .04398 Mdot
.556 .04399 Mdot
.556 .044 Mdot
.556 .04406 Mdot
.556 .04416 Mdot
.556 .04417 Mdot
.556 .0443 Mdot
.556 .04453 Mdot
.556 .04467 Mdot
.556 .04472 Mdot
.556 .04476 Mdot
.556 .04482 Mdot
.556 .04499 Mdot
.556 .04503 Mdot
.556 .04515 Mdot
.556 .04518 Mdot
.556 .0452 Mdot
.556 .04534 Mdot
.556 .04547 Mdot
.556 .04547 Mdot
.556 .04562 Mdot
.556 .04579 Mdot
.556 .04589 Mdot
.556 .04594 Mdot
.556 .04596 Mdot
.556 .04626 Mdot
.556 .04658 Mdot
.556 .0467 Mdot
.556 .04713 Mdot
.556 .04713 Mdot
.556 .0472 Mdot
.556 .04726 Mdot
.556 .04727 Mdot
.556 .04728 Mdot
.556 .04734 Mdot
.556 .04746 Mdot
.556 .04747 Mdot
.556 .04761 Mdot
.556 .04787 Mdot
.556 .04803 Mdot
.556 .04808 Mdot
.556 .04813 Mdot
.556 .0482 Mdot
.556 .04838 Mdot
.556 .04842 Mdot
.556 .04843 Mdot
.556 .04855 Mdot
.556 .04859 Mdot
.556 .04861 Mdot
.556 .04877 Mdot
.556 .04891 Mdot
.556 .04891 Mdot
.556 .04908 Mdot
.556 .04927 Mdot
.556 .04938 Mdot
.556 .04944 Mdot
.556 .04946 Mdot
.556 .04979 Mdot
.556 .05015 Mdot
.556 .05028 Mdot
.556 .05076 Mdot
.556 .05076 Mdot
.556 .05084 Mdot
.556 .0509 Mdot
.556 .05091 Mdot
.556 .05092 Mdot
.556 .051 Mdot
.556 .05113 Mdot
.556 .05114 Mdot
.556 .0513 Mdot
.556 .05158 Mdot
.556 .05176 Mdot
.556 .05182 Mdot
.556 .05187 Mdot
.556 .05195 Mdot
.556 .05215 Mdot
.556 .05219 Mdot
.556 .0522 Mdot
.556 .05234 Mdot
.556 .05239 Mdot
.556 .05241 Mdot
.556 .05259 Mdot
.556 .05274 Mdot
.556 .05275 Mdot
.556 .05292 Mdot
.556 .05314 Mdot
.556 .05326 Mdot
.556 .05333 Mdot
.556 .05335 Mdot
.556 .05372 Mdot
.556 .05412 Mdot
.556 .05427 Mdot
.556 .0548 Mdot
.556 .0548 Mdot
.556 .05489 Mdot
.556 .05496 Mdot
.556 .05497 Mdot
.556 .05498 Mdot
.556 .05506 Mdot
.556 .0552 Mdot
.556 .05522 Mdot
.556 .0554 Mdot
.556 .05571 Mdot
.556 .05591 Mdot
.556 .05597 Mdot
.556 .05603 Mdot
.556 .05612 Mdot
.556 .05634 Mdot
.556 .05639 Mdot
.556 .0564 Mdot
.556 .05656 Mdot
.556 .05661 Mdot
.556 .05663 Mdot
.556 .05683 Mdot
.556 .057 Mdot
.556 .057 Mdot
.556 .0572 Mdot
.556 .05745 Mdot
.556 .05758 Mdot
.556 .05766 Mdot
.556 .05768 Mdot
.556 .05809 Mdot
.556 .05853 Mdot
.556 .0587 Mdot
.556 .05929 Mdot
.556 .05929 Mdot
.556 .05939 Mdot
.556 .05947 Mdot
.556 .05947 Mdot
.556 .05949 Mdot
.556 .05958 Mdot
.556 .05974 Mdot
.556 .05975 Mdot
.556 .05995 Mdot
.556 .06031 Mdot
.556 .06052 Mdot
.556 .06059 Mdot
.556 .06066 Mdot
.556 .06075 Mdot
.556 .061 Mdot
.556 .06106 Mdot
.556 .06107 Mdot
.556 .06124 Mdot
.556 .0613 Mdot
.556 .06132 Mdot
.556 .06154 Mdot
.556 .06174 Mdot
.556 .06174 Mdot
.556 .06196 Mdot
.556 .06223 Mdot
.556 .06238 Mdot
.556 .06247 Mdot
.556 .06249 Mdot
.556 .06294 Mdot
.556 .06344 Mdot
.556 .06362 Mdot
.556 .06428 Mdot
.556 .06428 Mdot
.556 .06439 Mdot
.556 .06448 Mdot
.556 .06449 Mdot
.556 .06451 Mdot
.556 .0646 Mdot
.556 .06478 Mdot
.556 .0648 Mdot
.556 .06502 Mdot
.556 .06541 Mdot
.556 .06565 Mdot
.556 .06573 Mdot
.556 .0658 Mdot
.556 .06591 Mdot
.556 .06619 Mdot
.556 .06625 Mdot
.556 .06626 Mdot
.556 .06637 Mdot
.556 .06646 Mdot
.556 .06652 Mdot
.556 .06654 Mdot
.556 .06679 Mdot
.556 .067 Mdot
.556 .06701 Mdot
.556 .06725 Mdot
.556 .06756 Mdot
.556 .06772 Mdot
.556 .06782 Mdot
.556 .06784 Mdot
.556 .06835 Mdot
.556 .06889 Mdot
.556 .0691 Mdot
.556 .06983 Mdot
.556 .06983 Mdot
.556 .06995 Mdot
.556 .07005 Mdot
.556 .07006 Mdot
.556 .07008 Mdot
.556 .07019 Mdot
.556 .07039 Mdot
.556 .0704 Mdot
.556 .07065 Mdot
.556 .07109 Mdot
.556 .07136 Mdot
.556 .07145 Mdot
.556 .07153 Mdot
.556 .07164 Mdot
.556 .07195 Mdot
.556 .07202 Mdot
.556 .07203 Mdot
.556 .07215 Mdot
.556 .07225 Mdot
.556 .07232 Mdot
.556 .07235 Mdot
.556 .07262 Mdot
.556 .07286 Mdot
.556 .07286 Mdot
.556 .07314 Mdot
.556 .07348 Mdot
.556 .07365 Mdot
.556 .07376 Mdot
.556 .07379 Mdot
.556 .07435 Mdot
.556 .07496 Mdot
.556 .07519 Mdot
.556 .076 Mdot
.556 .07601 Mdot
.556 .07614 Mdot
.556 .07625 Mdot
.556 .07626 Mdot
.556 .07628 Mdot
.556 .07641 Mdot
.556 .07663 Mdot
.556 .07664 Mdot
.556 .07692 Mdot
.556 .0774 Mdot
.556 .0777 Mdot
.556 .0778 Mdot
.556 .07789 Mdot
.556 .07802 Mdot
.556 .07836 Mdot
.556 .07843 Mdot
.556 .07845 Mdot
.556 .07859 Mdot
.556 .07869 Mdot
.556 .07877 Mdot
.556 .0788 Mdot
.556 .07911 Mdot
.556 .07937 Mdot
.556 .07938 Mdot
.556 .07968 Mdot
.556 .08006 Mdot
.556 .08025 Mdot
.556 .08038 Mdot
.556 .08041 Mdot
.556 .08103 Mdot
.556 .08171 Mdot
.556 .08197 Mdot
.556 .08287 Mdot
.556 .08287 Mdot
.556 .08302 Mdot
.556 .08314 Mdot
.556 .08315 Mdot
.556 .08318 Mdot
.556 .08331 Mdot
.556 .08356 Mdot
.556 .08358 Mdot
.556 .08389 Mdot
.556 .08442 Mdot
.556 .08475 Mdot
.556 .08487 Mdot
.556 .08496 Mdot
.556 .08511 Mdot
.556 .08549 Mdot
.556 .08557 Mdot
.556 .08559 Mdot
.556 .08574 Mdot
.556 .08586 Mdot
.556 .08595 Mdot
.556 .08598 Mdot
.556 .08632 Mdot
.556 .08661 Mdot
.556 .08662 Mdot
.556 .08696 Mdot
.556 .08737 Mdot
.556 .08759 Mdot
.556 .08773 Mdot
.556 .08776 Mdot
.556 .08846 Mdot
.556 .08921 Mdot
.556 .0895 Mdot
.556 .0905 Mdot
.556 .09051 Mdot
.556 .09067 Mdot
.556 .0908 Mdot
.556 .09082 Mdot
.556 .09085 Mdot
.556 .091 Mdot
.556 .09127 Mdot
.556 .09129 Mdot
.556 .09163 Mdot
.556 .09223 Mdot
.556 .0926 Mdot
.556 .09272 Mdot
.556 .09283 Mdot
.556 .09299 Mdot
.556 .09342 Mdot
.556 .09351 Mdot
.556 .09353 Mdot
.556 .09369 Mdot
.556 .09383 Mdot
.556 .09392 Mdot
.556 .09396 Mdot
.556 .09434 Mdot
.556 .09466 Mdot
.556 .09467 Mdot
.556 .09505 Mdot
.556 .09551 Mdot
.556 .09576 Mdot
.556 .09591 Mdot
.556 .09594 Mdot
.556 .09672 Mdot
.556 .09756 Mdot
.556 .09787 Mdot
.556 .09899 Mdot
.556 .09899 Mdot
.556 .09918 Mdot
.556 .09933 Mdot
.556 .09934 Mdot
.556 .09937 Mdot
.556 .09954 Mdot
.556 .09984 Mdot
.556 .09987 Mdot
.556 .10025 Mdot
.556 .10091 Mdot
.556 .10132 Mdot
.556 .10146 Mdot
.556 .10158 Mdot
.556 .10176 Mdot
.556 .10223 Mdot
.556 .10233 Mdot
.556 .10236 Mdot
.556 .10254 Mdot
.556 .10269 Mdot
.556 .10279 Mdot
.556 .10284 Mdot
.556 .10326 Mdot
.556 .10362 Mdot
.556 .10363 Mdot
.556 .10405 Mdot
.556 .10456 Mdot
.556 .10483 Mdot
.556 .105 Mdot
.556 .10504 Mdot
.556 .1059 Mdot
.556 .10684 Mdot
.556 .10719 Mdot
.556 .10842 Mdot
.556 .10843 Mdot
.556 .10864 Mdot
.556 .1088 Mdot
.556 .10882 Mdot
.556 .10885 Mdot
.556 .10904 Mdot
.556 .10938 Mdot
.556 .1094 Mdot
.556 .10983 Mdot
.556 .11057 Mdot
.556 .11102 Mdot
.556 .11118 Mdot
.556 .11131 Mdot
.556 .11151 Mdot
.556 .11204 Mdot
.556 .11215 Mdot
.556 .11217 Mdot
.556 .11238 Mdot
.556 .11254 Mdot
.556 .11266 Mdot
.556 .11271 Mdot
.556 .11317 Mdot
.556 .11357 Mdot
.556 .11359 Mdot
.556 .11405 Mdot
.556 .11463 Mdot
.556 .11493 Mdot
.556 .11511 Mdot
.556 .11516 Mdot
.556 .11612 Mdot
.556 .11715 Mdot
.556 .11754 Mdot
.556 .11892 Mdot
.556 .11893 Mdot
.556 .11916 Mdot
.556 .11934 Mdot
.556 .11936 Mdot
.556 .1194 Mdot
.556 .11961 Mdot
.556 .11998 Mdot
.556 .12001 Mdot
.556 .12048 Mdot
.556 .1213 Mdot
.556 .12181 Mdot
.556 .12198 Mdot
.556 .12213 Mdot
.556 .12235 Mdot
.556 .12294 Mdot
.556 .12306 Mdot
.556 .12309 Mdot
.556 .12331 Mdot
.556 .1235 Mdot
.556 .12363 Mdot
.556 .12368 Mdot
.556 .1242 Mdot
.556 .12465 Mdot
.556 .12466 Mdot
.556 .12518 Mdot
.556 .12581 Mdot
.556 .12615 Mdot
.556 .12636 Mdot
.556 .12641 Mdot
.556 .12747 Mdot
.556 .12863 Mdot
.556 .12906 Mdot
.556 .13059 Mdot
.556 .1306 Mdot
.556 .13085 Mdot
.556 .13106 Mdot
.556 .13108 Mdot
.556 .13112 Mdot
.556 .13135 Mdot
.556 .13177 Mdot
.556 .1318 Mdot
.556 .13233 Mdot
.556 .13324 Mdot
.556 .1338 Mdot
.556 .13399 Mdot
.556 .13416 Mdot
.556 .1344 Mdot
.556 .13506 Mdot
.556 .13519 Mdot
.556 .13522 Mdot
.556 .13548 Mdot
.556 .13568 Mdot
.556 .13583 Mdot
.556 .13589 Mdot
.556 .13646 Mdot
.556 .13696 Mdot
.556 .13697 Mdot
.556 .13755 Mdot
.556 .13826 Mdot
.556 .13863 Mdot
.556 .13886 Mdot
.556 .13892 Mdot
.556 .1401 Mdot
.556 .14138 Mdot
.556 .14187 Mdot
.556 .14357 Mdot
.556 .14358 Mdot
.556 .14386 Mdot
.556 .14409 Mdot
.556 .14411 Mdot
.556 .14416 Mdot
.556 .14442 Mdot
.556 .14488 Mdot
.556 .14491 Mdot
.556 .1455 Mdot
.556 .14652 Mdot
.556 .14714 Mdot
.556 .14735 Mdot
.556 .14754 Mdot
.556 .14781 Mdot
.556 .14853 Mdot
.556 .14868 Mdot
.556 .14872 Mdot
.556 .149 Mdot
.556 .14923 Mdot
.556 .14939 Mdot
.556 .14946 Mdot
.556 .1501 Mdot
.556 .15065 Mdot
.556 .15067 Mdot
.556 .15131 Mdot
.556 .1521 Mdot
.556 .15251 Mdot
.556 .15277 Mdot
.556 .15283 Mdot
.556 .15415 Mdot
.556 .15557 Mdot
.556 .15611 Mdot
.556 .158 Mdot
.556 .15801 Mdot
.556 .15832 Mdot
.556 .15858 Mdot
.556 .1586 Mdot
.556 .15866 Mdot
.556 .15894 Mdot
.556 .15946 Mdot
.556 .1595 Mdot
.556 .16015 Mdot
.556 .16128 Mdot
.556 .16197 Mdot
.556 .16221 Mdot
.556 .16241 Mdot
.556 .16272 Mdot
.556 .16352 Mdot
.556 .16369 Mdot
.556 .16373 Mdot
.556 .16404 Mdot
.556 .1643 Mdot
.556 .16448 Mdot
.556 .16455 Mdot
.556 .16526 Mdot
.556 .16587 Mdot
.556 .16589 Mdot
.556 .16661 Mdot
.556 .16748 Mdot
.556 .16794 Mdot
.556 .16823 Mdot
.556 .1683 Mdot
.556 .16976 Mdot
.556 .17135 Mdot
.556 .17195 Mdot
.556 .17405 Mdot
.556 .17406 Mdot
.556 .17441 Mdot
.556 .17469 Mdot
.556 .17472 Mdot
.556 .17478 Mdot
.556 .1751 Mdot
.556 .17567 Mdot
.556 .17571 Mdot
.556 .17643 Mdot
.556 .17769 Mdot
.556 .17846 Mdot
.556 .17873 Mdot
.556 .17896 Mdot
.556 .17929 Mdot
.556 .18019 Mdot
.556 .18037 Mdot
.556 .18042 Mdot
.556 .18077 Mdot
.556 .18105 Mdot
.556 .18125 Mdot
.556 .18133 Mdot
.556 .18212 Mdot
.556 .1828 Mdot
.556 .18282 Mdot
.556 .18362 Mdot
.556 .18459 Mdot
.556 .18511 Mdot
.556 .18542 Mdot
.556 .1855 Mdot
.556 .18713 Mdot
.556 .18889 Mdot
.556 .18956 Mdot
.556 .19189 Mdot
.556 .19191 Mdot
.556 .19229 Mdot
.556 .19261 Mdot
.556 .19264 Mdot
.556 .19271 Mdot
.556 .19306 Mdot
.556 .1937 Mdot
.556 .19374 Mdot
.556 .19455 Mdot
.556 .19595 Mdot
.556 .1968 Mdot
.556 .1971 Mdot
.556 .19735 Mdot
.556 .19772 Mdot
.556 .19872 Mdot
.556 .19893 Mdot
.556 .19898 Mdot
.556 .19937 Mdot
.556 .19968 Mdot
.556 .1999 Mdot
.556 .2 Mdot
.556 .20087 Mdot
.556 .20163 Mdot
.556 .20165 Mdot
.556 .20254 Mdot
.556 .20362 Mdot
.556 .20419 Mdot
.556 .20454 Mdot
.556 .20463 Mdot
.556 .20644 Mdot
.556 .2084 Mdot
.556 .20914 Mdot
.556 .21174 Mdot
.556 .21176 Mdot
.556 .21218 Mdot
.556 .21253 Mdot
.556 .21257 Mdot
.556 .21264 Mdot
.556 .21304 Mdot
.556 .21374 Mdot
.556 .21379 Mdot
.556 .21469 Mdot
.556 .21625 Mdot
.556 .2172 Mdot
.556 .21752 Mdot
.556 .21781 Mdot
.556 .21822 Mdot
.556 .21933 Mdot
.556 .21956 Mdot
.556 .21961 Mdot
.556 .22005 Mdot
.556 .2204 Mdot
.556 .22064 Mdot
.556 .22075 Mdot
.556 .22172 Mdot
.556 .22257 Mdot
.556 .22259 Mdot
.556 .22357 Mdot
.556 .22477 Mdot
.556 .22541 Mdot
.556 .2258 Mdot
.556 .2259 Mdot
.556 .22791 Mdot
.556 .23009 Mdot
.556 .23091 Mdot
.556 .2338 Mdot
.556 .23382 Mdot
.556 .2343 Mdot
.556 .23469 Mdot
.556 .23473 Mdot
.556 .23481 Mdot
.556 .23525 Mdot
.556 .23604 Mdot
.556 .23609 Mdot
.556 .23708 Mdot
.556 .23882 Mdot
.556 .23988 Mdot
.556 .24024 Mdot
.556 .24055 Mdot
.556 .24101 Mdot
.556 .24225 Mdot
.556 .2425 Mdot
.556 .24256 Mdot
.556 .24304 Mdot
.556 .24343 Mdot
.556 .24371 Mdot
.556 .24382 Mdot
.556 .24491 Mdot
.556 .24584 Mdot
.556 .24587 Mdot
.556 .24696 Mdot
.556 .2483 Mdot
.556 .24901 Mdot
.556 .24944 Mdot
.556 .24955 Mdot
.556 .25179 Mdot
.556 .25421 Mdot
.556 .25513 Mdot
.556 .25834 Mdot
.556 .25837 Mdot
.556 .25889 Mdot
.556 .25932 Mdot
.556 .25937 Mdot
.556 .25946 Mdot
.556 .25995 Mdot
.556 .26082 Mdot
.556 .26089 Mdot
.556 .26199 Mdot
.556 .26392 Mdot
.556 .26509 Mdot
.556 .26549 Mdot
.556 .26585 Mdot
.556 .26636 Mdot
.556 .26773 Mdot
.556 .26802 Mdot
.556 .26808 Mdot
.556 .26862 Mdot
.556 .26905 Mdot
.556 .26935 Mdot
.556 .26948 Mdot
.556 .27069 Mdot
.556 .27173 Mdot
.556 .27176 Mdot
.556 .27297 Mdot
.556 .27446 Mdot
.556 .27525 Mdot
.556 .27573 Mdot
.556 .27585 Mdot
.556 .27834 Mdot
.556 .28104 Mdot
.556 .28205 Mdot
.556 .28563 Mdot
.556 .28565 Mdot
.556 .28624 Mdot
.556 .28672 Mdot
.556 .28677 Mdot
.556 .28687 Mdot
.556 .28741 Mdot
.556 .28839 Mdot
.556 .28846 Mdot
.556 .28968 Mdot
.556 .29183 Mdot
.556 .29314 Mdot
.556 .29358 Mdot
.556 .29397 Mdot
.556 .29454 Mdot
.556 .29607 Mdot
.556 .29639 Mdot
.556 .29646 Mdot
.556 .29705 Mdot
.556 .29753 Mdot
.556 .29787 Mdot
.556 .29802 Mdot
.556 .29936 Mdot
.556 .30052 Mdot
.556 .30055 Mdot
.556 .3019 Mdot
.556 .30355 Mdot
.556 .30443 Mdot
.556 .30496 Mdot
.556 .3051 Mdot
.556 .30787 Mdot
.556 .31087 Mdot
.556 .312 Mdot
.556 .31597 Mdot
.556 .316 Mdot
.556 .31665 Mdot
.556 .31718 Mdot
.556 .31724 Mdot
.556 .31735 Mdot
.556 .31795 Mdot
.556 .31904 Mdot
.556 .31912 Mdot
.556 .32048 Mdot
.556 .32286 Mdot
.556 .32432 Mdot
.556 .32481 Mdot
.556 .32525 Mdot
.556 .32588 Mdot
.556 .32758 Mdot
.556 .32793 Mdot
.556 .32801 Mdot
.556 .32867 Mdot
.556 .32921 Mdot
.556 .32959 Mdot
.556 .32975 Mdot
.556 .33124 Mdot
.556 .33253 Mdot
.556 .33256 Mdot
.556 .33406 Mdot
.556 .3359 Mdot
.556 .33688 Mdot
.556 .33747 Mdot
.556 .33762 Mdot
.556 .3407 Mdot
.558 .01586 Mdot
.558 .01592 Mdot
.558 .016 Mdot
.558 .01607 Mdot
.558 .01615 Mdot
.558 .01622 Mdot
.558 .01631 Mdot
.558 .0164 Mdot
.558 .0165 Mdot
.558 .01659 Mdot
.558 .01671 Mdot
.558 .01681 Mdot
.558 .01694 Mdot
.558 .01705 Mdot
.558 .01715 Mdot
.558 .01719 Mdot
.558 .01732 Mdot
.558 .01743 Mdot
.558 .01748 Mdot
.558 .01763 Mdot
.558 .01775 Mdot
.558 .0178 Mdot
.558 .01796 Mdot
.558 .01801 Mdot
.558 .0181 Mdot
.558 .01816 Mdot
.558 .01834 Mdot
.558 .01839 Mdot
.558 .01849 Mdot
.558 .01856 Mdot
.558 .01876 Mdot
.558 .01882 Mdot
.558 .01893 Mdot
.558 .01901 Mdot
.558 .01923 Mdot
.558 .0193 Mdot
.558 .01942 Mdot
.558 .0195 Mdot
.558 .01975 Mdot
.558 .01983 Mdot
.558 .01997 Mdot
.558 .02006 Mdot
.558 .02034 Mdot
.558 .02042 Mdot
.558 .02053 Mdot
.558 .02058 Mdot
.558 .02068 Mdot
.558 .02099 Mdot
.558 .02108 Mdot
.558 .0212 Mdot
.558 .02125 Mdot
.558 .02137 Mdot
.558 .02172 Mdot
.558 .02182 Mdot
.558 .02182 Mdot
.558 .02195 Mdot
.558 .02201 Mdot
.558 .02214 Mdot
.558 .02225 Mdot
.558 .02253 Mdot
.558 .02265 Mdot
.558 .02265 Mdot
.558 .0227 Mdot
.558 .02279 Mdot
.558 .02286 Mdot
.558 .023 Mdot
.558 .02312 Mdot
.558 .02344 Mdot
.558 .02357 Mdot
.558 .02357 Mdot
.558 .02363 Mdot
.558 .02373 Mdot
.558 .0238 Mdot
.558 .02397 Mdot
.558 .0241 Mdot
.558 .02445 Mdot
.558 .02459 Mdot
.558 .0246 Mdot
.558 .02466 Mdot
.558 .02473 Mdot
.558 .02477 Mdot
.558 .02486 Mdot
.558 .02504 Mdot
.558 .02518 Mdot
.558 .02558 Mdot
.558 .02574 Mdot
.558 .02574 Mdot
.558 .02581 Mdot
.558 .0259 Mdot
.558 .02594 Mdot
.558 .02604 Mdot
.558 .02624 Mdot
.558 .0264 Mdot
.558 .02646 Mdot
.558 .02684 Mdot
.558 .02702 Mdot
.558 .02702 Mdot
.558 .0271 Mdot
.558 .02719 Mdot
.558 .02724 Mdot
.558 .02735 Mdot
.558 .02757 Mdot
.558 .02764 Mdot
.558 .02775 Mdot
.558 .02782 Mdot
.558 .02796 Mdot
.558 .02824 Mdot
.558 .02845 Mdot
.558 .02845 Mdot
.558 .02854 Mdot
.558 .02864 Mdot
.558 .02869 Mdot
.558 .02881 Mdot
.558 .02906 Mdot
.558 .02913 Mdot
.558 .02927 Mdot
.558 .02934 Mdot
.558 .02949 Mdot
.558 .02963 Mdot
.558 .02975 Mdot
.558 .02981 Mdot
.558 .02996 Mdot
.558 .03004 Mdot
.558 .03004 Mdot
.558 .03014 Mdot
.558 .03026 Mdot
.558 .03032 Mdot
.558 .03045 Mdot
.558 .03068 Mdot
.558 .03073 Mdot
.558 .03073 Mdot
.558 .03081 Mdot
.558 .03095 Mdot
.558 .03104 Mdot
.558 .03121 Mdot
.558 .03136 Mdot
.558 .0315 Mdot
.558 .03156 Mdot
.558 .03173 Mdot
.558 .03182 Mdot
.558 .03182 Mdot
.558 .03193 Mdot
.558 .03206 Mdot
.558 .03213 Mdot
.558 .03228 Mdot
.558 .03244 Mdot
.558 .03253 Mdot
.558 .03258 Mdot
.558 .03259 Mdot
.558 .03267 Mdot
.558 .03284 Mdot
.558 .03293 Mdot
.558 .03312 Mdot
.558 .03329 Mdot
.558 .03344 Mdot
.558 .03352 Mdot
.558 .0337 Mdot
.558 .0338 Mdot
.558 .03381 Mdot
.558 .03393 Mdot
.558 .03407 Mdot
.558 .03415 Mdot
.558 .03431 Mdot
.558 .0345 Mdot
.558 .0346 Mdot
.558 .03461 Mdot
.558 .03466 Mdot
.558 .03466 Mdot
.558 .03476 Mdot
.558 .03494 Mdot
.558 .03505 Mdot
.558 .03525 Mdot
.558 .03545 Mdot
.558 .0356 Mdot
.558 .03562 Mdot
.558 .0357 Mdot
.558 .0359 Mdot
.558 .03602 Mdot
.558 .03602 Mdot
.558 .03615 Mdot
.558 .03632 Mdot
.558 .0364 Mdot
.558 .03659 Mdot
.558 .03679 Mdot
.558 .0369 Mdot
.558 .03692 Mdot
.558 .03697 Mdot
.558 .03697 Mdot
.558 .03708 Mdot
.558 .03729 Mdot
.558 .0374 Mdot
.558 .03745 Mdot
.558 .03764 Mdot
.558 .03785 Mdot
.558 .03803 Mdot
.558 .03804 Mdot
.558 .03814 Mdot
.558 .03814 Mdot
.558 .03836 Mdot
.558 .03849 Mdot
.558 .03849 Mdot
.558 .03864 Mdot
.558 .03882 Mdot
.558 .03891 Mdot
.558 .03912 Mdot
.558 .03935 Mdot
.558 .03947 Mdot
.558 .0395 Mdot
.558 .03955 Mdot
.558 .03955 Mdot
.558 .03968 Mdot
.558 .0399 Mdot
.558 .04004 Mdot
.558 .04009 Mdot
.558 .0403 Mdot
.558 .04054 Mdot
.558 .04073 Mdot
.558 .04075 Mdot
.558 .04085 Mdot
.558 .04086 Mdot
.558 .04111 Mdot
.558 .04124 Mdot
.558 .04125 Mdot
.558 .04142 Mdot
.558 .04162 Mdot
.558 .04172 Mdot
.558 .04176 Mdot
.558 .04195 Mdot
.558 .04221 Mdot
.558 .04235 Mdot
.558 .04236 Mdot
.558 .04237 Mdot
.558 .04243 Mdot
.558 .04243 Mdot
.558 .04257 Mdot
.558 .04283 Mdot
.558 .04297 Mdot
.558 .04303 Mdot
.558 .04326 Mdot
.558 .04337 Mdot
.558 .04353 Mdot
.558 .04375 Mdot
.558 .04377 Mdot
.558 .04388 Mdot
.558 .04389 Mdot
.558 .04417 Mdot
.558 .04432 Mdot
.558 .04433 Mdot
.558 .04444 Mdot
.558 .04451 Mdot
.558 .04474 Mdot
.558 .04485 Mdot
.558 .04489 Mdot
.558 .04511 Mdot
.558 .0454 Mdot
.558 .04555 Mdot
.558 .04556 Mdot
.558 .04558 Mdot
.558 .04565 Mdot
.558 .04565 Mdot
.558 .0458 Mdot
.558 .04609 Mdot
.558 .04625 Mdot
.558 .04631 Mdot
.558 .04657 Mdot
.558 .04669 Mdot
.558 .04678 Mdot
.558 .04688 Mdot
.558 .04709 Mdot
.558 .04711 Mdot
.558 .04712 Mdot
.558 .04714 Mdot
.558 .04727 Mdot
.558 .04728 Mdot
.558 .04734 Mdot
.558 .04758 Mdot
.558 .04776 Mdot
.558 .04776 Mdot
.558 .04788 Mdot
.558 .04797 Mdot
.558 .04822 Mdot
.558 .04835 Mdot
.558 .04839 Mdot
.558 .04864 Mdot
.558 .04881 Mdot
.558 .04893 Mdot
.558 .04896 Mdot
.558 .04913 Mdot
.558 .04914 Mdot
.558 .04916 Mdot
.558 .04923 Mdot
.558 .04924 Mdot
.558 .04941 Mdot
.558 .04963 Mdot
.558 .04973 Mdot
.558 .04991 Mdot
.558 .04998 Mdot
.558 .05027 Mdot
.558 .0504 Mdot
.558 .0505 Mdot
.558 .05061 Mdot
.558 .05084 Mdot
.558 .05087 Mdot
.558 .05087 Mdot
.558 .0509 Mdot
.558 .05104 Mdot
.558 .05106 Mdot
.558 .05112 Mdot
.558 .0514 Mdot
.558 .05159 Mdot
.558 .0516 Mdot
.558 .05173 Mdot
.558 .05183 Mdot
.558 .05211 Mdot
.558 .05225 Mdot
.558 .0523 Mdot
.558 .05235 Mdot
.558 .05258 Mdot
.558 .05277 Mdot
.558 .0529 Mdot
.558 .05294 Mdot
.558 .05312 Mdot
.558 .05314 Mdot
.558 .05316 Mdot
.558 .05324 Mdot
.558 .05324 Mdot
.558 .05343 Mdot
.558 .05368 Mdot
.558 .05379 Mdot
.558 .05399 Mdot
.558 .05407 Mdot
.558 .05439 Mdot
.558 .05454 Mdot
.558 .05465 Mdot
.558 .05477 Mdot
.558 .05503 Mdot
.558 .05507 Mdot
.558 .05507 Mdot
.558 .05509 Mdot
.558 .05526 Mdot
.558 .05527 Mdot
.558 .05535 Mdot
.558 .05565 Mdot
.558 .05587 Mdot
.558 .05587 Mdot
.558 .05603 Mdot
.558 .05613 Mdot
.558 .05645 Mdot
.558 .05661 Mdot
.558 .05666 Mdot
.558 .05672 Mdot
.558 .05697 Mdot
.558 .05718 Mdot
.558 .05733 Mdot
.558 .05737 Mdot
.558 .05758 Mdot
.558 .05759 Mdot
.558 .05762 Mdot
.558 .05771 Mdot
.558 .05771 Mdot
.558 .05793 Mdot
.558 .0582 Mdot
.558 .05832 Mdot
.558 .05855 Mdot
.558 .05863 Mdot
.558 .059 Mdot
.558 .05916 Mdot
.558 .05928 Mdot
.558 .05942 Mdot
.558 .05971 Mdot
.558 .05975 Mdot
.558 .05975 Mdot
.558 .05978 Mdot
.558 .05996 Mdot
.558 .05998 Mdot
.558 .06006 Mdot
.558 .0604 Mdot
.558 .06064 Mdot
.558 .06065 Mdot
.558 .06082 Mdot
.558 .06094 Mdot
.558 .06129 Mdot
.558 .06147 Mdot
.558 .06152 Mdot
.558 .06159 Mdot
.558 .06187 Mdot
.558 .06211 Mdot
.558 .06227 Mdot
.558 .06232 Mdot
.558 .06255 Mdot
.558 .06257 Mdot
.558 .06259 Mdot
.558 .06269 Mdot
.558 .0627 Mdot
.558 .06294 Mdot
.558 .06324 Mdot
.558 .06338 Mdot
.558 .06363 Mdot
.558 .06373 Mdot
.558 .06413 Mdot
.558 .06431 Mdot
.558 .06445 Mdot
.558 .0646 Mdot
.558 .06493 Mdot
.558 .06497 Mdot
.558 .06497 Mdot
.558 .065 Mdot
.558 .06521 Mdot
.558 .06523 Mdot
.558 .06532 Mdot
.558 .0657 Mdot
.558 .06597 Mdot
.558 .06598 Mdot
.558 .06617 Mdot
.558 .0663 Mdot
.558 .06669 Mdot
.558 .06689 Mdot
.558 .06695 Mdot
.558 .06702 Mdot
.558 .06734 Mdot
.558 .06761 Mdot
.558 .06779 Mdot
.558 .06784 Mdot
.558 .0681 Mdot
.558 .06812 Mdot
.558 .06815 Mdot
.558 .06826 Mdot
.558 .06827 Mdot
.558 .06853 Mdot
.558 .06887 Mdot
.558 .06902 Mdot
.558 .06931 Mdot
.558 .06941 Mdot
.558 .06987 Mdot
.558 .07007 Mdot
.558 .07022 Mdot
.558 .07039 Mdot
.558 .07075 Mdot
.558 .0708 Mdot
.558 .0708 Mdot
.558 .07084 Mdot
.558 .07107 Mdot
.558 .07108 Mdot
.558 .07119 Mdot
.558 .07161 Mdot
.558 .07191 Mdot
.558 .07192 Mdot
.558 .07213 Mdot
.558 .07228 Mdot
.558 .07272 Mdot
.558 .07294 Mdot
.558 .07301 Mdot
.558 .07309 Mdot
.558 .07344 Mdot
.558 .07374 Mdot
.558 .07395 Mdot
.558 .074 Mdot
.558 .07429 Mdot
.558 .07431 Mdot
.558 .07435 Mdot
.558 .07447 Mdot
.558 .07448 Mdot
.558 .07478 Mdot
.558 .07515 Mdot
.558 .07532 Mdot
.558 .07564 Mdot
.558 .07576 Mdot
.558 .07626 Mdot
.558 .07649 Mdot
.558 .07666 Mdot
.558 .07685 Mdot
.558 .07725 Mdot
.558 .0773 Mdot
.558 .07731 Mdot
.558 .07735 Mdot
.558 .0776 Mdot
.558 .07762 Mdot
.558 .07774 Mdot
.558 .07821 Mdot
.558 .07855 Mdot
.558 .07856 Mdot
.558 .07879 Mdot
.558 .07896 Mdot
.558 .07944 Mdot
.558 .0797 Mdot
.558 .07978 Mdot
.558 .07986 Mdot
.558 .08026 Mdot
.558 .08059 Mdot
.558 .08082 Mdot
.558 .08088 Mdot
.558 .0812 Mdot
.558 .08122 Mdot
.558 .08126 Mdot
.558 .0814 Mdot
.558 .08141 Mdot
.558 .08174 Mdot
.558 .08216 Mdot
.558 .08235 Mdot
.558 .08271 Mdot
.558 .08284 Mdot
.558 .0834 Mdot
.558 .08365 Mdot
.558 .08385 Mdot
.558 .08405 Mdot
.558 .08451 Mdot
.558 .08457 Mdot
.558 .08457 Mdot
.558 .08461 Mdot
.558 .0849 Mdot
.558 .08492 Mdot
.558 .08505 Mdot
.558 .08558 Mdot
.558 .08595 Mdot
.558 .08596 Mdot
.558 .08623 Mdot
.558 .08641 Mdot
.558 .08695 Mdot
.558 .08723 Mdot
.558 .08732 Mdot
.558 .08742 Mdot
.558 .08786 Mdot
.558 .08823 Mdot
.558 .08848 Mdot
.558 .08855 Mdot
.558 .08891 Mdot
.558 .08894 Mdot
.558 .08898 Mdot
.558 .08914 Mdot
.558 .08915 Mdot
.558 .08952 Mdot
.558 .08998 Mdot
.558 .0902 Mdot
.558 .09059 Mdot
.558 .09074 Mdot
.558 .09137 Mdot
.558 .09152 Mdot
.558 .09165 Mdot
.558 .09187 Mdot
.558 .0921 Mdot
.558 .0926 Mdot
.558 .09267 Mdot
.558 .09267 Mdot
.558 .09272 Mdot
.558 .09304 Mdot
.558 .09306 Mdot
.558 .09321 Mdot
.558 .0938 Mdot
.558 .09421 Mdot
.558 .09423 Mdot
.558 .09452 Mdot
.558 .09473 Mdot
.558 .09533 Mdot
.558 .09565 Mdot
.558 .09575 Mdot
.558 .09586 Mdot
.558 .09634 Mdot
.558 .09676 Mdot
.558 .09704 Mdot
.558 .09712 Mdot
.558 .09752 Mdot
.558 .09755 Mdot
.558 .0976 Mdot
.558 .09777 Mdot
.558 .09778 Mdot
.558 .09819 Mdot
.558 .09872 Mdot
.558 .09895 Mdot
.558 .0994 Mdot
.558 .09956 Mdot
.558 .10026 Mdot
.558 .10043 Mdot
.558 .10057 Mdot
.558 .10082 Mdot
.558 .10107 Mdot
.558 .10164 Mdot
.558 .10171 Mdot
.558 .10172 Mdot
.558 .10177 Mdot
.558 .10212 Mdot
.558 .10215 Mdot
.558 .10232 Mdot
.558 .10297 Mdot
.558 .10344 Mdot
.558 .10345 Mdot
.558 .10378 Mdot
.558 .10401 Mdot
.558 .10469 Mdot
.558 .10503 Mdot
.558 .10515 Mdot
.558 .10527 Mdot
.558 .10581 Mdot
.558 .10628 Mdot
.558 .10659 Mdot
.558 .10668 Mdot
.558 .10713 Mdot
.558 .10716 Mdot
.558 .10721 Mdot
.558 .10741 Mdot
.558 .10742 Mdot
.558 .10788 Mdot
.558 .10846 Mdot
.558 .10872 Mdot
.558 .10922 Mdot
.558 .10941 Mdot
.558 .11019 Mdot
.558 .11037 Mdot
.558 .11053 Mdot
.558 .11081 Mdot
.558 .11109 Mdot
.558 .11172 Mdot
.558 .1118 Mdot
.558 .11181 Mdot
.558 .11187 Mdot
.558 .11226 Mdot
.558 .1123 Mdot
.558 .11248 Mdot
.558 .11321 Mdot
.558 .11373 Mdot
.558 .11375 Mdot
.558 .11411 Mdot
.558 .11437 Mdot
.558 .11512 Mdot
.558 .11551 Mdot
.558 .11564 Mdot
.558 .11577 Mdot
.558 .11638 Mdot
.558 .1169 Mdot
.558 .11725 Mdot
.558 .11734 Mdot
.558 .11784 Mdot
.558 .11788 Mdot
.558 .11794 Mdot
.558 .11816 Mdot
.558 .11817 Mdot
.558 .11868 Mdot
.558 .11933 Mdot
.558 .11963 Mdot
.558 .12018 Mdot
.558 .12039 Mdot
.558 .12126 Mdot
.558 .12147 Mdot
.558 .12165 Mdot
.558 .12195 Mdot
.558 .12227 Mdot
.558 .12297 Mdot
.558 .12306 Mdot
.558 .12307 Mdot
.558 .12314 Mdot
.558 .12358 Mdot
.558 .12362 Mdot
.558 .12382 Mdot
.558 .12464 Mdot
.558 .12521 Mdot
.558 .12523 Mdot
.558 .12564 Mdot
.558 .12593 Mdot
.558 .12677 Mdot
.558 .1272 Mdot
.558 .12734 Mdot
.558 .12749 Mdot
.558 .12817 Mdot
.558 .12875 Mdot
.558 .12914 Mdot
.558 .12925 Mdot
.558 .12981 Mdot
.558 .12985 Mdot
.558 .12992 Mdot
.558 .13016 Mdot
.558 .13017 Mdot
.558 .13075 Mdot
.558 .13147 Mdot
.558 .1318 Mdot
.558 .13242 Mdot
.558 .13265 Mdot
.558 .13362 Mdot
.558 .13385 Mdot
.558 .13405 Mdot
.558 .13439 Mdot
.558 .13475 Mdot
.558 .13553 Mdot
.558 .13563 Mdot
.558 .13564 Mdot
.558 .13572 Mdot
.558 .13621 Mdot
.558 .13625 Mdot
.558 .13648 Mdot
.558 .13739 Mdot
.558 .13803 Mdot
.558 .13805 Mdot
.558 .13851 Mdot
.558 .13883 Mdot
.558 .13977 Mdot
.558 .14025 Mdot
.558 .14041 Mdot
.558 .14058 Mdot
.558 .14133 Mdot
.558 .14198 Mdot
.558 .14242 Mdot
.558 .14253 Mdot
.558 .14316 Mdot
.558 .1432 Mdot
.558 .14328 Mdot
.558 .14355 Mdot
.558 .14357 Mdot
.558 .14421 Mdot
.558 .14501 Mdot
.558 .14538 Mdot
.558 .14607 Mdot
.558 .14633 Mdot
.558 .14741 Mdot
.558 .14767 Mdot
.558 .1479 Mdot
.558 .14827 Mdot
.558 .14867 Mdot
.558 .14954 Mdot
.558 .14966 Mdot
.558 .14967 Mdot
.558 .14975 Mdot
.558 .1503 Mdot
.558 .15035 Mdot
.558 .1506 Mdot
.558 .15162 Mdot
.558 .15234 Mdot
.558 .15236 Mdot
.558 .15287 Mdot
.558 .15323 Mdot
.558 .15427 Mdot
.558 .15481 Mdot
.558 .15499 Mdot
.558 .15518 Mdot
.558 .15602 Mdot
.558 .15674 Mdot
.558 .15723 Mdot
.558 .15736 Mdot
.558 .15806 Mdot
.558 .15811 Mdot
.558 .15819 Mdot
.558 .15849 Mdot
.558 .15851 Mdot
.558 .15923 Mdot
.558 .16013 Mdot
.558 .16054 Mdot
.558 .16131 Mdot
.558 .1616 Mdot
.558 .16281 Mdot
.558 .1631 Mdot
.558 .16335 Mdot
.558 .16377 Mdot
.558 .16421 Mdot
.558 .16518 Mdot
.558 .16531 Mdot
.558 .16532 Mdot
.558 .16542 Mdot
.558 .16603 Mdot
.558 .16608 Mdot
.558 .16637 Mdot
.558 .1675 Mdot
.558 .1683 Mdot
.558 .16833 Mdot
.558 .1689 Mdot
.558 .1693 Mdot
.558 .17046 Mdot
.558 .17106 Mdot
.558 .17126 Mdot
.558 .17147 Mdot
.558 .17241 Mdot
.558 .17321 Mdot
.558 .17376 Mdot
.558 .17391 Mdot
.558 .17469 Mdot
.558 .17474 Mdot
.558 .17484 Mdot
.558 .17517 Mdot
.558 .17519 Mdot
.558 .17599 Mdot
.558 .177 Mdot
.558 .17746 Mdot
.558 .17831 Mdot
.558 .17863 Mdot
.558 .17999 Mdot
.558 .18031 Mdot
.558 .18059 Mdot
.558 .18106 Mdot
.558 .18155 Mdot
.558 .18264 Mdot
.558 .18278 Mdot
.558 .18279 Mdot
.558 .1829 Mdot
.558 .18358 Mdot
.558 .18364 Mdot
.558 .18396 Mdot
.558 .18522 Mdot
.558 .18612 Mdot
.558 .18615 Mdot
.558 .18678 Mdot
.558 .18723 Mdot
.558 .18853 Mdot
.558 .1892 Mdot
.558 .18942 Mdot
.558 .18965 Mdot
.558 .19071 Mdot
.558 .1916 Mdot
.558 .19221 Mdot
.558 .19237 Mdot
.558 .19324 Mdot
.558 .1933 Mdot
.558 .19341 Mdot
.558 .19378 Mdot
.558 .19381 Mdot
.558 .1947 Mdot
.558 .19582 Mdot
.558 .19633 Mdot
.558 .19729 Mdot
.558 .19765 Mdot
.558 .19916 Mdot
.558 .19952 Mdot
.558 .19983 Mdot
.558 .20035 Mdot
.558 .20091 Mdot
.558 .20212 Mdot
.558 .20228 Mdot
.558 .20229 Mdot
.558 .20241 Mdot
.558 .20317 Mdot
.558 .20323 Mdot
.558 .20359 Mdot
.558 .205 Mdot
.558 .206 Mdot
.558 .20603 Mdot
.558 .20674 Mdot
.558 .20724 Mdot
.558 .20869 Mdot
.558 .20944 Mdot
.558 .20969 Mdot
.558 .20995 Mdot
.558 .21112 Mdot
.558 .21212 Mdot
.558 .2128 Mdot
.558 .21298 Mdot
.558 .21395 Mdot
.558 .21402 Mdot
.558 .21414 Mdot
.558 .21456 Mdot
.558 .21458 Mdot
.558 .21557 Mdot
.558 .21683 Mdot
.558 .2174 Mdot
.558 .21847 Mdot
.558 .21887 Mdot
.558 .22055 Mdot
.558 .22095 Mdot
.558 .2213 Mdot
.558 .22189 Mdot
.558 .2225 Mdot
.558 .22386 Mdot
.558 .22403 Mdot
.558 .22405 Mdot
.558 .22418 Mdot
.558 .22503 Mdot
.558 .2251 Mdot
.558 .2255 Mdot
.558 .22707 Mdot
.558 .22819 Mdot
.558 .22823 Mdot
.558 .22902 Mdot
.558 .22957 Mdot
.558 .23119 Mdot
.558 .23203 Mdot
.558 .2323 Mdot
.558 .23259 Mdot
.558 .23391 Mdot
.558 .23502 Mdot
.558 .23578 Mdot
.558 .23598 Mdot
.558 .23706 Mdot
.558 .23714 Mdot
.558 .23727 Mdot
.558 .23774 Mdot
.558 .23777 Mdot
.558 .23887 Mdot
.558 .24027 Mdot
.558 .24091 Mdot
.558 .2421 Mdot
.558 .24255 Mdot
.558 .24443 Mdot
.558 .24488 Mdot
.558 .24527 Mdot
.558 .24592 Mdot
.558 .24661 Mdot
.558 .24812 Mdot
.558 .24831 Mdot
.558 .24833 Mdot
.558 .24848 Mdot
.558 .24943 Mdot
.558 .2495 Mdot
.558 .24995 Mdot
.558 .25171 Mdot
.558 .25295 Mdot
.558 .25299 Mdot
.558 .25388 Mdot
.558 .25449 Mdot
.558 .2563 Mdot
.558 .25724 Mdot
.558 .25754 Mdot
.558 .25787 Mdot
.558 .25933 Mdot
.558 .26057 Mdot
.558 .26142 Mdot
.558 .26165 Mdot
.558 .26286 Mdot
.558 .26294 Mdot
.558 .26309 Mdot
.558 .26361 Mdot
.558 .26364 Mdot
.558 .26488 Mdot
.558 .26644 Mdot
.558 .26715 Mdot
.558 .26848 Mdot
.558 .26898 Mdot
.558 .27108 Mdot
.558 .27158 Mdot
.558 .27201 Mdot
.558 .27274 Mdot
.558 .27351 Mdot
.558 .27519 Mdot
.558 .27541 Mdot
.558 .27543 Mdot
.558 .2756 Mdot
.558 .27666 Mdot
.558 .27674 Mdot
.558 .27724 Mdot
.558 .2792 Mdot
.558 .28059 Mdot
.558 .28063 Mdot
.558 .28162 Mdot
.558 .28231 Mdot
.558 .28433 Mdot
.558 .28537 Mdot
.558 .28571 Mdot
.558 .28607 Mdot
.558 .28771 Mdot
.558 .28909 Mdot
.558 .29004 Mdot
.558 .29029 Mdot
.558 .29164 Mdot
.558 .29174 Mdot
.558 .2919 Mdot
.558 .29248 Mdot
.558 .29252 Mdot
.558 .2939 Mdot
.558 .29564 Mdot
.558 .29643 Mdot
.558 .29792 Mdot
.558 .29847 Mdot
.558 .30137 Mdot
.558 .30186 Mdot
.558 .30267 Mdot
.558 .30353 Mdot
.558 .30541 Mdot
.558 .30565 Mdot
.558 .30568 Mdot
.558 .30586 Mdot
.558 .30704 Mdot
.558 .30713 Mdot
.558 .30769 Mdot
.558 .30988 Mdot
.558 .31143 Mdot
.558 .31148 Mdot
.558 .31258 Mdot
.558 .31335 Mdot
.558 .3156 Mdot
.558 .31677 Mdot
.558 .31715 Mdot
.558 .31755 Mdot
.558 .31937 Mdot
.558 .32092 Mdot
.558 .32197 Mdot
.558 .32226 Mdot
.558 .32376 Mdot
.558 .32387 Mdot
.558 .32406 Mdot
.558 .3247 Mdot
.558 .32474 Mdot
.558 .32628 Mdot
.558 .32823 Mdot
.558 .32911 Mdot
.558 .33077 Mdot
.558 .33139 Mdot
.558 .33463 Mdot
.558 .33516 Mdot
.558 .33607 Mdot
.558 .33703 Mdot
.558 .33913 Mdot
.558 .3394 Mdot
.558 .33943 Mdot
.558 .33963 Mdot
.558 .34095 Mdot
.558 .34106 Mdot
.558 .34168 Mdot
.558 .34412 Mdot
.56 .01501 Mdot
.56 .01505 Mdot
.56 .01509 Mdot
.56 .01514 Mdot
.56 .01519 Mdot
.56 .01524 Mdot
.56 .01531 Mdot
.56 .01538 Mdot
.56 .01546 Mdot
.56 .01554 Mdot
.56 .01564 Mdot
.56 .01568 Mdot
.56 .01576 Mdot
.56 .0158 Mdot
.56 .01588 Mdot
.56 .01592 Mdot
.56 .01602 Mdot
.56 .01607 Mdot
.56 .01618 Mdot
.56 .01618 Mdot
.56 .01623 Mdot
.56 .01629 Mdot
.56 .01635 Mdot
.56 .01635 Mdot
.56 .01641 Mdot
.56 .01648 Mdot
.56 .01655 Mdot
.56 .01655 Mdot
.56 .01662 Mdot
.56 .01669 Mdot
.56 .01677 Mdot
.56 .01677 Mdot
.56 .01685 Mdot
.56 .01692 Mdot
.56 .01701 Mdot
.56 .01702 Mdot
.56 .0171 Mdot
.56 .0171 Mdot
.56 .01719 Mdot
.56 .01729 Mdot
.56 .01729 Mdot
.56 .01738 Mdot
.56 .01739 Mdot
.56 .01749 Mdot
.56 .0176 Mdot
.56 .0176 Mdot
.56 .0177 Mdot
.56 .01771 Mdot
.56 .01782 Mdot
.56 .01794 Mdot
.56 .01795 Mdot
.56 .01806 Mdot
.56 .01807 Mdot
.56 .01819 Mdot
.56 .01833 Mdot
.56 .01834 Mdot
.56 .01847 Mdot
.56 .01847 Mdot
.56 .01861 Mdot
.56 .01876 Mdot
.56 .01877 Mdot
.56 .01888 Mdot
.56 .01892 Mdot
.56 .01892 Mdot
.56 .01907 Mdot
.56 .01925 Mdot
.56 .01926 Mdot
.56 .01938 Mdot
.56 .01942 Mdot
.56 .01943 Mdot
.56 .0196 Mdot
.56 .01979 Mdot
.56 .0198 Mdot
.56 .01994 Mdot
.56 .01998 Mdot
.56 .01999 Mdot
.56 .02 Mdot
.56 .02018 Mdot
.56 .0204 Mdot
.56 .02041 Mdot
.56 .02046 Mdot
.56 .02057 Mdot
.56 .02062 Mdot
.56 .02063 Mdot
.56 .02063 Mdot
.56 .02084 Mdot
.56 .02109 Mdot
.56 .0211 Mdot
.56 .02115 Mdot
.56 .02127 Mdot
.56 .02132 Mdot
.56 .02134 Mdot
.56 .02134 Mdot
.56 .02158 Mdot
.56 .02185 Mdot
.56 .02186 Mdot
.56 .02193 Mdot
.56 .02201 Mdot
.56 .02206 Mdot
.56 .02212 Mdot
.56 .02213 Mdot
.56 .02214 Mdot
.56 .0224 Mdot
.56 .02271 Mdot
.56 .02272 Mdot
.56 .02279 Mdot
.56 .02289 Mdot
.56 .02294 Mdot
.56 .02301 Mdot
.56 .02302 Mdot
.56 .02303 Mdot
.56 .02332 Mdot
.56 .02355 Mdot
.56 .02367 Mdot
.56 .02368 Mdot
.56 .02376 Mdot
.56 .02387 Mdot
.56 .02393 Mdot
.56 .024 Mdot
.56 .02402 Mdot
.56 .02402 Mdot
.56 .02403 Mdot
.56 .02435 Mdot
.56 .02461 Mdot
.56 .02474 Mdot
.56 .02476 Mdot
.56 .02485 Mdot
.56 .02497 Mdot
.56 .02503 Mdot
.56 .02511 Mdot
.56 .02513 Mdot
.56 .02513 Mdot
.56 .02514 Mdot
.56 .02551 Mdot
.56 .0258 Mdot
.56 .02594 Mdot
.56 .02596 Mdot
.56 .02606 Mdot
.56 .0262 Mdot
.56 .02627 Mdot
.56 .02636 Mdot
.56 .02638 Mdot
.56 .02638 Mdot
.56 .0264 Mdot
.56 .0268 Mdot
.56 .02713 Mdot
.56 .02729 Mdot
.56 .02731 Mdot
.56 .02743 Mdot
.56 .02758 Mdot
.56 .02761 Mdot
.56 .02766 Mdot
.56 .02776 Mdot
.56 .02778 Mdot
.56 .02778 Mdot
.56 .0278 Mdot
.56 .02826 Mdot
.56 .02862 Mdot
.56 .0288 Mdot
.56 .02882 Mdot
.56 .02895 Mdot
.56 .02912 Mdot
.56 .02916 Mdot
.56 .02921 Mdot
.56 .02932 Mdot
.56 .02935 Mdot
.56 .02935 Mdot
.56 .02937 Mdot
.56 .02983 Mdot
.56 .02988 Mdot
.56 .03029 Mdot
.56 .03049 Mdot
.56 .03051 Mdot
.56 .03066 Mdot
.56 .03085 Mdot
.56 .03089 Mdot
.56 .03095 Mdot
.56 .03108 Mdot
.56 .03111 Mdot
.56 .03111 Mdot
.56 .03112 Mdot
.56 .03136 Mdot
.56 .03164 Mdot
.56 .0317 Mdot
.56 .03216 Mdot
.56 .03223 Mdot
.56 .03239 Mdot
.56 .03241 Mdot
.56 .03249 Mdot
.56 .03257 Mdot
.56 .03279 Mdot
.56 .03283 Mdot
.56 .0329 Mdot
.56 .03304 Mdot
.56 .03308 Mdot
.56 .03308 Mdot
.56 .03309 Mdot
.56 .03313 Mdot
.56 .03314 Mdot
.56 .03336 Mdot
.56 .03349 Mdot
.56 .03367 Mdot
.56 .03374 Mdot
.56 .03414 Mdot
.56 .03425 Mdot
.56 .03429 Mdot
.56 .03434 Mdot
.56 .03451 Mdot
.56 .03453 Mdot
.56 .03462 Mdot
.56 .03472 Mdot
.56 .03495 Mdot
.56 .035 Mdot
.56 .03508 Mdot
.56 .03524 Mdot
.56 .03528 Mdot
.56 .03528 Mdot
.56 .0353 Mdot
.56 .03534 Mdot
.56 .03535 Mdot
.56 .03559 Mdot
.56 .03574 Mdot
.56 .03589 Mdot
.56 .03594 Mdot
.56 .03602 Mdot
.56 .03647 Mdot
.56 .0366 Mdot
.56 .03664 Mdot
.56 .03669 Mdot
.56 .03688 Mdot
.56 .03691 Mdot
.56 .03701 Mdot
.56 .03712 Mdot
.56 .03738 Mdot
.56 .03744 Mdot
.56 .03753 Mdot
.56 .0377 Mdot
.56 .03775 Mdot
.56 .03775 Mdot
.56 .03777 Mdot
.56 .03781 Mdot
.56 .03782 Mdot
.56 .0381 Mdot
.56 .03826 Mdot
.56 .03843 Mdot
.56 .03848 Mdot
.56 .03849 Mdot
.56 .03858 Mdot
.56 .03908 Mdot
.56 .03917 Mdot
.56 .03922 Mdot
.56 .03927 Mdot
.56 .03933 Mdot
.56 .03954 Mdot
.56 .03958 Mdot
.56 .03969 Mdot
.56 .0398 Mdot
.56 .03984 Mdot
.56 .0401 Mdot
.56 .04017 Mdot
.56 .04027 Mdot
.56 .04046 Mdot
.56 .04051 Mdot
.56 .04051 Mdot
.56 .04054 Mdot
.56 .04058 Mdot
.56 .0406 Mdot
.56 .04071 Mdot
.56 .0409 Mdot
.56 .041 Mdot
.56 .04109 Mdot
.56 .04128 Mdot
.56 .04133 Mdot
.56 .04135 Mdot
.56 .04144 Mdot
.56 .042 Mdot
.56 .04211 Mdot
.56 .04216 Mdot
.56 .04221 Mdot
.56 .04228 Mdot
.56 .04252 Mdot
.56 .04256 Mdot
.56 .04269 Mdot
.56 .04281 Mdot
.56 .04285 Mdot
.56 .04315 Mdot
.56 .04333 Mdot
.56 .04346 Mdot
.56 .04353 Mdot
.56 .04355 Mdot
.56 .0436 Mdot
.56 .04361 Mdot
.56 .04363 Mdot
.56 .04369 Mdot
.56 .0437 Mdot
.56 .04383 Mdot
.56 .04405 Mdot
.56 .04416 Mdot
.56 .04423 Mdot
.56 .04426 Mdot
.56 .04446 Mdot
.56 .04446 Mdot
.56 .04452 Mdot
.56 .04454 Mdot
.56 .04465 Mdot
.56 .04527 Mdot
.56 .0454 Mdot
.56 .04546 Mdot
.56 .04551 Mdot
.56 .04559 Mdot
.56 .04575 Mdot
.56 .04586 Mdot
.56 .0459 Mdot
.56 .04604 Mdot
.56 .04619 Mdot
.56 .04623 Mdot
.56 .04656 Mdot
.56 .04677 Mdot
.56 .04691 Mdot
.56 .04699 Mdot
.56 .04701 Mdot
.56 .04707 Mdot
.56 .04707 Mdot
.56 .04711 Mdot
.56 .04717 Mdot
.56 .04718 Mdot
.56 .04733 Mdot
.56 .04757 Mdot
.56 .04769 Mdot
.56 .04777 Mdot
.56 .0478 Mdot
.56 .04803 Mdot
.56 .04803 Mdot
.56 .0481 Mdot
.56 .04812 Mdot
.56 .04824 Mdot
.56 .04894 Mdot
.56 .04908 Mdot
.56 .04915 Mdot
.56 .04921 Mdot
.56 .04929 Mdot
.56 .04948 Mdot
.56 .04959 Mdot
.56 .04964 Mdot
.56 .0498 Mdot
.56 .04996 Mdot
.56 .05001 Mdot
.56 .05038 Mdot
.56 .05061 Mdot
.56 .05077 Mdot
.56 .05086 Mdot
.56 .05089 Mdot
.56 .05095 Mdot
.56 .05096 Mdot
.56 .05099 Mdot
.56 .05106 Mdot
.56 .05107 Mdot
.56 .05124 Mdot
.56 .05151 Mdot
.56 .05158 Mdot
.56 .05165 Mdot
.56 .05174 Mdot
.56 .05177 Mdot
.56 .05203 Mdot
.56 .05203 Mdot
.56 .05211 Mdot
.56 .05213 Mdot
.56 .05226 Mdot
.56 .05305 Mdot
.56 .0532 Mdot
.56 .05328 Mdot
.56 .05333 Mdot
.56 .05335 Mdot
.56 .05344 Mdot
.56 .05365 Mdot
.56 .05378 Mdot
.56 .05383 Mdot
.56 .05401 Mdot
.56 .05419 Mdot
.56 .05425 Mdot
.56 .05466 Mdot
.56 .05492 Mdot
.56 .0551 Mdot
.56 .0552 Mdot
.56 .05523 Mdot
.56 .0553 Mdot
.56 .0553 Mdot
.56 .05535 Mdot
.56 .05542 Mdot
.56 .05544 Mdot
.56 .05562 Mdot
.56 .05592 Mdot
.56 .05601 Mdot
.56 .05608 Mdot
.56 .05618 Mdot
.56 .05622 Mdot
.56 .0565 Mdot
.56 .05651 Mdot
.56 .05659 Mdot
.56 .05662 Mdot
.56 .05677 Mdot
.56 .05765 Mdot
.56 .05782 Mdot
.56 .0579 Mdot
.56 .05797 Mdot
.56 .05798 Mdot
.56 .05809 Mdot
.56 .05832 Mdot
.56 .05847 Mdot
.56 .05853 Mdot
.56 .05873 Mdot
.56 .05893 Mdot
.56 .05899 Mdot
.56 .05946 Mdot
.56 .05974 Mdot
.56 .05994 Mdot
.56 .06006 Mdot
.56 .06009 Mdot
.56 .06017 Mdot
.56 .06017 Mdot
.56 .06022 Mdot
.56 .0603 Mdot
.56 .06032 Mdot
.56 .06053 Mdot
.56 .06087 Mdot
.56 .06096 Mdot
.56 .06105 Mdot
.56 .06116 Mdot
.56 .0612 Mdot
.56 .06152 Mdot
.56 .06153 Mdot
.56 .06162 Mdot
.56 .06165 Mdot
.56 .06182 Mdot
.56 .0628 Mdot
.56 .06299 Mdot
.56 .06309 Mdot
.56 .06316 Mdot
.56 .06318 Mdot
.56 .06329 Mdot
.56 .06355 Mdot
.56 .06372 Mdot
.56 .06378 Mdot
.56 .06401 Mdot
.56 .06423 Mdot
.56 .0643 Mdot
.56 .06482 Mdot
.56 .06515 Mdot
.56 .06537 Mdot
.56 .0655 Mdot
.56 .06554 Mdot
.56 .06563 Mdot
.56 .06563 Mdot
.56 .06568 Mdot
.56 .06578 Mdot
.56 .0658 Mdot
.56 .06603 Mdot
.56 .06641 Mdot
.56 .06651 Mdot
.56 .06661 Mdot
.56 .06673 Mdot
.56 .06678 Mdot
.56 .06713 Mdot
.56 .06714 Mdot
.56 .06725 Mdot
.56 .06728 Mdot
.56 .06747 Mdot
.56 .06857 Mdot
.56 .06878 Mdot
.56 .06889 Mdot
.56 .06897 Mdot
.56 .06899 Mdot
.56 .06912 Mdot
.56 .06941 Mdot
.56 .0696 Mdot
.56 .06967 Mdot
.56 .06993 Mdot
.56 .07018 Mdot
.56 .07025 Mdot
.56 .07084 Mdot
.56 .0712 Mdot
.56 .07145 Mdot
.56 .07159 Mdot
.56 .07163 Mdot
.56 .07174 Mdot
.56 .07174 Mdot
.56 .0718 Mdot
.56 .0719 Mdot
.56 .07193 Mdot
.56 .07219 Mdot
.56 .07261 Mdot
.56 .07272 Mdot
.56 .07283 Mdot
.56 .07298 Mdot
.56 .07302 Mdot
.56 .07342 Mdot
.56 .07344 Mdot
.56 .07355 Mdot
.56 .07359 Mdot
.56 .0738 Mdot
.56 .07503 Mdot
.56 .07527 Mdot
.56 .07539 Mdot
.56 .07548 Mdot
.56 .0755 Mdot
.56 .07565 Mdot
.56 .07598 Mdot
.56 .07618 Mdot
.56 .07627 Mdot
.56 .07655 Mdot
.56 .07683 Mdot
.56 .07692 Mdot
.56 .07757 Mdot
.56 .07798 Mdot
.56 .07826 Mdot
.56 .07842 Mdot
.56 .07846 Mdot
.56 .07858 Mdot
.56 .07858 Mdot
.56 .07865 Mdot
.56 .07877 Mdot
.56 .07879 Mdot
.56 .07909 Mdot
.56 .07956 Mdot
.56 .07969 Mdot
.56 .07981 Mdot
.56 .07997 Mdot
.56 .08002 Mdot
.56 .08047 Mdot
.56 .08048 Mdot
.56 .08061 Mdot
.56 .08065 Mdot
.56 .08089 Mdot
.56 .08227 Mdot
.56 .08254 Mdot
.56 .08267 Mdot
.56 .08278 Mdot
.56 .0828 Mdot
.56 .08297 Mdot
.56 .08333 Mdot
.56 .08356 Mdot
.56 .08365 Mdot
.56 .08397 Mdot
.56 .08429 Mdot
.56 .08438 Mdot
.56 .08512 Mdot
.56 .08557 Mdot
.56 .08588 Mdot
.56 .08606 Mdot
.56 .08611 Mdot
.56 .08625 Mdot
.56 .08625 Mdot
.56 .08632 Mdot
.56 .08645 Mdot
.56 .08648 Mdot
.56 .08681 Mdot
.56 .08734 Mdot
.56 .08748 Mdot
.56 .08762 Mdot
.56 .0878 Mdot
.56 .08786 Mdot
.56 .08836 Mdot
.56 .08837 Mdot
.56 .08852 Mdot
.56 .08856 Mdot
.56 .08883 Mdot
.56 .09038 Mdot
.56 .09068 Mdot
.56 .09083 Mdot
.56 .09094 Mdot
.56 .09097 Mdot
.56 .09116 Mdot
.56 .09156 Mdot
.56 .09182 Mdot
.56 .09193 Mdot
.56 .09228 Mdot
.56 .09263 Mdot
.56 .09274 Mdot
.56 .09356 Mdot
.56 .09407 Mdot
.56 .09442 Mdot
.56 .09462 Mdot
.56 .09468 Mdot
.56 .09483 Mdot
.56 .09483 Mdot
.56 .09491 Mdot
.56 .09506 Mdot
.56 .09509 Mdot
.56 .09546 Mdot
.56 .09605 Mdot
.56 .09621 Mdot
.56 .09637 Mdot
.56 .09657 Mdot
.56 .09663 Mdot
.56 .0972 Mdot
.56 .09721 Mdot
.56 .09737 Mdot
.56 .09743 Mdot
.56 .09772 Mdot
.56 .09946 Mdot
.56 .09979 Mdot
.56 .09996 Mdot
.56 .10009 Mdot
.56 .10012 Mdot
.56 .10033 Mdot
.56 .10079 Mdot
.56 .10107 Mdot
.56 .10119 Mdot
.56 .10159 Mdot
.56 .10198 Mdot
.56 .1021 Mdot
.56 .10303 Mdot
.56 .10359 Mdot
.56 .10399 Mdot
.56 .10421 Mdot
.56 .10428 Mdot
.56 .10444 Mdot
.56 .10444 Mdot
.56 .10454 Mdot
.56 .1047 Mdot
.56 .10474 Mdot
.56 .10515 Mdot
.56 .10582 Mdot
.56 .10599 Mdot
.56 .10616 Mdot
.56 .10639 Mdot
.56 .10646 Mdot
.56 .10709 Mdot
.56 .10711 Mdot
.56 .10729 Mdot
.56 .10735 Mdot
.56 .10768 Mdot
.56 .10963 Mdot
.56 .11 Mdot
.56 .11019 Mdot
.56 .11034 Mdot
.56 .11037 Mdot
.56 .1106 Mdot
.56 .11111 Mdot
.56 .11144 Mdot
.56 .11157 Mdot
.56 .11201 Mdot
.56 .11246 Mdot
.56 .11259 Mdot
.56 .11362 Mdot
.56 .11426 Mdot
.56 .1147 Mdot
.56 .11495 Mdot
.56 .11503 Mdot
.56 .11521 Mdot
.56 .11521 Mdot
.56 .11531 Mdot
.56 .1155 Mdot
.56 .11554 Mdot
.56 .116 Mdot
.56 .11675 Mdot
.56 .11695 Mdot
.56 .11714 Mdot
.56 .11739 Mdot
.56 .11747 Mdot
.56 .11818 Mdot
.56 .1182 Mdot
.56 .1184 Mdot
.56 .11847 Mdot
.56 .11884 Mdot
.56 .12102 Mdot
.56 .12144 Mdot
.56 .12165 Mdot
.56 .12181 Mdot
.56 .12185 Mdot
.56 .12211 Mdot
.56 .12268 Mdot
.56 .12304 Mdot
.56 .12319 Mdot
.56 .12369 Mdot
.56 .12419 Mdot
.56 .12434 Mdot
.56 .12549 Mdot
.56 .12621 Mdot
.56 .1267 Mdot
.56 .12698 Mdot
.56 .12706 Mdot
.56 .12727 Mdot
.56 .12727 Mdot
.56 .12739 Mdot
.56 .12759 Mdot
.56 .12764 Mdot
.56 .12816 Mdot
.56 .12899 Mdot
.56 .12922 Mdot
.56 .12943 Mdot
.56 .12971 Mdot
.56 .12981 Mdot
.56 .1306 Mdot
.56 .13062 Mdot
.56 .13084 Mdot
.56 .13092 Mdot
.56 .13133 Mdot
.56 .13378 Mdot
.56 .13424 Mdot
.56 .13448 Mdot
.56 .13466 Mdot
.56 .1347 Mdot
.56 .135 Mdot
.56 .13564 Mdot
.56 .13604 Mdot
.56 .13621 Mdot
.56 .13677 Mdot
.56 .13732 Mdot
.56 .13749 Mdot
.56 .13879 Mdot
.56 .13958 Mdot
.56 .14014 Mdot
.56 .14045 Mdot
.56 .14055 Mdot
.56 .14078 Mdot
.56 .14078 Mdot
.56 .14091 Mdot
.56 .14114 Mdot
.56 .14119 Mdot
.56 .14177 Mdot
.56 .1427 Mdot
.56 .14296 Mdot
.56 .1432 Mdot
.56 .14351 Mdot
.56 .14362 Mdot
.56 .1445 Mdot
.56 .14453 Mdot
.56 .14478 Mdot
.56 .14486 Mdot
.56 .14533 Mdot
.56 .14806 Mdot
.56 .14859 Mdot
.56 .14886 Mdot
.56 .14906 Mdot
.56 .1491 Mdot
.56 .14943 Mdot
.56 .15015 Mdot
.56 .1506 Mdot
.56 .15079 Mdot
.56 .15141 Mdot
.56 .15204 Mdot
.56 .15222 Mdot
.56 .15367 Mdot
.56 .15457 Mdot
.56 .15519 Mdot
.56 .15554 Mdot
.56 .15565 Mdot
.56 .1559 Mdot
.56 .15591 Mdot
.56 .15605 Mdot
.56 .15631 Mdot
.56 .15637 Mdot
.56 .15702 Mdot
.56 .15806 Mdot
.56 .15834 Mdot
.56 .15861 Mdot
.56 .15897 Mdot
.56 .15908 Mdot
.56 .16008 Mdot
.56 .1601 Mdot
.56 .16039 Mdot
.56 .16048 Mdot
.56 .161 Mdot
.56 .16406 Mdot
.56 .16465 Mdot
.56 .16495 Mdot
.56 .16518 Mdot
.56 .16523 Mdot
.56 .16559 Mdot
.56 .1664 Mdot
.56 .16691 Mdot
.56 .16712 Mdot
.56 .16782 Mdot
.56 .16851 Mdot
.56 .16872 Mdot
.56 .17035 Mdot
.56 .17135 Mdot
.56 .17205 Mdot
.56 .17244 Mdot
.56 .17256 Mdot
.56 .17285 Mdot
.56 .17285 Mdot
.56 .17301 Mdot
.56 .1733 Mdot
.56 .17337 Mdot
.56 .17409 Mdot
.56 .17527 Mdot
.56 .17558 Mdot
.56 .17588 Mdot
.56 .17628 Mdot
.56 .17641 Mdot
.56 .17752 Mdot
.56 .17755 Mdot
.56 .17787 Mdot
.56 .17797 Mdot
.56 .17856 Mdot
.56 .18199 Mdot
.56 .18264 Mdot
.56 .18298 Mdot
.56 .18323 Mdot
.56 .18329 Mdot
.56 .1837 Mdot
.56 .1846 Mdot
.56 .18517 Mdot
.56 .18541 Mdot
.56 .18619 Mdot
.56 .18697 Mdot
.56 .18721 Mdot
.56 .18902 Mdot
.56 .19015 Mdot
.56 .19092 Mdot
.56 .19137 Mdot
.56 .1915 Mdot
.56 .19182 Mdot
.56 .19183 Mdot
.56 .192 Mdot
.56 .19233 Mdot
.56 .19241 Mdot
.56 .19322 Mdot
.56 .19453 Mdot
.56 .19488 Mdot
.56 .19522 Mdot
.56 .19566 Mdot
.56 .19581 Mdot
.56 .19705 Mdot
.56 .19709 Mdot
.56 .19745 Mdot
.56 .19756 Mdot
.56 .19822 Mdot
.56 .20206 Mdot
.56 .2028 Mdot
.56 .20317 Mdot
.56 .20345 Mdot
.56 .20352 Mdot
.56 .20398 Mdot
.56 .20499 Mdot
.56 .20562 Mdot
.56 .20589 Mdot
.56 .20677 Mdot
.56 .20764 Mdot
.56 .2079 Mdot
.56 .20994 Mdot
.56 .2112 Mdot
.56 .21207 Mdot
.56 .21257 Mdot
.56 .21271 Mdot
.56 .21307 Mdot
.56 .21308 Mdot
.56 .21328 Mdot
.56 .21365 Mdot
.56 .21373 Mdot
.56 .21464 Mdot
.56 .21611 Mdot
.56 .2165 Mdot
.56 .21688 Mdot
.56 .21738 Mdot
.56 .21754 Mdot
.56 .21894 Mdot
.56 .21898 Mdot
.56 .21937 Mdot
.56 .2195 Mdot
.56 .22024 Mdot
.56 .22354 Mdot
.56 .22454 Mdot
.56 .22537 Mdot
.56 .22579 Mdot
.56 .2261 Mdot
.56 .22617 Mdot
.56 .22669 Mdot
.56 .22782 Mdot
.56 .22853 Mdot
.56 .22883 Mdot
.56 .22981 Mdot
.56 .23079 Mdot
.56 .23109 Mdot
.56 .23337 Mdot
.56 .23478 Mdot
.56 .23575 Mdot
.56 .23631 Mdot
.56 .23647 Mdot
.56 .23688 Mdot
.56 .23688 Mdot
.56 .23711 Mdot
.56 .23752 Mdot
.56 .23761 Mdot
.56 .23863 Mdot
.56 .24028 Mdot
.56 .24072 Mdot
.56 .24114 Mdot
.56 .2417 Mdot
.56 .24188 Mdot
.56 .24344 Mdot
.56 .24349 Mdot
.56 .24393 Mdot
.56 .24408 Mdot
.56 .2449 Mdot
.56 .2486 Mdot
.56 .24972 Mdot
.56 .25064 Mdot
.56 .25112 Mdot
.56 .25147 Mdot
.56 .25155 Mdot
.56 .25213 Mdot
.56 .2534 Mdot
.56 .25419 Mdot
.56 .25452 Mdot
.56 .25562 Mdot
.56 .25672 Mdot
.56 .25705 Mdot
.56 .25961 Mdot
.56 .26119 Mdot
.56 .26228 Mdot
.56 .2629 Mdot
.56 .26308 Mdot
.56 .26354 Mdot
.56 .26354 Mdot
.56 .26379 Mdot
.56 .26425 Mdot
.56 .26436 Mdot
.56 .2655 Mdot
.56 .26734 Mdot
.56 .26784 Mdot
.56 .26831 Mdot
.56 .26894 Mdot
.56 .26914 Mdot
.56 .27089 Mdot
.56 .27094 Mdot
.56 .27144 Mdot
.56 .2716 Mdot
.56 .27252 Mdot
.56 .27667 Mdot
.56 .27792 Mdot
.56 .27895 Mdot
.56 .27948 Mdot
.56 .27988 Mdot
.56 .27997 Mdot
.56 .28062 Mdot
.56 .28204 Mdot
.56 .28293 Mdot
.56 .2833 Mdot
.56 .28453 Mdot
.56 .28576 Mdot
.56 .28613 Mdot
.56 .28899 Mdot
.56 .29076 Mdot
.56 .29198 Mdot
.56 .29268 Mdot
.56 .29289 Mdot
.56 .29339 Mdot
.56 .2934 Mdot
.56 .29368 Mdot
.56 .2942 Mdot
.56 .29432 Mdot
.56 .2956 Mdot
.56 .29766 Mdot
.56 .29821 Mdot
.56 .29874 Mdot
.56 .29944 Mdot
.56 .29967 Mdot
.56 .30163 Mdot
.56 .30169 Mdot
.56 .30225 Mdot
.56 .30243 Mdot
.56 .30346 Mdot
.56 .30811 Mdot
.56 .3095 Mdot
.56 .31066 Mdot
.56 .31126 Mdot
.56 .3117 Mdot
.56 .3118 Mdot
.56 .31252 Mdot
.56 .31412 Mdot
.56 .31511 Mdot
.56 .31553 Mdot
.56 .31691 Mdot
.56 .31829 Mdot
.56 .3187 Mdot
.56 .32191 Mdot
.56 .32389 Mdot
.56 .32526 Mdot
.56 .32604 Mdot
.56 .32627 Mdot
.56 .32684 Mdot
.56 .32684 Mdot
.56 .32716 Mdot
.56 .32774 Mdot
.56 .32787 Mdot
.56 .3293 Mdot
.56 .33161 Mdot
.56 .33223 Mdot
.56 .33283 Mdot
.56 .33361 Mdot
.56 .33387 Mdot
.56 .33606 Mdot
.56 .33612 Mdot
.56 .33675 Mdot
.56 .33695 Mdot
.56 .33811 Mdot
.56 .34331 Mdot
.56 .34488 Mdot
.562 .01603 Mdot
.562 .01618 Mdot
.562 .0162 Mdot
.562 .01636 Mdot
.562 .01638 Mdot
.562 .01657 Mdot
.562 .01659 Mdot
.562 .0168 Mdot
.562 .01682 Mdot
.562 .01705 Mdot
.562 .01708 Mdot
.562 .01734 Mdot
.562 .01738 Mdot
.562 .01748 Mdot
.562 .01767 Mdot
.562 .01771 Mdot
.562 .01782 Mdot
.562 .01804 Mdot
.562 .01808 Mdot
.562 .01821 Mdot
.562 .01845 Mdot
.562 .01849 Mdot
.562 .01864 Mdot
.562 .01891 Mdot
.562 .01896 Mdot
.562 .01913 Mdot
.562 .01943 Mdot
.562 .01949 Mdot
.562 .01968 Mdot
.562 .02002 Mdot
.562 .02008 Mdot
.562 .02015 Mdot
.562 .02029 Mdot
.562 .02032 Mdot
.562 .02067 Mdot
.562 .02075 Mdot
.562 .02082 Mdot
.562 .02098 Mdot
.562 .02101 Mdot
.562 .0214 Mdot
.562 .02141 Mdot
.562 .0215 Mdot
.562 .02158 Mdot
.562 .02176 Mdot
.562 .02177 Mdot
.562 .02179 Mdot
.562 .02203 Mdot
.562 .0222 Mdot
.562 .02223 Mdot
.562 .02224 Mdot
.562 .02234 Mdot
.562 .02243 Mdot
.562 .02264 Mdot
.562 .02264 Mdot
.562 .02267 Mdot
.562 .02294 Mdot
.562 .02313 Mdot
.562 .02316 Mdot
.562 .02317 Mdot
.562 .02328 Mdot
.562 .02338 Mdot
.562 .02362 Mdot
.562 .02362 Mdot
.562 .02366 Mdot
.562 .02396 Mdot
.562 .02417 Mdot
.562 .02421 Mdot
.562 .02422 Mdot
.562 .02434 Mdot
.562 .02446 Mdot
.562 .02472 Mdot
.562 .02473 Mdot
.562 .02477 Mdot
.562 .0251 Mdot
.562 .02534 Mdot
.562 .02538 Mdot
.562 .0254 Mdot
.562 .02549 Mdot
.562 .02554 Mdot
.562 .02566 Mdot
.562 .02596 Mdot
.562 .02597 Mdot
.562 .02601 Mdot
.562 .02639 Mdot
.562 .02654 Mdot
.562 .02666 Mdot
.562 .02671 Mdot
.562 .02672 Mdot
.562 .02673 Mdot
.562 .02682 Mdot
.562 .02688 Mdot
.562 .02702 Mdot
.562 .02736 Mdot
.562 .02736 Mdot
.562 .02741 Mdot
.562 .02752 Mdot
.562 .02784 Mdot
.562 .028 Mdot
.562 .02814 Mdot
.562 .0282 Mdot
.562 .0282 Mdot
.562 .02822 Mdot
.562 .02832 Mdot
.562 .02839 Mdot
.562 .02855 Mdot
.562 .02872 Mdot
.562 .02893 Mdot
.562 .02893 Mdot
.562 .02899 Mdot
.562 .02911 Mdot
.562 .02947 Mdot
.562 .02965 Mdot
.562 .02981 Mdot
.562 .02987 Mdot
.562 .02988 Mdot
.562 .02989 Mdot
.562 .03001 Mdot
.562 .03008 Mdot
.562 .03026 Mdot
.562 .03028 Mdot
.562 .03046 Mdot
.562 .03069 Mdot
.562 .0307 Mdot
.562 .03076 Mdot
.562 .03089 Mdot
.562 .0313 Mdot
.562 .0315 Mdot
.562 .03168 Mdot
.562 .03175 Mdot
.562 .03176 Mdot
.562 .03177 Mdot
.562 .03191 Mdot
.562 .03199 Mdot
.562 .03219 Mdot
.562 .03222 Mdot
.562 .03241 Mdot
.562 .03245 Mdot
.562 .03267 Mdot
.562 .03268 Mdot
.562 .03275 Mdot
.562 .0329 Mdot
.562 .03298 Mdot
.562 .033 Mdot
.562 .03335 Mdot
.562 .03358 Mdot
.562 .03358 Mdot
.562 .03378 Mdot
.562 .03386 Mdot
.562 .03387 Mdot
.562 .03389 Mdot
.562 .03404 Mdot
.562 .03413 Mdot
.562 .03436 Mdot
.562 .03439 Mdot
.562 .0346 Mdot
.562 .03465 Mdot
.562 .0349 Mdot
.562 .0349 Mdot
.562 .03498 Mdot
.562 .03515 Mdot
.562 .03524 Mdot
.562 .03527 Mdot
.562 .03559 Mdot
.562 .03566 Mdot
.562 .03592 Mdot
.562 .03592 Mdot
.562 .03614 Mdot
.562 .03623 Mdot
.562 .03625 Mdot
.562 .03627 Mdot
.562 .03643 Mdot
.562 .03654 Mdot
.562 .0367 Mdot
.562 .03679 Mdot
.562 .03682 Mdot
.562 .03707 Mdot
.562 .03712 Mdot
.562 .03721 Mdot
.562 .0374 Mdot
.562 .03741 Mdot
.562 .0375 Mdot
.562 .03769 Mdot
.562 .03779 Mdot
.562 .03782 Mdot
.562 .03812 Mdot
.562 .03818 Mdot
.562 .03826 Mdot
.562 .03837 Mdot
.562 .03855 Mdot
.562 .03855 Mdot
.562 .03873 Mdot
.562 .0388 Mdot
.562 .0389 Mdot
.562 .03892 Mdot
.562 .03894 Mdot
.562 .03913 Mdot
.562 .03924 Mdot
.562 .03943 Mdot
.562 .03953 Mdot
.562 .03957 Mdot
.562 .03984 Mdot
.562 .0399 Mdot
.562 .04 Mdot
.562 .04021 Mdot
.562 .04022 Mdot
.562 .04032 Mdot
.562 .04054 Mdot
.562 .04065 Mdot
.562 .04068 Mdot
.562 .04103 Mdot
.562 .04109 Mdot
.562 .04118 Mdot
.562 .0413 Mdot
.562 .04146 Mdot
.562 .0415 Mdot
.562 .04151 Mdot
.562 .0417 Mdot
.562 .04179 Mdot
.562 .0419 Mdot
.562 .04192 Mdot
.562 .04194 Mdot
.562 .04215 Mdot
.562 .04229 Mdot
.562 .04249 Mdot
.562 .04261 Mdot
.562 .04265 Mdot
.562 .04295 Mdot
.562 .04302 Mdot
.562 .04314 Mdot
.562 .04321 Mdot
.562 .04337 Mdot
.562 .04338 Mdot
.562 .0435 Mdot
.562 .04374 Mdot
.562 .04386 Mdot
.562 .0439 Mdot
.562 .04429 Mdot
.562 .04436 Mdot
.562 .04446 Mdot
.562 .0446 Mdot
.562 .04478 Mdot
.562 .04483 Mdot
.562 .04483 Mdot
.562 .04505 Mdot
.562 .04515 Mdot
.562 .04519 Mdot
.562 .04527 Mdot
.562 .04529 Mdot
.562 .04532 Mdot
.562 .04556 Mdot
.562 .0457 Mdot
.562 .04588 Mdot
.562 .04593 Mdot
.562 .04607 Mdot
.562 .04611 Mdot
.562 .04646 Mdot
.562 .04653 Mdot
.562 .04667 Mdot
.562 .04674 Mdot
.562 .04692 Mdot
.562 .04694 Mdot
.562 .04706 Mdot
.562 .04734 Mdot
.562 .04744 Mdot
.562 .04748 Mdot
.562 .04752 Mdot
.562 .04794 Mdot
.562 .04796 Mdot
.562 .04803 Mdot
.562 .04805 Mdot
.562 .04815 Mdot
.562 .0483 Mdot
.562 .04851 Mdot
.562 .04856 Mdot
.562 .04856 Mdot
.562 .04881 Mdot
.562 .04892 Mdot
.562 .04897 Mdot
.562 .04906 Mdot
.562 .04908 Mdot
.562 .04912 Mdot
.562 .04938 Mdot
.562 .04955 Mdot
.562 .04974 Mdot
.562 .04981 Mdot
.562 .04996 Mdot
.562 .05 Mdot
.562 .05039 Mdot
.562 .05048 Mdot
.562 .05063 Mdot
.562 .05071 Mdot
.562 .05092 Mdot
.562 .05093 Mdot
.562 .05108 Mdot
.562 .05138 Mdot
.562 .0515 Mdot
.562 .05154 Mdot
.562 .05157 Mdot
.562 .05159 Mdot
.562 .05194 Mdot
.562 .05206 Mdot
.562 .05208 Mdot
.562 .05216 Mdot
.562 .05218 Mdot
.562 .05229 Mdot
.562 .05246 Mdot
.562 .0527 Mdot
.562 .05276 Mdot
.562 .05276 Mdot
.562 .05282 Mdot
.562 .05304 Mdot
.562 .05316 Mdot
.562 .05322 Mdot
.562 .05332 Mdot
.562 .05334 Mdot
.562 .05338 Mdot
.562 .05368 Mdot
.562 .05387 Mdot
.562 .05408 Mdot
.562 .05416 Mdot
.562 .05433 Mdot
.562 .05438 Mdot
.562 .05439 Mdot
.562 .05481 Mdot
.562 .05491 Mdot
.562 .05508 Mdot
.562 .05517 Mdot
.562 .05525 Mdot
.562 .05541 Mdot
.562 .05543 Mdot
.562 .05558 Mdot
.562 .05591 Mdot
.562 .05593 Mdot
.562 .05606 Mdot
.562 .05611 Mdot
.562 .05614 Mdot
.562 .05616 Mdot
.562 .05656 Mdot
.562 .05669 Mdot
.562 .05671 Mdot
.562 .05681 Mdot
.562 .05683 Mdot
.562 .05695 Mdot
.562 .05715 Mdot
.562 .05741 Mdot
.562 .05747 Mdot
.562 .05748 Mdot
.562 .05755 Mdot
.562 .05779 Mdot
.562 .05793 Mdot
.562 .05799 Mdot
.562 .0581 Mdot
.562 .05813 Mdot
.562 .05818 Mdot
.562 .05851 Mdot
.562 .05872 Mdot
.562 .05896 Mdot
.562 .05905 Mdot
.562 .05924 Mdot
.562 .0593 Mdot
.562 .05931 Mdot
.562 .05979 Mdot
.562 .05989 Mdot
.562 .06009 Mdot
.562 .06019 Mdot
.562 .06027 Mdot
.562 .06045 Mdot
.562 .06047 Mdot
.562 .06065 Mdot
.562 .06102 Mdot
.562 .06104 Mdot
.562 .06119 Mdot
.562 .06124 Mdot
.562 .06128 Mdot
.562 .0613 Mdot
.562 .06175 Mdot
.562 .06189 Mdot
.562 .06192 Mdot
.562 .06203 Mdot
.562 .06205 Mdot
.562 .06219 Mdot
.562 .06241 Mdot
.562 .0627 Mdot
.562 .06278 Mdot
.562 .06278 Mdot
.562 .06286 Mdot
.562 .06313 Mdot
.562 .06329 Mdot
.562 .06336 Mdot
.562 .06348 Mdot
.562 .06351 Mdot
.562 .06356 Mdot
.562 .06394 Mdot
.562 .06418 Mdot
.562 .06445 Mdot
.562 .06454 Mdot
.562 .06476 Mdot
.562 .06483 Mdot
.562 .06484 Mdot
.562 .06538 Mdot
.562 .0655 Mdot
.562 .06571 Mdot
.562 .06583 Mdot
.562 .06592 Mdot
.562 .06613 Mdot
.562 .06615 Mdot
.562 .06635 Mdot
.562 .06676 Mdot
.562 .06679 Mdot
.562 .06695 Mdot
.562 .06701 Mdot
.562 .06705 Mdot
.562 .06708 Mdot
.562 .06758 Mdot
.562 .06774 Mdot
.562 .06777 Mdot
.562 .0679 Mdot
.562 .06792 Mdot
.562 .06808 Mdot
.562 .06832 Mdot
.562 .06865 Mdot
.562 .06874 Mdot
.562 .06874 Mdot
.562 .06883 Mdot
.562 .06914 Mdot
.562 .06931 Mdot
.562 .06939 Mdot
.562 .06953 Mdot
.562 .06957 Mdot
.562 .06962 Mdot
.562 .07004 Mdot
.562 .07031 Mdot
.562 .07062 Mdot
.562 .07072 Mdot
.562 .07096 Mdot
.562 .07104 Mdot
.562 .07106 Mdot
.562 .07166 Mdot
.562 .07179 Mdot
.562 .07204 Mdot
.562 .07217 Mdot
.562 .07227 Mdot
.562 .0725 Mdot
.562 .07253 Mdot
.562 .07275 Mdot
.562 .07321 Mdot
.562 .07324 Mdot
.562 .07343 Mdot
.562 .07349 Mdot
.562 .07354 Mdot
.562 .07357 Mdot
.562 .07414 Mdot
.562 .07432 Mdot
.562 .07435 Mdot
.562 .07449 Mdot
.562 .07452 Mdot
.562 .0747 Mdot
.562 .07497 Mdot
.562 .07534 Mdot
.562 .07543 Mdot
.562 .07544 Mdot
.562 .07554 Mdot
.562 .07589 Mdot
.562 .07608 Mdot
.562 .07617 Mdot
.562 .07633 Mdot
.562 .07637 Mdot
.562 .07643 Mdot
.562 .0769 Mdot
.562 .07721 Mdot
.562 .07755 Mdot
.562 .07767 Mdot
.562 .07794 Mdot
.562 .07803 Mdot
.562 .07804 Mdot
.562 .07872 Mdot
.562 .07887 Mdot
.562 .07914 Mdot
.562 .07929 Mdot
.562 .07941 Mdot
.562 .07967 Mdot
.562 .07969 Mdot
.562 .07995 Mdot
.562 .08047 Mdot
.562 .0805 Mdot
.562 .08071 Mdot
.562 .08078 Mdot
.562 .08083 Mdot
.562 .08087 Mdot
.562 .08151 Mdot
.562 .08171 Mdot
.562 .08174 Mdot
.562 .0819 Mdot
.562 .08193 Mdot
.562 .08213 Mdot
.562 .08244 Mdot
.562 .08286 Mdot
.562 .08296 Mdot
.562 .08297 Mdot
.562 .08308 Mdot
.562 .08347 Mdot
.562 .08369 Mdot
.562 .08379 Mdot
.562 .08397 Mdot
.562 .08401 Mdot
.562 .08408 Mdot
.562 .08462 Mdot
.562 .08495 Mdot
.562 .08534 Mdot
.562 .08547 Mdot
.562 .08578 Mdot
.562 .08588 Mdot
.562 .0859 Mdot
.562 .08666 Mdot
.562 .08683 Mdot
.562 .08713 Mdot
.562 .0873 Mdot
.562 .08743 Mdot
.562 .08772 Mdot
.562 .08775 Mdot
.562 .08804 Mdot
.562 .08862 Mdot
.562 .08866 Mdot
.562 .08889 Mdot
.562 .08897 Mdot
.562 .08903 Mdot
.562 .08907 Mdot
.562 .08979 Mdot
.562 .09002 Mdot
.562 .09006 Mdot
.562 .09023 Mdot
.562 .09027 Mdot
.562 .09049 Mdot
.562 .09084 Mdot
.562 .09131 Mdot
.562 .09143 Mdot
.562 .09143 Mdot
.562 .09156 Mdot
.562 .092 Mdot
.562 .09224 Mdot
.562 .09235 Mdot
.562 .09255 Mdot
.562 .09261 Mdot
.562 .09268 Mdot
.562 .09328 Mdot
.562 .09366 Mdot
.562 .0941 Mdot
.562 .09425 Mdot
.562 .09459 Mdot
.562 .0947 Mdot
.562 .09472 Mdot
.562 .09558 Mdot
.562 .09577 Mdot
.562 .09611 Mdot
.562 .0963 Mdot
.562 .09644 Mdot
.562 .09677 Mdot
.562 .09681 Mdot
.562 .09713 Mdot
.562 .09778 Mdot
.562 .09783 Mdot
.562 .09809 Mdot
.562 .09818 Mdot
.562 .09825 Mdot
.562 .09829 Mdot
.562 .0991 Mdot
.562 .09935 Mdot
.562 .0994 Mdot
.562 .0996 Mdot
.562 .09963 Mdot
.562 .09989 Mdot
.562 .10028 Mdot
.562 .10081 Mdot
.562 .10094 Mdot
.562 .10094 Mdot
.562 .10109 Mdot
.562 .10158 Mdot
.562 .10185 Mdot
.562 .10198 Mdot
.562 .1022 Mdot
.562 .10226 Mdot
.562 .10235 Mdot
.562 .10303 Mdot
.562 .10345 Mdot
.562 .10394 Mdot
.562 .10411 Mdot
.562 .1045 Mdot
.562 .10462 Mdot
.562 .10464 Mdot
.562 .1056 Mdot
.562 .10582 Mdot
.562 .10621 Mdot
.562 .10641 Mdot
.562 .10658 Mdot
.562 .10695 Mdot
.562 .10699 Mdot
.562 .10735 Mdot
.562 .10808 Mdot
.562 .10813 Mdot
.562 .10843 Mdot
.562 .10853 Mdot
.562 .1086 Mdot
.562 .10865 Mdot
.562 .10956 Mdot
.562 .10985 Mdot
.562 .1099 Mdot
.562 .11012 Mdot
.562 .11045 Mdot
.562 .11089 Mdot
.562 .11148 Mdot
.562 .11163 Mdot
.562 .11164 Mdot
.562 .1118 Mdot
.562 .11235 Mdot
.562 .11266 Mdot
.562 .1128 Mdot
.562 .11305 Mdot
.562 .11312 Mdot
.562 .11322 Mdot
.562 .11398 Mdot
.562 .11446 Mdot
.562 .11501 Mdot
.562 .1152 Mdot
.562 .11563 Mdot
.562 .11577 Mdot
.562 .1158 Mdot
.562 .11687 Mdot
.562 .11712 Mdot
.562 .11755 Mdot
.562 .11779 Mdot
.562 .11797 Mdot
.562 .11838 Mdot
.562 .11843 Mdot
.562 .11883 Mdot
.562 .11966 Mdot
.562 .11971 Mdot
.562 .12005 Mdot
.562 .12016 Mdot
.562 .12025 Mdot
.562 .1203 Mdot
.562 .12132 Mdot
.562 .12165 Mdot
.562 .1217 Mdot
.562 .12195 Mdot
.562 .12232 Mdot
.562 .12281 Mdot
.562 .12348 Mdot
.562 .12365 Mdot
.562 .12366 Mdot
.562 .12384 Mdot
.562 .12446 Mdot
.562 .1248 Mdot
.562 .12496 Mdot
.562 .12525 Mdot
.562 .12532 Mdot
.562 .12543 Mdot
.562 .12628 Mdot
.562 .12683 Mdot
.562 .12744 Mdot
.562 .12766 Mdot
.562 .12814 Mdot
.562 .1283 Mdot
.562 .12833 Mdot
.562 .12954 Mdot
.562 .12981 Mdot
.562 .1303 Mdot
.562 .13057 Mdot
.562 .13077 Mdot
.562 .13124 Mdot
.562 .13129 Mdot
.562 .13174 Mdot
.562 .13267 Mdot
.562 .13273 Mdot
.562 .13311 Mdot
.562 .13324 Mdot
.562 .13333 Mdot
.562 .13339 Mdot
.562 .13454 Mdot
.562 .13491 Mdot
.562 .13497 Mdot
.562 .13525 Mdot
.562 .13567 Mdot
.562 .13622 Mdot
.562 .13697 Mdot
.562 .13716 Mdot
.562 .13716 Mdot
.562 .13737 Mdot
.562 .13807 Mdot
.562 .13846 Mdot
.562 .13864 Mdot
.562 .13895 Mdot
.562 .13904 Mdot
.562 .13916 Mdot
.562 .14012 Mdot
.562 .14073 Mdot
.562 .14142 Mdot
.562 .14166 Mdot
.562 .14221 Mdot
.562 .14238 Mdot
.562 .14242 Mdot
.562 .14378 Mdot
.562 .14409 Mdot
.562 .14463 Mdot
.562 .14493 Mdot
.562 .14516 Mdot
.562 .14569 Mdot
.562 .14574 Mdot
.562 .14626 Mdot
.562 .1473 Mdot
.562 .14737 Mdot
.562 .14779 Mdot
.562 .14794 Mdot
.562 .14804 Mdot
.562 .14811 Mdot
.562 .1494 Mdot
.562 .14981 Mdot
.562 .14988 Mdot
.562 .1502 Mdot
.562 .15067 Mdot
.562 .15128 Mdot
.562 .15213 Mdot
.562 .15234 Mdot
.562 .15235 Mdot
.562 .15257 Mdot
.562 .15336 Mdot
.562 .1538 Mdot
.562 .154 Mdot
.562 .15436 Mdot
.562 .15445 Mdot
.562 .15459 Mdot
.562 .15567 Mdot
.562 .15635 Mdot
.562 .15713 Mdot
.562 .1574 Mdot
.562 .15802 Mdot
.562 .15821 Mdot
.562 .15825 Mdot
.562 .15978 Mdot
.562 .16013 Mdot
.562 .16074 Mdot
.562 .16108 Mdot
.562 .16134 Mdot
.562 .16193 Mdot
.562 .16199 Mdot
.562 .16257 Mdot
.562 .16374 Mdot
.562 .16382 Mdot
.562 .1643 Mdot
.562 .16446 Mdot
.562 .16457 Mdot
.562 .16465 Mdot
.562 .1661 Mdot
.562 .16656 Mdot
.562 .16664 Mdot
.562 .167 Mdot
.562 .16752 Mdot
.562 .16822 Mdot
.562 .16917 Mdot
.562 .1694 Mdot
.562 .16941 Mdot
.562 .16967 Mdot
.562 .17056 Mdot
.562 .17105 Mdot
.562 .17127 Mdot
.562 .17167 Mdot
.562 .17178 Mdot
.562 .17194 Mdot
.562 .17315 Mdot
.562 .17392 Mdot
.562 .17479 Mdot
.562 .17509 Mdot
.562 .17579 Mdot
.562 .176 Mdot
.562 .17605 Mdot
.562 .17777 Mdot
.562 .17816 Mdot
.562 .17885 Mdot
.562 .17923 Mdot
.562 .17952 Mdot
.562 .18018 Mdot
.562 .18025 Mdot
.562 .1809 Mdot
.562 .18222 Mdot
.562 .18231 Mdot
.562 .18284 Mdot
.562 .18302 Mdot
.562 .18316 Mdot
.562 .18324 Mdot
.562 .18487 Mdot
.562 .18539 Mdot
.562 .18548 Mdot
.562 .18588 Mdot
.562 .18647 Mdot
.562 .18725 Mdot
.562 .18832 Mdot
.562 .18858 Mdot
.562 .1886 Mdot
.562 .18888 Mdot
.562 .18988 Mdot
.562 .19043 Mdot
.562 .19069 Mdot
.562 .19114 Mdot
.562 .19126 Mdot
.562 .19144 Mdot
.562 .19279 Mdot
.562 .19366 Mdot
.562 .19464 Mdot
.562 .19498 Mdot
.562 .19576 Mdot
.562 .196 Mdot
.562 .19606 Mdot
.562 .19799 Mdot
.562 .19843 Mdot
.562 .1992 Mdot
.562 .19963 Mdot
.562 .19996 Mdot
.562 .2007 Mdot
.562 .20078 Mdot
.562 .20151 Mdot
.562 .20299 Mdot
.562 .20309 Mdot
.562 .20369 Mdot
.562 .20389 Mdot
.562 .20404 Mdot
.562 .20414 Mdot
.562 .20597 Mdot
.562 .20655 Mdot
.562 .20665 Mdot
.562 .2071 Mdot
.562 .20777 Mdot
.562 .20864 Mdot
.562 .20985 Mdot
.562 .21014 Mdot
.562 .21016 Mdot
.562 .21048 Mdot
.562 .2116 Mdot
.562 .21222 Mdot
.562 .21251 Mdot
.562 .21301 Mdot
.562 .21315 Mdot
.562 .21335 Mdot
.562 .21488 Mdot
.562 .21585 Mdot
.562 .21695 Mdot
.562 .21733 Mdot
.562 .21821 Mdot
.562 .21848 Mdot
.562 .21854 Mdot
.562 .22072 Mdot
.562 .22121 Mdot
.562 .22208 Mdot
.562 .22256 Mdot
.562 .22293 Mdot
.562 .22376 Mdot
.562 .22385 Mdot
.562 .22467 Mdot
.562 .22634 Mdot
.562 .22645 Mdot
.562 .22712 Mdot
.562 .22735 Mdot
.562 .22752 Mdot
.562 .22762 Mdot
.562 .22968 Mdot
.562 .23034 Mdot
.562 .23046 Mdot
.562 .23096 Mdot
.562 .23171 Mdot
.562 .23269 Mdot
.562 .23405 Mdot
.562 .23438 Mdot
.562 .23439 Mdot
.562 .23476 Mdot
.562 .23601 Mdot
.562 .23671 Mdot
.562 .23703 Mdot
.562 .2376 Mdot
.562 .23775 Mdot
.562 .23798 Mdot
.562 .23969 Mdot
.562 .24079 Mdot
.562 .24203 Mdot
.562 .24246 Mdot
.562 .24344 Mdot
.562 .24375 Mdot
.562 .24382 Mdot
.562 .24626 Mdot
.562 .24681 Mdot
.562 .24779 Mdot
.562 .24833 Mdot
.562 .24874 Mdot
.562 .24968 Mdot
.562 .24979 Mdot
.562 .2507 Mdot
.562 .25258 Mdot
.562 .2527 Mdot
.562 .25346 Mdot
.562 .25372 Mdot
.562 .25391 Mdot
.562 .25403 Mdot
.562 .25634 Mdot
.562 .25708 Mdot
.562 .25721 Mdot
.562 .25777 Mdot
.562 .25862 Mdot
.562 .25972 Mdot
.562 .26124 Mdot
.562 .26162 Mdot
.562 .26163 Mdot
.562 .26204 Mdot
.562 .26346 Mdot
.562 .26424 Mdot
.562 .2646 Mdot
.562 .26524 Mdot
.562 .26541 Mdot
.562 .26566 Mdot
.562 .26759 Mdot
.562 .26882 Mdot
.562 .27022 Mdot
.562 .2707 Mdot
.562 .2718 Mdot
.562 .27215 Mdot
.562 .27223 Mdot
.562 .27497 Mdot
.562 .27559 Mdot
.562 .2767 Mdot
.562 .2773 Mdot
.562 .27776 Mdot
.562 .27882 Mdot
.562 .27894 Mdot
.562 .27997 Mdot
.562 .28207 Mdot
.562 .28221 Mdot
.562 .28307 Mdot
.562 .28336 Mdot
.562 .28357 Mdot
.562 .2837 Mdot
.562 .2863 Mdot
.562 .28713 Mdot
.562 .28728 Mdot
.562 .28791 Mdot
.562 .28886 Mdot
.562 .2901 Mdot
.562 .29181 Mdot
.562 .29223 Mdot
.562 .29225 Mdot
.562 .29271 Mdot
.562 .2943 Mdot
.562 .29518 Mdot
.562 .29559 Mdot
.562 .2963 Mdot
.562 .2965 Mdot
.562 .29678 Mdot
.562 .29895 Mdot
.562 .30033 Mdot
.562 .3019 Mdot
.562 .30244 Mdot
.562 .30368 Mdot
.562 .30407 Mdot
.562 .30416 Mdot
.562 .30724 Mdot
.562 .30794 Mdot
.562 .30918 Mdot
.562 .30986 Mdot
.562 .31038 Mdot
.562 .31157 Mdot
.562 .3117 Mdot
.562 .31286 Mdot
.562 .31523 Mdot
.562 .31538 Mdot
.562 .31634 Mdot
.562 .31667 Mdot
.562 .3169 Mdot
.562 .31705 Mdot
.562 .31998 Mdot
.562 .32091 Mdot
.562 .32107 Mdot
.562 .32179 Mdot
.562 .32286 Mdot
.562 .32425 Mdot
.562 .32617 Mdot
.562 .32664 Mdot
.562 .32666 Mdot
.562 .32718 Mdot
.562 .32897 Mdot
.562 .32996 Mdot
.562 .33041 Mdot
.562 .33122 Mdot
.562 .33144 Mdot
.562 .33176 Mdot
.562 .33419 Mdot
.562 .33574 Mdot
.562 .33751 Mdot
.562 .33812 Mdot
.562 .33951 Mdot
.562 .33995 Mdot
.562 .34005 Mdot
.562 .34352 Mdot
.562 .3443 Mdot
.562 .3457 Mdot
.562 .34645 Mdot
.562 .34705 Mdot
.564 .01566 Mdot
.564 .01579 Mdot
.564 .01592 Mdot
.564 .01608 Mdot
.564 .01625 Mdot
.564 .01645 Mdot
.564 .01667 Mdot
.564 .01692 Mdot
.564 .0172 Mdot
.564 .01752 Mdot
.564 .01764 Mdot
.564 .01788 Mdot
.564 .01802 Mdot
.564 .01829 Mdot
.564 .01844 Mdot
.564 .01874 Mdot
.564 .01892 Mdot
.564 .01926 Mdot
.564 .01945 Mdot
.564 .01984 Mdot
.564 .02006 Mdot
.564 .02041 Mdot
.564 .0205 Mdot
.564 .02075 Mdot
.564 .02114 Mdot
.564 .02124 Mdot
.564 .02152 Mdot
.564 .02196 Mdot
.564 .02207 Mdot
.564 .02234 Mdot
.564 .02239 Mdot
.564 .02266 Mdot
.564 .02289 Mdot
.564 .02301 Mdot
.564 .02317 Mdot
.564 .02331 Mdot
.564 .02337 Mdot
.564 .02368 Mdot
.564 .02394 Mdot
.564 .02396 Mdot
.564 .02408 Mdot
.564 .02409 Mdot
.564 .02426 Mdot
.564 .02441 Mdot
.564 .02448 Mdot
.564 .02483 Mdot
.564 .02512 Mdot
.564 .02514 Mdot
.564 .02527 Mdot
.564 .02529 Mdot
.564 .02548 Mdot
.564 .02565 Mdot
.564 .02573 Mdot
.564 .02612 Mdot
.564 .02645 Mdot
.564 .02648 Mdot
.564 .02663 Mdot
.564 .02664 Mdot
.564 .02686 Mdot
.564 .02705 Mdot
.564 .02714 Mdot
.564 .02758 Mdot
.564 .02766 Mdot
.564 .02795 Mdot
.564 .02798 Mdot
.564 .02815 Mdot
.564 .02817 Mdot
.564 .02841 Mdot
.564 .02841 Mdot
.564 .02856 Mdot
.564 .02863 Mdot
.564 .02873 Mdot
.564 .02883 Mdot
.564 .02923 Mdot
.564 .02931 Mdot
.564 .02964 Mdot
.564 .02968 Mdot
.564 .02987 Mdot
.564 .02989 Mdot
.564 .03016 Mdot
.564 .03017 Mdot
.564 .03033 Mdot
.564 .03041 Mdot
.564 .03052 Mdot
.564 .03061 Mdot
.564 .03063 Mdot
.564 .03108 Mdot
.564 .03111 Mdot
.564 .03118 Mdot
.564 .03155 Mdot
.564 .0316 Mdot
.564 .03181 Mdot
.564 .03183 Mdot
.564 .03214 Mdot
.564 .03215 Mdot
.564 .03233 Mdot
.564 .03242 Mdot
.564 .03254 Mdot
.564 .03265 Mdot
.564 .03267 Mdot
.564 .03271 Mdot
.564 .03318 Mdot
.564 .03321 Mdot
.564 .03329 Mdot
.564 .03371 Mdot
.564 .03376 Mdot
.564 .034 Mdot
.564 .03402 Mdot
.564 .03412 Mdot
.564 .03437 Mdot
.564 .03438 Mdot
.564 .03458 Mdot
.564 .03469 Mdot
.564 .03482 Mdot
.564 .03494 Mdot
.564 .03497 Mdot
.564 .03502 Mdot
.564 .03513 Mdot
.564 .03521 Mdot
.564 .03554 Mdot
.564 .03558 Mdot
.564 .03567 Mdot
.564 .03614 Mdot
.564 .0362 Mdot
.564 .03647 Mdot
.564 .03649 Mdot
.564 .03661 Mdot
.564 .03689 Mdot
.564 .03689 Mdot
.564 .03713 Mdot
.564 .03717 Mdot
.564 .03725 Mdot
.564 .0374 Mdot
.564 .03753 Mdot
.564 .03756 Mdot
.564 .03761 Mdot
.564 .03775 Mdot
.564 .03783 Mdot
.564 .03821 Mdot
.564 .03825 Mdot
.564 .03825 Mdot
.564 .03835 Mdot
.564 .03885 Mdot
.564 .03888 Mdot
.564 .03894 Mdot
.564 .03895 Mdot
.564 .03925 Mdot
.564 .03928 Mdot
.564 .03941 Mdot
.564 .03956 Mdot
.564 .03965 Mdot
.564 .03973 Mdot
.564 .03973 Mdot
.564 .03999 Mdot
.564 .04 Mdot
.564 .04005 Mdot
.564 .04013 Mdot
.564 .0403 Mdot
.564 .04045 Mdot
.564 .04048 Mdot
.564 .04055 Mdot
.564 .04069 Mdot
.564 .04079 Mdot
.564 .04086 Mdot
.564 .04121 Mdot
.564 .04126 Mdot
.564 .04126 Mdot
.564 .04138 Mdot
.564 .04193 Mdot
.564 .04197 Mdot
.564 .04204 Mdot
.564 .04205 Mdot
.564 .04239 Mdot
.564 .04243 Mdot
.564 .04257 Mdot
.564 .04273 Mdot
.564 .04285 Mdot
.564 .04293 Mdot
.564 .04293 Mdot
.564 .04322 Mdot
.564 .04323 Mdot
.564 .04328 Mdot
.564 .04329 Mdot
.564 .04338 Mdot
.564 .04358 Mdot
.564 .04363 Mdot
.564 .04375 Mdot
.564 .04378 Mdot
.564 .04385 Mdot
.564 .04398 Mdot
.564 .04402 Mdot
.564 .04413 Mdot
.564 .04421 Mdot
.564 .04461 Mdot
.564 .04466 Mdot
.564 .04466 Mdot
.564 .04479 Mdot
.564 .04539 Mdot
.564 .04542 Mdot
.564 .04546 Mdot
.564 .04553 Mdot
.564 .04555 Mdot
.564 .04587 Mdot
.564 .04594 Mdot
.564 .04597 Mdot
.564 .04613 Mdot
.564 .04632 Mdot
.564 .04645 Mdot
.564 .04654 Mdot
.564 .04655 Mdot
.564 .04672 Mdot
.564 .04687 Mdot
.564 .04688 Mdot
.564 .04694 Mdot
.564 .04695 Mdot
.564 .04705 Mdot
.564 .04727 Mdot
.564 .04733 Mdot
.564 .04746 Mdot
.564 .0475 Mdot
.564 .04758 Mdot
.564 .04773 Mdot
.564 .04777 Mdot
.564 .04789 Mdot
.564 .04798 Mdot
.564 .04838 Mdot
.564 .04843 Mdot
.564 .04849 Mdot
.564 .0485 Mdot
.564 .04864 Mdot
.564 .04884 Mdot
.564 .04912 Mdot
.564 .04931 Mdot
.564 .04935 Mdot
.564 .0494 Mdot
.564 .04948 Mdot
.564 .04949 Mdot
.564 .04985 Mdot
.564 .04993 Mdot
.564 .04995 Mdot
.564 .04997 Mdot
.564 .05015 Mdot
.564 .0502 Mdot
.564 .05037 Mdot
.564 .05051 Mdot
.564 .05061 Mdot
.564 .05062 Mdot
.564 .05082 Mdot
.564 .05099 Mdot
.564 .051 Mdot
.564 .05106 Mdot
.564 .05107 Mdot
.564 .05119 Mdot
.564 .05144 Mdot
.564 .05151 Mdot
.564 .05165 Mdot
.564 .0517 Mdot
.564 .05179 Mdot
.564 .05196 Mdot
.564 .052 Mdot
.564 .05214 Mdot
.564 .05224 Mdot
.564 .05268 Mdot
.564 .05275 Mdot
.564 .05281 Mdot
.564 .05282 Mdot
.564 .05298 Mdot
.564 .05321 Mdot
.564 .05352 Mdot
.564 .05374 Mdot
.564 .05378 Mdot
.564 .05384 Mdot
.564 .05393 Mdot
.564 .05394 Mdot
.564 .05435 Mdot
.564 .05444 Mdot
.564 .05446 Mdot
.564 .05449 Mdot
.564 .05469 Mdot
.564 .05475 Mdot
.564 .05493 Mdot
.564 .05509 Mdot
.564 .05521 Mdot
.564 .05522 Mdot
.564 .05544 Mdot
.564 .05556 Mdot
.564 .05563 Mdot
.564 .05564 Mdot
.564 .05571 Mdot
.564 .05572 Mdot
.564 .05586 Mdot
.564 .05614 Mdot
.564 .05618 Mdot
.564 .05622 Mdot
.564 .05638 Mdot
.564 .05644 Mdot
.564 .05653 Mdot
.564 .05672 Mdot
.564 .05678 Mdot
.564 .05681 Mdot
.564 .0569 Mdot
.564 .05693 Mdot
.564 .05704 Mdot
.564 .05754 Mdot
.564 .05762 Mdot
.564 .05769 Mdot
.564 .0577 Mdot
.564 .05788 Mdot
.564 .05813 Mdot
.564 .05849 Mdot
.564 .05874 Mdot
.564 .05878 Mdot
.564 .05885 Mdot
.564 .05895 Mdot
.564 .05897 Mdot
.564 .05943 Mdot
.564 .05952 Mdot
.564 .05954 Mdot
.564 .05958 Mdot
.564 .05981 Mdot
.564 .05987 Mdot
.564 .06008 Mdot
.564 .06026 Mdot
.564 .06039 Mdot
.564 .0604 Mdot
.564 .06065 Mdot
.564 .06079 Mdot
.564 .06087 Mdot
.564 .06088 Mdot
.564 .06096 Mdot
.564 .06097 Mdot
.564 .06113 Mdot
.564 .06144 Mdot
.564 .06149 Mdot
.564 .06153 Mdot
.564 .06171 Mdot
.564 .06178 Mdot
.564 .06189 Mdot
.564 .0621 Mdot
.564 .06216 Mdot
.564 .0622 Mdot
.564 .0623 Mdot
.564 .06234 Mdot
.564 .06246 Mdot
.564 .06303 Mdot
.564 .06311 Mdot
.564 .06319 Mdot
.564 .0632 Mdot
.564 .0634 Mdot
.564 .06369 Mdot
.564 .06409 Mdot
.564 .06437 Mdot
.564 .06442 Mdot
.564 .0645 Mdot
.564 .06461 Mdot
.564 .06463 Mdot
.564 .06515 Mdot
.564 .06526 Mdot
.564 .06528 Mdot
.564 .06532 Mdot
.564 .06558 Mdot
.564 .06565 Mdot
.564 .06588 Mdot
.564 .06609 Mdot
.564 .06624 Mdot
.564 .06625 Mdot
.564 .06653 Mdot
.564 .06669 Mdot
.564 .06678 Mdot
.564 .06679 Mdot
.564 .06688 Mdot
.564 .0669 Mdot
.564 .06707 Mdot
.564 .06742 Mdot
.564 .06747 Mdot
.564 .06753 Mdot
.564 .06773 Mdot
.564 .0678 Mdot
.564 .06792 Mdot
.564 .06816 Mdot
.564 .06823 Mdot
.564 .06827 Mdot
.564 .06839 Mdot
.564 .06843 Mdot
.564 .06857 Mdot
.564 .06921 Mdot
.564 .0693 Mdot
.564 .06939 Mdot
.564 .06941 Mdot
.564 .06964 Mdot
.564 .06996 Mdot
.564 .07041 Mdot
.564 .07073 Mdot
.564 .07078 Mdot
.564 .07087 Mdot
.564 .071 Mdot
.564 .07102 Mdot
.564 .0716 Mdot
.564 .07173 Mdot
.564 .07175 Mdot
.564 .0718 Mdot
.564 .07209 Mdot
.564 .07217 Mdot
.564 .07243 Mdot
.564 .07267 Mdot
.564 .07283 Mdot
.564 .07284 Mdot
.564 .07317 Mdot
.564 .07334 Mdot
.564 .07344 Mdot
.564 .07346 Mdot
.564 .07356 Mdot
.564 .07357 Mdot
.564 .07377 Mdot
.564 .07417 Mdot
.564 .07423 Mdot
.564 .07428 Mdot
.564 .07452 Mdot
.564 .07459 Mdot
.564 .07473 Mdot
.564 .07501 Mdot
.564 .07508 Mdot
.564 .07513 Mdot
.564 .07526 Mdot
.564 .07531 Mdot
.564 .07547 Mdot
.564 .07619 Mdot
.564 .07629 Mdot
.564 .07639 Mdot
.564 .07641 Mdot
.564 .07666 Mdot
.564 .07703 Mdot
.564 .07754 Mdot
.564 .0779 Mdot
.564 .07796 Mdot
.564 .07806 Mdot
.564 .0782 Mdot
.564 .07822 Mdot
.564 .07889 Mdot
.564 .07903 Mdot
.564 .07905 Mdot
.564 .0791 Mdot
.564 .07943 Mdot
.564 .07953 Mdot
.564 .07982 Mdot
.564 .08008 Mdot
.564 .08027 Mdot
.564 .08028 Mdot
.564 .08065 Mdot
.564 .08085 Mdot
.564 .08096 Mdot
.564 .08098 Mdot
.564 .08109 Mdot
.564 .08111 Mdot
.564 .08133 Mdot
.564 .08178 Mdot
.564 .08185 Mdot
.564 .08191 Mdot
.564 .08217 Mdot
.564 .08226 Mdot
.564 .08242 Mdot
.564 .08272 Mdot
.564 .08281 Mdot
.564 .08286 Mdot
.564 .08301 Mdot
.564 .08306 Mdot
.564 .08324 Mdot
.564 .08405 Mdot
.564 .08417 Mdot
.564 .08429 Mdot
.564 .0843 Mdot
.564 .08459 Mdot
.564 .08501 Mdot
.564 .08559 Mdot
.564 .08599 Mdot
.564 .08606 Mdot
.564 .08616 Mdot
.564 .08633 Mdot
.564 .08635 Mdot
.564 .0871 Mdot
.564 .08726 Mdot
.564 .08729 Mdot
.564 .08734 Mdot
.564 .08772 Mdot
.564 .08782 Mdot
.564 .08816 Mdot
.564 .08845 Mdot
.564 .08866 Mdot
.564 .08868 Mdot
.564 .08909 Mdot
.564 .08931 Mdot
.564 .08944 Mdot
.564 .08946 Mdot
.564 .08959 Mdot
.564 .08961 Mdot
.564 .08986 Mdot
.564 .09036 Mdot
.564 .09044 Mdot
.564 .09051 Mdot
.564 .0908 Mdot
.564 .0909 Mdot
.564 .09108 Mdot
.564 .09143 Mdot
.564 .09153 Mdot
.564 .09158 Mdot
.564 .09176 Mdot
.564 .09181 Mdot
.564 .09202 Mdot
.564 .09293 Mdot
.564 .09306 Mdot
.564 .09319 Mdot
.564 .09321 Mdot
.564 .09354 Mdot
.564 .09401 Mdot
.564 .09466 Mdot
.564 .09511 Mdot
.564 .09519 Mdot
.564 .09531 Mdot
.564 .09549 Mdot
.564 .09552 Mdot
.564 .09637 Mdot
.564 .09654 Mdot
.564 .09658 Mdot
.564 .09664 Mdot
.564 .09706 Mdot
.564 .09718 Mdot
.564 .09756 Mdot
.564 .09789 Mdot
.564 .09813 Mdot
.564 .09814 Mdot
.564 .09861 Mdot
.564 .09886 Mdot
.564 .099 Mdot
.564 .09902 Mdot
.564 .09917 Mdot
.564 .09919 Mdot
.564 .09948 Mdot
.564 .10005 Mdot
.564 .10013 Mdot
.564 .10021 Mdot
.564 .10054 Mdot
.564 .10066 Mdot
.564 .10086 Mdot
.564 .10125 Mdot
.564 .10136 Mdot
.564 .10142 Mdot
.564 .10162 Mdot
.564 .10168 Mdot
.564 .10294 Mdot
.564 .10309 Mdot
.564 .10323 Mdot
.564 .10326 Mdot
.564 .10363 Mdot
.564 .10415 Mdot
.564 .10489 Mdot
.564 .1054 Mdot
.564 .10549 Mdot
.564 .10562 Mdot
.564 .10583 Mdot
.564 .10587 Mdot
.564 .10682 Mdot
.564 .10702 Mdot
.564 .10706 Mdot
.564 .10713 Mdot
.564 .1076 Mdot
.564 .10773 Mdot
.564 .10816 Mdot
.564 .10853 Mdot
.564 .1088 Mdot
.564 .10882 Mdot
.564 .10935 Mdot
.564 .10963 Mdot
.564 .10979 Mdot
.564 .10981 Mdot
.564 .10998 Mdot
.564 .11001 Mdot
.564 .11033 Mdot
.564 .11097 Mdot
.564 .11106 Mdot
.564 .11116 Mdot
.564 .11153 Mdot
.564 .11166 Mdot
.564 .11188 Mdot
.564 .11232 Mdot
.564 .11245 Mdot
.564 .11252 Mdot
.564 .11274 Mdot
.564 .11281 Mdot
.564 .11423 Mdot
.564 .1144 Mdot
.564 .11457 Mdot
.564 .11459 Mdot
.564 .11501 Mdot
.564 .1156 Mdot
.564 .11643 Mdot
.564 .11701 Mdot
.564 .11711 Mdot
.564 .11726 Mdot
.564 .1175 Mdot
.564 .11754 Mdot
.564 .11861 Mdot
.564 .11883 Mdot
.564 .11888 Mdot
.564 .11896 Mdot
.564 .11949 Mdot
.564 .11964 Mdot
.564 .12012 Mdot
.564 .12054 Mdot
.564 .12085 Mdot
.564 .12087 Mdot
.564 .12146 Mdot
.564 .12178 Mdot
.564 .12196 Mdot
.564 .12199 Mdot
.564 .12217 Mdot
.564 .1222 Mdot
.564 .12256 Mdot
.564 .12329 Mdot
.564 .1234 Mdot
.564 .1235 Mdot
.564 .12392 Mdot
.564 .12407 Mdot
.564 .12432 Mdot
.564 .12482 Mdot
.564 .12496 Mdot
.564 .12504 Mdot
.564 .12529 Mdot
.564 .12537 Mdot
.564 .12697 Mdot
.564 .12716 Mdot
.564 .12735 Mdot
.564 .12737 Mdot
.564 .12785 Mdot
.564 .12852 Mdot
.564 .12945 Mdot
.564 .1301 Mdot
.564 .13021 Mdot
.564 .13039 Mdot
.564 .13065 Mdot
.564 .1307 Mdot
.564 .1319 Mdot
.564 .13216 Mdot
.564 .13221 Mdot
.564 .1323 Mdot
.564 .1329 Mdot
.564 .13307 Mdot
.564 .13361 Mdot
.564 .13409 Mdot
.564 .13443 Mdot
.564 .13446 Mdot
.564 .13512 Mdot
.564 .13549 Mdot
.564 .13569 Mdot
.564 .13572 Mdot
.564 .13593 Mdot
.564 .13596 Mdot
.564 .13607 Mdot
.564 .13637 Mdot
.564 .13719 Mdot
.564 .13731 Mdot
.564 .13743 Mdot
.564 .1379 Mdot
.564 .13806 Mdot
.564 .13835 Mdot
.564 .13891 Mdot
.564 .13907 Mdot
.564 .13916 Mdot
.564 .13944 Mdot
.564 .13953 Mdot
.564 .14134 Mdot
.564 .14155 Mdot
.564 .14176 Mdot
.564 .1418 Mdot
.564 .14233 Mdot
.564 .14308 Mdot
.564 .14414 Mdot
.564 .14487 Mdot
.564 .145 Mdot
.564 .14519 Mdot
.564 .14549 Mdot
.564 .14554 Mdot
.564 .1469 Mdot
.564 .14719 Mdot
.564 .14725 Mdot
.564 .14735 Mdot
.564 .14803 Mdot
.564 .14822 Mdot
.564 .14883 Mdot
.564 .14937 Mdot
.564 .14976 Mdot
.564 .14978 Mdot
.564 .15053 Mdot
.564 .15095 Mdot
.564 .15117 Mdot
.564 .15121 Mdot
.564 .15144 Mdot
.564 .15148 Mdot
.564 .15161 Mdot
.564 .15194 Mdot
.564 .15286 Mdot
.564 .153 Mdot
.564 .15313 Mdot
.564 .15367 Mdot
.564 .15385 Mdot
.564 .15418 Mdot
.564 .15481 Mdot
.564 .15498 Mdot
.564 .15509 Mdot
.564 .15541 Mdot
.564 .15551 Mdot
.564 .15755 Mdot
.564 .15779 Mdot
.564 .15803 Mdot
.564 .15806 Mdot
.564 .15866 Mdot
.564 .15951 Mdot
.564 .1607 Mdot
.564 .16153 Mdot
.564 .16167 Mdot
.564 .16189 Mdot
.564 .16223 Mdot
.564 .16229 Mdot
.564 .16382 Mdot
.564 .16415 Mdot
.564 .16421 Mdot
.564 .16433 Mdot
.564 .1651 Mdot
.564 .16531 Mdot
.564 .166 Mdot
.564 .16661 Mdot
.564 .16704 Mdot
.564 .16707 Mdot
.564 .16792 Mdot
.564 .16838 Mdot
.564 .16864 Mdot
.564 .16868 Mdot
.564 .16894 Mdot
.564 .16899 Mdot
.564 .16913 Mdot
.564 .16951 Mdot
.564 .17055 Mdot
.564 .1707 Mdot
.564 .17085 Mdot
.564 .17145 Mdot
.564 .17166 Mdot
.564 .17203 Mdot
.564 .17274 Mdot
.564 .17294 Mdot
.564 .17306 Mdot
.564 .17342 Mdot
.564 .17353 Mdot
.564 .17583 Mdot
.564 .1761 Mdot
.564 .17637 Mdot
.564 .17641 Mdot
.564 .17709 Mdot
.564 .17805 Mdot
.564 .17939 Mdot
.564 .18033 Mdot
.564 .18048 Mdot
.564 .18073 Mdot
.564 .18111 Mdot
.564 .18118 Mdot
.564 .18291 Mdot
.564 .18328 Mdot
.564 .18335 Mdot
.564 .18348 Mdot
.564 .18434 Mdot
.564 .18459 Mdot
.564 .18536 Mdot
.564 .18605 Mdot
.564 .18654 Mdot
.564 .18658 Mdot
.564 .18753 Mdot
.564 .18805 Mdot
.564 .18834 Mdot
.564 .18839 Mdot
.564 .18869 Mdot
.564 .18873 Mdot
.564 .1889 Mdot
.564 .18932 Mdot
.564 .19049 Mdot
.564 .19067 Mdot
.564 .19084 Mdot
.564 .19152 Mdot
.564 .19175 Mdot
.564 .19216 Mdot
.564 .19297 Mdot
.564 .19319 Mdot
.564 .19333 Mdot
.564 .19373 Mdot
.564 .19386 Mdot
.564 .19646 Mdot
.564 .19676 Mdot
.564 .19706 Mdot
.564 .19711 Mdot
.564 .19787 Mdot
.564 .19895 Mdot
.564 .20047 Mdot
.564 .20152 Mdot
.564 .2017 Mdot
.564 .20198 Mdot
.564 .20241 Mdot
.564 .20248 Mdot
.564 .20444 Mdot
.564 .20485 Mdot
.564 .20493 Mdot
.564 .20508 Mdot
.564 .20606 Mdot
.564 .20633 Mdot
.564 .20721 Mdot
.564 .20798 Mdot
.564 .20853 Mdot
.564 .20857 Mdot
.564 .20965 Mdot
.564 .21024 Mdot
.564 .21056 Mdot
.564 .21061 Mdot
.564 .21095 Mdot
.564 .21101 Mdot
.564 .21119 Mdot
.564 .21167 Mdot
.564 .21299 Mdot
.564 .21319 Mdot
.564 .21338 Mdot
.564 .21415 Mdot
.564 .21441 Mdot
.564 .21488 Mdot
.564 .21578 Mdot
.564 .21604 Mdot
.564 .21619 Mdot
.564 .21664 Mdot
.564 .21679 Mdot
.564 .21972 Mdot
.564 .22006 Mdot
.564 .2204 Mdot
.564 .22045 Mdot
.564 .22132 Mdot
.564 .22254 Mdot
.564 .22425 Mdot
.564 .22544 Mdot
.564 .22564 Mdot
.564 .22595 Mdot
.564 .22644 Mdot
.564 .22652 Mdot
.564 .22872 Mdot
.564 .22919 Mdot
.564 .22928 Mdot
.564 .22945 Mdot
.564 .23055 Mdot
.564 .23086 Mdot
.564 .23185 Mdot
.564 .23272 Mdot
.564 .23334 Mdot
.564 .23339 Mdot
.564 .2346 Mdot
.564 .23527 Mdot
.564 .23563 Mdot
.564 .23569 Mdot
.564 .23607 Mdot
.564 .23613 Mdot
.564 .23634 Mdot
.564 .23688 Mdot
.564 .23837 Mdot
.564 .23859 Mdot
.564 .23881 Mdot
.564 .23968 Mdot
.564 .23997 Mdot
.564 .2405 Mdot
.564 .24152 Mdot
.564 .24181 Mdot
.564 .24198 Mdot
.564 .24249 Mdot
.564 .24265 Mdot
.564 .24596 Mdot
.564 .24634 Mdot
.564 .24673 Mdot
.564 .24679 Mdot
.564 .24776 Mdot
.564 .24914 Mdot
.564 .25107 Mdot
.564 .25241 Mdot
.564 .25263 Mdot
.564 .25299 Mdot
.564 .25354 Mdot
.564 .25363 Mdot
.564 .25612 Mdot
.564 .25664 Mdot
.564 .25674 Mdot
.564 .25693 Mdot
.564 .25817 Mdot
.564 .25852 Mdot
.564 .25964 Mdot
.564 .26062 Mdot
.564 .26132 Mdot
.564 .26138 Mdot
.564 .26274 Mdot
.564 .2635 Mdot
.564 .26391 Mdot
.564 .26397 Mdot
.564 .26441 Mdot
.564 .26448 Mdot
.564 .26471 Mdot
.564 .26532 Mdot
.564 .267 Mdot
.564 .26725 Mdot
.564 .26749 Mdot
.564 .26847 Mdot
.564 .2688 Mdot
.564 .2694 Mdot
.564 .27055 Mdot
.564 .27087 Mdot
.564 .27107 Mdot
.564 .27165 Mdot
.564 .27183 Mdot
.564 .27556 Mdot
.564 .27599 Mdot
.564 .27643 Mdot
.564 .27649 Mdot
.564 .27759 Mdot
.564 .27914 Mdot
.564 .28132 Mdot
.564 .28283 Mdot
.564 .28309 Mdot
.564 .28349 Mdot
.564 .28411 Mdot
.564 .28421 Mdot
.564 .28702 Mdot
.564 .28761 Mdot
.564 .28772 Mdot
.564 .28793 Mdot
.564 .28934 Mdot
.564 .28973 Mdot
.564 .29099 Mdot
.564 .2921 Mdot
.564 .29289 Mdot
.564 .29295 Mdot
.564 .29449 Mdot
.564 .29534 Mdot
.564 .29581 Mdot
.564 .29588 Mdot
.564 .29637 Mdot
.564 .29644 Mdot
.564 .29671 Mdot
.564 .29739 Mdot
.564 .29929 Mdot
.564 .29957 Mdot
.564 .29985 Mdot
.564 .30095 Mdot
.564 .30133 Mdot
.564 .302 Mdot
.564 .3033 Mdot
.564 .30366 Mdot
.564 .30388 Mdot
.564 .30453 Mdot
.564 .30474 Mdot
.564 .30895 Mdot
.564 .30943 Mdot
.564 .30993 Mdot
.564 .31 Mdot
.564 .31124 Mdot
.564 .31299 Mdot
.564 .31544 Mdot
.564 .31715 Mdot
.564 .31744 Mdot
.564 .3179 Mdot
.564 .31859 Mdot
.564 .31871 Mdot
.564 .32187 Mdot
.564 .32254 Mdot
.564 .32267 Mdot
.564 .32291 Mdot
.564 .32449 Mdot
.564 .32493 Mdot
.564 .32635 Mdot
.564 .3276 Mdot
.564 .3285 Mdot
.564 .32856 Mdot
.564 .3303 Mdot
.564 .33126 Mdot
.564 .33179 Mdot
.564 .33187 Mdot
.564 .33242 Mdot
.564 .33251 Mdot
.564 .3328 Mdot
.564 .33357 Mdot
.564 .33572 Mdot
.564 .33603 Mdot
.564 .33634 Mdot
.564 .33759 Mdot
.564 .33801 Mdot
.564 .33877 Mdot
.564 .34024 Mdot
.564 .34065 Mdot
.564 .3409 Mdot
.564 .34163 Mdot
.564 .34186 Mdot
.564 .34661 Mdot
.564 .34716 Mdot
.564 .34771 Mdot
.564 .3478 Mdot
.566 .01608 Mdot
.566 .01626 Mdot
.566 .01633 Mdot
.566 .01647 Mdot
.566 .01654 Mdot
.566 .0167 Mdot
.566 .01678 Mdot
.566 .01694 Mdot
.566 .01696 Mdot
.566 .01706 Mdot
.566 .01724 Mdot
.566 .01726 Mdot
.566 .0173 Mdot
.566 .01736 Mdot
.566 .01757 Mdot
.566 .01759 Mdot
.566 .01764 Mdot
.566 .01771 Mdot
.566 .01794 Mdot
.566 .01797 Mdot
.566 .01802 Mdot
.566 .01811 Mdot
.566 .01837 Mdot
.566 .0184 Mdot
.566 .01846 Mdot
.566 .01856 Mdot
.566 .01885 Mdot
.566 .01889 Mdot
.566 .01896 Mdot
.566 .01906 Mdot
.566 .01907 Mdot
.566 .0194 Mdot
.566 .01944 Mdot
.566 .01952 Mdot
.566 .01964 Mdot
.566 .01964 Mdot
.566 .02002 Mdot
.566 .02006 Mdot
.566 .02015 Mdot
.566 .02028 Mdot
.566 .02029 Mdot
.566 .02029 Mdot
.566 .02072 Mdot
.566 .02077 Mdot
.566 .02087 Mdot
.566 .02102 Mdot
.566 .02102 Mdot
.566 .02103 Mdot
.566 .02151 Mdot
.566 .02157 Mdot
.566 .02168 Mdot
.566 .02185 Mdot
.566 .02186 Mdot
.566 .02186 Mdot
.566 .02241 Mdot
.566 .02247 Mdot
.566 .0226 Mdot
.566 .02276 Mdot
.566 .02279 Mdot
.566 .0228 Mdot
.566 .0228 Mdot
.566 .02342 Mdot
.566 .0235 Mdot
.566 .02364 Mdot
.566 .02382 Mdot
.566 .02386 Mdot
.566 .02387 Mdot
.566 .02387 Mdot
.566 .02421 Mdot
.566 .02457 Mdot
.566 .02465 Mdot
.566 .02482 Mdot
.566 .02503 Mdot
.566 .02507 Mdot
.566 .02508 Mdot
.566 .02508 Mdot
.566 .02547 Mdot
.566 .02587 Mdot
.566 .02595 Mdot
.566 .02597 Mdot
.566 .02609 Mdot
.566 .02615 Mdot
.566 .02639 Mdot
.566 .02643 Mdot
.566 .02644 Mdot
.566 .02645 Mdot
.566 .02689 Mdot
.566 .02735 Mdot
.566 .02743 Mdot
.566 .02745 Mdot
.566 .02755 Mdot
.566 .02759 Mdot
.566 .02766 Mdot
.566 .02793 Mdot
.566 .02798 Mdot
.566 .02799 Mdot
.566 .028 Mdot
.566 .02849 Mdot
.566 .02897 Mdot
.566 .02901 Mdot
.566 .02911 Mdot
.566 .02913 Mdot
.566 .02924 Mdot
.566 .02929 Mdot
.566 .02937 Mdot
.566 .02961 Mdot
.566 .02967 Mdot
.566 .02973 Mdot
.566 .02974 Mdot
.566 .02975 Mdot
.566 .03031 Mdot
.566 .03085 Mdot
.566 .0309 Mdot
.566 .03101 Mdot
.566 .03104 Mdot
.566 .03116 Mdot
.566 .03121 Mdot
.566 .0313 Mdot
.566 .03158 Mdot
.566 .03165 Mdot
.566 .03171 Mdot
.566 .03173 Mdot
.566 .03173 Mdot
.566 .0322 Mdot
.566 .03237 Mdot
.566 .03298 Mdot
.566 .03304 Mdot
.566 .03316 Mdot
.566 .03319 Mdot
.566 .03333 Mdot
.566 .03333 Mdot
.566 .03339 Mdot
.566 .03349 Mdot
.566 .0338 Mdot
.566 .03388 Mdot
.566 .03396 Mdot
.566 .03397 Mdot
.566 .03398 Mdot
.566 .03451 Mdot
.566 .0347 Mdot
.566 .03539 Mdot
.566 .03545 Mdot
.566 .03559 Mdot
.566 .03563 Mdot
.566 .03579 Mdot
.566 .03579 Mdot
.566 .03586 Mdot
.566 .03595 Mdot
.566 .03597 Mdot
.566 .03632 Mdot
.566 .03641 Mdot
.566 .0365 Mdot
.566 .03652 Mdot
.566 .03652 Mdot
.566 .03668 Mdot
.566 .03712 Mdot
.566 .03733 Mdot
.566 .03734 Mdot
.566 .03798 Mdot
.566 .03812 Mdot
.566 .03819 Mdot
.566 .03835 Mdot
.566 .03839 Mdot
.566 .03857 Mdot
.566 .03857 Mdot
.566 .03865 Mdot
.566 .03875 Mdot
.566 .03878 Mdot
.566 .03914 Mdot
.566 .03917 Mdot
.566 .03927 Mdot
.566 .03937 Mdot
.566 .03939 Mdot
.566 .0394 Mdot
.566 .03958 Mdot
.566 .04008 Mdot
.566 .04031 Mdot
.566 .04032 Mdot
.566 .04105 Mdot
.566 .04111 Mdot
.566 .04116 Mdot
.566 .04121 Mdot
.566 .04129 Mdot
.566 .04147 Mdot
.566 .04151 Mdot
.566 .04152 Mdot
.566 .04172 Mdot
.566 .04172 Mdot
.566 .0418 Mdot
.566 .04192 Mdot
.566 .04195 Mdot
.566 .04216 Mdot
.566 .04219 Mdot
.566 .04237 Mdot
.566 .0424 Mdot
.566 .04252 Mdot
.566 .04263 Mdot
.566 .04265 Mdot
.566 .04266 Mdot
.566 .04287 Mdot
.566 .04289 Mdot
.566 .04343 Mdot
.566 .04369 Mdot
.566 .04371 Mdot
.566 .04453 Mdot
.566 .04459 Mdot
.566 .04465 Mdot
.566 .0447 Mdot
.566 .0448 Mdot
.566 .04496 Mdot
.566 .04497 Mdot
.566 .045 Mdot
.566 .04505 Mdot
.566 .04505 Mdot
.566 .04529 Mdot
.566 .04529 Mdot
.566 .04538 Mdot
.566 .04551 Mdot
.566 .04555 Mdot
.566 .04578 Mdot
.566 .04581 Mdot
.566 .04602 Mdot
.566 .04606 Mdot
.566 .04609 Mdot
.566 .04619 Mdot
.566 .04631 Mdot
.566 .04634 Mdot
.566 .04635 Mdot
.566 .04658 Mdot
.566 .04661 Mdot
.566 .04722 Mdot
.566 .04735 Mdot
.566 .04752 Mdot
.566 .04753 Mdot
.566 .04767 Mdot
.566 .04847 Mdot
.566 .04854 Mdot
.566 .0486 Mdot
.566 .04866 Mdot
.566 .04877 Mdot
.566 .04896 Mdot
.566 .04896 Mdot
.566 .049 Mdot
.566 .04906 Mdot
.566 .04906 Mdot
.566 .04932 Mdot
.566 .04932 Mdot
.566 .04943 Mdot
.566 .04958 Mdot
.566 .04962 Mdot
.566 .04988 Mdot
.566 .04992 Mdot
.566 .05015 Mdot
.566 .05019 Mdot
.566 .05023 Mdot
.566 .05034 Mdot
.566 .05048 Mdot
.566 .05051 Mdot
.566 .05052 Mdot
.566 .05079 Mdot
.566 .05082 Mdot
.566 .05088 Mdot
.566 .05111 Mdot
.566 .05124 Mdot
.566 .05151 Mdot
.566 .05166 Mdot
.566 .05185 Mdot
.566 .05186 Mdot
.566 .05202 Mdot
.566 .05292 Mdot
.566 .053 Mdot
.566 .05307 Mdot
.566 .05314 Mdot
.566 .05327 Mdot
.566 .05348 Mdot
.566 .05348 Mdot
.566 .05352 Mdot
.566 .05359 Mdot
.566 .05359 Mdot
.566 .05367 Mdot
.566 .05389 Mdot
.566 .05389 Mdot
.566 .05401 Mdot
.566 .05415 Mdot
.566 .05418 Mdot
.566 .05422 Mdot
.566 .05453 Mdot
.566 .05455 Mdot
.566 .05456 Mdot
.566 .05482 Mdot
.566 .05488 Mdot
.566 .05492 Mdot
.566 .05504 Mdot
.566 .0552 Mdot
.566 .05524 Mdot
.566 .05525 Mdot
.566 .05555 Mdot
.566 .05558 Mdot
.566 .05566 Mdot
.566 .0557 Mdot
.566 .05591 Mdot
.566 .05606 Mdot
.566 .05636 Mdot
.566 .05654 Mdot
.566 .05675 Mdot
.566 .05677 Mdot
.566 .05695 Mdot
.566 .0572 Mdot
.566 .05751 Mdot
.566 .05765 Mdot
.566 .05797 Mdot
.566 .05806 Mdot
.566 .05813 Mdot
.566 .05821 Mdot
.566 .05835 Mdot
.566 .05859 Mdot
.566 .0586 Mdot
.566 .05864 Mdot
.566 .05872 Mdot
.566 .05872 Mdot
.566 .05881 Mdot
.566 .05906 Mdot
.566 .05906 Mdot
.566 .0592 Mdot
.566 .05935 Mdot
.566 .05939 Mdot
.566 .05944 Mdot
.566 .05978 Mdot
.566 .05981 Mdot
.566 .05982 Mdot
.566 .06012 Mdot
.566 .06018 Mdot
.566 .06023 Mdot
.566 .06037 Mdot
.566 .06055 Mdot
.566 .06059 Mdot
.566 .0606 Mdot
.566 .06094 Mdot
.566 .06098 Mdot
.566 .06106 Mdot
.566 .06111 Mdot
.566 .06135 Mdot
.566 .06152 Mdot
.566 .06186 Mdot
.566 .06206 Mdot
.566 .0623 Mdot
.566 .06232 Mdot
.566 .06252 Mdot
.566 .06271 Mdot
.566 .0628 Mdot
.566 .06316 Mdot
.566 .06332 Mdot
.566 .06367 Mdot
.566 .06378 Mdot
.566 .06386 Mdot
.566 .06395 Mdot
.566 .06411 Mdot
.566 .06438 Mdot
.566 .06439 Mdot
.566 .06444 Mdot
.566 .06453 Mdot
.566 .06453 Mdot
.566 .06463 Mdot
.566 .06491 Mdot
.566 .06492 Mdot
.566 .06507 Mdot
.566 .06524 Mdot
.566 .06529 Mdot
.566 .06534 Mdot
.566 .06573 Mdot
.566 .06576 Mdot
.566 .06578 Mdot
.566 .06611 Mdot
.566 .06618 Mdot
.566 .06623 Mdot
.566 .06639 Mdot
.566 .0666 Mdot
.566 .06664 Mdot
.566 .06666 Mdot
.566 .06704 Mdot
.566 .06708 Mdot
.566 .06718 Mdot
.566 .06723 Mdot
.566 .06751 Mdot
.566 .0677 Mdot
.566 .06808 Mdot
.566 .06831 Mdot
.566 .06858 Mdot
.566 .0686 Mdot
.566 .06883 Mdot
.566 .06905 Mdot
.566 .06915 Mdot
.566 .06955 Mdot
.566 .06973 Mdot
.566 .07014 Mdot
.566 .07025 Mdot
.566 .07035 Mdot
.566 .07045 Mdot
.566 .07063 Mdot
.566 .07094 Mdot
.566 .07095 Mdot
.566 .071 Mdot
.566 .0711 Mdot
.566 .07111 Mdot
.566 .07122 Mdot
.566 .07154 Mdot
.566 .07154 Mdot
.566 .07172 Mdot
.566 .07191 Mdot
.566 .07196 Mdot
.566 .07203 Mdot
.566 .07246 Mdot
.566 .0725 Mdot
.566 .07252 Mdot
.566 .0729 Mdot
.566 .07297 Mdot
.566 .07303 Mdot
.566 .07321 Mdot
.566 .07345 Mdot
.566 .07349 Mdot
.566 .07352 Mdot
.566 .07395 Mdot
.566 .074 Mdot
.566 .0741 Mdot
.566 .07417 Mdot
.566 .07448 Mdot
.566 .07469 Mdot
.566 .07513 Mdot
.566 .07538 Mdot
.566 .07569 Mdot
.566 .07572 Mdot
.566 .07597 Mdot
.566 .07622 Mdot
.566 .07634 Mdot
.566 .07679 Mdot
.566 .07699 Mdot
.566 .07745 Mdot
.566 .07758 Mdot
.566 .0777 Mdot
.566 .07781 Mdot
.566 .07802 Mdot
.566 .07836 Mdot
.566 .07837 Mdot
.566 .07843 Mdot
.566 .07855 Mdot
.566 .07855 Mdot
.566 .07868 Mdot
.566 .07904 Mdot
.566 .07904 Mdot
.566 .07924 Mdot
.566 .07946 Mdot
.566 .07952 Mdot
.566 .07959 Mdot
.566 .08009 Mdot
.566 .08013 Mdot
.566 .08015 Mdot
.566 .08058 Mdot
.566 .08066 Mdot
.566 .08073 Mdot
.566 .08093 Mdot
.566 .0812 Mdot
.566 .08125 Mdot
.566 .08128 Mdot
.566 .08177 Mdot
.566 .08182 Mdot
.566 .08194 Mdot
.566 .08201 Mdot
.566 .08237 Mdot
.566 .08261 Mdot
.566 .0831 Mdot
.566 .08339 Mdot
.566 .08374 Mdot
.566 .08377 Mdot
.566 .08406 Mdot
.566 .08434 Mdot
.566 .08447 Mdot
.566 .08499 Mdot
.566 .08521 Mdot
.566 .08573 Mdot
.566 .08588 Mdot
.566 .08601 Mdot
.566 .08614 Mdot
.566 .08637 Mdot
.566 .08676 Mdot
.566 .08677 Mdot
.566 .08685 Mdot
.566 .08697 Mdot
.566 .08698 Mdot
.566 .08712 Mdot
.566 .08753 Mdot
.566 .08753 Mdot
.566 .08776 Mdot
.566 .08801 Mdot
.566 .08807 Mdot
.566 .08815 Mdot
.566 .08871 Mdot
.566 .08876 Mdot
.566 .08879 Mdot
.566 .08927 Mdot
.566 .08937 Mdot
.566 .08945 Mdot
.566 .08968 Mdot
.566 .08997 Mdot
.566 .09004 Mdot
.566 .09006 Mdot
.566 .09062 Mdot
.566 .09068 Mdot
.566 .09082 Mdot
.566 .0909 Mdot
.566 .0913 Mdot
.566 .09157 Mdot
.566 .09213 Mdot
.566 .09246 Mdot
.566 .09285 Mdot
.566 .09288 Mdot
.566 .09321 Mdot
.566 .09353 Mdot
.566 .09368 Mdot
.566 .09426 Mdot
.566 .09452 Mdot
.566 .09511 Mdot
.566 .09528 Mdot
.566 .09542 Mdot
.566 .09557 Mdot
.566 .09583 Mdot
.566 .09627 Mdot
.566 .09629 Mdot
.566 .09637 Mdot
.566 .09651 Mdot
.566 .09652 Mdot
.566 .09668 Mdot
.566 .09715 Mdot
.566 .09715 Mdot
.566 .0974 Mdot
.566 .09769 Mdot
.566 .09776 Mdot
.566 .09785 Mdot
.566 .09848 Mdot
.566 .09853 Mdot
.566 .09856 Mdot
.566 .09911 Mdot
.566 .09922 Mdot
.566 .09931 Mdot
.566 .09957 Mdot
.566 .09991 Mdot
.566 .09998 Mdot
.566 .10001 Mdot
.566 .10064 Mdot
.566 .10071 Mdot
.566 .10086 Mdot
.566 .10095 Mdot
.566 .1014 Mdot
.566 .10172 Mdot
.566 .10235 Mdot
.566 .10272 Mdot
.566 .10316 Mdot
.566 .1032 Mdot
.566 .10357 Mdot
.566 .10394 Mdot
.566 .1041 Mdot
.566 .10476 Mdot
.566 .10505 Mdot
.566 .10572 Mdot
.566 .10591 Mdot
.566 .10607 Mdot
.566 .10624 Mdot
.566 .10654 Mdot
.566 .10704 Mdot
.566 .10705 Mdot
.566 .10714 Mdot
.566 .10731 Mdot
.566 .10732 Mdot
.566 .1075 Mdot
.566 .10803 Mdot
.566 .10803 Mdot
.566 .10831 Mdot
.566 .10864 Mdot
.566 .10872 Mdot
.566 .10882 Mdot
.566 .10954 Mdot
.566 .1096 Mdot
.566 .10963 Mdot
.566 .11025 Mdot
.566 .11037 Mdot
.566 .11048 Mdot
.566 .11077 Mdot
.566 .11115 Mdot
.566 .11123 Mdot
.566 .11127 Mdot
.566 .11198 Mdot
.566 .11206 Mdot
.566 .11223 Mdot
.566 .11234 Mdot
.566 .11285 Mdot
.566 .1132 Mdot
.566 .11392 Mdot
.566 .11434 Mdot
.566 .11484 Mdot
.566 .11488 Mdot
.566 .1153 Mdot
.566 .11571 Mdot
.566 .1159 Mdot
.566 .11665 Mdot
.566 .11698 Mdot
.566 .11773 Mdot
.566 .11795 Mdot
.566 .11813 Mdot
.566 .11832 Mdot
.566 .11866 Mdot
.566 .11923 Mdot
.566 .11924 Mdot
.566 .11935 Mdot
.566 .11953 Mdot
.566 .11954 Mdot
.566 .11974 Mdot
.566 .12034 Mdot
.566 .12034 Mdot
.566 .12067 Mdot
.566 .12104 Mdot
.566 .12113 Mdot
.566 .12124 Mdot
.566 .12206 Mdot
.566 .12212 Mdot
.566 .12216 Mdot
.566 .12286 Mdot
.566 .123 Mdot
.566 .12312 Mdot
.566 .12345 Mdot
.566 .12388 Mdot
.566 .12397 Mdot
.566 .12401 Mdot
.566 .12482 Mdot
.566 .1249 Mdot
.566 .12511 Mdot
.566 .12522 Mdot
.566 .1258 Mdot
.566 .1262 Mdot
.566 .12701 Mdot
.566 .12749 Mdot
.566 .12806 Mdot
.566 .1281 Mdot
.566 .12858 Mdot
.566 .12905 Mdot
.566 .12926 Mdot
.566 .1301 Mdot
.566 .13048 Mdot
.566 .13133 Mdot
.566 .13157 Mdot
.566 .13179 Mdot
.566 .132 Mdot
.566 .13238 Mdot
.566 .13302 Mdot
.566 .13304 Mdot
.566 .13316 Mdot
.566 .13337 Mdot
.566 .13338 Mdot
.566 .13361 Mdot
.566 .13429 Mdot
.566 .13429 Mdot
.566 .13466 Mdot
.566 .13507 Mdot
.566 .13517 Mdot
.566 .13531 Mdot
.566 .13623 Mdot
.566 .1363 Mdot
.566 .13634 Mdot
.566 .13714 Mdot
.566 .13729 Mdot
.566 .13743 Mdot
.566 .1378 Mdot
.566 .13829 Mdot
.566 .1384 Mdot
.566 .13844 Mdot
.566 .13936 Mdot
.566 .13945 Mdot
.566 .13968 Mdot
.566 .13981 Mdot
.566 .14046 Mdot
.566 .14092 Mdot
.566 .14184 Mdot
.566 .14237 Mdot
.566 .14302 Mdot
.566 .14307 Mdot
.566 .14361 Mdot
.566 .14414 Mdot
.566 .14438 Mdot
.566 .14534 Mdot
.566 .14576 Mdot
.566 .14673 Mdot
.566 .147 Mdot
.566 .14724 Mdot
.566 .14748 Mdot
.566 .14791 Mdot
.566 .14864 Mdot
.566 .14866 Mdot
.566 .14879 Mdot
.566 .14903 Mdot
.566 .14904 Mdot
.566 .1493 Mdot
.566 .15007 Mdot
.566 .15007 Mdot
.566 .15049 Mdot
.566 .15096 Mdot
.566 .15107 Mdot
.566 .15226 Mdot
.566 .15235 Mdot
.566 .1524 Mdot
.566 .1533 Mdot
.566 .15348 Mdot
.566 .15363 Mdot
.566 .15405 Mdot
.566 .15461 Mdot
.566 .15472 Mdot
.566 .15477 Mdot
.566 .15581 Mdot
.566 .15591 Mdot
.566 .15617 Mdot
.566 .15632 Mdot
.566 .15706 Mdot
.566 .15758 Mdot
.566 .15862 Mdot
.566 .15922 Mdot
.566 .15995 Mdot
.566 .16001 Mdot
.566 .16063 Mdot
.566 .16122 Mdot
.566 .16149 Mdot
.566 .16258 Mdot
.566 .16305 Mdot
.566 .16415 Mdot
.566 .16446 Mdot
.566 .16473 Mdot
.566 .16501 Mdot
.566 .16549 Mdot
.566 .16632 Mdot
.566 .16634 Mdot
.566 .16649 Mdot
.566 .16676 Mdot
.566 .16677 Mdot
.566 .16707 Mdot
.566 .16794 Mdot
.566 .16794 Mdot
.566 .16841 Mdot
.566 .16894 Mdot
.566 .16907 Mdot
.566 .17042 Mdot
.566 .17052 Mdot
.566 .17057 Mdot
.566 .17159 Mdot
.566 .17179 Mdot
.566 .17196 Mdot
.566 .17244 Mdot
.566 .17307 Mdot
.566 .1732 Mdot
.566 .17326 Mdot
.566 .17444 Mdot
.566 .17455 Mdot
.566 .17484 Mdot
.566 .17501 Mdot
.566 .17585 Mdot
.566 .17643 Mdot
.566 .17761 Mdot
.566 .1783 Mdot
.566 .17912 Mdot
.566 .17919 Mdot
.566 .17989 Mdot
.566 .18056 Mdot
.566 .18086 Mdot
.566 .1821 Mdot
.566 .18263 Mdot
.566 .18388 Mdot
.566 .18423 Mdot
.566 .18453 Mdot
.566 .18484 Mdot
.566 .18539 Mdot
.566 .18633 Mdot
.566 .18635 Mdot
.566 .18652 Mdot
.566 .18683 Mdot
.566 .18684 Mdot
.566 .18718 Mdot
.566 .18816 Mdot
.566 .18816 Mdot
.566 .1887 Mdot
.566 .1893 Mdot
.566 .18945 Mdot
.566 .19097 Mdot
.566 .19108 Mdot
.566 .19115 Mdot
.566 .1923 Mdot
.566 .19253 Mdot
.566 .19272 Mdot
.566 .19326 Mdot
.566 .19398 Mdot
.566 .19412 Mdot
.566 .19419 Mdot
.566 .19552 Mdot
.566 .19565 Mdot
.566 .19598 Mdot
.566 .19617 Mdot
.566 .19712 Mdot
.566 .19778 Mdot
.566 .19911 Mdot
.566 .19989 Mdot
.566 .20083 Mdot
.566 .2009 Mdot
.566 .20169 Mdot
.566 .20245 Mdot
.566 .2028 Mdot
.566 .20419 Mdot
.566 .2048 Mdot
.566 .20621 Mdot
.566 .2066 Mdot
.566 .20695 Mdot
.566 .2073 Mdot
.566 .20792 Mdot
.566 .20898 Mdot
.566 .20901 Mdot
.566 .2092 Mdot
.566 .20955 Mdot
.566 .20956 Mdot
.566 .20994 Mdot
.566 .21106 Mdot
.566 .21106 Mdot
.566 .21166 Mdot
.566 .21234 Mdot
.566 .21251 Mdot
.566 .21424 Mdot
.566 .21436 Mdot
.566 .21443 Mdot
.566 .21574 Mdot
.566 .216 Mdot
.566 .21621 Mdot
.566 .21683 Mdot
.566 .21764 Mdot
.566 .21781 Mdot
.566 .21788 Mdot
.566 .21939 Mdot
.566 .21954 Mdot
.566 .21991 Mdot
.566 .22013 Mdot
.566 .2212 Mdot
.566 .22194 Mdot
.566 .22345 Mdot
.566 .22434 Mdot
.566 .22539 Mdot
.566 .22548 Mdot
.566 .22637 Mdot
.566 .22723 Mdot
.566 .22762 Mdot
.566 .2292 Mdot
.566 .22989 Mdot
.566 .23148 Mdot
.566 .23193 Mdot
.566 .23232 Mdot
.566 .23272 Mdot
.566 .23343 Mdot
.566 .23463 Mdot
.566 .23466 Mdot
.566 .23487 Mdot
.566 .23527 Mdot
.566 .23528 Mdot
.566 .23571 Mdot
.566 .23697 Mdot
.566 .23698 Mdot
.566 .23766 Mdot
.566 .23843 Mdot
.566 .23862 Mdot
.566 .24058 Mdot
.566 .24072 Mdot
.566 .2408 Mdot
.566 .24227 Mdot
.566 .24257 Mdot
.566 .24281 Mdot
.566 .24351 Mdot
.566 .24442 Mdot
.566 .24461 Mdot
.566 .2447 Mdot
.566 .2464 Mdot
.566 .24657 Mdot
.566 .24699 Mdot
.566 .24724 Mdot
.566 .24846 Mdot
.566 .2493 Mdot
.566 .25101 Mdot
.566 .25201 Mdot
.566 .2532 Mdot
.566 .2533 Mdot
.566 .25431 Mdot
.566 .25528 Mdot
.566 .25573 Mdot
.566 .25751 Mdot
.566 .25829 Mdot
.566 .2601 Mdot
.566 .2606 Mdot
.566 .26105 Mdot
.566 .2615 Mdot
.566 .2623 Mdot
.566 .26365 Mdot
.566 .26369 Mdot
.566 .26394 Mdot
.566 .26438 Mdot
.566 .2644 Mdot
.566 .26488 Mdot
.566 .26631 Mdot
.566 .26631 Mdot
.566 .26709 Mdot
.566 .26796 Mdot
.566 .26818 Mdot
.566 .27039 Mdot
.566 .27055 Mdot
.566 .27064 Mdot
.566 .27231 Mdot
.566 .27264 Mdot
.566 .27292 Mdot
.566 .27371 Mdot
.566 .27474 Mdot
.566 .27496 Mdot
.566 .27506 Mdot
.566 .27698 Mdot
.566 .27718 Mdot
.566 .27765 Mdot
.566 .27793 Mdot
.566 .27931 Mdot
.566 .28026 Mdot
.566 .2822 Mdot
.566 .28333 Mdot
.566 .28468 Mdot
.566 .28479 Mdot
.566 .28593 Mdot
.566 .28704 Mdot
.566 .28754 Mdot
.566 .28956 Mdot
.566 .29045 Mdot
.566 .29249 Mdot
.566 .29306 Mdot
.566 .29357 Mdot
.566 .29408 Mdot
.566 .29498 Mdot
.566 .29651 Mdot
.566 .29655 Mdot
.566 .29683 Mdot
.566 .29733 Mdot
.566 .29736 Mdot
.566 .2979 Mdot
.566 .29952 Mdot
.566 .29953 Mdot
.566 .3004 Mdot
.566 .30139 Mdot
.566 .30164 Mdot
.566 .30414 Mdot
.566 .30432 Mdot
.566 .30442 Mdot
.566 .30632 Mdot
.566 .30669 Mdot
.566 .307 Mdot
.566 .3079 Mdot
.566 .30907 Mdot
.566 .30931 Mdot
.566 .30942 Mdot
.566 .3116 Mdot
.566 .31182 Mdot
.566 .31236 Mdot
.566 .31268 Mdot
.566 .31424 Mdot
.566 .31532 Mdot
.566 .3175 Mdot
.566 .31879 Mdot
.566 .32032 Mdot
.566 .32044 Mdot
.566 .32173 Mdot
.566 .32299 Mdot
.566 .32355 Mdot
.566 .32584 Mdot
.566 .32684 Mdot
.566 .32915 Mdot
.566 .3298 Mdot
.566 .33037 Mdot
.566 .33095 Mdot
.566 .33197 Mdot
.566 .33371 Mdot
.566 .33375 Mdot
.566 .33407 Mdot
.566 .33464 Mdot
.566 .33466 Mdot
.566 .33528 Mdot
.566 .33712 Mdot
.566 .33712 Mdot
.566 .33811 Mdot
.566 .33923 Mdot
.566 .33951 Mdot
.566 .34235 Mdot
.566 .34255 Mdot
.566 .34266 Mdot
.566 .34481 Mdot
.566 .34523 Mdot
.566 .34559 Mdot
.566 .3466 Mdot
.566 .34792 Mdot
.566 .3482 Mdot
.566 .34832 Mdot
.568 .01617 Mdot
.568 .01636 Mdot
.568 .01659 Mdot
.568 .01684 Mdot
.568 .01713 Mdot
.568 .01746 Mdot
.568 .01783 Mdot
.568 .01794 Mdot
.568 .01826 Mdot
.568 .01838 Mdot
.568 .01874 Mdot
.568 .01888 Mdot
.568 .01929 Mdot
.568 .01945 Mdot
.568 .01991 Mdot
.568 .02009 Mdot
.568 .02042 Mdot
.568 .02061 Mdot
.568 .02082 Mdot
.568 .02115 Mdot
.568 .02119 Mdot
.568 .02142 Mdot
.568 .02165 Mdot
.568 .02203 Mdot
.568 .02207 Mdot
.568 .02233 Mdot
.568 .0226 Mdot
.568 .02302 Mdot
.568 .02307 Mdot
.568 .02336 Mdot
.568 .02367 Mdot
.568 .02407 Mdot
.568 .02415 Mdot
.568 .02421 Mdot
.568 .02454 Mdot
.568 .02465 Mdot
.568 .02489 Mdot
.568 .02534 Mdot
.568 .02543 Mdot
.568 .0255 Mdot
.568 .02588 Mdot
.568 .026 Mdot
.568 .02627 Mdot
.568 .02679 Mdot
.568 .02689 Mdot
.568 .02697 Mdot
.568 .02739 Mdot
.568 .02744 Mdot
.568 .02754 Mdot
.568 .02754 Mdot
.568 .02781 Mdot
.568 .02784 Mdot
.568 .0279 Mdot
.568 .0283 Mdot
.568 .02834 Mdot
.568 .02843 Mdot
.568 .02855 Mdot
.568 .02863 Mdot
.568 .02912 Mdot
.568 .02914 Mdot
.568 .02917 Mdot
.568 .02928 Mdot
.568 .02928 Mdot
.568 .02959 Mdot
.568 .02962 Mdot
.568 .0297 Mdot
.568 .03015 Mdot
.568 .03019 Mdot
.568 .03029 Mdot
.568 .03043 Mdot
.568 .03053 Mdot
.568 .03108 Mdot
.568 .0311 Mdot
.568 .03114 Mdot
.568 .03126 Mdot
.568 .03127 Mdot
.568 .03142 Mdot
.568 .03161 Mdot
.568 .03165 Mdot
.568 .03174 Mdot
.568 .03178 Mdot
.568 .03191 Mdot
.568 .03197 Mdot
.568 .03225 Mdot
.568 .03229 Mdot
.568 .03241 Mdot
.568 .03257 Mdot
.568 .03268 Mdot
.568 .0333 Mdot
.568 .03333 Mdot
.568 .03337 Mdot
.568 .03351 Mdot
.568 .03352 Mdot
.568 .0337 Mdot
.568 .03391 Mdot
.568 .03396 Mdot
.568 .03405 Mdot
.568 .0341 Mdot
.568 .03425 Mdot
.568 .03432 Mdot
.568 .03464 Mdot
.568 .03468 Mdot
.568 .03482 Mdot
.568 .03499 Mdot
.568 .03512 Mdot
.568 .0353 Mdot
.568 .0358 Mdot
.568 .03583 Mdot
.568 .03586 Mdot
.568 .03591 Mdot
.568 .03607 Mdot
.568 .03607 Mdot
.568 .03608 Mdot
.568 .03628 Mdot
.568 .03652 Mdot
.568 .03655 Mdot
.568 .03657 Mdot
.568 .03668 Mdot
.568 .03674 Mdot
.568 .03691 Mdot
.568 .03698 Mdot
.568 .03734 Mdot
.568 .0374 Mdot
.568 .03755 Mdot
.568 .03775 Mdot
.568 .0379 Mdot
.568 .0381 Mdot
.568 .03867 Mdot
.568 .0387 Mdot
.568 .03873 Mdot
.568 .03879 Mdot
.568 .03897 Mdot
.568 .03898 Mdot
.568 .03898 Mdot
.568 .03921 Mdot
.568 .03926 Mdot
.568 .03948 Mdot
.568 .03952 Mdot
.568 .03955 Mdot
.568 .03967 Mdot
.568 .03973 Mdot
.568 .0398 Mdot
.568 .03993 Mdot
.568 .04001 Mdot
.568 .04014 Mdot
.568 .04017 Mdot
.568 .04042 Mdot
.568 .04048 Mdot
.568 .04066 Mdot
.568 .04089 Mdot
.568 .04105 Mdot
.568 .04128 Mdot
.568 .04167 Mdot
.568 .04193 Mdot
.568 .04194 Mdot
.568 .04196 Mdot
.568 .042 Mdot
.568 .04206 Mdot
.568 .04224 Mdot
.568 .04227 Mdot
.568 .04228 Mdot
.568 .04228 Mdot
.568 .04254 Mdot
.568 .04258 Mdot
.568 .0426 Mdot
.568 .04285 Mdot
.568 .04289 Mdot
.568 .04292 Mdot
.568 .04292 Mdot
.568 .04306 Mdot
.568 .04314 Mdot
.568 .04321 Mdot
.568 .04335 Mdot
.568 .04345 Mdot
.568 .0436 Mdot
.568 .04363 Mdot
.568 .04386 Mdot
.568 .04392 Mdot
.568 .04399 Mdot
.568 .04418 Mdot
.568 .04444 Mdot
.568 .04463 Mdot
.568 .04489 Mdot
.568 .04533 Mdot
.568 .04563 Mdot
.568 .04564 Mdot
.568 .04567 Mdot
.568 .04571 Mdot
.568 .04571 Mdot
.568 .04578 Mdot
.568 .04598 Mdot
.568 .04601 Mdot
.568 .04603 Mdot
.568 .04603 Mdot
.568 .04633 Mdot
.568 .04637 Mdot
.568 .0464 Mdot
.568 .04668 Mdot
.568 .04673 Mdot
.568 .04676 Mdot
.568 .04676 Mdot
.568 .04692 Mdot
.568 .04694 Mdot
.568 .047 Mdot
.568 .04709 Mdot
.568 .04725 Mdot
.568 .04736 Mdot
.568 .04753 Mdot
.568 .04756 Mdot
.568 .04783 Mdot
.568 .04789 Mdot
.568 .04797 Mdot
.568 .04819 Mdot
.568 .04849 Mdot
.568 .0487 Mdot
.568 .04888 Mdot
.568 .04899 Mdot
.568 .0492 Mdot
.568 .04949 Mdot
.568 .04983 Mdot
.568 .04984 Mdot
.568 .04988 Mdot
.568 .04992 Mdot
.568 .04992 Mdot
.568 .05 Mdot
.568 .05024 Mdot
.568 .05027 Mdot
.568 .05028 Mdot
.568 .05029 Mdot
.568 .05063 Mdot
.568 .05068 Mdot
.568 .0507 Mdot
.568 .05075 Mdot
.568 .05103 Mdot
.568 .05108 Mdot
.568 .05111 Mdot
.568 .05112 Mdot
.568 .05127 Mdot
.568 .05129 Mdot
.568 .05132 Mdot
.568 .05139 Mdot
.568 .05149 Mdot
.568 .05167 Mdot
.568 .0518 Mdot
.568 .05199 Mdot
.568 .05203 Mdot
.568 .05223 Mdot
.568 .05233 Mdot
.568 .0524 Mdot
.568 .05249 Mdot
.568 .05275 Mdot
.568 .05293 Mdot
.568 .05308 Mdot
.568 .05332 Mdot
.568 .05352 Mdot
.568 .05365 Mdot
.568 .05381 Mdot
.568 .05389 Mdot
.568 .05422 Mdot
.568 .05461 Mdot
.568 .05462 Mdot
.568 .05466 Mdot
.568 .05471 Mdot
.568 .05471 Mdot
.568 .0548 Mdot
.568 .05507 Mdot
.568 .05511 Mdot
.568 .05512 Mdot
.568 .05513 Mdot
.568 .05551 Mdot
.568 .05557 Mdot
.568 .0556 Mdot
.568 .05565 Mdot
.568 .05596 Mdot
.568 .05602 Mdot
.568 .05606 Mdot
.568 .05607 Mdot
.568 .05624 Mdot
.568 .05627 Mdot
.568 .0563 Mdot
.568 .05634 Mdot
.568 .05638 Mdot
.568 .05649 Mdot
.568 .0567 Mdot
.568 .05684 Mdot
.568 .05706 Mdot
.568 .0571 Mdot
.568 .05734 Mdot
.568 .05745 Mdot
.568 .05753 Mdot
.568 .05763 Mdot
.568 .05792 Mdot
.568 .05812 Mdot
.568 .05815 Mdot
.568 .0583 Mdot
.568 .05835 Mdot
.568 .05857 Mdot
.568 .0588 Mdot
.568 .05895 Mdot
.568 .05912 Mdot
.568 .05922 Mdot
.568 .0596 Mdot
.568 .05967 Mdot
.568 .06004 Mdot
.568 .06005 Mdot
.568 .06008 Mdot
.568 .0601 Mdot
.568 .06015 Mdot
.568 .06015 Mdot
.568 .06026 Mdot
.568 .06055 Mdot
.568 .0606 Mdot
.568 .06062 Mdot
.568 .06062 Mdot
.568 .06106 Mdot
.568 .06112 Mdot
.568 .06116 Mdot
.568 .06122 Mdot
.568 .06157 Mdot
.568 .06164 Mdot
.568 .06169 Mdot
.568 .06169 Mdot
.568 .06189 Mdot
.568 .06192 Mdot
.568 .06196 Mdot
.568 .062 Mdot
.568 .06205 Mdot
.568 .06217 Mdot
.568 .06241 Mdot
.568 .06257 Mdot
.568 .06282 Mdot
.568 .06286 Mdot
.568 .06313 Mdot
.568 .06326 Mdot
.568 .06335 Mdot
.568 .06346 Mdot
.568 .06379 Mdot
.568 .06403 Mdot
.568 .06405 Mdot
.568 .06423 Mdot
.568 .06428 Mdot
.568 .06453 Mdot
.568 .0648 Mdot
.568 .06516 Mdot
.568 .06527 Mdot
.568 .0657 Mdot
.568 .06579 Mdot
.568 .0662 Mdot
.568 .06621 Mdot
.568 .06625 Mdot
.568 .06627 Mdot
.568 .06633 Mdot
.568 .06633 Mdot
.568 .06645 Mdot
.568 .06679 Mdot
.568 .06684 Mdot
.568 .06686 Mdot
.568 .06687 Mdot
.568 .06736 Mdot
.568 .06743 Mdot
.568 .06747 Mdot
.568 .06754 Mdot
.568 .06795 Mdot
.568 .06802 Mdot
.568 .06808 Mdot
.568 .06808 Mdot
.568 .0683 Mdot
.568 .06834 Mdot
.568 .06839 Mdot
.568 .06844 Mdot
.568 .06849 Mdot
.568 .06863 Mdot
.568 .0689 Mdot
.568 .06908 Mdot
.568 .06937 Mdot
.568 .06941 Mdot
.568 .06972 Mdot
.568 .06986 Mdot
.568 .06996 Mdot
.568 .07009 Mdot
.568 .07047 Mdot
.568 .07073 Mdot
.568 .07076 Mdot
.568 .07096 Mdot
.568 .07102 Mdot
.568 .07131 Mdot
.568 .07161 Mdot
.568 .07202 Mdot
.568 .07215 Mdot
.568 .07264 Mdot
.568 .07273 Mdot
.568 .0732 Mdot
.568 .07322 Mdot
.568 .07326 Mdot
.568 .07328 Mdot
.568 .07335 Mdot
.568 .07335 Mdot
.568 .07349 Mdot
.568 .07387 Mdot
.568 .07393 Mdot
.568 .07395 Mdot
.568 .07396 Mdot
.568 .07452 Mdot
.568 .0746 Mdot
.568 .07465 Mdot
.568 .07473 Mdot
.568 .07519 Mdot
.568 .07527 Mdot
.568 .07533 Mdot
.568 .07534 Mdot
.568 .07559 Mdot
.568 .07563 Mdot
.568 .07568 Mdot
.568 .07574 Mdot
.568 .0758 Mdot
.568 .07596 Mdot
.568 .07627 Mdot
.568 .07647 Mdot
.568 .0768 Mdot
.568 .07685 Mdot
.568 .0772 Mdot
.568 .07736 Mdot
.568 .07748 Mdot
.568 .07762 Mdot
.568 .07805 Mdot
.568 .07835 Mdot
.568 .07839 Mdot
.568 .07861 Mdot
.568 .07868 Mdot
.568 .07901 Mdot
.568 .07935 Mdot
.568 .07982 Mdot
.568 .07996 Mdot
.568 .08051 Mdot
.568 .08062 Mdot
.568 .08116 Mdot
.568 .08117 Mdot
.568 .08123 Mdot
.568 .08124 Mdot
.568 .08132 Mdot
.568 .08133 Mdot
.568 .08148 Mdot
.568 .08191 Mdot
.568 .08198 Mdot
.568 .08201 Mdot
.568 .08202 Mdot
.568 .08265 Mdot
.568 .08275 Mdot
.568 .0828 Mdot
.568 .08289 Mdot
.568 .08341 Mdot
.568 .08351 Mdot
.568 .08358 Mdot
.568 .08358 Mdot
.568 .08387 Mdot
.568 .08392 Mdot
.568 .08398 Mdot
.568 .08404 Mdot
.568 .08411 Mdot
.568 .08429 Mdot
.568 .08464 Mdot
.568 .08487 Mdot
.568 .08524 Mdot
.568 .0853 Mdot
.568 .0857 Mdot
.568 .08588 Mdot
.568 .08601 Mdot
.568 .08618 Mdot
.568 .08666 Mdot
.568 .08701 Mdot
.568 .08705 Mdot
.568 .0873 Mdot
.568 .08738 Mdot
.568 .08775 Mdot
.568 .08814 Mdot
.568 .08867 Mdot
.568 .08883 Mdot
.568 .08946 Mdot
.568 .08959 Mdot
.568 .09019 Mdot
.568 .09021 Mdot
.568 .09027 Mdot
.568 .09029 Mdot
.568 .09038 Mdot
.568 .09039 Mdot
.568 .09056 Mdot
.568 .09105 Mdot
.568 .09113 Mdot
.568 .09116 Mdot
.568 .09117 Mdot
.568 .09189 Mdot
.568 .092 Mdot
.568 .09206 Mdot
.568 .09216 Mdot
.568 .09275 Mdot
.568 .09287 Mdot
.568 .09294 Mdot
.568 .09295 Mdot
.568 .09327 Mdot
.568 .09333 Mdot
.568 .0934 Mdot
.568 .09347 Mdot
.568 .09354 Mdot
.568 .09375 Mdot
.568 .09415 Mdot
.568 .09441 Mdot
.568 .09483 Mdot
.568 .0949 Mdot
.568 .09535 Mdot
.568 .09556 Mdot
.568 .09571 Mdot
.568 .0959 Mdot
.568 .09645 Mdot
.568 .09684 Mdot
.568 .09688 Mdot
.568 .09717 Mdot
.568 .09726 Mdot
.568 .09768 Mdot
.568 .09812 Mdot
.568 .09873 Mdot
.568 .09891 Mdot
.568 .09963 Mdot
.568 .09977 Mdot
.568 .10046 Mdot
.568 .10048 Mdot
.568 .10055 Mdot
.568 .10057 Mdot
.568 .10067 Mdot
.568 .10068 Mdot
.568 .10087 Mdot
.568 .10144 Mdot
.568 .10152 Mdot
.568 .10156 Mdot
.568 .10157 Mdot
.568 .10239 Mdot
.568 .10251 Mdot
.568 .10258 Mdot
.568 .1027 Mdot
.568 .10336 Mdot
.568 .1035 Mdot
.568 .10358 Mdot
.568 .10359 Mdot
.568 .10395 Mdot
.568 .10402 Mdot
.568 .1041 Mdot
.568 .10418 Mdot
.568 .10426 Mdot
.568 .1045 Mdot
.568 .10495 Mdot
.568 .10525 Mdot
.568 .10573 Mdot
.568 .10581 Mdot
.568 .10632 Mdot
.568 .10655 Mdot
.568 .10672 Mdot
.568 .10694 Mdot
.568 .10756 Mdot
.568 .10801 Mdot
.568 .10806 Mdot
.568 .10838 Mdot
.568 .10848 Mdot
.568 .10897 Mdot
.568 .10946 Mdot
.568 .11015 Mdot
.568 .11036 Mdot
.568 .11117 Mdot
.568 .11134 Mdot
.568 .11212 Mdot
.568 .11214 Mdot
.568 .11222 Mdot
.568 .11225 Mdot
.568 .11236 Mdot
.568 .11237 Mdot
.568 .11259 Mdot
.568 .11323 Mdot
.568 .11333 Mdot
.568 .11337 Mdot
.568 .11338 Mdot
.568 .11431 Mdot
.568 .11445 Mdot
.568 .11453 Mdot
.568 .11466 Mdot
.568 .11542 Mdot
.568 .11557 Mdot
.568 .11567 Mdot
.568 .11567 Mdot
.568 .11609 Mdot
.568 .11617 Mdot
.568 .11625 Mdot
.568 .11635 Mdot
.568 .11644 Mdot
.568 .11671 Mdot
.568 .11722 Mdot
.568 .11757 Mdot
.568 .11811 Mdot
.568 .1182 Mdot
.568 .11877 Mdot
.568 .11904 Mdot
.568 .11924 Mdot
.568 .11948 Mdot
.568 .12019 Mdot
.568 .1207 Mdot
.568 .12075 Mdot
.568 .12112 Mdot
.568 .12124 Mdot
.568 .12179 Mdot
.568 .12235 Mdot
.568 .12313 Mdot
.568 .12337 Mdot
.568 .12429 Mdot
.568 .12448 Mdot
.568 .12536 Mdot
.568 .12539 Mdot
.568 .12548 Mdot
.568 .12551 Mdot
.568 .12564 Mdot
.568 .12565 Mdot
.568 .1259 Mdot
.568 .12663 Mdot
.568 .12674 Mdot
.568 .12678 Mdot
.568 .1268 Mdot
.568 .12786 Mdot
.568 .12802 Mdot
.568 .1281 Mdot
.568 .12826 Mdot
.568 .12912 Mdot
.568 .12929 Mdot
.568 .1294 Mdot
.568 .1294 Mdot
.568 .12988 Mdot
.568 .12996 Mdot
.568 .13006 Mdot
.568 .13017 Mdot
.568 .13028 Mdot
.568 .13058 Mdot
.568 .13116 Mdot
.568 .13155 Mdot
.568 .13217 Mdot
.568 .13227 Mdot
.568 .13293 Mdot
.568 .13323 Mdot
.568 .13345 Mdot
.568 .13373 Mdot
.568 .13454 Mdot
.568 .13511 Mdot
.568 .13517 Mdot
.568 .13559 Mdot
.568 .13572 Mdot
.568 .13635 Mdot
.568 .13699 Mdot
.568 .13788 Mdot
.568 .13814 Mdot
.568 .1392 Mdot
.568 .13941 Mdot
.568 .14041 Mdot
.568 .14045 Mdot
.568 .14054 Mdot
.568 .14058 Mdot
.568 .14072 Mdot
.568 .14073 Mdot
.568 .14102 Mdot
.568 .14185 Mdot
.568 .14198 Mdot
.568 .14202 Mdot
.568 .14205 Mdot
.568 .14324 Mdot
.568 .14343 Mdot
.568 .14353 Mdot
.568 .1437 Mdot
.568 .14468 Mdot
.568 .14487 Mdot
.568 .14499 Mdot
.568 .145 Mdot
.568 .14554 Mdot
.568 .14564 Mdot
.568 .14575 Mdot
.568 .14587 Mdot
.568 .14599 Mdot
.568 .14633 Mdot
.568 .147 Mdot
.568 .14744 Mdot
.568 .14814 Mdot
.568 .14826 Mdot
.568 .149 Mdot
.568 .14935 Mdot
.568 .1496 Mdot
.568 .14992 Mdot
.568 .15083 Mdot
.568 .15148 Mdot
.568 .15156 Mdot
.568 .15203 Mdot
.568 .15218 Mdot
.568 .15289 Mdot
.568 .15362 Mdot
.568 .15463 Mdot
.568 .15493 Mdot
.568 .15613 Mdot
.568 .15636 Mdot
.568 .15751 Mdot
.568 .15755 Mdot
.568 .15766 Mdot
.568 .1577 Mdot
.568 .15786 Mdot
.568 .15787 Mdot
.568 .1582 Mdot
.568 .15914 Mdot
.568 .15928 Mdot
.568 .15934 Mdot
.568 .15936 Mdot
.568 .16072 Mdot
.568 .16093 Mdot
.568 .16104 Mdot
.568 .16124 Mdot
.568 .16235 Mdot
.568 .16257 Mdot
.568 .16271 Mdot
.568 .16272 Mdot
.568 .16333 Mdot
.568 .16344 Mdot
.568 .16357 Mdot
.568 .16371 Mdot
.568 .16385 Mdot
.568 .16423 Mdot
.568 .16499 Mdot
.568 .16549 Mdot
.568 .16629 Mdot
.568 .16642 Mdot
.568 .16727 Mdot
.568 .16766 Mdot
.568 .16795 Mdot
.568 .16831 Mdot
.568 .16934 Mdot
.568 .17008 Mdot
.568 .17017 Mdot
.568 .17071 Mdot
.568 .17088 Mdot
.568 .17168 Mdot
.568 .17251 Mdot
.568 .17366 Mdot
.568 .174 Mdot
.568 .17536 Mdot
.568 .17563 Mdot
.568 .17693 Mdot
.568 .17697 Mdot
.568 .1771 Mdot
.568 .17714 Mdot
.568 .17733 Mdot
.568 .17734 Mdot
.568 .17772 Mdot
.568 .17878 Mdot
.568 .17895 Mdot
.568 .17901 Mdot
.568 .17903 Mdot
.568 .18058 Mdot
.568 .18082 Mdot
.568 .18094 Mdot
.568 .18117 Mdot
.568 .18243 Mdot
.568 .18268 Mdot
.568 .18284 Mdot
.568 .18285 Mdot
.568 .18355 Mdot
.568 .18367 Mdot
.568 .18381 Mdot
.568 .18397 Mdot
.568 .18413 Mdot
.568 .18457 Mdot
.568 .18543 Mdot
.568 .186 Mdot
.568 .1869 Mdot
.568 .18705 Mdot
.568 .18801 Mdot
.568 .18846 Mdot
.568 .18879 Mdot
.568 .18919 Mdot
.568 .19037 Mdot
.568 .19121 Mdot
.568 .19131 Mdot
.568 .19192 Mdot
.568 .19212 Mdot
.568 .19303 Mdot
.568 .19397 Mdot
.568 .19527 Mdot
.568 .19566 Mdot
.568 .1972 Mdot
.568 .19751 Mdot
.568 .19899 Mdot
.568 .19904 Mdot
.568 .19918 Mdot
.568 .19923 Mdot
.568 .19944 Mdot
.568 .19946 Mdot
.568 .19988 Mdot
.568 .20109 Mdot
.568 .20128 Mdot
.568 .20135 Mdot
.568 .20138 Mdot
.568 .20314 Mdot
.568 .20341 Mdot
.568 .20355 Mdot
.568 .2038 Mdot
.568 .20524 Mdot
.568 .20552 Mdot
.568 .2057 Mdot
.568 .20571 Mdot
.568 .20651 Mdot
.568 .20665 Mdot
.568 .20681 Mdot
.568 .20699 Mdot
.568 .20717 Mdot
.568 .20767 Mdot
.568 .20864 Mdot
.568 .2093 Mdot
.568 .21032 Mdot
.568 .21049 Mdot
.568 .21158 Mdot
.568 .21209 Mdot
.568 .21246 Mdot
.568 .21292 Mdot
.568 .21426 Mdot
.568 .21522 Mdot
.568 .21532 Mdot
.568 .21602 Mdot
.568 .21624 Mdot
.568 .21728 Mdot
.568 .21835 Mdot
.568 .21983 Mdot
.568 .22027 Mdot
.568 .22202 Mdot
.568 .22237 Mdot
.568 .22405 Mdot
.568 .2241 Mdot
.568 .22427 Mdot
.568 .22433 Mdot
.568 .22457 Mdot
.568 .22459 Mdot
.568 .22507 Mdot
.568 .22644 Mdot
.568 .22665 Mdot
.568 .22673 Mdot
.568 .22677 Mdot
.568 .22877 Mdot
.568 .22907 Mdot
.568 .22923 Mdot
.568 .22952 Mdot
.568 .23115 Mdot
.568 .23147 Mdot
.568 .23168 Mdot
.568 .23169 Mdot
.568 .23259 Mdot
.568 .23275 Mdot
.568 .23293 Mdot
.568 .23314 Mdot
.568 .23334 Mdot
.568 .23391 Mdot
.568 .23502 Mdot
.568 .23576 Mdot
.568 .23692 Mdot
.568 .23711 Mdot
.568 .23836 Mdot
.568 .23894 Mdot
.568 .23935 Mdot
.568 .23988 Mdot
.568 .2414 Mdot
.568 .24249 Mdot
.568 .24261 Mdot
.568 .2434 Mdot
.568 .24365 Mdot
.568 .24483 Mdot
.568 .24604 Mdot
.568 .24773 Mdot
.568 .24823 Mdot
.568 .25022 Mdot
.568 .25062 Mdot
.568 .25252 Mdot
.568 .25258 Mdot
.568 .25277 Mdot
.568 .25283 Mdot
.568 .25311 Mdot
.568 .25313 Mdot
.568 .25367 Mdot
.568 .25523 Mdot
.568 .25548 Mdot
.568 .25557 Mdot
.568 .25561 Mdot
.568 .25788 Mdot
.568 .25822 Mdot
.568 .25841 Mdot
.568 .25873 Mdot
.568 .26058 Mdot
.568 .26095 Mdot
.568 .26118 Mdot
.568 .2612 Mdot
.568 .26222 Mdot
.568 .26241 Mdot
.568 .26261 Mdot
.568 .26285 Mdot
.568 .26308 Mdot
.568 .26372 Mdot
.568 .26498 Mdot
.568 .26582 Mdot
.568 .26714 Mdot
.568 .26736 Mdot
.568 .26877 Mdot
.568 .26943 Mdot
.568 .2699 Mdot
.568 .2705 Mdot
.568 .27223 Mdot
.568 .27346 Mdot
.568 .2736 Mdot
.568 .2745 Mdot
.568 .27478 Mdot
.568 .27612 Mdot
.568 .2775 Mdot
.568 .27942 Mdot
.568 .27999 Mdot
.568 .28225 Mdot
.568 .2827 Mdot
.568 .28486 Mdot
.568 .28493 Mdot
.568 .28514 Mdot
.568 .28522 Mdot
.568 .28553 Mdot
.568 .28555 Mdot
.568 .28617 Mdot
.568 .28795 Mdot
.568 .28822 Mdot
.568 .28832 Mdot
.568 .28837 Mdot
.568 .29095 Mdot
.568 .29134 Mdot
.568 .29155 Mdot
.568 .29192 Mdot
.568 .29402 Mdot
.568 .29444 Mdot
.568 .2947 Mdot
.568 .29472 Mdot
.568 .29588 Mdot
.568 .29609 Mdot
.568 .29633 Mdot
.568 .29659 Mdot
.568 .29685 Mdot
.568 .29759 Mdot
.568 .29901 Mdot
.568 .29997 Mdot
.568 .30147 Mdot
.568 .30172 Mdot
.568 .30332 Mdot
.568 .30407 Mdot
.568 .30461 Mdot
.568 .30529 Mdot
.568 .30725 Mdot
.568 .30865 Mdot
.568 .30881 Mdot
.568 .30984 Mdot
.568 .31015 Mdot
.568 .31167 Mdot
.568 .31324 Mdot
.568 .31541 Mdot
.568 .31606 Mdot
.568 .31863 Mdot
.568 .31914 Mdot
.568 .3216 Mdot
.568 .32168 Mdot
.568 .32192 Mdot
.568 .32201 Mdot
.568 .32236 Mdot
.568 .32239 Mdot
.568 .32309 Mdot
.568 .3251 Mdot
.568 .32542 Mdot
.568 .32553 Mdot
.568 .32559 Mdot
.568 .32851 Mdot
.568 .32896 Mdot
.568 .3292 Mdot
.568 .32962 Mdot
.568 .33201 Mdot
.568 .33248 Mdot
.568 .33278 Mdot
.568 .3328 Mdot
.568 .33412 Mdot
.568 .33436 Mdot
.568 .33463 Mdot
.568 .33493 Mdot
.568 .33522 Mdot
.568 .33606 Mdot
.568 .33768 Mdot
.568 .33876 Mdot
.568 .34047 Mdot
.568 .34075 Mdot
.568 .34257 Mdot
.568 .34342 Mdot
.568 .34403 Mdot
.568 .34481 Mdot
.568 .34704 Mdot
.568 .34863 Mdot
.568 .3488 Mdot
.568 .34997 Mdot
.568 .35033 Mdot
.57 .01526 Mdot
.57 .01533 Mdot
.57 .01542 Mdot
.57 .01552 Mdot
.57 .01563 Mdot
.57 .01576 Mdot
.57 .0159 Mdot
.57 .01591 Mdot
.57 .01607 Mdot
.57 .01608 Mdot
.57 .01626 Mdot
.57 .01627 Mdot
.57 .01647 Mdot
.57 .01649 Mdot
.57 .01672 Mdot
.57 .01674 Mdot
.57 .017 Mdot
.57 .01702 Mdot
.57 .01732 Mdot
.57 .01735 Mdot
.57 .01768 Mdot
.57 .01768 Mdot
.57 .01771 Mdot
.57 .01795 Mdot
.57 .01809 Mdot
.57 .0181 Mdot
.57 .0181 Mdot
.57 .01813 Mdot
.57 .0184 Mdot
.57 .01856 Mdot
.57 .01857 Mdot
.57 .01857 Mdot
.57 .01861 Mdot
.57 .01892 Mdot
.57 .0191 Mdot
.57 .01911 Mdot
.57 .01911 Mdot
.57 .01916 Mdot
.57 .01951 Mdot
.57 .01972 Mdot
.57 .01973 Mdot
.57 .01973 Mdot
.57 .01978 Mdot
.57 .01978 Mdot
.57 .02018 Mdot
.57 .02042 Mdot
.57 .02043 Mdot
.57 .02043 Mdot
.57 .02048 Mdot
.57 .02049 Mdot
.57 .02094 Mdot
.57 .02117 Mdot
.57 .02122 Mdot
.57 .02123 Mdot
.57 .02123 Mdot
.57 .02129 Mdot
.57 .0213 Mdot
.57 .02181 Mdot
.57 .02208 Mdot
.57 .02213 Mdot
.57 .02214 Mdot
.57 .02214 Mdot
.57 .02221 Mdot
.57 .02222 Mdot
.57 .02281 Mdot
.57 .02311 Mdot
.57 .02316 Mdot
.57 .02318 Mdot
.57 .02318 Mdot
.57 .02326 Mdot
.57 .02327 Mdot
.57 .02394 Mdot
.57 .02428 Mdot
.57 .02435 Mdot
.57 .02437 Mdot
.57 .02437 Mdot
.57 .02446 Mdot
.57 .02447 Mdot
.57 .02523 Mdot
.57 .02562 Mdot
.57 .02569 Mdot
.57 .02572 Mdot
.57 .02572 Mdot
.57 .02579 Mdot
.57 .02582 Mdot
.57 .02583 Mdot
.57 .026 Mdot
.57 .0267 Mdot
.57 .02715 Mdot
.57 .02723 Mdot
.57 .02726 Mdot
.57 .02726 Mdot
.57 .02734 Mdot
.57 .02738 Mdot
.57 .02739 Mdot
.57 .02758 Mdot
.57 .02838 Mdot
.57 .02889 Mdot
.57 .02898 Mdot
.57 .02902 Mdot
.57 .02902 Mdot
.57 .02907 Mdot
.57 .0291 Mdot
.57 .02915 Mdot
.57 .02916 Mdot
.57 .02938 Mdot
.57 .03029 Mdot
.57 .03088 Mdot
.57 .03098 Mdot
.57 .03102 Mdot
.57 .03102 Mdot
.57 .03108 Mdot
.57 .03111 Mdot
.57 .03112 Mdot
.57 .03117 Mdot
.57 .03118 Mdot
.57 .03119 Mdot
.57 .03143 Mdot
.57 .03248 Mdot
.57 .03296 Mdot
.57 .03306 Mdot
.57 .03314 Mdot
.57 .03326 Mdot
.57 .0333 Mdot
.57 .0333 Mdot
.57 .03337 Mdot
.57 .0334 Mdot
.57 .03341 Mdot
.57 .03347 Mdot
.57 .03349 Mdot
.57 .03349 Mdot
.57 .03377 Mdot
.57 .03496 Mdot
.57 .03551 Mdot
.57 .03563 Mdot
.57 .03572 Mdot
.57 .03585 Mdot
.57 .0359 Mdot
.57 .0359 Mdot
.57 .03594 Mdot
.57 .03598 Mdot
.57 .03602 Mdot
.57 .03603 Mdot
.57 .0361 Mdot
.57 .03612 Mdot
.57 .03612 Mdot
.57 .03644 Mdot
.57 .0378 Mdot
.57 .03798 Mdot
.57 .03839 Mdot
.57 .03842 Mdot
.57 .03856 Mdot
.57 .03866 Mdot
.57 .03881 Mdot
.57 .03887 Mdot
.57 .03887 Mdot
.57 .03891 Mdot
.57 .03896 Mdot
.57 .039 Mdot
.57 .03902 Mdot
.57 .03909 Mdot
.57 .03911 Mdot
.57 .03912 Mdot
.57 .03928 Mdot
.57 .03948 Mdot
.57 .04096 Mdot
.57 .04103 Mdot
.57 .04124 Mdot
.57 .04171 Mdot
.57 .04174 Mdot
.57 .04189 Mdot
.57 .04201 Mdot
.57 .04219 Mdot
.57 .04221 Mdot
.57 .04225 Mdot
.57 .04225 Mdot
.57 .0423 Mdot
.57 .04236 Mdot
.57 .0424 Mdot
.57 .04242 Mdot
.57 .04251 Mdot
.57 .04253 Mdot
.57 .04253 Mdot
.57 .04272 Mdot
.57 .04294 Mdot
.57 .04296 Mdot
.57 .04464 Mdot
.57 .04471 Mdot
.57 .04496 Mdot
.57 .04541 Mdot
.57 .04549 Mdot
.57 .04552 Mdot
.57 .0457 Mdot
.57 .04584 Mdot
.57 .0459 Mdot
.57 .04603 Mdot
.57 .04606 Mdot
.57 .0461 Mdot
.57 .04611 Mdot
.57 .04616 Mdot
.57 .04623 Mdot
.57 .04628 Mdot
.57 .0463 Mdot
.57 .0464 Mdot
.57 .04642 Mdot
.57 .04643 Mdot
.57 .04664 Mdot
.57 .0469 Mdot
.57 .04691 Mdot
.57 .04764 Mdot
.57 .0486 Mdot
.57 .04883 Mdot
.57 .04891 Mdot
.57 .04907 Mdot
.57 .04919 Mdot
.57 .0497 Mdot
.57 .04979 Mdot
.57 .04984 Mdot
.57 .05004 Mdot
.57 .05019 Mdot
.57 .05026 Mdot
.57 .05042 Mdot
.57 .05045 Mdot
.57 .0505 Mdot
.57 .0505 Mdot
.57 .05057 Mdot
.57 .05064 Mdot
.57 .0507 Mdot
.57 .05072 Mdot
.57 .05083 Mdot
.57 .05086 Mdot
.57 .05087 Mdot
.57 .05111 Mdot
.57 .05118 Mdot
.57 .0514 Mdot
.57 .05142 Mdot
.57 .05225 Mdot
.57 .05282 Mdot
.57 .05302 Mdot
.57 .05334 Mdot
.57 .05356 Mdot
.57 .0536 Mdot
.57 .0537 Mdot
.57 .05388 Mdot
.57 .05402 Mdot
.57 .0546 Mdot
.57 .0547 Mdot
.57 .05476 Mdot
.57 .05498 Mdot
.57 .05516 Mdot
.57 .05518 Mdot
.57 .05524 Mdot
.57 .05531 Mdot
.57 .05541 Mdot
.57 .05545 Mdot
.57 .05551 Mdot
.57 .05551 Mdot
.57 .05556 Mdot
.57 .05558 Mdot
.57 .05567 Mdot
.57 .05574 Mdot
.57 .05576 Mdot
.57 .05589 Mdot
.57 .05592 Mdot
.57 .05593 Mdot
.57 .05606 Mdot
.57 .05608 Mdot
.57 .05621 Mdot
.57 .05629 Mdot
.57 .0565 Mdot
.57 .05654 Mdot
.57 .05655 Mdot
.57 .05676 Mdot
.57 .05693 Mdot
.57 .0575 Mdot
.57 .05753 Mdot
.57 .05815 Mdot
.57 .05816 Mdot
.57 .05838 Mdot
.57 .05839 Mdot
.57 .05875 Mdot
.57 .059 Mdot
.57 .05905 Mdot
.57 .05916 Mdot
.57 .05936 Mdot
.57 .05952 Mdot
.57 .05961 Mdot
.57 .05991 Mdot
.57 .05997 Mdot
.57 .06018 Mdot
.57 .0603 Mdot
.57 .06036 Mdot
.57 .06062 Mdot
.57 .06082 Mdot
.57 .06085 Mdot
.57 .06091 Mdot
.57 .06099 Mdot
.57 .06111 Mdot
.57 .06113 Mdot
.57 .06116 Mdot
.57 .06122 Mdot
.57 .06122 Mdot
.57 .06127 Mdot
.57 .06131 Mdot
.57 .06133 Mdot
.57 .0614 Mdot
.57 .06148 Mdot
.57 .06151 Mdot
.57 .06166 Mdot
.57 .06169 Mdot
.57 .0617 Mdot
.57 .06184 Mdot
.57 .06187 Mdot
.57 .06201 Mdot
.57 .06211 Mdot
.57 .06235 Mdot
.57 .06239 Mdot
.57 .06241 Mdot
.57 .06265 Mdot
.57 .06284 Mdot
.57 .06349 Mdot
.57 .06352 Mdot
.57 .06423 Mdot
.57 .06425 Mdot
.57 .06449 Mdot
.57 .06451 Mdot
.57 .06491 Mdot
.57 .0652 Mdot
.57 .06526 Mdot
.57 .06538 Mdot
.57 .06562 Mdot
.57 .06579 Mdot
.57 .06589 Mdot
.57 .06624 Mdot
.57 .06631 Mdot
.57 .06655 Mdot
.57 .06668 Mdot
.57 .06675 Mdot
.57 .06705 Mdot
.57 .06728 Mdot
.57 .0673 Mdot
.57 .06738 Mdot
.57 .06747 Mdot
.57 .06761 Mdot
.57 .06762 Mdot
.57 .06766 Mdot
.57 .06773 Mdot
.57 .06773 Mdot
.57 .06779 Mdot
.57 .06783 Mdot
.57 .06785 Mdot
.57 .06794 Mdot
.57 .06803 Mdot
.57 .06806 Mdot
.57 .06823 Mdot
.57 .06827 Mdot
.57 .06828 Mdot
.57 .06844 Mdot
.57 .06847 Mdot
.57 .06864 Mdot
.57 .06874 Mdot
.57 .06902 Mdot
.57 .06907 Mdot
.57 .06909 Mdot
.57 .06936 Mdot
.57 .06958 Mdot
.57 .07032 Mdot
.57 .07035 Mdot
.57 .07117 Mdot
.57 .07118 Mdot
.57 .07146 Mdot
.57 .07148 Mdot
.57 .07194 Mdot
.57 .07227 Mdot
.57 .07233 Mdot
.57 .07247 Mdot
.57 .07274 Mdot
.57 .07294 Mdot
.57 .07306 Mdot
.57 .07345 Mdot
.57 .07353 Mdot
.57 .07381 Mdot
.57 .07396 Mdot
.57 .07404 Mdot
.57 .07437 Mdot
.57 .07464 Mdot
.57 .07467 Mdot
.57 .07475 Mdot
.57 .07485 Mdot
.57 .07501 Mdot
.57 .07503 Mdot
.57 .07507 Mdot
.57 .07515 Mdot
.57 .07516 Mdot
.57 .07522 Mdot
.57 .07526 Mdot
.57 .07529 Mdot
.57 .07539 Mdot
.57 .07549 Mdot
.57 .07553 Mdot
.57 .07572 Mdot
.57 .07577 Mdot
.57 .07578 Mdot
.57 .07596 Mdot
.57 .07599 Mdot
.57 .07618 Mdot
.57 .0763 Mdot
.57 .07663 Mdot
.57 .07668 Mdot
.57 .0767 Mdot
.57 .07701 Mdot
.57 .07726 Mdot
.57 .0781 Mdot
.57 .07814 Mdot
.57 .07907 Mdot
.57 .07908 Mdot
.57 .07941 Mdot
.57 .07943 Mdot
.57 .07995 Mdot
.57 .08032 Mdot
.57 .0804 Mdot
.57 .08056 Mdot
.57 .08087 Mdot
.57 .08109 Mdot
.57 .08123 Mdot
.57 .08167 Mdot
.57 .08176 Mdot
.57 .08208 Mdot
.57 .08226 Mdot
.57 .08234 Mdot
.57 .08273 Mdot
.57 .08302 Mdot
.57 .08306 Mdot
.57 .08316 Mdot
.57 .08327 Mdot
.57 .08345 Mdot
.57 .08348 Mdot
.57 .08352 Mdot
.57 .08361 Mdot
.57 .08362 Mdot
.57 .08369 Mdot
.57 .08374 Mdot
.57 .08377 Mdot
.57 .08388 Mdot
.57 .084 Mdot
.57 .08404 Mdot
.57 .08426 Mdot
.57 .08432 Mdot
.57 .08433 Mdot
.57 .08454 Mdot
.57 .08457 Mdot
.57 .08479 Mdot
.57 .08493 Mdot
.57 .08529 Mdot
.57 .08535 Mdot
.57 .08538 Mdot
.57 .08573 Mdot
.57 .08602 Mdot
.57 .08698 Mdot
.57 .08702 Mdot
.57 .08808 Mdot
.57 .0881 Mdot
.57 .08846 Mdot
.57 .08849 Mdot
.57 .08908 Mdot
.57 .08951 Mdot
.57 .08959 Mdot
.57 .08978 Mdot
.57 .09013 Mdot
.57 .09039 Mdot
.57 .09054 Mdot
.57 .09105 Mdot
.57 .09115 Mdot
.57 .09151 Mdot
.57 .09171 Mdot
.57 .09181 Mdot
.57 .09225 Mdot
.57 .09259 Mdot
.57 .09263 Mdot
.57 .09274 Mdot
.57 .09287 Mdot
.57 .09308 Mdot
.57 .0931 Mdot
.57 .09316 Mdot
.57 .09326 Mdot
.57 .09326 Mdot
.57 .09335 Mdot
.57 .09341 Mdot
.57 .09344 Mdot
.57 .09356 Mdot
.57 .0937 Mdot
.57 .09374 Mdot
.57 .094 Mdot
.57 .09406 Mdot
.57 .09407 Mdot
.57 .09431 Mdot
.57 .09435 Mdot
.57 .0946 Mdot
.57 .09476 Mdot
.57 .09517 Mdot
.57 .09524 Mdot
.57 .09527 Mdot
.57 .09567 Mdot
.57 .096 Mdot
.57 .09709 Mdot
.57 .09714 Mdot
.57 .09835 Mdot
.57 .09837 Mdot
.57 .09879 Mdot
.57 .09881 Mdot
.57 .0995 Mdot
.57 .09998 Mdot
.57 .10008 Mdot
.57 .10029 Mdot
.57 .10068 Mdot
.57 .10098 Mdot
.57 .10116 Mdot
.57 .10174 Mdot
.57 .10185 Mdot
.57 .10226 Mdot
.57 .10249 Mdot
.57 .1026 Mdot
.57 .1031 Mdot
.57 .10349 Mdot
.57 .10354 Mdot
.57 .10366 Mdot
.57 .10381 Mdot
.57 .10405 Mdot
.57 .10408 Mdot
.57 .10414 Mdot
.57 .10425 Mdot
.57 .10426 Mdot
.57 .10436 Mdot
.57 .10442 Mdot
.57 .10446 Mdot
.57 .1046 Mdot
.57 .10475 Mdot
.57 .10481 Mdot
.57 .1051 Mdot
.57 .10517 Mdot
.57 .10518 Mdot
.57 .10546 Mdot
.57 .1055 Mdot
.57 .10579 Mdot
.57 .10596 Mdot
.57 .10644 Mdot
.57 .10651 Mdot
.57 .10655 Mdot
.57 .107 Mdot
.57 .10738 Mdot
.57 .10863 Mdot
.57 .10868 Mdot
.57 .11006 Mdot
.57 .11008 Mdot
.57 .11056 Mdot
.57 .11059 Mdot
.57 .11137 Mdot
.57 .11192 Mdot
.57 .11203 Mdot
.57 .11227 Mdot
.57 .11272 Mdot
.57 .11306 Mdot
.57 .11326 Mdot
.57 .11392 Mdot
.57 .11405 Mdot
.57 .11452 Mdot
.57 .11478 Mdot
.57 .11491 Mdot
.57 .11548 Mdot
.57 .11592 Mdot
.57 .11597 Mdot
.57 .11612 Mdot
.57 .11628 Mdot
.57 .11655 Mdot
.57 .11659 Mdot
.57 .11666 Mdot
.57 .11679 Mdot
.57 .1168 Mdot
.57 .11691 Mdot
.57 .11698 Mdot
.57 .11703 Mdot
.57 .11719 Mdot
.57 .11736 Mdot
.57 .11742 Mdot
.57 .11775 Mdot
.57 .11783 Mdot
.57 .11785 Mdot
.57 .11816 Mdot
.57 .11821 Mdot
.57 .11853 Mdot
.57 .11874 Mdot
.57 .11928 Mdot
.57 .11936 Mdot
.57 .11941 Mdot
.57 .11992 Mdot
.57 .12036 Mdot
.57 .12177 Mdot
.57 .12184 Mdot
.57 .12341 Mdot
.57 .12343 Mdot
.57 .12398 Mdot
.57 .12401 Mdot
.57 .1249 Mdot
.57 .12552 Mdot
.57 .12565 Mdot
.57 .12592 Mdot
.57 .12644 Mdot
.57 .12682 Mdot
.57 .12705 Mdot
.57 .12781 Mdot
.57 .12796 Mdot
.57 .12849 Mdot
.57 .12879 Mdot
.57 .12893 Mdot
.57 .12958 Mdot
.57 .13009 Mdot
.57 .13015 Mdot
.57 .13031 Mdot
.57 .1305 Mdot
.57 .13081 Mdot
.57 .13085 Mdot
.57 .13093 Mdot
.57 .13108 Mdot
.57 .13109 Mdot
.57 .13122 Mdot
.57 .1313 Mdot
.57 .13135 Mdot
.57 .13153 Mdot
.57 .13173 Mdot
.57 .1318 Mdot
.57 .13217 Mdot
.57 .13227 Mdot
.57 .13229 Mdot
.57 .13264 Mdot
.57 .1327 Mdot
.57 .13307 Mdot
.57 .1333 Mdot
.57 .13392 Mdot
.57 .13401 Mdot
.57 .13407 Mdot
.57 .13465 Mdot
.57 .13514 Mdot
.57 .13676 Mdot
.57 .13683 Mdot
.57 .13863 Mdot
.57 .13865 Mdot
.57 .13928 Mdot
.57 .13931 Mdot
.57 .14032 Mdot
.57 .14104 Mdot
.57 .14118 Mdot
.57 .14149 Mdot
.57 .14208 Mdot
.57 .14252 Mdot
.57 .14278 Mdot
.57 .14364 Mdot
.57 .14381 Mdot
.57 .14442 Mdot
.57 .14476 Mdot
.57 .14492 Mdot
.57 .14566 Mdot
.57 .14624 Mdot
.57 .14631 Mdot
.57 .1465 Mdot
.57 .14671 Mdot
.57 .14707 Mdot
.57 .14711 Mdot
.57 .1472 Mdot
.57 .14737 Mdot
.57 .14738 Mdot
.57 .14753 Mdot
.57 .14762 Mdot
.57 .14768 Mdot
.57 .14789 Mdot
.57 .14811 Mdot
.57 .14819 Mdot
.57 .14862 Mdot
.57 .14872 Mdot
.57 .14875 Mdot
.57 .14915 Mdot
.57 .14922 Mdot
.57 .14964 Mdot
.57 .1499 Mdot
.57 .15061 Mdot
.57 .15072 Mdot
.57 .15078 Mdot
.57 .15145 Mdot
.57 .152 Mdot
.57 .15385 Mdot
.57 .15393 Mdot
.57 .15597 Mdot
.57 .156 Mdot
.57 .15671 Mdot
.57 .15675 Mdot
.57 .15791 Mdot
.57 .15872 Mdot
.57 .15889 Mdot
.57 .15924 Mdot
.57 .15991 Mdot
.57 .16041 Mdot
.57 .16071 Mdot
.57 .16169 Mdot
.57 .16188 Mdot
.57 .16258 Mdot
.57 .16296 Mdot
.57 .16315 Mdot
.57 .164 Mdot
.57 .16465 Mdot
.57 .16473 Mdot
.57 .16495 Mdot
.57 .16519 Mdot
.57 .1656 Mdot
.57 .16564 Mdot
.57 .16575 Mdot
.57 .16594 Mdot
.57 .16595 Mdot
.57 .16612 Mdot
.57 .16623 Mdot
.57 .1663 Mdot
.57 .16653 Mdot
.57 .16679 Mdot
.57 .16688 Mdot
.57 .16736 Mdot
.57 .16749 Mdot
.57 .16751 Mdot
.57 .16797 Mdot
.57 .16805 Mdot
.57 .16853 Mdot
.57 .16883 Mdot
.57 .16963 Mdot
.57 .16976 Mdot
.57 .16982 Mdot
.57 .17059 Mdot
.57 .17123 Mdot
.57 .17333 Mdot
.57 .17342 Mdot
.57 .17575 Mdot
.57 .17579 Mdot
.57 .17659 Mdot
.57 .17664 Mdot
.57 .17795 Mdot
.57 .17888 Mdot
.57 .17907 Mdot
.57 .17947 Mdot
.57 .18024 Mdot
.57 .18081 Mdot
.57 .18115 Mdot
.57 .18226 Mdot
.57 .18249 Mdot
.57 .18328 Mdot
.57 .18372 Mdot
.57 .18393 Mdot
.57 .1849 Mdot
.57 .18564 Mdot
.57 .18573 Mdot
.57 .18598 Mdot
.57 .18626 Mdot
.57 .18672 Mdot
.57 .18678 Mdot
.57 .18689 Mdot
.57 .18712 Mdot
.57 .18713 Mdot
.57 .18732 Mdot
.57 .18744 Mdot
.57 .18752 Mdot
.57 .18779 Mdot
.57 .18808 Mdot
.57 .18818 Mdot
.57 .18874 Mdot
.57 .18887 Mdot
.57 .1889 Mdot
.57 .18943 Mdot
.57 .18952 Mdot
.57 .19006 Mdot
.57 .1904 Mdot
.57 .19132 Mdot
.57 .19146 Mdot
.57 .19154 Mdot
.57 .19241 Mdot
.57 .19314 Mdot
.57 .19553 Mdot
.57 .19564 Mdot
.57 .1983 Mdot
.57 .19834 Mdot
.57 .19926 Mdot
.57 .19931 Mdot
.57 .20081 Mdot
.57 .20187 Mdot
.57 .20208 Mdot
.57 .20254 Mdot
.57 .20341 Mdot
.57 .20406 Mdot
.57 .20445 Mdot
.57 .20572 Mdot
.57 .20598 Mdot
.57 .20688 Mdot
.57 .20738 Mdot
.57 .20763 Mdot
.57 .20872 Mdot
.57 .20957 Mdot
.57 .20968 Mdot
.57 .20996 Mdot
.57 .21028 Mdot
.57 .2108 Mdot
.57 .21086 Mdot
.57 .21099 Mdot
.57 .21125 Mdot
.57 .21126 Mdot
.57 .21149 Mdot
.57 .21162 Mdot
.57 .21171 Mdot
.57 .21202 Mdot
.57 .21235 Mdot
.57 .21247 Mdot
.57 .2131 Mdot
.57 .21326 Mdot
.57 .21329 Mdot
.57 .21389 Mdot
.57 .21399 Mdot
.57 .21461 Mdot
.57 .215 Mdot
.57 .21604 Mdot
.57 .21621 Mdot
.57 .21629 Mdot
.57 .21729 Mdot
.57 .21812 Mdot
.57 .22085 Mdot
.57 .22097 Mdot
.57 .224 Mdot
.57 .22404 Mdot
.57 .22509 Mdot
.57 .22515 Mdot
.57 .22686 Mdot
.57 .22807 Mdot
.57 .22831 Mdot
.57 .22884 Mdot
.57 .22983 Mdot
.57 .23057 Mdot
.57 .23101 Mdot
.57 .23246 Mdot
.57 .23275 Mdot
.57 .23378 Mdot
.57 .23435 Mdot
.57 .23463 Mdot
.57 .23588 Mdot
.57 .23685 Mdot
.57 .23697 Mdot
.57 .23729 Mdot
.57 .23765 Mdot
.57 .23825 Mdot
.57 .23832 Mdot
.57 .23847 Mdot
.57 .23877 Mdot
.57 .23878 Mdot
.57 .23903 Mdot
.57 .23919 Mdot
.57 .23929 Mdot
.57 .23964 Mdot
.57 .24002 Mdot
.57 .24015 Mdot
.57 .24087 Mdot
.57 .24105 Mdot
.57 .24109 Mdot
.57 .24177 Mdot
.57 .24189 Mdot
.57 .2426 Mdot
.57 .24304 Mdot
.57 .24423 Mdot
.57 .24441 Mdot
.57 .24452 Mdot
.57 .24565 Mdot
.57 .24659 Mdot
.57 .24971 Mdot
.57 .24985 Mdot
.57 .2533 Mdot
.57 .25335 Mdot
.57 .25454 Mdot
.57 .25461 Mdot
.57 .25656 Mdot
.57 .25794 Mdot
.57 .25821 Mdot
.57 .25881 Mdot
.57 .25995 Mdot
.57 .26079 Mdot
.57 .26129 Mdot
.57 .26295 Mdot
.57 .26328 Mdot
.57 .26445 Mdot
.57 .2651 Mdot
.57 .26542 Mdot
.57 .26685 Mdot
.57 .26795 Mdot
.57 .26809 Mdot
.57 .26845 Mdot
.57 .26887 Mdot
.57 .26955 Mdot
.57 .26963 Mdot
.57 .2698 Mdot
.57 .27014 Mdot
.57 .27015 Mdot
.57 .27044 Mdot
.57 .27061 Mdot
.57 .27073 Mdot
.57 .27113 Mdot
.57 .27156 Mdot
.57 .27171 Mdot
.57 .27253 Mdot
.57 .27274 Mdot
.57 .27278 Mdot
.57 .27356 Mdot
.57 .27369 Mdot
.57 .2745 Mdot
.57 .27501 Mdot
.57 .27636 Mdot
.57 .27657 Mdot
.57 .27669 Mdot
.57 .27798 Mdot
.57 .27905 Mdot
.57 .2826 Mdot
.57 .28276 Mdot
.57 .2867 Mdot
.57 .28676 Mdot
.57 .28812 Mdot
.57 .2882 Mdot
.57 .29042 Mdot
.57 .29199 Mdot
.57 .2923 Mdot
.57 .29299 Mdot
.57 .29428 Mdot
.57 .29524 Mdot
.57 .29581 Mdot
.57 .2977 Mdot
.57 .29808 Mdot
.57 .29942 Mdot
.57 .30016 Mdot
.57 .30052 Mdot
.57 .30214 Mdot
.57 .3034 Mdot
.57 .30356 Mdot
.57 .30397 Mdot
.57 .30522 Mdot
.57 .30532 Mdot
.57 .30551 Mdot
.57 .30589 Mdot
.57 .30591 Mdot
.57 .30624 Mdot
.57 .30644 Mdot
.57 .30657 Mdot
.57 .30703 Mdot
.57 .30752 Mdot
.57 .30769 Mdot
.57 .30863 Mdot
.57 .30886 Mdot
.57 .30891 Mdot
.57 .3098 Mdot
.57 .30995 Mdot
.57 .31087 Mdot
.57 .31145 Mdot
.57 .31299 Mdot
.57 .31323 Mdot
.57 .31336 Mdot
.57 .31483 Mdot
.57 .31606 Mdot
.57 .32011 Mdot
.57 .32029 Mdot
.57 .32478 Mdot
.57 .32484 Mdot
.57 .3264 Mdot
.57 .32649 Mdot
.57 .32902 Mdot
.57 .33081 Mdot
.57 .33117 Mdot
.57 .33194 Mdot
.57 .33342 Mdot
.57 .33452 Mdot
.57 .33517 Mdot
.57 .33732 Mdot
.57 .33775 Mdot
.57 .33927 Mdot
.57 .34012 Mdot
.57 .34053 Mdot
.57 .34238 Mdot
.57 .34382 Mdot
.57 .344 Mdot
.57 .34447 Mdot
.57 .34589 Mdot
.57 .346 Mdot
.57 .34622 Mdot
.57 .34666 Mdot
.57 .34668 Mdot
.57 .34705 Mdot
.57 .34728 Mdot
.57 .34743 Mdot
.57 .34795 Mdot
.57 .34851 Mdot
.57 .34871 Mdot
.57 .34978 Mdot
.57 .35004 Mdot
.57 .35009 Mdot
.57 .35111 Mdot
.57 .35128 Mdot
.572 .01513 Mdot
.572 .01518 Mdot
.572 .0152 Mdot
.572 .01525 Mdot
.572 .01526 Mdot
.572 .0153 Mdot
.572 .01532 Mdot
.572 .01534 Mdot
.572 .01538 Mdot
.572 .01541 Mdot
.572 .01543 Mdot
.572 .01548 Mdot
.572 .01551 Mdot
.572 .01554 Mdot
.572 .01559 Mdot
.572 .01563 Mdot
.572 .01566 Mdot
.572 .01571 Mdot
.572 .01576 Mdot
.572 .01579 Mdot
.572 .01585 Mdot
.572 .01591 Mdot
.572 .01595 Mdot
.572 .01598 Mdot
.572 .01602 Mdot
.572 .01608 Mdot
.572 .01612 Mdot
.572 .01616 Mdot
.572 .01621 Mdot
.572 .01626 Mdot
.572 .01627 Mdot
.572 .01633 Mdot
.572 .01637 Mdot
.572 .01642 Mdot
.572 .01648 Mdot
.572 .0165 Mdot
.572 .01656 Mdot
.572 .01661 Mdot
.572 .01667 Mdot
.572 .01673 Mdot
.572 .01675 Mdot
.572 .01682 Mdot
.572 .01688 Mdot
.572 .01695 Mdot
.572 .01702 Mdot
.572 .01705 Mdot
.572 .01713 Mdot
.572 .01719 Mdot
.572 .01727 Mdot
.572 .01736 Mdot
.572 .01738 Mdot
.572 .01748 Mdot
.572 .01755 Mdot
.572 .01764 Mdot
.572 .01774 Mdot
.572 .01777 Mdot
.572 .01787 Mdot
.572 .01796 Mdot
.572 .01806 Mdot
.572 .01817 Mdot
.572 .01821 Mdot
.572 .01833 Mdot
.572 .01842 Mdot
.572 .01854 Mdot
.572 .01867 Mdot
.572 .01871 Mdot
.572 .01885 Mdot
.572 .01896 Mdot
.572 .01909 Mdot
.572 .01924 Mdot
.572 .01929 Mdot
.572 .01944 Mdot
.572 .01957 Mdot
.572 .01972 Mdot
.572 .01989 Mdot
.572 .01995 Mdot
.572 .02012 Mdot
.572 .02027 Mdot
.572 .02044 Mdot
.572 .02064 Mdot
.572 .0207 Mdot
.572 .0209 Mdot
.572 .02107 Mdot
.572 .02116 Mdot
.572 .02127 Mdot
.572 .02132 Mdot
.572 .02149 Mdot
.572 .02156 Mdot
.572 .02179 Mdot
.572 .02198 Mdot
.572 .02209 Mdot
.572 .02221 Mdot
.572 .02227 Mdot
.572 .02246 Mdot
.572 .02255 Mdot
.572 .02278 Mdot
.572 .02281 Mdot
.572 .02303 Mdot
.572 .02315 Mdot
.572 .02329 Mdot
.572 .02336 Mdot
.572 .02358 Mdot
.572 .02367 Mdot
.572 .02395 Mdot
.572 .02398 Mdot
.572 .02423 Mdot
.572 .02436 Mdot
.572 .02452 Mdot
.572 .0246 Mdot
.572 .02486 Mdot
.572 .02496 Mdot
.572 .02528 Mdot
.572 .02531 Mdot
.572 .02539 Mdot
.572 .0256 Mdot
.572 .02575 Mdot
.572 .02593 Mdot
.572 .02603 Mdot
.572 .02632 Mdot
.572 .02644 Mdot
.572 .02665 Mdot
.572 .02671 Mdot
.572 .0268 Mdot
.572 .02684 Mdot
.572 .02693 Mdot
.572 .02716 Mdot
.572 .02727 Mdot
.572 .02734 Mdot
.572 .02755 Mdot
.572 .02766 Mdot
.572 .02799 Mdot
.572 .02813 Mdot
.572 .02837 Mdot
.572 .02843 Mdot
.572 .02854 Mdot
.572 .02859 Mdot
.572 .02869 Mdot
.572 .02896 Mdot
.572 .02908 Mdot
.572 .02916 Mdot
.572 .02921 Mdot
.572 .02938 Mdot
.572 .0294 Mdot
.572 .02952 Mdot
.572 .02975 Mdot
.572 .0299 Mdot
.572 .03006 Mdot
.572 .03033 Mdot
.572 .03041 Mdot
.572 .03053 Mdot
.572 .03059 Mdot
.572 .0307 Mdot
.572 .03101 Mdot
.572 .03115 Mdot
.572 .03124 Mdot
.572 .0313 Mdot
.572 .0313 Mdot
.572 .03138 Mdot
.572 .03138 Mdot
.572 .03149 Mdot
.572 .03151 Mdot
.572 .03165 Mdot
.572 .03191 Mdot
.572 .03209 Mdot
.572 .03227 Mdot
.572 .03258 Mdot
.572 .03259 Mdot
.572 .03267 Mdot
.572 .0328 Mdot
.572 .03287 Mdot
.572 .033 Mdot
.572 .03303 Mdot
.572 .03335 Mdot
.572 .03351 Mdot
.572 .03362 Mdot
.572 .03368 Mdot
.572 .03369 Mdot
.572 .03377 Mdot
.572 .03378 Mdot
.572 .03391 Mdot
.572 .03393 Mdot
.572 .03409 Mdot
.572 .03439 Mdot
.572 .03459 Mdot
.572 .0348 Mdot
.572 .03516 Mdot
.572 .03517 Mdot
.572 .03525 Mdot
.572 .03541 Mdot
.572 .03548 Mdot
.572 .03563 Mdot
.572 .03567 Mdot
.572 .03576 Mdot
.572 .03604 Mdot
.572 .03605 Mdot
.572 .03622 Mdot
.572 .03627 Mdot
.572 .03634 Mdot
.572 .03639 Mdot
.572 .03641 Mdot
.572 .03642 Mdot
.572 .03652 Mdot
.572 .03652 Mdot
.572 .03667 Mdot
.572 .0367 Mdot
.572 .03688 Mdot
.572 .03722 Mdot
.572 .03745 Mdot
.572 .03769 Mdot
.572 .0381 Mdot
.572 .03811 Mdot
.572 .03821 Mdot
.572 .03839 Mdot
.572 .03848 Mdot
.572 .03865 Mdot
.572 .03868 Mdot
.572 .03879 Mdot
.572 .03909 Mdot
.572 .03911 Mdot
.572 .03912 Mdot
.572 .03932 Mdot
.572 .03938 Mdot
.572 .03945 Mdot
.572 .03951 Mdot
.572 .03954 Mdot
.572 .03954 Mdot
.572 .03966 Mdot
.572 .03966 Mdot
.572 .03983 Mdot
.572 .03987 Mdot
.572 .04 Mdot
.572 .04008 Mdot
.572 .04046 Mdot
.572 .04072 Mdot
.572 .041 Mdot
.572 .04109 Mdot
.572 .04147 Mdot
.572 .04148 Mdot
.572 .04159 Mdot
.572 .0418 Mdot
.572 .0419 Mdot
.572 .04194 Mdot
.572 .04209 Mdot
.572 .04213 Mdot
.572 .04225 Mdot
.572 .04226 Mdot
.572 .04239 Mdot
.572 .04243 Mdot
.572 .0426 Mdot
.572 .04262 Mdot
.572 .04264 Mdot
.572 .04286 Mdot
.572 .04293 Mdot
.572 .04301 Mdot
.572 .04308 Mdot
.572 .04311 Mdot
.572 .04312 Mdot
.572 .04325 Mdot
.572 .04325 Mdot
.572 .04345 Mdot
.572 .04349 Mdot
.572 .04364 Mdot
.572 .04373 Mdot
.572 .04415 Mdot
.572 .04417 Mdot
.572 .04418 Mdot
.572 .04447 Mdot
.572 .04478 Mdot
.572 .04488 Mdot
.572 .04532 Mdot
.572 .04533 Mdot
.572 .04546 Mdot
.572 .04569 Mdot
.572 .04581 Mdot
.572 .04586 Mdot
.572 .04603 Mdot
.572 .04608 Mdot
.572 .04622 Mdot
.572 .04623 Mdot
.572 .04637 Mdot
.572 .04642 Mdot
.572 .04662 Mdot
.572 .04664 Mdot
.572 .04666 Mdot
.572 .04667 Mdot
.572 .04691 Mdot
.572 .04699 Mdot
.572 .04709 Mdot
.572 .04716 Mdot
.572 .04719 Mdot
.572 .0472 Mdot
.572 .04721 Mdot
.572 .04736 Mdot
.572 .04736 Mdot
.572 .04758 Mdot
.572 .04763 Mdot
.572 .0478 Mdot
.572 .0479 Mdot
.572 .04839 Mdot
.572 .04841 Mdot
.572 .04842 Mdot
.572 .04875 Mdot
.572 .04911 Mdot
.572 .04912 Mdot
.572 .04923 Mdot
.572 .04973 Mdot
.572 .04974 Mdot
.572 .04989 Mdot
.572 .05016 Mdot
.572 .05028 Mdot
.572 .05029 Mdot
.572 .05035 Mdot
.572 .05054 Mdot
.572 .0506 Mdot
.572 .05076 Mdot
.572 .05076 Mdot
.572 .05093 Mdot
.572 .05098 Mdot
.572 .05121 Mdot
.572 .05124 Mdot
.572 .05126 Mdot
.572 .05127 Mdot
.572 .05155 Mdot
.572 .05164 Mdot
.572 .05175 Mdot
.572 .05184 Mdot
.572 .05187 Mdot
.572 .05188 Mdot
.572 .05189 Mdot
.572 .05206 Mdot
.572 .05206 Mdot
.572 .05232 Mdot
.572 .05237 Mdot
.572 .05257 Mdot
.572 .05268 Mdot
.572 .05324 Mdot
.572 .05326 Mdot
.572 .05327 Mdot
.572 .05366 Mdot
.572 .05407 Mdot
.572 .05407 Mdot
.572 .0542 Mdot
.572 .05477 Mdot
.572 .05479 Mdot
.572 .05496 Mdot
.572 .05526 Mdot
.572 .05541 Mdot
.572 .05541 Mdot
.572 .05548 Mdot
.572 .0557 Mdot
.572 .05572 Mdot
.572 .05577 Mdot
.572 .05595 Mdot
.572 .05595 Mdot
.572 .05595 Mdot
.572 .0561 Mdot
.572 .05615 Mdot
.572 .05621 Mdot
.572 .05646 Mdot
.572 .0565 Mdot
.572 .05652 Mdot
.572 .05654 Mdot
.572 .05685 Mdot
.572 .05696 Mdot
.572 .05708 Mdot
.572 .05718 Mdot
.572 .05722 Mdot
.572 .05723 Mdot
.572 .05724 Mdot
.572 .05744 Mdot
.572 .05744 Mdot
.572 .05773 Mdot
.572 .05779 Mdot
.572 .05802 Mdot
.572 .05815 Mdot
.572 .05878 Mdot
.572 .05881 Mdot
.572 .05883 Mdot
.572 .05926 Mdot
.572 .05973 Mdot
.572 .05974 Mdot
.572 .05985 Mdot
.572 .05988 Mdot
.572 .06053 Mdot
.572 .06056 Mdot
.572 .06075 Mdot
.572 .0611 Mdot
.572 .06126 Mdot
.572 .06127 Mdot
.572 .06135 Mdot
.572 .06161 Mdot
.572 .06163 Mdot
.572 .06168 Mdot
.572 .06188 Mdot
.572 .06189 Mdot
.572 .06189 Mdot
.572 .06205 Mdot
.572 .06211 Mdot
.572 .06218 Mdot
.572 .06248 Mdot
.572 .06251 Mdot
.572 .06254 Mdot
.572 .06256 Mdot
.572 .06292 Mdot
.572 .06304 Mdot
.572 .06318 Mdot
.572 .0633 Mdot
.572 .06334 Mdot
.572 .06336 Mdot
.572 .06336 Mdot
.572 .06359 Mdot
.572 .06359 Mdot
.572 .06393 Mdot
.572 .064 Mdot
.572 .06425 Mdot
.572 .06441 Mdot
.572 .06513 Mdot
.572 .06516 Mdot
.572 .06518 Mdot
.572 .06568 Mdot
.572 .06622 Mdot
.572 .06622 Mdot
.572 .06635 Mdot
.572 .06639 Mdot
.572 .06713 Mdot
.572 .06716 Mdot
.572 .06738 Mdot
.572 .06778 Mdot
.572 .06797 Mdot
.572 .06798 Mdot
.572 .06806 Mdot
.572 .06836 Mdot
.572 .06838 Mdot
.572 .06844 Mdot
.572 .06867 Mdot
.572 .06869 Mdot
.572 .06869 Mdot
.572 .06887 Mdot
.572 .06894 Mdot
.572 .06902 Mdot
.572 .06935 Mdot
.572 .0694 Mdot
.572 .06943 Mdot
.572 .06945 Mdot
.572 .06986 Mdot
.572 .07 Mdot
.572 .07016 Mdot
.572 .07029 Mdot
.572 .07034 Mdot
.572 .07036 Mdot
.572 .07037 Mdot
.572 .07063 Mdot
.572 .07063 Mdot
.572 .07101 Mdot
.572 .07109 Mdot
.572 .07138 Mdot
.572 .07156 Mdot
.572 .07239 Mdot
.572 .07242 Mdot
.572 .07245 Mdot
.572 .07302 Mdot
.572 .07363 Mdot
.572 .07364 Mdot
.572 .07378 Mdot
.572 .07383 Mdot
.572 .07468 Mdot
.572 .07471 Mdot
.572 .07496 Mdot
.572 .07542 Mdot
.572 .07564 Mdot
.572 .07565 Mdot
.572 .07574 Mdot
.572 .07608 Mdot
.572 .07611 Mdot
.572 .07618 Mdot
.572 .07644 Mdot
.572 .07646 Mdot
.572 .07646 Mdot
.572 .07667 Mdot
.572 .07675 Mdot
.572 .07684 Mdot
.572 .07722 Mdot
.572 .07727 Mdot
.572 .07731 Mdot
.572 .07733 Mdot
.572 .0778 Mdot
.572 .07796 Mdot
.572 .07815 Mdot
.572 .0783 Mdot
.572 .07835 Mdot
.572 .07837 Mdot
.572 .07838 Mdot
.572 .07868 Mdot
.572 .07869 Mdot
.572 .07912 Mdot
.572 .07921 Mdot
.572 .07955 Mdot
.572 .07975 Mdot
.572 .08069 Mdot
.572 .08073 Mdot
.572 .08076 Mdot
.572 .08141 Mdot
.572 .08212 Mdot
.572 .08213 Mdot
.572 .08229 Mdot
.572 .08234 Mdot
.572 .08332 Mdot
.572 .08335 Mdot
.572 .08364 Mdot
.572 .08416 Mdot
.572 .08441 Mdot
.572 .08442 Mdot
.572 .08453 Mdot
.572 .08492 Mdot
.572 .08495 Mdot
.572 .08503 Mdot
.572 .08533 Mdot
.572 .08535 Mdot
.572 .08535 Mdot
.572 .08559 Mdot
.572 .08568 Mdot
.572 .08578 Mdot
.572 .08622 Mdot
.572 .08628 Mdot
.572 .08632 Mdot
.572 .08635 Mdot
.572 .08689 Mdot
.572 .08707 Mdot
.572 .08728 Mdot
.572 .08745 Mdot
.572 .08751 Mdot
.572 .08754 Mdot
.572 .08755 Mdot
.572 .08789 Mdot
.572 .0879 Mdot
.572 .08839 Mdot
.572 .0885 Mdot
.572 .08888 Mdot
.572 .08911 Mdot
.572 .0902 Mdot
.572 .09024 Mdot
.572 .09027 Mdot
.572 .09102 Mdot
.572 .09182 Mdot
.572 .09183 Mdot
.572 .09186 Mdot
.572 .09202 Mdot
.572 .09208 Mdot
.572 .09319 Mdot
.572 .09323 Mdot
.572 .09357 Mdot
.572 .09416 Mdot
.572 .09445 Mdot
.572 .09446 Mdot
.572 .09459 Mdot
.572 .09503 Mdot
.572 .09507 Mdot
.572 .09515 Mdot
.572 .0955 Mdot
.572 .09552 Mdot
.572 .09552 Mdot
.572 .0958 Mdot
.572 .0959 Mdot
.572 .09602 Mdot
.572 .09652 Mdot
.572 .09659 Mdot
.572 .09664 Mdot
.572 .09666 Mdot
.572 .09728 Mdot
.572 .09748 Mdot
.572 .09773 Mdot
.572 .09793 Mdot
.572 .098 Mdot
.572 .09803 Mdot
.572 .09804 Mdot
.572 .09843 Mdot
.572 .09844 Mdot
.572 .099 Mdot
.572 .09912 Mdot
.572 .09956 Mdot
.572 .09983 Mdot
.572 .10106 Mdot
.572 .10112 Mdot
.572 .10115 Mdot
.572 .102 Mdot
.572 .10293 Mdot
.572 .10294 Mdot
.572 .10297 Mdot
.572 .10315 Mdot
.572 .10322 Mdot
.572 .1045 Mdot
.572 .10454 Mdot
.572 .10492 Mdot
.572 .1056 Mdot
.572 .10593 Mdot
.572 .10594 Mdot
.572 .10609 Mdot
.572 .10659 Mdot
.572 .10664 Mdot
.572 .10673 Mdot
.572 .10714 Mdot
.572 .10716 Mdot
.572 .10716 Mdot
.572 .10747 Mdot
.572 .10759 Mdot
.572 .10772 Mdot
.572 .1083 Mdot
.572 .10838 Mdot
.572 .10843 Mdot
.572 .10846 Mdot
.572 .10917 Mdot
.572 .1094 Mdot
.572 .10969 Mdot
.572 .10991 Mdot
.572 .10999 Mdot
.572 .11003 Mdot
.572 .11004 Mdot
.572 .11048 Mdot
.572 .11049 Mdot
.572 .11114 Mdot
.572 .11128 Mdot
.572 .11178 Mdot
.572 .11208 Mdot
.572 .1135 Mdot
.572 .11356 Mdot
.572 .1136 Mdot
.572 .11457 Mdot
.572 .11563 Mdot
.572 .11564 Mdot
.572 .11568 Mdot
.572 .11588 Mdot
.572 .11596 Mdot
.572 .11742 Mdot
.572 .11747 Mdot
.572 .11791 Mdot
.572 .11869 Mdot
.572 .11906 Mdot
.572 .11908 Mdot
.572 .11925 Mdot
.572 .11982 Mdot
.572 .11987 Mdot
.572 .11998 Mdot
.572 .12045 Mdot
.572 .12047 Mdot
.572 .12047 Mdot
.572 .12083 Mdot
.572 .12096 Mdot
.572 .12112 Mdot
.572 .12178 Mdot
.572 .12186 Mdot
.572 .12193 Mdot
.572 .12196 Mdot
.572 .12277 Mdot
.572 .12304 Mdot
.572 .12336 Mdot
.572 .12362 Mdot
.572 .12371 Mdot
.572 .12375 Mdot
.572 .12376 Mdot
.572 .12427 Mdot
.572 .12428 Mdot
.572 .12503 Mdot
.572 .12518 Mdot
.572 .12576 Mdot
.572 .1261 Mdot
.572 .12772 Mdot
.572 .12779 Mdot
.572 .12783 Mdot
.572 .12895 Mdot
.572 .13016 Mdot
.572 .13018 Mdot
.572 .13022 Mdot
.572 .13045 Mdot
.572 .13054 Mdot
.572 .13221 Mdot
.572 .13227 Mdot
.572 .13277 Mdot
.572 .13366 Mdot
.572 .13409 Mdot
.572 .13411 Mdot
.572 .1343 Mdot
.572 .13496 Mdot
.572 .13502 Mdot
.572 .13514 Mdot
.572 .13567 Mdot
.572 .1357 Mdot
.572 .1357 Mdot
.572 .13611 Mdot
.572 .13626 Mdot
.572 .13644 Mdot
.572 .13719 Mdot
.572 .13729 Mdot
.572 .13737 Mdot
.572 .13741 Mdot
.572 .13833 Mdot
.572 .13864 Mdot
.572 .13901 Mdot
.572 .1393 Mdot
.572 .13941 Mdot
.572 .13945 Mdot
.572 .13947 Mdot
.572 .14005 Mdot
.572 .14006 Mdot
.572 .14091 Mdot
.572 .14109 Mdot
.572 .14175 Mdot
.572 .14214 Mdot
.572 .144 Mdot
.572 .14408 Mdot
.572 .14412 Mdot
.572 .1454 Mdot
.572 .14679 Mdot
.572 .1468 Mdot
.572 .14685 Mdot
.572 .14712 Mdot
.572 .14722 Mdot
.572 .14913 Mdot
.572 .1492 Mdot
.572 .14977 Mdot
.572 .15079 Mdot
.572 .15128 Mdot
.572 .1513 Mdot
.572 .15152 Mdot
.572 .15227 Mdot
.572 .15234 Mdot
.572 .15248 Mdot
.572 .15309 Mdot
.572 .15312 Mdot
.572 .15312 Mdot
.572 .15359 Mdot
.572 .15376 Mdot
.572 .15397 Mdot
.572 .15483 Mdot
.572 .15494 Mdot
.572 .15503 Mdot
.572 .15507 Mdot
.572 .15613 Mdot
.572 .15648 Mdot
.572 .15691 Mdot
.572 .15724 Mdot
.572 .15736 Mdot
.572 .15741 Mdot
.572 .15743 Mdot
.572 .1581 Mdot
.572 .15811 Mdot
.572 .15908 Mdot
.572 .15929 Mdot
.572 .16004 Mdot
.572 .16049 Mdot
.572 .16261 Mdot
.572 .1627 Mdot
.572 .16276 Mdot
.572 .16422 Mdot
.572 .1658 Mdot
.572 .16582 Mdot
.572 .16588 Mdot
.572 .16618 Mdot
.572 .1663 Mdot
.572 .16849 Mdot
.572 .16856 Mdot
.572 .16922 Mdot
.572 .17038 Mdot
.572 .17094 Mdot
.572 .17097 Mdot
.572 .17122 Mdot
.572 .17208 Mdot
.572 .17216 Mdot
.572 .17232 Mdot
.572 .17301 Mdot
.572 .17305 Mdot
.572 .17305 Mdot
.572 .17359 Mdot
.572 .17379 Mdot
.572 .17402 Mdot
.572 .17501 Mdot
.572 .17514 Mdot
.572 .17523 Mdot
.572 .17529 Mdot
.572 .17649 Mdot
.572 .17689 Mdot
.572 .17738 Mdot
.572 .17776 Mdot
.572 .1779 Mdot
.572 .17796 Mdot
.572 .17798 Mdot
.572 .17875 Mdot
.572 .17876 Mdot
.572 .17987 Mdot
.572 .1801 Mdot
.572 .18096 Mdot
.572 .18148 Mdot
.572 .18391 Mdot
.572 .18401 Mdot
.572 .18408 Mdot
.572 .18575 Mdot
.572 .18756 Mdot
.572 .18758 Mdot
.572 .18764 Mdot
.572 .18799 Mdot
.572 .18813 Mdot
.572 .19063 Mdot
.572 .19072 Mdot
.572 .19146 Mdot
.572 .19279 Mdot
.572 .19344 Mdot
.572 .19347 Mdot
.572 .19375 Mdot
.572 .19474 Mdot
.572 .19483 Mdot
.572 .19502 Mdot
.572 .19581 Mdot
.572 .19585 Mdot
.572 .19585 Mdot
.572 .19647 Mdot
.572 .19669 Mdot
.572 .19696 Mdot
.572 .19809 Mdot
.572 .19824 Mdot
.572 .19835 Mdot
.572 .19841 Mdot
.572 .19979 Mdot
.572 .20025 Mdot
.572 .2008 Mdot
.572 .20124 Mdot
.572 .2014 Mdot
.572 .20147 Mdot
.572 .20149 Mdot
.572 .20237 Mdot
.572 .20238 Mdot
.572 .20366 Mdot
.572 .20392 Mdot
.572 .2049 Mdot
.572 .2055 Mdot
.572 .20827 Mdot
.572 .20839 Mdot
.572 .20847 Mdot
.572 .21038 Mdot
.572 .21245 Mdot
.572 .21248 Mdot
.572 .21254 Mdot
.572 .21294 Mdot
.572 .21311 Mdot
.572 .21597 Mdot
.572 .21606 Mdot
.572 .21692 Mdot
.572 .21844 Mdot
.572 .21917 Mdot
.572 .21921 Mdot
.572 .21954 Mdot
.572 .22067 Mdot
.572 .22077 Mdot
.572 .22098 Mdot
.572 .22189 Mdot
.572 .22193 Mdot
.572 .22193 Mdot
.572 .22264 Mdot
.572 .2229 Mdot
.572 .22449 Mdot
.572 .22466 Mdot
.572 .22479 Mdot
.572 .22486 Mdot
.572 .22644 Mdot
.572 .22697 Mdot
.572 .2276 Mdot
.572 .2281 Mdot
.572 .22828 Mdot
.572 .22836 Mdot
.572 .22839 Mdot
.572 .22939 Mdot
.572 .22941 Mdot
.572 .23086 Mdot
.572 .23117 Mdot
.572 .23229 Mdot
.572 .23297 Mdot
.572 .23615 Mdot
.572 .23628 Mdot
.572 .23637 Mdot
.572 .23855 Mdot
.572 .24092 Mdot
.572 .24095 Mdot
.572 .24103 Mdot
.572 .24149 Mdot
.572 .24167 Mdot
.572 .24495 Mdot
.572 .24506 Mdot
.572 .24603 Mdot
.572 .24777 Mdot
.572 .24861 Mdot
.572 .24865 Mdot
.572 .24903 Mdot
.572 .25033 Mdot
.572 .25044 Mdot
.572 .25068 Mdot
.572 .25172 Mdot
.572 .25177 Mdot
.572 .25177 Mdot
.572 .25258 Mdot
.572 .25288 Mdot
.572 .2547 Mdot
.572 .2549 Mdot
.572 .25504 Mdot
.572 .25512 Mdot
.572 .25692 Mdot
.572 .25753 Mdot
.572 .25826 Mdot
.572 .25883 Mdot
.572 .25904 Mdot
.572 .25913 Mdot
.572 .25915 Mdot
.572 .2603 Mdot
.572 .26032 Mdot
.572 .26199 Mdot
.572 .26234 Mdot
.572 .26362 Mdot
.572 .2644 Mdot
.572 .26803 Mdot
.572 .26819 Mdot
.572 .26828 Mdot
.572 .27079 Mdot
.572 .2735 Mdot
.572 .27353 Mdot
.572 .27362 Mdot
.572 .27414 Mdot
.572 .27436 Mdot
.572 .2781 Mdot
.572 .27822 Mdot
.572 .27934 Mdot
.572 .28133 Mdot
.572 .2823 Mdot
.572 .28234 Mdot
.572 .28277 Mdot
.572 .28425 Mdot
.572 .28438 Mdot
.572 .28466 Mdot
.572 .28585 Mdot
.572 .28591 Mdot
.572 .28591 Mdot
.572 .28684 Mdot
.572 .28717 Mdot
.572 .28926 Mdot
.572 .28948 Mdot
.572 .28965 Mdot
.572 .28974 Mdot
.572 .2918 Mdot
.572 .29249 Mdot
.572 .29333 Mdot
.572 .29398 Mdot
.572 .29422 Mdot
.572 .29432 Mdot
.572 .29435 Mdot
.572 .29567 Mdot
.572 .29569 Mdot
.572 .2976 Mdot
.572 .29799 Mdot
.572 .29947 Mdot
.572 .30036 Mdot
.572 .30451 Mdot
.572 .30469 Mdot
.572 .3048 Mdot
.572 .30766 Mdot
.572 .31076 Mdot
.572 .3108 Mdot
.572 .3109 Mdot
.572 .3115 Mdot
.572 .31174 Mdot
.572 .31603 Mdot
.572 .31617 Mdot
.572 .31745 Mdot
.572 .31973 Mdot
.572 .32083 Mdot
.572 .32088 Mdot
.572 .32137 Mdot
.572 .32307 Mdot
.572 .32321 Mdot
.572 .32354 Mdot
.572 .32489 Mdot
.572 .32496 Mdot
.572 .32496 Mdot
.572 .32602 Mdot
.572 .3264 Mdot
.572 .32879 Mdot
.572 .32905 Mdot
.572 .32924 Mdot
.572 .32934 Mdot
.572 .3317 Mdot
.572 .33249 Mdot
.572 .33345 Mdot
.572 .3342 Mdot
.572 .33447 Mdot
.572 .33459 Mdot
.572 .33462 Mdot
.572 .33613 Mdot
.572 .33615 Mdot
.572 .33833 Mdot
.572 .33878 Mdot
.572 .34047 Mdot
.572 .34149 Mdot
.572 .34624 Mdot
.572 .34644 Mdot
.572 .34657 Mdot
.572 .34985 Mdot
.574 .01557 Mdot
.574 .0157 Mdot
.574 .01584 Mdot
.574 .01601 Mdot
.574 .0162 Mdot
.574 .01642 Mdot
.574 .01668 Mdot
.574 .01697 Mdot
.574 .0173 Mdot
.574 .01748 Mdot
.574 .01768 Mdot
.574 .01789 Mdot
.574 .01812 Mdot
.574 .01821 Mdot
.574 .01836 Mdot
.574 .0184 Mdot
.574 .01863 Mdot
.574 .01872 Mdot
.574 .0189 Mdot
.574 .01895 Mdot
.574 .01921 Mdot
.574 .01932 Mdot
.574 .01951 Mdot
.574 .01953 Mdot
.574 .01957 Mdot
.574 .01987 Mdot
.574 .02 Mdot
.574 .02022 Mdot
.574 .02025 Mdot
.574 .02029 Mdot
.574 .02063 Mdot
.574 .02078 Mdot
.574 .02104 Mdot
.574 .02106 Mdot
.574 .02112 Mdot
.574 .02151 Mdot
.574 .02153 Mdot
.574 .02168 Mdot
.574 .02198 Mdot
.574 .022 Mdot
.574 .02206 Mdot
.574 .02251 Mdot
.574 .02254 Mdot
.574 .02271 Mdot
.574 .02274 Mdot
.574 .02279 Mdot
.574 .02286 Mdot
.574 .02305 Mdot
.574 .02308 Mdot
.574 .02315 Mdot
.574 .02367 Mdot
.574 .02369 Mdot
.574 .02389 Mdot
.574 .02393 Mdot
.574 .02398 Mdot
.574 .02406 Mdot
.574 .02428 Mdot
.574 .02432 Mdot
.574 .0244 Mdot
.574 .02467 Mdot
.574 .02499 Mdot
.574 .02502 Mdot
.574 .02525 Mdot
.574 .02529 Mdot
.574 .02535 Mdot
.574 .02545 Mdot
.574 .0257 Mdot
.574 .02574 Mdot
.574 .02574 Mdot
.574 .02584 Mdot
.574 .02614 Mdot
.574 .02651 Mdot
.574 .02655 Mdot
.574 .0268 Mdot
.574 .02686 Mdot
.574 .02693 Mdot
.574 .02704 Mdot
.574 .02733 Mdot
.574 .02737 Mdot
.574 .02738 Mdot
.574 .02748 Mdot
.574 .02783 Mdot
.574 .02826 Mdot
.574 .0283 Mdot
.574 .02843 Mdot
.574 .02859 Mdot
.574 .02866 Mdot
.574 .02873 Mdot
.574 .02886 Mdot
.574 .02919 Mdot
.574 .02925 Mdot
.574 .02925 Mdot
.574 .02937 Mdot
.574 .02978 Mdot
.574 .03027 Mdot
.574 .03031 Mdot
.574 .03046 Mdot
.574 .03057 Mdot
.574 .03065 Mdot
.574 .03072 Mdot
.574 .03081 Mdot
.574 .03095 Mdot
.574 .03134 Mdot
.574 .0314 Mdot
.574 .0314 Mdot
.574 .03154 Mdot
.574 .032 Mdot
.574 .03257 Mdot
.574 .03262 Mdot
.574 .03279 Mdot
.574 .03292 Mdot
.574 .03301 Mdot
.574 .03309 Mdot
.574 .03319 Mdot
.574 .03336 Mdot
.574 .0338 Mdot
.574 .03387 Mdot
.574 .03387 Mdot
.574 .03403 Mdot
.574 .03456 Mdot
.574 .03521 Mdot
.574 .03526 Mdot
.574 .03535 Mdot
.574 .03543 Mdot
.574 .03547 Mdot
.574 .03561 Mdot
.574 .03564 Mdot
.574 .03571 Mdot
.574 .03581 Mdot
.574 .03592 Mdot
.574 .03611 Mdot
.574 .03662 Mdot
.574 .0367 Mdot
.574 .03671 Mdot
.574 .03689 Mdot
.574 .03706 Mdot
.574 .0375 Mdot
.574 .03824 Mdot
.574 .03831 Mdot
.574 .03841 Mdot
.574 .03849 Mdot
.574 .03854 Mdot
.574 .0387 Mdot
.574 .03874 Mdot
.574 .03882 Mdot
.574 .03893 Mdot
.574 .03906 Mdot
.574 .03928 Mdot
.574 .03933 Mdot
.574 .03972 Mdot
.574 .03986 Mdot
.574 .03995 Mdot
.574 .03996 Mdot
.574 .04017 Mdot
.574 .04036 Mdot
.574 .04087 Mdot
.574 .04118 Mdot
.574 .04172 Mdot
.574 .0418 Mdot
.574 .04191 Mdot
.574 .04201 Mdot
.574 .04207 Mdot
.574 .04208 Mdot
.574 .04226 Mdot
.574 .04227 Mdot
.574 .0423 Mdot
.574 .04239 Mdot
.574 .04251 Mdot
.574 .04267 Mdot
.574 .04292 Mdot
.574 .04297 Mdot
.574 .04342 Mdot
.574 .04358 Mdot
.574 .04369 Mdot
.574 .0437 Mdot
.574 .04394 Mdot
.574 .04416 Mdot
.574 .04474 Mdot
.574 .0451 Mdot
.574 .0454 Mdot
.574 .04572 Mdot
.574 .04581 Mdot
.574 .04594 Mdot
.574 .04605 Mdot
.574 .0461 Mdot
.574 .04612 Mdot
.574 .04613 Mdot
.574 .04633 Mdot
.574 .04635 Mdot
.574 .04638 Mdot
.574 .04648 Mdot
.574 .04663 Mdot
.574 .0468 Mdot
.574 .04709 Mdot
.574 .04715 Mdot
.574 .04716 Mdot
.574 .04767 Mdot
.574 .04786 Mdot
.574 .04798 Mdot
.574 .04798 Mdot
.574 .04816 Mdot
.574 .04826 Mdot
.574 .04852 Mdot
.574 .04919 Mdot
.574 .0496 Mdot
.574 .04974 Mdot
.574 .04984 Mdot
.574 .04994 Mdot
.574 .05031 Mdot
.574 .05041 Mdot
.574 .05056 Mdot
.574 .05069 Mdot
.574 .05075 Mdot
.574 .05076 Mdot
.574 .05078 Mdot
.574 .05101 Mdot
.574 .05103 Mdot
.574 .05106 Mdot
.574 .0511 Mdot
.574 .05119 Mdot
.574 .05135 Mdot
.574 .05155 Mdot
.574 .05173 Mdot
.574 .05188 Mdot
.574 .05188 Mdot
.574 .05195 Mdot
.574 .05196 Mdot
.574 .05211 Mdot
.574 .05254 Mdot
.574 .05276 Mdot
.574 .0529 Mdot
.574 .05291 Mdot
.574 .05311 Mdot
.574 .05323 Mdot
.574 .05352 Mdot
.574 .05376 Mdot
.574 .05429 Mdot
.574 .05431 Mdot
.574 .05447 Mdot
.574 .05472 Mdot
.574 .05476 Mdot
.574 .05492 Mdot
.574 .05502 Mdot
.574 .05504 Mdot
.574 .05515 Mdot
.574 .05539 Mdot
.574 .05546 Mdot
.574 .05558 Mdot
.574 .05569 Mdot
.574 .05586 Mdot
.574 .05601 Mdot
.574 .05608 Mdot
.574 .0561 Mdot
.574 .05612 Mdot
.574 .0563 Mdot
.574 .05638 Mdot
.574 .05641 Mdot
.574 .05644 Mdot
.574 .05648 Mdot
.574 .05658 Mdot
.574 .05677 Mdot
.574 .05701 Mdot
.574 .05721 Mdot
.574 .05738 Mdot
.574 .05738 Mdot
.574 .05746 Mdot
.574 .05747 Mdot
.574 .05764 Mdot
.574 .058 Mdot
.574 .05814 Mdot
.574 .05839 Mdot
.574 .05855 Mdot
.574 .05856 Mdot
.574 .05879 Mdot
.574 .05893 Mdot
.574 .05926 Mdot
.574 .05953 Mdot
.574 .06014 Mdot
.574 .06015 Mdot
.574 .06017 Mdot
.574 .06035 Mdot
.574 .06064 Mdot
.574 .06069 Mdot
.574 .06087 Mdot
.574 .06099 Mdot
.574 .06101 Mdot
.574 .06113 Mdot
.574 .0614 Mdot
.574 .06149 Mdot
.574 .06163 Mdot
.574 .06175 Mdot
.574 .06195 Mdot
.574 .06197 Mdot
.574 .06212 Mdot
.574 .0622 Mdot
.574 .06222 Mdot
.574 .06225 Mdot
.574 .06246 Mdot
.574 .06253 Mdot
.574 .06255 Mdot
.574 .06258 Mdot
.574 .06262 Mdot
.574 .06266 Mdot
.574 .06267 Mdot
.574 .06278 Mdot
.574 .06299 Mdot
.574 .06326 Mdot
.574 .06349 Mdot
.574 .06357 Mdot
.574 .06358 Mdot
.574 .0637 Mdot
.574 .0637 Mdot
.574 .06379 Mdot
.574 .0638 Mdot
.574 .064 Mdot
.574 .06427 Mdot
.574 .06438 Mdot
.574 .06441 Mdot
.574 .06457 Mdot
.574 .06486 Mdot
.574 .06504 Mdot
.574 .06505 Mdot
.574 .06531 Mdot
.574 .06547 Mdot
.574 .06586 Mdot
.574 .06617 Mdot
.574 .06686 Mdot
.574 .06687 Mdot
.574 .0669 Mdot
.574 .06711 Mdot
.574 .06744 Mdot
.574 .06749 Mdot
.574 .0677 Mdot
.574 .06783 Mdot
.574 .06786 Mdot
.574 .068 Mdot
.574 .06831 Mdot
.574 .06842 Mdot
.574 .06857 Mdot
.574 .06871 Mdot
.574 .06894 Mdot
.574 .06896 Mdot
.574 .06914 Mdot
.574 .06923 Mdot
.574 .06925 Mdot
.574 .06929 Mdot
.574 .06953 Mdot
.574 .06961 Mdot
.574 .06963 Mdot
.574 .06966 Mdot
.574 .06971 Mdot
.574 .06976 Mdot
.574 .06977 Mdot
.574 .06989 Mdot
.574 .07014 Mdot
.574 .07045 Mdot
.574 .07071 Mdot
.574 .0708 Mdot
.574 .07082 Mdot
.574 .07095 Mdot
.574 .07095 Mdot
.574 .07105 Mdot
.574 .07106 Mdot
.574 .07129 Mdot
.574 .07161 Mdot
.574 .07173 Mdot
.574 .07176 Mdot
.574 .07195 Mdot
.574 .07228 Mdot
.574 .07248 Mdot
.574 .07249 Mdot
.574 .0725 Mdot
.574 .0728 Mdot
.574 .07298 Mdot
.574 .07343 Mdot
.574 .07378 Mdot
.574 .07458 Mdot
.574 .07459 Mdot
.574 .07463 Mdot
.574 .07486 Mdot
.574 .07524 Mdot
.574 .0753 Mdot
.574 .07555 Mdot
.574 .0757 Mdot
.574 .07573 Mdot
.574 .07589 Mdot
.574 .07625 Mdot
.574 .07636 Mdot
.574 .07654 Mdot
.574 .07671 Mdot
.574 .07697 Mdot
.574 .07699 Mdot
.574 .0772 Mdot
.574 .0773 Mdot
.574 .07733 Mdot
.574 .07736 Mdot
.574 .07764 Mdot
.574 .07773 Mdot
.574 .07776 Mdot
.574 .0778 Mdot
.574 .07785 Mdot
.574 .07791 Mdot
.574 .07792 Mdot
.574 .07806 Mdot
.574 .07834 Mdot
.574 .0787 Mdot
.574 .079 Mdot
.574 .0791 Mdot
.574 .07912 Mdot
.574 .07927 Mdot
.574 .07927 Mdot
.574 .07939 Mdot
.574 .0794 Mdot
.574 .07966 Mdot
.574 .08003 Mdot
.574 .08016 Mdot
.574 .0802 Mdot
.574 .08042 Mdot
.574 .0808 Mdot
.574 .08103 Mdot
.574 .08104 Mdot
.574 .08105 Mdot
.574 .0814 Mdot
.574 .0816 Mdot
.574 .08212 Mdot
.574 .08252 Mdot
.574 .08344 Mdot
.574 .08345 Mdot
.574 .08349 Mdot
.574 .08376 Mdot
.574 .0842 Mdot
.574 .08427 Mdot
.574 .08455 Mdot
.574 .08472 Mdot
.574 .08476 Mdot
.574 .08535 Mdot
.574 .08549 Mdot
.574 .08569 Mdot
.574 .08588 Mdot
.574 .08618 Mdot
.574 .0862 Mdot
.574 .08644 Mdot
.574 .08656 Mdot
.574 .08659 Mdot
.574 .08663 Mdot
.574 .08695 Mdot
.574 .08706 Mdot
.574 .08709 Mdot
.574 .08713 Mdot
.574 .08719 Mdot
.574 .08726 Mdot
.574 .08728 Mdot
.574 .08744 Mdot
.574 .08776 Mdot
.574 .08817 Mdot
.574 .08852 Mdot
.574 .08862 Mdot
.574 .08865 Mdot
.574 .08882 Mdot
.574 .08883 Mdot
.574 .08896 Mdot
.574 .08898 Mdot
.574 .08927 Mdot
.574 .08969 Mdot
.574 .08985 Mdot
.574 .08989 Mdot
.574 .09014 Mdot
.574 .09058 Mdot
.574 .09084 Mdot
.574 .09085 Mdot
.574 .09087 Mdot
.574 .09127 Mdot
.574 .0915 Mdot
.574 .09209 Mdot
.574 .09256 Mdot
.574 .09361 Mdot
.574 .09362 Mdot
.574 .09367 Mdot
.574 .09398 Mdot
.574 .09448 Mdot
.574 .09456 Mdot
.574 .09489 Mdot
.574 .09508 Mdot
.574 .09512 Mdot
.574 .09581 Mdot
.574 .09596 Mdot
.574 .09619 Mdot
.574 .09641 Mdot
.574 .09676 Mdot
.574 .09678 Mdot
.574 .09706 Mdot
.574 .0972 Mdot
.574 .09723 Mdot
.574 .09728 Mdot
.574 .09764 Mdot
.574 .09776 Mdot
.574 .0978 Mdot
.574 .09785 Mdot
.574 .09792 Mdot
.574 .098 Mdot
.574 .09801 Mdot
.574 .0982 Mdot
.574 .09857 Mdot
.574 .09904 Mdot
.574 .09944 Mdot
.574 .09956 Mdot
.574 .09959 Mdot
.574 .09979 Mdot
.574 .09979 Mdot
.574 .09994 Mdot
.574 .09997 Mdot
.574 .10031 Mdot
.574 .10079 Mdot
.574 .10097 Mdot
.574 .10102 Mdot
.574 .10131 Mdot
.574 .10181 Mdot
.574 .10211 Mdot
.574 .10212 Mdot
.574 .10214 Mdot
.574 .1026 Mdot
.574 .10287 Mdot
.574 .10354 Mdot
.574 .10408 Mdot
.574 .10528 Mdot
.574 .1053 Mdot
.574 .10536 Mdot
.574 .10571 Mdot
.574 .10628 Mdot
.574 .10638 Mdot
.574 .10675 Mdot
.574 .10698 Mdot
.574 .10702 Mdot
.574 .10781 Mdot
.574 .10799 Mdot
.574 .10825 Mdot
.574 .1085 Mdot
.574 .1089 Mdot
.574 .10893 Mdot
.574 .10924 Mdot
.574 .1094 Mdot
.574 .10944 Mdot
.574 .1095 Mdot
.574 .10991 Mdot
.574 .11005 Mdot
.574 .11009 Mdot
.574 .11016 Mdot
.574 .11023 Mdot
.574 .11032 Mdot
.574 .11034 Mdot
.574 .11055 Mdot
.574 .11098 Mdot
.574 .11152 Mdot
.574 .11198 Mdot
.574 .11212 Mdot
.574 .11216 Mdot
.574 .11238 Mdot
.574 .11238 Mdot
.574 .11256 Mdot
.574 .11258 Mdot
.574 .11298 Mdot
.574 .11353 Mdot
.574 .11374 Mdot
.574 .11379 Mdot
.574 .11412 Mdot
.574 .1147 Mdot
.574 .11505 Mdot
.574 .11506 Mdot
.574 .11508 Mdot
.574 .1156 Mdot
.574 .11591 Mdot
.574 .11669 Mdot
.574 .11731 Mdot
.574 .11869 Mdot
.574 .11871 Mdot
.574 .11877 Mdot
.574 .11918 Mdot
.574 .11984 Mdot
.574 .11995 Mdot
.574 .12037 Mdot
.574 .12063 Mdot
.574 .12069 Mdot
.574 .12159 Mdot
.574 .12179 Mdot
.574 .12209 Mdot
.574 .12239 Mdot
.574 .12284 Mdot
.574 .12287 Mdot
.574 .12323 Mdot
.574 .12342 Mdot
.574 .12346 Mdot
.574 .12353 Mdot
.574 .124 Mdot
.574 .12416 Mdot
.574 .12421 Mdot
.574 .12428 Mdot
.574 .12437 Mdot
.574 .12447 Mdot
.574 .1245 Mdot
.574 .12474 Mdot
.574 .12523 Mdot
.574 .12584 Mdot
.574 .12637 Mdot
.574 .12654 Mdot
.574 .12658 Mdot
.574 .12683 Mdot
.574 .12684 Mdot
.574 .12704 Mdot
.574 .12707 Mdot
.574 .12752 Mdot
.574 .12815 Mdot
.574 .12839 Mdot
.574 .12846 Mdot
.574 .12883 Mdot
.574 .12949 Mdot
.574 .1299 Mdot
.574 .12991 Mdot
.574 .12993 Mdot
.574 .13053 Mdot
.574 .13089 Mdot
.574 .13178 Mdot
.574 .13249 Mdot
.574 .13408 Mdot
.574 .1341 Mdot
.574 .13417 Mdot
.574 .13464 Mdot
.574 .1354 Mdot
.574 .13552 Mdot
.574 .13601 Mdot
.574 .13631 Mdot
.574 .13637 Mdot
.574 .13741 Mdot
.574 .13764 Mdot
.574 .13799 Mdot
.574 .13832 Mdot
.574 .13885 Mdot
.574 .13888 Mdot
.574 .1393 Mdot
.574 .1395 Mdot
.574 .13956 Mdot
.574 .13963 Mdot
.574 .14018 Mdot
.574 .14036 Mdot
.574 .14041 Mdot
.574 .1405 Mdot
.574 .1406 Mdot
.574 .14072 Mdot
.574 .14074 Mdot
.574 .14102 Mdot
.574 .14158 Mdot
.574 .14229 Mdot
.574 .1429 Mdot
.574 .14308 Mdot
.574 .14313 Mdot
.574 .14343 Mdot
.574 .14343 Mdot
.574 .14366 Mdot
.574 .1437 Mdot
.574 .14421 Mdot
.574 .14494 Mdot
.574 .14522 Mdot
.574 .14529 Mdot
.574 .14572 Mdot
.574 .14648 Mdot
.574 .14694 Mdot
.574 .14696 Mdot
.574 .14699 Mdot
.574 .14768 Mdot
.574 .14808 Mdot
.574 .14911 Mdot
.574 .14992 Mdot
.574 .15174 Mdot
.574 .15177 Mdot
.574 .15185 Mdot
.574 .15239 Mdot
.574 .15326 Mdot
.574 .1534 Mdot
.574 .15396 Mdot
.574 .1543 Mdot
.574 .15438 Mdot
.574 .15556 Mdot
.574 .15583 Mdot
.574 .15623 Mdot
.574 .15661 Mdot
.574 .15722 Mdot
.574 .15726 Mdot
.574 .15773 Mdot
.574 .15797 Mdot
.574 .15803 Mdot
.574 .15812 Mdot
.574 .15875 Mdot
.574 .15896 Mdot
.574 .15902 Mdot
.574 .15911 Mdot
.574 .15923 Mdot
.574 .15937 Mdot
.574 .15939 Mdot
.574 .15971 Mdot
.574 .16036 Mdot
.574 .16117 Mdot
.574 .16187 Mdot
.574 .16208 Mdot
.574 .16214 Mdot
.574 .16248 Mdot
.574 .16249 Mdot
.574 .16275 Mdot
.574 .16279 Mdot
.574 .16338 Mdot
.574 .16421 Mdot
.574 .16453 Mdot
.574 .16462 Mdot
.574 .16511 Mdot
.574 .16598 Mdot
.574 .16651 Mdot
.574 .16653 Mdot
.574 .16656 Mdot
.574 .16735 Mdot
.574 .16782 Mdot
.574 .169 Mdot
.574 .16993 Mdot
.574 .17202 Mdot
.574 .17205 Mdot
.574 .17215 Mdot
.574 .17277 Mdot
.574 .17376 Mdot
.574 .17393 Mdot
.574 .17457 Mdot
.574 .17496 Mdot
.574 .17505 Mdot
.574 .17641 Mdot
.574 .17672 Mdot
.574 .17717 Mdot
.574 .17762 Mdot
.574 .17831 Mdot
.574 .17835 Mdot
.574 .1789 Mdot
.574 .17918 Mdot
.574 .17924 Mdot
.574 .17934 Mdot
.574 .18006 Mdot
.574 .18031 Mdot
.574 .18037 Mdot
.574 .18048 Mdot
.574 .18061 Mdot
.574 .18077 Mdot
.574 .18081 Mdot
.574 .18117 Mdot
.574 .18192 Mdot
.574 .18285 Mdot
.574 .18365 Mdot
.574 .18389 Mdot
.574 .18396 Mdot
.574 .18435 Mdot
.574 .18436 Mdot
.574 .18466 Mdot
.574 .1847 Mdot
.574 .18538 Mdot
.574 .18634 Mdot
.574 .1867 Mdot
.574 .1868 Mdot
.574 .18737 Mdot
.574 .18837 Mdot
.574 .18898 Mdot
.574 .189 Mdot
.574 .18904 Mdot
.574 .18995 Mdot
.574 .19048 Mdot
.574 .19183 Mdot
.574 .19291 Mdot
.574 .1953 Mdot
.574 .19534 Mdot
.574 .19545 Mdot
.574 .19616 Mdot
.574 .1973 Mdot
.574 .19749 Mdot
.574 .19823 Mdot
.574 .19868 Mdot
.574 .19877 Mdot
.574 .20034 Mdot
.574 .20069 Mdot
.574 .20122 Mdot
.574 .20173 Mdot
.574 .20252 Mdot
.574 .20257 Mdot
.574 .2032 Mdot
.574 .20352 Mdot
.574 .20359 Mdot
.574 .20371 Mdot
.574 .20453 Mdot
.574 .20481 Mdot
.574 .20489 Mdot
.574 .20502 Mdot
.574 .20517 Mdot
.574 .20535 Mdot
.574 .20539 Mdot
.574 .20581 Mdot
.574 .20666 Mdot
.574 .20773 Mdot
.574 .20865 Mdot
.574 .20893 Mdot
.574 .20901 Mdot
.574 .20945 Mdot
.574 .20946 Mdot
.574 .20981 Mdot
.574 .20986 Mdot
.574 .21064 Mdot
.574 .21174 Mdot
.574 .21216 Mdot
.574 .21227 Mdot
.574 .21292 Mdot
.574 .21407 Mdot
.574 .21477 Mdot
.574 .2148 Mdot
.574 .21484 Mdot
.574 .21588 Mdot
.574 .2165 Mdot
.574 .21805 Mdot
.574 .21928 Mdot
.574 .22203 Mdot
.574 .22207 Mdot
.574 .2222 Mdot
.574 .22301 Mdot
.574 .22432 Mdot
.574 .22454 Mdot
.574 .22539 Mdot
.574 .22591 Mdot
.574 .22601 Mdot
.574 .22781 Mdot
.574 .22822 Mdot
.574 .22882 Mdot
.574 .2294 Mdot
.574 .23031 Mdot
.574 .23037 Mdot
.574 .2311 Mdot
.574 .23146 Mdot
.574 .23155 Mdot
.574 .23168 Mdot
.574 .23263 Mdot
.574 .23295 Mdot
.574 .23304 Mdot
.574 .23318 Mdot
.574 .23335 Mdot
.574 .23356 Mdot
.574 .23361 Mdot
.574 .23409 Mdot
.574 .23507 Mdot
.574 .2363 Mdot
.574 .23735 Mdot
.574 .23768 Mdot
.574 .23776 Mdot
.574 .23827 Mdot
.574 .23828 Mdot
.574 .23868 Mdot
.574 .23874 Mdot
.574 .23964 Mdot
.574 .2409 Mdot
.574 .24138 Mdot
.574 .24151 Mdot
.574 .24226 Mdot
.574 .24357 Mdot
.574 .24438 Mdot
.574 .24441 Mdot
.574 .24445 Mdot
.574 .24565 Mdot
.574 .24636 Mdot
.574 .24814 Mdot
.574 .24955 Mdot
.574 .25271 Mdot
.574 .25276 Mdot
.574 .2529 Mdot
.574 .25384 Mdot
.574 .25534 Mdot
.574 .2556 Mdot
.574 .25657 Mdot
.574 .25716 Mdot
.574 .25729 Mdot
.574 .25935 Mdot
.574 .25982 Mdot
.574 .26051 Mdot
.574 .26118 Mdot
.574 .26222 Mdot
.574 .26229 Mdot
.574 .26312 Mdot
.574 .26354 Mdot
.574 .26364 Mdot
.574 .26379 Mdot
.574 .26488 Mdot
.574 .26525 Mdot
.574 .26535 Mdot
.574 .26551 Mdot
.574 .26571 Mdot
.574 .26595 Mdot
.574 .266 Mdot
.574 .26656 Mdot
.574 .26768 Mdot
.574 .26909 Mdot
.574 .2703 Mdot
.574 .27068 Mdot
.574 .27077 Mdot
.574 .27136 Mdot
.574 .27137 Mdot
.574 .27183 Mdot
.574 .2719 Mdot
.574 .27293 Mdot
.574 .27437 Mdot
.574 .27493 Mdot
.574 .27507 Mdot
.574 .27593 Mdot
.574 .27745 Mdot
.574 .27837 Mdot
.574 .2784 Mdot
.574 .27846 Mdot
.574 .27983 Mdot
.574 .28064 Mdot
.574 .28269 Mdot
.574 .28431 Mdot
.574 .28794 Mdot
.574 .28799 Mdot
.574 .28816 Mdot
.574 .28923 Mdot
.574 .29096 Mdot
.574 .29125 Mdot
.574 .29236 Mdot
.574 .29304 Mdot
.574 .29319 Mdot
.574 .29556 Mdot
.574 .29609 Mdot
.574 .29689 Mdot
.574 .29765 Mdot
.574 .29885 Mdot
.574 .29893 Mdot
.574 .29988 Mdot
.574 .30036 Mdot
.574 .30048 Mdot
.574 .30065 Mdot
.574 .3019 Mdot
.574 .30232 Mdot
.574 .30244 Mdot
.574 .30263 Mdot
.574 .30286 Mdot
.574 .30314 Mdot
.574 .3032 Mdot
.574 .30383 Mdot
.574 .30512 Mdot
.574 .30674 Mdot
.574 .30813 Mdot
.574 .30856 Mdot
.574 .30867 Mdot
.574 .30934 Mdot
.574 .30936 Mdot
.574 .30988 Mdot
.574 .30996 Mdot
.574 .31114 Mdot
.574 .3128 Mdot
.574 .31344 Mdot
.574 .31361 Mdot
.574 .31459 Mdot
.574 .31633 Mdot
.574 .31739 Mdot
.574 .31743 Mdot
.574 .31749 Mdot
.574 .31907 Mdot
.574 .32 Mdot
.574 .32235 Mdot
.574 .32421 Mdot
.574 .32837 Mdot
.574 .32844 Mdot
.574 .32863 Mdot
.574 .32986 Mdot
.574 .33184 Mdot
.574 .33218 Mdot
.574 .33345 Mdot
.574 .33424 Mdot
.574 .3344 Mdot
.574 .33712 Mdot
.574 .33774 Mdot
.574 .33865 Mdot
.574 .33953 Mdot
.574 .3409 Mdot
.574 .341 Mdot
.574 .34209 Mdot
.574 .34264 Mdot
.574 .34277 Mdot
.574 .34297 Mdot
.574 .3444 Mdot
.574 .34489 Mdot
.574 .34502 Mdot
.574 .34524 Mdot
.574 .34551 Mdot
.574 .34582 Mdot
.574 .34589 Mdot
.574 .34662 Mdot
.574 .3481 Mdot
.574 .34996 Mdot
.574 .35155 Mdot
.574 .35205 Mdot
.574 .35217 Mdot
.574 .35295 Mdot
.574 .35296 Mdot
.574 .35356 Mdot
.574 .35366 Mdot
.576 .01518 Mdot
.576 .01525 Mdot
.576 .01533 Mdot
.576 .01543 Mdot
.576 .01554 Mdot
.576 .01559 Mdot
.576 .01566 Mdot
.576 .01572 Mdot
.576 .01581 Mdot
.576 .01587 Mdot
.576 .01597 Mdot
.576 .01605 Mdot
.576 .01616 Mdot
.576 .01625 Mdot
.576 .01638 Mdot
.576 .01648 Mdot
.576 .01664 Mdot
.576 .01675 Mdot
.576 .01693 Mdot
.576 .01706 Mdot
.576 .01727 Mdot
.576 .01742 Mdot
.576 .01765 Mdot
.576 .01783 Mdot
.576 .0181 Mdot
.576 .0183 Mdot
.576 .01862 Mdot
.576 .01884 Mdot
.576 .01921 Mdot
.576 .01947 Mdot
.576 .01973 Mdot
.576 .01989 Mdot
.576 .02019 Mdot
.576 .0205 Mdot
.576 .02066 Mdot
.576 .02068 Mdot
.576 .02103 Mdot
.576 .02111 Mdot
.576 .02131 Mdot
.576 .02138 Mdot
.576 .02156 Mdot
.576 .02157 Mdot
.576 .02159 Mdot
.576 .02199 Mdot
.576 .02208 Mdot
.576 .02215 Mdot
.576 .02231 Mdot
.576 .02239 Mdot
.576 .0226 Mdot
.576 .02261 Mdot
.576 .02263 Mdot
.576 .02309 Mdot
.576 .02312 Mdot
.576 .0232 Mdot
.576 .02328 Mdot
.576 .02329 Mdot
.576 .02347 Mdot
.576 .02355 Mdot
.576 .02377 Mdot
.576 .0238 Mdot
.576 .02381 Mdot
.576 .02383 Mdot
.576 .02384 Mdot
.576 .02418 Mdot
.576 .02436 Mdot
.576 .02439 Mdot
.576 .02449 Mdot
.576 .02458 Mdot
.576 .02459 Mdot
.576 .0248 Mdot
.576 .0249 Mdot
.576 .02514 Mdot
.576 .02518 Mdot
.576 .02519 Mdot
.576 .02522 Mdot
.576 .02522 Mdot
.576 .02561 Mdot
.576 .02583 Mdot
.576 .02586 Mdot
.576 .02597 Mdot
.576 .02608 Mdot
.576 .02609 Mdot
.576 .02633 Mdot
.576 .02645 Mdot
.576 .02673 Mdot
.576 .02677 Mdot
.576 .02678 Mdot
.576 .02682 Mdot
.576 .02682 Mdot
.576 .02727 Mdot
.576 .02752 Mdot
.576 .02756 Mdot
.576 .02768 Mdot
.576 .02781 Mdot
.576 .02782 Mdot
.576 .02809 Mdot
.576 .02821 Mdot
.576 .02823 Mdot
.576 .02855 Mdot
.576 .0286 Mdot
.576 .02862 Mdot
.576 .02865 Mdot
.576 .02866 Mdot
.576 .02918 Mdot
.576 .02947 Mdot
.576 .02951 Mdot
.576 .02965 Mdot
.576 .0298 Mdot
.576 .02982 Mdot
.576 .03013 Mdot
.576 .03019 Mdot
.576 .03026 Mdot
.576 .03028 Mdot
.576 .03046 Mdot
.576 .03066 Mdot
.576 .03071 Mdot
.576 .03073 Mdot
.576 .03075 Mdot
.576 .03077 Mdot
.576 .03078 Mdot
.576 .03138 Mdot
.576 .03171 Mdot
.576 .03176 Mdot
.576 .03192 Mdot
.576 .03209 Mdot
.576 .03211 Mdot
.576 .03247 Mdot
.576 .03255 Mdot
.576 .0326 Mdot
.576 .03263 Mdot
.576 .03265 Mdot
.576 .03286 Mdot
.576 .03308 Mdot
.576 .03314 Mdot
.576 .03317 Mdot
.576 .03319 Mdot
.576 .03321 Mdot
.576 .03322 Mdot
.576 .03338 Mdot
.576 .03381 Mdot
.576 .03391 Mdot
.576 .03429 Mdot
.576 .0343 Mdot
.576 .03435 Mdot
.576 .03454 Mdot
.576 .03473 Mdot
.576 .03474 Mdot
.576 .03476 Mdot
.576 .03484 Mdot
.576 .03517 Mdot
.576 .03522 Mdot
.576 .03526 Mdot
.576 .03531 Mdot
.576 .03532 Mdot
.576 .03535 Mdot
.576 .03537 Mdot
.576 .03561 Mdot
.576 .03587 Mdot
.576 .03594 Mdot
.576 .03597 Mdot
.576 .036 Mdot
.576 .03603 Mdot
.576 .03603 Mdot
.576 .03622 Mdot
.576 .03671 Mdot
.576 .03683 Mdot
.576 .03727 Mdot
.576 .03728 Mdot
.576 .03734 Mdot
.576 .03755 Mdot
.576 .03772 Mdot
.576 .03778 Mdot
.576 .03778 Mdot
.576 .0378 Mdot
.576 .0379 Mdot
.576 .03793 Mdot
.576 .03828 Mdot
.576 .03834 Mdot
.576 .03838 Mdot
.576 .03844 Mdot
.576 .03845 Mdot
.576 .03849 Mdot
.576 .03849 Mdot
.576 .03852 Mdot
.576 .03879 Mdot
.576 .03909 Mdot
.576 .03917 Mdot
.576 .0392 Mdot
.576 .03923 Mdot
.576 .03927 Mdot
.576 .03927 Mdot
.576 .03949 Mdot
.576 .03991 Mdot
.576 .04006 Mdot
.576 .04019 Mdot
.576 .0407 Mdot
.576 .0407 Mdot
.576 .04078 Mdot
.576 .04085 Mdot
.576 .04103 Mdot
.576 .04121 Mdot
.576 .04128 Mdot
.576 .04128 Mdot
.576 .04131 Mdot
.576 .04143 Mdot
.576 .04146 Mdot
.576 .04186 Mdot
.576 .04191 Mdot
.576 .04193 Mdot
.576 .04197 Mdot
.576 .04205 Mdot
.576 .04206 Mdot
.576 .0421 Mdot
.576 .04211 Mdot
.576 .04213 Mdot
.576 .04245 Mdot
.576 .04279 Mdot
.576 .04289 Mdot
.576 .04293 Mdot
.576 .04296 Mdot
.576 .043 Mdot
.576 .043 Mdot
.576 .04325 Mdot
.576 .04374 Mdot
.576 .04391 Mdot
.576 .04406 Mdot
.576 .04465 Mdot
.576 .04465 Mdot
.576 .04474 Mdot
.576 .04476 Mdot
.576 .04482 Mdot
.576 .04503 Mdot
.576 .04524 Mdot
.576 .04532 Mdot
.576 .04532 Mdot
.576 .04535 Mdot
.576 .04549 Mdot
.576 .04553 Mdot
.576 .04598 Mdot
.576 .04604 Mdot
.576 .04606 Mdot
.576 .04612 Mdot
.576 .0462 Mdot
.576 .04622 Mdot
.576 .04626 Mdot
.576 .04627 Mdot
.576 .0463 Mdot
.576 .04666 Mdot
.576 .04687 Mdot
.576 .04706 Mdot
.576 .04717 Mdot
.576 .04721 Mdot
.576 .04725 Mdot
.576 .0473 Mdot
.576 .0473 Mdot
.576 .04759 Mdot
.576 .04816 Mdot
.576 .04835 Mdot
.576 .04852 Mdot
.576 .04883 Mdot
.576 .0492 Mdot
.576 .04921 Mdot
.576 .0493 Mdot
.576 .04933 Mdot
.576 .0494 Mdot
.576 .04963 Mdot
.576 .04988 Mdot
.576 .04997 Mdot
.576 .04997 Mdot
.576 .05001 Mdot
.576 .05017 Mdot
.576 .05021 Mdot
.576 .05074 Mdot
.576 .0508 Mdot
.576 .05083 Mdot
.576 .05089 Mdot
.576 .05099 Mdot
.576 .05101 Mdot
.576 .05106 Mdot
.576 .05107 Mdot
.576 .0511 Mdot
.576 .05152 Mdot
.576 .05175 Mdot
.576 .05198 Mdot
.576 .0521 Mdot
.576 .05215 Mdot
.576 .0522 Mdot
.576 .05221 Mdot
.576 .05225 Mdot
.576 .05226 Mdot
.576 .05259 Mdot
.576 .05324 Mdot
.576 .05346 Mdot
.576 .05366 Mdot
.576 .05401 Mdot
.576 .05444 Mdot
.576 .05445 Mdot
.576 .05456 Mdot
.576 .05459 Mdot
.576 .05467 Mdot
.576 .05494 Mdot
.576 .05522 Mdot
.576 .05533 Mdot
.576 .05533 Mdot
.576 .05538 Mdot
.576 .05555 Mdot
.576 .0556 Mdot
.576 .0561 Mdot
.576 .05621 Mdot
.576 .05626 Mdot
.576 .05629 Mdot
.576 .05632 Mdot
.576 .05639 Mdot
.576 .0565 Mdot
.576 .05653 Mdot
.576 .05658 Mdot
.576 .05659 Mdot
.576 .05663 Mdot
.576 .05712 Mdot
.576 .05738 Mdot
.576 .05742 Mdot
.576 .05764 Mdot
.576 .05773 Mdot
.576 .05779 Mdot
.576 .05784 Mdot
.576 .0579 Mdot
.576 .05791 Mdot
.576 .05795 Mdot
.576 .05797 Mdot
.576 .05835 Mdot
.576 .05852 Mdot
.576 .0591 Mdot
.576 .05935 Mdot
.576 .05958 Mdot
.576 .05999 Mdot
.576 .06047 Mdot
.576 .06049 Mdot
.576 .06061 Mdot
.576 .06065 Mdot
.576 .06074 Mdot
.576 .06105 Mdot
.576 .06111 Mdot
.576 .06138 Mdot
.576 .0615 Mdot
.576 .06151 Mdot
.576 .06156 Mdot
.576 .06157 Mdot
.576 .06176 Mdot
.576 .06182 Mdot
.576 .06239 Mdot
.576 .06252 Mdot
.576 .06258 Mdot
.576 .06261 Mdot
.576 .06264 Mdot
.576 .06272 Mdot
.576 .06286 Mdot
.576 .06288 Mdot
.576 .06295 Mdot
.576 .06296 Mdot
.576 .063 Mdot
.576 .06356 Mdot
.576 .06383 Mdot
.576 .06387 Mdot
.576 .06391 Mdot
.576 .06417 Mdot
.576 .06427 Mdot
.576 .06433 Mdot
.576 .0644 Mdot
.576 .06446 Mdot
.576 .06447 Mdot
.576 .06453 Mdot
.576 .06454 Mdot
.576 .06487 Mdot
.576 .0649 Mdot
.576 .06498 Mdot
.576 .06517 Mdot
.576 .0653 Mdot
.576 .06545 Mdot
.576 .06584 Mdot
.576 .06613 Mdot
.576 .0664 Mdot
.576 .06687 Mdot
.576 .06743 Mdot
.576 .06759 Mdot
.576 .06763 Mdot
.576 .06774 Mdot
.576 .0681 Mdot
.576 .06816 Mdot
.576 .06847 Mdot
.576 .06862 Mdot
.576 .06862 Mdot
.576 .06868 Mdot
.576 .0687 Mdot
.576 .06891 Mdot
.576 .06898 Mdot
.576 .06964 Mdot
.576 .06978 Mdot
.576 .06986 Mdot
.576 .06989 Mdot
.576 .06993 Mdot
.576 .07002 Mdot
.576 .07017 Mdot
.576 .0702 Mdot
.576 .07028 Mdot
.576 .07029 Mdot
.576 .07034 Mdot
.576 .07098 Mdot
.576 .0713 Mdot
.576 .07134 Mdot
.576 .07139 Mdot
.576 .07168 Mdot
.576 .07181 Mdot
.576 .07187 Mdot
.576 .07195 Mdot
.576 .07202 Mdot
.576 .07204 Mdot
.576 .0721 Mdot
.576 .07211 Mdot
.576 .07249 Mdot
.576 .07253 Mdot
.576 .07262 Mdot
.576 .07284 Mdot
.576 .07299 Mdot
.576 .07316 Mdot
.576 .07361 Mdot
.576 .07395 Mdot
.576 .07426 Mdot
.576 .0748 Mdot
.576 .07544 Mdot
.576 .07563 Mdot
.576 .07568 Mdot
.576 .0758 Mdot
.576 .07621 Mdot
.576 .07629 Mdot
.576 .07664 Mdot
.576 .07681 Mdot
.576 .07681 Mdot
.576 .07688 Mdot
.576 .0769 Mdot
.576 .07715 Mdot
.576 .07723 Mdot
.576 .07799 Mdot
.576 .07816 Mdot
.576 .07824 Mdot
.576 .07827 Mdot
.576 .07832 Mdot
.576 .07843 Mdot
.576 .0786 Mdot
.576 .07864 Mdot
.576 .07872 Mdot
.576 .07874 Mdot
.576 .0788 Mdot
.576 .07954 Mdot
.576 .0799 Mdot
.576 .07995 Mdot
.576 .08 Mdot
.576 .08034 Mdot
.576 .08048 Mdot
.576 .08056 Mdot
.576 .08065 Mdot
.576 .08073 Mdot
.576 .08075 Mdot
.576 .08082 Mdot
.576 .08084 Mdot
.576 .08128 Mdot
.576 .08132 Mdot
.576 .08142 Mdot
.576 .08168 Mdot
.576 .08185 Mdot
.576 .08204 Mdot
.576 .08257 Mdot
.576 .08295 Mdot
.576 .08331 Mdot
.576 .08393 Mdot
.576 .08467 Mdot
.576 .08488 Mdot
.576 .08494 Mdot
.576 .08508 Mdot
.576 .08556 Mdot
.576 .08564 Mdot
.576 .08606 Mdot
.576 .08625 Mdot
.576 .08625 Mdot
.576 .08633 Mdot
.576 .08635 Mdot
.576 .08664 Mdot
.576 .08673 Mdot
.576 .0876 Mdot
.576 .0878 Mdot
.576 .08789 Mdot
.576 .08793 Mdot
.576 .08799 Mdot
.576 .08811 Mdot
.576 .08832 Mdot
.576 .08835 Mdot
.576 .08845 Mdot
.576 .08847 Mdot
.576 .08854 Mdot
.576 .08939 Mdot
.576 .08981 Mdot
.576 .08986 Mdot
.576 .08993 Mdot
.576 .09032 Mdot
.576 .09048 Mdot
.576 .09057 Mdot
.576 .09067 Mdot
.576 .09077 Mdot
.576 .09079 Mdot
.576 .09087 Mdot
.576 .09089 Mdot
.576 .09139 Mdot
.576 .09144 Mdot
.576 .09156 Mdot
.576 .09186 Mdot
.576 .09206 Mdot
.576 .09228 Mdot
.576 .09288 Mdot
.576 .09332 Mdot
.576 .09374 Mdot
.576 .09445 Mdot
.576 .09531 Mdot
.576 .09555 Mdot
.576 .09562 Mdot
.576 .09578 Mdot
.576 .09633 Mdot
.576 .09643 Mdot
.576 .0969 Mdot
.576 .09712 Mdot
.576 .09713 Mdot
.576 .09721 Mdot
.576 .09724 Mdot
.576 .09758 Mdot
.576 .09767 Mdot
.576 .09868 Mdot
.576 .09891 Mdot
.576 .09901 Mdot
.576 .09906 Mdot
.576 .09912 Mdot
.576 .09927 Mdot
.576 .0995 Mdot
.576 .09954 Mdot
.576 .09966 Mdot
.576 .09968 Mdot
.576 .09976 Mdot
.576 .10074 Mdot
.576 .10122 Mdot
.576 .10129 Mdot
.576 .10136 Mdot
.576 .10181 Mdot
.576 .102 Mdot
.576 .1021 Mdot
.576 .10222 Mdot
.576 .10232 Mdot
.576 .10235 Mdot
.576 .10244 Mdot
.576 .10247 Mdot
.576 .10305 Mdot
.576 .1031 Mdot
.576 .10324 Mdot
.576 .10358 Mdot
.576 .10381 Mdot
.576 .10407 Mdot
.576 .10476 Mdot
.576 .10527 Mdot
.576 .10575 Mdot
.576 .10657 Mdot
.576 .10752 Mdot
.576 .10756 Mdot
.576 .10784 Mdot
.576 .10791 Mdot
.576 .1081 Mdot
.576 .10873 Mdot
.576 .10885 Mdot
.576 .10939 Mdot
.576 .10965 Mdot
.576 .10965 Mdot
.576 .10975 Mdot
.576 .10979 Mdot
.576 .11017 Mdot
.576 .11028 Mdot
.576 .11144 Mdot
.576 .1117 Mdot
.576 .11183 Mdot
.576 .11188 Mdot
.576 .11195 Mdot
.576 .11212 Mdot
.576 .11239 Mdot
.576 .11244 Mdot
.576 .11257 Mdot
.576 .11259 Mdot
.576 .11269 Mdot
.576 .11382 Mdot
.576 .11437 Mdot
.576 .11445 Mdot
.576 .11453 Mdot
.576 .11505 Mdot
.576 .11526 Mdot
.576 .11538 Mdot
.576 .11552 Mdot
.576 .11564 Mdot
.576 .11567 Mdot
.576 .11578 Mdot
.576 .1158 Mdot
.576 .11648 Mdot
.576 .11654 Mdot
.576 .11669 Mdot
.576 .11709 Mdot
.576 .11735 Mdot
.576 .11765 Mdot
.576 .11845 Mdot
.576 .11904 Mdot
.576 .11959 Mdot
.576 .12053 Mdot
.576 .12162 Mdot
.576 .12167 Mdot
.576 .12199 Mdot
.576 .12208 Mdot
.576 .1223 Mdot
.576 .12302 Mdot
.576 .12315 Mdot
.576 .12379 Mdot
.576 .12408 Mdot
.576 .12408 Mdot
.576 .1242 Mdot
.576 .12424 Mdot
.576 .12468 Mdot
.576 .12481 Mdot
.576 .12615 Mdot
.576 .12645 Mdot
.576 .12659 Mdot
.576 .12665 Mdot
.576 .12674 Mdot
.576 .12693 Mdot
.576 .12724 Mdot
.576 .12729 Mdot
.576 .12745 Mdot
.576 .12747 Mdot
.576 .12758 Mdot
.576 .12888 Mdot
.576 .12952 Mdot
.576 .12961 Mdot
.576 .1297 Mdot
.576 .1303 Mdot
.576 .13055 Mdot
.576 .13069 Mdot
.576 .13084 Mdot
.576 .13098 Mdot
.576 .13102 Mdot
.576 .13114 Mdot
.576 .13117 Mdot
.576 .13194 Mdot
.576 .13201 Mdot
.576 .13219 Mdot
.576 .13265 Mdot
.576 .13295 Mdot
.576 .1333 Mdot
.576 .13422 Mdot
.576 .13489 Mdot
.576 .13553 Mdot
.576 .13662 Mdot
.576 .13787 Mdot
.576 .13792 Mdot
.576 .1383 Mdot
.576 .1384 Mdot
.576 .13865 Mdot
.576 .13949 Mdot
.576 .13964 Mdot
.576 .14036 Mdot
.576 .1407 Mdot
.576 .14071 Mdot
.576 .14084 Mdot
.576 .14088 Mdot
.576 .14139 Mdot
.576 .14154 Mdot
.576 .14308 Mdot
.576 .14343 Mdot
.576 .14359 Mdot
.576 .14367 Mdot
.576 .14376 Mdot
.576 .14398 Mdot
.576 .14434 Mdot
.576 .1444 Mdot
.576 .14458 Mdot
.576 .14461 Mdot
.576 .14473 Mdot
.576 .14623 Mdot
.576 .14697 Mdot
.576 .14707 Mdot
.576 .14718 Mdot
.576 .14786 Mdot
.576 .14815 Mdot
.576 .14831 Mdot
.576 .14849 Mdot
.576 .14866 Mdot
.576 .1487 Mdot
.576 .14884 Mdot
.576 .14887 Mdot
.576 .14976 Mdot
.576 .14984 Mdot
.576 .15005 Mdot
.576 .15058 Mdot
.576 .15093 Mdot
.576 .15132 Mdot
.576 .15238 Mdot
.576 .15316 Mdot
.576 .15389 Mdot
.576 .15515 Mdot
.576 .15659 Mdot
.576 .15665 Mdot
.576 .15708 Mdot
.576 .1572 Mdot
.576 .15749 Mdot
.576 .15845 Mdot
.576 .15862 Mdot
.576 .15946 Mdot
.576 .15985 Mdot
.576 .15986 Mdot
.576 .16001 Mdot
.576 .16006 Mdot
.576 .16065 Mdot
.576 .16082 Mdot
.576 .1626 Mdot
.576 .16299 Mdot
.576 .16318 Mdot
.576 .16327 Mdot
.576 .16338 Mdot
.576 .16363 Mdot
.576 .16404 Mdot
.576 .16412 Mdot
.576 .16432 Mdot
.576 .16435 Mdot
.576 .1645 Mdot
.576 .16622 Mdot
.576 .16707 Mdot
.576 .16719 Mdot
.576 .16731 Mdot
.576 .1681 Mdot
.576 .16844 Mdot
.576 .16862 Mdot
.576 .16883 Mdot
.576 .16901 Mdot
.576 .16906 Mdot
.576 .16922 Mdot
.576 .16926 Mdot
.576 .17029 Mdot
.576 .17038 Mdot
.576 .17062 Mdot
.576 .17123 Mdot
.576 .17163 Mdot
.576 .17208 Mdot
.576 .1733 Mdot
.576 .17421 Mdot
.576 .17504 Mdot
.576 .17649 Mdot
.576 .17816 Mdot
.576 .17823 Mdot
.576 .17872 Mdot
.576 .17885 Mdot
.576 .17919 Mdot
.576 .1803 Mdot
.576 .1805 Mdot
.576 .18146 Mdot
.576 .18191 Mdot
.576 .18192 Mdot
.576 .18209 Mdot
.576 .18216 Mdot
.576 .18283 Mdot
.576 .18303 Mdot
.576 .18507 Mdot
.576 .18553 Mdot
.576 .18575 Mdot
.576 .18585 Mdot
.576 .18597 Mdot
.576 .18627 Mdot
.576 .18674 Mdot
.576 .18683 Mdot
.576 .18706 Mdot
.576 .1871 Mdot
.576 .18726 Mdot
.576 .18925 Mdot
.576 .19023 Mdot
.576 .19036 Mdot
.576 .1905 Mdot
.576 .19142 Mdot
.576 .1918 Mdot
.576 .19201 Mdot
.576 .19225 Mdot
.576 .19247 Mdot
.576 .19252 Mdot
.576 .19271 Mdot
.576 .19275 Mdot
.576 .19394 Mdot
.576 .19404 Mdot
.576 .19432 Mdot
.576 .19502 Mdot
.576 .19548 Mdot
.576 .196 Mdot
.576 .19741 Mdot
.576 .19845 Mdot
.576 .19941 Mdot
.576 .20108 Mdot
.576 .203 Mdot
.576 .20308 Mdot
.576 .20365 Mdot
.576 .2038 Mdot
.576 .20419 Mdot
.576 .20547 Mdot
.576 .2057 Mdot
.576 .20681 Mdot
.576 .20732 Mdot
.576 .20734 Mdot
.576 .20753 Mdot
.576 .20761 Mdot
.576 .20838 Mdot
.576 .20861 Mdot
.576 .21097 Mdot
.576 .2115 Mdot
.576 .21175 Mdot
.576 .21186 Mdot
.576 .21201 Mdot
.576 .21234 Mdot
.576 .21289 Mdot
.576 .21299 Mdot
.576 .21326 Mdot
.576 .2133 Mdot
.576 .21349 Mdot
.576 .21578 Mdot
.576 .21691 Mdot
.576 .21706 Mdot
.576 .21723 Mdot
.576 .21828 Mdot
.576 .21872 Mdot
.576 .21896 Mdot
.576 .21924 Mdot
.576 .21949 Mdot
.576 .21955 Mdot
.576 .21976 Mdot
.576 .21981 Mdot
.576 .22118 Mdot
.576 .2213 Mdot
.576 .22162 Mdot
.576 .22243 Mdot
.576 .22296 Mdot
.576 .22356 Mdot
.576 .22518 Mdot
.576 .22638 Mdot
.576 .22749 Mdot
.576 .22941 Mdot
.576 .23162 Mdot
.576 .23171 Mdot
.576 .23237 Mdot
.576 .23255 Mdot
.576 .23299 Mdot
.576 .23446 Mdot
.576 .23473 Mdot
.576 .23601 Mdot
.576 .2366 Mdot
.576 .23661 Mdot
.576 .23684 Mdot
.576 .23693 Mdot
.576 .23782 Mdot
.576 .23809 Mdot
.576 .2408 Mdot
.576 .24141 Mdot
.576 .2417 Mdot
.576 .24183 Mdot
.576 .24199 Mdot
.576 .24238 Mdot
.576 .24301 Mdot
.576 .24313 Mdot
.576 .24344 Mdot
.576 .24348 Mdot
.576 .24371 Mdot
.576 .24635 Mdot
.576 .24764 Mdot
.576 .24782 Mdot
.576 .24801 Mdot
.576 .24922 Mdot
.576 .24973 Mdot
.576 .25001 Mdot
.576 .25033 Mdot
.576 .25061 Mdot
.576 .25068 Mdot
.576 .25093 Mdot
.576 .25099 Mdot
.576 .25256 Mdot
.576 .2527 Mdot
.576 .25307 Mdot
.576 .254 Mdot
.576 .25461 Mdot
.576 .2553 Mdot
.576 .25717 Mdot
.576 .25855 Mdot
.576 .25983 Mdot
.576 .26204 Mdot
.576 .26459 Mdot
.576 .26469 Mdot
.576 .26545 Mdot
.576 .26566 Mdot
.576 .26617 Mdot
.576 .26786 Mdot
.576 .26817 Mdot
.576 .26964 Mdot
.576 .27032 Mdot
.576 .27034 Mdot
.576 .27061 Mdot
.576 .2707 Mdot
.576 .27173 Mdot
.576 .27204 Mdot
.576 .27516 Mdot
.576 .27587 Mdot
.576 .2762 Mdot
.576 .27635 Mdot
.576 .27654 Mdot
.576 .27699 Mdot
.576 .27771 Mdot
.576 .27784 Mdot
.576 .2782 Mdot
.576 .27826 Mdot
.576 .27851 Mdot
.576 .28155 Mdot
.576 .28305 Mdot
.576 .28325 Mdot
.576 .28347 Mdot
.576 .28486 Mdot
.576 .28545 Mdot
.576 .28577 Mdot
.576 .28614 Mdot
.576 .28647 Mdot
.576 .28655 Mdot
.576 .28683 Mdot
.576 .2869 Mdot
.576 .28871 Mdot
.576 .28888 Mdot
.576 .2893 Mdot
.576 .29037 Mdot
.576 .29108 Mdot
.576 .29187 Mdot
.576 .29402 Mdot
.576 .29561 Mdot
.576 .29709 Mdot
.576 .29964 Mdot
.576 .30257 Mdot
.576 .30269 Mdot
.576 .30356 Mdot
.576 .3038 Mdot
.576 .30439 Mdot
.576 .30634 Mdot
.576 .30669 Mdot
.576 .30839 Mdot
.576 .30918 Mdot
.576 .3092 Mdot
.576 .3095 Mdot
.576 .30961 Mdot
.576 .3108 Mdot
.576 .31115 Mdot
.576 .31475 Mdot
.576 .31556 Mdot
.576 .31594 Mdot
.576 .31612 Mdot
.576 .31634 Mdot
.576 .31685 Mdot
.576 .31769 Mdot
.576 .31784 Mdot
.576 .31825 Mdot
.576 .31831 Mdot
.576 .31861 Mdot
.576 .32211 Mdot
.576 .32383 Mdot
.576 .32407 Mdot
.576 .32432 Mdot
.576 .32592 Mdot
.576 .3266 Mdot
.576 .32697 Mdot
.576 .3274 Mdot
.576 .32777 Mdot
.576 .32787 Mdot
.576 .3282 Mdot
.576 .32828 Mdot
.576 .33036 Mdot
.576 .33055 Mdot
.576 .33104 Mdot
.576 .33227 Mdot
.576 .33308 Mdot
.576 .334 Mdot
.576 .33648 Mdot
.576 .33831 Mdot
.576 .34001 Mdot
.576 .34294 Mdot
.576 .34632 Mdot
.576 .34646 Mdot
.576 .34747 Mdot
.576 .34774 Mdot
.576 .34842 Mdot
.576 .35067 Mdot
.576 .35107 Mdot
.576 .35303 Mdot
.576 .35393 Mdot
.576 .35396 Mdot
.576 .35431 Mdot
.576 .35444 Mdot
.578 .01544 Mdot
.578 .01555 Mdot
.578 .01568 Mdot
.578 .01583 Mdot
.578 .01601 Mdot
.578 .01619 Mdot
.578 .01621 Mdot
.578 .01642 Mdot
.578 .01644 Mdot
.578 .01669 Mdot
.578 .01671 Mdot
.578 .01699 Mdot
.578 .01702 Mdot
.578 .01735 Mdot
.578 .01738 Mdot
.578 .01776 Mdot
.578 .0178 Mdot
.578 .01823 Mdot
.578 .01828 Mdot
.578 .01878 Mdot
.578 .01884 Mdot
.578 .01891 Mdot
.578 .01942 Mdot
.578 .01948 Mdot
.578 .01957 Mdot
.578 .02015 Mdot
.578 .02022 Mdot
.578 .02032 Mdot
.578 .02093 Mdot
.578 .021 Mdot
.578 .02106 Mdot
.578 .02108 Mdot
.578 .0212 Mdot
.578 .02189 Mdot
.578 .02191 Mdot
.578 .02198 Mdot
.578 .02205 Mdot
.578 .02208 Mdot
.578 .02221 Mdot
.578 .02287 Mdot
.578 .02301 Mdot
.578 .02303 Mdot
.578 .02311 Mdot
.578 .0232 Mdot
.578 .02323 Mdot
.578 .02338 Mdot
.578 .02414 Mdot
.578 .02416 Mdot
.578 .02431 Mdot
.578 .02433 Mdot
.578 .02437 Mdot
.578 .02442 Mdot
.578 .02452 Mdot
.578 .02455 Mdot
.578 .02473 Mdot
.578 .02561 Mdot
.578 .02564 Mdot
.578 .0258 Mdot
.578 .02583 Mdot
.578 .02588 Mdot
.578 .02594 Mdot
.578 .02605 Mdot
.578 .02609 Mdot
.578 .02617 Mdot
.578 .02629 Mdot
.578 .02712 Mdot
.578 .02731 Mdot
.578 .02734 Mdot
.578 .02746 Mdot
.578 .02753 Mdot
.578 .02756 Mdot
.578 .02762 Mdot
.578 .02769 Mdot
.578 .02782 Mdot
.578 .02786 Mdot
.578 .02795 Mdot
.578 .0281 Mdot
.578 .0286 Mdot
.578 .02905 Mdot
.578 .02927 Mdot
.578 .02931 Mdot
.578 .02945 Mdot
.578 .02953 Mdot
.578 .02956 Mdot
.578 .02963 Mdot
.578 .02971 Mdot
.578 .02986 Mdot
.578 .02991 Mdot
.578 .03002 Mdot
.578 .03019 Mdot
.578 .03053 Mdot
.578 .03077 Mdot
.578 .03129 Mdot
.578 .03154 Mdot
.578 .03159 Mdot
.578 .03175 Mdot
.578 .03185 Mdot
.578 .03188 Mdot
.578 .03196 Mdot
.578 .03205 Mdot
.578 .03223 Mdot
.578 .03229 Mdot
.578 .03241 Mdot
.578 .03259 Mdot
.578 .0326 Mdot
.578 .033 Mdot
.578 .03327 Mdot
.578 .03328 Mdot
.578 .0333 Mdot
.578 .03377 Mdot
.578 .03388 Mdot
.578 .03417 Mdot
.578 .03422 Mdot
.578 .03441 Mdot
.578 .03452 Mdot
.578 .03456 Mdot
.578 .03458 Mdot
.578 .03465 Mdot
.578 .03476 Mdot
.578 .03488 Mdot
.578 .03496 Mdot
.578 .03503 Mdot
.578 .03512 Mdot
.578 .03517 Mdot
.578 .03537 Mdot
.578 .03539 Mdot
.578 .03585 Mdot
.578 .03616 Mdot
.578 .03617 Mdot
.578 .0362 Mdot
.578 .03632 Mdot
.578 .03674 Mdot
.578 .03687 Mdot
.578 .03693 Mdot
.578 .0372 Mdot
.578 .03726 Mdot
.578 .03728 Mdot
.578 .03748 Mdot
.578 .03761 Mdot
.578 .03765 Mdot
.578 .03768 Mdot
.578 .03775 Mdot
.578 .03789 Mdot
.578 .03802 Mdot
.578 .03812 Mdot
.578 .03819 Mdot
.578 .0383 Mdot
.578 .03836 Mdot
.578 .0386 Mdot
.578 .03862 Mdot
.578 .03909 Mdot
.578 .03914 Mdot
.578 .03951 Mdot
.578 .03952 Mdot
.578 .03956 Mdot
.578 .03956 Mdot
.578 .03969 Mdot
.578 .04017 Mdot
.578 .04032 Mdot
.578 .04039 Mdot
.578 .04056 Mdot
.578 .04071 Mdot
.578 .04078 Mdot
.578 .0408 Mdot
.578 .04089 Mdot
.578 .04103 Mdot
.578 .04118 Mdot
.578 .04123 Mdot
.578 .04127 Mdot
.578 .04135 Mdot
.578 .0415 Mdot
.578 .04166 Mdot
.578 .04169 Mdot
.578 .04177 Mdot
.578 .04179 Mdot
.578 .04186 Mdot
.578 .04198 Mdot
.578 .04204 Mdot
.578 .04232 Mdot
.578 .04234 Mdot
.578 .04235 Mdot
.578 .04249 Mdot
.578 .04289 Mdot
.578 .04296 Mdot
.578 .04338 Mdot
.578 .04339 Mdot
.578 .04343 Mdot
.578 .04344 Mdot
.578 .04346 Mdot
.578 .04358 Mdot
.578 .04415 Mdot
.578 .04432 Mdot
.578 .04433 Mdot
.578 .0444 Mdot
.578 .04448 Mdot
.578 .04459 Mdot
.578 .04476 Mdot
.578 .04484 Mdot
.578 .04487 Mdot
.578 .04497 Mdot
.578 .04513 Mdot
.578 .04531 Mdot
.578 .04537 Mdot
.578 .04541 Mdot
.578 .0455 Mdot
.578 .04568 Mdot
.578 .04586 Mdot
.578 .0459 Mdot
.578 .04599 Mdot
.578 .04601 Mdot
.578 .04609 Mdot
.578 .04623 Mdot
.578 .04631 Mdot
.578 .04663 Mdot
.578 .04665 Mdot
.578 .04666 Mdot
.578 .04682 Mdot
.578 .04729 Mdot
.578 .04736 Mdot
.578 .04785 Mdot
.578 .04786 Mdot
.578 .04791 Mdot
.578 .04792 Mdot
.578 .04794 Mdot
.578 .04809 Mdot
.578 .04811 Mdot
.578 .0484 Mdot
.578 .04847 Mdot
.578 .04874 Mdot
.578 .04893 Mdot
.578 .04895 Mdot
.578 .04903 Mdot
.578 .04913 Mdot
.578 .04925 Mdot
.578 .04927 Mdot
.578 .04945 Mdot
.578 .04954 Mdot
.578 .04958 Mdot
.578 .04969 Mdot
.578 .04988 Mdot
.578 .05008 Mdot
.578 .05015 Mdot
.578 .0502 Mdot
.578 .05031 Mdot
.578 .05033 Mdot
.578 .05051 Mdot
.578 .05072 Mdot
.578 .05077 Mdot
.578 .05087 Mdot
.578 .0509 Mdot
.578 .05099 Mdot
.578 .05115 Mdot
.578 .05124 Mdot
.578 .05161 Mdot
.578 .05164 Mdot
.578 .05164 Mdot
.578 .05183 Mdot
.578 .05237 Mdot
.578 .05245 Mdot
.578 .05302 Mdot
.578 .05303 Mdot
.578 .05309 Mdot
.578 .0531 Mdot
.578 .05312 Mdot
.578 .05329 Mdot
.578 .05332 Mdot
.578 .05365 Mdot
.578 .05373 Mdot
.578 .05404 Mdot
.578 .05427 Mdot
.578 .05429 Mdot
.578 .05438 Mdot
.578 .05449 Mdot
.578 .05464 Mdot
.578 .05466 Mdot
.578 .05487 Mdot
.578 .05498 Mdot
.578 .05502 Mdot
.578 .05515 Mdot
.578 .05536 Mdot
.578 .0556 Mdot
.578 .05568 Mdot
.578 .05573 Mdot
.578 .05583 Mdot
.578 .05586 Mdot
.578 .05589 Mdot
.578 .05609 Mdot
.578 .05634 Mdot
.578 .05639 Mdot
.578 .0565 Mdot
.578 .05654 Mdot
.578 .05664 Mdot
.578 .05671 Mdot
.578 .05683 Mdot
.578 .05693 Mdot
.578 .05736 Mdot
.578 .0574 Mdot
.578 .0574 Mdot
.578 .0575 Mdot
.578 .05762 Mdot
.578 .05824 Mdot
.578 .05834 Mdot
.578 .05899 Mdot
.578 .05901 Mdot
.578 .05908 Mdot
.578 .05909 Mdot
.578 .05912 Mdot
.578 .05931 Mdot
.578 .05935 Mdot
.578 .05972 Mdot
.578 .05982 Mdot
.578 .06018 Mdot
.578 .06044 Mdot
.578 .06046 Mdot
.578 .06057 Mdot
.578 .0607 Mdot
.578 .06087 Mdot
.578 .0609 Mdot
.578 .06113 Mdot
.578 .06126 Mdot
.578 .0613 Mdot
.578 .06145 Mdot
.578 .06171 Mdot
.578 .06198 Mdot
.578 .06207 Mdot
.578 .06213 Mdot
.578 .06224 Mdot
.578 .06228 Mdot
.578 .06231 Mdot
.578 .06247 Mdot
.578 .06255 Mdot
.578 .06259 Mdot
.578 .06283 Mdot
.578 .06289 Mdot
.578 .06302 Mdot
.578 .06307 Mdot
.578 .06317 Mdot
.578 .06319 Mdot
.578 .06326 Mdot
.578 .06328 Mdot
.578 .0634 Mdot
.578 .06352 Mdot
.578 .06354 Mdot
.578 .06402 Mdot
.578 .06405 Mdot
.578 .06406 Mdot
.578 .06417 Mdot
.578 .06431 Mdot
.578 .06503 Mdot
.578 .06515 Mdot
.578 .06525 Mdot
.578 .06556 Mdot
.578 .0659 Mdot
.578 .06592 Mdot
.578 .066 Mdot
.578 .06601 Mdot
.578 .06604 Mdot
.578 .06627 Mdot
.578 .06631 Mdot
.578 .06674 Mdot
.578 .06686 Mdot
.578 .06727 Mdot
.578 .06758 Mdot
.578 .0676 Mdot
.578 .06773 Mdot
.578 .06787 Mdot
.578 .06807 Mdot
.578 .0681 Mdot
.578 .06837 Mdot
.578 .06852 Mdot
.578 .06857 Mdot
.578 .06874 Mdot
.578 .06904 Mdot
.578 .06935 Mdot
.578 .06946 Mdot
.578 .06953 Mdot
.578 .06965 Mdot
.578 .0697 Mdot
.578 .06973 Mdot
.578 .06992 Mdot
.578 .07001 Mdot
.578 .07006 Mdot
.578 .07034 Mdot
.578 .07041 Mdot
.578 .07056 Mdot
.578 .07061 Mdot
.578 .07073 Mdot
.578 .07075 Mdot
.578 .07083 Mdot
.578 .07085 Mdot
.578 .071 Mdot
.578 .07113 Mdot
.578 .07116 Mdot
.578 .07171 Mdot
.578 .07175 Mdot
.578 .07176 Mdot
.578 .07188 Mdot
.578 .07204 Mdot
.578 .07288 Mdot
.578 .07301 Mdot
.578 .07313 Mdot
.578 .07349 Mdot
.578 .07389 Mdot
.578 .07391 Mdot
.578 .074 Mdot
.578 .07401 Mdot
.578 .07405 Mdot
.578 .07431 Mdot
.578 .07436 Mdot
.578 .07486 Mdot
.578 .07499 Mdot
.578 .07547 Mdot
.578 .07582 Mdot
.578 .07585 Mdot
.578 .076 Mdot
.578 .07617 Mdot
.578 .07639 Mdot
.578 .07643 Mdot
.578 .07674 Mdot
.578 .07691 Mdot
.578 .07697 Mdot
.578 .07717 Mdot
.578 .07751 Mdot
.578 .07787 Mdot
.578 .078 Mdot
.578 .07808 Mdot
.578 .07822 Mdot
.578 .07827 Mdot
.578 .07832 Mdot
.578 .07853 Mdot
.578 .07863 Mdot
.578 .0787 Mdot
.578 .07901 Mdot
.578 .0791 Mdot
.578 .07927 Mdot
.578 .07933 Mdot
.578 .07947 Mdot
.578 .07949 Mdot
.578 .07959 Mdot
.578 .07961 Mdot
.578 .07978 Mdot
.578 .07993 Mdot
.578 .07996 Mdot
.578 .0806 Mdot
.578 .08065 Mdot
.578 .08066 Mdot
.578 .0808 Mdot
.578 .08099 Mdot
.578 .08195 Mdot
.578 .08211 Mdot
.578 .08225 Mdot
.578 .08266 Mdot
.578 .08312 Mdot
.578 .08314 Mdot
.578 .08324 Mdot
.578 .08326 Mdot
.578 .08331 Mdot
.578 .08361 Mdot
.578 .08366 Mdot
.578 .08424 Mdot
.578 .0844 Mdot
.578 .08495 Mdot
.578 .08536 Mdot
.578 .08539 Mdot
.578 .08556 Mdot
.578 .08575 Mdot
.578 .08601 Mdot
.578 .08606 Mdot
.578 .08642 Mdot
.578 .08661 Mdot
.578 .08668 Mdot
.578 .08692 Mdot
.578 .08731 Mdot
.578 .08772 Mdot
.578 .08787 Mdot
.578 .08796 Mdot
.578 .08813 Mdot
.578 .08819 Mdot
.578 .08824 Mdot
.578 .08848 Mdot
.578 .08861 Mdot
.578 .08868 Mdot
.578 .08904 Mdot
.578 .08914 Mdot
.578 .08934 Mdot
.578 .08941 Mdot
.578 .08957 Mdot
.578 .08959 Mdot
.578 .08971 Mdot
.578 .08973 Mdot
.578 .08993 Mdot
.578 .09011 Mdot
.578 .09014 Mdot
.578 .09088 Mdot
.578 .09093 Mdot
.578 .09095 Mdot
.578 .09111 Mdot
.578 .09133 Mdot
.578 .09244 Mdot
.578 .09262 Mdot
.578 .09278 Mdot
.578 .09326 Mdot
.578 .09379 Mdot
.578 .09382 Mdot
.578 .09393 Mdot
.578 .09395 Mdot
.578 .09401 Mdot
.578 .09435 Mdot
.578 .09442 Mdot
.578 .09509 Mdot
.578 .09527 Mdot
.578 .09591 Mdot
.578 .09638 Mdot
.578 .09641 Mdot
.578 .09661 Mdot
.578 .09683 Mdot
.578 .09714 Mdot
.578 .09719 Mdot
.578 .09761 Mdot
.578 .09783 Mdot
.578 .09791 Mdot
.578 .09818 Mdot
.578 .09863 Mdot
.578 .09911 Mdot
.578 .09928 Mdot
.578 .09939 Mdot
.578 .09958 Mdot
.578 .09965 Mdot
.578 .09971 Mdot
.578 .09999 Mdot
.578 .10013 Mdot
.578 .10022 Mdot
.578 .10064 Mdot
.578 .10075 Mdot
.578 .10098 Mdot
.578 .10106 Mdot
.578 .10125 Mdot
.578 .10127 Mdot
.578 .1014 Mdot
.578 .10144 Mdot
.578 .10166 Mdot
.578 .10187 Mdot
.578 .10191 Mdot
.578 .10276 Mdot
.578 .10282 Mdot
.578 .10284 Mdot
.578 .10303 Mdot
.578 .10328 Mdot
.578 .10457 Mdot
.578 .10477 Mdot
.578 .10496 Mdot
.578 .10551 Mdot
.578 .10613 Mdot
.578 .10616 Mdot
.578 .10629 Mdot
.578 .10632 Mdot
.578 .10638 Mdot
.578 .10678 Mdot
.578 .10685 Mdot
.578 .10763 Mdot
.578 .10783 Mdot
.578 .10857 Mdot
.578 .10912 Mdot
.578 .10915 Mdot
.578 .10938 Mdot
.578 .10964 Mdot
.578 .11 Mdot
.578 .11005 Mdot
.578 .11054 Mdot
.578 .1108 Mdot
.578 .11089 Mdot
.578 .1112 Mdot
.578 .11172 Mdot
.578 .11228 Mdot
.578 .11247 Mdot
.578 .1126 Mdot
.578 .11282 Mdot
.578 .1129 Mdot
.578 .11297 Mdot
.578 .11329 Mdot
.578 .11346 Mdot
.578 .11355 Mdot
.578 .11404 Mdot
.578 .11417 Mdot
.578 .11444 Mdot
.578 .11453 Mdot
.578 .11475 Mdot
.578 .11478 Mdot
.578 .11493 Mdot
.578 .11497 Mdot
.578 .11523 Mdot
.578 .11547 Mdot
.578 .11551 Mdot
.578 .11649 Mdot
.578 .11657 Mdot
.578 .11659 Mdot
.578 .11681 Mdot
.578 .11709 Mdot
.578 .11858 Mdot
.578 .11882 Mdot
.578 .11904 Mdot
.578 .11967 Mdot
.578 .12039 Mdot
.578 .12042 Mdot
.578 .12058 Mdot
.578 .12061 Mdot
.578 .12068 Mdot
.578 .12114 Mdot
.578 .12122 Mdot
.578 .12212 Mdot
.578 .12236 Mdot
.578 .12321 Mdot
.578 .12384 Mdot
.578 .12389 Mdot
.578 .12415 Mdot
.578 .12445 Mdot
.578 .12486 Mdot
.578 .12492 Mdot
.578 .12549 Mdot
.578 .12579 Mdot
.578 .12589 Mdot
.578 .12625 Mdot
.578 .12686 Mdot
.578 .1275 Mdot
.578 .12773 Mdot
.578 .12787 Mdot
.578 .12813 Mdot
.578 .12822 Mdot
.578 .12829 Mdot
.578 .12867 Mdot
.578 .12886 Mdot
.578 .12897 Mdot
.578 .12954 Mdot
.578 .12969 Mdot
.578 .13 Mdot
.578 .1301 Mdot
.578 .13036 Mdot
.578 .13039 Mdot
.578 .13056 Mdot
.578 .1306 Mdot
.578 .13091 Mdot
.578 .13118 Mdot
.578 .13123 Mdot
.578 .13237 Mdot
.578 .13246 Mdot
.578 .13248 Mdot
.578 .13273 Mdot
.578 .13306 Mdot
.578 .13479 Mdot
.578 .13506 Mdot
.578 .13531 Mdot
.578 .13687 Mdot
.578 .13691 Mdot
.578 .13709 Mdot
.578 .13712 Mdot
.578 .13721 Mdot
.578 .13774 Mdot
.578 .13784 Mdot
.578 .13888 Mdot
.578 .13915 Mdot
.578 .14014 Mdot
.578 .14087 Mdot
.578 .14092 Mdot
.578 .14122 Mdot
.578 .14157 Mdot
.578 .14204 Mdot
.578 .14212 Mdot
.578 .14277 Mdot
.578 .14311 Mdot
.578 .14324 Mdot
.578 .14365 Mdot
.578 .14435 Mdot
.578 .14509 Mdot
.578 .14535 Mdot
.578 .14552 Mdot
.578 .14582 Mdot
.578 .14593 Mdot
.578 .14601 Mdot
.578 .14645 Mdot
.578 .14667 Mdot
.578 .1468 Mdot
.578 .14745 Mdot
.578 .14762 Mdot
.578 .14799 Mdot
.578 .1481 Mdot
.578 .1484 Mdot
.578 .14843 Mdot
.578 .14863 Mdot
.578 .14868 Mdot
.578 .14904 Mdot
.578 .14935 Mdot
.578 .14941 Mdot
.578 .15072 Mdot
.578 .15083 Mdot
.578 .15085 Mdot
.578 .15114 Mdot
.578 .15153 Mdot
.578 .15352 Mdot
.578 .15384 Mdot
.578 .15412 Mdot
.578 .15593 Mdot
.578 .15597 Mdot
.578 .15618 Mdot
.578 .15622 Mdot
.578 .15631 Mdot
.578 .15693 Mdot
.578 .15705 Mdot
.578 .15825 Mdot
.578 .15856 Mdot
.578 .1597 Mdot
.578 .16055 Mdot
.578 .16061 Mdot
.578 .16096 Mdot
.578 .16136 Mdot
.578 .1619 Mdot
.578 .16199 Mdot
.578 .16274 Mdot
.578 .16314 Mdot
.578 .16329 Mdot
.578 .16377 Mdot
.578 .16457 Mdot
.578 .16543 Mdot
.578 .16573 Mdot
.578 .16593 Mdot
.578 .16627 Mdot
.578 .16639 Mdot
.578 .16649 Mdot
.578 .167 Mdot
.578 .16725 Mdot
.578 .1674 Mdot
.578 .16816 Mdot
.578 .16836 Mdot
.578 .16878 Mdot
.578 .16891 Mdot
.578 .16925 Mdot
.578 .16929 Mdot
.578 .16952 Mdot
.578 .16958 Mdot
.578 .16999 Mdot
.578 .17035 Mdot
.578 .17042 Mdot
.578 .17194 Mdot
.578 .17206 Mdot
.578 .17209 Mdot
.578 .17243 Mdot
.578 .17287 Mdot
.578 .17517 Mdot
.578 .17554 Mdot
.578 .17587 Mdot
.578 .17795 Mdot
.578 .17801 Mdot
.578 .17825 Mdot
.578 .17829 Mdot
.578 .1784 Mdot
.578 .17912 Mdot
.578 .17925 Mdot
.578 .18064 Mdot
.578 .181 Mdot
.578 .18232 Mdot
.578 .1833 Mdot
.578 .18336 Mdot
.578 .18377 Mdot
.578 .18424 Mdot
.578 .18487 Mdot
.578 .18497 Mdot
.578 .18584 Mdot
.578 .1863 Mdot
.578 .18646 Mdot
.578 .18702 Mdot
.578 .18795 Mdot
.578 .18895 Mdot
.578 .18929 Mdot
.578 .18952 Mdot
.578 .18991 Mdot
.578 .19006 Mdot
.578 .19017 Mdot
.578 .19075 Mdot
.578 .19105 Mdot
.578 .19122 Mdot
.578 .1921 Mdot
.578 .19233 Mdot
.578 .19281 Mdot
.578 .19297 Mdot
.578 .19336 Mdot
.578 .1934 Mdot
.578 .19368 Mdot
.578 .19374 Mdot
.578 .19421 Mdot
.578 .19463 Mdot
.578 .19471 Mdot
.578 .19647 Mdot
.578 .1966 Mdot
.578 .19664 Mdot
.578 .19703 Mdot
.578 .19754 Mdot
.578 .2002 Mdot
.578 .20063 Mdot
.578 .20101 Mdot
.578 .20342 Mdot
.578 .20348 Mdot
.578 .20376 Mdot
.578 .20381 Mdot
.578 .20394 Mdot
.578 .20477 Mdot
.578 .20492 Mdot
.578 .20652 Mdot
.578 .20694 Mdot
.578 .20847 Mdot
.578 .2096 Mdot
.578 .20967 Mdot
.578 .21015 Mdot
.578 .21068 Mdot
.578 .21141 Mdot
.578 .21152 Mdot
.578 .21253 Mdot
.578 .21306 Mdot
.578 .21326 Mdot
.578 .2139 Mdot
.578 .21497 Mdot
.578 .21613 Mdot
.578 .21653 Mdot
.578 .21679 Mdot
.578 .21724 Mdot
.578 .21741 Mdot
.578 .21754 Mdot
.578 .21822 Mdot
.578 .21856 Mdot
.578 .21876 Mdot
.578 .21977 Mdot
.578 .22003 Mdot
.578 .22059 Mdot
.578 .22077 Mdot
.578 .22123 Mdot
.578 .22128 Mdot
.578 .22159 Mdot
.578 .22167 Mdot
.578 .22221 Mdot
.578 .2227 Mdot
.578 .22279 Mdot
.578 .22482 Mdot
.578 .22498 Mdot
.578 .22502 Mdot
.578 .22547 Mdot
.578 .22606 Mdot
.578 .22914 Mdot
.578 .22963 Mdot
.578 .23007 Mdot
.578 .23286 Mdot
.578 .23293 Mdot
.578 .23325 Mdot
.578 .23331 Mdot
.578 .23346 Mdot
.578 .23442 Mdot
.578 .23459 Mdot
.578 .23645 Mdot
.578 .23693 Mdot
.578 .23869 Mdot
.578 .24 Mdot
.578 .24009 Mdot
.578 .24063 Mdot
.578 .24125 Mdot
.578 .24209 Mdot
.578 .24223 Mdot
.578 .24339 Mdot
.578 .24401 Mdot
.578 .24423 Mdot
.578 .24497 Mdot
.578 .24621 Mdot
.578 .24755 Mdot
.578 .24801 Mdot
.578 .24831 Mdot
.578 .24884 Mdot
.578 .24903 Mdot
.578 .24918 Mdot
.578 .24996 Mdot
.578 .25036 Mdot
.578 .25059 Mdot
.578 .25175 Mdot
.578 .25206 Mdot
.578 .25271 Mdot
.578 .25292 Mdot
.578 .25344 Mdot
.578 .2535 Mdot
.578 .25387 Mdot
.578 .25395 Mdot
.578 .25458 Mdot
.578 .25515 Mdot
.578 .25525 Mdot
.578 .2576 Mdot
.578 .25778 Mdot
.578 .25783 Mdot
.578 .25835 Mdot
.578 .25903 Mdot
.578 .26259 Mdot
.578 .26316 Mdot
.578 .26367 Mdot
.578 .26689 Mdot
.578 .26697 Mdot
.578 .26735 Mdot
.578 .26741 Mdot
.578 .26758 Mdot
.578 .26869 Mdot
.578 .26889 Mdot
.578 .27104 Mdot
.578 .2716 Mdot
.578 .27363 Mdot
.578 .27514 Mdot
.578 .27524 Mdot
.578 .27588 Mdot
.578 .27659 Mdot
.578 .27756 Mdot
.578 .27772 Mdot
.578 .27906 Mdot
.578 .27978 Mdot
.578 .28003 Mdot
.578 .28089 Mdot
.578 .28233 Mdot
.578 .28387 Mdot
.578 .2844 Mdot
.578 .28475 Mdot
.578 .28536 Mdot
.578 .28558 Mdot
.578 .28576 Mdot
.578 .28666 Mdot
.578 .28712 Mdot
.578 .28738 Mdot
.578 .28873 Mdot
.578 .28909 Mdot
.578 .28983 Mdot
.578 .29008 Mdot
.578 .29068 Mdot
.578 .29076 Mdot
.578 .29117 Mdot
.578 .29128 Mdot
.578 .292 Mdot
.578 .29265 Mdot
.578 .29277 Mdot
.578 .29549 Mdot
.578 .2957 Mdot
.578 .29575 Mdot
.578 .29636 Mdot
.578 .29715 Mdot
.578 .30126 Mdot
.578 .30192 Mdot
.578 .30251 Mdot
.578 .30623 Mdot
.578 .30632 Mdot
.578 .30676 Mdot
.578 .30683 Mdot
.578 .30703 Mdot
.578 .30831 Mdot
.578 .30854 Mdot
.578 .31102 Mdot
.578 .31167 Mdot
.578 .31403 Mdot
.578 .31577 Mdot
.578 .31589 Mdot
.578 .31662 Mdot
.578 .31745 Mdot
.578 .31857 Mdot
.578 .31875 Mdot
.578 .3203 Mdot
.578 .32113 Mdot
.578 .32142 Mdot
.578 .32241 Mdot
.578 .32408 Mdot
.578 .32586 Mdot
.578 .32648 Mdot
.578 .32688 Mdot
.578 .32758 Mdot
.578 .32784 Mdot
.578 .32805 Mdot
.578 .32908 Mdot
.578 .32961 Mdot
.578 .32992 Mdot
.578 .33148 Mdot
.578 .33189 Mdot
.578 .33275 Mdot
.578 .33304 Mdot
.578 .33373 Mdot
.578 .33382 Mdot
.578 .3343 Mdot
.578 .33442 Mdot
.578 .33526 Mdot
.578 .33601 Mdot
.578 .33615 Mdot
.578 .33929 Mdot
.578 .33953 Mdot
.578 .3396 Mdot
.578 .34029 Mdot
.578 .34121 Mdot
.578 .34596 Mdot
.578 .34672 Mdot
.578 .3474 Mdot
.578 .3517 Mdot
.578 .35181 Mdot
.578 .35231 Mdot
.578 .3524 Mdot
.578 .35263 Mdot
.578 .35411 Mdot
.578 .35438 Mdot
.58 .01522 Mdot
.58 .01531 Mdot
.58 .0154 Mdot
.58 .01551 Mdot
.58 .01564 Mdot
.58 .01578 Mdot
.58 .01596 Mdot
.58 .01615 Mdot
.58 .01638 Mdot
.58 .01665 Mdot
.58 .01696 Mdot
.58 .01732 Mdot
.58 .01763 Mdot
.58 .01774 Mdot
.58 .01809 Mdot
.58 .01822 Mdot
.58 .01863 Mdot
.58 .01878 Mdot
.58 .01886 Mdot
.58 .0189 Mdot
.58 .01914 Mdot
.58 .01926 Mdot
.58 .01943 Mdot
.58 .01952 Mdot
.58 .01957 Mdot
.58 .01985 Mdot
.58 .01998 Mdot
.58 .02019 Mdot
.58 .02019 Mdot
.58 .02029 Mdot
.58 .02035 Mdot
.58 .02067 Mdot
.58 .02079 Mdot
.58 .02083 Mdot
.58 .02089 Mdot
.58 .02106 Mdot
.58 .02106 Mdot
.58 .02118 Mdot
.58 .02125 Mdot
.58 .02162 Mdot
.58 .02176 Mdot
.58 .02181 Mdot
.58 .02188 Mdot
.58 .02208 Mdot
.58 .02208 Mdot
.58 .02222 Mdot
.58 .02229 Mdot
.58 .02273 Mdot
.58 .02288 Mdot
.58 .02294 Mdot
.58 .02303 Mdot
.58 .02325 Mdot
.58 .02326 Mdot
.58 .02333 Mdot
.58 .02342 Mdot
.58 .02351 Mdot
.58 .02397 Mdot
.58 .02401 Mdot
.58 .02426 Mdot
.58 .02436 Mdot
.58 .0244 Mdot
.58 .0246 Mdot
.58 .02462 Mdot
.58 .02462 Mdot
.58 .02471 Mdot
.58 .02473 Mdot
.58 .02481 Mdot
.58 .02491 Mdot
.58 .02546 Mdot
.58 .0255 Mdot
.58 .02578 Mdot
.58 .0259 Mdot
.58 .02595 Mdot
.58 .02619 Mdot
.58 .02621 Mdot
.58 .02621 Mdot
.58 .02631 Mdot
.58 .02633 Mdot
.58 .02643 Mdot
.58 .02655 Mdot
.58 .02695 Mdot
.58 .02717 Mdot
.58 .02722 Mdot
.58 .02746 Mdot
.58 .02755 Mdot
.58 .02769 Mdot
.58 .02774 Mdot
.58 .02802 Mdot
.58 .02804 Mdot
.58 .02805 Mdot
.58 .02817 Mdot
.58 .02819 Mdot
.58 .0283 Mdot
.58 .02844 Mdot
.58 .02891 Mdot
.58 .02917 Mdot
.58 .0292 Mdot
.58 .02922 Mdot
.58 .0295 Mdot
.58 .02961 Mdot
.58 .02977 Mdot
.58 .02983 Mdot
.58 .03015 Mdot
.58 .03018 Mdot
.58 .03018 Mdot
.58 .03032 Mdot
.58 .03035 Mdot
.58 .03047 Mdot
.58 .03063 Mdot
.58 .03069 Mdot
.58 .0311 Mdot
.58 .03118 Mdot
.58 .03148 Mdot
.58 .03152 Mdot
.58 .03155 Mdot
.58 .03187 Mdot
.58 .03199 Mdot
.58 .03214 Mdot
.58 .03218 Mdot
.58 .03225 Mdot
.58 .03237 Mdot
.58 .03262 Mdot
.58 .03265 Mdot
.58 .03266 Mdot
.58 .03282 Mdot
.58 .03285 Mdot
.58 .03299 Mdot
.58 .03318 Mdot
.58 .03325 Mdot
.58 .03373 Mdot
.58 .03381 Mdot
.58 .03416 Mdot
.58 .03421 Mdot
.58 .03424 Mdot
.58 .03461 Mdot
.58 .03475 Mdot
.58 .03493 Mdot
.58 .03497 Mdot
.58 .03503 Mdot
.58 .03505 Mdot
.58 .03519 Mdot
.58 .03549 Mdot
.58 .03552 Mdot
.58 .03553 Mdot
.58 .03571 Mdot
.58 .03575 Mdot
.58 .03592 Mdot
.58 .03614 Mdot
.58 .03621 Mdot
.58 .03677 Mdot
.58 .03687 Mdot
.58 .03727 Mdot
.58 .03733 Mdot
.58 .03736 Mdot
.58 .03736 Mdot
.58 .03779 Mdot
.58 .03796 Mdot
.58 .03817 Mdot
.58 .03821 Mdot
.58 .03828 Mdot
.58 .0383 Mdot
.58 .03834 Mdot
.58 .03847 Mdot
.58 .03881 Mdot
.58 .03885 Mdot
.58 .03886 Mdot
.58 .03907 Mdot
.58 .03911 Mdot
.58 .03931 Mdot
.58 .03954 Mdot
.58 .03956 Mdot
.58 .03965 Mdot
.58 .0403 Mdot
.58 .04041 Mdot
.58 .04088 Mdot
.58 .04095 Mdot
.58 .04098 Mdot
.58 .04099 Mdot
.58 .04149 Mdot
.58 .04168 Mdot
.58 .04169 Mdot
.58 .04192 Mdot
.58 .04197 Mdot
.58 .04205 Mdot
.58 .04208 Mdot
.58 .04212 Mdot
.58 .04227 Mdot
.58 .04256 Mdot
.58 .04266 Mdot
.58 .04271 Mdot
.58 .04272 Mdot
.58 .04297 Mdot
.58 .04302 Mdot
.58 .04325 Mdot
.58 .04339 Mdot
.58 .04351 Mdot
.58 .04354 Mdot
.58 .04364 Mdot
.58 .04439 Mdot
.58 .04453 Mdot
.58 .04507 Mdot
.58 .04514 Mdot
.58 .04519 Mdot
.58 .04519 Mdot
.58 .04567 Mdot
.58 .04577 Mdot
.58 .04599 Mdot
.58 .04601 Mdot
.58 .04627 Mdot
.58 .04633 Mdot
.58 .04642 Mdot
.58 .04646 Mdot
.58 .04651 Mdot
.58 .04667 Mdot
.58 .0469 Mdot
.58 .04701 Mdot
.58 .04704 Mdot
.58 .04714 Mdot
.58 .04719 Mdot
.58 .0472 Mdot
.58 .04749 Mdot
.58 .04755 Mdot
.58 .04781 Mdot
.58 .04798 Mdot
.58 .04811 Mdot
.58 .04815 Mdot
.58 .04827 Mdot
.58 .04873 Mdot
.58 .04883 Mdot
.58 .04914 Mdot
.58 .04929 Mdot
.58 .04993 Mdot
.58 .05001 Mdot
.58 .05006 Mdot
.58 .05007 Mdot
.58 .05019 Mdot
.58 .05062 Mdot
.58 .05074 Mdot
.58 .051 Mdot
.58 .05102 Mdot
.58 .0511 Mdot
.58 .05132 Mdot
.58 .05139 Mdot
.58 .0515 Mdot
.58 .05154 Mdot
.58 .0516 Mdot
.58 .05164 Mdot
.58 .05168 Mdot
.58 .05179 Mdot
.58 .05205 Mdot
.58 .05218 Mdot
.58 .05221 Mdot
.58 .05232 Mdot
.58 .05239 Mdot
.58 .0524 Mdot
.58 .05273 Mdot
.58 .0528 Mdot
.58 .05305 Mdot
.58 .05311 Mdot
.58 .0533 Mdot
.58 .05346 Mdot
.58 .0535 Mdot
.58 .05364 Mdot
.58 .05418 Mdot
.58 .05428 Mdot
.58 .05464 Mdot
.58 .05483 Mdot
.58 .05521 Mdot
.58 .05556 Mdot
.58 .05566 Mdot
.58 .05572 Mdot
.58 .05572 Mdot
.58 .05587 Mdot
.58 .0561 Mdot
.58 .05637 Mdot
.58 .0565 Mdot
.58 .0568 Mdot
.58 .05683 Mdot
.58 .05693 Mdot
.58 .05717 Mdot
.58 .05726 Mdot
.58 .05738 Mdot
.58 .05743 Mdot
.58 .0575 Mdot
.58 .05755 Mdot
.58 .05759 Mdot
.58 .05764 Mdot
.58 .05772 Mdot
.58 .05802 Mdot
.58 .05817 Mdot
.58 .05821 Mdot
.58 .05834 Mdot
.58 .05842 Mdot
.58 .05843 Mdot
.58 .05882 Mdot
.58 .05889 Mdot
.58 .05891 Mdot
.58 .05919 Mdot
.58 .05925 Mdot
.58 .05947 Mdot
.58 .05966 Mdot
.58 .05971 Mdot
.58 .05987 Mdot
.58 .06049 Mdot
.58 .06061 Mdot
.58 .06103 Mdot
.58 .06125 Mdot
.58 .06168 Mdot
.58 .0617 Mdot
.58 .06191 Mdot
.58 .0621 Mdot
.58 .06221 Mdot
.58 .06228 Mdot
.58 .06228 Mdot
.58 .06246 Mdot
.58 .06273 Mdot
.58 .06284 Mdot
.58 .06303 Mdot
.58 .06319 Mdot
.58 .06354 Mdot
.58 .06357 Mdot
.58 .06368 Mdot
.58 .06397 Mdot
.58 .06407 Mdot
.58 .06421 Mdot
.58 .06426 Mdot
.58 .06434 Mdot
.58 .0644 Mdot
.58 .06445 Mdot
.58 .06451 Mdot
.58 .0646 Mdot
.58 .06495 Mdot
.58 .06513 Mdot
.58 .06513 Mdot
.58 .06517 Mdot
.58 .06532 Mdot
.58 .06541 Mdot
.58 .06542 Mdot
.58 .06587 Mdot
.58 .06593 Mdot
.58 .06596 Mdot
.58 .06598 Mdot
.58 .0663 Mdot
.58 .06638 Mdot
.58 .06663 Mdot
.58 .06685 Mdot
.58 .06691 Mdot
.58 .06706 Mdot
.58 .06709 Mdot
.58 .06748 Mdot
.58 .06782 Mdot
.58 .06796 Mdot
.58 .06813 Mdot
.58 .06844 Mdot
.58 .06857 Mdot
.58 .06869 Mdot
.58 .06902 Mdot
.58 .0692 Mdot
.58 .06922 Mdot
.58 .06947 Mdot
.58 .06948 Mdot
.58 .06968 Mdot
.58 .06981 Mdot
.58 .06989 Mdot
.58 .06989 Mdot
.58 .07009 Mdot
.58 .07041 Mdot
.58 .07054 Mdot
.58 .07076 Mdot
.58 .07094 Mdot
.58 .07135 Mdot
.58 .07138 Mdot
.58 .07152 Mdot
.58 .07185 Mdot
.58 .07196 Mdot
.58 .07213 Mdot
.58 .07219 Mdot
.58 .07228 Mdot
.58 .07235 Mdot
.58 .07241 Mdot
.58 .07248 Mdot
.58 .07258 Mdot
.58 .07299 Mdot
.58 .07319 Mdot
.58 .0732 Mdot
.58 .07324 Mdot
.58 .07342 Mdot
.58 .07352 Mdot
.58 .07354 Mdot
.58 .07406 Mdot
.58 .07413 Mdot
.58 .07416 Mdot
.58 .07418 Mdot
.58 .07456 Mdot
.58 .07464 Mdot
.58 .07494 Mdot
.58 .07519 Mdot
.58 .07526 Mdot
.58 .07543 Mdot
.58 .07547 Mdot
.58 .07592 Mdot
.58 .07631 Mdot
.58 .07648 Mdot
.58 .07668 Mdot
.58 .07704 Mdot
.58 .07719 Mdot
.58 .07733 Mdot
.58 .07771 Mdot
.58 .07792 Mdot
.58 .07794 Mdot
.58 .07823 Mdot
.58 .07824 Mdot
.58 .07847 Mdot
.58 .07863 Mdot
.58 .07872 Mdot
.58 .07872 Mdot
.58 .07895 Mdot
.58 .07932 Mdot
.58 .07947 Mdot
.58 .07973 Mdot
.58 .07994 Mdot
.58 .08041 Mdot
.58 .08045 Mdot
.58 .0806 Mdot
.58 .08099 Mdot
.58 .08112 Mdot
.58 .08131 Mdot
.58 .08138 Mdot
.58 .08149 Mdot
.58 .08157 Mdot
.58 .08164 Mdot
.58 .08172 Mdot
.58 .08184 Mdot
.58 .08231 Mdot
.58 .08255 Mdot
.58 .08256 Mdot
.58 .08261 Mdot
.58 .08281 Mdot
.58 .08293 Mdot
.58 .08295 Mdot
.58 .08355 Mdot
.58 .08363 Mdot
.58 .08367 Mdot
.58 .0837 Mdot
.58 .08413 Mdot
.58 .08423 Mdot
.58 .08457 Mdot
.58 .08486 Mdot
.58 .08494 Mdot
.58 .08515 Mdot
.58 .08519 Mdot
.58 .08571 Mdot
.58 .08617 Mdot
.58 .08636 Mdot
.58 .08659 Mdot
.58 .08701 Mdot
.58 .08718 Mdot
.58 .08734 Mdot
.58 .08779 Mdot
.58 .08803 Mdot
.58 .08806 Mdot
.58 .08839 Mdot
.58 .08841 Mdot
.58 .08867 Mdot
.58 .08885 Mdot
.58 .08896 Mdot
.58 .08896 Mdot
.58 .08923 Mdot
.58 .08965 Mdot
.58 .08983 Mdot
.58 .09013 Mdot
.58 .09038 Mdot
.58 .09092 Mdot
.58 .09096 Mdot
.58 .09115 Mdot
.58 .09159 Mdot
.58 .09175 Mdot
.58 .09197 Mdot
.58 .09205 Mdot
.58 .09218 Mdot
.58 .09227 Mdot
.58 .09235 Mdot
.58 .09244 Mdot
.58 .09258 Mdot
.58 .09313 Mdot
.58 .0934 Mdot
.58 .09341 Mdot
.58 .09347 Mdot
.58 .09371 Mdot
.58 .09384 Mdot
.58 .09387 Mdot
.58 .09456 Mdot
.58 .09466 Mdot
.58 .09471 Mdot
.58 .09474 Mdot
.58 .09524 Mdot
.58 .09535 Mdot
.58 .09575 Mdot
.58 .09609 Mdot
.58 .09618 Mdot
.58 .09642 Mdot
.58 .09647 Mdot
.58 .09707 Mdot
.58 .0976 Mdot
.58 .09782 Mdot
.58 .09809 Mdot
.58 .09858 Mdot
.58 .09878 Mdot
.58 .09896 Mdot
.58 .09948 Mdot
.58 .09976 Mdot
.58 .09979 Mdot
.58 .10018 Mdot
.58 .1002 Mdot
.58 .10051 Mdot
.58 .10071 Mdot
.58 .10084 Mdot
.58 .10084 Mdot
.58 .10116 Mdot
.58 .10164 Mdot
.58 .10185 Mdot
.58 .1022 Mdot
.58 .10248 Mdot
.58 .10312 Mdot
.58 .10316 Mdot
.58 .10337 Mdot
.58 .10389 Mdot
.58 .10408 Mdot
.58 .10433 Mdot
.58 .10443 Mdot
.58 .10457 Mdot
.58 .10467 Mdot
.58 .10478 Mdot
.58 .10488 Mdot
.58 .10504 Mdot
.58 .10567 Mdot
.58 .10599 Mdot
.58 .10601 Mdot
.58 .10607 Mdot
.58 .10634 Mdot
.58 .1065 Mdot
.58 .10653 Mdot
.58 .10734 Mdot
.58 .10745 Mdot
.58 .10751 Mdot
.58 .10754 Mdot
.58 .10812 Mdot
.58 .10826 Mdot
.58 .10871 Mdot
.58 .10911 Mdot
.58 .10921 Mdot
.58 .10949 Mdot
.58 .10955 Mdot
.58 .11025 Mdot
.58 .11086 Mdot
.58 .11112 Mdot
.58 .11143 Mdot
.58 .112 Mdot
.58 .11223 Mdot
.58 .11244 Mdot
.58 .11304 Mdot
.58 .11337 Mdot
.58 .1134 Mdot
.58 .11385 Mdot
.58 .11387 Mdot
.58 .11423 Mdot
.58 .11447 Mdot
.58 .11461 Mdot
.58 .11463 Mdot
.58 .11499 Mdot
.58 .11555 Mdot
.58 .11579 Mdot
.58 .11619 Mdot
.58 .11653 Mdot
.58 .11726 Mdot
.58 .11732 Mdot
.58 .11756 Mdot
.58 .11816 Mdot
.58 .11837 Mdot
.58 .11867 Mdot
.58 .11878 Mdot
.58 .11895 Mdot
.58 .11907 Mdot
.58 .11919 Mdot
.58 .11931 Mdot
.58 .11949 Mdot
.58 .12022 Mdot
.58 .1206 Mdot
.58 .12061 Mdot
.58 .12069 Mdot
.58 .121 Mdot
.58 .12119 Mdot
.58 .12122 Mdot
.58 .12196 Mdot
.58 .12216 Mdot
.58 .12229 Mdot
.58 .12235 Mdot
.58 .12239 Mdot
.58 .12307 Mdot
.58 .12322 Mdot
.58 .12375 Mdot
.58 .12421 Mdot
.58 .12433 Mdot
.58 .12465 Mdot
.58 .12472 Mdot
.58 .12553 Mdot
.58 .12624 Mdot
.58 .12654 Mdot
.58 .12691 Mdot
.58 .12757 Mdot
.58 .12783 Mdot
.58 .12808 Mdot
.58 .12878 Mdot
.58 .12915 Mdot
.58 .1292 Mdot
.58 .12971 Mdot
.58 .12974 Mdot
.58 .13016 Mdot
.58 .13044 Mdot
.58 .1306 Mdot
.58 .13061 Mdot
.58 .13103 Mdot
.58 .13169 Mdot
.58 .13196 Mdot
.58 .13243 Mdot
.58 .13282 Mdot
.58 .13367 Mdot
.58 .13373 Mdot
.58 .13401 Mdot
.58 .13471 Mdot
.58 .13496 Mdot
.58 .1353 Mdot
.58 .13543 Mdot
.58 .13563 Mdot
.58 .13576 Mdot
.58 .1359 Mdot
.58 .13604 Mdot
.58 .13626 Mdot
.58 .1371 Mdot
.58 .13754 Mdot
.58 .13756 Mdot
.58 .13764 Mdot
.58 .13801 Mdot
.58 .13822 Mdot
.58 .13826 Mdot
.58 .13912 Mdot
.58 .13935 Mdot
.58 .1395 Mdot
.58 .13957 Mdot
.58 .13962 Mdot
.58 .1404 Mdot
.58 .14059 Mdot
.58 .1412 Mdot
.58 .14173 Mdot
.58 .14187 Mdot
.58 .14224 Mdot
.58 .14232 Mdot
.58 .14326 Mdot
.58 .14409 Mdot
.58 .14444 Mdot
.58 .14486 Mdot
.58 .14562 Mdot
.58 .14593 Mdot
.58 .14622 Mdot
.58 .14703 Mdot
.58 .14746 Mdot
.58 .14751 Mdot
.58 .14811 Mdot
.58 .14814 Mdot
.58 .14863 Mdot
.58 .14895 Mdot
.58 .14914 Mdot
.58 .14915 Mdot
.58 .14964 Mdot
.58 .1504 Mdot
.58 .15072 Mdot
.58 .15126 Mdot
.58 .15171 Mdot
.58 .1527 Mdot
.58 .15278 Mdot
.58 .1531 Mdot
.58 .15391 Mdot
.58 .1542 Mdot
.58 .1546 Mdot
.58 .15474 Mdot
.58 .15498 Mdot
.58 .15513 Mdot
.58 .15529 Mdot
.58 .15545 Mdot
.58 .1557 Mdot
.58 .15669 Mdot
.58 .15719 Mdot
.58 .15721 Mdot
.58 .15731 Mdot
.58 .15774 Mdot
.58 .15798 Mdot
.58 .15803 Mdot
.58 .15903 Mdot
.58 .15929 Mdot
.58 .15947 Mdot
.58 .15955 Mdot
.58 .1596 Mdot
.58 .16051 Mdot
.58 .16072 Mdot
.58 .16144 Mdot
.58 .16205 Mdot
.58 .16222 Mdot
.58 .16265 Mdot
.58 .16274 Mdot
.58 .16383 Mdot
.58 .16479 Mdot
.58 .16519 Mdot
.58 .16568 Mdot
.58 .16657 Mdot
.58 .16692 Mdot
.58 .16726 Mdot
.58 .1682 Mdot
.58 .1687 Mdot
.58 .16876 Mdot
.58 .16946 Mdot
.58 .16949 Mdot
.58 .17005 Mdot
.58 .17043 Mdot
.58 .17065 Mdot
.58 .17066 Mdot
.58 .17123 Mdot
.58 .17211 Mdot
.58 .17248 Mdot
.58 .17311 Mdot
.58 .17363 Mdot
.58 .17478 Mdot
.58 .17487 Mdot
.58 .17524 Mdot
.58 .17619 Mdot
.58 .17651 Mdot
.58 .17698 Mdot
.58 .17715 Mdot
.58 .17742 Mdot
.58 .1776 Mdot
.58 .17778 Mdot
.58 .17797 Mdot
.58 .17826 Mdot
.58 .1794 Mdot
.58 .17999 Mdot
.58 .18001 Mdot
.58 .18012 Mdot
.58 .18062 Mdot
.58 .18091 Mdot
.58 .18096 Mdot
.58 .18212 Mdot
.58 .18243 Mdot
.58 .18263 Mdot
.58 .18273 Mdot
.58 .18279 Mdot
.58 .18384 Mdot
.58 .18409 Mdot
.58 .18491 Mdot
.58 .18562 Mdot
.58 .18582 Mdot
.58 .18631 Mdot
.58 .18642 Mdot
.58 .18769 Mdot
.58 .1888 Mdot
.58 .18927 Mdot
.58 .18983 Mdot
.58 .19086 Mdot
.58 .19127 Mdot
.58 .19167 Mdot
.58 .19275 Mdot
.58 .19334 Mdot
.58 .19341 Mdot
.58 .19421 Mdot
.58 .19426 Mdot
.58 .19491 Mdot
.58 .19534 Mdot
.58 .1956 Mdot
.58 .19562 Mdot
.58 .19627 Mdot
.58 .1973 Mdot
.58 .19772 Mdot
.58 .19846 Mdot
.58 .19906 Mdot
.58 .20039 Mdot
.58 .20049 Mdot
.58 .20093 Mdot
.58 .20202 Mdot
.58 .2024 Mdot
.58 .20294 Mdot
.58 .20314 Mdot
.58 .20345 Mdot
.58 .20366 Mdot
.58 .20387 Mdot
.58 .20409 Mdot
.58 .20443 Mdot
.58 .20575 Mdot
.58 .20643 Mdot
.58 .20646 Mdot
.58 .20659 Mdot
.58 .20717 Mdot
.58 .2075 Mdot
.58 .20756 Mdot
.58 .20891 Mdot
.58 .20926 Mdot
.58 .20949 Mdot
.58 .20961 Mdot
.58 .20968 Mdot
.58 .2109 Mdot
.58 .21119 Mdot
.58 .21215 Mdot
.58 .21297 Mdot
.58 .2132 Mdot
.58 .21377 Mdot
.58 .21389 Mdot
.58 .21536 Mdot
.58 .21665 Mdot
.58 .2172 Mdot
.58 .21785 Mdot
.58 .21905 Mdot
.58 .21952 Mdot
.58 .21998 Mdot
.58 .22124 Mdot
.58 .22192 Mdot
.58 .222 Mdot
.58 .22293 Mdot
.58 .22298 Mdot
.58 .22374 Mdot
.58 .22424 Mdot
.58 .22454 Mdot
.58 .22456 Mdot
.58 .22532 Mdot
.58 .22651 Mdot
.58 .227 Mdot
.58 .22785 Mdot
.58 .22855 Mdot
.58 .2301 Mdot
.58 .23021 Mdot
.58 .23072 Mdot
.58 .23199 Mdot
.58 .23243 Mdot
.58 .23305 Mdot
.58 .23329 Mdot
.58 .23365 Mdot
.58 .23389 Mdot
.58 .23414 Mdot
.58 .23439 Mdot
.58 .23478 Mdot
.58 .23632 Mdot
.58 .23711 Mdot
.58 .23714 Mdot
.58 .23729 Mdot
.58 .23796 Mdot
.58 .23834 Mdot
.58 .23841 Mdot
.58 .23998 Mdot
.58 .24039 Mdot
.58 .24066 Mdot
.58 .24079 Mdot
.58 .24087 Mdot
.58 .24229 Mdot
.58 .24262 Mdot
.58 .24374 Mdot
.58 .24469 Mdot
.58 .24495 Mdot
.58 .24562 Mdot
.58 .24576 Mdot
.58 .24747 Mdot
.58 .24896 Mdot
.58 .24959 Mdot
.58 .25036 Mdot
.58 .25174 Mdot
.58 .25229 Mdot
.58 .25282 Mdot
.58 .25428 Mdot
.58 .25507 Mdot
.58 .25516 Mdot
.58 .25625 Mdot
.58 .25631 Mdot
.58 .25718 Mdot
.58 .25777 Mdot
.58 .25811 Mdot
.58 .25814 Mdot
.58 .25902 Mdot
.58 .2604 Mdot
.58 .26097 Mdot
.58 .26196 Mdot
.58 .26277 Mdot
.58 .26456 Mdot
.58 .26469 Mdot
.58 .26528 Mdot
.58 .26676 Mdot
.58 .26727 Mdot
.58 .26799 Mdot
.58 .26826 Mdot
.58 .26868 Mdot
.58 .26896 Mdot
.58 .26925 Mdot
.58 .26954 Mdot
.58 .26999 Mdot
.58 .27178 Mdot
.58 .27269 Mdot
.58 .27272 Mdot
.58 .2729 Mdot
.58 .27368 Mdot
.58 .27412 Mdot
.58 .2742 Mdot
.58 .27602 Mdot
.58 .27649 Mdot
.58 .27681 Mdot
.58 .27696 Mdot
.58 .27706 Mdot
.58 .27871 Mdot
.58 .27909 Mdot
.58 .28038 Mdot
.58 .28149 Mdot
.58 .28179 Mdot
.58 .28256 Mdot
.58 .28273 Mdot
.58 .28471 Mdot
.58 .28644 Mdot
.58 .28717 Mdot
.58 .28806 Mdot
.58 .28966 Mdot
.58 .2903 Mdot
.58 .29092 Mdot
.58 .29262 Mdot
.58 .29353 Mdot
.58 .29363 Mdot
.58 .29489 Mdot
.58 .29496 Mdot
.58 .29598 Mdot
.58 .29666 Mdot
.58 .29705 Mdot
.58 .29708 Mdot
.58 .2981 Mdot
.58 .2997 Mdot
.58 .30037 Mdot
.58 .30152 Mdot
.58 .30246 Mdot
.58 .30453 Mdot
.58 .30469 Mdot
.58 .30538 Mdot
.58 .30708 Mdot
.58 .30768 Mdot
.58 .30851 Mdot
.58 .30882 Mdot
.58 .30931 Mdot
.58 .30964 Mdot
.58 .30997 Mdot
.58 .31031 Mdot
.58 .31084 Mdot
.58 .3129 Mdot
.58 .31397 Mdot
.58 .314 Mdot
.58 .31421 Mdot
.58 .31511 Mdot
.58 .31563 Mdot
.58 .31572 Mdot
.58 .31783 Mdot
.58 .31838 Mdot
.58 .31874 Mdot
.58 .31892 Mdot
.58 .31903 Mdot
.58 .32094 Mdot
.58 .32138 Mdot
.58 .32289 Mdot
.58 .32417 Mdot
.58 .32452 Mdot
.58 .32542 Mdot
.58 .32561 Mdot
.58 .32791 Mdot
.58 .32992 Mdot
.58 .33077 Mdot
.58 .33179 Mdot
.58 .33365 Mdot
.58 .3344 Mdot
.58 .33511 Mdot
.58 .33708 Mdot
.58 .33814 Mdot
.58 .33826 Mdot
.58 .33972 Mdot
.58 .3398 Mdot
.58 .34098 Mdot
.58 .34177 Mdot
.58 .34223 Mdot
.58 .34226 Mdot
.58 .34345 Mdot
.58 .3453 Mdot
.58 .34608 Mdot
.58 .3474 Mdot
.58 .34849 Mdot
.58 .3509 Mdot
.58 .35109 Mdot
.58 .35188 Mdot
.58 .35386 Mdot
.58 .35455 Mdot
.58 .35552 Mdot
.58 .35588 Mdot
.58 .35644 Mdot
.58 .35682 Mdot
.58 .35721 Mdot
.58 .35761 Mdot
.582 .01547 Mdot
.582 .01552 Mdot
.582 .01559 Mdot
.582 .01565 Mdot
.582 .01574 Mdot
.582 .01581 Mdot
.582 .01591 Mdot
.582 .01599 Mdot
.582 .0161 Mdot
.582 .0162 Mdot
.582 .01633 Mdot
.582 .01644 Mdot
.582 .01659 Mdot
.582 .01672 Mdot
.582 .01681 Mdot
.582 .0169 Mdot
.582 .01705 Mdot
.582 .01716 Mdot
.582 .01726 Mdot
.582 .01743 Mdot
.582 .01756 Mdot
.582 .01768 Mdot
.582 .01788 Mdot
.582 .01802 Mdot
.582 .01817 Mdot
.582 .01831 Mdot
.582 .0184 Mdot
.582 .01856 Mdot
.582 .01873 Mdot
.582 .0189 Mdot
.582 .019 Mdot
.582 .01917 Mdot
.582 .01919 Mdot
.582 .01939 Mdot
.582 .01958 Mdot
.582 .0197 Mdot
.582 .0199 Mdot
.582 .01993 Mdot
.582 .01994 Mdot
.582 .02016 Mdot
.582 .02038 Mdot
.582 .02052 Mdot
.582 .02075 Mdot
.582 .02078 Mdot
.582 .02079 Mdot
.582 .02105 Mdot
.582 .02105 Mdot
.582 .02107 Mdot
.582 .02131 Mdot
.582 .02147 Mdot
.582 .02173 Mdot
.582 .02178 Mdot
.582 .02179 Mdot
.582 .02209 Mdot
.582 .02209 Mdot
.582 .02211 Mdot
.582 .02239 Mdot
.582 .02258 Mdot
.582 .02289 Mdot
.582 .02294 Mdot
.582 .02295 Mdot
.582 .0233 Mdot
.582 .0233 Mdot
.582 .02333 Mdot
.582 .02365 Mdot
.582 .02387 Mdot
.582 .02422 Mdot
.582 .02429 Mdot
.582 .0243 Mdot
.582 .02471 Mdot
.582 .02471 Mdot
.582 .02474 Mdot
.582 .02479 Mdot
.582 .02511 Mdot
.582 .02538 Mdot
.582 .02578 Mdot
.582 .02586 Mdot
.582 .02588 Mdot
.582 .02634 Mdot
.582 .02635 Mdot
.582 .02638 Mdot
.582 .02644 Mdot
.582 .02682 Mdot
.582 .02712 Mdot
.582 .0276 Mdot
.582 .02768 Mdot
.582 .02771 Mdot
.582 .02811 Mdot
.582 .02825 Mdot
.582 .02826 Mdot
.582 .0283 Mdot
.582 .02837 Mdot
.582 .02881 Mdot
.582 .02908 Mdot
.582 .02916 Mdot
.582 .02971 Mdot
.582 .02981 Mdot
.582 .02984 Mdot
.582 .03031 Mdot
.582 .03031 Mdot
.582 .03047 Mdot
.582 .03048 Mdot
.582 .03052 Mdot
.582 .03061 Mdot
.582 .03112 Mdot
.582 .03144 Mdot
.582 .03153 Mdot
.582 .03217 Mdot
.582 .03223 Mdot
.582 .03229 Mdot
.582 .03232 Mdot
.582 .03287 Mdot
.582 .03287 Mdot
.582 .03287 Mdot
.582 .03306 Mdot
.582 .03307 Mdot
.582 .03311 Mdot
.582 .03321 Mdot
.582 .03381 Mdot
.582 .03418 Mdot
.582 .03422 Mdot
.582 .03429 Mdot
.582 .03449 Mdot
.582 .03468 Mdot
.582 .03504 Mdot
.582 .03511 Mdot
.582 .03517 Mdot
.582 .0352 Mdot
.582 .03546 Mdot
.582 .03577 Mdot
.582 .03585 Mdot
.582 .03585 Mdot
.582 .03585 Mdot
.582 .03606 Mdot
.582 .03608 Mdot
.582 .03613 Mdot
.582 .03625 Mdot
.582 .03689 Mdot
.582 .03694 Mdot
.582 .03737 Mdot
.582 .03742 Mdot
.582 .03749 Mdot
.582 .0375 Mdot
.582 .03774 Mdot
.582 .03795 Mdot
.582 .03802 Mdot
.582 .03837 Mdot
.582 .03845 Mdot
.582 .03852 Mdot
.582 .03856 Mdot
.582 .03886 Mdot
.582 .03922 Mdot
.582 .03931 Mdot
.582 .03931 Mdot
.582 .03931 Mdot
.582 .03955 Mdot
.582 .03957 Mdot
.582 .03958 Mdot
.582 .03964 Mdot
.582 .03978 Mdot
.582 .04053 Mdot
.582 .04058 Mdot
.582 .04081 Mdot
.582 .04109 Mdot
.582 .04115 Mdot
.582 .04123 Mdot
.582 .04123 Mdot
.582 .04151 Mdot
.582 .04176 Mdot
.582 .04184 Mdot
.582 .04208 Mdot
.582 .04225 Mdot
.582 .04232 Mdot
.582 .04234 Mdot
.582 .04243 Mdot
.582 .04247 Mdot
.582 .04282 Mdot
.582 .0432 Mdot
.582 .04324 Mdot
.582 .04334 Mdot
.582 .04335 Mdot
.582 .04335 Mdot
.582 .04362 Mdot
.582 .04364 Mdot
.582 .04366 Mdot
.582 .04373 Mdot
.582 .04389 Mdot
.582 .04439 Mdot
.582 .04476 Mdot
.582 .04482 Mdot
.582 .04509 Mdot
.582 .04509 Mdot
.582 .04541 Mdot
.582 .04548 Mdot
.582 .04558 Mdot
.582 .04558 Mdot
.582 .04591 Mdot
.582 .0462 Mdot
.582 .04629 Mdot
.582 .04656 Mdot
.582 .04676 Mdot
.582 .04685 Mdot
.582 .04688 Mdot
.582 .04697 Mdot
.582 .04703 Mdot
.582 .04707 Mdot
.582 .04743 Mdot
.582 .04763 Mdot
.582 .0477 Mdot
.582 .04787 Mdot
.582 .04792 Mdot
.582 .04804 Mdot
.582 .04804 Mdot
.582 .04804 Mdot
.582 .04831 Mdot
.582 .04836 Mdot
.582 .04838 Mdot
.582 .0484 Mdot
.582 .04849 Mdot
.582 .04867 Mdot
.582 .04899 Mdot
.582 .04903 Mdot
.582 .04904 Mdot
.582 .04926 Mdot
.582 .04969 Mdot
.582 .04976 Mdot
.582 .05007 Mdot
.582 .05007 Mdot
.582 .05045 Mdot
.582 .05053 Mdot
.582 .05064 Mdot
.582 .05064 Mdot
.582 .05102 Mdot
.582 .05136 Mdot
.582 .05146 Mdot
.582 .05179 Mdot
.582 .05185 Mdot
.582 .05202 Mdot
.582 .05204 Mdot
.582 .05212 Mdot
.582 .05215 Mdot
.582 .05226 Mdot
.582 .05233 Mdot
.582 .05238 Mdot
.582 .05254 Mdot
.582 .05267 Mdot
.582 .0528 Mdot
.582 .05282 Mdot
.582 .05291 Mdot
.582 .05303 Mdot
.582 .0531 Mdot
.582 .05331 Mdot
.582 .05337 Mdot
.582 .0535 Mdot
.582 .05351 Mdot
.582 .05351 Mdot
.582 .05382 Mdot
.582 .05388 Mdot
.582 .05391 Mdot
.582 .05393 Mdot
.582 .05403 Mdot
.582 .05413 Mdot
.582 .05424 Mdot
.582 .05461 Mdot
.582 .05465 Mdot
.582 .05467 Mdot
.582 .05492 Mdot
.582 .05511 Mdot
.582 .05543 Mdot
.582 .05551 Mdot
.582 .05587 Mdot
.582 .05587 Mdot
.582 .05621 Mdot
.582 .05631 Mdot
.582 .0564 Mdot
.582 .05653 Mdot
.582 .05653 Mdot
.582 .05698 Mdot
.582 .05738 Mdot
.582 .05749 Mdot
.582 .05787 Mdot
.582 .05794 Mdot
.582 .0581 Mdot
.582 .05814 Mdot
.582 .05816 Mdot
.582 .05825 Mdot
.582 .05829 Mdot
.582 .05842 Mdot
.582 .05849 Mdot
.582 .05856 Mdot
.582 .05874 Mdot
.582 .05889 Mdot
.582 .05904 Mdot
.582 .05907 Mdot
.582 .05917 Mdot
.582 .05932 Mdot
.582 .0594 Mdot
.582 .05964 Mdot
.582 .0597 Mdot
.582 .05978 Mdot
.582 .05987 Mdot
.582 .05987 Mdot
.582 .05987 Mdot
.582 .06021 Mdot
.582 .06023 Mdot
.582 .0603 Mdot
.582 .06032 Mdot
.582 .06033 Mdot
.582 .06036 Mdot
.582 .06048 Mdot
.582 .0606 Mdot
.582 .06073 Mdot
.582 .06115 Mdot
.582 .0612 Mdot
.582 .06122 Mdot
.582 .06151 Mdot
.582 .06174 Mdot
.582 .06211 Mdot
.582 .0622 Mdot
.582 .06262 Mdot
.582 .06262 Mdot
.582 .0628 Mdot
.582 .06301 Mdot
.582 .06313 Mdot
.582 .06324 Mdot
.582 .06339 Mdot
.582 .06339 Mdot
.582 .06391 Mdot
.582 .06437 Mdot
.582 .06451 Mdot
.582 .06468 Mdot
.582 .06494 Mdot
.582 .06503 Mdot
.582 .06522 Mdot
.582 .06526 Mdot
.582 .06528 Mdot
.582 .06539 Mdot
.582 .06543 Mdot
.582 .06559 Mdot
.582 .06567 Mdot
.582 .06575 Mdot
.582 .06596 Mdot
.582 .06613 Mdot
.582 .06631 Mdot
.582 .06634 Mdot
.582 .06647 Mdot
.582 .06663 Mdot
.582 .06673 Mdot
.582 .067 Mdot
.582 .06708 Mdot
.582 .06718 Mdot
.582 .06727 Mdot
.582 .06728 Mdot
.582 .06728 Mdot
.582 .06767 Mdot
.582 .06769 Mdot
.582 .06776 Mdot
.582 .06778 Mdot
.582 .0678 Mdot
.582 .06781 Mdot
.582 .06784 Mdot
.582 .06798 Mdot
.582 .06812 Mdot
.582 .06827 Mdot
.582 .06854 Mdot
.582 .06877 Mdot
.582 .06883 Mdot
.582 .06884 Mdot
.582 .06919 Mdot
.582 .06945 Mdot
.582 .06988 Mdot
.582 .06998 Mdot
.582 .07047 Mdot
.582 .07048 Mdot
.582 .07069 Mdot
.582 .07093 Mdot
.582 .07107 Mdot
.582 .07119 Mdot
.582 .07137 Mdot
.582 .07138 Mdot
.582 .07198 Mdot
.582 .07252 Mdot
.582 .07267 Mdot
.582 .07287 Mdot
.582 .07318 Mdot
.582 .07328 Mdot
.582 .0735 Mdot
.582 .07355 Mdot
.582 .07358 Mdot
.582 .0737 Mdot
.582 .07375 Mdot
.582 .07393 Mdot
.582 .07403 Mdot
.582 .07412 Mdot
.582 .07436 Mdot
.582 .07457 Mdot
.582 .07477 Mdot
.582 .07481 Mdot
.582 .07495 Mdot
.582 .07515 Mdot
.582 .07526 Mdot
.582 .07558 Mdot
.582 .07567 Mdot
.582 .07578 Mdot
.582 .07589 Mdot
.582 .0759 Mdot
.582 .0759 Mdot
.582 .07635 Mdot
.582 .07638 Mdot
.582 .07646 Mdot
.582 .07648 Mdot
.582 .07651 Mdot
.582 .07652 Mdot
.582 .07656 Mdot
.582 .07672 Mdot
.582 .07688 Mdot
.582 .07706 Mdot
.582 .07736 Mdot
.582 .07763 Mdot
.582 .0777 Mdot
.582 .07772 Mdot
.582 .07812 Mdot
.582 .07843 Mdot
.582 .07892 Mdot
.582 .07905 Mdot
.582 .07962 Mdot
.582 .07962 Mdot
.582 .07987 Mdot
.582 .08015 Mdot
.582 .08031 Mdot
.582 .08046 Mdot
.582 .08067 Mdot
.582 .08067 Mdot
.582 .08137 Mdot
.582 .08199 Mdot
.582 .08218 Mdot
.582 .08241 Mdot
.582 .08277 Mdot
.582 .08289 Mdot
.582 .08314 Mdot
.582 .08319 Mdot
.582 .08323 Mdot
.582 .08338 Mdot
.582 .08343 Mdot
.582 .08365 Mdot
.582 .08376 Mdot
.582 .08386 Mdot
.582 .08415 Mdot
.582 .08438 Mdot
.582 .08462 Mdot
.582 .08467 Mdot
.582 .08483 Mdot
.582 .08506 Mdot
.582 .08519 Mdot
.582 .08556 Mdot
.582 .08567 Mdot
.582 .08579 Mdot
.582 .08592 Mdot
.582 .08593 Mdot
.582 .08593 Mdot
.582 .08646 Mdot
.582 .0865 Mdot
.582 .08659 Mdot
.582 .08661 Mdot
.582 .08664 Mdot
.582 .08666 Mdot
.582 .0867 Mdot
.582 .08689 Mdot
.582 .08707 Mdot
.582 .08728 Mdot
.582 .08764 Mdot
.582 .08795 Mdot
.582 .08803 Mdot
.582 .08805 Mdot
.582 .08852 Mdot
.582 .08887 Mdot
.582 .08945 Mdot
.582 .0896 Mdot
.582 .09026 Mdot
.582 .09027 Mdot
.582 .09055 Mdot
.582 .09088 Mdot
.582 .09107 Mdot
.582 .09124 Mdot
.582 .09148 Mdot
.582 .09149 Mdot
.582 .0923 Mdot
.582 .09303 Mdot
.582 .09324 Mdot
.582 .09351 Mdot
.582 .09393 Mdot
.582 .09407 Mdot
.582 .09437 Mdot
.582 .09443 Mdot
.582 .09447 Mdot
.582 .09464 Mdot
.582 .0947 Mdot
.582 .09495 Mdot
.582 .09508 Mdot
.582 .0952 Mdot
.582 .09553 Mdot
.582 .09581 Mdot
.582 .09609 Mdot
.582 .09614 Mdot
.582 .09633 Mdot
.582 .09659 Mdot
.582 .09675 Mdot
.582 .09718 Mdot
.582 .0973 Mdot
.582 .09745 Mdot
.582 .0976 Mdot
.582 .09761 Mdot
.582 .09761 Mdot
.582 .09823 Mdot
.582 .09827 Mdot
.582 .09838 Mdot
.582 .09841 Mdot
.582 .09844 Mdot
.582 .09846 Mdot
.582 .0985 Mdot
.582 .09873 Mdot
.582 .09894 Mdot
.582 .09918 Mdot
.582 .0996 Mdot
.582 .09996 Mdot
.582 .10006 Mdot
.582 .10008 Mdot
.582 .10063 Mdot
.582 .10104 Mdot
.582 .10171 Mdot
.582 .10188 Mdot
.582 .10265 Mdot
.582 .10266 Mdot
.582 .10299 Mdot
.582 .10337 Mdot
.582 .10359 Mdot
.582 .10379 Mdot
.582 .10407 Mdot
.582 .10408 Mdot
.582 .10502 Mdot
.582 .10587 Mdot
.582 .10612 Mdot
.582 .10643 Mdot
.582 .10692 Mdot
.582 .10708 Mdot
.582 .10743 Mdot
.582 .1075 Mdot
.582 .10755 Mdot
.582 .10774 Mdot
.582 .10782 Mdot
.582 .10811 Mdot
.582 .10826 Mdot
.582 .1084 Mdot
.582 .10879 Mdot
.582 .10911 Mdot
.582 .10943 Mdot
.582 .10949 Mdot
.582 .10972 Mdot
.582 .11002 Mdot
.582 .1102 Mdot
.582 .1107 Mdot
.582 .11085 Mdot
.582 .11102 Mdot
.582 .11119 Mdot
.582 .1112 Mdot
.582 .11121 Mdot
.582 .11192 Mdot
.582 .11197 Mdot
.582 .1121 Mdot
.582 .11213 Mdot
.582 .11217 Mdot
.582 .11219 Mdot
.582 .11224 Mdot
.582 .1125 Mdot
.582 .11275 Mdot
.582 .11303 Mdot
.582 .11352 Mdot
.582 .11395 Mdot
.582 .11405 Mdot
.582 .11408 Mdot
.582 .11471 Mdot
.582 .11519 Mdot
.582 .11598 Mdot
.582 .11618 Mdot
.582 .11707 Mdot
.582 .11708 Mdot
.582 .11747 Mdot
.582 .11791 Mdot
.582 .11817 Mdot
.582 .11839 Mdot
.582 .11873 Mdot
.582 .11873 Mdot
.582 .11984 Mdot
.582 .12082 Mdot
.582 .12111 Mdot
.582 .12147 Mdot
.582 .12204 Mdot
.582 .12223 Mdot
.582 .12263 Mdot
.582 .12271 Mdot
.582 .12277 Mdot
.582 .123 Mdot
.582 .12309 Mdot
.582 .12343 Mdot
.582 .1236 Mdot
.582 .12376 Mdot
.582 .12421 Mdot
.582 .12459 Mdot
.582 .12496 Mdot
.582 .12504 Mdot
.582 .1253 Mdot
.582 .12565 Mdot
.582 .12586 Mdot
.582 .12645 Mdot
.582 .12661 Mdot
.582 .12681 Mdot
.582 .12702 Mdot
.582 .12703 Mdot
.582 .12703 Mdot
.582 .12786 Mdot
.582 .12792 Mdot
.582 .12807 Mdot
.582 .12811 Mdot
.582 .12815 Mdot
.582 .12818 Mdot
.582 .12854 Mdot
.582 .12883 Mdot
.582 .12916 Mdot
.582 .12972 Mdot
.582 .13022 Mdot
.582 .13034 Mdot
.582 .13038 Mdot
.582 .13111 Mdot
.582 .13167 Mdot
.582 .13259 Mdot
.582 .13282 Mdot
.582 .13386 Mdot
.582 .13387 Mdot
.582 .13432 Mdot
.582 .13483 Mdot
.582 .13513 Mdot
.582 .1354 Mdot
.582 .13578 Mdot
.582 .13579 Mdot
.582 .13707 Mdot
.582 .13822 Mdot
.582 .13856 Mdot
.582 .13898 Mdot
.582 .13965 Mdot
.582 .13986 Mdot
.582 .14033 Mdot
.582 .14043 Mdot
.582 .14049 Mdot
.582 .14076 Mdot
.582 .14087 Mdot
.582 .14125 Mdot
.582 .14146 Mdot
.582 .14164 Mdot
.582 .14217 Mdot
.582 .14261 Mdot
.582 .14304 Mdot
.582 .14313 Mdot
.582 .14343 Mdot
.582 .14384 Mdot
.582 .14409 Mdot
.582 .14477 Mdot
.582 .14496 Mdot
.582 .1452 Mdot
.582 .14543 Mdot
.582 .14545 Mdot
.582 .14545 Mdot
.582 .14642 Mdot
.582 .14649 Mdot
.582 .14666 Mdot
.582 .1467 Mdot
.582 .14676 Mdot
.582 .14679 Mdot
.582 .14721 Mdot
.582 .14755 Mdot
.582 .14793 Mdot
.582 .14858 Mdot
.582 .14916 Mdot
.582 .14931 Mdot
.582 .14935 Mdot
.582 .1502 Mdot
.582 .15085 Mdot
.582 .15192 Mdot
.582 .15218 Mdot
.582 .15339 Mdot
.582 .15341 Mdot
.582 .15393 Mdot
.582 .15453 Mdot
.582 .15488 Mdot
.582 .15519 Mdot
.582 .15564 Mdot
.582 .15565 Mdot
.582 .15714 Mdot
.582 .15848 Mdot
.582 .15887 Mdot
.582 .15936 Mdot
.582 .16013 Mdot
.582 .16039 Mdot
.582 .16093 Mdot
.582 .16104 Mdot
.582 .16112 Mdot
.582 .16143 Mdot
.582 .16156 Mdot
.582 .16201 Mdot
.582 .16225 Mdot
.582 .16246 Mdot
.582 .16308 Mdot
.582 .16358 Mdot
.582 .16409 Mdot
.582 .16419 Mdot
.582 .16454 Mdot
.582 .16502 Mdot
.582 .1653 Mdot
.582 .1661 Mdot
.582 .16633 Mdot
.582 .1666 Mdot
.582 .16687 Mdot
.582 .16689 Mdot
.582 .16689 Mdot
.582 .16802 Mdot
.582 .1681 Mdot
.582 .1683 Mdot
.582 .16835 Mdot
.582 .16841 Mdot
.582 .16845 Mdot
.582 .16894 Mdot
.582 .16933 Mdot
.582 .16977 Mdot
.582 .17053 Mdot
.582 .17121 Mdot
.582 .17138 Mdot
.582 .17143 Mdot
.582 .17242 Mdot
.582 .17318 Mdot
.582 .17442 Mdot
.582 .17473 Mdot
.582 .17614 Mdot
.582 .17616 Mdot
.582 .17677 Mdot
.582 .17746 Mdot
.582 .17787 Mdot
.582 .17823 Mdot
.582 .17875 Mdot
.582 .17876 Mdot
.582 .1805 Mdot
.582 .18205 Mdot
.582 .18251 Mdot
.582 .18308 Mdot
.582 .18398 Mdot
.582 .18428 Mdot
.582 .18491 Mdot
.582 .18504 Mdot
.582 .18513 Mdot
.582 .18549 Mdot
.582 .18564 Mdot
.582 .18616 Mdot
.582 .18645 Mdot
.582 .18669 Mdot
.582 .18741 Mdot
.582 .188 Mdot
.582 .18859 Mdot
.582 .1887 Mdot
.582 .18911 Mdot
.582 .18967 Mdot
.582 .19 Mdot
.582 .19093 Mdot
.582 .19119 Mdot
.582 .1915 Mdot
.582 .19182 Mdot
.582 .19184 Mdot
.582 .19185 Mdot
.582 .19316 Mdot
.582 .19325 Mdot
.582 .19348 Mdot
.582 .19354 Mdot
.582 .19362 Mdot
.582 .19366 Mdot
.582 .19423 Mdot
.582 .19469 Mdot
.582 .1952 Mdot
.582 .19609 Mdot
.582 .19688 Mdot
.582 .19707 Mdot
.582 .19713 Mdot
.582 .19829 Mdot
.582 .19917 Mdot
.582 .20061 Mdot
.582 .20097 Mdot
.582 .20261 Mdot
.582 .20264 Mdot
.582 .20334 Mdot
.582 .20416 Mdot
.582 .20462 Mdot
.582 .20504 Mdot
.582 .20565 Mdot
.582 .20566 Mdot
.582 .20769 Mdot
.582 .2095 Mdot
.582 .21003 Mdot
.582 .2107 Mdot
.582 .21174 Mdot
.582 .21209 Mdot
.582 .21283 Mdot
.582 .21297 Mdot
.582 .21307 Mdot
.582 .2135 Mdot
.582 .21367 Mdot
.582 .21428 Mdot
.582 .21461 Mdot
.582 .21489 Mdot
.582 .21573 Mdot
.582 .21642 Mdot
.582 .2171 Mdot
.582 .21724 Mdot
.582 .21772 Mdot
.582 .21836 Mdot
.582 .21874 Mdot
.582 .21983 Mdot
.582 .22013 Mdot
.582 .2205 Mdot
.582 .22087 Mdot
.582 .22089 Mdot
.582 .2209 Mdot
.582 .22243 Mdot
.582 .22253 Mdot
.582 .2228 Mdot
.582 .22287 Mdot
.582 .22296 Mdot
.582 .22301 Mdot
.582 .22367 Mdot
.582 .22421 Mdot
.582 .2248 Mdot
.582 .22583 Mdot
.582 .22675 Mdot
.582 .22698 Mdot
.582 .22704 Mdot
.582 .22839 Mdot
.582 .22942 Mdot
.582 .2311 Mdot
.582 .23152 Mdot
.582 .23343 Mdot
.582 .23346 Mdot
.582 .23428 Mdot
.582 .23522 Mdot
.582 .23577 Mdot
.582 .23626 Mdot
.582 .23697 Mdot
.582 .23698 Mdot
.582 .23934 Mdot
.582 .24144 Mdot
.582 .24206 Mdot
.582 .24284 Mdot
.582 .24405 Mdot
.582 .24446 Mdot
.582 .24532 Mdot
.582 .24549 Mdot
.582 .24561 Mdot
.582 .2461 Mdot
.582 .2463 Mdot
.582 .24701 Mdot
.582 .24739 Mdot
.582 .24772 Mdot
.582 .24869 Mdot
.582 .24949 Mdot
.582 .2503 Mdot
.582 .25045 Mdot
.582 .25101 Mdot
.582 .25176 Mdot
.582 .25221 Mdot
.582 .25346 Mdot
.582 .25382 Mdot
.582 .25425 Mdot
.582 .25468 Mdot
.582 .2547 Mdot
.582 .25471 Mdot
.582 .25649 Mdot
.582 .25661 Mdot
.582 .25693 Mdot
.582 .25701 Mdot
.582 .25711 Mdot
.582 .25717 Mdot
.582 .25794 Mdot
.582 .25856 Mdot
.582 .25925 Mdot
.582 .26046 Mdot
.582 .26152 Mdot
.582 .26179 Mdot
.582 .26187 Mdot
.582 .26344 Mdot
.582 .26463 Mdot
.582 .26658 Mdot
.582 .26707 Mdot
.582 .26929 Mdot
.582 .26933 Mdot
.582 .27028 Mdot
.582 .27139 Mdot
.582 .27202 Mdot
.582 .27259 Mdot
.582 .27341 Mdot
.582 .27343 Mdot
.582 .27617 Mdot
.582 .27863 Mdot
.582 .27934 Mdot
.582 .28025 Mdot
.582 .28167 Mdot
.582 .28213 Mdot
.582 .28313 Mdot
.582 .28333 Mdot
.582 .28347 Mdot
.582 .28405 Mdot
.582 .28428 Mdot
.582 .28511 Mdot
.582 .28555 Mdot
.582 .28593 Mdot
.582 .28707 Mdot
.582 .288 Mdot
.582 .28893 Mdot
.582 .28911 Mdot
.582 .28976 Mdot
.582 .29064 Mdot
.582 .29115 Mdot
.582 .29262 Mdot
.582 .29303 Mdot
.582 .29353 Mdot
.582 .29403 Mdot
.582 .29406 Mdot
.582 .29407 Mdot
.582 .29615 Mdot
.582 .29628 Mdot
.582 .29665 Mdot
.582 .29675 Mdot
.582 .29686 Mdot
.582 .29693 Mdot
.582 .29783 Mdot
.582 .29855 Mdot
.582 .29936 Mdot
.582 .30076 Mdot
.582 .302 Mdot
.582 .30231 Mdot
.582 .3024 Mdot
.582 .30423 Mdot
.582 .30561 Mdot
.582 .30789 Mdot
.582 .30846 Mdot
.582 .31105 Mdot
.582 .31109 Mdot
.582 .3122 Mdot
.582 .31348 Mdot
.582 .31422 Mdot
.582 .31488 Mdot
.582 .31584 Mdot
.582 .31586 Mdot
.582 .31905 Mdot
.582 .32191 Mdot
.582 .32274 Mdot
.582 .3238 Mdot
.582 .32545 Mdot
.582 .32599 Mdot
.582 .32716 Mdot
.582 .32739 Mdot
.582 .32755 Mdot
.582 .32822 Mdot
.582 .32848 Mdot
.582 .32945 Mdot
.582 .32997 Mdot
.582 .33041 Mdot
.582 .33173 Mdot
.582 .33282 Mdot
.582 .3339 Mdot
.582 .33411 Mdot
.582 .33487 Mdot
.582 .33589 Mdot
.582 .33649 Mdot
.582 .33819 Mdot
.582 .33868 Mdot
.582 .33873 Mdot
.582 .33926 Mdot
.582 .33984 Mdot
.582 .33987 Mdot
.582 .33988 Mdot
.582 .3423 Mdot
.582 .34246 Mdot
.582 .34289 Mdot
.582 .343 Mdot
.582 .34313 Mdot
.582 .34321 Mdot
.582 .34426 Mdot
.582 .3451 Mdot
.582 .34604 Mdot
.582 .34767 Mdot
.582 .34912 Mdot
.582 .34948 Mdot
.582 .34958 Mdot
.582 .35171 Mdot
.582 .35332 Mdot
.582 .35597 Mdot
.582 .35663 Mdot
.584 .01576 Mdot
.584 .01593 Mdot
.584 .01614 Mdot
.584 .01638 Mdot
.584 .01659 Mdot
.584 .01666 Mdot
.584 .0167 Mdot
.584 .01691 Mdot
.584 .01698 Mdot
.584 .01704 Mdot
.584 .01728 Mdot
.584 .01736 Mdot
.584 .01742 Mdot
.584 .01771 Mdot
.584 .01781 Mdot
.584 .01788 Mdot
.584 .01821 Mdot
.584 .01833 Mdot
.584 .01841 Mdot
.584 .01844 Mdot
.584 .0188 Mdot
.584 .01894 Mdot
.584 .01903 Mdot
.584 .01907 Mdot
.584 .01918 Mdot
.584 .01949 Mdot
.584 .01965 Mdot
.584 .01976 Mdot
.584 .0198 Mdot
.584 .01993 Mdot
.584 .02003 Mdot
.584 .02029 Mdot
.584 .02029 Mdot
.584 .02047 Mdot
.584 .02061 Mdot
.584 .02065 Mdot
.584 .02081 Mdot
.584 .02092 Mdot
.584 .02092 Mdot
.584 .02103 Mdot
.584 .02123 Mdot
.584 .02123 Mdot
.584 .02144 Mdot
.584 .02159 Mdot
.584 .02165 Mdot
.584 .02183 Mdot
.584 .02196 Mdot
.584 .02197 Mdot
.584 .0221 Mdot
.584 .02232 Mdot
.584 .02233 Mdot
.584 .02257 Mdot
.584 .02275 Mdot
.584 .02282 Mdot
.584 .02302 Mdot
.584 .02318 Mdot
.584 .02319 Mdot
.584 .02334 Mdot
.584 .0236 Mdot
.584 .0236 Mdot
.584 .02389 Mdot
.584 .0241 Mdot
.584 .02418 Mdot
.584 .02442 Mdot
.584 .02445 Mdot
.584 .0246 Mdot
.584 .02461 Mdot
.584 .02478 Mdot
.584 .02487 Mdot
.584 .02509 Mdot
.584 .0251 Mdot
.584 .02543 Mdot
.584 .02568 Mdot
.584 .02577 Mdot
.584 .02605 Mdot
.584 .02609 Mdot
.584 .02626 Mdot
.584 .02627 Mdot
.584 .02646 Mdot
.584 .02648 Mdot
.584 .02657 Mdot
.584 .02683 Mdot
.584 .02684 Mdot
.584 .02705 Mdot
.584 .02723 Mdot
.584 .02752 Mdot
.584 .02758 Mdot
.584 .02762 Mdot
.584 .02796 Mdot
.584 .028 Mdot
.584 .0282 Mdot
.584 .02821 Mdot
.584 .02843 Mdot
.584 .02845 Mdot
.584 .02854 Mdot
.584 .02857 Mdot
.584 .02887 Mdot
.584 .02888 Mdot
.584 .02912 Mdot
.584 .02934 Mdot
.584 .02966 Mdot
.584 .02967 Mdot
.584 .02974 Mdot
.584 .02979 Mdot
.584 .02983 Mdot
.584 .03018 Mdot
.584 .03023 Mdot
.584 .03047 Mdot
.584 .03048 Mdot
.584 .03062 Mdot
.584 .03073 Mdot
.584 .03076 Mdot
.584 .03086 Mdot
.584 .03089 Mdot
.584 .03125 Mdot
.584 .03126 Mdot
.584 .03154 Mdot
.584 .03179 Mdot
.584 .03217 Mdot
.584 .03218 Mdot
.584 .03226 Mdot
.584 .03233 Mdot
.584 .03237 Mdot
.584 .03278 Mdot
.584 .03284 Mdot
.584 .03307 Mdot
.584 .03311 Mdot
.584 .03313 Mdot
.584 .03329 Mdot
.584 .03343 Mdot
.584 .03345 Mdot
.584 .03357 Mdot
.584 .03361 Mdot
.584 .03402 Mdot
.584 .03404 Mdot
.584 .03437 Mdot
.584 .03446 Mdot
.584 .03466 Mdot
.584 .0351 Mdot
.584 .03512 Mdot
.584 .03521 Mdot
.584 .03528 Mdot
.584 .03534 Mdot
.584 .03541 Mdot
.584 .03581 Mdot
.584 .03588 Mdot
.584 .03616 Mdot
.584 .0362 Mdot
.584 .03622 Mdot
.584 .03641 Mdot
.584 .03657 Mdot
.584 .0366 Mdot
.584 .03674 Mdot
.584 .03679 Mdot
.584 .03727 Mdot
.584 .03729 Mdot
.584 .03767 Mdot
.584 .03773 Mdot
.584 .03778 Mdot
.584 .03801 Mdot
.584 .03846 Mdot
.584 .03852 Mdot
.584 .03854 Mdot
.584 .03865 Mdot
.584 .03874 Mdot
.584 .03878 Mdot
.584 .0388 Mdot
.584 .03888 Mdot
.584 .03908 Mdot
.584 .03936 Mdot
.584 .03944 Mdot
.584 .03976 Mdot
.584 .03981 Mdot
.584 .03984 Mdot
.584 .04006 Mdot
.584 .04009 Mdot
.584 .04024 Mdot
.584 .04028 Mdot
.584 .04044 Mdot
.584 .0405 Mdot
.584 .04105 Mdot
.584 .04108 Mdot
.584 .04152 Mdot
.584 .0416 Mdot
.584 .04165 Mdot
.584 .04193 Mdot
.584 .04245 Mdot
.584 .04252 Mdot
.584 .04255 Mdot
.584 .04268 Mdot
.584 .04278 Mdot
.584 .04282 Mdot
.584 .04285 Mdot
.584 .04294 Mdot
.584 .04306 Mdot
.584 .04317 Mdot
.584 .0435 Mdot
.584 .04359 Mdot
.584 .04397 Mdot
.584 .04403 Mdot
.584 .04406 Mdot
.584 .04431 Mdot
.584 .04435 Mdot
.584 .04453 Mdot
.584 .04457 Mdot
.584 .04476 Mdot
.584 .04483 Mdot
.584 .04503 Mdot
.584 .04548 Mdot
.584 .04551 Mdot
.584 .04562 Mdot
.584 .04603 Mdot
.584 .04608 Mdot
.584 .04612 Mdot
.584 .04618 Mdot
.584 .0465 Mdot
.584 .04683 Mdot
.584 .04711 Mdot
.584 .0472 Mdot
.584 .04722 Mdot
.584 .04729 Mdot
.584 .04737 Mdot
.584 .04749 Mdot
.584 .04754 Mdot
.584 .04758 Mdot
.584 .04768 Mdot
.584 .04783 Mdot
.584 .04795 Mdot
.584 .04833 Mdot
.584 .04844 Mdot
.584 .04888 Mdot
.584 .04895 Mdot
.584 .04899 Mdot
.584 .04928 Mdot
.584 .04933 Mdot
.584 .04954 Mdot
.584 .04959 Mdot
.584 .04968 Mdot
.584 .04981 Mdot
.584 .04989 Mdot
.584 .05012 Mdot
.584 .05065 Mdot
.584 .05068 Mdot
.584 .05071 Mdot
.584 .05081 Mdot
.584 .05129 Mdot
.584 .05135 Mdot
.584 .05139 Mdot
.584 .05146 Mdot
.584 .05184 Mdot
.584 .05223 Mdot
.584 .05255 Mdot
.584 .05265 Mdot
.584 .05269 Mdot
.584 .05276 Mdot
.584 .05286 Mdot
.584 .053 Mdot
.584 .05306 Mdot
.584 .0531 Mdot
.584 .05322 Mdot
.584 .05339 Mdot
.584 .05354 Mdot
.584 .05398 Mdot
.584 .0541 Mdot
.584 .05462 Mdot
.584 .05469 Mdot
.584 .0547 Mdot
.584 .05475 Mdot
.584 .05509 Mdot
.584 .05514 Mdot
.584 .05539 Mdot
.584 .05545 Mdot
.584 .05556 Mdot
.584 .0557 Mdot
.584 .05579 Mdot
.584 .05607 Mdot
.584 .05669 Mdot
.584 .05672 Mdot
.584 .05676 Mdot
.584 .05687 Mdot
.584 .05743 Mdot
.584 .0575 Mdot
.584 .05755 Mdot
.584 .05764 Mdot
.584 .05796 Mdot
.584 .05808 Mdot
.584 .05853 Mdot
.584 .0589 Mdot
.584 .05903 Mdot
.584 .05905 Mdot
.584 .05906 Mdot
.584 .05915 Mdot
.584 .05927 Mdot
.584 .05928 Mdot
.584 .05938 Mdot
.584 .05943 Mdot
.584 .0595 Mdot
.584 .05955 Mdot
.584 .05969 Mdot
.584 .05989 Mdot
.584 .06006 Mdot
.584 .06011 Mdot
.584 .06014 Mdot
.584 .06058 Mdot
.584 .06072 Mdot
.584 .06118 Mdot
.584 .06129 Mdot
.584 .06132 Mdot
.584 .06141 Mdot
.584 .06142 Mdot
.584 .06147 Mdot
.584 .06188 Mdot
.584 .06193 Mdot
.584 .06214 Mdot
.584 .06222 Mdot
.584 .06229 Mdot
.584 .06242 Mdot
.584 .06257 Mdot
.584 .06259 Mdot
.584 .0627 Mdot
.584 .06302 Mdot
.584 .06321 Mdot
.584 .06364 Mdot
.584 .06374 Mdot
.584 .06378 Mdot
.584 .06382 Mdot
.584 .06395 Mdot
.584 .06461 Mdot
.584 .06469 Mdot
.584 .06475 Mdot
.584 .06485 Mdot
.584 .06491 Mdot
.584 .06523 Mdot
.584 .06536 Mdot
.584 .06589 Mdot
.584 .06633 Mdot
.584 .06647 Mdot
.584 .0665 Mdot
.584 .06651 Mdot
.584 .06661 Mdot
.584 .06662 Mdot
.584 .06675 Mdot
.584 .06677 Mdot
.584 .06688 Mdot
.584 .06694 Mdot
.584 .06702 Mdot
.584 .06708 Mdot
.584 .06725 Mdot
.584 .06748 Mdot
.584 .06768 Mdot
.584 .06774 Mdot
.584 .06778 Mdot
.584 .06812 Mdot
.584 .06828 Mdot
.584 .06845 Mdot
.584 .0686 Mdot
.584 .06887 Mdot
.584 .06898 Mdot
.584 .06911 Mdot
.584 .06915 Mdot
.584 .06925 Mdot
.584 .06927 Mdot
.584 .06933 Mdot
.584 .0698 Mdot
.584 .06986 Mdot
.584 .07011 Mdot
.584 .0702 Mdot
.584 .07028 Mdot
.584 .07043 Mdot
.584 .07061 Mdot
.584 .07063 Mdot
.584 .07076 Mdot
.584 .07114 Mdot
.584 .07135 Mdot
.584 .0715 Mdot
.584 .07186 Mdot
.584 .07197 Mdot
.584 .07202 Mdot
.584 .07207 Mdot
.584 .07222 Mdot
.584 .07269 Mdot
.584 .07299 Mdot
.584 .07308 Mdot
.584 .07315 Mdot
.584 .07327 Mdot
.584 .07334 Mdot
.584 .07371 Mdot
.584 .07387 Mdot
.584 .07449 Mdot
.584 .075 Mdot
.584 .07517 Mdot
.584 .0752 Mdot
.584 .07522 Mdot
.584 .07533 Mdot
.584 .07534 Mdot
.584 .0755 Mdot
.584 .07551 Mdot
.584 .07565 Mdot
.584 .07571 Mdot
.584 .07581 Mdot
.584 .07588 Mdot
.584 .07608 Mdot
.584 .07634 Mdot
.584 .07657 Mdot
.584 .07665 Mdot
.584 .07669 Mdot
.584 .0771 Mdot
.584 .07728 Mdot
.584 .07748 Mdot
.584 .07765 Mdot
.584 .07796 Mdot
.584 .0781 Mdot
.584 .07825 Mdot
.584 .0783 Mdot
.584 .07841 Mdot
.584 .07843 Mdot
.584 .0785 Mdot
.584 .07905 Mdot
.584 .07913 Mdot
.584 .07942 Mdot
.584 .07952 Mdot
.584 .07962 Mdot
.584 .07979 Mdot
.584 .08 Mdot
.584 .08003 Mdot
.584 .08017 Mdot
.584 .08062 Mdot
.584 .08087 Mdot
.584 .08104 Mdot
.584 .08146 Mdot
.584 .08159 Mdot
.584 .08165 Mdot
.584 .0817 Mdot
.584 .08189 Mdot
.584 .08243 Mdot
.584 .08278 Mdot
.584 .08289 Mdot
.584 .08297 Mdot
.584 .08311 Mdot
.584 .08319 Mdot
.584 .08362 Mdot
.584 .08381 Mdot
.584 .08453 Mdot
.584 .08513 Mdot
.584 .08532 Mdot
.584 .08536 Mdot
.584 .08538 Mdot
.584 .08551 Mdot
.584 .08552 Mdot
.584 .08571 Mdot
.584 .08573 Mdot
.584 .08588 Mdot
.584 .08596 Mdot
.584 .08608 Mdot
.584 .08615 Mdot
.584 .08638 Mdot
.584 .08669 Mdot
.584 .08697 Mdot
.584 .08705 Mdot
.584 .0871 Mdot
.584 .08758 Mdot
.584 .08779 Mdot
.584 .08802 Mdot
.584 .08822 Mdot
.584 .08859 Mdot
.584 .08875 Mdot
.584 .08893 Mdot
.584 .08898 Mdot
.584 .08912 Mdot
.584 .08914 Mdot
.584 .08922 Mdot
.584 .08986 Mdot
.584 .08995 Mdot
.584 .09029 Mdot
.584 .09041 Mdot
.584 .09052 Mdot
.584 .09073 Mdot
.584 .09096 Mdot
.584 .091 Mdot
.584 .09117 Mdot
.584 .09169 Mdot
.584 .09198 Mdot
.584 .09218 Mdot
.584 .09267 Mdot
.584 .09283 Mdot
.584 .09289 Mdot
.584 .09296 Mdot
.584 .09317 Mdot
.584 .0938 Mdot
.584 .09422 Mdot
.584 .09434 Mdot
.584 .09444 Mdot
.584 .0946 Mdot
.584 .09469 Mdot
.584 .0952 Mdot
.584 .09542 Mdot
.584 .09626 Mdot
.584 .09695 Mdot
.584 .09718 Mdot
.584 .09723 Mdot
.584 .09725 Mdot
.584 .09741 Mdot
.584 .09742 Mdot
.584 .09763 Mdot
.584 .09766 Mdot
.584 .09784 Mdot
.584 .09793 Mdot
.584 .09806 Mdot
.584 .09816 Mdot
.584 .09842 Mdot
.584 .09878 Mdot
.584 .0991 Mdot
.584 .0992 Mdot
.584 .09926 Mdot
.584 .09982 Mdot
.584 .10007 Mdot
.584 .10034 Mdot
.584 .10057 Mdot
.584 .101 Mdot
.584 .10118 Mdot
.584 .10139 Mdot
.584 .10146 Mdot
.584 .10162 Mdot
.584 .10164 Mdot
.584 .10173 Mdot
.584 .10249 Mdot
.584 .10259 Mdot
.584 .10298 Mdot
.584 .10313 Mdot
.584 .10326 Mdot
.584 .1035 Mdot
.584 .10377 Mdot
.584 .10382 Mdot
.584 .10401 Mdot
.584 .10462 Mdot
.584 .10496 Mdot
.584 .10519 Mdot
.584 .10577 Mdot
.584 .10595 Mdot
.584 .10603 Mdot
.584 .1061 Mdot
.584 .10635 Mdot
.584 .10709 Mdot
.584 .10757 Mdot
.584 .10772 Mdot
.584 .10783 Mdot
.584 .10802 Mdot
.584 .10813 Mdot
.584 .10872 Mdot
.584 .10898 Mdot
.584 .10996 Mdot
.584 .11077 Mdot
.584 .11104 Mdot
.584 .1111 Mdot
.584 .11112 Mdot
.584 .1113 Mdot
.584 .11131 Mdot
.584 .11156 Mdot
.584 .11159 Mdot
.584 .1118 Mdot
.584 .11191 Mdot
.584 .11207 Mdot
.584 .11217 Mdot
.584 .11249 Mdot
.584 .11291 Mdot
.584 .11328 Mdot
.584 .1134 Mdot
.584 .11347 Mdot
.584 .11412 Mdot
.584 .11441 Mdot
.584 .11472 Mdot
.584 .115 Mdot
.584 .1155 Mdot
.584 .11571 Mdot
.584 .11595 Mdot
.584 .11603 Mdot
.584 .11621 Mdot
.584 .11625 Mdot
.584 .11635 Mdot
.584 .11723 Mdot
.584 .11735 Mdot
.584 .11781 Mdot
.584 .11798 Mdot
.584 .11814 Mdot
.584 .11841 Mdot
.584 .11874 Mdot
.584 .11879 Mdot
.584 .11901 Mdot
.584 .11972 Mdot
.584 .12012 Mdot
.584 .1204 Mdot
.584 .12107 Mdot
.584 .12128 Mdot
.584 .12137 Mdot
.584 .12146 Mdot
.584 .12175 Mdot
.584 .12261 Mdot
.584 .12317 Mdot
.584 .12334 Mdot
.584 .12348 Mdot
.584 .12369 Mdot
.584 .12383 Mdot
.584 .12452 Mdot
.584 .12481 Mdot
.584 .12596 Mdot
.584 .12691 Mdot
.584 .12722 Mdot
.584 .12729 Mdot
.584 .12732 Mdot
.584 .12753 Mdot
.584 .12754 Mdot
.584 .12784 Mdot
.584 .12787 Mdot
.584 .12811 Mdot
.584 .12824 Mdot
.584 .12842 Mdot
.584 .12855 Mdot
.584 .12891 Mdot
.584 .1294 Mdot
.584 .12984 Mdot
.584 .12998 Mdot
.584 .13006 Mdot
.584 .13082 Mdot
.584 .13116 Mdot
.584 .13152 Mdot
.584 .13184 Mdot
.584 .13243 Mdot
.584 .13268 Mdot
.584 .13296 Mdot
.584 .13305 Mdot
.584 .13327 Mdot
.584 .1333 Mdot
.584 .13343 Mdot
.584 .13446 Mdot
.584 .1346 Mdot
.584 .13513 Mdot
.584 .13533 Mdot
.584 .13551 Mdot
.584 .13583 Mdot
.584 .13621 Mdot
.584 .13627 Mdot
.584 .13654 Mdot
.584 .13736 Mdot
.584 .13783 Mdot
.584 .13815 Mdot
.584 .13893 Mdot
.584 .13918 Mdot
.584 .13929 Mdot
.584 .13939 Mdot
.584 .13973 Mdot
.584 .14073 Mdot
.584 .1414 Mdot
.584 .14159 Mdot
.584 .14175 Mdot
.584 .142 Mdot
.584 .14216 Mdot
.584 .14296 Mdot
.584 .14331 Mdot
.584 .14465 Mdot
.584 .14576 Mdot
.584 .14612 Mdot
.584 .1462 Mdot
.584 .14623 Mdot
.584 .14648 Mdot
.584 .14649 Mdot
.584 .14684 Mdot
.584 .14688 Mdot
.584 .14717 Mdot
.584 .14731 Mdot
.584 .14752 Mdot
.584 .14767 Mdot
.584 .1481 Mdot
.584 .14867 Mdot
.584 .14918 Mdot
.584 .14934 Mdot
.584 .14943 Mdot
.584 .15032 Mdot
.584 .15072 Mdot
.584 .15115 Mdot
.584 .15152 Mdot
.584 .1522 Mdot
.584 .1525 Mdot
.584 .15283 Mdot
.584 .15293 Mdot
.584 .15318 Mdot
.584 .15323 Mdot
.584 .15337 Mdot
.584 .15457 Mdot
.584 .15474 Mdot
.584 .15536 Mdot
.584 .15559 Mdot
.584 .1558 Mdot
.584 .15618 Mdot
.584 .15662 Mdot
.584 .15669 Mdot
.584 .157 Mdot
.584 .15797 Mdot
.584 .15851 Mdot
.584 .15889 Mdot
.584 .1598 Mdot
.584 .16009 Mdot
.584 .16021 Mdot
.584 .16033 Mdot
.584 .16073 Mdot
.584 .1619 Mdot
.584 .16268 Mdot
.584 .16291 Mdot
.584 .16309 Mdot
.584 .16339 Mdot
.584 .16357 Mdot
.584 .16451 Mdot
.584 .16491 Mdot
.584 .16648 Mdot
.584 .16777 Mdot
.584 .1682 Mdot
.584 .16829 Mdot
.584 .16833 Mdot
.584 .16862 Mdot
.584 .16863 Mdot
.584 .16904 Mdot
.584 .16908 Mdot
.584 .16942 Mdot
.584 .16958 Mdot
.584 .16984 Mdot
.584 .17001 Mdot
.584 .17051 Mdot
.584 .17118 Mdot
.584 .17177 Mdot
.584 .17196 Mdot
.584 .17207 Mdot
.584 .1731 Mdot
.584 .17357 Mdot
.584 .17407 Mdot
.584 .1745 Mdot
.584 .1753 Mdot
.584 .17564 Mdot
.584 .17603 Mdot
.584 .17616 Mdot
.584 .17645 Mdot
.584 .1765 Mdot
.584 .17666 Mdot
.584 .17807 Mdot
.584 .17826 Mdot
.584 .17899 Mdot
.584 .17926 Mdot
.584 .17951 Mdot
.584 .17995 Mdot
.584 .18046 Mdot
.584 .18054 Mdot
.584 .1809 Mdot
.584 .18203 Mdot
.584 .18267 Mdot
.584 .18311 Mdot
.584 .18418 Mdot
.584 .18451 Mdot
.584 .18466 Mdot
.584 .1848 Mdot
.584 .18526 Mdot
.584 .18663 Mdot
.584 .18754 Mdot
.584 .1878 Mdot
.584 .18802 Mdot
.584 .18836 Mdot
.584 .18857 Mdot
.584 .18967 Mdot
.584 .19015 Mdot
.584 .19198 Mdot
.584 .19348 Mdot
.584 .19399 Mdot
.584 .19409 Mdot
.584 .19414 Mdot
.584 .19447 Mdot
.584 .19449 Mdot
.584 .19496 Mdot
.584 .19501 Mdot
.584 .19541 Mdot
.584 .1956 Mdot
.584 .1959 Mdot
.584 .1961 Mdot
.584 .19668 Mdot
.584 .19746 Mdot
.584 .19816 Mdot
.584 .19838 Mdot
.584 .1985 Mdot
.584 .19971 Mdot
.584 .20026 Mdot
.584 .20084 Mdot
.584 .20135 Mdot
.584 .20228 Mdot
.584 .20268 Mdot
.584 .20313 Mdot
.584 .20328 Mdot
.584 .20362 Mdot
.584 .20367 Mdot
.584 .20387 Mdot
.584 .20551 Mdot
.584 .20574 Mdot
.584 .20659 Mdot
.584 .20691 Mdot
.584 .20719 Mdot
.584 .20771 Mdot
.584 .20831 Mdot
.584 .2084 Mdot
.584 .20882 Mdot
.584 .21014 Mdot
.584 .21089 Mdot
.584 .2114 Mdot
.584 .21265 Mdot
.584 .21304 Mdot
.584 .21321 Mdot
.584 .21337 Mdot
.584 .21391 Mdot
.584 .21551 Mdot
.584 .21657 Mdot
.584 .21688 Mdot
.584 .21713 Mdot
.584 .21754 Mdot
.584 .21778 Mdot
.584 .21907 Mdot
.584 .21962 Mdot
.584 .22176 Mdot
.584 .22352 Mdot
.584 .2241 Mdot
.584 .22423 Mdot
.584 .22428 Mdot
.584 .22467 Mdot
.584 .22469 Mdot
.584 .22524 Mdot
.584 .2253 Mdot
.584 .22576 Mdot
.584 .22599 Mdot
.584 .22633 Mdot
.584 .22657 Mdot
.584 .22725 Mdot
.584 .22816 Mdot
.584 .22898 Mdot
.584 .22923 Mdot
.584 .22938 Mdot
.584 .23079 Mdot
.584 .23143 Mdot
.584 .23211 Mdot
.584 .2327 Mdot
.584 .23379 Mdot
.584 .23426 Mdot
.584 .23479 Mdot
.584 .23496 Mdot
.584 .23535 Mdot
.584 .23542 Mdot
.584 .23565 Mdot
.584 .23756 Mdot
.584 .23783 Mdot
.584 .23882 Mdot
.584 .23919 Mdot
.584 .23953 Mdot
.584 .24013 Mdot
.584 .24083 Mdot
.584 .24094 Mdot
.584 .24144 Mdot
.584 .24298 Mdot
.584 .24385 Mdot
.584 .24444 Mdot
.584 .2459 Mdot
.584 .24636 Mdot
.584 .24656 Mdot
.584 .24674 Mdot
.584 .24738 Mdot
.584 .24925 Mdot
.584 .25048 Mdot
.584 .25085 Mdot
.584 .25114 Mdot
.584 .25161 Mdot
.584 .2519 Mdot
.584 .2534 Mdot
.584 .25404 Mdot
.584 .25654 Mdot
.584 .2586 Mdot
.584 .25928 Mdot
.584 .25942 Mdot
.584 .25948 Mdot
.584 .25995 Mdot
.584 .25996 Mdot
.584 .26061 Mdot
.584 .26068 Mdot
.584 .26122 Mdot
.584 .26149 Mdot
.584 .26189 Mdot
.584 .26216 Mdot
.584 .26296 Mdot
.584 .26402 Mdot
.584 .26497 Mdot
.584 .26527 Mdot
.584 .26544 Mdot
.584 .26709 Mdot
.584 .26784 Mdot
.584 .26863 Mdot
.584 .26932 Mdot
.584 .2706 Mdot
.584 .27114 Mdot
.584 .27176 Mdot
.584 .27196 Mdot
.584 .27242 Mdot
.584 .2725 Mdot
.584 .27277 Mdot
.584 .275 Mdot
.584 .27531 Mdot
.584 .27647 Mdot
.584 .27691 Mdot
.584 .2773 Mdot
.584 .278 Mdot
.584 .27882 Mdot
.584 .27895 Mdot
.584 .27952 Mdot
.584 .28132 Mdot
.584 .28234 Mdot
.584 .28303 Mdot
.584 .28474 Mdot
.584 .28527 Mdot
.584 .28551 Mdot
.584 .28573 Mdot
.584 .28646 Mdot
.584 .28865 Mdot
.584 .29009 Mdot
.584 .29052 Mdot
.584 .29086 Mdot
.584 .29141 Mdot
.584 .29174 Mdot
.584 .2935 Mdot
.584 .29425 Mdot
.584 .29717 Mdot
.584 .29957 Mdot
.584 .30037 Mdot
.584 .30053 Mdot
.584 .30061 Mdot
.584 .30114 Mdot
.584 .30117 Mdot
.584 .30192 Mdot
.584 .30201 Mdot
.584 .30263 Mdot
.584 .30294 Mdot
.584 .30341 Mdot
.584 .30373 Mdot
.584 .30466 Mdot
.584 .30591 Mdot
.584 .30702 Mdot
.584 .30736 Mdot
.584 .30756 Mdot
.584 .30949 Mdot
.584 .31036 Mdot
.584 .31129 Mdot
.584 .3121 Mdot
.584 .31359 Mdot
.584 .31422 Mdot
.584 .31494 Mdot
.584 .31517 Mdot
.584 .31571 Mdot
.584 .31581 Mdot
.584 .31873 Mdot
.584 .31909 Mdot
.584 .32045 Mdot
.584 .32096 Mdot
.584 .32141 Mdot
.584 .32223 Mdot
.584 .32319 Mdot
.584 .32334 Mdot
.584 .32401 Mdot
.584 .32611 Mdot
.584 .3273 Mdot
.584 .32811 Mdot
.584 .3301 Mdot
.584 .33072 Mdot
.584 .331 Mdot
.584 .33126 Mdot
.584 .33212 Mdot
.584 .33467 Mdot
.584 .33635 Mdot
.584 .33685 Mdot
.584 .33725 Mdot
.584 .33789 Mdot
.584 .33828 Mdot
.584 .34033 Mdot
.584 .34121 Mdot
.584 .34462 Mdot
.584 .34742 Mdot
.584 .34836 Mdot
.584 .34855 Mdot
.584 .34864 Mdot
.584 .34926 Mdot
.584 .34929 Mdot
.584 .35017 Mdot
.584 .35027 Mdot
.584 .351 Mdot
.584 .35137 Mdot
.584 .35191 Mdot
.584 .35228 Mdot
.584 .35337 Mdot
.584 .35483 Mdot
.584 .35612 Mdot
.584 .35653 Mdot
.584 .35676 Mdot
.584 .35901 Mdot
.584 .36003 Mdot
.586 .0154 Mdot
.586 .01552 Mdot
.586 .01559 Mdot
.586 .01566 Mdot
.586 .01574 Mdot
.586 .01582 Mdot
.586 .01592 Mdot
.586 .01601 Mdot
.586 .01613 Mdot
.586 .01624 Mdot
.586 .01637 Mdot
.586 .0165 Mdot
.586 .01666 Mdot
.586 .01681 Mdot
.586 .01699 Mdot
.586 .01717 Mdot
.586 .01738 Mdot
.586 .01759 Mdot
.586 .01784 Mdot
.586 .01808 Mdot
.586 .01817 Mdot
.586 .0182 Mdot
.586 .01831 Mdot
.586 .01838 Mdot
.586 .01866 Mdot
.586 .01876 Mdot
.586 .01879 Mdot
.586 .01893 Mdot
.586 .01901 Mdot
.586 .01934 Mdot
.586 .01946 Mdot
.586 .0195 Mdot
.586 .01966 Mdot
.586 .01975 Mdot
.586 .02013 Mdot
.586 .02026 Mdot
.586 .02027 Mdot
.586 .02032 Mdot
.586 .02051 Mdot
.586 .02062 Mdot
.586 .02107 Mdot
.586 .02121 Mdot
.586 .02123 Mdot
.586 .02128 Mdot
.586 .02134 Mdot
.586 .02151 Mdot
.586 .02163 Mdot
.586 .02216 Mdot
.586 .02233 Mdot
.586 .02235 Mdot
.586 .02241 Mdot
.586 .02247 Mdot
.586 .02267 Mdot
.586 .02282 Mdot
.586 .02344 Mdot
.586 .02344 Mdot
.586 .02364 Mdot
.586 .02366 Mdot
.586 .02374 Mdot
.586 .02381 Mdot
.586 .02404 Mdot
.586 .02422 Mdot
.586 .02467 Mdot
.586 .02494 Mdot
.586 .02494 Mdot
.586 .02517 Mdot
.586 .0252 Mdot
.586 .02529 Mdot
.586 .02537 Mdot
.586 .02565 Mdot
.586 .02585 Mdot
.586 .02638 Mdot
.586 .02655 Mdot
.586 .0267 Mdot
.586 .0267 Mdot
.586 .0268 Mdot
.586 .02681 Mdot
.586 .02697 Mdot
.586 .027 Mdot
.586 .02711 Mdot
.586 .02721 Mdot
.586 .02721 Mdot
.586 .02753 Mdot
.586 .02777 Mdot
.586 .02799 Mdot
.586 .02839 Mdot
.586 .02858 Mdot
.586 .02876 Mdot
.586 .02876 Mdot
.586 .02888 Mdot
.586 .0289 Mdot
.586 .02908 Mdot
.586 .02911 Mdot
.586 .02924 Mdot
.586 .02935 Mdot
.586 .02936 Mdot
.586 .02973 Mdot
.586 .03001 Mdot
.586 .03027 Mdot
.586 .03074 Mdot
.586 .03097 Mdot
.586 .03117 Mdot
.586 .03118 Mdot
.586 .03132 Mdot
.586 .03133 Mdot
.586 .03141 Mdot
.586 .03155 Mdot
.586 .03159 Mdot
.586 .03174 Mdot
.586 .03187 Mdot
.586 .03187 Mdot
.586 .03231 Mdot
.586 .03264 Mdot
.586 .03294 Mdot
.586 .03335 Mdot
.586 .0335 Mdot
.586 .03365 Mdot
.586 .03376 Mdot
.586 .03385 Mdot
.586 .034 Mdot
.586 .03401 Mdot
.586 .03406 Mdot
.586 .03418 Mdot
.586 .03419 Mdot
.586 .03428 Mdot
.586 .03445 Mdot
.586 .03449 Mdot
.586 .03466 Mdot
.586 .03482 Mdot
.586 .03482 Mdot
.586 .03534 Mdot
.586 .03572 Mdot
.586 .03608 Mdot
.586 .03655 Mdot
.586 .03673 Mdot
.586 .0369 Mdot
.586 .03704 Mdot
.586 .03714 Mdot
.586 .03732 Mdot
.586 .03732 Mdot
.586 .03738 Mdot
.586 .03752 Mdot
.586 .03754 Mdot
.586 .03765 Mdot
.586 .03769 Mdot
.586 .03784 Mdot
.586 .0379 Mdot
.586 .0381 Mdot
.586 .03811 Mdot
.586 .03828 Mdot
.586 .03828 Mdot
.586 .03889 Mdot
.586 .03934 Mdot
.586 .03975 Mdot
.586 .04004 Mdot
.586 .04031 Mdot
.586 .04051 Mdot
.586 .04072 Mdot
.586 .04087 Mdot
.586 .04099 Mdot
.586 .04121 Mdot
.586 .04121 Mdot
.586 .04128 Mdot
.586 .04145 Mdot
.586 .04147 Mdot
.586 .04159 Mdot
.586 .04164 Mdot
.586 .04182 Mdot
.586 .04188 Mdot
.586 .04212 Mdot
.586 .04213 Mdot
.586 .04233 Mdot
.586 .04234 Mdot
.586 .04302 Mdot
.586 .04305 Mdot
.586 .04311 Mdot
.586 .04356 Mdot
.586 .04357 Mdot
.586 .04406 Mdot
.586 .0443 Mdot
.586 .0443 Mdot
.586 .0444 Mdot
.586 .04471 Mdot
.586 .04495 Mdot
.586 .04519 Mdot
.586 .04537 Mdot
.586 .04551 Mdot
.586 .04577 Mdot
.586 .04577 Mdot
.586 .04585 Mdot
.586 .04604 Mdot
.586 .04607 Mdot
.586 .04618 Mdot
.586 .04621 Mdot
.586 .04628 Mdot
.586 .04648 Mdot
.586 .04656 Mdot
.586 .04683 Mdot
.586 .04685 Mdot
.586 .04708 Mdot
.586 .04709 Mdot
.586 .04728 Mdot
.586 .04788 Mdot
.586 .04792 Mdot
.586 .04799 Mdot
.586 .04831 Mdot
.586 .04852 Mdot
.586 .04854 Mdot
.586 .04911 Mdot
.586 .04938 Mdot
.586 .04939 Mdot
.586 .0495 Mdot
.586 .04978 Mdot
.586 .04987 Mdot
.586 .05015 Mdot
.586 .05043 Mdot
.586 .05065 Mdot
.586 .05069 Mdot
.586 .05081 Mdot
.586 .05111 Mdot
.586 .05111 Mdot
.586 .05121 Mdot
.586 .05133 Mdot
.586 .05143 Mdot
.586 .05146 Mdot
.586 .05159 Mdot
.586 .05163 Mdot
.586 .0517 Mdot
.586 .05195 Mdot
.586 .05203 Mdot
.586 .05235 Mdot
.586 .05237 Mdot
.586 .05265 Mdot
.586 .05266 Mdot
.586 .05288 Mdot
.586 .05322 Mdot
.586 .05359 Mdot
.586 .05363 Mdot
.586 .05372 Mdot
.586 .05409 Mdot
.586 .0543 Mdot
.586 .05433 Mdot
.586 .05435 Mdot
.586 .05437 Mdot
.586 .05502 Mdot
.586 .05535 Mdot
.586 .05536 Mdot
.586 .0554 Mdot
.586 .05548 Mdot
.586 .05581 Mdot
.586 .05592 Mdot
.586 .05625 Mdot
.586 .05657 Mdot
.586 .05658 Mdot
.586 .05669 Mdot
.586 .05683 Mdot
.586 .05687 Mdot
.586 .05702 Mdot
.586 .05737 Mdot
.586 .05737 Mdot
.586 .05748 Mdot
.586 .05763 Mdot
.586 .05775 Mdot
.586 .05779 Mdot
.586 .05793 Mdot
.586 .05798 Mdot
.586 .05807 Mdot
.586 .05835 Mdot
.586 .05844 Mdot
.586 .05845 Mdot
.586 .05883 Mdot
.586 .05885 Mdot
.586 .05918 Mdot
.586 .05918 Mdot
.586 .05944 Mdot
.586 .05985 Mdot
.586 .06 Mdot
.586 .06028 Mdot
.586 .06033 Mdot
.586 .06043 Mdot
.586 .06086 Mdot
.586 .06111 Mdot
.586 .06114 Mdot
.586 .06117 Mdot
.586 .0612 Mdot
.586 .06166 Mdot
.586 .06171 Mdot
.586 .06196 Mdot
.586 .06233 Mdot
.586 .06235 Mdot
.586 .0624 Mdot
.586 .0625 Mdot
.586 .06274 Mdot
.586 .06288 Mdot
.586 .06301 Mdot
.586 .06339 Mdot
.586 .06377 Mdot
.586 .06378 Mdot
.586 .06391 Mdot
.586 .06406 Mdot
.586 .06407 Mdot
.586 .06413 Mdot
.586 .06429 Mdot
.586 .0647 Mdot
.586 .06471 Mdot
.586 .06484 Mdot
.586 .06501 Mdot
.586 .06515 Mdot
.586 .06516 Mdot
.586 .06519 Mdot
.586 .06526 Mdot
.586 .06536 Mdot
.586 .06542 Mdot
.586 .06552 Mdot
.586 .06552 Mdot
.586 .06585 Mdot
.586 .06596 Mdot
.586 .06597 Mdot
.586 .06602 Mdot
.586 .06641 Mdot
.586 .06644 Mdot
.586 .06683 Mdot
.586 .06683 Mdot
.586 .06685 Mdot
.586 .06714 Mdot
.586 .0673 Mdot
.586 .06761 Mdot
.586 .06779 Mdot
.586 .06807 Mdot
.586 .06811 Mdot
.586 .06811 Mdot
.586 .06817 Mdot
.586 .06829 Mdot
.586 .0688 Mdot
.586 .06909 Mdot
.586 .06913 Mdot
.586 .06916 Mdot
.586 .06919 Mdot
.586 .06973 Mdot
.586 .06979 Mdot
.586 .07008 Mdot
.586 .07053 Mdot
.586 .07054 Mdot
.586 .07061 Mdot
.586 .07072 Mdot
.586 .07072 Mdot
.586 .071 Mdot
.586 .07116 Mdot
.586 .07131 Mdot
.586 .07153 Mdot
.586 .07167 Mdot
.586 .07176 Mdot
.586 .07205 Mdot
.586 .07221 Mdot
.586 .07222 Mdot
.586 .07237 Mdot
.586 .07254 Mdot
.586 .07256 Mdot
.586 .07262 Mdot
.586 .07282 Mdot
.586 .0733 Mdot
.586 .07331 Mdot
.586 .07346 Mdot
.586 .07366 Mdot
.586 .07382 Mdot
.586 .07384 Mdot
.586 .07388 Mdot
.586 .07395 Mdot
.586 .07407 Mdot
.586 .07414 Mdot
.586 .07426 Mdot
.586 .07426 Mdot
.586 .07465 Mdot
.586 .07477 Mdot
.586 .07479 Mdot
.586 .07485 Mdot
.586 .07531 Mdot
.586 .07534 Mdot
.586 .07579 Mdot
.586 .07579 Mdot
.586 .07581 Mdot
.586 .07615 Mdot
.586 .07634 Mdot
.586 .07671 Mdot
.586 .07692 Mdot
.586 .07725 Mdot
.586 .0773 Mdot
.586 .0773 Mdot
.586 .07737 Mdot
.586 .0775 Mdot
.586 .0781 Mdot
.586 .07844 Mdot
.586 .07849 Mdot
.586 .07852 Mdot
.586 .07856 Mdot
.586 .0792 Mdot
.586 .07927 Mdot
.586 .07961 Mdot
.586 .08012 Mdot
.586 .08014 Mdot
.586 .08022 Mdot
.586 .08035 Mdot
.586 .08035 Mdot
.586 .08068 Mdot
.586 .08087 Mdot
.586 .08105 Mdot
.586 .0813 Mdot
.586 .08146 Mdot
.586 .08158 Mdot
.586 .08191 Mdot
.586 .08209 Mdot
.586 .08211 Mdot
.586 .08229 Mdot
.586 .08249 Mdot
.586 .08251 Mdot
.586 .08258 Mdot
.586 .08282 Mdot
.586 .08338 Mdot
.586 .08339 Mdot
.586 .08357 Mdot
.586 .0838 Mdot
.586 .08399 Mdot
.586 .08401 Mdot
.586 .08405 Mdot
.586 .08414 Mdot
.586 .08428 Mdot
.586 .08436 Mdot
.586 .0845 Mdot
.586 .0845 Mdot
.586 .08496 Mdot
.586 .0851 Mdot
.586 .08512 Mdot
.586 .08519 Mdot
.586 .08573 Mdot
.586 .08577 Mdot
.586 .08629 Mdot
.586 .0863 Mdot
.586 .08632 Mdot
.586 .08672 Mdot
.586 .08694 Mdot
.586 .08737 Mdot
.586 .08762 Mdot
.586 .08801 Mdot
.586 .08806 Mdot
.586 .08806 Mdot
.586 .08814 Mdot
.586 .0883 Mdot
.586 .089 Mdot
.586 .0894 Mdot
.586 .08946 Mdot
.586 .0895 Mdot
.586 .08954 Mdot
.586 .09029 Mdot
.586 .09037 Mdot
.586 .09077 Mdot
.586 .09138 Mdot
.586 .09139 Mdot
.586 .09149 Mdot
.586 .09164 Mdot
.586 .09164 Mdot
.586 .09202 Mdot
.586 .09225 Mdot
.586 .09246 Mdot
.586 .09276 Mdot
.586 .09294 Mdot
.586 .09308 Mdot
.586 .09346 Mdot
.586 .09368 Mdot
.586 .0937 Mdot
.586 .09391 Mdot
.586 .09415 Mdot
.586 .09417 Mdot
.586 .09426 Mdot
.586 .09453 Mdot
.586 .09519 Mdot
.586 .0952 Mdot
.586 .09541 Mdot
.586 .09568 Mdot
.586 .0959 Mdot
.586 .09592 Mdot
.586 .09598 Mdot
.586 .09608 Mdot
.586 .09625 Mdot
.586 .09634 Mdot
.586 .0965 Mdot
.586 .09651 Mdot
.586 .09704 Mdot
.586 .09721 Mdot
.586 .09723 Mdot
.586 .09731 Mdot
.586 .09794 Mdot
.586 .09799 Mdot
.586 .0986 Mdot
.586 .09861 Mdot
.586 .09864 Mdot
.586 .09911 Mdot
.586 .09936 Mdot
.586 .09987 Mdot
.586 .10016 Mdot
.586 .10061 Mdot
.586 .10067 Mdot
.586 .10068 Mdot
.586 .10077 Mdot
.586 .10096 Mdot
.586 .10178 Mdot
.586 .10224 Mdot
.586 .10231 Mdot
.586 .10236 Mdot
.586 .10241 Mdot
.586 .10328 Mdot
.586 .10338 Mdot
.586 .10385 Mdot
.586 .10456 Mdot
.586 .10458 Mdot
.586 .10469 Mdot
.586 .10487 Mdot
.586 .10487 Mdot
.586 .10532 Mdot
.586 .10558 Mdot
.586 .10583 Mdot
.586 .10618 Mdot
.586 .1064 Mdot
.586 .10655 Mdot
.586 .10701 Mdot
.586 .10726 Mdot
.586 .10728 Mdot
.586 .10753 Mdot
.586 .10781 Mdot
.586 .10784 Mdot
.586 .10794 Mdot
.586 .10826 Mdot
.586 .10903 Mdot
.586 .10904 Mdot
.586 .10929 Mdot
.586 .1096 Mdot
.586 .10987 Mdot
.586 .10989 Mdot
.586 .10995 Mdot
.586 .11008 Mdot
.586 .11027 Mdot
.586 .11038 Mdot
.586 .11057 Mdot
.586 .11058 Mdot
.586 .1112 Mdot
.586 .1114 Mdot
.586 .11143 Mdot
.586 .11152 Mdot
.586 .11226 Mdot
.586 .11231 Mdot
.586 .11303 Mdot
.586 .11304 Mdot
.586 .11307 Mdot
.586 .11362 Mdot
.586 .11392 Mdot
.586 .11451 Mdot
.586 .11486 Mdot
.586 .11539 Mdot
.586 .11546 Mdot
.586 .11546 Mdot
.586 .11557 Mdot
.586 .11579 Mdot
.586 .11675 Mdot
.586 .1173 Mdot
.586 .11738 Mdot
.586 .11744 Mdot
.586 .1175 Mdot
.586 .11852 Mdot
.586 .11864 Mdot
.586 .11918 Mdot
.586 .12001 Mdot
.586 .12004 Mdot
.586 .12017 Mdot
.586 .12037 Mdot
.586 .12038 Mdot
.586 .1209 Mdot
.586 .12121 Mdot
.586 .1215 Mdot
.586 .12191 Mdot
.586 .12217 Mdot
.586 .12235 Mdot
.586 .12288 Mdot
.586 .12318 Mdot
.586 .1232 Mdot
.586 .12349 Mdot
.586 .12382 Mdot
.586 .12386 Mdot
.586 .12397 Mdot
.586 .12435 Mdot
.586 .12525 Mdot
.586 .12527 Mdot
.586 .12555 Mdot
.586 .12592 Mdot
.586 .12623 Mdot
.586 .12626 Mdot
.586 .12634 Mdot
.586 .12648 Mdot
.586 .12671 Mdot
.586 .12684 Mdot
.586 .12705 Mdot
.586 .12706 Mdot
.586 .1278 Mdot
.586 .12802 Mdot
.586 .12806 Mdot
.586 .12817 Mdot
.586 .12903 Mdot
.586 .1291 Mdot
.586 .12994 Mdot
.586 .12995 Mdot
.586 .12999 Mdot
.586 .13063 Mdot
.586 .13099 Mdot
.586 .13168 Mdot
.586 .13209 Mdot
.586 .1327 Mdot
.586 .13279 Mdot
.586 .13279 Mdot
.586 .13292 Mdot
.586 .13318 Mdot
.586 .1343 Mdot
.586 .13494 Mdot
.586 .13504 Mdot
.586 .13511 Mdot
.586 .13518 Mdot
.586 .13637 Mdot
.586 .13651 Mdot
.586 .13715 Mdot
.586 .13813 Mdot
.586 .13816 Mdot
.586 .1383 Mdot
.586 .13855 Mdot
.586 .13855 Mdot
.586 .13917 Mdot
.586 .13953 Mdot
.586 .13987 Mdot
.586 .14035 Mdot
.586 .14065 Mdot
.586 .14086 Mdot
.586 .14149 Mdot
.586 .14184 Mdot
.586 .14187 Mdot
.586 .1422 Mdot
.586 .14259 Mdot
.586 .14263 Mdot
.586 .14277 Mdot
.586 .1432 Mdot
.586 .14426 Mdot
.586 .14428 Mdot
.586 .14462 Mdot
.586 .14505 Mdot
.586 .14542 Mdot
.586 .14545 Mdot
.586 .14553 Mdot
.586 .1457 Mdot
.586 .14597 Mdot
.586 .14612 Mdot
.586 .14638 Mdot
.586 .14639 Mdot
.586 .14725 Mdot
.586 .14751 Mdot
.586 .14756 Mdot
.586 .14768 Mdot
.586 .1487 Mdot
.586 .14877 Mdot
.586 .14976 Mdot
.586 .14977 Mdot
.586 .14982 Mdot
.586 .15057 Mdot
.586 .15099 Mdot
.586 .1518 Mdot
.586 .15227 Mdot
.586 .153 Mdot
.586 .1531 Mdot
.586 .1531 Mdot
.586 .15325 Mdot
.586 .15355 Mdot
.586 .15487 Mdot
.586 .15562 Mdot
.586 .15574 Mdot
.586 .15581 Mdot
.586 .15589 Mdot
.586 .1573 Mdot
.586 .15746 Mdot
.586 .1582 Mdot
.586 .15935 Mdot
.586 .15939 Mdot
.586 .15956 Mdot
.586 .15985 Mdot
.586 .15985 Mdot
.586 .16057 Mdot
.586 .161 Mdot
.586 .16139 Mdot
.586 .16196 Mdot
.586 .16231 Mdot
.586 .16256 Mdot
.586 .16329 Mdot
.586 .16371 Mdot
.586 .16374 Mdot
.586 .16413 Mdot
.586 .16458 Mdot
.586 .16463 Mdot
.586 .16479 Mdot
.586 .1653 Mdot
.586 .16655 Mdot
.586 .16657 Mdot
.586 .16696 Mdot
.586 .16747 Mdot
.586 .1679 Mdot
.586 .16793 Mdot
.586 .16803 Mdot
.586 .16823 Mdot
.586 .16855 Mdot
.586 .16872 Mdot
.586 .16902 Mdot
.586 .16904 Mdot
.586 .17004 Mdot
.586 .17036 Mdot
.586 .17041 Mdot
.586 .17055 Mdot
.586 .17174 Mdot
.586 .17183 Mdot
.586 .17299 Mdot
.586 .17301 Mdot
.586 .17306 Mdot
.586 .17394 Mdot
.586 .17443 Mdot
.586 .17538 Mdot
.586 .17593 Mdot
.586 .17678 Mdot
.586 .1769 Mdot
.586 .1769 Mdot
.586 .17708 Mdot
.586 .17743 Mdot
.586 .17898 Mdot
.586 .17986 Mdot
.586 .17999 Mdot
.586 .18008 Mdot
.586 .18018 Mdot
.586 .18182 Mdot
.586 .18201 Mdot
.586 .18288 Mdot
.586 .18423 Mdot
.586 .18427 Mdot
.586 .18447 Mdot
.586 .18481 Mdot
.586 .18481 Mdot
.586 .18566 Mdot
.586 .18616 Mdot
.586 .18662 Mdot
.586 .18729 Mdot
.586 .1877 Mdot
.586 .18799 Mdot
.586 .18885 Mdot
.586 .18933 Mdot
.586 .18937 Mdot
.586 .18983 Mdot
.586 .19036 Mdot
.586 .19041 Mdot
.586 .1912 Mdot
.586 .19266 Mdot
.586 .19268 Mdot
.586 .19315 Mdot
.586 .19374 Mdot
.586 .19424 Mdot
.586 .19429 Mdot
.586 .19441 Mdot
.586 .19463 Mdot
.586 .19501 Mdot
.586 .19521 Mdot
.586 .19556 Mdot
.586 .19558 Mdot
.586 .19676 Mdot
.586 .19713 Mdot
.586 .19719 Mdot
.586 .19736 Mdot
.586 .19875 Mdot
.586 .19885 Mdot
.586 .20022 Mdot
.586 .20023 Mdot
.586 .20029 Mdot
.586 .20132 Mdot
.586 .2019 Mdot
.586 .20301 Mdot
.586 .20366 Mdot
.586 .20466 Mdot
.586 .20479 Mdot
.586 .2048 Mdot
.586 .20501 Mdot
.586 .20542 Mdot
.586 .20723 Mdot
.586 .20826 Mdot
.586 .20842 Mdot
.586 .20853 Mdot
.586 .20864 Mdot
.586 .21056 Mdot
.586 .21078 Mdot
.586 .21181 Mdot
.586 .21339 Mdot
.586 .21344 Mdot
.586 .21367 Mdot
.586 .21406 Mdot
.586 .21407 Mdot
.586 .21506 Mdot
.586 .21565 Mdot
.586 .21619 Mdot
.586 .21697 Mdot
.586 .21745 Mdot
.586 .21779 Mdot
.586 .2188 Mdot
.586 .21937 Mdot
.586 .21941 Mdot
.586 .21995 Mdot
.586 .22057 Mdot
.586 .22063 Mdot
.586 .22156 Mdot
.586 .22327 Mdot
.586 .22329 Mdot
.586 .22384 Mdot
.586 .22454 Mdot
.586 .22512 Mdot
.586 .22517 Mdot
.586 .22531 Mdot
.586 .22558 Mdot
.586 .22602 Mdot
.586 .22626 Mdot
.586 .22667 Mdot
.586 .22669 Mdot
.586 .22807 Mdot
.586 .2285 Mdot
.586 .22857 Mdot
.586 .22877 Mdot
.586 .23041 Mdot
.586 .23052 Mdot
.586 .23212 Mdot
.586 .23214 Mdot
.586 .23221 Mdot
.586 .23342 Mdot
.586 .23409 Mdot
.586 .2354 Mdot
.586 .23616 Mdot
.586 .23733 Mdot
.586 .23749 Mdot
.586 .23749 Mdot
.586 .23774 Mdot
.586 .23822 Mdot
.586 .24035 Mdot
.586 .24155 Mdot
.586 .24174 Mdot
.586 .24186 Mdot
.586 .24199 Mdot
.586 .24425 Mdot
.586 .24451 Mdot
.586 .24571 Mdot
.586 .24756 Mdot
.586 .24762 Mdot
.586 .24789 Mdot
.586 .24835 Mdot
.586 .24836 Mdot
.586 .24952 Mdot
.586 .25021 Mdot
.586 .25085 Mdot
.586 .25176 Mdot
.586 .25232 Mdot
.586 .25272 Mdot
.586 .2539 Mdot
.586 .25457 Mdot
.586 .25461 Mdot
.586 .25525 Mdot
.586 .25598 Mdot
.586 .25605 Mdot
.586 .25714 Mdot
.586 .25811 Mdot
.586 .25914 Mdot
.586 .25917 Mdot
.586 .25981 Mdot
.586 .26063 Mdot
.586 .26131 Mdot
.586 .26137 Mdot
.586 .26154 Mdot
.586 .26185 Mdot
.586 .26236 Mdot
.586 .26264 Mdot
.586 .26312 Mdot
.586 .26315 Mdot
.586 .26476 Mdot
.586 .26527 Mdot
.586 .26536 Mdot
.586 .26559 Mdot
.586 .2675 Mdot
.586 .26764 Mdot
.586 .26952 Mdot
.586 .26954 Mdot
.586 .26962 Mdot
.586 .27104 Mdot
.586 .27182 Mdot
.586 .27335 Mdot
.586 .27425 Mdot
.586 .27562 Mdot
.586 .2758 Mdot
.586 .27581 Mdot
.586 .2761 Mdot
.586 .27666 Mdot
.586 .27916 Mdot
.586 .28057 Mdot
.586 .28079 Mdot
.586 .28093 Mdot
.586 .28108 Mdot
.586 .28373 Mdot
.586 .28403 Mdot
.586 .28544 Mdot
.586 .28761 Mdot
.586 .28767 Mdot
.586 .288 Mdot
.586 .28854 Mdot
.586 .28854 Mdot
.586 .28991 Mdot
.586 .29071 Mdot
.586 .29146 Mdot
.586 .29253 Mdot
.586 .29319 Mdot
.586 .29366 Mdot
.586 .29504 Mdot
.586 .29582 Mdot
.586 .29588 Mdot
.586 .29663 Mdot
.586 .29747 Mdot
.586 .29756 Mdot
.586 .29883 Mdot
.586 .29997 Mdot
.586 .30118 Mdot
.586 .30122 Mdot
.586 .30196 Mdot
.586 .30292 Mdot
.586 .30373 Mdot
.586 .3038 Mdot
.586 .30399 Mdot
.586 .30436 Mdot
.586 .30496 Mdot
.586 .30528 Mdot
.586 .30585 Mdot
.586 .30588 Mdot
.586 .30777 Mdot
.586 .30837 Mdot
.586 .30847 Mdot
.586 .30874 Mdot
.586 .31098 Mdot
.586 .31115 Mdot
.586 .31334 Mdot
.586 .31337 Mdot
.586 .31347 Mdot
.586 .31513 Mdot
.586 .31605 Mdot
.586 .31784 Mdot
.586 .31889 Mdot
.586 .32049 Mdot
.586 .32071 Mdot
.586 .32072 Mdot
.586 .32105 Mdot
.586 .32172 Mdot
.586 .32464 Mdot
.586 .3263 Mdot
.586 .32655 Mdot
.586 .32672 Mdot
.586 .3269 Mdot
.586 .33 Mdot
.586 .33036 Mdot
.586 .332 Mdot
.586 .33454 Mdot
.586 .33462 Mdot
.586 .335 Mdot
.586 .33564 Mdot
.586 .33564 Mdot
.586 .33724 Mdot
.586 .33818 Mdot
.586 .33906 Mdot
.586 .34031 Mdot
.586 .34109 Mdot
.586 .34164 Mdot
.586 .34325 Mdot
.586 .34417 Mdot
.586 .34424 Mdot
.586 .34511 Mdot
.586 .34611 Mdot
.586 .34621 Mdot
.586 .3477 Mdot
.586 .34904 Mdot
.586 .35045 Mdot
.586 .3505 Mdot
.586 .35137 Mdot
.586 .3525 Mdot
.586 .35344 Mdot
.586 .35352 Mdot
.586 .35374 Mdot
.586 .35417 Mdot
.586 .35488 Mdot
.586 .35526 Mdot
.586 .35592 Mdot
.586 .35596 Mdot
.586 .35818 Mdot
.586 .35887 Mdot
.586 .35899 Mdot
.586 .35931 Mdot
.588 .01597 Mdot
.588 .01619 Mdot
.588 .01645 Mdot
.588 .01676 Mdot
.588 .01712 Mdot
.588 .01754 Mdot
.588 .01767 Mdot
.588 .01804 Mdot
.588 .01819 Mdot
.588 .01849 Mdot
.588 .01862 Mdot
.588 .0188 Mdot
.588 .01915 Mdot
.588 .01931 Mdot
.588 .01952 Mdot
.588 .01993 Mdot
.588 .02012 Mdot
.588 .02036 Mdot
.588 .02037 Mdot
.588 .02085 Mdot
.588 .02107 Mdot
.588 .02136 Mdot
.588 .02136 Mdot
.588 .02193 Mdot
.588 .02218 Mdot
.588 .02225 Mdot
.588 .02253 Mdot
.588 .02253 Mdot
.588 .0232 Mdot
.588 .0235 Mdot
.588 .02357 Mdot
.588 .0239 Mdot
.588 .02391 Mdot
.588 .0247 Mdot
.588 .02504 Mdot
.588 .02513 Mdot
.588 .02552 Mdot
.588 .02553 Mdot
.588 .02631 Mdot
.588 .02646 Mdot
.588 .02686 Mdot
.588 .02696 Mdot
.588 .02742 Mdot
.588 .02743 Mdot
.588 .02765 Mdot
.588 .02835 Mdot
.588 .02852 Mdot
.588 .029 Mdot
.588 .02912 Mdot
.588 .02933 Mdot
.588 .02966 Mdot
.588 .02967 Mdot
.588 .02989 Mdot
.588 .02992 Mdot
.588 .03075 Mdot
.588 .03095 Mdot
.588 .03151 Mdot
.588 .03153 Mdot
.588 .03165 Mdot
.588 .0319 Mdot
.588 .03193 Mdot
.588 .03229 Mdot
.588 .0323 Mdot
.588 .03256 Mdot
.588 .03259 Mdot
.588 .0326 Mdot
.588 .03285 Mdot
.588 .03295 Mdot
.588 .03333 Mdot
.588 .03349 Mdot
.588 .03357 Mdot
.588 .03381 Mdot
.588 .03447 Mdot
.588 .03448 Mdot
.588 .03463 Mdot
.588 .03492 Mdot
.588 .03496 Mdot
.588 .03538 Mdot
.588 .03539 Mdot
.588 .03561 Mdot
.588 .03561 Mdot
.588 .0357 Mdot
.588 .03574 Mdot
.588 .03575 Mdot
.588 .03604 Mdot
.588 .03616 Mdot
.588 .0366 Mdot
.588 .03679 Mdot
.588 .03689 Mdot
.588 .037 Mdot
.588 .03717 Mdot
.588 .03795 Mdot
.588 .03796 Mdot
.588 .03814 Mdot
.588 .03848 Mdot
.588 .03852 Mdot
.588 .03898 Mdot
.588 .03902 Mdot
.588 .03903 Mdot
.588 .03928 Mdot
.588 .03928 Mdot
.588 .0394 Mdot
.588 .03944 Mdot
.588 .03945 Mdot
.588 .03979 Mdot
.588 .03993 Mdot
.588 .04045 Mdot
.588 .04068 Mdot
.588 .04079 Mdot
.588 .04092 Mdot
.588 .04098 Mdot
.588 .04112 Mdot
.588 .04126 Mdot
.588 .04167 Mdot
.588 .04204 Mdot
.588 .04205 Mdot
.588 .04209 Mdot
.588 .04226 Mdot
.588 .04266 Mdot
.588 .04271 Mdot
.588 .04325 Mdot
.588 .04329 Mdot
.588 .0433 Mdot
.588 .04331 Mdot
.588 .04361 Mdot
.588 .04361 Mdot
.588 .04374 Mdot
.588 .04379 Mdot
.588 .0438 Mdot
.588 .0442 Mdot
.588 .04437 Mdot
.588 .04498 Mdot
.588 .04525 Mdot
.588 .04538 Mdot
.588 .04553 Mdot
.588 .0456 Mdot
.588 .04577 Mdot
.588 .04593 Mdot
.588 .04641 Mdot
.588 .04679 Mdot
.588 .04684 Mdot
.588 .04687 Mdot
.588 .04691 Mdot
.588 .04692 Mdot
.588 .04711 Mdot
.588 .0474 Mdot
.588 .04758 Mdot
.588 .04764 Mdot
.588 .04827 Mdot
.588 .04832 Mdot
.588 .04834 Mdot
.588 .04834 Mdot
.588 .04869 Mdot
.588 .04869 Mdot
.588 .04881 Mdot
.588 .04885 Mdot
.588 .0489 Mdot
.588 .04892 Mdot
.588 .04922 Mdot
.588 .04939 Mdot
.588 .04941 Mdot
.588 .04957 Mdot
.588 .04959 Mdot
.588 .04963 Mdot
.588 .05031 Mdot
.588 .05062 Mdot
.588 .05078 Mdot
.588 .05096 Mdot
.588 .05104 Mdot
.588 .05124 Mdot
.588 .05143 Mdot
.588 .05199 Mdot
.588 .05243 Mdot
.588 .0525 Mdot
.588 .05252 Mdot
.588 .05257 Mdot
.588 .05259 Mdot
.588 .05281 Mdot
.588 .05281 Mdot
.588 .05316 Mdot
.588 .05337 Mdot
.588 .05344 Mdot
.588 .05361 Mdot
.588 .05403 Mdot
.588 .05417 Mdot
.588 .05424 Mdot
.588 .05425 Mdot
.588 .05426 Mdot
.588 .05467 Mdot
.588 .05481 Mdot
.588 .05486 Mdot
.588 .05492 Mdot
.588 .05494 Mdot
.588 .05498 Mdot
.588 .0553 Mdot
.588 .05542 Mdot
.588 .0555 Mdot
.588 .05551 Mdot
.588 .0557 Mdot
.588 .05573 Mdot
.588 .05578 Mdot
.588 .05604 Mdot
.588 .05619 Mdot
.588 .05658 Mdot
.588 .05665 Mdot
.588 .05694 Mdot
.588 .05713 Mdot
.588 .05733 Mdot
.588 .05743 Mdot
.588 .05766 Mdot
.588 .05789 Mdot
.588 .05855 Mdot
.588 .05907 Mdot
.588 .05915 Mdot
.588 .05918 Mdot
.588 .05919 Mdot
.588 .05924 Mdot
.588 .05926 Mdot
.588 .05951 Mdot
.588 .05951 Mdot
.588 .05968 Mdot
.588 .05992 Mdot
.588 .06017 Mdot
.588 .06025 Mdot
.588 .06045 Mdot
.588 .06087 Mdot
.588 .06089 Mdot
.588 .06095 Mdot
.588 .06112 Mdot
.588 .06119 Mdot
.588 .06121 Mdot
.588 .06122 Mdot
.588 .06161 Mdot
.588 .0617 Mdot
.588 .06175 Mdot
.588 .06187 Mdot
.588 .06192 Mdot
.588 .062 Mdot
.588 .06202 Mdot
.588 .06207 Mdot
.588 .06244 Mdot
.588 .06259 Mdot
.588 .06259 Mdot
.588 .06267 Mdot
.588 .06269 Mdot
.588 .06292 Mdot
.588 .06295 Mdot
.588 .063 Mdot
.588 .06331 Mdot
.588 .06349 Mdot
.588 .06362 Mdot
.588 .06385 Mdot
.588 .06395 Mdot
.588 .06403 Mdot
.588 .06432 Mdot
.588 .06438 Mdot
.588 .06459 Mdot
.588 .06484 Mdot
.588 .06495 Mdot
.588 .06522 Mdot
.588 .06549 Mdot
.588 .06626 Mdot
.588 .06682 Mdot
.588 .06687 Mdot
.588 .06697 Mdot
.588 .06701 Mdot
.588 .06702 Mdot
.588 .06707 Mdot
.588 .0671 Mdot
.588 .0674 Mdot
.588 .0674 Mdot
.588 .0676 Mdot
.588 .06788 Mdot
.588 .06817 Mdot
.588 .06821 Mdot
.588 .06827 Mdot
.588 .06833 Mdot
.588 .0685 Mdot
.588 .069 Mdot
.588 .06902 Mdot
.588 .06909 Mdot
.588 .06929 Mdot
.588 .06935 Mdot
.588 .06937 Mdot
.588 .0694 Mdot
.588 .0694 Mdot
.588 .06986 Mdot
.588 .06997 Mdot
.588 .07003 Mdot
.588 .07017 Mdot
.588 .07023 Mdot
.588 .07032 Mdot
.588 .07034 Mdot
.588 .07041 Mdot
.588 .07077 Mdot
.588 .07084 Mdot
.588 .07101 Mdot
.588 .07101 Mdot
.588 .07112 Mdot
.588 .07114 Mdot
.588 .07126 Mdot
.588 .0714 Mdot
.588 .07144 Mdot
.588 .0715 Mdot
.588 .07186 Mdot
.588 .07206 Mdot
.588 .07208 Mdot
.588 .07222 Mdot
.588 .07249 Mdot
.588 .07261 Mdot
.588 .07271 Mdot
.588 .07276 Mdot
.588 .07305 Mdot
.588 .07312 Mdot
.588 .07313 Mdot
.588 .07337 Mdot
.588 .07366 Mdot
.588 .07379 Mdot
.588 .07411 Mdot
.588 .07443 Mdot
.588 .07511 Mdot
.588 .07533 Mdot
.588 .07562 Mdot
.588 .07571 Mdot
.588 .07599 Mdot
.588 .07605 Mdot
.588 .07617 Mdot
.588 .07621 Mdot
.588 .07623 Mdot
.588 .07629 Mdot
.588 .07632 Mdot
.588 .07667 Mdot
.588 .07667 Mdot
.588 .07691 Mdot
.588 .07724 Mdot
.588 .07758 Mdot
.588 .07762 Mdot
.588 .07769 Mdot
.588 .07776 Mdot
.588 .07797 Mdot
.588 .07855 Mdot
.588 .07857 Mdot
.588 .07866 Mdot
.588 .07889 Mdot
.588 .07896 Mdot
.588 .07899 Mdot
.588 .07902 Mdot
.588 .07903 Mdot
.588 .07956 Mdot
.588 .0797 Mdot
.588 .07977 Mdot
.588 .07993 Mdot
.588 .08 Mdot
.588 .08011 Mdot
.588 .08013 Mdot
.588 .08021 Mdot
.588 .08064 Mdot
.588 .08072 Mdot
.588 .08092 Mdot
.588 .08092 Mdot
.588 .08104 Mdot
.588 .08107 Mdot
.588 .08121 Mdot
.588 .08138 Mdot
.588 .08142 Mdot
.588 .0815 Mdot
.588 .08192 Mdot
.588 .08215 Mdot
.588 .08217 Mdot
.588 .08234 Mdot
.588 .08266 Mdot
.588 .0828 Mdot
.588 .08292 Mdot
.588 .08298 Mdot
.588 .08331 Mdot
.588 .0834 Mdot
.588 .08341 Mdot
.588 .0837 Mdot
.588 .08403 Mdot
.588 .08419 Mdot
.588 .08456 Mdot
.588 .08494 Mdot
.588 .08574 Mdot
.588 .086 Mdot
.588 .08634 Mdot
.588 .08645 Mdot
.588 .08677 Mdot
.588 .08685 Mdot
.588 .08698 Mdot
.588 .08703 Mdot
.588 .08705 Mdot
.588 .08713 Mdot
.588 .08716 Mdot
.588 .08758 Mdot
.588 .08758 Mdot
.588 .08785 Mdot
.588 .08824 Mdot
.588 .08864 Mdot
.588 .08869 Mdot
.588 .08877 Mdot
.588 .08886 Mdot
.588 .0891 Mdot
.588 .08979 Mdot
.588 .08981 Mdot
.588 .08991 Mdot
.588 .09019 Mdot
.588 .09027 Mdot
.588 .0903 Mdot
.588 .09034 Mdot
.588 .09035 Mdot
.588 .09098 Mdot
.588 .09113 Mdot
.588 .09122 Mdot
.588 .09141 Mdot
.588 .09149 Mdot
.588 .09161 Mdot
.588 .09165 Mdot
.588 .09174 Mdot
.588 .09224 Mdot
.588 .09234 Mdot
.588 .09257 Mdot
.588 .09257 Mdot
.588 .09272 Mdot
.588 .09274 Mdot
.588 .09291 Mdot
.588 .09311 Mdot
.588 .09316 Mdot
.588 .09325 Mdot
.588 .09375 Mdot
.588 .09402 Mdot
.588 .09404 Mdot
.588 .09425 Mdot
.588 .09462 Mdot
.588 .09478 Mdot
.588 .09492 Mdot
.588 .09499 Mdot
.588 .09538 Mdot
.588 .09548 Mdot
.588 .0955 Mdot
.588 .09584 Mdot
.588 .09623 Mdot
.588 .09642 Mdot
.588 .09686 Mdot
.588 .09729 Mdot
.588 .09824 Mdot
.588 .09855 Mdot
.588 .09894 Mdot
.588 .09907 Mdot
.588 .09945 Mdot
.588 .09955 Mdot
.588 .0997 Mdot
.588 .09976 Mdot
.588 .09978 Mdot
.588 .09987 Mdot
.588 .09991 Mdot
.588 .1004 Mdot
.588 .1004 Mdot
.588 .10072 Mdot
.588 .10118 Mdot
.588 .10165 Mdot
.588 .10171 Mdot
.588 .10181 Mdot
.588 .10191 Mdot
.588 .10219 Mdot
.588 .103 Mdot
.588 .10303 Mdot
.588 .10314 Mdot
.588 .10347 Mdot
.588 .10357 Mdot
.588 .10361 Mdot
.588 .10365 Mdot
.588 .10366 Mdot
.588 .1044 Mdot
.588 .10458 Mdot
.588 .10468 Mdot
.588 .1049 Mdot
.588 .10501 Mdot
.588 .10515 Mdot
.588 .10518 Mdot
.588 .10529 Mdot
.588 .10588 Mdot
.588 .106 Mdot
.588 .10627 Mdot
.588 .10628 Mdot
.588 .10644 Mdot
.588 .10648 Mdot
.588 .10667 Mdot
.588 .10691 Mdot
.588 .10696 Mdot
.588 .10707 Mdot
.588 .10765 Mdot
.588 .10798 Mdot
.588 .10801 Mdot
.588 .10824 Mdot
.588 .10869 Mdot
.588 .10887 Mdot
.588 .10904 Mdot
.588 .10912 Mdot
.588 .10958 Mdot
.588 .1097 Mdot
.588 .10972 Mdot
.588 .11011 Mdot
.588 .11058 Mdot
.588 .1108 Mdot
.588 .11131 Mdot
.588 .11183 Mdot
.588 .11294 Mdot
.588 .1133 Mdot
.588 .11376 Mdot
.588 .11392 Mdot
.588 .11436 Mdot
.588 .11448 Mdot
.588 .11466 Mdot
.588 .11473 Mdot
.588 .11475 Mdot
.588 .11486 Mdot
.588 .1149 Mdot
.588 .11548 Mdot
.588 .11548 Mdot
.588 .11586 Mdot
.588 .1164 Mdot
.588 .11695 Mdot
.588 .11703 Mdot
.588 .11714 Mdot
.588 .11725 Mdot
.588 .11758 Mdot
.588 .11854 Mdot
.588 .11857 Mdot
.588 .11871 Mdot
.588 .11909 Mdot
.588 .1192 Mdot
.588 .11925 Mdot
.588 .1193 Mdot
.588 .11931 Mdot
.588 .12018 Mdot
.588 .1204 Mdot
.588 .12052 Mdot
.588 .12078 Mdot
.588 .1209 Mdot
.588 .12107 Mdot
.588 .12111 Mdot
.588 .12123 Mdot
.588 .12193 Mdot
.588 .12206 Mdot
.588 .12239 Mdot
.588 .12239 Mdot
.588 .12259 Mdot
.588 .12263 Mdot
.588 .12286 Mdot
.588 .12314 Mdot
.588 .1232 Mdot
.588 .12333 Mdot
.588 .12401 Mdot
.588 .12439 Mdot
.588 .12442 Mdot
.588 .1247 Mdot
.588 .12523 Mdot
.588 .12545 Mdot
.588 .12564 Mdot
.588 .12574 Mdot
.588 .12628 Mdot
.588 .12642 Mdot
.588 .12644 Mdot
.588 .1269 Mdot
.588 .12745 Mdot
.588 .12771 Mdot
.588 .12832 Mdot
.588 .12892 Mdot
.588 .13023 Mdot
.588 .13066 Mdot
.588 .1312 Mdot
.588 .13138 Mdot
.588 .1319 Mdot
.588 .13203 Mdot
.588 .13225 Mdot
.588 .13233 Mdot
.588 .13236 Mdot
.588 .13248 Mdot
.588 .13253 Mdot
.588 .13321 Mdot
.588 .13322 Mdot
.588 .13366 Mdot
.588 .1343 Mdot
.588 .13494 Mdot
.588 .13503 Mdot
.588 .13516 Mdot
.588 .1353 Mdot
.588 .13569 Mdot
.588 .13681 Mdot
.588 .13685 Mdot
.588 .13701 Mdot
.588 .13746 Mdot
.588 .13759 Mdot
.588 .13765 Mdot
.588 .1377 Mdot
.588 .13772 Mdot
.588 .13875 Mdot
.588 .139 Mdot
.588 .13914 Mdot
.588 .13944 Mdot
.588 .13959 Mdot
.588 .13978 Mdot
.588 .13983 Mdot
.588 .13998 Mdot
.588 .1408 Mdot
.588 .14096 Mdot
.588 .14134 Mdot
.588 .14134 Mdot
.588 .14157 Mdot
.588 .14162 Mdot
.588 .14189 Mdot
.588 .14222 Mdot
.588 .14229 Mdot
.588 .14244 Mdot
.588 .14325 Mdot
.588 .1437 Mdot
.588 .14373 Mdot
.588 .14406 Mdot
.588 .14468 Mdot
.588 .14493 Mdot
.588 .14516 Mdot
.588 .14528 Mdot
.588 .14591 Mdot
.588 .14608 Mdot
.588 .14611 Mdot
.588 .14665 Mdot
.588 .14729 Mdot
.588 .1476 Mdot
.588 .14831 Mdot
.588 .14902 Mdot
.588 .15056 Mdot
.588 .15106 Mdot
.588 .1517 Mdot
.588 .15191 Mdot
.588 .15253 Mdot
.588 .15268 Mdot
.588 .15293 Mdot
.588 .15303 Mdot
.588 .15307 Mdot
.588 .15321 Mdot
.588 .15327 Mdot
.588 .15407 Mdot
.588 .15407 Mdot
.588 .1546 Mdot
.588 .15535 Mdot
.588 .1561 Mdot
.588 .15621 Mdot
.588 .15636 Mdot
.588 .15652 Mdot
.588 .15698 Mdot
.588 .1583 Mdot
.588 .15835 Mdot
.588 .15853 Mdot
.588 .15906 Mdot
.588 .15922 Mdot
.588 .15929 Mdot
.588 .15935 Mdot
.588 .15937 Mdot
.588 .16058 Mdot
.588 .16088 Mdot
.588 .16104 Mdot
.588 .1614 Mdot
.588 .16156 Mdot
.588 .16179 Mdot
.588 .16185 Mdot
.588 .16203 Mdot
.588 .16299 Mdot
.588 .16317 Mdot
.588 .16362 Mdot
.588 .16363 Mdot
.588 .1639 Mdot
.588 .16396 Mdot
.588 .16427 Mdot
.588 .16466 Mdot
.588 .16475 Mdot
.588 .16492 Mdot
.588 .16587 Mdot
.588 .1664 Mdot
.588 .16644 Mdot
.588 .16683 Mdot
.588 .16755 Mdot
.588 .16785 Mdot
.588 .16812 Mdot
.588 .16826 Mdot
.588 .16901 Mdot
.588 .1692 Mdot
.588 .16923 Mdot
.588 .16987 Mdot
.588 .17062 Mdot
.588 .17099 Mdot
.588 .17182 Mdot
.588 .17266 Mdot
.588 .17446 Mdot
.588 .17506 Mdot
.588 .17581 Mdot
.588 .17606 Mdot
.588 .17678 Mdot
.588 .17696 Mdot
.588 .17726 Mdot
.588 .17737 Mdot
.588 .17742 Mdot
.588 .17758 Mdot
.588 .17766 Mdot
.588 .1786 Mdot
.588 .1786 Mdot
.588 .17922 Mdot
.588 .1801 Mdot
.588 .18099 Mdot
.588 .18111 Mdot
.588 .18129 Mdot
.588 .18148 Mdot
.588 .18202 Mdot
.588 .18357 Mdot
.588 .18363 Mdot
.588 .18384 Mdot
.588 .18447 Mdot
.588 .18465 Mdot
.588 .18473 Mdot
.588 .18481 Mdot
.588 .18483 Mdot
.588 .18625 Mdot
.588 .1866 Mdot
.588 .18679 Mdot
.588 .18721 Mdot
.588 .18741 Mdot
.588 .18768 Mdot
.588 .18775 Mdot
.588 .18795 Mdot
.588 .18908 Mdot
.588 .1893 Mdot
.588 .18983 Mdot
.588 .18984 Mdot
.588 .19016 Mdot
.588 .19022 Mdot
.588 .19059 Mdot
.588 .19105 Mdot
.588 .19115 Mdot
.588 .19136 Mdot
.588 .19247 Mdot
.588 .19309 Mdot
.588 .19314 Mdot
.588 .1936 Mdot
.588 .19445 Mdot
.588 .1948 Mdot
.588 .19512 Mdot
.588 .19528 Mdot
.588 .19616 Mdot
.588 .19639 Mdot
.588 .19643 Mdot
.588 .19717 Mdot
.588 .19806 Mdot
.588 .19849 Mdot
.588 .19947 Mdot
.588 .20046 Mdot
.588 .20258 Mdot
.588 .20328 Mdot
.588 .20416 Mdot
.588 .20445 Mdot
.588 .20531 Mdot
.588 .20552 Mdot
.588 .20586 Mdot
.588 .206 Mdot
.588 .20605 Mdot
.588 .20625 Mdot
.588 .20633 Mdot
.588 .20744 Mdot
.588 .20744 Mdot
.588 .20817 Mdot
.588 .2092 Mdot
.588 .21025 Mdot
.588 .2104 Mdot
.588 .21061 Mdot
.588 .21083 Mdot
.588 .21147 Mdot
.588 .21329 Mdot
.588 .21336 Mdot
.588 .21361 Mdot
.588 .21435 Mdot
.588 .21456 Mdot
.588 .21466 Mdot
.588 .21474 Mdot
.588 .21477 Mdot
.588 .21644 Mdot
.588 .21685 Mdot
.588 .21707 Mdot
.588 .21757 Mdot
.588 .2178 Mdot
.588 .21812 Mdot
.588 .2182 Mdot
.588 .21844 Mdot
.588 .21977 Mdot
.588 .22003 Mdot
.588 .22065 Mdot
.588 .22066 Mdot
.588 .22103 Mdot
.588 .22111 Mdot
.588 .22155 Mdot
.588 .22209 Mdot
.588 .22221 Mdot
.588 .22245 Mdot
.588 .22376 Mdot
.588 .22449 Mdot
.588 .22455 Mdot
.588 .22508 Mdot
.588 .22583 Mdot
.588 .22608 Mdot
.588 .2265 Mdot
.588 .22687 Mdot
.588 .22706 Mdot
.588 .22809 Mdot
.588 .22836 Mdot
.588 .22841 Mdot
.588 .22929 Mdot
.588 .23033 Mdot
.588 .23084 Mdot
.588 .23199 Mdot
.588 .23315 Mdot
.588 .23564 Mdot
.588 .23647 Mdot
.588 .2375 Mdot
.588 .23785 Mdot
.588 .23885 Mdot
.588 .2391 Mdot
.588 .23951 Mdot
.588 .23966 Mdot
.588 .23973 Mdot
.588 .23996 Mdot
.588 .24006 Mdot
.588 .24136 Mdot
.588 .24136 Mdot
.588 .24222 Mdot
.588 .24343 Mdot
.588 .24467 Mdot
.588 .24484 Mdot
.588 .24509 Mdot
.588 .24535 Mdot
.588 .24609 Mdot
.588 .24823 Mdot
.588 .24832 Mdot
.588 .24862 Mdot
.588 .24948 Mdot
.588 .24973 Mdot
.588 .24985 Mdot
.588 .24995 Mdot
.588 .24998 Mdot
.588 .25194 Mdot
.588 .25243 Mdot
.588 .25269 Mdot
.588 .25328 Mdot
.588 .25355 Mdot
.588 .25392 Mdot
.588 .25402 Mdot
.588 .2543 Mdot
.588 .25586 Mdot
.588 .25617 Mdot
.588 .2569 Mdot
.588 .25691 Mdot
.588 .25735 Mdot
.588 .25744 Mdot
.588 .25795 Mdot
.588 .25858 Mdot
.588 .25873 Mdot
.588 .25901 Mdot
.588 .26055 Mdot
.588 .26141 Mdot
.588 .26148 Mdot
.588 .26211 Mdot
.588 .26298 Mdot
.588 .26328 Mdot
.588 .26377 Mdot
.588 .26421 Mdot
.588 .26443 Mdot
.588 .26565 Mdot
.588 .26596 Mdot
.588 .26602 Mdot
.588 .26705 Mdot
.588 .26828 Mdot
.588 .26887 Mdot
.588 .27023 Mdot
.588 .27159 Mdot
.588 .27453 Mdot
.588 .27549 Mdot
.588 .27671 Mdot
.588 .27712 Mdot
.588 .2783 Mdot
.588 .27859 Mdot
.588 .27907 Mdot
.588 .27925 Mdot
.588 .27933 Mdot
.588 .2796 Mdot
.588 .27972 Mdot
.588 .28125 Mdot
.588 .28125 Mdot
.588 .28226 Mdot
.588 .28369 Mdot
.588 .28514 Mdot
.588 .28534 Mdot
.588 .28563 Mdot
.588 .28594 Mdot
.588 .28682 Mdot
.588 .28933 Mdot
.588 .28943 Mdot
.588 .28978 Mdot
.588 .2908 Mdot
.588 .2911 Mdot
.588 .29123 Mdot
.588 .29135 Mdot
.588 .29139 Mdot
.588 .29369 Mdot
.588 .29427 Mdot
.588 .29457 Mdot
.588 .29526 Mdot
.588 .29558 Mdot
.588 .29602 Mdot
.588 .29614 Mdot
.588 .29647 Mdot
.588 .2983 Mdot
.588 .29866 Mdot
.588 .29952 Mdot
.588 .29953 Mdot
.588 .30005 Mdot
.588 .30016 Mdot
.588 .30076 Mdot
.588 .3015 Mdot
.588 .30167 Mdot
.588 .30201 Mdot
.588 .30382 Mdot
.588 .30482 Mdot
.588 .30491 Mdot
.588 .30565 Mdot
.588 .30668 Mdot
.588 .30703 Mdot
.588 .30761 Mdot
.588 .30812 Mdot
.588 .30838 Mdot
.588 .30981 Mdot
.588 .31018 Mdot
.588 .31025 Mdot
.588 .31146 Mdot
.588 .31291 Mdot
.588 .31361 Mdot
.588 .3152 Mdot
.588 .3168 Mdot
.588 .32026 Mdot
.588 .32139 Mdot
.588 .32282 Mdot
.588 .3233 Mdot
.588 .32469 Mdot
.588 .32503 Mdot
.588 .3256 Mdot
.588 .32581 Mdot
.588 .3259 Mdot
.588 .32622 Mdot
.588 .32636 Mdot
.588 .32816 Mdot
.588 .32816 Mdot
.588 .32934 Mdot
.588 .33103 Mdot
.588 .33273 Mdot
.588 .33297 Mdot
.588 .33331 Mdot
.588 .33367 Mdot
.588 .33471 Mdot
.588 .33767 Mdot
.588 .33778 Mdot
.588 .33819 Mdot
.588 .33939 Mdot
.588 .33974 Mdot
.588 .3399 Mdot
.588 .34003 Mdot
.588 .34009 Mdot
.588 .34279 Mdot
.588 .34347 Mdot
.588 .34383 Mdot
.588 .34464 Mdot
.588 .34501 Mdot
.588 .34553 Mdot
.588 .34567 Mdot
.588 .34606 Mdot
.588 .34822 Mdot
.588 .34863 Mdot
.588 .34965 Mdot
.588 .34966 Mdot
.588 .35027 Mdot
.588 .3504 Mdot
.588 .3511 Mdot
.588 .35198 Mdot
.588 .35218 Mdot
.588 .35257 Mdot
.588 .3547 Mdot
.588 .35588 Mdot
.588 .35598 Mdot
.588 .35685 Mdot
.588 .35806 Mdot
.588 .35847 Mdot
.588 .35916 Mdot
.588 .35976 Mdot
.588 .36007 Mdot
.588 .36175 Mdot
.588 .36218 Mdot
.588 .36226 Mdot
.59 .01579 Mdot
.59 .01599 Mdot
.59 .01621 Mdot
.59 .01648 Mdot
.59 .01663 Mdot
.59 .0168 Mdot
.59 .01698 Mdot
.59 .01718 Mdot
.59 .01738 Mdot
.59 .01762 Mdot
.59 .01786 Mdot
.59 .01814 Mdot
.59 .01843 Mdot
.59 .01876 Mdot
.59 .0191 Mdot
.59 .01949 Mdot
.59 .01953 Mdot
.59 .01966 Mdot
.59 .01989 Mdot
.59 .02035 Mdot
.59 .02039 Mdot
.59 .02054 Mdot
.59 .02082 Mdot
.59 .02136 Mdot
.59 .02138 Mdot
.59 .02142 Mdot
.59 .02159 Mdot
.59 .02171 Mdot
.59 .02192 Mdot
.59 .022 Mdot
.59 .02256 Mdot
.59 .02258 Mdot
.59 .02262 Mdot
.59 .02283 Mdot
.59 .02297 Mdot
.59 .02312 Mdot
.59 .02322 Mdot
.59 .02331 Mdot
.59 .02369 Mdot
.59 .02397 Mdot
.59 .02399 Mdot
.59 .02405 Mdot
.59 .02429 Mdot
.59 .02446 Mdot
.59 .02464 Mdot
.59 .02475 Mdot
.59 .02486 Mdot
.59 .0253 Mdot
.59 .02564 Mdot
.59 .02566 Mdot
.59 .02573 Mdot
.59 .02602 Mdot
.59 .02621 Mdot
.59 .02633 Mdot
.59 .02642 Mdot
.59 .02655 Mdot
.59 .02669 Mdot
.59 .02721 Mdot
.59 .02735 Mdot
.59 .0276 Mdot
.59 .02763 Mdot
.59 .02771 Mdot
.59 .02805 Mdot
.59 .02828 Mdot
.59 .02842 Mdot
.59 .02853 Mdot
.59 .02868 Mdot
.59 .02884 Mdot
.59 .02946 Mdot
.59 .02963 Mdot
.59 .02992 Mdot
.59 .02996 Mdot
.59 .03005 Mdot
.59 .03024 Mdot
.59 .03045 Mdot
.59 .03072 Mdot
.59 .03088 Mdot
.59 .03102 Mdot
.59 .03112 Mdot
.59 .0312 Mdot
.59 .03139 Mdot
.59 .03186 Mdot
.59 .03199 Mdot
.59 .03211 Mdot
.59 .03231 Mdot
.59 .03243 Mdot
.59 .0327 Mdot
.59 .03281 Mdot
.59 .03304 Mdot
.59 .03328 Mdot
.59 .03333 Mdot
.59 .03335 Mdot
.59 .0336 Mdot
.59 .03373 Mdot
.59 .03379 Mdot
.59 .03395 Mdot
.59 .03407 Mdot
.59 .03416 Mdot
.59 .03439 Mdot
.59 .03448 Mdot
.59 .03495 Mdot
.59 .03509 Mdot
.59 .03525 Mdot
.59 .03534 Mdot
.59 .03548 Mdot
.59 .03562 Mdot
.59 .03594 Mdot
.59 .03606 Mdot
.59 .03615 Mdot
.59 .03634 Mdot
.59 .03663 Mdot
.59 .03668 Mdot
.59 .03671 Mdot
.59 .037 Mdot
.59 .03715 Mdot
.59 .03723 Mdot
.59 .0374 Mdot
.59 .03741 Mdot
.59 .03756 Mdot
.59 .03766 Mdot
.59 .03793 Mdot
.59 .03803 Mdot
.59 .03859 Mdot
.59 .03868 Mdot
.59 .03876 Mdot
.59 .03894 Mdot
.59 .03905 Mdot
.59 .03922 Mdot
.59 .03939 Mdot
.59 .03976 Mdot
.59 .0399 Mdot
.59 .03993 Mdot
.59 .04 Mdot
.59 .04023 Mdot
.59 .04057 Mdot
.59 .04063 Mdot
.59 .04066 Mdot
.59 .04101 Mdot
.59 .04111 Mdot
.59 .04119 Mdot
.59 .04128 Mdot
.59 .04148 Mdot
.59 .0415 Mdot
.59 .04167 Mdot
.59 .0418 Mdot
.59 .04211 Mdot
.59 .04214 Mdot
.59 .04223 Mdot
.59 .04288 Mdot
.59 .043 Mdot
.59 .04309 Mdot
.59 .0433 Mdot
.59 .04343 Mdot
.59 .04363 Mdot
.59 .04382 Mdot
.59 .04383 Mdot
.59 .04394 Mdot
.59 .04426 Mdot
.59 .04427 Mdot
.59 .04444 Mdot
.59 .04446 Mdot
.59 .04456 Mdot
.59 .04482 Mdot
.59 .04491 Mdot
.59 .04522 Mdot
.59 .0453 Mdot
.59 .04533 Mdot
.59 .04575 Mdot
.59 .04586 Mdot
.59 .04596 Mdot
.59 .04606 Mdot
.59 .0463 Mdot
.59 .04632 Mdot
.59 .04652 Mdot
.59 .04666 Mdot
.59 .04667 Mdot
.59 .04704 Mdot
.59 .04708 Mdot
.59 .04718 Mdot
.59 .04796 Mdot
.59 .04809 Mdot
.59 .0482 Mdot
.59 .04826 Mdot
.59 .04843 Mdot
.59 .04845 Mdot
.59 .0486 Mdot
.59 .04883 Mdot
.59 .04906 Mdot
.59 .04907 Mdot
.59 .04921 Mdot
.59 .04957 Mdot
.59 .04959 Mdot
.59 .04979 Mdot
.59 .04982 Mdot
.59 .04993 Mdot
.59 .05024 Mdot
.59 .05034 Mdot
.59 .05063 Mdot
.59 .05072 Mdot
.59 .0508 Mdot
.59 .05085 Mdot
.59 .05093 Mdot
.59 .05121 Mdot
.59 .05133 Mdot
.59 .05146 Mdot
.59 .05158 Mdot
.59 .0517 Mdot
.59 .05198 Mdot
.59 .05201 Mdot
.59 .05225 Mdot
.59 .05241 Mdot
.59 .05242 Mdot
.59 .05286 Mdot
.59 .05287 Mdot
.59 .0529 Mdot
.59 .05294 Mdot
.59 .05303 Mdot
.59 .05332 Mdot
.59 .05372 Mdot
.59 .05394 Mdot
.59 .0541 Mdot
.59 .05423 Mdot
.59 .0543 Mdot
.59 .0545 Mdot
.59 .05452 Mdot
.59 .05458 Mdot
.59 .0547 Mdot
.59 .05497 Mdot
.59 .05524 Mdot
.59 .05525 Mdot
.59 .05541 Mdot
.59 .05585 Mdot
.59 .05586 Mdot
.59 .0561 Mdot
.59 .05614 Mdot
.59 .05627 Mdot
.59 .05664 Mdot
.59 .05676 Mdot
.59 .05709 Mdot
.59 .0572 Mdot
.59 .0573 Mdot
.59 .05735 Mdot
.59 .05745 Mdot
.59 .05759 Mdot
.59 .05778 Mdot
.59 .05793 Mdot
.59 .05808 Mdot
.59 .05822 Mdot
.59 .05836 Mdot
.59 .05869 Mdot
.59 .05872 Mdot
.59 .059 Mdot
.59 .05919 Mdot
.59 .05921 Mdot
.59 .05972 Mdot
.59 .05973 Mdot
.59 .05978 Mdot
.59 .05982 Mdot
.59 .05992 Mdot
.59 .06027 Mdot
.59 .06074 Mdot
.59 .061 Mdot
.59 .06118 Mdot
.59 .06134 Mdot
.59 .06143 Mdot
.59 .06162 Mdot
.59 .06166 Mdot
.59 .06168 Mdot
.59 .06175 Mdot
.59 .06189 Mdot
.59 .06222 Mdot
.59 .06237 Mdot
.59 .06254 Mdot
.59 .06255 Mdot
.59 .06274 Mdot
.59 .06325 Mdot
.59 .06327 Mdot
.59 .06355 Mdot
.59 .06359 Mdot
.59 .06375 Mdot
.59 .06382 Mdot
.59 .06418 Mdot
.59 .06433 Mdot
.59 .06472 Mdot
.59 .06484 Mdot
.59 .06494 Mdot
.59 .06496 Mdot
.59 .06502 Mdot
.59 .06515 Mdot
.59 .0653 Mdot
.59 .06542 Mdot
.59 .06553 Mdot
.59 .0657 Mdot
.59 .06588 Mdot
.59 .06605 Mdot
.59 .06621 Mdot
.59 .06659 Mdot
.59 .0666 Mdot
.59 .06665 Mdot
.59 .06673 Mdot
.59 .06697 Mdot
.59 .0672 Mdot
.59 .06722 Mdot
.59 .06752 Mdot
.59 .06783 Mdot
.59 .06784 Mdot
.59 .06789 Mdot
.59 .06794 Mdot
.59 .06806 Mdot
.59 .06847 Mdot
.59 .06903 Mdot
.59 .06913 Mdot
.59 .06933 Mdot
.59 .06948 Mdot
.59 .06955 Mdot
.59 .06971 Mdot
.59 .06973 Mdot
.59 .06984 Mdot
.59 .07006 Mdot
.59 .07011 Mdot
.59 .07014 Mdot
.59 .07022 Mdot
.59 .07028 Mdot
.59 .07039 Mdot
.59 .07076 Mdot
.59 .07077 Mdot
.59 .07095 Mdot
.59 .07115 Mdot
.59 .07115 Mdot
.59 .07138 Mdot
.59 .07152 Mdot
.59 .07199 Mdot
.59 .07201 Mdot
.59 .07234 Mdot
.59 .07239 Mdot
.59 .07257 Mdot
.59 .07266 Mdot
.59 .07309 Mdot
.59 .07326 Mdot
.59 .07372 Mdot
.59 .07387 Mdot
.59 .07399 Mdot
.59 .07401 Mdot
.59 .07408 Mdot
.59 .07422 Mdot
.59 .07423 Mdot
.59 .07429 Mdot
.59 .07441 Mdot
.59 .07455 Mdot
.59 .07468 Mdot
.59 .07488 Mdot
.59 .07509 Mdot
.59 .07529 Mdot
.59 .07548 Mdot
.59 .07565 Mdot
.59 .07592 Mdot
.59 .07594 Mdot
.59 .07599 Mdot
.59 .0761 Mdot
.59 .07638 Mdot
.59 .07664 Mdot
.59 .07667 Mdot
.59 .07702 Mdot
.59 .07707 Mdot
.59 .07712 Mdot
.59 .07739 Mdot
.59 .0774 Mdot
.59 .07746 Mdot
.59 .07753 Mdot
.59 .07766 Mdot
.59 .07815 Mdot
.59 .0788 Mdot
.59 .07893 Mdot
.59 .07916 Mdot
.59 .07934 Mdot
.59 .07942 Mdot
.59 .07961 Mdot
.59 .07963 Mdot
.59 .07976 Mdot
.59 .08002 Mdot
.59 .08008 Mdot
.59 .08011 Mdot
.59 .08021 Mdot
.59 .08028 Mdot
.59 .08041 Mdot
.59 .08085 Mdot
.59 .08086 Mdot
.59 .08108 Mdot
.59 .08131 Mdot
.59 .08131 Mdot
.59 .08158 Mdot
.59 .08174 Mdot
.59 .0823 Mdot
.59 .08232 Mdot
.59 .08271 Mdot
.59 .08277 Mdot
.59 .08298 Mdot
.59 .08309 Mdot
.59 .0836 Mdot
.59 .08379 Mdot
.59 .08435 Mdot
.59 .08451 Mdot
.59 .08465 Mdot
.59 .08468 Mdot
.59 .08476 Mdot
.59 .08493 Mdot
.59 .08494 Mdot
.59 .08501 Mdot
.59 .08515 Mdot
.59 .08532 Mdot
.59 .08547 Mdot
.59 .08571 Mdot
.59 .08596 Mdot
.59 .08619 Mdot
.59 .08642 Mdot
.59 .08662 Mdot
.59 .08694 Mdot
.59 .08696 Mdot
.59 .08702 Mdot
.59 .08715 Mdot
.59 .08748 Mdot
.59 .08779 Mdot
.59 .08782 Mdot
.59 .08824 Mdot
.59 .0883 Mdot
.59 .08835 Mdot
.59 .08867 Mdot
.59 .08868 Mdot
.59 .08875 Mdot
.59 .08883 Mdot
.59 .08899 Mdot
.59 .08957 Mdot
.59 .09034 Mdot
.59 .09048 Mdot
.59 .09076 Mdot
.59 .09098 Mdot
.59 .09107 Mdot
.59 .09129 Mdot
.59 .09132 Mdot
.59 .09147 Mdot
.59 .09178 Mdot
.59 .09184 Mdot
.59 .09189 Mdot
.59 .09199 Mdot
.59 .09209 Mdot
.59 .09223 Mdot
.59 .09275 Mdot
.59 .09276 Mdot
.59 .09302 Mdot
.59 .09329 Mdot
.59 .0933 Mdot
.59 .09362 Mdot
.59 .09381 Mdot
.59 .09446 Mdot
.59 .09449 Mdot
.59 .09495 Mdot
.59 .09502 Mdot
.59 .09527 Mdot
.59 .0954 Mdot
.59 .096 Mdot
.59 .09623 Mdot
.59 .09688 Mdot
.59 .09708 Mdot
.59 .09724 Mdot
.59 .09727 Mdot
.59 .09737 Mdot
.59 .09757 Mdot
.59 .09758 Mdot
.59 .09766 Mdot
.59 .09783 Mdot
.59 .09803 Mdot
.59 .09821 Mdot
.59 .09849 Mdot
.59 .09878 Mdot
.59 .09906 Mdot
.59 .09933 Mdot
.59 .09956 Mdot
.59 .09994 Mdot
.59 .09997 Mdot
.59 .10004 Mdot
.59 .10019 Mdot
.59 .10058 Mdot
.59 .10094 Mdot
.59 .10098 Mdot
.59 .10147 Mdot
.59 .10154 Mdot
.59 .10161 Mdot
.59 .10198 Mdot
.59 .102 Mdot
.59 .10208 Mdot
.59 .10217 Mdot
.59 .10236 Mdot
.59 .10304 Mdot
.59 .10395 Mdot
.59 .10412 Mdot
.59 .10445 Mdot
.59 .1047 Mdot
.59 .10481 Mdot
.59 .10507 Mdot
.59 .10511 Mdot
.59 .10528 Mdot
.59 .10565 Mdot
.59 .10573 Mdot
.59 .10578 Mdot
.59 .10591 Mdot
.59 .10601 Mdot
.59 .10618 Mdot
.59 .10679 Mdot
.59 .10681 Mdot
.59 .10712 Mdot
.59 .10744 Mdot
.59 .10745 Mdot
.59 .10782 Mdot
.59 .10805 Mdot
.59 .10882 Mdot
.59 .10885 Mdot
.59 .1094 Mdot
.59 .10948 Mdot
.59 .10977 Mdot
.59 .10992 Mdot
.59 .11063 Mdot
.59 .1109 Mdot
.59 .11167 Mdot
.59 .1119 Mdot
.59 .1121 Mdot
.59 .11213 Mdot
.59 .11225 Mdot
.59 .11249 Mdot
.59 .11249 Mdot
.59 .1126 Mdot
.59 .11279 Mdot
.59 .11302 Mdot
.59 .11324 Mdot
.59 .11357 Mdot
.59 .11391 Mdot
.59 .11424 Mdot
.59 .11456 Mdot
.59 .11483 Mdot
.59 .11528 Mdot
.59 .11531 Mdot
.59 .1154 Mdot
.59 .11557 Mdot
.59 .11603 Mdot
.59 .11646 Mdot
.59 .11651 Mdot
.59 .11709 Mdot
.59 .11717 Mdot
.59 .11725 Mdot
.59 .11769 Mdot
.59 .11771 Mdot
.59 .11781 Mdot
.59 .11791 Mdot
.59 .11814 Mdot
.59 .11894 Mdot
.59 .12001 Mdot
.59 .12022 Mdot
.59 .1206 Mdot
.59 .1209 Mdot
.59 .12103 Mdot
.59 .12134 Mdot
.59 .12138 Mdot
.59 .12158 Mdot
.59 .12201 Mdot
.59 .12211 Mdot
.59 .12217 Mdot
.59 .12232 Mdot
.59 .12245 Mdot
.59 .12265 Mdot
.59 .12337 Mdot
.59 .12339 Mdot
.59 .12375 Mdot
.59 .12413 Mdot
.59 .12414 Mdot
.59 .12458 Mdot
.59 .12485 Mdot
.59 .12576 Mdot
.59 .1258 Mdot
.59 .12644 Mdot
.59 .12653 Mdot
.59 .12688 Mdot
.59 .12706 Mdot
.59 .12789 Mdot
.59 .12821 Mdot
.59 .12912 Mdot
.59 .12939 Mdot
.59 .12963 Mdot
.59 .12967 Mdot
.59 .12981 Mdot
.59 .13009 Mdot
.59 .13009 Mdot
.59 .13021 Mdot
.59 .13045 Mdot
.59 .13072 Mdot
.59 .13097 Mdot
.59 .13136 Mdot
.59 .13177 Mdot
.59 .13216 Mdot
.59 .13253 Mdot
.59 .13285 Mdot
.59 .13338 Mdot
.59 .13342 Mdot
.59 .13352 Mdot
.59 .13372 Mdot
.59 .13427 Mdot
.59 .13478 Mdot
.59 .13483 Mdot
.59 .13552 Mdot
.59 .13561 Mdot
.59 .1357 Mdot
.59 .13622 Mdot
.59 .13625 Mdot
.59 .13637 Mdot
.59 .13649 Mdot
.59 .13676 Mdot
.59 .1377 Mdot
.59 .13897 Mdot
.59 .13921 Mdot
.59 .13966 Mdot
.59 .14001 Mdot
.59 .14016 Mdot
.59 .14053 Mdot
.59 .14057 Mdot
.59 .14082 Mdot
.59 .14133 Mdot
.59 .14144 Mdot
.59 .14151 Mdot
.59 .14169 Mdot
.59 .14184 Mdot
.59 .14208 Mdot
.59 .14293 Mdot
.59 .14295 Mdot
.59 .14337 Mdot
.59 .14382 Mdot
.59 .14383 Mdot
.59 .14436 Mdot
.59 .14467 Mdot
.59 .14574 Mdot
.59 .14579 Mdot
.59 .14655 Mdot
.59 .14666 Mdot
.59 .14707 Mdot
.59 .14728 Mdot
.59 .14826 Mdot
.59 .14864 Mdot
.59 .14971 Mdot
.59 .15004 Mdot
.59 .15031 Mdot
.59 .15036 Mdot
.59 .15052 Mdot
.59 .15085 Mdot
.59 .15086 Mdot
.59 .151 Mdot
.59 .15128 Mdot
.59 .1516 Mdot
.59 .1519 Mdot
.59 .15236 Mdot
.59 .15284 Mdot
.59 .1533 Mdot
.59 .15374 Mdot
.59 .15412 Mdot
.59 .15474 Mdot
.59 .15479 Mdot
.59 .1549 Mdot
.59 .15514 Mdot
.59 .15579 Mdot
.59 .15639 Mdot
.59 .15645 Mdot
.59 .15726 Mdot
.59 .15738 Mdot
.59 .15748 Mdot
.59 .15809 Mdot
.59 .15812 Mdot
.59 .15826 Mdot
.59 .15841 Mdot
.59 .15873 Mdot
.59 .15984 Mdot
.59 .16133 Mdot
.59 .16161 Mdot
.59 .16215 Mdot
.59 .16257 Mdot
.59 .16274 Mdot
.59 .16317 Mdot
.59 .16323 Mdot
.59 .16352 Mdot
.59 .16412 Mdot
.59 .16425 Mdot
.59 .16433 Mdot
.59 .16454 Mdot
.59 .16472 Mdot
.59 .165 Mdot
.59 .166 Mdot
.59 .16603 Mdot
.59 .16653 Mdot
.59 .16706 Mdot
.59 .16708 Mdot
.59 .16769 Mdot
.59 .16806 Mdot
.59 .16933 Mdot
.59 .16938 Mdot
.59 .17028 Mdot
.59 .17041 Mdot
.59 .1709 Mdot
.59 .17115 Mdot
.59 .1723 Mdot
.59 .17275 Mdot
.59 .17401 Mdot
.59 .1744 Mdot
.59 .17472 Mdot
.59 .17477 Mdot
.59 .17497 Mdot
.59 .17536 Mdot
.59 .17537 Mdot
.59 .17554 Mdot
.59 .17586 Mdot
.59 .17624 Mdot
.59 .17659 Mdot
.59 .17714 Mdot
.59 .1777 Mdot
.59 .17824 Mdot
.59 .17876 Mdot
.59 .17921 Mdot
.59 .17995 Mdot
.59 .18 Mdot
.59 .18014 Mdot
.59 .18042 Mdot
.59 .18119 Mdot
.59 .18189 Mdot
.59 .18196 Mdot
.59 .18292 Mdot
.59 .18306 Mdot
.59 .18318 Mdot
.59 .1839 Mdot
.59 .18393 Mdot
.59 .1841 Mdot
.59 .18427 Mdot
.59 .18465 Mdot
.59 .18596 Mdot
.59 .18773 Mdot
.59 .18806 Mdot
.59 .18869 Mdot
.59 .18918 Mdot
.59 .18939 Mdot
.59 .1899 Mdot
.59 .18996 Mdot
.59 .19031 Mdot
.59 .19101 Mdot
.59 .19116 Mdot
.59 .19126 Mdot
.59 .19151 Mdot
.59 .19172 Mdot
.59 .19205 Mdot
.59 .19324 Mdot
.59 .19326 Mdot
.59 .19386 Mdot
.59 .19448 Mdot
.59 .1945 Mdot
.59 .19523 Mdot
.59 .19566 Mdot
.59 .19716 Mdot
.59 .19722 Mdot
.59 .19828 Mdot
.59 .19843 Mdot
.59 .19901 Mdot
.59 .1993 Mdot
.59 .20066 Mdot
.59 .20119 Mdot
.59 .20269 Mdot
.59 .20314 Mdot
.59 .20352 Mdot
.59 .20358 Mdot
.59 .20381 Mdot
.59 .20428 Mdot
.59 .20429 Mdot
.59 .20448 Mdot
.59 .20487 Mdot
.59 .20531 Mdot
.59 .20573 Mdot
.59 .20637 Mdot
.59 .20704 Mdot
.59 .20768 Mdot
.59 .20829 Mdot
.59 .20882 Mdot
.59 .20969 Mdot
.59 .20975 Mdot
.59 .20991 Mdot
.59 .21025 Mdot
.59 .21115 Mdot
.59 .21198 Mdot
.59 .21206 Mdot
.59 .2132 Mdot
.59 .21336 Mdot
.59 .2135 Mdot
.59 .21435 Mdot
.59 .21439 Mdot
.59 .21459 Mdot
.59 .21479 Mdot
.59 .21524 Mdot
.59 .21679 Mdot
.59 .21887 Mdot
.59 .21926 Mdot
.59 .22 Mdot
.59 .22058 Mdot
.59 .22083 Mdot
.59 .22143 Mdot
.59 .22151 Mdot
.59 .22191 Mdot
.59 .22274 Mdot
.59 .22292 Mdot
.59 .22304 Mdot
.59 .22334 Mdot
.59 .22358 Mdot
.59 .22397 Mdot
.59 .22537 Mdot
.59 .2254 Mdot
.59 .22611 Mdot
.59 .22684 Mdot
.59 .22686 Mdot
.59 .22772 Mdot
.59 .22824 Mdot
.59 .23 Mdot
.59 .23008 Mdot
.59 .23133 Mdot
.59 .2315 Mdot
.59 .23219 Mdot
.59 .23253 Mdot
.59 .23414 Mdot
.59 .23476 Mdot
.59 .23652 Mdot
.59 .23705 Mdot
.59 .2375 Mdot
.59 .23758 Mdot
.59 .23785 Mdot
.59 .2384 Mdot
.59 .23841 Mdot
.59 .23864 Mdot
.59 .2391 Mdot
.59 .23962 Mdot
.59 .24011 Mdot
.59 .24087 Mdot
.59 .24166 Mdot
.59 .24241 Mdot
.59 .24313 Mdot
.59 .24376 Mdot
.59 .24478 Mdot
.59 .24486 Mdot
.59 .24505 Mdot
.59 .24545 Mdot
.59 .24651 Mdot
.59 .24749 Mdot
.59 .24759 Mdot
.59 .24893 Mdot
.59 .24911 Mdot
.59 .24928 Mdot
.59 .25029 Mdot
.59 .25034 Mdot
.59 .25057 Mdot
.59 .25081 Mdot
.59 .25133 Mdot
.59 .25316 Mdot
.59 .25561 Mdot
.59 .25608 Mdot
.59 .25696 Mdot
.59 .25764 Mdot
.59 .25793 Mdot
.59 .25864 Mdot
.59 .25873 Mdot
.59 .25921 Mdot
.59 .26019 Mdot
.59 .2604 Mdot
.59 .26054 Mdot
.59 .26089 Mdot
.59 .26118 Mdot
.59 .26164 Mdot
.59 .26329 Mdot
.59 .26333 Mdot
.59 .26416 Mdot
.59 .26502 Mdot
.59 .26505 Mdot
.59 .26607 Mdot
.59 .26667 Mdot
.59 .26875 Mdot
.59 .26884 Mdot
.59 .27032 Mdot
.59 .27053 Mdot
.59 .27133 Mdot
.59 .27174 Mdot
.59 .27363 Mdot
.59 .27437 Mdot
.59 .27645 Mdot
.59 .27707 Mdot
.59 .27761 Mdot
.59 .2777 Mdot
.59 .27802 Mdot
.59 .27866 Mdot
.59 .27868 Mdot
.59 .27895 Mdot
.59 .27948 Mdot
.59 .2801 Mdot
.59 .28068 Mdot
.59 .28158 Mdot
.59 .28251 Mdot
.59 .2834 Mdot
.59 .28425 Mdot
.59 .28499 Mdot
.59 .2862 Mdot
.59 .28628 Mdot
.59 .28651 Mdot
.59 .28698 Mdot
.59 .28823 Mdot
.59 .28939 Mdot
.59 .2895 Mdot
.59 .29109 Mdot
.59 .2913 Mdot
.59 .2915 Mdot
.59 .29269 Mdot
.59 .29275 Mdot
.59 .29302 Mdot
.59 .29331 Mdot
.59 .29392 Mdot
.59 .29608 Mdot
.59 .29898 Mdot
.59 .29952 Mdot
.59 .30056 Mdot
.59 .30137 Mdot
.59 .30171 Mdot
.59 .30254 Mdot
.59 .30265 Mdot
.59 .30322 Mdot
.59 .30437 Mdot
.59 .30463 Mdot
.59 .30479 Mdot
.59 .3052 Mdot
.59 .30554 Mdot
.59 .30609 Mdot
.59 .30803 Mdot
.59 .30808 Mdot
.59 .30905 Mdot
.59 .31008 Mdot
.59 .31011 Mdot
.59 .31131 Mdot
.59 .31202 Mdot
.59 .31447 Mdot
.59 .31458 Mdot
.59 .31604 Mdot
.59 .31633 Mdot
.59 .31657 Mdot
.59 .31752 Mdot
.59 .318 Mdot
.59 .32024 Mdot
.59 .32111 Mdot
.59 .32356 Mdot
.59 .3243 Mdot
.59 .32493 Mdot
.59 .32503 Mdot
.59 .32541 Mdot
.59 .32617 Mdot
.59 .32619 Mdot
.59 .32651 Mdot
.59 .32714 Mdot
.59 .32787 Mdot
.59 .32856 Mdot
.59 .32962 Mdot
.59 .33071 Mdot
.59 .33176 Mdot
.59 .33276 Mdot
.59 .33364 Mdot
.59 .33506 Mdot
.59 .33517 Mdot
.59 .33543 Mdot
.59 .33598 Mdot
.59 .33746 Mdot
.59 .33883 Mdot
.59 .33897 Mdot
.59 .34083 Mdot
.59 .34109 Mdot
.59 .34133 Mdot
.59 .34273 Mdot
.59 .34279 Mdot
.59 .34312 Mdot
.59 .34345 Mdot
.59 .34418 Mdot
.59 .34673 Mdot
.59 .35014 Mdot
.59 .35079 Mdot
.59 .35201 Mdot
.59 .35296 Mdot
.59 .35337 Mdot
.59 .35435 Mdot
.59 .35448 Mdot
.59 .35515 Mdot
.59 .35651 Mdot
.59 .35681 Mdot
.59 .357 Mdot
.59 .35749 Mdot
.59 .35789 Mdot
.59 .35854 Mdot
.59 .36083 Mdot
.59 .36088 Mdot
.59 .36204 Mdot
.59 .36324 Mdot
.59 .36328 Mdot
.592 .01495 Mdot
.592 .01499 Mdot
.592 .01504 Mdot
.592 .0151 Mdot
.592 .01517 Mdot
.592 .01526 Mdot
.592 .01536 Mdot
.592 .01547 Mdot
.592 .01561 Mdot
.592 .01578 Mdot
.592 .01597 Mdot
.592 .0162 Mdot
.592 .01648 Mdot
.592 .0168 Mdot
.592 .01719 Mdot
.592 .01764 Mdot
.592 .01818 Mdot
.592 .01882 Mdot
.592 .01957 Mdot
.592 .01993 Mdot
.592 .01995 Mdot
.592 .02004 Mdot
.592 .02047 Mdot
.592 .02089 Mdot
.592 .02092 Mdot
.592 .02102 Mdot
.592 .02152 Mdot
.592 .02152 Mdot
.592 .02181 Mdot
.592 .02202 Mdot
.592 .02206 Mdot
.592 .02218 Mdot
.592 .02265 Mdot
.592 .02276 Mdot
.592 .02277 Mdot
.592 .02278 Mdot
.592 .02287 Mdot
.592 .02311 Mdot
.592 .02336 Mdot
.592 .02341 Mdot
.592 .02355 Mdot
.592 .02379 Mdot
.592 .02411 Mdot
.592 .02425 Mdot
.592 .02425 Mdot
.592 .02426 Mdot
.592 .02437 Mdot
.592 .02466 Mdot
.592 .02496 Mdot
.592 .02501 Mdot
.592 .02518 Mdot
.592 .02547 Mdot
.592 .02584 Mdot
.592 .026 Mdot
.592 .02601 Mdot
.592 .02601 Mdot
.592 .02602 Mdot
.592 .02615 Mdot
.592 .02649 Mdot
.592 .02667 Mdot
.592 .02684 Mdot
.592 .0269 Mdot
.592 .02704 Mdot
.592 .02744 Mdot
.592 .02788 Mdot
.592 .02808 Mdot
.592 .02808 Mdot
.592 .02809 Mdot
.592 .0281 Mdot
.592 .02826 Mdot
.592 .02841 Mdot
.592 .02866 Mdot
.592 .02887 Mdot
.592 .02907 Mdot
.592 .02914 Mdot
.592 .02931 Mdot
.592 .02979 Mdot
.592 .03031 Mdot
.592 .03053 Mdot
.592 .03054 Mdot
.592 .03055 Mdot
.592 .03056 Mdot
.592 .03075 Mdot
.592 .03093 Mdot
.592 .03122 Mdot
.592 .03147 Mdot
.592 .03171 Mdot
.592 .0318 Mdot
.592 .032 Mdot
.592 .03235 Mdot
.592 .03256 Mdot
.592 .03317 Mdot
.592 .03327 Mdot
.592 .03344 Mdot
.592 .03346 Mdot
.592 .03346 Mdot
.592 .03347 Mdot
.592 .0337 Mdot
.592 .03392 Mdot
.592 .03395 Mdot
.592 .03426 Mdot
.592 .03455 Mdot
.592 .03484 Mdot
.592 .03494 Mdot
.592 .035 Mdot
.592 .03518 Mdot
.592 .03532 Mdot
.592 .03559 Mdot
.592 .03584 Mdot
.592 .03657 Mdot
.592 .03668 Mdot
.592 .03689 Mdot
.592 .0369 Mdot
.592 .03691 Mdot
.592 .03692 Mdot
.592 .03708 Mdot
.592 .03719 Mdot
.592 .03745 Mdot
.592 .03749 Mdot
.592 .0377 Mdot
.592 .03785 Mdot
.592 .03786 Mdot
.592 .03814 Mdot
.592 .0382 Mdot
.592 .03854 Mdot
.592 .03866 Mdot
.592 .03873 Mdot
.592 .03894 Mdot
.592 .03911 Mdot
.592 .03943 Mdot
.592 .03955 Mdot
.592 .03969 Mdot
.592 .03973 Mdot
.592 .03976 Mdot
.592 .03986 Mdot
.592 .04001 Mdot
.592 .04052 Mdot
.592 .04056 Mdot
.592 .04059 Mdot
.592 .04072 Mdot
.592 .04097 Mdot
.592 .04099 Mdot
.592 .04099 Mdot
.592 .04101 Mdot
.592 .04119 Mdot
.592 .04133 Mdot
.592 .04164 Mdot
.592 .04168 Mdot
.592 .0419 Mdot
.592 .04193 Mdot
.592 .04211 Mdot
.592 .04211 Mdot
.592 .04245 Mdot
.592 .04252 Mdot
.592 .04293 Mdot
.592 .04307 Mdot
.592 .04314 Mdot
.592 .04315 Mdot
.592 .0434 Mdot
.592 .04359 Mdot
.592 .04398 Mdot
.592 .04412 Mdot
.592 .04428 Mdot
.592 .04433 Mdot
.592 .04437 Mdot
.592 .04449 Mdot
.592 .04466 Mdot
.592 .04527 Mdot
.592 .04531 Mdot
.592 .04535 Mdot
.592 .04551 Mdot
.592 .0458 Mdot
.592 .04582 Mdot
.592 .04583 Mdot
.592 .04585 Mdot
.592 .04607 Mdot
.592 .04622 Mdot
.592 .04643 Mdot
.592 .04659 Mdot
.592 .04664 Mdot
.592 .04691 Mdot
.592 .04694 Mdot
.592 .04715 Mdot
.592 .04715 Mdot
.592 .04755 Mdot
.592 .04764 Mdot
.592 .04812 Mdot
.592 .04829 Mdot
.592 .04836 Mdot
.592 .04839 Mdot
.592 .04868 Mdot
.592 .04891 Mdot
.592 .04936 Mdot
.592 .04953 Mdot
.592 .04956 Mdot
.592 .04972 Mdot
.592 .04978 Mdot
.592 .04982 Mdot
.592 .04997 Mdot
.592 .05004 Mdot
.592 .05017 Mdot
.592 .0506 Mdot
.592 .05089 Mdot
.592 .05094 Mdot
.592 .05099 Mdot
.592 .05117 Mdot
.592 .05152 Mdot
.592 .05154 Mdot
.592 .05155 Mdot
.592 .05158 Mdot
.592 .05184 Mdot
.592 .05202 Mdot
.592 .05226 Mdot
.592 .05245 Mdot
.592 .05251 Mdot
.592 .05255 Mdot
.592 .05283 Mdot
.592 .05287 Mdot
.592 .05312 Mdot
.592 .05312 Mdot
.592 .0536 Mdot
.592 .0537 Mdot
.592 .05427 Mdot
.592 .05446 Mdot
.592 .05456 Mdot
.592 .05458 Mdot
.592 .05493 Mdot
.592 .055 Mdot
.592 .0552 Mdot
.592 .05564 Mdot
.592 .05574 Mdot
.592 .05593 Mdot
.592 .05597 Mdot
.592 .05616 Mdot
.592 .05623 Mdot
.592 .05625 Mdot
.592 .05628 Mdot
.592 .05645 Mdot
.592 .05647 Mdot
.592 .05655 Mdot
.592 .05655 Mdot
.592 .0567 Mdot
.592 .05684 Mdot
.592 .0572 Mdot
.592 .05755 Mdot
.592 .05761 Mdot
.592 .05767 Mdot
.592 .05788 Mdot
.592 .05823 Mdot
.592 .0583 Mdot
.592 .05832 Mdot
.592 .05833 Mdot
.592 .05836 Mdot
.592 .05867 Mdot
.592 .05888 Mdot
.592 .05917 Mdot
.592 .0594 Mdot
.592 .05947 Mdot
.592 .05951 Mdot
.592 .05957 Mdot
.592 .05984 Mdot
.592 .05989 Mdot
.592 .05991 Mdot
.592 .06019 Mdot
.592 .06019 Mdot
.592 .06075 Mdot
.592 .06087 Mdot
.592 .06153 Mdot
.592 .06154 Mdot
.592 .06174 Mdot
.592 .06178 Mdot
.592 .06189 Mdot
.592 .06192 Mdot
.592 .06233 Mdot
.592 .06242 Mdot
.592 .06247 Mdot
.592 .06265 Mdot
.592 .06317 Mdot
.592 .06329 Mdot
.592 .06351 Mdot
.592 .06356 Mdot
.592 .06379 Mdot
.592 .06387 Mdot
.592 .06389 Mdot
.592 .06393 Mdot
.592 .06411 Mdot
.592 .06413 Mdot
.592 .06416 Mdot
.592 .06424 Mdot
.592 .06425 Mdot
.592 .06442 Mdot
.592 .06459 Mdot
.592 .06502 Mdot
.592 .06543 Mdot
.592 .0655 Mdot
.592 .06557 Mdot
.592 .06583 Mdot
.592 .06615 Mdot
.592 .06623 Mdot
.592 .06631 Mdot
.592 .06634 Mdot
.592 .06635 Mdot
.592 .06639 Mdot
.592 .06675 Mdot
.592 .0668 Mdot
.592 .06701 Mdot
.592 .06704 Mdot
.592 .06713 Mdot
.592 .06735 Mdot
.592 .06762 Mdot
.592 .0677 Mdot
.592 .06774 Mdot
.592 .06775 Mdot
.592 .06783 Mdot
.592 .06815 Mdot
.592 .0682 Mdot
.592 .06822 Mdot
.592 .06855 Mdot
.592 .06856 Mdot
.592 .06922 Mdot
.592 .06937 Mdot
.592 .07014 Mdot
.592 .07015 Mdot
.592 .07016 Mdot
.592 .07039 Mdot
.592 .07044 Mdot
.592 .07057 Mdot
.592 .07059 Mdot
.592 .0706 Mdot
.592 .07075 Mdot
.592 .07109 Mdot
.592 .07119 Mdot
.592 .07125 Mdot
.592 .07147 Mdot
.592 .07208 Mdot
.592 .07222 Mdot
.592 .07233 Mdot
.592 .07249 Mdot
.592 .07254 Mdot
.592 .07282 Mdot
.592 .07292 Mdot
.592 .07294 Mdot
.592 .07298 Mdot
.592 .0732 Mdot
.592 .07322 Mdot
.592 .07324 Mdot
.592 .07325 Mdot
.592 .07328 Mdot
.592 .07336 Mdot
.592 .07336 Mdot
.592 .07357 Mdot
.592 .07376 Mdot
.592 .07428 Mdot
.592 .07476 Mdot
.592 .07484 Mdot
.592 .07493 Mdot
.592 .07523 Mdot
.592 .07561 Mdot
.592 .07571 Mdot
.592 .07581 Mdot
.592 .07584 Mdot
.592 .07586 Mdot
.592 .0759 Mdot
.592 .07633 Mdot
.592 .07638 Mdot
.592 .07663 Mdot
.592 .07667 Mdot
.592 .07678 Mdot
.592 .07704 Mdot
.592 .07735 Mdot
.592 .07745 Mdot
.592 .07749 Mdot
.592 .07751 Mdot
.592 .0776 Mdot
.592 .07798 Mdot
.592 .07805 Mdot
.592 .07807 Mdot
.592 .07832 Mdot
.592 .07846 Mdot
.592 .07846 Mdot
.592 .07925 Mdot
.592 .07942 Mdot
.592 .08034 Mdot
.592 .08035 Mdot
.592 .08036 Mdot
.592 .08064 Mdot
.592 .08069 Mdot
.592 .08084 Mdot
.592 .08087 Mdot
.592 .08089 Mdot
.592 .08106 Mdot
.592 .08146 Mdot
.592 .08159 Mdot
.592 .08166 Mdot
.592 .08191 Mdot
.592 .08263 Mdot
.592 .08281 Mdot
.592 .08293 Mdot
.592 .08313 Mdot
.592 .08318 Mdot
.592 .08351 Mdot
.592 .08362 Mdot
.592 .08365 Mdot
.592 .08371 Mdot
.592 .08397 Mdot
.592 .08399 Mdot
.592 .084 Mdot
.592 .08402 Mdot
.592 .08405 Mdot
.592 .08415 Mdot
.592 .08415 Mdot
.592 .0844 Mdot
.592 .08463 Mdot
.592 .08524 Mdot
.592 .08581 Mdot
.592 .0859 Mdot
.592 .08601 Mdot
.592 .08637 Mdot
.592 .08682 Mdot
.592 .08694 Mdot
.592 .08705 Mdot
.592 .08709 Mdot
.592 .08711 Mdot
.592 .08716 Mdot
.592 .08742 Mdot
.592 .08766 Mdot
.592 .08773 Mdot
.592 .08803 Mdot
.592 .08806 Mdot
.592 .0882 Mdot
.592 .0885 Mdot
.592 .08888 Mdot
.592 .089 Mdot
.592 .08904 Mdot
.592 .08906 Mdot
.592 .08917 Mdot
.592 .08962 Mdot
.592 .0897 Mdot
.592 .08973 Mdot
.592 .09002 Mdot
.592 .09019 Mdot
.592 .09019 Mdot
.592 .09113 Mdot
.592 .09133 Mdot
.592 .09242 Mdot
.592 .09242 Mdot
.592 .09244 Mdot
.592 .09276 Mdot
.592 .09283 Mdot
.592 .09301 Mdot
.592 .09304 Mdot
.592 .09306 Mdot
.592 .09326 Mdot
.592 .09375 Mdot
.592 .09389 Mdot
.592 .09397 Mdot
.592 .09427 Mdot
.592 .09513 Mdot
.592 .09533 Mdot
.592 .09548 Mdot
.592 .09571 Mdot
.592 .09578 Mdot
.592 .09617 Mdot
.592 .0963 Mdot
.592 .09634 Mdot
.592 .0964 Mdot
.592 .09671 Mdot
.592 .09674 Mdot
.592 .09675 Mdot
.592 .09678 Mdot
.592 .09681 Mdot
.592 .09692 Mdot
.592 .09693 Mdot
.592 .09722 Mdot
.592 .09749 Mdot
.592 .09821 Mdot
.592 .0989 Mdot
.592 .099 Mdot
.592 .09912 Mdot
.592 .09955 Mdot
.592 .10009 Mdot
.592 .10023 Mdot
.592 .10036 Mdot
.592 .10041 Mdot
.592 .10043 Mdot
.592 .10049 Mdot
.592 .10079 Mdot
.592 .10109 Mdot
.592 .10116 Mdot
.592 .10152 Mdot
.592 .10156 Mdot
.592 .10172 Mdot
.592 .10208 Mdot
.592 .10253 Mdot
.592 .10267 Mdot
.592 .10272 Mdot
.592 .10274 Mdot
.592 .10287 Mdot
.592 .1034 Mdot
.592 .10349 Mdot
.592 .10353 Mdot
.592 .10388 Mdot
.592 .10407 Mdot
.592 .10408 Mdot
.592 .10519 Mdot
.592 .10542 Mdot
.592 .10671 Mdot
.592 .10672 Mdot
.592 .10674 Mdot
.592 .10713 Mdot
.592 .1072 Mdot
.592 .10742 Mdot
.592 .10745 Mdot
.592 .10748 Mdot
.592 .10771 Mdot
.592 .10829 Mdot
.592 .10846 Mdot
.592 .10856 Mdot
.592 .10891 Mdot
.592 .10993 Mdot
.592 .11017 Mdot
.592 .11034 Mdot
.592 .11062 Mdot
.592 .1107 Mdot
.592 .11115 Mdot
.592 .11132 Mdot
.592 .11136 Mdot
.592 .11143 Mdot
.592 .11179 Mdot
.592 .11183 Mdot
.592 .11185 Mdot
.592 .11187 Mdot
.592 .11191 Mdot
.592 .11205 Mdot
.592 .11205 Mdot
.592 .1124 Mdot
.592 .11272 Mdot
.592 .11358 Mdot
.592 .11439 Mdot
.592 .11451 Mdot
.592 .11466 Mdot
.592 .11516 Mdot
.592 .1158 Mdot
.592 .11596 Mdot
.592 .11612 Mdot
.592 .11618 Mdot
.592 .1162 Mdot
.592 .11627 Mdot
.592 .11663 Mdot
.592 .11698 Mdot
.592 .11707 Mdot
.592 .11749 Mdot
.592 .11754 Mdot
.592 .11773 Mdot
.592 .11815 Mdot
.592 .11868 Mdot
.592 .11885 Mdot
.592 .11891 Mdot
.592 .11894 Mdot
.592 .11909 Mdot
.592 .11972 Mdot
.592 .11983 Mdot
.592 .11987 Mdot
.592 .12028 Mdot
.592 .12052 Mdot
.592 .12053 Mdot
.592 .12183 Mdot
.592 .12211 Mdot
.592 .12364 Mdot
.592 .12365 Mdot
.592 .12368 Mdot
.592 .12413 Mdot
.592 .12422 Mdot
.592 .12448 Mdot
.592 .12451 Mdot
.592 .12454 Mdot
.592 .12483 Mdot
.592 .1255 Mdot
.592 .12571 Mdot
.592 .12582 Mdot
.592 .12624 Mdot
.592 .12745 Mdot
.592 .12773 Mdot
.592 .12794 Mdot
.592 .12826 Mdot
.592 .12836 Mdot
.592 .1289 Mdot
.592 .12909 Mdot
.592 .12914 Mdot
.592 .12922 Mdot
.592 .12966 Mdot
.592 .1297 Mdot
.592 .12972 Mdot
.592 .12975 Mdot
.592 .1298 Mdot
.592 .12996 Mdot
.592 .12997 Mdot
.592 .13038 Mdot
.592 .13076 Mdot
.592 .13177 Mdot
.592 .13272 Mdot
.592 .13287 Mdot
.592 .13304 Mdot
.592 .13364 Mdot
.592 .13439 Mdot
.592 .13459 Mdot
.592 .13478 Mdot
.592 .13484 Mdot
.592 .13487 Mdot
.592 .13496 Mdot
.592 .13538 Mdot
.592 .1358 Mdot
.592 .1359 Mdot
.592 .1364 Mdot
.592 .13646 Mdot
.592 .13668 Mdot
.592 .13719 Mdot
.592 .13781 Mdot
.592 .13801 Mdot
.592 .13808 Mdot
.592 .13811 Mdot
.592 .1383 Mdot
.592 .13904 Mdot
.592 .13917 Mdot
.592 .13922 Mdot
.592 .13971 Mdot
.592 .13998 Mdot
.592 .14 Mdot
.592 .14154 Mdot
.592 .14188 Mdot
.592 .14368 Mdot
.592 .14369 Mdot
.592 .14372 Mdot
.592 .14426 Mdot
.592 .14437 Mdot
.592 .14467 Mdot
.592 .14471 Mdot
.592 .14475 Mdot
.592 .14509 Mdot
.592 .14589 Mdot
.592 .14613 Mdot
.592 .14627 Mdot
.592 .14676 Mdot
.592 .14819 Mdot
.592 .14853 Mdot
.592 .14877 Mdot
.592 .14916 Mdot
.592 .14927 Mdot
.592 .14991 Mdot
.592 .15014 Mdot
.592 .15019 Mdot
.592 .15029 Mdot
.592 .15081 Mdot
.592 .15086 Mdot
.592 .15088 Mdot
.592 .15092 Mdot
.592 .15097 Mdot
.592 .15116 Mdot
.592 .15117 Mdot
.592 .15166 Mdot
.592 .15211 Mdot
.592 .1533 Mdot
.592 .15444 Mdot
.592 .15462 Mdot
.592 .15482 Mdot
.592 .15552 Mdot
.592 .15642 Mdot
.592 .15665 Mdot
.592 .15687 Mdot
.592 .15695 Mdot
.592 .15698 Mdot
.592 .15708 Mdot
.592 .15759 Mdot
.592 .15807 Mdot
.592 .1582 Mdot
.592 .15879 Mdot
.592 .15886 Mdot
.592 .15912 Mdot
.592 .15972 Mdot
.592 .16046 Mdot
.592 .1607 Mdot
.592 .16078 Mdot
.592 .16082 Mdot
.592 .16104 Mdot
.592 .16191 Mdot
.592 .16207 Mdot
.592 .16213 Mdot
.592 .1627 Mdot
.592 .16303 Mdot
.592 .16305 Mdot
.592 .16488 Mdot
.592 .16527 Mdot
.592 .16741 Mdot
.592 .16742 Mdot
.592 .16746 Mdot
.592 .1681 Mdot
.592 .16822 Mdot
.592 .16858 Mdot
.592 .16863 Mdot
.592 .16868 Mdot
.592 .16908 Mdot
.592 .17003 Mdot
.592 .17031 Mdot
.592 .17047 Mdot
.592 .17106 Mdot
.592 .17275 Mdot
.592 .17315 Mdot
.592 .17344 Mdot
.592 .17389 Mdot
.592 .17403 Mdot
.592 .17479 Mdot
.592 .17505 Mdot
.592 .17512 Mdot
.592 .17524 Mdot
.592 .17585 Mdot
.592 .17591 Mdot
.592 .17594 Mdot
.592 .17598 Mdot
.592 .17604 Mdot
.592 .17627 Mdot
.592 .17628 Mdot
.592 .17686 Mdot
.592 .17739 Mdot
.592 .1788 Mdot
.592 .18015 Mdot
.592 .18036 Mdot
.592 .1806 Mdot
.592 .18143 Mdot
.592 .18249 Mdot
.592 .18276 Mdot
.592 .18302 Mdot
.592 .18312 Mdot
.592 .18315 Mdot
.592 .18328 Mdot
.592 .18387 Mdot
.592 .18445 Mdot
.592 .1846 Mdot
.592 .18529 Mdot
.592 .18538 Mdot
.592 .1857 Mdot
.592 .1864 Mdot
.592 .18728 Mdot
.592 .18756 Mdot
.592 .18766 Mdot
.592 .1877 Mdot
.592 .18796 Mdot
.592 .18899 Mdot
.592 .18919 Mdot
.592 .18925 Mdot
.592 .18994 Mdot
.592 .19032 Mdot
.592 .19034 Mdot
.592 .19251 Mdot
.592 .19298 Mdot
.592 .19551 Mdot
.592 .19552 Mdot
.592 .19557 Mdot
.592 .19632 Mdot
.592 .19647 Mdot
.592 .19689 Mdot
.592 .19695 Mdot
.592 .19701 Mdot
.592 .19748 Mdot
.592 .1986 Mdot
.592 .19894 Mdot
.592 .19913 Mdot
.592 .19983 Mdot
.592 .20183 Mdot
.592 .2023 Mdot
.592 .20265 Mdot
.592 .20318 Mdot
.592 .20334 Mdot
.592 .20424 Mdot
.592 .20456 Mdot
.592 .20463 Mdot
.592 .20478 Mdot
.592 .20549 Mdot
.592 .20556 Mdot
.592 .2056 Mdot
.592 .20565 Mdot
.592 .20573 Mdot
.592 .20599 Mdot
.592 .20601 Mdot
.592 .20669 Mdot
.592 .20732 Mdot
.592 .20899 Mdot
.592 .21059 Mdot
.592 .21084 Mdot
.592 .21112 Mdot
.592 .21211 Mdot
.592 .21336 Mdot
.592 .21368 Mdot
.592 .21399 Mdot
.592 .21411 Mdot
.592 .21415 Mdot
.592 .21429 Mdot
.592 .215 Mdot
.592 .21568 Mdot
.592 .21585 Mdot
.592 .21668 Mdot
.592 .21679 Mdot
.592 .21716 Mdot
.592 .21799 Mdot
.592 .21903 Mdot
.592 .21936 Mdot
.592 .21948 Mdot
.592 .21953 Mdot
.592 .21984 Mdot
.592 .22106 Mdot
.592 .22129 Mdot
.592 .22137 Mdot
.592 .22218 Mdot
.592 .22264 Mdot
.592 .22266 Mdot
.592 .22522 Mdot
.592 .22578 Mdot
.592 .22878 Mdot
.592 .22879 Mdot
.592 .22884 Mdot
.592 .22974 Mdot
.592 .22991 Mdot
.592 .23042 Mdot
.592 .23049 Mdot
.592 .23055 Mdot
.592 .23111 Mdot
.592 .23244 Mdot
.592 .23284 Mdot
.592 .23306 Mdot
.592 .23389 Mdot
.592 .23626 Mdot
.592 .23681 Mdot
.592 .23722 Mdot
.592 .23786 Mdot
.592 .23805 Mdot
.592 .23911 Mdot
.592 .23949 Mdot
.592 .23958 Mdot
.592 .23975 Mdot
.592 .2406 Mdot
.592 .24068 Mdot
.592 .24072 Mdot
.592 .24079 Mdot
.592 .24088 Mdot
.592 .24118 Mdot
.592 .2412 Mdot
.592 .24202 Mdot
.592 .24276 Mdot
.592 .24474 Mdot
.592 .24663 Mdot
.592 .24692 Mdot
.592 .24726 Mdot
.592 .24843 Mdot
.592 .24991 Mdot
.592 .25029 Mdot
.592 .25066 Mdot
.592 .25079 Mdot
.592 .25084 Mdot
.592 .25101 Mdot
.592 .25185 Mdot
.592 .25266 Mdot
.592 .25286 Mdot
.592 .25384 Mdot
.592 .25397 Mdot
.592 .25441 Mdot
.592 .2554 Mdot
.592 .25663 Mdot
.592 .25701 Mdot
.592 .25716 Mdot
.592 .25722 Mdot
.592 .25758 Mdot
.592 .25903 Mdot
.592 .2593 Mdot
.592 .25939 Mdot
.592 .26035 Mdot
.592 .26089 Mdot
.592 .26092 Mdot
.592 .26396 Mdot
.592 .26461 Mdot
.592 .26816 Mdot
.592 .26818 Mdot
.592 .26824 Mdot
.592 .2693 Mdot
.592 .26951 Mdot
.592 .27011 Mdot
.592 .27019 Mdot
.592 .27027 Mdot
.592 .27092 Mdot
.592 .2725 Mdot
.592 .27297 Mdot
.592 .27324 Mdot
.592 .27422 Mdot
.592 .27702 Mdot
.592 .27768 Mdot
.592 .27817 Mdot
.592 .27892 Mdot
.592 .27914 Mdot
.592 .2804 Mdot
.592 .28084 Mdot
.592 .28095 Mdot
.592 .28116 Mdot
.592 .28216 Mdot
.592 .28226 Mdot
.592 .28231 Mdot
.592 .28238 Mdot
.592 .28249 Mdot
.592 .28286 Mdot
.592 .28288 Mdot
.592 .28384 Mdot
.592 .28472 Mdot
.592 .28707 Mdot
.592 .2893 Mdot
.592 .28965 Mdot
.592 .29004 Mdot
.592 .29143 Mdot
.592 .29319 Mdot
.592 .29364 Mdot
.592 .29407 Mdot
.592 .29423 Mdot
.592 .29429 Mdot
.592 .29449 Mdot
.592 .29548 Mdot
.592 .29645 Mdot
.592 .29668 Mdot
.592 .29784 Mdot
.592 .29799 Mdot
.592 .29851 Mdot
.592 .29968 Mdot
.592 .30114 Mdot
.592 .3016 Mdot
.592 .30177 Mdot
.592 .30184 Mdot
.592 .30227 Mdot
.592 .30398 Mdot
.592 .3043 Mdot
.592 .30441 Mdot
.592 .30554 Mdot
.592 .30619 Mdot
.592 .30622 Mdot
.592 .30982 Mdot
.592 .31059 Mdot
.592 .3148 Mdot
.592 .31482 Mdot
.592 .31489 Mdot
.592 .31614 Mdot
.592 .31639 Mdot
.592 .3171 Mdot
.592 .31719 Mdot
.592 .31729 Mdot
.592 .31806 Mdot
.592 .31993 Mdot
.592 .32049 Mdot
.592 .32081 Mdot
.592 .32197 Mdot
.592 .32529 Mdot
.592 .32607 Mdot
.592 .32664 Mdot
.592 .32753 Mdot
.592 .32779 Mdot
.592 .32929 Mdot
.592 .32981 Mdot
.592 .32994 Mdot
.592 .33018 Mdot
.592 .33137 Mdot
.592 .33149 Mdot
.592 .33155 Mdot
.592 .33163 Mdot
.592 .33176 Mdot
.592 .33219 Mdot
.592 .33222 Mdot
.592 .33336 Mdot
.592 .3344 Mdot
.592 .33718 Mdot
.592 .33982 Mdot
.592 .34024 Mdot
.592 .3407 Mdot
.592 .34235 Mdot
.592 .34442 Mdot
.592 .34496 Mdot
.592 .34548 Mdot
.592 .34566 Mdot
.592 .34573 Mdot
.592 .34597 Mdot
.592 .34715 Mdot
.592 .34828 Mdot
.592 .34857 Mdot
.592 .34994 Mdot
.592 .35011 Mdot
.592 .35073 Mdot
.592 .35212 Mdot
.592 .35384 Mdot
.592 .35438 Mdot
.592 .35459 Mdot
.592 .35467 Mdot
.592 .35518 Mdot
.592 .35721 Mdot
.592 .35758 Mdot
.592 .35772 Mdot
.592 .35906 Mdot
.592 .35982 Mdot
.592 .35986 Mdot
.592 .36411 Mdot
.594 .01637 Mdot
.594 .01667 Mdot
.594 .01668 Mdot
.594 .01703 Mdot
.594 .01705 Mdot
.594 .01747 Mdot
.594 .01749 Mdot
.594 .01766 Mdot
.594 .01799 Mdot
.594 .01801 Mdot
.594 .01821 Mdot
.594 .0186 Mdot
.594 .01863 Mdot
.594 .01868 Mdot
.594 .01884 Mdot
.594 .01887 Mdot
.594 .01912 Mdot
.594 .01933 Mdot
.594 .01937 Mdot
.594 .01942 Mdot
.594 .01961 Mdot
.594 .01965 Mdot
.594 .01994 Mdot
.594 .0202 Mdot
.594 .02024 Mdot
.594 .02031 Mdot
.594 .02053 Mdot
.594 .02057 Mdot
.594 .02093 Mdot
.594 .02123 Mdot
.594 .02126 Mdot
.594 .02128 Mdot
.594 .02136 Mdot
.594 .02163 Mdot
.594 .02168 Mdot
.594 .02209 Mdot
.594 .02237 Mdot
.594 .02246 Mdot
.594 .02248 Mdot
.594 .02252 Mdot
.594 .02261 Mdot
.594 .02272 Mdot
.594 .02293 Mdot
.594 .02298 Mdot
.594 .02348 Mdot
.594 .02381 Mdot
.594 .02392 Mdot
.594 .02395 Mdot
.594 .02399 Mdot
.594 .0241 Mdot
.594 .02422 Mdot
.594 .02447 Mdot
.594 .02447 Mdot
.594 .02454 Mdot
.594 .02513 Mdot
.594 .02513 Mdot
.594 .02552 Mdot
.594 .02565 Mdot
.594 .02568 Mdot
.594 .02573 Mdot
.594 .02586 Mdot
.594 .02601 Mdot
.594 .02625 Mdot
.594 .02631 Mdot
.594 .02631 Mdot
.594 .02639 Mdot
.594 .02689 Mdot
.594 .02696 Mdot
.594 .02709 Mdot
.594 .02709 Mdot
.594 .02755 Mdot
.594 .0277 Mdot
.594 .02774 Mdot
.594 .0278 Mdot
.594 .02796 Mdot
.594 .02813 Mdot
.594 .02831 Mdot
.594 .02842 Mdot
.594 .02848 Mdot
.594 .02849 Mdot
.594 .02858 Mdot
.594 .02876 Mdot
.594 .02887 Mdot
.594 .02917 Mdot
.594 .02919 Mdot
.594 .02927 Mdot
.594 .02938 Mdot
.594 .02941 Mdot
.594 .02941 Mdot
.594 .02997 Mdot
.594 .03014 Mdot
.594 .03019 Mdot
.594 .03026 Mdot
.594 .03044 Mdot
.594 .03066 Mdot
.594 .03087 Mdot
.594 .03099 Mdot
.594 .03107 Mdot
.594 .03108 Mdot
.594 .03119 Mdot
.594 .0314 Mdot
.594 .03154 Mdot
.594 .03189 Mdot
.594 .03191 Mdot
.594 .032 Mdot
.594 .03213 Mdot
.594 .03217 Mdot
.594 .03218 Mdot
.594 .03284 Mdot
.594 .03304 Mdot
.594 .0331 Mdot
.594 .03318 Mdot
.594 .0334 Mdot
.594 .03366 Mdot
.594 .03391 Mdot
.594 .03405 Mdot
.594 .03415 Mdot
.594 .03415 Mdot
.594 .03423 Mdot
.594 .03428 Mdot
.594 .03454 Mdot
.594 .0347 Mdot
.594 .03471 Mdot
.594 .03512 Mdot
.594 .03515 Mdot
.594 .03525 Mdot
.594 .03541 Mdot
.594 .03546 Mdot
.594 .03546 Mdot
.594 .03569 Mdot
.594 .03624 Mdot
.594 .03649 Mdot
.594 .03656 Mdot
.594 .03665 Mdot
.594 .03691 Mdot
.594 .03715 Mdot
.594 .03722 Mdot
.594 .03729 Mdot
.594 .03752 Mdot
.594 .03755 Mdot
.594 .03769 Mdot
.594 .0378 Mdot
.594 .03781 Mdot
.594 .03789 Mdot
.594 .03796 Mdot
.594 .03827 Mdot
.594 .03845 Mdot
.594 .03846 Mdot
.594 .03896 Mdot
.594 .03899 Mdot
.594 .03911 Mdot
.594 .0393 Mdot
.594 .03936 Mdot
.594 .03936 Mdot
.594 .03964 Mdot
.594 .04029 Mdot
.594 .04058 Mdot
.594 .04066 Mdot
.594 .04078 Mdot
.594 .04109 Mdot
.594 .04137 Mdot
.594 .04145 Mdot
.594 .04154 Mdot
.594 .0418 Mdot
.594 .04185 Mdot
.594 .04201 Mdot
.594 .04214 Mdot
.594 .04215 Mdot
.594 .04225 Mdot
.594 .04229 Mdot
.594 .04233 Mdot
.594 .0427 Mdot
.594 .04273 Mdot
.594 .04292 Mdot
.594 .04293 Mdot
.594 .04352 Mdot
.594 .04355 Mdot
.594 .0437 Mdot
.594 .04392 Mdot
.594 .04399 Mdot
.594 .04399 Mdot
.594 .04414 Mdot
.594 .04432 Mdot
.594 .04491 Mdot
.594 .04509 Mdot
.594 .0451 Mdot
.594 .04545 Mdot
.594 .04552 Mdot
.594 .04553 Mdot
.594 .04554 Mdot
.594 .04568 Mdot
.594 .04605 Mdot
.594 .04636 Mdot
.594 .04638 Mdot
.594 .04647 Mdot
.594 .04658 Mdot
.594 .04689 Mdot
.594 .04695 Mdot
.594 .04714 Mdot
.594 .0473 Mdot
.594 .04731 Mdot
.594 .04743 Mdot
.594 .04748 Mdot
.594 .04751 Mdot
.594 .04752 Mdot
.594 .04796 Mdot
.594 .048 Mdot
.594 .04822 Mdot
.594 .04823 Mdot
.594 .04893 Mdot
.594 .04897 Mdot
.594 .04897 Mdot
.594 .04904 Mdot
.594 .04915 Mdot
.594 .04941 Mdot
.594 .04949 Mdot
.594 .0495 Mdot
.594 .04964 Mdot
.594 .04967 Mdot
.594 .04989 Mdot
.594 .05045 Mdot
.594 .05058 Mdot
.594 .0508 Mdot
.594 .05081 Mdot
.594 .05122 Mdot
.594 .05131 Mdot
.594 .05132 Mdot
.594 .05134 Mdot
.594 .05135 Mdot
.594 .05141 Mdot
.594 .0515 Mdot
.594 .0519 Mdot
.594 .05194 Mdot
.594 .0523 Mdot
.594 .05234 Mdot
.594 .05244 Mdot
.594 .05257 Mdot
.594 .05294 Mdot
.594 .05298 Mdot
.594 .05301 Mdot
.594 .05324 Mdot
.594 .05336 Mdot
.594 .05342 Mdot
.594 .05343 Mdot
.594 .05358 Mdot
.594 .05364 Mdot
.594 .05367 Mdot
.594 .05369 Mdot
.594 .05421 Mdot
.594 .05426 Mdot
.594 .05452 Mdot
.594 .05453 Mdot
.594 .05536 Mdot
.594 .05541 Mdot
.594 .05541 Mdot
.594 .0555 Mdot
.594 .05562 Mdot
.594 .05578 Mdot
.594 .05593 Mdot
.594 .05603 Mdot
.594 .05604 Mdot
.594 .05609 Mdot
.594 .0562 Mdot
.594 .05624 Mdot
.594 .0565 Mdot
.594 .05717 Mdot
.594 .05732 Mdot
.594 .05758 Mdot
.594 .05759 Mdot
.594 .05809 Mdot
.594 .05819 Mdot
.594 .0582 Mdot
.594 .05822 Mdot
.594 .05824 Mdot
.594 .05831 Mdot
.594 .05841 Mdot
.594 .05889 Mdot
.594 .05893 Mdot
.594 .05937 Mdot
.594 .05941 Mdot
.594 .05953 Mdot
.594 .05968 Mdot
.594 .06013 Mdot
.594 .06017 Mdot
.594 .0602 Mdot
.594 .06048 Mdot
.594 .06062 Mdot
.594 .0607 Mdot
.594 .06071 Mdot
.594 .06088 Mdot
.594 .06095 Mdot
.594 .06099 Mdot
.594 .06102 Mdot
.594 .06163 Mdot
.594 .06169 Mdot
.594 .062 Mdot
.594 .06202 Mdot
.594 .06205 Mdot
.594 .06301 Mdot
.594 .06306 Mdot
.594 .06306 Mdot
.594 .06317 Mdot
.594 .06331 Mdot
.594 .0635 Mdot
.594 .06351 Mdot
.594 .06368 Mdot
.594 .0638 Mdot
.594 .06381 Mdot
.594 .06387 Mdot
.594 .064 Mdot
.594 .06405 Mdot
.594 .06436 Mdot
.594 .06515 Mdot
.594 .06533 Mdot
.594 .06564 Mdot
.594 .06566 Mdot
.594 .06592 Mdot
.594 .06603 Mdot
.594 .06624 Mdot
.594 .06637 Mdot
.594 .06638 Mdot
.594 .0664 Mdot
.594 .06642 Mdot
.594 .06651 Mdot
.594 .06663 Mdot
.594 .0672 Mdot
.594 .06725 Mdot
.594 .06777 Mdot
.594 .06781 Mdot
.594 .06796 Mdot
.594 .06811 Mdot
.594 .06814 Mdot
.594 .06867 Mdot
.594 .06872 Mdot
.594 .06876 Mdot
.594 .06899 Mdot
.594 .06908 Mdot
.594 .06925 Mdot
.594 .06935 Mdot
.594 .06936 Mdot
.594 .06956 Mdot
.594 .06965 Mdot
.594 .06969 Mdot
.594 .06972 Mdot
.594 .07045 Mdot
.594 .07052 Mdot
.594 .07067 Mdot
.594 .07089 Mdot
.594 .07091 Mdot
.594 .07095 Mdot
.594 .07166 Mdot
.594 .07173 Mdot
.594 .07194 Mdot
.594 .07206 Mdot
.594 .07208 Mdot
.594 .07215 Mdot
.594 .07215 Mdot
.594 .07227 Mdot
.594 .07245 Mdot
.594 .07267 Mdot
.594 .07268 Mdot
.594 .07277 Mdot
.594 .07289 Mdot
.594 .07302 Mdot
.594 .07303 Mdot
.594 .07311 Mdot
.594 .07327 Mdot
.594 .07333 Mdot
.594 .07369 Mdot
.594 .07374 Mdot
.594 .07463 Mdot
.594 .07485 Mdot
.594 .07522 Mdot
.594 .07523 Mdot
.594 .07555 Mdot
.594 .07568 Mdot
.594 .07593 Mdot
.594 .07608 Mdot
.594 .07609 Mdot
.594 .07612 Mdot
.594 .07614 Mdot
.594 .07624 Mdot
.594 .07639 Mdot
.594 .07707 Mdot
.594 .07712 Mdot
.594 .07774 Mdot
.594 .07779 Mdot
.594 .07797 Mdot
.594 .07815 Mdot
.594 .07818 Mdot
.594 .07823 Mdot
.594 .07861 Mdot
.594 .07881 Mdot
.594 .07887 Mdot
.594 .07892 Mdot
.594 .07919 Mdot
.594 .07931 Mdot
.594 .0795 Mdot
.594 .07962 Mdot
.594 .07963 Mdot
.594 .07987 Mdot
.594 .07995 Mdot
.594 .07997 Mdot
.594 .08003 Mdot
.594 .08006 Mdot
.594 .08093 Mdot
.594 .08101 Mdot
.594 .08119 Mdot
.594 .08145 Mdot
.594 .08148 Mdot
.594 .08152 Mdot
.594 .08237 Mdot
.594 .08245 Mdot
.594 .0827 Mdot
.594 .08284 Mdot
.594 .08287 Mdot
.594 .08295 Mdot
.594 .08295 Mdot
.594 .0831 Mdot
.594 .0833 Mdot
.594 .08356 Mdot
.594 .08358 Mdot
.594 .08368 Mdot
.594 .08383 Mdot
.594 .08399 Mdot
.594 .084 Mdot
.594 .08409 Mdot
.594 .08428 Mdot
.594 .08435 Mdot
.594 .08478 Mdot
.594 .08483 Mdot
.594 .0859 Mdot
.594 .08616 Mdot
.594 .08659 Mdot
.594 .08661 Mdot
.594 .08698 Mdot
.594 .08714 Mdot
.594 .08744 Mdot
.594 .08762 Mdot
.594 .08763 Mdot
.594 .08766 Mdot
.594 .08769 Mdot
.594 .08781 Mdot
.594 .08799 Mdot
.594 .08879 Mdot
.594 .08886 Mdot
.594 .08959 Mdot
.594 .08965 Mdot
.594 .08986 Mdot
.594 .09008 Mdot
.594 .09011 Mdot
.594 .09017 Mdot
.594 .09063 Mdot
.594 .09086 Mdot
.594 .09094 Mdot
.594 .09099 Mdot
.594 .09131 Mdot
.594 .09145 Mdot
.594 .09169 Mdot
.594 .09182 Mdot
.594 .09184 Mdot
.594 .09212 Mdot
.594 .09222 Mdot
.594 .09224 Mdot
.594 .09231 Mdot
.594 .09235 Mdot
.594 .09338 Mdot
.594 .09348 Mdot
.594 .09369 Mdot
.594 .094 Mdot
.594 .09403 Mdot
.594 .09408 Mdot
.594 .09509 Mdot
.594 .09518 Mdot
.594 .09548 Mdot
.594 .09564 Mdot
.594 .09568 Mdot
.594 .09577 Mdot
.594 .09578 Mdot
.594 .09595 Mdot
.594 .0962 Mdot
.594 .09651 Mdot
.594 .09652 Mdot
.594 .09665 Mdot
.594 .09682 Mdot
.594 .09701 Mdot
.594 .09702 Mdot
.594 .09713 Mdot
.594 .09736 Mdot
.594 .09744 Mdot
.594 .09795 Mdot
.594 .09802 Mdot
.594 .09928 Mdot
.594 .09959 Mdot
.594 .1001 Mdot
.594 .10012 Mdot
.594 .10057 Mdot
.594 .10075 Mdot
.594 .10111 Mdot
.594 .10132 Mdot
.594 .10133 Mdot
.594 .10138 Mdot
.594 .1014 Mdot
.594 .10155 Mdot
.594 .10176 Mdot
.594 .10271 Mdot
.594 .10279 Mdot
.594 .10367 Mdot
.594 .10374 Mdot
.594 .10399 Mdot
.594 .10425 Mdot
.594 .10429 Mdot
.594 .10436 Mdot
.594 .1049 Mdot
.594 .10518 Mdot
.594 .10527 Mdot
.594 .10533 Mdot
.594 .10571 Mdot
.594 .10587 Mdot
.594 .10616 Mdot
.594 .10632 Mdot
.594 .10634 Mdot
.594 .10668 Mdot
.594 .10679 Mdot
.594 .10682 Mdot
.594 .1069 Mdot
.594 .10694 Mdot
.594 .10817 Mdot
.594 .10829 Mdot
.594 .10854 Mdot
.594 .1089 Mdot
.594 .10894 Mdot
.594 .109 Mdot
.594 .1102 Mdot
.594 .11031 Mdot
.594 .11067 Mdot
.594 .11086 Mdot
.594 .1109 Mdot
.594 .11101 Mdot
.594 .11101 Mdot
.594 .11122 Mdot
.594 .11151 Mdot
.594 .11188 Mdot
.594 .1119 Mdot
.594 .11205 Mdot
.594 .11226 Mdot
.594 .11248 Mdot
.594 .1125 Mdot
.594 .11262 Mdot
.594 .11289 Mdot
.594 .11299 Mdot
.594 .1136 Mdot
.594 .11368 Mdot
.594 .11518 Mdot
.594 .11554 Mdot
.594 .11615 Mdot
.594 .11618 Mdot
.594 .11671 Mdot
.594 .11693 Mdot
.594 .11735 Mdot
.594 .1176 Mdot
.594 .11762 Mdot
.594 .11767 Mdot
.594 .1177 Mdot
.594 .11788 Mdot
.594 .11812 Mdot
.594 .11926 Mdot
.594 .11935 Mdot
.594 .12039 Mdot
.594 .12048 Mdot
.594 .12077 Mdot
.594 .12108 Mdot
.594 .12113 Mdot
.594 .12121 Mdot
.594 .12185 Mdot
.594 .12219 Mdot
.594 .12229 Mdot
.594 .12236 Mdot
.594 .12281 Mdot
.594 .12301 Mdot
.594 .12335 Mdot
.594 .12354 Mdot
.594 .12356 Mdot
.594 .12396 Mdot
.594 .1241 Mdot
.594 .12413 Mdot
.594 .12423 Mdot
.594 .12428 Mdot
.594 .12573 Mdot
.594 .12588 Mdot
.594 .12617 Mdot
.594 .12661 Mdot
.594 .12665 Mdot
.594 .12673 Mdot
.594 .12815 Mdot
.594 .12828 Mdot
.594 .1287 Mdot
.594 .12893 Mdot
.594 .12899 Mdot
.594 .12912 Mdot
.594 .12912 Mdot
.594 .12937 Mdot
.594 .12971 Mdot
.594 .13015 Mdot
.594 .13017 Mdot
.594 .13035 Mdot
.594 .13059 Mdot
.594 .13086 Mdot
.594 .13088 Mdot
.594 .13103 Mdot
.594 .13135 Mdot
.594 .13146 Mdot
.594 .13219 Mdot
.594 .13228 Mdot
.594 .13407 Mdot
.594 .1345 Mdot
.594 .13522 Mdot
.594 .13526 Mdot
.594 .13588 Mdot
.594 .13614 Mdot
.594 .13665 Mdot
.594 .13694 Mdot
.594 .13696 Mdot
.594 .13703 Mdot
.594 .13706 Mdot
.594 .13728 Mdot
.594 .13757 Mdot
.594 .13891 Mdot
.594 .13903 Mdot
.594 .13943 Mdot
.594 .14026 Mdot
.594 .14036 Mdot
.594 .14071 Mdot
.594 .14108 Mdot
.594 .14113 Mdot
.594 .14123 Mdot
.594 .14199 Mdot
.594 .14239 Mdot
.594 .14251 Mdot
.594 .1426 Mdot
.594 .14314 Mdot
.594 .14337 Mdot
.594 .14377 Mdot
.594 .144 Mdot
.594 .14402 Mdot
.594 .1445 Mdot
.594 .14466 Mdot
.594 .1447 Mdot
.594 .14482 Mdot
.594 .14488 Mdot
.594 .14661 Mdot
.594 .14678 Mdot
.594 .14713 Mdot
.594 .14765 Mdot
.594 .1477 Mdot
.594 .14779 Mdot
.594 .14948 Mdot
.594 .14963 Mdot
.594 .15013 Mdot
.594 .15041 Mdot
.594 .15047 Mdot
.594 .15062 Mdot
.594 .15063 Mdot
.594 .15092 Mdot
.594 .15133 Mdot
.594 .15185 Mdot
.594 .15188 Mdot
.594 .15209 Mdot
.594 .15238 Mdot
.594 .1527 Mdot
.594 .15272 Mdot
.594 .15289 Mdot
.594 .15328 Mdot
.594 .15341 Mdot
.594 .15428 Mdot
.594 .15438 Mdot
.594 .1565 Mdot
.594 .15702 Mdot
.594 .15788 Mdot
.594 .15792 Mdot
.594 .15866 Mdot
.594 .15897 Mdot
.594 .15957 Mdot
.594 .15992 Mdot
.594 .15995 Mdot
.594 .16002 Mdot
.594 .16006 Mdot
.594 .16032 Mdot
.594 .16066 Mdot
.594 .16226 Mdot
.594 .1624 Mdot
.594 .16287 Mdot
.594 .16386 Mdot
.594 .16398 Mdot
.594 .1644 Mdot
.594 .16483 Mdot
.594 .1649 Mdot
.594 .16502 Mdot
.594 .16592 Mdot
.594 .16639 Mdot
.594 .16654 Mdot
.594 .16664 Mdot
.594 .16728 Mdot
.594 .16756 Mdot
.594 .16803 Mdot
.594 .1683 Mdot
.594 .16833 Mdot
.594 .1689 Mdot
.594 .16909 Mdot
.594 .16914 Mdot
.594 .16927 Mdot
.594 .16935 Mdot
.594 .1714 Mdot
.594 .1716 Mdot
.594 .17202 Mdot
.594 .17264 Mdot
.594 .1727 Mdot
.594 .17281 Mdot
.594 .17481 Mdot
.594 .175 Mdot
.594 .17559 Mdot
.594 .17592 Mdot
.594 .17599 Mdot
.594 .17618 Mdot
.594 .17618 Mdot
.594 .17653 Mdot
.594 .17701 Mdot
.594 .17763 Mdot
.594 .17766 Mdot
.594 .17792 Mdot
.594 .17826 Mdot
.594 .17864 Mdot
.594 .17867 Mdot
.594 .17887 Mdot
.594 .17933 Mdot
.594 .17949 Mdot
.594 .18051 Mdot
.594 .18064 Mdot
.594 .18316 Mdot
.594 .18377 Mdot
.594 .1848 Mdot
.594 .18484 Mdot
.594 .18572 Mdot
.594 .18609 Mdot
.594 .1868 Mdot
.594 .18722 Mdot
.594 .18725 Mdot
.594 .18734 Mdot
.594 .18739 Mdot
.594 .18769 Mdot
.594 .1881 Mdot
.594 .19 Mdot
.594 .19016 Mdot
.594 .19073 Mdot
.594 .1919 Mdot
.594 .19204 Mdot
.594 .19254 Mdot
.594 .19305 Mdot
.594 .19313 Mdot
.594 .19327 Mdot
.594 .19435 Mdot
.594 .19491 Mdot
.594 .19508 Mdot
.594 .1952 Mdot
.594 .19596 Mdot
.594 .19629 Mdot
.594 .19686 Mdot
.594 .19717 Mdot
.594 .19721 Mdot
.594 .19789 Mdot
.594 .19812 Mdot
.594 .19817 Mdot
.594 .19833 Mdot
.594 .19843 Mdot
.594 .20086 Mdot
.594 .2011 Mdot
.594 .2016 Mdot
.594 .20233 Mdot
.594 .2024 Mdot
.594 .20253 Mdot
.594 .20491 Mdot
.594 .20513 Mdot
.594 .20584 Mdot
.594 .20622 Mdot
.594 .20631 Mdot
.594 .20653 Mdot
.594 .20653 Mdot
.594 .20695 Mdot
.594 .20753 Mdot
.594 .20826 Mdot
.594 .2083 Mdot
.594 .2086 Mdot
.594 .20901 Mdot
.594 .20946 Mdot
.594 .20949 Mdot
.594 .20973 Mdot
.594 .21028 Mdot
.594 .21046 Mdot
.594 .21168 Mdot
.594 .21184 Mdot
.594 .21483 Mdot
.594 .21555 Mdot
.594 .21677 Mdot
.594 .21683 Mdot
.594 .21787 Mdot
.594 .21831 Mdot
.594 .21916 Mdot
.594 .21965 Mdot
.594 .21969 Mdot
.594 .21979 Mdot
.594 .21985 Mdot
.594 .22021 Mdot
.594 .2207 Mdot
.594 .22295 Mdot
.594 .22314 Mdot
.594 .22382 Mdot
.594 .22521 Mdot
.594 .22538 Mdot
.594 .22597 Mdot
.594 .22658 Mdot
.594 .22668 Mdot
.594 .22684 Mdot
.594 .22812 Mdot
.594 .22879 Mdot
.594 .22899 Mdot
.594 .22913 Mdot
.594 .23004 Mdot
.594 .23043 Mdot
.594 .2311 Mdot
.594 .23148 Mdot
.594 .23152 Mdot
.594 .23233 Mdot
.594 .2326 Mdot
.594 .23266 Mdot
.594 .23285 Mdot
.594 .23296 Mdot
.594 .23585 Mdot
.594 .23614 Mdot
.594 .23673 Mdot
.594 .2376 Mdot
.594 .23768 Mdot
.594 .23784 Mdot
.594 .24067 Mdot
.594 .24093 Mdot
.594 .24177 Mdot
.594 .24222 Mdot
.594 .24233 Mdot
.594 .24259 Mdot
.594 .24259 Mdot
.594 .24309 Mdot
.594 .24378 Mdot
.594 .24465 Mdot
.594 .24469 Mdot
.594 .24505 Mdot
.594 .24553 Mdot
.594 .24607 Mdot
.594 .24611 Mdot
.594 .2464 Mdot
.594 .24704 Mdot
.594 .24726 Mdot
.594 .24871 Mdot
.594 .24889 Mdot
.594 .25245 Mdot
.594 .25331 Mdot
.594 .25476 Mdot
.594 .25482 Mdot
.594 .25607 Mdot
.594 .25659 Mdot
.594 .25759 Mdot
.594 .25818 Mdot
.594 .25822 Mdot
.594 .25835 Mdot
.594 .25842 Mdot
.594 .25884 Mdot
.594 .25942 Mdot
.594 .2621 Mdot
.594 .26233 Mdot
.594 .26313 Mdot
.594 .26478 Mdot
.594 .26499 Mdot
.594 .26569 Mdot
.594 .26641 Mdot
.594 .26653 Mdot
.594 .26672 Mdot
.594 .26824 Mdot
.594 .26903 Mdot
.594 .26928 Mdot
.594 .26944 Mdot
.594 .27052 Mdot
.594 .27098 Mdot
.594 .27178 Mdot
.594 .27223 Mdot
.594 .27228 Mdot
.594 .27324 Mdot
.594 .27356 Mdot
.594 .27364 Mdot
.594 .27386 Mdot
.594 .27399 Mdot
.594 .27743 Mdot
.594 .27777 Mdot
.594 .27847 Mdot
.594 .2795 Mdot
.594 .2796 Mdot
.594 .27979 Mdot
.594 .28314 Mdot
.594 .28346 Mdot
.594 .28445 Mdot
.594 .285 Mdot
.594 .28513 Mdot
.594 .28543 Mdot
.594 .28544 Mdot
.594 .28602 Mdot
.594 .28684 Mdot
.594 .28788 Mdot
.594 .28793 Mdot
.594 .28835 Mdot
.594 .28893 Mdot
.594 .28956 Mdot
.594 .28961 Mdot
.594 .28995 Mdot
.594 .29072 Mdot
.594 .29098 Mdot
.594 .2927 Mdot
.594 .29292 Mdot
.594 .29715 Mdot
.594 .29817 Mdot
.594 .29988 Mdot
.594 .29996 Mdot
.594 .30144 Mdot
.594 .30206 Mdot
.594 .30325 Mdot
.594 .30396 Mdot
.594 .304 Mdot
.594 .30415 Mdot
.594 .30423 Mdot
.594 .30474 Mdot
.594 .30542 Mdot
.594 .30861 Mdot
.594 .30888 Mdot
.594 .30983 Mdot
.594 .31179 Mdot
.594 .31204 Mdot
.594 .31287 Mdot
.594 .31373 Mdot
.594 .31387 Mdot
.594 .3141 Mdot
.594 .3159 Mdot
.594 .31684 Mdot
.594 .31713 Mdot
.594 .31861 Mdot
.594 .31916 Mdot
.594 .32011 Mdot
.594 .32064 Mdot
.594 .32071 Mdot
.594 .32184 Mdot
.594 .32222 Mdot
.594 .32231 Mdot
.594 .32258 Mdot
.594 .32274 Mdot
.594 .32682 Mdot
.594 .32722 Mdot
.594 .32806 Mdot
.594 .32928 Mdot
.594 .3294 Mdot
.594 .32962 Mdot
.594 .33361 Mdot
.594 .33398 Mdot
.594 .33516 Mdot
.594 .33581 Mdot
.594 .33596 Mdot
.594 .33633 Mdot
.594 .33633 Mdot
.594 .33703 Mdot
.594 .338 Mdot
.594 .33923 Mdot
.594 .33929 Mdot
.594 .33979 Mdot
.594 .34048 Mdot
.594 .34123 Mdot
.594 .34129 Mdot
.594 .3417 Mdot
.594 .34261 Mdot
.594 .34292 Mdot
.594 .34497 Mdot
.594 .34522 Mdot
.594 .35024 Mdot
.594 .35146 Mdot
.594 .3535 Mdot
.594 .35359 Mdot
.594 .35534 Mdot
.594 .35608 Mdot
.594 .3575 Mdot
.594 .35833 Mdot
.594 .35839 Mdot
.594 .35857 Mdot
.594 .35866 Mdot
.594 .35926 Mdot
.594 .36008 Mdot
.594 .36386 Mdot
.594 .36418 Mdot
.594 .36531 Mdot
.596 .01507 Mdot
.596 .01514 Mdot
.596 .01522 Mdot
.596 .01532 Mdot
.596 .01544 Mdot
.596 .01557 Mdot
.596 .01574 Mdot
.596 .01593 Mdot
.596 .01617 Mdot
.596 .01645 Mdot
.596 .01663 Mdot
.596 .01678 Mdot
.596 .01689 Mdot
.596 .017 Mdot
.596 .01718 Mdot
.596 .01723 Mdot
.596 .01731 Mdot
.596 .01743 Mdot
.596 .01765 Mdot
.596 .01772 Mdot
.596 .01781 Mdot
.596 .01796 Mdot
.596 .01821 Mdot
.596 .01829 Mdot
.596 .0184 Mdot
.596 .01858 Mdot
.596 .01889 Mdot
.596 .01898 Mdot
.596 .01911 Mdot
.596 .01932 Mdot
.596 .01969 Mdot
.596 .0198 Mdot
.596 .01996 Mdot
.596 .0202 Mdot
.596 .02057 Mdot
.596 .02064 Mdot
.596 .02078 Mdot
.596 .02096 Mdot
.596 .02126 Mdot
.596 .0217 Mdot
.596 .02178 Mdot
.596 .0218 Mdot
.596 .02194 Mdot
.596 .02216 Mdot
.596 .02228 Mdot
.596 .02252 Mdot
.596 .02253 Mdot
.596 .02304 Mdot
.596 .02313 Mdot
.596 .02317 Mdot
.596 .02333 Mdot
.596 .02359 Mdot
.596 .02373 Mdot
.596 .02401 Mdot
.596 .02402 Mdot
.596 .02463 Mdot
.596 .02475 Mdot
.596 .02479 Mdot
.596 .02487 Mdot
.596 .02498 Mdot
.596 .02504 Mdot
.596 .0253 Mdot
.596 .02546 Mdot
.596 .0258 Mdot
.596 .02581 Mdot
.596 .02597 Mdot
.596 .02654 Mdot
.596 .02668 Mdot
.596 .02672 Mdot
.596 .02681 Mdot
.596 .02695 Mdot
.596 .02703 Mdot
.596 .02708 Mdot
.596 .02733 Mdot
.596 .02752 Mdot
.596 .02793 Mdot
.596 .02794 Mdot
.596 .02813 Mdot
.596 .02845 Mdot
.596 .02858 Mdot
.596 .02881 Mdot
.596 .02897 Mdot
.596 .02903 Mdot
.596 .02914 Mdot
.596 .0293 Mdot
.596 .02939 Mdot
.596 .02945 Mdot
.596 .02975 Mdot
.596 .02998 Mdot
.596 .03023 Mdot
.596 .03046 Mdot
.596 .03048 Mdot
.596 .0307 Mdot
.596 .03088 Mdot
.596 .03109 Mdot
.596 .03124 Mdot
.596 .03152 Mdot
.596 .03171 Mdot
.596 .03172 Mdot
.596 .03178 Mdot
.596 .03191 Mdot
.596 .03208 Mdot
.596 .0321 Mdot
.596 .03221 Mdot
.596 .03228 Mdot
.596 .03264 Mdot
.596 .03291 Mdot
.596 .03321 Mdot
.596 .03349 Mdot
.596 .03351 Mdot
.596 .03377 Mdot
.596 .03388 Mdot
.596 .03394 Mdot
.596 .03398 Mdot
.596 .03423 Mdot
.596 .03441 Mdot
.596 .03443 Mdot
.596 .03474 Mdot
.596 .03498 Mdot
.596 .03499 Mdot
.596 .03505 Mdot
.596 .03521 Mdot
.596 .03542 Mdot
.596 .03544 Mdot
.596 .03557 Mdot
.596 .03565 Mdot
.596 .03608 Mdot
.596 .0364 Mdot
.596 .03676 Mdot
.596 .03709 Mdot
.596 .03712 Mdot
.596 .03743 Mdot
.596 .03751 Mdot
.596 .03756 Mdot
.596 .03763 Mdot
.596 .03768 Mdot
.596 .03797 Mdot
.596 .03819 Mdot
.596 .03821 Mdot
.596 .03859 Mdot
.596 .03887 Mdot
.596 .03888 Mdot
.596 .03896 Mdot
.596 .03914 Mdot
.596 .03915 Mdot
.596 .03939 Mdot
.596 .0394 Mdot
.596 .03942 Mdot
.596 .03957 Mdot
.596 .03957 Mdot
.596 .03967 Mdot
.596 .04019 Mdot
.596 .04057 Mdot
.596 .04099 Mdot
.596 .041 Mdot
.596 .04139 Mdot
.596 .04142 Mdot
.596 .04178 Mdot
.596 .04179 Mdot
.596 .04189 Mdot
.596 .04195 Mdot
.596 .04203 Mdot
.596 .04208 Mdot
.596 .04244 Mdot
.596 .0427 Mdot
.596 .04272 Mdot
.596 .04299 Mdot
.596 .04317 Mdot
.596 .0435 Mdot
.596 .04352 Mdot
.596 .04361 Mdot
.596 .04369 Mdot
.596 .04383 Mdot
.596 .04385 Mdot
.596 .04413 Mdot
.596 .04414 Mdot
.596 .04416 Mdot
.596 .04435 Mdot
.596 .04435 Mdot
.596 .04446 Mdot
.596 .04508 Mdot
.596 .04553 Mdot
.596 .04604 Mdot
.596 .04605 Mdot
.596 .04651 Mdot
.596 .04655 Mdot
.596 .04697 Mdot
.596 .04699 Mdot
.596 .04711 Mdot
.596 .04718 Mdot
.596 .04728 Mdot
.596 .04734 Mdot
.596 .04776 Mdot
.596 .04808 Mdot
.596 .0481 Mdot
.596 .04842 Mdot
.596 .04863 Mdot
.596 .04865 Mdot
.596 .04903 Mdot
.596 .04905 Mdot
.596 .04916 Mdot
.596 .04926 Mdot
.596 .04932 Mdot
.596 .04942 Mdot
.596 .04944 Mdot
.596 .04969 Mdot
.596 .04977 Mdot
.596 .04979 Mdot
.596 .04981 Mdot
.596 .05003 Mdot
.596 .05004 Mdot
.596 .05017 Mdot
.596 .05091 Mdot
.596 .05145 Mdot
.596 .0518 Mdot
.596 .05205 Mdot
.596 .05206 Mdot
.596 .0523 Mdot
.596 .0526 Mdot
.596 .05261 Mdot
.596 .05266 Mdot
.596 .05317 Mdot
.596 .05318 Mdot
.596 .05333 Mdot
.596 .05341 Mdot
.596 .05353 Mdot
.596 .0536 Mdot
.596 .05411 Mdot
.596 .05448 Mdot
.596 .05451 Mdot
.596 .0549 Mdot
.596 .05514 Mdot
.596 .05517 Mdot
.596 .05562 Mdot
.596 .05564 Mdot
.596 .05577 Mdot
.596 .05589 Mdot
.596 .05597 Mdot
.596 .05608 Mdot
.596 .05611 Mdot
.596 .05637 Mdot
.596 .0564 Mdot
.596 .0565 Mdot
.596 .05651 Mdot
.596 .05652 Mdot
.596 .05655 Mdot
.596 .05682 Mdot
.596 .05682 Mdot
.596 .05698 Mdot
.596 .05785 Mdot
.596 .05826 Mdot
.596 .0585 Mdot
.596 .05878 Mdot
.596 .0588 Mdot
.596 .05892 Mdot
.596 .05905 Mdot
.596 .05922 Mdot
.596 .05923 Mdot
.596 .05951 Mdot
.596 .05966 Mdot
.596 .05988 Mdot
.596 .05989 Mdot
.596 .05994 Mdot
.596 .06055 Mdot
.596 .06057 Mdot
.596 .06074 Mdot
.596 .06084 Mdot
.596 .06099 Mdot
.596 .06107 Mdot
.596 .06167 Mdot
.596 .06175 Mdot
.596 .06212 Mdot
.596 .06215 Mdot
.596 .06261 Mdot
.596 .06263 Mdot
.596 .06291 Mdot
.596 .06294 Mdot
.596 .06337 Mdot
.596 .06346 Mdot
.596 .06347 Mdot
.596 .0635 Mdot
.596 .06365 Mdot
.596 .06366 Mdot
.596 .06379 Mdot
.596 .06389 Mdot
.596 .06403 Mdot
.596 .06405 Mdot
.596 .06437 Mdot
.596 .06441 Mdot
.596 .06452 Mdot
.596 .06453 Mdot
.596 .06455 Mdot
.596 .06458 Mdot
.596 .0649 Mdot
.596 .0649 Mdot
.596 .06495 Mdot
.596 .06499 Mdot
.596 .06509 Mdot
.596 .06609 Mdot
.596 .06614 Mdot
.596 .06662 Mdot
.596 .06687 Mdot
.596 .0669 Mdot
.596 .06724 Mdot
.596 .06727 Mdot
.596 .0674 Mdot
.596 .06756 Mdot
.596 .06776 Mdot
.596 .06778 Mdot
.596 .06802 Mdot
.596 .06811 Mdot
.596 .06824 Mdot
.596 .06829 Mdot
.596 .06855 Mdot
.596 .06856 Mdot
.596 .06863 Mdot
.596 .06935 Mdot
.596 .06937 Mdot
.596 .06958 Mdot
.596 .06969 Mdot
.596 .06987 Mdot
.596 .06997 Mdot
.596 .07069 Mdot
.596 .07079 Mdot
.596 .07084 Mdot
.596 .07114 Mdot
.596 .07122 Mdot
.596 .07126 Mdot
.596 .07181 Mdot
.596 .07183 Mdot
.596 .07208 Mdot
.596 .07216 Mdot
.596 .07216 Mdot
.596 .0722 Mdot
.596 .07228 Mdot
.596 .07259 Mdot
.596 .07271 Mdot
.596 .07282 Mdot
.596 .07283 Mdot
.596 .07286 Mdot
.596 .07305 Mdot
.596 .07306 Mdot
.596 .07321 Mdot
.596 .07333 Mdot
.596 .07349 Mdot
.596 .07353 Mdot
.596 .0739 Mdot
.596 .07395 Mdot
.596 .07408 Mdot
.596 .07409 Mdot
.596 .07411 Mdot
.596 .07416 Mdot
.596 .07453 Mdot
.596 .07454 Mdot
.596 .0746 Mdot
.596 .07464 Mdot
.596 .07477 Mdot
.596 .0752 Mdot
.596 .07564 Mdot
.596 .07591 Mdot
.596 .07595 Mdot
.596 .07601 Mdot
.596 .07659 Mdot
.596 .0768 Mdot
.596 .07688 Mdot
.596 .07692 Mdot
.596 .07733 Mdot
.596 .07736 Mdot
.596 .07752 Mdot
.596 .07771 Mdot
.596 .07795 Mdot
.596 .07797 Mdot
.596 .07825 Mdot
.596 .07837 Mdot
.596 .07851 Mdot
.596 .07857 Mdot
.596 .07889 Mdot
.596 .0789 Mdot
.596 .07898 Mdot
.596 .0798 Mdot
.596 .07984 Mdot
.596 .07987 Mdot
.596 .08011 Mdot
.596 .08025 Mdot
.596 .08046 Mdot
.596 .08058 Mdot
.596 .08144 Mdot
.596 .08155 Mdot
.596 .08161 Mdot
.596 .08198 Mdot
.596 .08207 Mdot
.596 .08212 Mdot
.596 .08277 Mdot
.596 .08279 Mdot
.596 .0831 Mdot
.596 .08319 Mdot
.596 .08319 Mdot
.596 .08323 Mdot
.596 .08334 Mdot
.596 .0837 Mdot
.596 .08385 Mdot
.596 .08398 Mdot
.596 .08399 Mdot
.596 .08403 Mdot
.596 .08425 Mdot
.596 .08426 Mdot
.596 .08445 Mdot
.596 .08458 Mdot
.596 .08478 Mdot
.596 .08482 Mdot
.596 .08527 Mdot
.596 .08532 Mdot
.596 .08548 Mdot
.596 .08549 Mdot
.596 .08552 Mdot
.596 .08557 Mdot
.596 .08602 Mdot
.596 .08603 Mdot
.596 .0861 Mdot
.596 .08614 Mdot
.596 .0863 Mdot
.596 .08681 Mdot
.596 .08733 Mdot
.596 .08765 Mdot
.596 .08771 Mdot
.596 .08778 Mdot
.596 .08847 Mdot
.596 .08872 Mdot
.596 .08882 Mdot
.596 .08887 Mdot
.596 .08935 Mdot
.596 .08939 Mdot
.596 .08958 Mdot
.596 .08981 Mdot
.596 .09009 Mdot
.596 .09011 Mdot
.596 .09045 Mdot
.596 .09059 Mdot
.596 .09076 Mdot
.596 .09084 Mdot
.596 .09121 Mdot
.596 .09122 Mdot
.596 .09132 Mdot
.596 .09229 Mdot
.596 .09234 Mdot
.596 .09238 Mdot
.596 .09267 Mdot
.596 .09283 Mdot
.596 .09308 Mdot
.596 .09323 Mdot
.596 .09425 Mdot
.596 .09438 Mdot
.596 .09446 Mdot
.596 .09489 Mdot
.596 .095 Mdot
.596 .09506 Mdot
.596 .09584 Mdot
.596 .09586 Mdot
.596 .09622 Mdot
.596 .09633 Mdot
.596 .09634 Mdot
.596 .09639 Mdot
.596 .09651 Mdot
.596 .09694 Mdot
.596 .09712 Mdot
.596 .09728 Mdot
.596 .09729 Mdot
.596 .09734 Mdot
.596 .0976 Mdot
.596 .09761 Mdot
.596 .09784 Mdot
.596 .098 Mdot
.596 .09823 Mdot
.596 .09828 Mdot
.596 .09881 Mdot
.596 .09888 Mdot
.596 .09907 Mdot
.596 .09908 Mdot
.596 .09911 Mdot
.596 .09917 Mdot
.596 .09971 Mdot
.596 .09972 Mdot
.596 .0998 Mdot
.596 .09986 Mdot
.596 .10004 Mdot
.596 .10066 Mdot
.596 .10128 Mdot
.596 .10166 Mdot
.596 .10172 Mdot
.596 .10181 Mdot
.596 .10263 Mdot
.596 .10293 Mdot
.596 .10304 Mdot
.596 .10311 Mdot
.596 .10368 Mdot
.596 .10372 Mdot
.596 .10395 Mdot
.596 .10422 Mdot
.596 .10456 Mdot
.596 .10459 Mdot
.596 .105 Mdot
.596 .10515 Mdot
.596 .10536 Mdot
.596 .10545 Mdot
.596 .10589 Mdot
.596 .10591 Mdot
.596 .10603 Mdot
.596 .10719 Mdot
.596 .10725 Mdot
.596 .10729 Mdot
.596 .10764 Mdot
.596 .10783 Mdot
.596 .10813 Mdot
.596 .1083 Mdot
.596 .10952 Mdot
.596 .10968 Mdot
.596 .10977 Mdot
.596 .11029 Mdot
.596 .11041 Mdot
.596 .11049 Mdot
.596 .11141 Mdot
.596 .11144 Mdot
.596 .11187 Mdot
.596 .112 Mdot
.596 .11201 Mdot
.596 .11207 Mdot
.596 .11222 Mdot
.596 .11273 Mdot
.596 .11295 Mdot
.596 .11313 Mdot
.596 .11315 Mdot
.596 .1132 Mdot
.596 .11352 Mdot
.596 .11352 Mdot
.596 .11379 Mdot
.596 .11399 Mdot
.596 .11427 Mdot
.596 .11432 Mdot
.596 .11496 Mdot
.596 .11504 Mdot
.596 .11526 Mdot
.596 .11528 Mdot
.596 .11531 Mdot
.596 .11539 Mdot
.596 .11603 Mdot
.596 .11604 Mdot
.596 .11614 Mdot
.596 .1162 Mdot
.596 .11642 Mdot
.596 .11716 Mdot
.596 .1179 Mdot
.596 .11835 Mdot
.596 .11843 Mdot
.596 .11853 Mdot
.596 .11951 Mdot
.596 .11987 Mdot
.596 .12 Mdot
.596 .12008 Mdot
.596 .12076 Mdot
.596 .12081 Mdot
.596 .12108 Mdot
.596 .12141 Mdot
.596 .12181 Mdot
.596 .12185 Mdot
.596 .12233 Mdot
.596 .12252 Mdot
.596 .12277 Mdot
.596 .12287 Mdot
.596 .1234 Mdot
.596 .12342 Mdot
.596 .12356 Mdot
.596 .12494 Mdot
.596 .12501 Mdot
.596 .12506 Mdot
.596 .12548 Mdot
.596 .12571 Mdot
.596 .12606 Mdot
.596 .12627 Mdot
.596 .12772 Mdot
.596 .12791 Mdot
.596 .12802 Mdot
.596 .12864 Mdot
.596 .12878 Mdot
.596 .12887 Mdot
.596 .12998 Mdot
.596 .13001 Mdot
.596 .13053 Mdot
.596 .13068 Mdot
.596 .13069 Mdot
.596 .13076 Mdot
.596 .13094 Mdot
.596 .13155 Mdot
.596 .13181 Mdot
.596 .13202 Mdot
.596 .13205 Mdot
.596 .13211 Mdot
.596 .13249 Mdot
.596 .1325 Mdot
.596 .13282 Mdot
.596 .13305 Mdot
.596 .13338 Mdot
.596 .13345 Mdot
.596 .13421 Mdot
.596 .1343 Mdot
.596 .13457 Mdot
.596 .13459 Mdot
.596 .13463 Mdot
.596 .13472 Mdot
.596 .13548 Mdot
.596 .13549 Mdot
.596 .13561 Mdot
.596 .13569 Mdot
.596 .13595 Mdot
.596 .13683 Mdot
.596 .13771 Mdot
.596 .13825 Mdot
.596 .13834 Mdot
.596 .13846 Mdot
.596 .13963 Mdot
.596 .14006 Mdot
.596 .14022 Mdot
.596 .14031 Mdot
.596 .14112 Mdot
.596 .14119 Mdot
.596 .14151 Mdot
.596 .14189 Mdot
.596 .14237 Mdot
.596 .14242 Mdot
.596 .14299 Mdot
.596 .14322 Mdot
.596 .14351 Mdot
.596 .14364 Mdot
.596 .14427 Mdot
.596 .14429 Mdot
.596 .14446 Mdot
.596 .1461 Mdot
.596 .14619 Mdot
.596 .14625 Mdot
.596 .14675 Mdot
.596 .14702 Mdot
.596 .14744 Mdot
.596 .14769 Mdot
.596 .14942 Mdot
.596 .14965 Mdot
.596 .14978 Mdot
.596 .15051 Mdot
.596 .15069 Mdot
.596 .15079 Mdot
.596 .15211 Mdot
.596 .15215 Mdot
.596 .15276 Mdot
.596 .15295 Mdot
.596 .15295 Mdot
.596 .15304 Mdot
.596 .15325 Mdot
.596 .15398 Mdot
.596 .15429 Mdot
.596 .15455 Mdot
.596 .15458 Mdot
.596 .15465 Mdot
.596 .1551 Mdot
.596 .15511 Mdot
.596 .15549 Mdot
.596 .15577 Mdot
.596 .15617 Mdot
.596 .15624 Mdot
.596 .15715 Mdot
.596 .15726 Mdot
.596 .15758 Mdot
.596 .15761 Mdot
.596 .15765 Mdot
.596 .15776 Mdot
.596 .15867 Mdot
.596 .15868 Mdot
.596 .15882 Mdot
.596 .15892 Mdot
.596 .15923 Mdot
.596 .16027 Mdot
.596 .16132 Mdot
.596 .16197 Mdot
.596 .16208 Mdot
.596 .16222 Mdot
.596 .16361 Mdot
.596 .16412 Mdot
.596 .16432 Mdot
.596 .16442 Mdot
.596 .16539 Mdot
.596 .16547 Mdot
.596 .16585 Mdot
.596 .16631 Mdot
.596 .16688 Mdot
.596 .16694 Mdot
.596 .16762 Mdot
.596 .16789 Mdot
.596 .16824 Mdot
.596 .16839 Mdot
.596 .16914 Mdot
.596 .16916 Mdot
.596 .16937 Mdot
.596 .17065 Mdot
.596 .17133 Mdot
.596 .17143 Mdot
.596 .17151 Mdot
.596 .1721 Mdot
.596 .17242 Mdot
.596 .17293 Mdot
.596 .17322 Mdot
.596 .17528 Mdot
.596 .17556 Mdot
.596 .17571 Mdot
.596 .17658 Mdot
.596 .17679 Mdot
.596 .17692 Mdot
.596 .17849 Mdot
.596 .17854 Mdot
.596 .17927 Mdot
.596 .17949 Mdot
.596 .1795 Mdot
.596 .1796 Mdot
.596 .17985 Mdot
.596 .18072 Mdot
.596 .18108 Mdot
.596 .18139 Mdot
.596 .18143 Mdot
.596 .18151 Mdot
.596 .18205 Mdot
.596 .18206 Mdot
.596 .18252 Mdot
.596 .18285 Mdot
.596 .18333 Mdot
.596 .18342 Mdot
.596 .1845 Mdot
.596 .18462 Mdot
.596 .18501 Mdot
.596 .18504 Mdot
.596 .1851 Mdot
.596 .18522 Mdot
.596 .18631 Mdot
.596 .18632 Mdot
.596 .18649 Mdot
.596 .1866 Mdot
.596 .18697 Mdot
.596 .18822 Mdot
.596 .18947 Mdot
.596 .19024 Mdot
.596 .19037 Mdot
.596 .19054 Mdot
.596 .1922 Mdot
.596 .19281 Mdot
.596 .19304 Mdot
.596 .19316 Mdot
.596 .19432 Mdot
.596 .19441 Mdot
.596 .19487 Mdot
.596 .19542 Mdot
.596 .1961 Mdot
.596 .19616 Mdot
.596 .19698 Mdot
.596 .1973 Mdot
.596 .19772 Mdot
.596 .1979 Mdot
.596 .19879 Mdot
.596 .19882 Mdot
.596 .19906 Mdot
.596 .20059 Mdot
.596 .2014 Mdot
.596 .20152 Mdot
.596 .20161 Mdot
.596 .20232 Mdot
.596 .2027 Mdot
.596 .2033 Mdot
.596 .20365 Mdot
.596 .20611 Mdot
.596 .20644 Mdot
.596 .20662 Mdot
.596 .20766 Mdot
.596 .20791 Mdot
.596 .20806 Mdot
.596 .20993 Mdot
.596 .20999 Mdot
.596 .21086 Mdot
.596 .21112 Mdot
.596 .21113 Mdot
.596 .21126 Mdot
.596 .21156 Mdot
.596 .2126 Mdot
.596 .21303 Mdot
.596 .2134 Mdot
.596 .21344 Mdot
.596 .21354 Mdot
.596 .21418 Mdot
.596 .2142 Mdot
.596 .21474 Mdot
.596 .21513 Mdot
.596 .2157 Mdot
.596 .21581 Mdot
.596 .2171 Mdot
.596 .21725 Mdot
.596 .21771 Mdot
.596 .21775 Mdot
.596 .21781 Mdot
.596 .21796 Mdot
.596 .21926 Mdot
.596 .21927 Mdot
.596 .21947 Mdot
.596 .21961 Mdot
.596 .22005 Mdot
.596 .22153 Mdot
.596 .22303 Mdot
.596 .22394 Mdot
.596 .2241 Mdot
.596 .2243 Mdot
.596 .22627 Mdot
.596 .227 Mdot
.596 .22728 Mdot
.596 .22743 Mdot
.596 .22881 Mdot
.596 .22891 Mdot
.596 .22946 Mdot
.596 .23011 Mdot
.596 .23092 Mdot
.596 .231 Mdot
.596 .23197 Mdot
.596 .23236 Mdot
.596 .23286 Mdot
.596 .23307 Mdot
.596 .23413 Mdot
.596 .23417 Mdot
.596 .23445 Mdot
.596 .23628 Mdot
.596 .23724 Mdot
.596 .23739 Mdot
.596 .23749 Mdot
.596 .23833 Mdot
.596 .23879 Mdot
.596 .23951 Mdot
.596 .23992 Mdot
.596 .24285 Mdot
.596 .24325 Mdot
.596 .24346 Mdot
.596 .24471 Mdot
.596 .245 Mdot
.596 .24519 Mdot
.596 .24741 Mdot
.596 .24748 Mdot
.596 .24853 Mdot
.596 .24883 Mdot
.596 .24885 Mdot
.596 .24899 Mdot
.596 .24935 Mdot
.596 .25059 Mdot
.596 .2511 Mdot
.596 .25154 Mdot
.596 .2516 Mdot
.596 .25171 Mdot
.596 .25248 Mdot
.596 .2525 Mdot
.596 .25315 Mdot
.596 .25361 Mdot
.596 .25429 Mdot
.596 .25442 Mdot
.596 .25595 Mdot
.596 .25613 Mdot
.596 .25669 Mdot
.596 .25673 Mdot
.596 .2568 Mdot
.596 .25698 Mdot
.596 .25853 Mdot
.596 .25855 Mdot
.596 .25879 Mdot
.596 .25894 Mdot
.596 .25947 Mdot
.596 .26124 Mdot
.596 .26302 Mdot
.596 .26412 Mdot
.596 .2643 Mdot
.596 .26454 Mdot
.596 .26689 Mdot
.596 .26776 Mdot
.596 .26809 Mdot
.596 .26827 Mdot
.596 .26991 Mdot
.596 .27004 Mdot
.596 .27069 Mdot
.596 .27147 Mdot
.596 .27244 Mdot
.596 .27253 Mdot
.596 .27369 Mdot
.596 .27414 Mdot
.596 .27474 Mdot
.596 .27499 Mdot
.596 .27626 Mdot
.596 .2763 Mdot
.596 .27664 Mdot
.596 .27882 Mdot
.596 .27997 Mdot
.596 .28014 Mdot
.596 .28027 Mdot
.596 .28127 Mdot
.596 .28182 Mdot
.596 .28267 Mdot
.596 .28316 Mdot
.596 .28666 Mdot
.596 .28713 Mdot
.596 .28738 Mdot
.596 .28887 Mdot
.596 .28922 Mdot
.596 .28944 Mdot
.596 .29209 Mdot
.596 .29218 Mdot
.596 .29342 Mdot
.596 .29378 Mdot
.596 .2938 Mdot
.596 .29397 Mdot
.596 .2944 Mdot
.596 .29588 Mdot
.596 .29649 Mdot
.596 .29701 Mdot
.596 .29708 Mdot
.596 .29722 Mdot
.596 .29813 Mdot
.596 .29815 Mdot
.596 .29893 Mdot
.596 .29947 Mdot
.596 .30029 Mdot
.596 .30044 Mdot
.596 .30227 Mdot
.596 .30248 Mdot
.596 .30314 Mdot
.596 .3032 Mdot
.596 .30329 Mdot
.596 .3035 Mdot
.596 .30534 Mdot
.596 .30565 Mdot
.596 .30584 Mdot
.596 .30646 Mdot
.596 .30857 Mdot
.596 .3107 Mdot
.596 .312 Mdot
.596 .31222 Mdot
.596 .31251 Mdot
.596 .31531 Mdot
.596 .31634 Mdot
.596 .31674 Mdot
.596 .31695 Mdot
.596 .31891 Mdot
.596 .31906 Mdot
.596 .31983 Mdot
.596 .32077 Mdot
.596 .32192 Mdot
.596 .32203 Mdot
.596 .32341 Mdot
.596 .32395 Mdot
.596 .32466 Mdot
.596 .32496 Mdot
.596 .32647 Mdot
.596 .32653 Mdot
.596 .32693 Mdot
.596 .32952 Mdot
.596 .3309 Mdot
.596 .3311 Mdot
.596 .33125 Mdot
.596 .33245 Mdot
.596 .3331 Mdot
.596 .33412 Mdot
.596 .33471 Mdot
.596 .33887 Mdot
.596 .33943 Mdot
.596 .33974 Mdot
.596 .3415 Mdot
.596 .34192 Mdot
.596 .34218 Mdot
.596 .34534 Mdot
.596 .34545 Mdot
.596 .34693 Mdot
.596 .34737 Mdot
.596 .34738 Mdot
.596 .34759 Mdot
.596 .3481 Mdot
.596 .34986 Mdot
.596 .35059 Mdot
.596 .35122 Mdot
.596 .35129 Mdot
.596 .35146 Mdot
.596 .35254 Mdot
.596 .35257 Mdot
.596 .35349 Mdot
.596 .35415 Mdot
.596 .35512 Mdot
.596 .3553 Mdot
.596 .35748 Mdot
.596 .35774 Mdot
.596 .35852 Mdot
.596 .35859 Mdot
.596 .35869 Mdot
.596 .35895 Mdot
.596 .36114 Mdot
.596 .36151 Mdot
.596 .36173 Mdot
.596 .36248 Mdot
.596 .36499 Mdot
.598 .01483 Mdot
.598 .01485 Mdot
.598 .01487 Mdot
.598 .0149 Mdot
.598 .01494 Mdot
.598 .01499 Mdot
.598 .01504 Mdot
.598 .0151 Mdot
.598 .01518 Mdot
.598 .01527 Mdot
.598 .01538 Mdot
.598 .01551 Mdot
.598 .01566 Mdot
.598 .01576 Mdot
.598 .01585 Mdot
.598 .01597 Mdot
.598 .01607 Mdot
.598 .01612 Mdot
.598 .01622 Mdot
.598 .01633 Mdot
.598 .0164 Mdot
.598 .01651 Mdot
.598 .01665 Mdot
.598 .01673 Mdot
.598 .01686 Mdot
.598 .01688 Mdot
.598 .01703 Mdot
.598 .01712 Mdot
.598 .01728 Mdot
.598 .01731 Mdot
.598 .01748 Mdot
.598 .0176 Mdot
.598 .01779 Mdot
.598 .01781 Mdot
.598 .01797 Mdot
.598 .01803 Mdot
.598 .01816 Mdot
.598 .01839 Mdot
.598 .01842 Mdot
.598 .0186 Mdot
.598 .01868 Mdot
.598 .01884 Mdot
.598 .01911 Mdot
.598 .01915 Mdot
.598 .01937 Mdot
.598 .01945 Mdot
.598 .01962 Mdot
.598 .01964 Mdot
.598 .01997 Mdot
.598 .02002 Mdot
.598 .02028 Mdot
.598 .02038 Mdot
.598 .02058 Mdot
.598 .02061 Mdot
.598 .02072 Mdot
.598 .02072 Mdot
.598 .021 Mdot
.598 .02106 Mdot
.598 .02137 Mdot
.598 .02149 Mdot
.598 .02173 Mdot
.598 .02176 Mdot
.598 .02189 Mdot
.598 .0219 Mdot
.598 .02223 Mdot
.598 .0223 Mdot
.598 .02267 Mdot
.598 .02267 Mdot
.598 .02282 Mdot
.598 .0231 Mdot
.598 .02315 Mdot
.598 .0233 Mdot
.598 .02331 Mdot
.598 .02362 Mdot
.598 .02371 Mdot
.598 .02379 Mdot
.598 .02423 Mdot
.598 .02423 Mdot
.598 .02427 Mdot
.598 .02441 Mdot
.598 .02474 Mdot
.598 .0248 Mdot
.598 .02498 Mdot
.598 .025 Mdot
.598 .02536 Mdot
.598 .02547 Mdot
.598 .02556 Mdot
.598 .02609 Mdot
.598 .0261 Mdot
.598 .02615 Mdot
.598 .02625 Mdot
.598 .02631 Mdot
.598 .02671 Mdot
.598 .02677 Mdot
.598 .02689 Mdot
.598 .02699 Mdot
.598 .02701 Mdot
.598 .02736 Mdot
.598 .02745 Mdot
.598 .02758 Mdot
.598 .02769 Mdot
.598 .02816 Mdot
.598 .02832 Mdot
.598 .02833 Mdot
.598 .02839 Mdot
.598 .02851 Mdot
.598 .02858 Mdot
.598 .02906 Mdot
.598 .02906 Mdot
.598 .02914 Mdot
.598 .0292 Mdot
.598 .02928 Mdot
.598 .02931 Mdot
.598 .0294 Mdot
.598 .0294 Mdot
.598 .02942 Mdot
.598 .02978 Mdot
.598 .02978 Mdot
.598 .02984 Mdot
.598 .02994 Mdot
.598 .0301 Mdot
.598 .03023 Mdot
.598 .0308 Mdot
.598 .03099 Mdot
.598 .031 Mdot
.598 .03107 Mdot
.598 .03121 Mdot
.598 .0313 Mdot
.598 .03187 Mdot
.598 .03187 Mdot
.598 .03196 Mdot
.598 .03204 Mdot
.598 .03214 Mdot
.598 .03217 Mdot
.598 .03228 Mdot
.598 .03228 Mdot
.598 .0323 Mdot
.598 .03269 Mdot
.598 .03273 Mdot
.598 .03274 Mdot
.598 .0328 Mdot
.598 .03293 Mdot
.598 .03311 Mdot
.598 .03327 Mdot
.598 .0335 Mdot
.598 .03381 Mdot
.598 .03395 Mdot
.598 .03418 Mdot
.598 .03419 Mdot
.598 .03427 Mdot
.598 .03444 Mdot
.598 .03455 Mdot
.598 .03523 Mdot
.598 .03523 Mdot
.598 .03535 Mdot
.598 .03544 Mdot
.598 .03555 Mdot
.598 .03559 Mdot
.598 .03572 Mdot
.598 .03572 Mdot
.598 .03575 Mdot
.598 .03592 Mdot
.598 .03621 Mdot
.598 .03627 Mdot
.598 .03627 Mdot
.598 .03634 Mdot
.598 .0365 Mdot
.598 .03672 Mdot
.598 .03691 Mdot
.598 .03718 Mdot
.598 .03755 Mdot
.598 .03772 Mdot
.598 .03782 Mdot
.598 .03799 Mdot
.598 .038 Mdot
.598 .03811 Mdot
.598 .03831 Mdot
.598 .0384 Mdot
.598 .03844 Mdot
.598 .03879 Mdot
.598 .03885 Mdot
.598 .03926 Mdot
.598 .03926 Mdot
.598 .03939 Mdot
.598 .0395 Mdot
.598 .03963 Mdot
.598 .03968 Mdot
.598 .03984 Mdot
.598 .03984 Mdot
.598 .03988 Mdot
.598 .04007 Mdot
.598 .04015 Mdot
.598 .04042 Mdot
.598 .04049 Mdot
.598 .04049 Mdot
.598 .04058 Mdot
.598 .04077 Mdot
.598 .04103 Mdot
.598 .04126 Mdot
.598 .04158 Mdot
.598 .04203 Mdot
.598 .04223 Mdot
.598 .04234 Mdot
.598 .04256 Mdot
.598 .04257 Mdot
.598 .04269 Mdot
.598 .04289 Mdot
.598 .04293 Mdot
.598 .04304 Mdot
.598 .04305 Mdot
.598 .04309 Mdot
.598 .0435 Mdot
.598 .04359 Mdot
.598 .04407 Mdot
.598 .04407 Mdot
.598 .04423 Mdot
.598 .04436 Mdot
.598 .04452 Mdot
.598 .04457 Mdot
.598 .04476 Mdot
.598 .04477 Mdot
.598 .04481 Mdot
.598 .04504 Mdot
.598 .04513 Mdot
.598 .04546 Mdot
.598 .04554 Mdot
.598 .04555 Mdot
.598 .04565 Mdot
.598 .04588 Mdot
.598 .04619 Mdot
.598 .04646 Mdot
.598 .04671 Mdot
.598 .04684 Mdot
.598 .04738 Mdot
.598 .04762 Mdot
.598 .04776 Mdot
.598 .04801 Mdot
.598 .04803 Mdot
.598 .04817 Mdot
.598 .04842 Mdot
.598 .04846 Mdot
.598 .04859 Mdot
.598 .0486 Mdot
.598 .04865 Mdot
.598 .04915 Mdot
.598 .04924 Mdot
.598 .04982 Mdot
.598 .04982 Mdot
.598 .05001 Mdot
.598 .0501 Mdot
.598 .05017 Mdot
.598 .05036 Mdot
.598 .05042 Mdot
.598 .05047 Mdot
.598 .05065 Mdot
.598 .05066 Mdot
.598 .0507 Mdot
.598 .05099 Mdot
.598 .0511 Mdot
.598 .0513 Mdot
.598 .05148 Mdot
.598 .05149 Mdot
.598 .05158 Mdot
.598 .05159 Mdot
.598 .05172 Mdot
.598 .05198 Mdot
.598 .05236 Mdot
.598 .05269 Mdot
.598 .05299 Mdot
.598 .05314 Mdot
.598 .05316 Mdot
.598 .05378 Mdot
.598 .05407 Mdot
.598 .05424 Mdot
.598 .05454 Mdot
.598 .05455 Mdot
.598 .05473 Mdot
.598 .05475 Mdot
.598 .05492 Mdot
.598 .05502 Mdot
.598 .05508 Mdot
.598 .05523 Mdot
.598 .05524 Mdot
.598 .0553 Mdot
.598 .05567 Mdot
.598 .0559 Mdot
.598 .05601 Mdot
.598 .05625 Mdot
.598 .0567 Mdot
.598 .0567 Mdot
.598 .05693 Mdot
.598 .05704 Mdot
.598 .05711 Mdot
.598 .05735 Mdot
.598 .05742 Mdot
.598 .05747 Mdot
.598 .05769 Mdot
.598 .0577 Mdot
.598 .05776 Mdot
.598 .0581 Mdot
.598 .05823 Mdot
.598 .05847 Mdot
.598 .05869 Mdot
.598 .0587 Mdot
.598 .05881 Mdot
.598 .05882 Mdot
.598 .05897 Mdot
.598 .05929 Mdot
.598 .05973 Mdot
.598 .06013 Mdot
.598 .06027 Mdot
.598 .06049 Mdot
.598 .06067 Mdot
.598 .06069 Mdot
.598 .06132 Mdot
.598 .06144 Mdot
.598 .06178 Mdot
.598 .06198 Mdot
.598 .06235 Mdot
.598 .06236 Mdot
.598 .06258 Mdot
.598 .0626 Mdot
.598 .0628 Mdot
.598 .06292 Mdot
.598 .06299 Mdot
.598 .06317 Mdot
.598 .06319 Mdot
.598 .06326 Mdot
.598 .0637 Mdot
.598 .06397 Mdot
.598 .06411 Mdot
.598 .06424 Mdot
.598 .06439 Mdot
.598 .06454 Mdot
.598 .06493 Mdot
.598 .06493 Mdot
.598 .0652 Mdot
.598 .06533 Mdot
.598 .06543 Mdot
.598 .0657 Mdot
.598 .06579 Mdot
.598 .06586 Mdot
.598 .06597 Mdot
.598 .06611 Mdot
.598 .06613 Mdot
.598 .06614 Mdot
.598 .06619 Mdot
.598 .0666 Mdot
.598 .06676 Mdot
.598 .06705 Mdot
.598 .06731 Mdot
.598 .06732 Mdot
.598 .06745 Mdot
.598 .06746 Mdot
.598 .06764 Mdot
.598 .06802 Mdot
.598 .06856 Mdot
.598 .06903 Mdot
.598 .06908 Mdot
.598 .0692 Mdot
.598 .06923 Mdot
.598 .06946 Mdot
.598 .06968 Mdot
.598 .0697 Mdot
.598 .06981 Mdot
.598 .07045 Mdot
.598 .0706 Mdot
.598 .07101 Mdot
.598 .07105 Mdot
.598 .07125 Mdot
.598 .07127 Mdot
.598 .07168 Mdot
.598 .0717 Mdot
.598 .07196 Mdot
.598 .07199 Mdot
.598 .07223 Mdot
.598 .07237 Mdot
.598 .07245 Mdot
.598 .07267 Mdot
.598 .07269 Mdot
.598 .07277 Mdot
.598 .073 Mdot
.598 .0733 Mdot
.598 .07362 Mdot
.598 .07379 Mdot
.598 .07394 Mdot
.598 .074 Mdot
.598 .07413 Mdot
.598 .07431 Mdot
.598 .07459 Mdot
.598 .07477 Mdot
.598 .07477 Mdot
.598 .0751 Mdot
.598 .07525 Mdot
.598 .07536 Mdot
.598 .07569 Mdot
.598 .0758 Mdot
.598 .07588 Mdot
.598 .07601 Mdot
.598 .07616 Mdot
.598 .07619 Mdot
.598 .0762 Mdot
.598 .07622 Mdot
.598 .07628 Mdot
.598 .07628 Mdot
.598 .07677 Mdot
.598 .0769 Mdot
.598 .07696 Mdot
.598 .07731 Mdot
.598 .07762 Mdot
.598 .07763 Mdot
.598 .07779 Mdot
.598 .0778 Mdot
.598 .07802 Mdot
.598 .07847 Mdot
.598 .0785 Mdot
.598 .07911 Mdot
.598 .07968 Mdot
.598 .07974 Mdot
.598 .07988 Mdot
.598 .07991 Mdot
.598 .08019 Mdot
.598 .08045 Mdot
.598 .08048 Mdot
.598 .08061 Mdot
.598 .0807 Mdot
.598 .08138 Mdot
.598 .08155 Mdot
.598 .08204 Mdot
.598 .08209 Mdot
.598 .08233 Mdot
.598 .08236 Mdot
.598 .08285 Mdot
.598 .08287 Mdot
.598 .08297 Mdot
.598 .08318 Mdot
.598 .08321 Mdot
.598 .0835 Mdot
.598 .08367 Mdot
.598 .08377 Mdot
.598 .08403 Mdot
.598 .08405 Mdot
.598 .08415 Mdot
.598 .08442 Mdot
.598 .08479 Mdot
.598 .08517 Mdot
.598 .08536 Mdot
.598 .08555 Mdot
.598 .08562 Mdot
.598 .08578 Mdot
.598 .08599 Mdot
.598 .08632 Mdot
.598 .08654 Mdot
.598 .08654 Mdot
.598 .08693 Mdot
.598 .08712 Mdot
.598 .08725 Mdot
.598 .08765 Mdot
.598 .08777 Mdot
.598 .08787 Mdot
.598 .08803 Mdot
.598 .08821 Mdot
.598 .08824 Mdot
.598 .08826 Mdot
.598 .08828 Mdot
.598 .08835 Mdot
.598 .08835 Mdot
.598 .08893 Mdot
.598 .08909 Mdot
.598 .08916 Mdot
.598 .08958 Mdot
.598 .08995 Mdot
.598 .08996 Mdot
.598 .09015 Mdot
.598 .09016 Mdot
.598 .09042 Mdot
.598 .09097 Mdot
.598 .091 Mdot
.598 .09173 Mdot
.598 .09241 Mdot
.598 .09248 Mdot
.598 .09265 Mdot
.598 .09269 Mdot
.598 .09302 Mdot
.598 .09334 Mdot
.598 .09337 Mdot
.598 .09352 Mdot
.598 .09364 Mdot
.598 .09444 Mdot
.598 .09465 Mdot
.598 .09523 Mdot
.598 .09529 Mdot
.598 .09558 Mdot
.598 .09561 Mdot
.598 .0962 Mdot
.598 .09623 Mdot
.598 .09635 Mdot
.598 .09659 Mdot
.598 .09664 Mdot
.598 .09698 Mdot
.598 .09718 Mdot
.598 .0973 Mdot
.598 .09762 Mdot
.598 .09764 Mdot
.598 .09776 Mdot
.598 .09808 Mdot
.598 .09852 Mdot
.598 .09897 Mdot
.598 .09921 Mdot
.598 .09944 Mdot
.598 .09952 Mdot
.598 .0997 Mdot
.598 .09996 Mdot
.598 .10036 Mdot
.598 .10062 Mdot
.598 .10062 Mdot
.598 .10109 Mdot
.598 .10131 Mdot
.598 .10147 Mdot
.598 .10194 Mdot
.598 .10209 Mdot
.598 .10221 Mdot
.598 .1024 Mdot
.598 .10261 Mdot
.598 .10265 Mdot
.598 .10267 Mdot
.598 .10269 Mdot
.598 .10278 Mdot
.598 .10278 Mdot
.598 .10348 Mdot
.598 .10367 Mdot
.598 .10375 Mdot
.598 .10425 Mdot
.598 .10469 Mdot
.598 .1047 Mdot
.598 .10494 Mdot
.598 .10495 Mdot
.598 .10526 Mdot
.598 .10592 Mdot
.598 .10595 Mdot
.598 .10683 Mdot
.598 .10764 Mdot
.598 .10773 Mdot
.598 .10793 Mdot
.598 .10797 Mdot
.598 .10837 Mdot
.598 .10875 Mdot
.598 .10879 Mdot
.598 .10897 Mdot
.598 .10911 Mdot
.598 .11007 Mdot
.598 .11032 Mdot
.598 .11101 Mdot
.598 .11109 Mdot
.598 .11143 Mdot
.598 .11147 Mdot
.598 .11217 Mdot
.598 .11221 Mdot
.598 .11235 Mdot
.598 .11264 Mdot
.598 .11269 Mdot
.598 .11311 Mdot
.598 .11335 Mdot
.598 .11349 Mdot
.598 .11386 Mdot
.598 .11389 Mdot
.598 .11404 Mdot
.598 .11442 Mdot
.598 .11495 Mdot
.598 .11549 Mdot
.598 .11577 Mdot
.598 .11604 Mdot
.598 .11614 Mdot
.598 .11636 Mdot
.598 .11667 Mdot
.598 .11714 Mdot
.598 .11746 Mdot
.598 .11746 Mdot
.598 .11801 Mdot
.598 .11829 Mdot
.598 .11847 Mdot
.598 .11904 Mdot
.598 .11922 Mdot
.598 .11935 Mdot
.598 .11958 Mdot
.598 .11984 Mdot
.598 .11988 Mdot
.598 .11991 Mdot
.598 .11994 Mdot
.598 .12005 Mdot
.598 .12005 Mdot
.598 .12088 Mdot
.598 .12111 Mdot
.598 .1212 Mdot
.598 .1218 Mdot
.598 .12233 Mdot
.598 .12234 Mdot
.598 .12262 Mdot
.598 .12264 Mdot
.598 .12301 Mdot
.598 .12379 Mdot
.598 .12384 Mdot
.598 .12488 Mdot
.598 .12585 Mdot
.598 .12596 Mdot
.598 .12619 Mdot
.598 .12625 Mdot
.598 .12672 Mdot
.598 .12718 Mdot
.598 .12723 Mdot
.598 .12744 Mdot
.598 .12761 Mdot
.598 .12876 Mdot
.598 .12906 Mdot
.598 .12989 Mdot
.598 .12998 Mdot
.598 .13038 Mdot
.598 .13043 Mdot
.598 .13127 Mdot
.598 .13131 Mdot
.598 .13148 Mdot
.598 .13184 Mdot
.598 .1319 Mdot
.598 .13239 Mdot
.598 .13268 Mdot
.598 .13285 Mdot
.598 .1333 Mdot
.598 .13333 Mdot
.598 .13351 Mdot
.598 .13396 Mdot
.598 .13459 Mdot
.598 .13524 Mdot
.598 .13558 Mdot
.598 .1359 Mdot
.598 .13602 Mdot
.598 .13628 Mdot
.598 .13665 Mdot
.598 .13722 Mdot
.598 .13759 Mdot
.598 .1376 Mdot
.598 .13826 Mdot
.598 .13858 Mdot
.598 .13881 Mdot
.598 .13948 Mdot
.598 .1397 Mdot
.598 .13986 Mdot
.598 .14014 Mdot
.598 .14044 Mdot
.598 .14049 Mdot
.598 .14053 Mdot
.598 .14056 Mdot
.598 .14069 Mdot
.598 .14069 Mdot
.598 .14168 Mdot
.598 .14196 Mdot
.598 .14207 Mdot
.598 .14279 Mdot
.598 .14342 Mdot
.598 .14344 Mdot
.598 .14377 Mdot
.598 .14379 Mdot
.598 .14423 Mdot
.598 .14517 Mdot
.598 .14522 Mdot
.598 .14648 Mdot
.598 .14763 Mdot
.598 .14776 Mdot
.598 .14804 Mdot
.598 .14811 Mdot
.598 .14868 Mdot
.598 .14922 Mdot
.598 .14928 Mdot
.598 .14954 Mdot
.598 .14974 Mdot
.598 .15111 Mdot
.598 .15147 Mdot
.598 .15246 Mdot
.598 .15257 Mdot
.598 .15305 Mdot
.598 .15311 Mdot
.598 .15412 Mdot
.598 .15417 Mdot
.598 .15437 Mdot
.598 .15479 Mdot
.598 .15487 Mdot
.598 .15546 Mdot
.598 .1558 Mdot
.598 .156 Mdot
.598 .15654 Mdot
.598 .15658 Mdot
.598 .15679 Mdot
.598 .15734 Mdot
.598 .15809 Mdot
.598 .15886 Mdot
.598 .15927 Mdot
.598 .15965 Mdot
.598 .1598 Mdot
.598 .16011 Mdot
.598 .16055 Mdot
.598 .16123 Mdot
.598 .16168 Mdot
.598 .16168 Mdot
.598 .16248 Mdot
.598 .16286 Mdot
.598 .16313 Mdot
.598 .16394 Mdot
.598 .1642 Mdot
.598 .16439 Mdot
.598 .16472 Mdot
.598 .16509 Mdot
.598 .16515 Mdot
.598 .16519 Mdot
.598 .16523 Mdot
.598 .16538 Mdot
.598 .16538 Mdot
.598 .16657 Mdot
.598 .1669 Mdot
.598 .16703 Mdot
.598 .16789 Mdot
.598 .16867 Mdot
.598 .16906 Mdot
.598 .16909 Mdot
.598 .16962 Mdot
.598 .17074 Mdot
.598 .1708 Mdot
.598 .1723 Mdot
.598 .17369 Mdot
.598 .17384 Mdot
.598 .17418 Mdot
.598 .17425 Mdot
.598 .17493 Mdot
.598 .17559 Mdot
.598 .17566 Mdot
.598 .17596 Mdot
.598 .1762 Mdot
.598 .17784 Mdot
.598 .17827 Mdot
.598 .17946 Mdot
.598 .17959 Mdot
.598 .18017 Mdot
.598 .18024 Mdot
.598 .18144 Mdot
.598 .1815 Mdot
.598 .18174 Mdot
.598 .18225 Mdot
.598 .18234 Mdot
.598 .18304 Mdot
.598 .18345 Mdot
.598 .18369 Mdot
.598 .18434 Mdot
.598 .18439 Mdot
.598 .18464 Mdot
.598 .18529 Mdot
.598 .18619 Mdot
.598 .18712 Mdot
.598 .1876 Mdot
.598 .18806 Mdot
.598 .18824 Mdot
.598 .18861 Mdot
.598 .18914 Mdot
.598 .18994 Mdot
.598 .19048 Mdot
.598 .19049 Mdot
.598 .19144 Mdot
.598 .1919 Mdot
.598 .19222 Mdot
.598 .19318 Mdot
.598 .1935 Mdot
.598 .19373 Mdot
.598 .19412 Mdot
.598 .19456 Mdot
.598 .19463 Mdot
.598 .19468 Mdot
.598 .19473 Mdot
.598 .19491 Mdot
.598 .19491 Mdot
.598 .19633 Mdot
.598 .19673 Mdot
.598 .19688 Mdot
.598 .19791 Mdot
.598 .19884 Mdot
.598 .19931 Mdot
.598 .19935 Mdot
.598 .19998 Mdot
.598 .20132 Mdot
.598 .2014 Mdot
.598 .20319 Mdot
.598 .20484 Mdot
.598 .20502 Mdot
.598 .20543 Mdot
.598 .20552 Mdot
.598 .20634 Mdot
.598 .20712 Mdot
.598 .2072 Mdot
.598 .20757 Mdot
.598 .20785 Mdot
.598 .20981 Mdot
.598 .21033 Mdot
.598 .21175 Mdot
.598 .2119 Mdot
.598 .2126 Mdot
.598 .21268 Mdot
.598 .21412 Mdot
.598 .21419 Mdot
.598 .21448 Mdot
.598 .21508 Mdot
.598 .21519 Mdot
.598 .21603 Mdot
.598 .21653 Mdot
.598 .21681 Mdot
.598 .21758 Mdot
.598 .21764 Mdot
.598 .21794 Mdot
.598 .21872 Mdot
.598 .2198 Mdot
.598 .22091 Mdot
.598 .22149 Mdot
.598 .22204 Mdot
.598 .22225 Mdot
.598 .22269 Mdot
.598 .22333 Mdot
.598 .22429 Mdot
.598 .22493 Mdot
.598 .22494 Mdot
.598 .22607 Mdot
.598 .22663 Mdot
.598 .22701 Mdot
.598 .22817 Mdot
.598 .22854 Mdot
.598 .22881 Mdot
.598 .22928 Mdot
.598 .22981 Mdot
.598 .22989 Mdot
.598 .22995 Mdot
.598 .23001 Mdot
.598 .23023 Mdot
.598 .23023 Mdot
.598 .23193 Mdot
.598 .2324 Mdot
.598 .23259 Mdot
.598 .23382 Mdot
.598 .23493 Mdot
.598 .2355 Mdot
.598 .23553 Mdot
.598 .23629 Mdot
.598 .2379 Mdot
.598 .23799 Mdot
.598 .24013 Mdot
.598 .24211 Mdot
.598 .24232 Mdot
.598 .24281 Mdot
.598 .24292 Mdot
.598 .2439 Mdot
.598 .24483 Mdot
.598 .24493 Mdot
.598 .24537 Mdot
.598 .2457 Mdot
.598 .24805 Mdot
.598 .24867 Mdot
.598 .25037 Mdot
.598 .25055 Mdot
.598 .25138 Mdot
.598 .25149 Mdot
.598 .2532 Mdot
.598 .25329 Mdot
.598 .25363 Mdot
.598 .25435 Mdot
.598 .25448 Mdot
.598 .25549 Mdot
.598 .25608 Mdot
.598 .25642 Mdot
.598 .25734 Mdot
.598 .25741 Mdot
.598 .25778 Mdot
.598 .25871 Mdot
.598 .26 Mdot
.598 .26132 Mdot
.598 .26202 Mdot
.598 .26267 Mdot
.598 .26292 Mdot
.598 .26345 Mdot
.598 .26421 Mdot
.598 .26537 Mdot
.598 .26613 Mdot
.598 .26614 Mdot
.598 .2675 Mdot
.598 .26816 Mdot
.598 .26862 Mdot
.598 .27 Mdot
.598 .27045 Mdot
.598 .27078 Mdot
.598 .27134 Mdot
.598 .27197 Mdot
.598 .27207 Mdot
.598 .27214 Mdot
.598 .27221 Mdot
.598 .27247 Mdot
.598 .27247 Mdot
.598 .2745 Mdot
.598 .27507 Mdot
.598 .27529 Mdot
.598 .27676 Mdot
.598 .27809 Mdot
.598 .2785 Mdot
.598 .27877 Mdot
.598 .27882 Mdot
.598 .27972 Mdot
.598 .28164 Mdot
.598 .28175 Mdot
.598 .28431 Mdot
.598 .28668 Mdot
.598 .28693 Mdot
.598 .28752 Mdot
.598 .28765 Mdot
.598 .28882 Mdot
.598 .28993 Mdot
.598 .29005 Mdot
.598 .29057 Mdot
.598 .29098 Mdot
.598 .29379 Mdot
.598 .29452 Mdot
.598 .29656 Mdot
.598 .29678 Mdot
.598 .29777 Mdot
.598 .29789 Mdot
.598 .29995 Mdot
.598 .30005 Mdot
.598 .30046 Mdot
.598 .30132 Mdot
.598 .30148 Mdot
.598 .30268 Mdot
.598 .30339 Mdot
.598 .3038 Mdot
.598 .3049 Mdot
.598 .30498 Mdot
.598 .30542 Mdot
.598 .30653 Mdot
.598 .30807 Mdot
.598 .30966 Mdot
.598 .31049 Mdot
.598 .31127 Mdot
.598 .31157 Mdot
.598 .31221 Mdot
.598 .31311 Mdot
.598 .31449 Mdot
.598 .31541 Mdot
.598 .31542 Mdot
.598 .31705 Mdot
.598 .31784 Mdot
.598 .31839 Mdot
.598 .32004 Mdot
.598 .32058 Mdot
.598 .32097 Mdot
.598 .32164 Mdot
.598 .32239 Mdot
.598 .32251 Mdot
.598 .3226 Mdot
.598 .32268 Mdot
.598 .32299 Mdot
.598 .323 Mdot
.598 .32542 Mdot
.598 .3261 Mdot
.598 .32636 Mdot
.598 .32812 Mdot
.598 .32971 Mdot
.598 .3302 Mdot
.598 .33052 Mdot
.598 .33058 Mdot
.598 .33166 Mdot
.598 .33396 Mdot
.598 .33409 Mdot
.598 .33715 Mdot
.598 .33998 Mdot
.598 .34029 Mdot
.598 .34099 Mdot
.598 .34114 Mdot
.598 .34254 Mdot
.598 .34387 Mdot
.598 .34401 Mdot
.598 .34464 Mdot
.598 .34513 Mdot
.598 .34849 Mdot
.598 .34936 Mdot
.598 .3518 Mdot
.598 .35206 Mdot
.598 .35325 Mdot
.598 .35339 Mdot
.598 .35585 Mdot
.598 .35597 Mdot
.598 .35646 Mdot
.598 .3575 Mdot
.598 .35768 Mdot
.598 .35913 Mdot
.598 .35997 Mdot
.598 .36046 Mdot
.598 .36177 Mdot
.598 .36188 Mdot
.598 .36239 Mdot
.598 .36373 Mdot
.598 .36557 Mdot
.598 .36746 Mdot
.6 .01623 Mdot
.6 .01653 Mdot
.6 .01658 Mdot
.6 .0169 Mdot
.6 .01695 Mdot
.6 .01733 Mdot
.6 .0174 Mdot
.6 .01774 Mdot
.6 .01785 Mdot
.6 .01793 Mdot
.6 .01804 Mdot
.6 .01835 Mdot
.6 .01848 Mdot
.6 .01857 Mdot
.6 .01871 Mdot
.6 .01905 Mdot
.6 .01907 Mdot
.6 .01924 Mdot
.6 .01927 Mdot
.6 .01935 Mdot
.6 .01951 Mdot
.6 .01991 Mdot
.6 .01994 Mdot
.6 .02014 Mdot
.6 .02018 Mdot
.6 .02027 Mdot
.6 .02047 Mdot
.6 .02095 Mdot
.6 .02099 Mdot
.6 .02122 Mdot
.6 .02128 Mdot
.6 .02138 Mdot
.6 .02162 Mdot
.6 .02184 Mdot
.6 .02219 Mdot
.6 .0222 Mdot
.6 .02224 Mdot
.6 .02239 Mdot
.6 .02253 Mdot
.6 .02259 Mdot
.6 .02272 Mdot
.6 .023 Mdot
.6 .02318 Mdot
.6 .02326 Mdot
.6 .02363 Mdot
.6 .02368 Mdot
.6 .0237 Mdot
.6 .02375 Mdot
.6 .02393 Mdot
.6 .02409 Mdot
.6 .02417 Mdot
.6 .02432 Mdot
.6 .02465 Mdot
.6 .02487 Mdot
.6 .02497 Mdot
.6 .02499 Mdot
.6 .02523 Mdot
.6 .02541 Mdot
.6 .02548 Mdot
.6 .0255 Mdot
.6 .02551 Mdot
.6 .02556 Mdot
.6 .02577 Mdot
.6 .02596 Mdot
.6 .02606 Mdot
.6 .02624 Mdot
.6 .02654 Mdot
.6 .02664 Mdot
.6 .0269 Mdot
.6 .02702 Mdot
.6 .02704 Mdot
.6 .02733 Mdot
.6 .02755 Mdot
.6 .02759 Mdot
.6 .02763 Mdot
.6 .02765 Mdot
.6 .02767 Mdot
.6 .02772 Mdot
.6 .02798 Mdot
.6 .0281 Mdot
.6 .02821 Mdot
.6 .02832 Mdot
.6 .02855 Mdot
.6 .02859 Mdot
.6 .02891 Mdot
.6 .02903 Mdot
.6 .02917 Mdot
.6 .02934 Mdot
.6 .02944 Mdot
.6 .02948 Mdot
.6 .0295 Mdot
.6 .02986 Mdot
.6 .03012 Mdot
.6 .03016 Mdot
.6 .03022 Mdot
.6 .03024 Mdot
.6 .03026 Mdot
.6 .03033 Mdot
.6 .03064 Mdot
.6 .03078 Mdot
.6 .03091 Mdot
.6 .03104 Mdot
.6 .03131 Mdot
.6 .03136 Mdot
.6 .03175 Mdot
.6 .03189 Mdot
.6 .03206 Mdot
.6 .03226 Mdot
.6 .03238 Mdot
.6 .03243 Mdot
.6 .03246 Mdot
.6 .03289 Mdot
.6 .0332 Mdot
.6 .03325 Mdot
.6 .03325 Mdot
.6 .03332 Mdot
.6 .03335 Mdot
.6 .03337 Mdot
.6 .03345 Mdot
.6 .03382 Mdot
.6 .03399 Mdot
.6 .03415 Mdot
.6 .03431 Mdot
.6 .03439 Mdot
.6 .03463 Mdot
.6 .03469 Mdot
.6 .03515 Mdot
.6 .03533 Mdot
.6 .03553 Mdot
.6 .03577 Mdot
.6 .03592 Mdot
.6 .03598 Mdot
.6 .03601 Mdot
.6 .03619 Mdot
.6 .03652 Mdot
.6 .0369 Mdot
.6 .03695 Mdot
.6 .03696 Mdot
.6 .03703 Mdot
.6 .03707 Mdot
.6 .0371 Mdot
.6 .0371 Mdot
.6 .03719 Mdot
.6 .03765 Mdot
.6 .03773 Mdot
.6 .03784 Mdot
.6 .03804 Mdot
.6 .03821 Mdot
.6 .03823 Mdot
.6 .03832 Mdot
.6 .03861 Mdot
.6 .03868 Mdot
.6 .03902 Mdot
.6 .03924 Mdot
.6 .03927 Mdot
.6 .03945 Mdot
.6 .03969 Mdot
.6 .03999 Mdot
.6 .04016 Mdot
.6 .04023 Mdot
.6 .04027 Mdot
.6 .04049 Mdot
.6 .04088 Mdot
.6 .04096 Mdot
.6 .04133 Mdot
.6 .0414 Mdot
.6 .04141 Mdot
.6 .0415 Mdot
.6 .0415 Mdot
.6 .04154 Mdot
.6 .04157 Mdot
.6 .04158 Mdot
.6 .04169 Mdot
.6 .04223 Mdot
.6 .04234 Mdot
.6 .04247 Mdot
.6 .04271 Mdot
.6 .04291 Mdot
.6 .04293 Mdot
.6 .04304 Mdot
.6 .04339 Mdot
.6 .04348 Mdot
.6 .04388 Mdot
.6 .04414 Mdot
.6 .04418 Mdot
.6 .04424 Mdot
.6 .04426 Mdot
.6 .04439 Mdot
.6 .04465 Mdot
.6 .04468 Mdot
.6 .04504 Mdot
.6 .04525 Mdot
.6 .04533 Mdot
.6 .04538 Mdot
.6 .04565 Mdot
.6 .04612 Mdot
.6 .0462 Mdot
.6 .04666 Mdot
.6 .04674 Mdot
.6 .04674 Mdot
.6 .04685 Mdot
.6 .04686 Mdot
.6 .04691 Mdot
.6 .04695 Mdot
.6 .04695 Mdot
.6 .04708 Mdot
.6 .04773 Mdot
.6 .04786 Mdot
.6 .04802 Mdot
.6 .0483 Mdot
.6 .04854 Mdot
.6 .04858 Mdot
.6 .04867 Mdot
.6 .04871 Mdot
.6 .04913 Mdot
.6 .04923 Mdot
.6 .04925 Mdot
.6 .04961 Mdot
.6 .04972 Mdot
.6 .05003 Mdot
.6 .05007 Mdot
.6 .05015 Mdot
.6 .05017 Mdot
.6 .05033 Mdot
.6 .05064 Mdot
.6 .05068 Mdot
.6 .05111 Mdot
.6 .05114 Mdot
.6 .05135 Mdot
.6 .05145 Mdot
.6 .05152 Mdot
.6 .05183 Mdot
.6 .05189 Mdot
.6 .0524 Mdot
.6 .0525 Mdot
.6 .05296 Mdot
.6 .05305 Mdot
.6 .05314 Mdot
.6 .05315 Mdot
.6 .05328 Mdot
.6 .05328 Mdot
.6 .05335 Mdot
.6 .05339 Mdot
.6 .0534 Mdot
.6 .05356 Mdot
.6 .05364 Mdot
.6 .05375 Mdot
.6 .05434 Mdot
.6 .05449 Mdot
.6 .05468 Mdot
.6 .05502 Mdot
.6 .05531 Mdot
.6 .05535 Mdot
.6 .05546 Mdot
.6 .05551 Mdot
.6 .05601 Mdot
.6 .05613 Mdot
.6 .05616 Mdot
.6 .05659 Mdot
.6 .05672 Mdot
.6 .05702 Mdot
.6 .05709 Mdot
.6 .05714 Mdot
.6 .05724 Mdot
.6 .05726 Mdot
.6 .05745 Mdot
.6 .05782 Mdot
.6 .05787 Mdot
.6 .05838 Mdot
.6 .05842 Mdot
.6 .0586 Mdot
.6 .05868 Mdot
.6 .0588 Mdot
.6 .05888 Mdot
.6 .05926 Mdot
.6 .05933 Mdot
.6 .05993 Mdot
.6 .06006 Mdot
.6 .06061 Mdot
.6 .06071 Mdot
.6 .06083 Mdot
.6 .06084 Mdot
.6 .06099 Mdot
.6 .061 Mdot
.6 .06108 Mdot
.6 .06113 Mdot
.6 .06113 Mdot
.6 .06133 Mdot
.6 .06142 Mdot
.6 .06155 Mdot
.6 .06226 Mdot
.6 .06245 Mdot
.6 .06267 Mdot
.6 .06305 Mdot
.6 .06308 Mdot
.6 .06343 Mdot
.6 .06348 Mdot
.6 .06361 Mdot
.6 .06367 Mdot
.6 .06406 Mdot
.6 .0642 Mdot
.6 .06427 Mdot
.6 .06441 Mdot
.6 .06445 Mdot
.6 .06496 Mdot
.6 .06512 Mdot
.6 .06548 Mdot
.6 .06557 Mdot
.6 .06563 Mdot
.6 .06574 Mdot
.6 .06577 Mdot
.6 .066 Mdot
.6 .06644 Mdot
.6 .0665 Mdot
.6 .06712 Mdot
.6 .06717 Mdot
.6 .06737 Mdot
.6 .06747 Mdot
.6 .06762 Mdot
.6 .06771 Mdot
.6 .06816 Mdot
.6 .06825 Mdot
.6 .06897 Mdot
.6 .06911 Mdot
.6 .06913 Mdot
.6 .06979 Mdot
.6 .06991 Mdot
.6 .07002 Mdot
.6 .07005 Mdot
.6 .07006 Mdot
.6 .07025 Mdot
.6 .07025 Mdot
.6 .07035 Mdot
.6 .07041 Mdot
.6 .07042 Mdot
.6 .07065 Mdot
.6 .07076 Mdot
.6 .07082 Mdot
.6 .07092 Mdot
.6 .07103 Mdot
.6 .07114 Mdot
.6 .07177 Mdot
.6 .07199 Mdot
.6 .07226 Mdot
.6 .07251 Mdot
.6 .07256 Mdot
.6 .07272 Mdot
.6 .07276 Mdot
.6 .07317 Mdot
.6 .07323 Mdot
.6 .07326 Mdot
.6 .07339 Mdot
.6 .07346 Mdot
.6 .07372 Mdot
.6 .07376 Mdot
.6 .07393 Mdot
.6 .0741 Mdot
.6 .07418 Mdot
.6 .07426 Mdot
.6 .07435 Mdot
.6 .0744 Mdot
.6 .07501 Mdot
.6 .0752 Mdot
.6 .07549 Mdot
.6 .07564 Mdot
.6 .07574 Mdot
.6 .07581 Mdot
.6 .07595 Mdot
.6 .07599 Mdot
.6 .07626 Mdot
.6 .07635 Mdot
.6 .07679 Mdot
.6 .07679 Mdot
.6 .07685 Mdot
.6 .0775 Mdot
.6 .0776 Mdot
.6 .07766 Mdot
.6 .0779 Mdot
.6 .07802 Mdot
.6 .0782 Mdot
.6 .07831 Mdot
.6 .07832 Mdot
.6 .07885 Mdot
.6 .07896 Mdot
.6 .07911 Mdot
.6 .07983 Mdot
.6 .07999 Mdot
.6 .08001 Mdot
.6 .08081 Mdot
.6 .08095 Mdot
.6 .08108 Mdot
.6 .08112 Mdot
.6 .08113 Mdot
.6 .08135 Mdot
.6 .08136 Mdot
.6 .08148 Mdot
.6 .08155 Mdot
.6 .08156 Mdot
.6 .08164 Mdot
.6 .08184 Mdot
.6 .08197 Mdot
.6 .08205 Mdot
.6 .08216 Mdot
.6 .08229 Mdot
.6 .08242 Mdot
.6 .08318 Mdot
.6 .08345 Mdot
.6 .08377 Mdot
.6 .08384 Mdot
.6 .08407 Mdot
.6 .08413 Mdot
.6 .08432 Mdot
.6 .08436 Mdot
.6 .08486 Mdot
.6 .08493 Mdot
.6 .08497 Mdot
.6 .08512 Mdot
.6 .08521 Mdot
.6 .08547 Mdot
.6 .08552 Mdot
.6 .08557 Mdot
.6 .08577 Mdot
.6 .08598 Mdot
.6 .08607 Mdot
.6 .08617 Mdot
.6 .08628 Mdot
.6 .08633 Mdot
.6 .08707 Mdot
.6 .08729 Mdot
.6 .08764 Mdot
.6 .08782 Mdot
.6 .08794 Mdot
.6 .08803 Mdot
.6 .08819 Mdot
.6 .08824 Mdot
.6 .08857 Mdot
.6 .08867 Mdot
.6 .0892 Mdot
.6 .08921 Mdot
.6 .08928 Mdot
.6 .09006 Mdot
.6 .09017 Mdot
.6 .09024 Mdot
.6 .09054 Mdot
.6 .09069 Mdot
.6 .09089 Mdot
.6 .09102 Mdot
.6 .09105 Mdot
.6 .09168 Mdot
.6 .09181 Mdot
.6 .09199 Mdot
.6 .09285 Mdot
.6 .09304 Mdot
.6 .09307 Mdot
.6 .09402 Mdot
.6 .0942 Mdot
.6 .09436 Mdot
.6 .0944 Mdot
.6 .09442 Mdot
.6 .09468 Mdot
.6 .09469 Mdot
.6 .09483 Mdot
.6 .09492 Mdot
.6 .09493 Mdot
.6 .09502 Mdot
.6 .09526 Mdot
.6 .09543 Mdot
.6 .09551 Mdot
.6 .09565 Mdot
.6 .09581 Mdot
.6 .09596 Mdot
.6 .09688 Mdot
.6 .09719 Mdot
.6 .09759 Mdot
.6 .09767 Mdot
.6 .09794 Mdot
.6 .09801 Mdot
.6 .09824 Mdot
.6 .09829 Mdot
.6 .09889 Mdot
.6 .09897 Mdot
.6 .09902 Mdot
.6 .0992 Mdot
.6 .09931 Mdot
.6 .09962 Mdot
.6 .09968 Mdot
.6 .09974 Mdot
.6 .09998 Mdot
.6 .10023 Mdot
.6 .10035 Mdot
.6 .10046 Mdot
.6 .1006 Mdot
.6 .10066 Mdot
.6 .10154 Mdot
.6 .10181 Mdot
.6 .10223 Mdot
.6 .10244 Mdot
.6 .10259 Mdot
.6 .1027 Mdot
.6 .10289 Mdot
.6 .10294 Mdot
.6 .10334 Mdot
.6 .10346 Mdot
.6 .1041 Mdot
.6 .10411 Mdot
.6 .1042 Mdot
.6 .10513 Mdot
.6 .10527 Mdot
.6 .10535 Mdot
.6 .10571 Mdot
.6 .10588 Mdot
.6 .10613 Mdot
.6 .10629 Mdot
.6 .10631 Mdot
.6 .10707 Mdot
.6 .10723 Mdot
.6 .10744 Mdot
.6 .10848 Mdot
.6 .10871 Mdot
.6 .10874 Mdot
.6 .10988 Mdot
.6 .1101 Mdot
.6 .11028 Mdot
.6 .11033 Mdot
.6 .11036 Mdot
.6 .11068 Mdot
.6 .11069 Mdot
.6 .11085 Mdot
.6 .11096 Mdot
.6 .11097 Mdot
.6 .11108 Mdot
.6 .11137 Mdot
.6 .11157 Mdot
.6 .11167 Mdot
.6 .11184 Mdot
.6 .11203 Mdot
.6 .11221 Mdot
.6 .11331 Mdot
.6 .11369 Mdot
.6 .11416 Mdot
.6 .11426 Mdot
.6 .11458 Mdot
.6 .11467 Mdot
.6 .11495 Mdot
.6 .11501 Mdot
.6 .11573 Mdot
.6 .11582 Mdot
.6 .11588 Mdot
.6 .1161 Mdot
.6 .11623 Mdot
.6 .1166 Mdot
.6 .11667 Mdot
.6 .11675 Mdot
.6 .11704 Mdot
.6 .11733 Mdot
.6 .11747 Mdot
.6 .11761 Mdot
.6 .11777 Mdot
.6 .11785 Mdot
.6 .11891 Mdot
.6 .11923 Mdot
.6 .11973 Mdot
.6 .11999 Mdot
.6 .12016 Mdot
.6 .12029 Mdot
.6 .12052 Mdot
.6 .12059 Mdot
.6 .12106 Mdot
.6 .12121 Mdot
.6 .12198 Mdot
.6 .12198 Mdot
.6 .12209 Mdot
.6 .12321 Mdot
.6 .12338 Mdot
.6 .12348 Mdot
.6 .1239 Mdot
.6 .12411 Mdot
.6 .12441 Mdot
.6 .1246 Mdot
.6 .12463 Mdot
.6 .12554 Mdot
.6 .12573 Mdot
.6 .12598 Mdot
.6 .12723 Mdot
.6 .12751 Mdot
.6 .12755 Mdot
.6 .12892 Mdot
.6 .12917 Mdot
.6 .1294 Mdot
.6 .12945 Mdot
.6 .12948 Mdot
.6 .12987 Mdot
.6 .12988 Mdot
.6 .13008 Mdot
.6 .1302 Mdot
.6 .13022 Mdot
.6 .13036 Mdot
.6 .1307 Mdot
.6 .13094 Mdot
.6 .13106 Mdot
.6 .13126 Mdot
.6 .13149 Mdot
.6 .13171 Mdot
.6 .13303 Mdot
.6 .13348 Mdot
.6 .13405 Mdot
.6 .13417 Mdot
.6 .13456 Mdot
.6 .13466 Mdot
.6 .13499 Mdot
.6 .13507 Mdot
.6 .13593 Mdot
.6 .13605 Mdot
.6 .13611 Mdot
.6 .13638 Mdot
.6 .13653 Mdot
.6 .13698 Mdot
.6 .13706 Mdot
.6 .13716 Mdot
.6 .1375 Mdot
.6 .13785 Mdot
.6 .13803 Mdot
.6 .13819 Mdot
.6 .13838 Mdot
.6 .13847 Mdot
.6 .13975 Mdot
.6 .14013 Mdot
.6 .14074 Mdot
.6 .14104 Mdot
.6 .14125 Mdot
.6 .14141 Mdot
.6 .14168 Mdot
.6 .14177 Mdot
.6 .14233 Mdot
.6 .14251 Mdot
.6 .14343 Mdot
.6 .14344 Mdot
.6 .14357 Mdot
.6 .14491 Mdot
.6 .14511 Mdot
.6 .14523 Mdot
.6 .14574 Mdot
.6 .14599 Mdot
.6 .14635 Mdot
.6 .14658 Mdot
.6 .14661 Mdot
.6 .14771 Mdot
.6 .14793 Mdot
.6 .14824 Mdot
.6 .14973 Mdot
.6 .15007 Mdot
.6 .15012 Mdot
.6 .15176 Mdot
.6 .15206 Mdot
.6 .15233 Mdot
.6 .1524 Mdot
.6 .15244 Mdot
.6 .1529 Mdot
.6 .15291 Mdot
.6 .15315 Mdot
.6 .1533 Mdot
.6 .15332 Mdot
.6 .15348 Mdot
.6 .1539 Mdot
.6 .15418 Mdot
.6 .15433 Mdot
.6 .15457 Mdot
.6 .15485 Mdot
.6 .15511 Mdot
.6 .15669 Mdot
.6 .15724 Mdot
.6 .15792 Mdot
.6 .15806 Mdot
.6 .15852 Mdot
.6 .15865 Mdot
.6 .15905 Mdot
.6 .15914 Mdot
.6 .16017 Mdot
.6 .16031 Mdot
.6 .16039 Mdot
.6 .16071 Mdot
.6 .16089 Mdot
.6 .16144 Mdot
.6 .16153 Mdot
.6 .16165 Mdot
.6 .16206 Mdot
.6 .16248 Mdot
.6 .16269 Mdot
.6 .16288 Mdot
.6 .16312 Mdot
.6 .16323 Mdot
.6 .16476 Mdot
.6 .16521 Mdot
.6 .16594 Mdot
.6 .1663 Mdot
.6 .16656 Mdot
.6 .16675 Mdot
.6 .16708 Mdot
.6 .16718 Mdot
.6 .16785 Mdot
.6 .16807 Mdot
.6 .16918 Mdot
.6 .16918 Mdot
.6 .16934 Mdot
.6 .17095 Mdot
.6 .17119 Mdot
.6 .17133 Mdot
.6 .17195 Mdot
.6 .17225 Mdot
.6 .17268 Mdot
.6 .17295 Mdot
.6 .17299 Mdot
.6 .17431 Mdot
.6 .17458 Mdot
.6 .17494 Mdot
.6 .17673 Mdot
.6 .17714 Mdot
.6 .1772 Mdot
.6 .17917 Mdot
.6 .17953 Mdot
.6 .17986 Mdot
.6 .17994 Mdot
.6 .17998 Mdot
.6 .18053 Mdot
.6 .18055 Mdot
.6 .18084 Mdot
.6 .18102 Mdot
.6 .18104 Mdot
.6 .18124 Mdot
.6 .18173 Mdot
.6 .18208 Mdot
.6 .18226 Mdot
.6 .18254 Mdot
.6 .18287 Mdot
.6 .18319 Mdot
.6 .18509 Mdot
.6 .18574 Mdot
.6 .18656 Mdot
.6 .18672 Mdot
.6 .18729 Mdot
.6 .18743 Mdot
.6 .18792 Mdot
.6 .18802 Mdot
.6 .18926 Mdot
.6 .18943 Mdot
.6 .18953 Mdot
.6 .18991 Mdot
.6 .19013 Mdot
.6 .19078 Mdot
.6 .1909 Mdot
.6 .19103 Mdot
.6 .19153 Mdot
.6 .19203 Mdot
.6 .19228 Mdot
.6 .19252 Mdot
.6 .1928 Mdot
.6 .19293 Mdot
.6 .19476 Mdot
.6 .19531 Mdot
.6 .19619 Mdot
.6 .19662 Mdot
.6 .19693 Mdot
.6 .19716 Mdot
.6 .19755 Mdot
.6 .19767 Mdot
.6 .19848 Mdot
.6 .19874 Mdot
.6 .20007 Mdot
.6 .20008 Mdot
.6 .20026 Mdot
.6 .2022 Mdot
.6 .20248 Mdot
.6 .20265 Mdot
.6 .20339 Mdot
.6 .20376 Mdot
.6 .20427 Mdot
.6 .2046 Mdot
.6 .20465 Mdot
.6 .20623 Mdot
.6 .20655 Mdot
.6 .20699 Mdot
.6 .20914 Mdot
.6 .20962 Mdot
.6 .20969 Mdot
.6 .21206 Mdot
.6 .2125 Mdot
.6 .21289 Mdot
.6 .21298 Mdot
.6 .21304 Mdot
.6 .2137 Mdot
.6 .21372 Mdot
.6 .21406 Mdot
.6 .21428 Mdot
.6 .2143 Mdot
.6 .21454 Mdot
.6 .21514 Mdot
.6 .21555 Mdot
.6 .21576 Mdot
.6 .21611 Mdot
.6 .2165 Mdot
.6 .21688 Mdot
.6 .21916 Mdot
.6 .21995 Mdot
.6 .22093 Mdot
.6 .22113 Mdot
.6 .2218 Mdot
.6 .22198 Mdot
.6 .22256 Mdot
.6 .22269 Mdot
.6 .22417 Mdot
.6 .22437 Mdot
.6 .22449 Mdot
.6 .22495 Mdot
.6 .22521 Mdot
.6 .22599 Mdot
.6 .22613 Mdot
.6 .2263 Mdot
.6 .22689 Mdot
.6 .2275 Mdot
.6 .22779 Mdot
.6 .22808 Mdot
.6 .22841 Mdot
.6 .22857 Mdot
.6 .23077 Mdot
.6 .23143 Mdot
.6 .23248 Mdot
.6 .233 Mdot
.6 .23337 Mdot
.6 .23364 Mdot
.6 .23412 Mdot
.6 .23426 Mdot
.6 .23524 Mdot
.6 .23555 Mdot
.6 .23714 Mdot
.6 .23715 Mdot
.6 .23737 Mdot
.6 .2397 Mdot
.6 .24004 Mdot
.6 .24024 Mdot
.6 .24113 Mdot
.6 .24156 Mdot
.6 .24218 Mdot
.6 .24257 Mdot
.6 .24264 Mdot
.6 .24453 Mdot
.6 .24492 Mdot
.6 .24544 Mdot
.6 .24802 Mdot
.6 .24861 Mdot
.6 .24869 Mdot
.6 .25153 Mdot
.6 .25205 Mdot
.6 .25252 Mdot
.6 .25264 Mdot
.6 .2527 Mdot
.6 .25349 Mdot
.6 .25352 Mdot
.6 .25393 Mdot
.6 .25419 Mdot
.6 .25422 Mdot
.6 .25451 Mdot
.6 .25522 Mdot
.6 .25571 Mdot
.6 .25597 Mdot
.6 .25639 Mdot
.6 .25686 Mdot
.6 .25731 Mdot
.6 .26005 Mdot
.6 .261 Mdot
.6 .26217 Mdot
.6 .26241 Mdot
.6 .26322 Mdot
.6 .26343 Mdot
.6 .26413 Mdot
.6 .26428 Mdot
.6 .26606 Mdot
.6 .26631 Mdot
.6 .26645 Mdot
.6 .26699 Mdot
.6 .26731 Mdot
.6 .26825 Mdot
.6 .26842 Mdot
.6 .26861 Mdot
.6 .26933 Mdot
.6 .27005 Mdot
.6 .27041 Mdot
.6 .27075 Mdot
.6 .27115 Mdot
.6 .27134 Mdot
.6 .27398 Mdot
.6 .27478 Mdot
.6 .27603 Mdot
.6 .27666 Mdot
.6 .2771 Mdot
.6 .27743 Mdot
.6 .278 Mdot
.6 .27817 Mdot
.6 .27934 Mdot
.6 .27971 Mdot
.6 .28162 Mdot
.6 .28164 Mdot
.6 .2819 Mdot
.6 .28469 Mdot
.6 .2851 Mdot
.6 .28535 Mdot
.6 .28641 Mdot
.6 .28693 Mdot
.6 .28768 Mdot
.6 .28815 Mdot
.6 .28822 Mdot
.6 .29049 Mdot
.6 .29096 Mdot
.6 .29159 Mdot
.6 .29468 Mdot
.6 .29538 Mdot
.6 .29548 Mdot
.6 .29889 Mdot
.6 .29952 Mdot
.6 .30008 Mdot
.6 .30022 Mdot
.6 .3003 Mdot
.6 .30125 Mdot
.6 .30128 Mdot
.6 .30177 Mdot
.6 .30209 Mdot
.6 .30212 Mdot
.6 .30247 Mdot
.6 .30332 Mdot
.6 .30391 Mdot
.6 .30423 Mdot
.6 .30472 Mdot
.6 .30529 Mdot
.6 .30583 Mdot
.6 .30912 Mdot
.6 .31025 Mdot
.6 .31166 Mdot
.6 .31195 Mdot
.6 .31292 Mdot
.6 .31317 Mdot
.6 .31401 Mdot
.6 .31419 Mdot
.6 .31633 Mdot
.6 .31663 Mdot
.6 .3168 Mdot
.6 .31745 Mdot
.6 .31783 Mdot
.6 .31895 Mdot
.6 .31916 Mdot
.6 .31939 Mdot
.6 .32025 Mdot
.6 .32112 Mdot
.6 .32155 Mdot
.6 .32195 Mdot
.6 .32244 Mdot
.6 .32267 Mdot
.6 .32584 Mdot
.6 .32679 Mdot
.6 .3283 Mdot
.6 .32905 Mdot
.6 .32958 Mdot
.6 .32997 Mdot
.6 .33065 Mdot
.6 .33086 Mdot
.6 .33226 Mdot
.6 .33271 Mdot
.6 .335 Mdot
.6 .33502 Mdot
.6 .33534 Mdot
.6 .33869 Mdot
.6 .33918 Mdot
.6 .33947 Mdot
.6 .34075 Mdot
.6 .34138 Mdot
.6 .34227 Mdot
.6 .34283 Mdot
.6 .34292 Mdot
.6 .34565 Mdot
.6 .34696 Mdot
.6 .35068 Mdot
.6 .35152 Mdot
.6 .35163 Mdot
.6 .35573 Mdot
.6 .35648 Mdot
.6 .35715 Mdot
.6 .35733 Mdot
.6 .35741 Mdot
.6 .35856 Mdot
.6 .3586 Mdot
.6 .35918 Mdot
.6 .35957 Mdot
.6 .3596 Mdot
.6 .36002 Mdot
.6 .36104 Mdot
.6 .36175 Mdot
.6 .36213 Mdot
.6 .36272 Mdot
.6 .3634 Mdot
.6 .36406 Mdot
.6 .36616 Mdot
.6 .368 Mdot
.6 .36936 Mdot
.602 .01503 Mdot
.602 .01509 Mdot
.602 .01517 Mdot
.602 .0152 Mdot
.602 .01526 Mdot
.602 .0153 Mdot
.602 .01538 Mdot
.602 .01542 Mdot
.602 .01545 Mdot
.602 .01551 Mdot
.602 .01557 Mdot
.602 .01561 Mdot
.602 .01565 Mdot
.602 .01567 Mdot
.602 .01574 Mdot
.602 .01579 Mdot
.602 .01584 Mdot
.602 .01587 Mdot
.602 .01595 Mdot
.602 .01601 Mdot
.602 .01607 Mdot
.602 .0161 Mdot
.602 .01618 Mdot
.602 .0162 Mdot
.602 .01627 Mdot
.602 .01634 Mdot
.602 .01639 Mdot
.602 .01648 Mdot
.602 .01651 Mdot
.602 .01659 Mdot
.602 .01667 Mdot
.602 .01673 Mdot
.602 .01684 Mdot
.602 .01687 Mdot
.602 .01697 Mdot
.602 .01707 Mdot
.602 .01714 Mdot
.602 .01728 Mdot
.602 .01732 Mdot
.602 .01743 Mdot
.602 .01743 Mdot
.602 .01755 Mdot
.602 .01764 Mdot
.602 .0178 Mdot
.602 .01785 Mdot
.602 .01798 Mdot
.602 .01799 Mdot
.602 .01813 Mdot
.602 .01823 Mdot
.602 .01843 Mdot
.602 .01848 Mdot
.602 .01865 Mdot
.602 .01865 Mdot
.602 .01883 Mdot
.602 .01895 Mdot
.602 .01919 Mdot
.602 .01925 Mdot
.602 .01945 Mdot
.602 .01946 Mdot
.602 .01967 Mdot
.602 .01981 Mdot
.602 .0201 Mdot
.602 .02018 Mdot
.602 .02041 Mdot
.602 .02042 Mdot
.602 .02068 Mdot
.602 .02085 Mdot
.602 .02116 Mdot
.602 .0212 Mdot
.602 .02129 Mdot
.602 .02158 Mdot
.602 .02159 Mdot
.602 .0219 Mdot
.602 .0221 Mdot
.602 .02248 Mdot
.602 .02252 Mdot
.602 .02264 Mdot
.602 .02298 Mdot
.602 .02299 Mdot
.602 .02302 Mdot
.602 .02327 Mdot
.602 .02336 Mdot
.602 .02361 Mdot
.602 .02406 Mdot
.602 .02411 Mdot
.602 .02425 Mdot
.602 .02459 Mdot
.602 .02465 Mdot
.602 .02466 Mdot
.602 .02468 Mdot
.602 .02472 Mdot
.602 .02502 Mdot
.602 .02513 Mdot
.602 .02543 Mdot
.602 .02568 Mdot
.602 .02597 Mdot
.602 .02603 Mdot
.602 .0262 Mdot
.602 .0266 Mdot
.602 .02668 Mdot
.602 .02669 Mdot
.602 .02671 Mdot
.602 .02676 Mdot
.602 .02712 Mdot
.602 .02725 Mdot
.602 .02734 Mdot
.602 .02761 Mdot
.602 .02791 Mdot
.602 .02803 Mdot
.602 .02827 Mdot
.602 .02833 Mdot
.602 .02854 Mdot
.602 .02903 Mdot
.602 .02912 Mdot
.602 .02914 Mdot
.602 .02916 Mdot
.602 .02921 Mdot
.602 .02952 Mdot
.602 .02965 Mdot
.602 .02981 Mdot
.602 .02991 Mdot
.602 .03024 Mdot
.602 .03061 Mdot
.602 .03074 Mdot
.602 .03103 Mdot
.602 .03111 Mdot
.602 .0312 Mdot
.602 .03136 Mdot
.602 .03151 Mdot
.602 .0318 Mdot
.602 .03195 Mdot
.602 .03206 Mdot
.602 .03208 Mdot
.602 .0321 Mdot
.602 .03217 Mdot
.602 .03254 Mdot
.602 .03269 Mdot
.602 .03289 Mdot
.602 .03301 Mdot
.602 .03341 Mdot
.602 .03353 Mdot
.602 .03365 Mdot
.602 .03373 Mdot
.602 .03383 Mdot
.602 .03385 Mdot
.602 .03401 Mdot
.602 .03432 Mdot
.602 .03436 Mdot
.602 .0344 Mdot
.602 .03446 Mdot
.602 .03456 Mdot
.602 .03476 Mdot
.602 .03494 Mdot
.602 .03495 Mdot
.602 .03528 Mdot
.602 .03547 Mdot
.602 .0356 Mdot
.602 .03562 Mdot
.602 .03565 Mdot
.602 .03573 Mdot
.602 .03617 Mdot
.602 .03636 Mdot
.602 .0366 Mdot
.602 .03674 Mdot
.602 .03722 Mdot
.602 .03737 Mdot
.602 .03752 Mdot
.602 .03761 Mdot
.602 .03773 Mdot
.602 .03775 Mdot
.602 .03795 Mdot
.602 .03832 Mdot
.602 .03837 Mdot
.602 .03842 Mdot
.602 .03848 Mdot
.602 .03861 Mdot
.602 .03884 Mdot
.602 .03907 Mdot
.602 .03907 Mdot
.602 .03948 Mdot
.602 .0397 Mdot
.602 .03986 Mdot
.602 .03988 Mdot
.602 .03992 Mdot
.602 .03995 Mdot
.602 .04002 Mdot
.602 .04055 Mdot
.602 .04077 Mdot
.602 .04095 Mdot
.602 .04106 Mdot
.602 .04124 Mdot
.602 .04166 Mdot
.602 .0418 Mdot
.602 .04182 Mdot
.602 .042 Mdot
.602 .04217 Mdot
.602 .04228 Mdot
.602 .04243 Mdot
.602 .04245 Mdot
.602 .04259 Mdot
.602 .04268 Mdot
.602 .04313 Mdot
.602 .04319 Mdot
.602 .04325 Mdot
.602 .04333 Mdot
.602 .04348 Mdot
.602 .04367 Mdot
.602 .04377 Mdot
.602 .04404 Mdot
.602 .04404 Mdot
.602 .04453 Mdot
.602 .0448 Mdot
.602 .04499 Mdot
.602 .04502 Mdot
.602 .04506 Mdot
.602 .0451 Mdot
.602 .04518 Mdot
.602 .0452 Mdot
.602 .04567 Mdot
.602 .04582 Mdot
.602 .04609 Mdot
.602 .0463 Mdot
.602 .04643 Mdot
.602 .04665 Mdot
.602 .04716 Mdot
.602 .04732 Mdot
.602 .04735 Mdot
.602 .04746 Mdot
.602 .04756 Mdot
.602 .04777 Mdot
.602 .0479 Mdot
.602 .04805 Mdot
.602 .04808 Mdot
.602 .04811 Mdot
.602 .04826 Mdot
.602 .04828 Mdot
.602 .04833 Mdot
.602 .04839 Mdot
.602 .04893 Mdot
.602 .04899 Mdot
.602 .049 Mdot
.602 .04907 Mdot
.602 .04917 Mdot
.602 .04935 Mdot
.602 .04951 Mdot
.602 .04958 Mdot
.602 .04969 Mdot
.602 .05002 Mdot
.602 .05003 Mdot
.602 .05061 Mdot
.602 .05093 Mdot
.602 .05116 Mdot
.602 .0512 Mdot
.602 .05125 Mdot
.602 .0513 Mdot
.602 .05139 Mdot
.602 .05142 Mdot
.602 .05198 Mdot
.602 .05217 Mdot
.602 .05249 Mdot
.602 .05274 Mdot
.602 .0529 Mdot
.602 .05311 Mdot
.602 .05316 Mdot
.602 .05324 Mdot
.602 .05337 Mdot
.602 .05377 Mdot
.602 .05397 Mdot
.602 .054 Mdot
.602 .05414 Mdot
.602 .05426 Mdot
.602 .05444 Mdot
.602 .05451 Mdot
.602 .05468 Mdot
.602 .05486 Mdot
.602 .05489 Mdot
.602 .05492 Mdot
.602 .05511 Mdot
.602 .05513 Mdot
.602 .05519 Mdot
.602 .05526 Mdot
.602 .05591 Mdot
.602 .05598 Mdot
.602 .056 Mdot
.602 .05608 Mdot
.602 .0562 Mdot
.602 .05642 Mdot
.602 .05661 Mdot
.602 .05667 Mdot
.602 .0567 Mdot
.602 .05683 Mdot
.602 .05722 Mdot
.602 .05723 Mdot
.602 .05736 Mdot
.602 .05794 Mdot
.602 .05832 Mdot
.602 .05832 Mdot
.602 .0586 Mdot
.602 .05864 Mdot
.602 .05871 Mdot
.602 .05877 Mdot
.602 .05888 Mdot
.602 .05891 Mdot
.602 .05959 Mdot
.602 .05979 Mdot
.602 .05981 Mdot
.602 .0602 Mdot
.602 .0605 Mdot
.602 .06069 Mdot
.602 .06095 Mdot
.602 .061 Mdot
.602 .06103 Mdot
.602 .0611 Mdot
.602 .06126 Mdot
.602 .06174 Mdot
.602 .06198 Mdot
.602 .06202 Mdot
.602 .06219 Mdot
.602 .06233 Mdot
.602 .06254 Mdot
.602 .06263 Mdot
.602 .06283 Mdot
.602 .06304 Mdot
.602 .06309 Mdot
.602 .06312 Mdot
.602 .06335 Mdot
.602 .06336 Mdot
.602 .06337 Mdot
.602 .06339 Mdot
.602 .06345 Mdot
.602 .06353 Mdot
.602 .06431 Mdot
.602 .0644 Mdot
.602 .06442 Mdot
.602 .06452 Mdot
.602 .06466 Mdot
.602 .06492 Mdot
.602 .06516 Mdot
.602 .06523 Mdot
.602 .06526 Mdot
.602 .06535 Mdot
.602 .06542 Mdot
.602 .06589 Mdot
.602 .0659 Mdot
.602 .06592 Mdot
.602 .06606 Mdot
.602 .06635 Mdot
.602 .06675 Mdot
.602 .06692 Mdot
.602 .06722 Mdot
.602 .06722 Mdot
.602 .06748 Mdot
.602 .06755 Mdot
.602 .06761 Mdot
.602 .06768 Mdot
.602 .06775 Mdot
.602 .06792 Mdot
.602 .06874 Mdot
.602 .0688 Mdot
.602 .06899 Mdot
.602 .06901 Mdot
.602 .06948 Mdot
.602 .06984 Mdot
.602 .07007 Mdot
.602 .07038 Mdot
.602 .07044 Mdot
.602 .07047 Mdot
.602 .07056 Mdot
.602 .07075 Mdot
.602 .07134 Mdot
.602 .07163 Mdot
.602 .07167 Mdot
.602 .07187 Mdot
.602 .07204 Mdot
.602 .0723 Mdot
.602 .07241 Mdot
.602 .07264 Mdot
.602 .0729 Mdot
.602 .07295 Mdot
.602 .073 Mdot
.602 .07327 Mdot
.602 .07329 Mdot
.602 .0733 Mdot
.602 .07332 Mdot
.602 .07339 Mdot
.602 .07349 Mdot
.602 .07443 Mdot
.602 .07454 Mdot
.602 .07456 Mdot
.602 .07468 Mdot
.602 .07485 Mdot
.602 .07509 Mdot
.602 .07516 Mdot
.602 .07545 Mdot
.602 .07554 Mdot
.602 .07557 Mdot
.602 .07558 Mdot
.602 .07568 Mdot
.602 .07576 Mdot
.602 .07633 Mdot
.602 .07635 Mdot
.602 .07637 Mdot
.602 .07654 Mdot
.602 .07688 Mdot
.602 .07699 Mdot
.602 .07714 Mdot
.602 .07737 Mdot
.602 .07756 Mdot
.602 .07793 Mdot
.602 .07793 Mdot
.602 .07824 Mdot
.602 .07833 Mdot
.602 .0784 Mdot
.602 .07848 Mdot
.602 .07857 Mdot
.602 .07878 Mdot
.602 .07976 Mdot
.602 .07984 Mdot
.602 .08006 Mdot
.602 .08008 Mdot
.602 .08065 Mdot
.602 .08077 Mdot
.602 .08108 Mdot
.602 .08137 Mdot
.602 .08153 Mdot
.602 .08173 Mdot
.602 .08181 Mdot
.602 .08185 Mdot
.602 .08195 Mdot
.602 .08219 Mdot
.602 .08289 Mdot
.602 .08324 Mdot
.602 .08328 Mdot
.602 .08353 Mdot
.602 .08354 Mdot
.602 .08374 Mdot
.602 .08405 Mdot
.602 .08418 Mdot
.602 .08446 Mdot
.602 .08477 Mdot
.602 .08483 Mdot
.602 .08489 Mdot
.602 .08521 Mdot
.602 .08524 Mdot
.602 .08525 Mdot
.602 .08527 Mdot
.602 .08536 Mdot
.602 .08538 Mdot
.602 .08548 Mdot
.602 .08642 Mdot
.602 .08661 Mdot
.602 .08674 Mdot
.602 .08677 Mdot
.602 .08692 Mdot
.602 .08712 Mdot
.602 .08741 Mdot
.602 .0875 Mdot
.602 .08783 Mdot
.602 .08795 Mdot
.602 .08798 Mdot
.602 .088 Mdot
.602 .08812 Mdot
.602 .08822 Mdot
.602 .0889 Mdot
.602 .08892 Mdot
.602 .08895 Mdot
.602 .08915 Mdot
.602 .08957 Mdot
.602 .0897 Mdot
.602 .08988 Mdot
.602 .09015 Mdot
.602 .09039 Mdot
.602 .09082 Mdot
.602 .09083 Mdot
.602 .0912 Mdot
.602 .09131 Mdot
.602 .09139 Mdot
.602 .09149 Mdot
.602 .0916 Mdot
.602 .09185 Mdot
.602 .09303 Mdot
.602 .09312 Mdot
.602 .09339 Mdot
.602 .09342 Mdot
.602 .0941 Mdot
.602 .09424 Mdot
.602 .09462 Mdot
.602 .09497 Mdot
.602 .09516 Mdot
.602 .09541 Mdot
.602 .0955 Mdot
.602 .09555 Mdot
.602 .09567 Mdot
.602 .09595 Mdot
.602 .09679 Mdot
.602 .09722 Mdot
.602 .09727 Mdot
.602 .09757 Mdot
.602 .09758 Mdot
.602 .09782 Mdot
.602 .09819 Mdot
.602 .09835 Mdot
.602 .09869 Mdot
.602 .09907 Mdot
.602 .09914 Mdot
.602 .0992 Mdot
.602 .0996 Mdot
.602 .09962 Mdot
.602 .09964 Mdot
.602 .09966 Mdot
.602 .09977 Mdot
.602 .09979 Mdot
.602 .09992 Mdot
.602 .10105 Mdot
.602 .10127 Mdot
.602 .10144 Mdot
.602 .10147 Mdot
.602 .10165 Mdot
.602 .10189 Mdot
.602 .10224 Mdot
.602 .10234 Mdot
.602 .10275 Mdot
.602 .10288 Mdot
.602 .10293 Mdot
.602 .10295 Mdot
.602 .1031 Mdot
.602 .10321 Mdot
.602 .10403 Mdot
.602 .10406 Mdot
.602 .10409 Mdot
.602 .10433 Mdot
.602 .10484 Mdot
.602 .10499 Mdot
.602 .10521 Mdot
.602 .10554 Mdot
.602 .10582 Mdot
.602 .10635 Mdot
.602 .10636 Mdot
.602 .1068 Mdot
.602 .10693 Mdot
.602 .10703 Mdot
.602 .10716 Mdot
.602 .10728 Mdot
.602 .10758 Mdot
.602 .10901 Mdot
.602 .10912 Mdot
.602 .10944 Mdot
.602 .10947 Mdot
.602 .11029 Mdot
.602 .11047 Mdot
.602 .11092 Mdot
.602 .11134 Mdot
.602 .11157 Mdot
.602 .11187 Mdot
.602 .11198 Mdot
.602 .11203 Mdot
.602 .11218 Mdot
.602 .11252 Mdot
.602 .11354 Mdot
.602 .11405 Mdot
.602 .11411 Mdot
.602 .11447 Mdot
.602 .11449 Mdot
.602 .11477 Mdot
.602 .11522 Mdot
.602 .11541 Mdot
.602 .11582 Mdot
.602 .11627 Mdot
.602 .11636 Mdot
.602 .11644 Mdot
.602 .11691 Mdot
.602 .11694 Mdot
.602 .11697 Mdot
.602 .11699 Mdot
.602 .11713 Mdot
.602 .11715 Mdot
.602 .1173 Mdot
.602 .11866 Mdot
.602 .11893 Mdot
.602 .11913 Mdot
.602 .11916 Mdot
.602 .11938 Mdot
.602 .11968 Mdot
.602 .12009 Mdot
.602 .12022 Mdot
.602 .12071 Mdot
.602 .12087 Mdot
.602 .12093 Mdot
.602 .12095 Mdot
.602 .12113 Mdot
.602 .12127 Mdot
.602 .12225 Mdot
.602 .12228 Mdot
.602 .12232 Mdot
.602 .12261 Mdot
.602 .12322 Mdot
.602 .12341 Mdot
.602 .12367 Mdot
.602 .12407 Mdot
.602 .12441 Mdot
.602 .12504 Mdot
.602 .12505 Mdot
.602 .12559 Mdot
.602 .12574 Mdot
.602 .12586 Mdot
.602 .12601 Mdot
.602 .12617 Mdot
.602 .12653 Mdot
.602 .12824 Mdot
.602 .12838 Mdot
.602 .12876 Mdot
.602 .1288 Mdot
.602 .12979 Mdot
.602 .13 Mdot
.602 .13055 Mdot
.602 .13105 Mdot
.602 .13133 Mdot
.602 .13169 Mdot
.602 .13182 Mdot
.602 .13189 Mdot
.602 .13206 Mdot
.602 .13247 Mdot
.602 .1337 Mdot
.602 .13431 Mdot
.602 .13439 Mdot
.602 .13482 Mdot
.602 .13484 Mdot
.602 .13518 Mdot
.602 .13572 Mdot
.602 .13595 Mdot
.602 .13644 Mdot
.602 .13699 Mdot
.602 .1371 Mdot
.602 .13719 Mdot
.602 .13776 Mdot
.602 .1378 Mdot
.602 .13782 Mdot
.602 .13786 Mdot
.602 .13802 Mdot
.602 .13804 Mdot
.602 .13822 Mdot
.602 .13987 Mdot
.602 .14019 Mdot
.602 .14043 Mdot
.602 .14047 Mdot
.602 .14073 Mdot
.602 .14109 Mdot
.602 .14159 Mdot
.602 .14174 Mdot
.602 .14233 Mdot
.602 .14253 Mdot
.602 .1426 Mdot
.602 .14262 Mdot
.602 .14283 Mdot
.602 .143 Mdot
.602 .14419 Mdot
.602 .14423 Mdot
.602 .14427 Mdot
.602 .14462 Mdot
.602 .14536 Mdot
.602 .14558 Mdot
.602 .1459 Mdot
.602 .14638 Mdot
.602 .14679 Mdot
.602 .14755 Mdot
.602 .14756 Mdot
.602 .14821 Mdot
.602 .14839 Mdot
.602 .14853 Mdot
.602 .14872 Mdot
.602 .1489 Mdot
.602 .14934 Mdot
.602 .1514 Mdot
.602 .15156 Mdot
.602 .15203 Mdot
.602 .15208 Mdot
.602 .15327 Mdot
.602 .15352 Mdot
.602 .15418 Mdot
.602 .15478 Mdot
.602 .15512 Mdot
.602 .15555 Mdot
.602 .15571 Mdot
.602 .15579 Mdot
.602 .156 Mdot
.602 .1565 Mdot
.602 .15797 Mdot
.602 .15871 Mdot
.602 .1588 Mdot
.602 .15933 Mdot
.602 .15935 Mdot
.602 .15976 Mdot
.602 .16041 Mdot
.602 .16068 Mdot
.602 .16127 Mdot
.602 .16194 Mdot
.602 .16206 Mdot
.602 .16217 Mdot
.602 .16286 Mdot
.602 .16291 Mdot
.602 .16294 Mdot
.602 .16298 Mdot
.602 .16317 Mdot
.602 .1632 Mdot
.602 .16342 Mdot
.602 .1654 Mdot
.602 .16579 Mdot
.602 .16607 Mdot
.602 .16613 Mdot
.602 .16644 Mdot
.602 .16687 Mdot
.602 .16747 Mdot
.602 .16766 Mdot
.602 .16837 Mdot
.602 .1686 Mdot
.602 .16868 Mdot
.602 .16871 Mdot
.602 .16897 Mdot
.602 .16918 Mdot
.602 .1706 Mdot
.602 .17065 Mdot
.602 .1707 Mdot
.602 .17112 Mdot
.602 .17201 Mdot
.602 .17228 Mdot
.602 .17266 Mdot
.602 .17324 Mdot
.602 .17373 Mdot
.602 .17465 Mdot
.602 .17466 Mdot
.602 .17544 Mdot
.602 .17566 Mdot
.602 .17583 Mdot
.602 .17605 Mdot
.602 .17628 Mdot
.602 .1768 Mdot
.602 .17929 Mdot
.602 .17948 Mdot
.602 .18004 Mdot
.602 .1801 Mdot
.602 .18153 Mdot
.602 .18183 Mdot
.602 .18263 Mdot
.602 .18335 Mdot
.602 .18376 Mdot
.602 .18428 Mdot
.602 .18448 Mdot
.602 .18457 Mdot
.602 .18483 Mdot
.602 .18542 Mdot
.602 .1872 Mdot
.602 .18808 Mdot
.602 .1882 Mdot
.602 .18883 Mdot
.602 .18886 Mdot
.602 .18934 Mdot
.602 .19013 Mdot
.602 .19046 Mdot
.602 .19117 Mdot
.602 .19197 Mdot
.602 .19212 Mdot
.602 .19226 Mdot
.602 .19308 Mdot
.602 .19314 Mdot
.602 .19318 Mdot
.602 .19323 Mdot
.602 .19346 Mdot
.602 .1935 Mdot
.602 .19376 Mdot
.602 .19614 Mdot
.602 .19661 Mdot
.602 .19695 Mdot
.602 .19702 Mdot
.602 .19739 Mdot
.602 .19791 Mdot
.602 .19863 Mdot
.602 .19886 Mdot
.602 .19971 Mdot
.602 .19999 Mdot
.602 .20009 Mdot
.602 .20013 Mdot
.602 .20044 Mdot
.602 .20069 Mdot
.602 .2024 Mdot
.602 .20246 Mdot
.602 .20252 Mdot
.602 .20303 Mdot
.602 .20409 Mdot
.602 .20442 Mdot
.602 .20488 Mdot
.602 .20558 Mdot
.602 .20617 Mdot
.602 .20728 Mdot
.602 .20729 Mdot
.602 .20822 Mdot
.602 .2085 Mdot
.602 .2087 Mdot
.602 .20897 Mdot
.602 .20923 Mdot
.602 .20987 Mdot
.602 .21286 Mdot
.602 .21309 Mdot
.602 .21376 Mdot
.602 .21383 Mdot
.602 .21556 Mdot
.602 .21592 Mdot
.602 .21688 Mdot
.602 .21775 Mdot
.602 .21825 Mdot
.602 .21887 Mdot
.602 .21911 Mdot
.602 .21922 Mdot
.602 .21953 Mdot
.602 .22024 Mdot
.602 .22238 Mdot
.602 .22345 Mdot
.602 .22359 Mdot
.602 .22435 Mdot
.602 .22438 Mdot
.602 .22497 Mdot
.602 .22592 Mdot
.602 .22631 Mdot
.602 .22717 Mdot
.602 .22813 Mdot
.602 .22831 Mdot
.602 .22848 Mdot
.602 .22947 Mdot
.602 .22954 Mdot
.602 .22958 Mdot
.602 .22964 Mdot
.602 .22992 Mdot
.602 .22997 Mdot
.602 .23028 Mdot
.602 .23315 Mdot
.602 .23372 Mdot
.602 .23413 Mdot
.602 .2342 Mdot
.602 .23466 Mdot
.602 .23528 Mdot
.602 .23615 Mdot
.602 .23642 Mdot
.602 .23745 Mdot
.602 .23779 Mdot
.602 .23791 Mdot
.602 .23795 Mdot
.602 .23833 Mdot
.602 .23862 Mdot
.602 .24069 Mdot
.602 .24076 Mdot
.602 .24084 Mdot
.602 .24145 Mdot
.602 .24273 Mdot
.602 .24312 Mdot
.602 .24367 Mdot
.602 .24451 Mdot
.602 .24522 Mdot
.602 .24656 Mdot
.602 .24657 Mdot
.602 .2477 Mdot
.602 .24803 Mdot
.602 .24827 Mdot
.602 .2486 Mdot
.602 .24892 Mdot
.602 .24968 Mdot
.602 .25328 Mdot
.602 .25356 Mdot
.602 .25437 Mdot
.602 .25445 Mdot
.602 .25653 Mdot
.602 .25697 Mdot
.602 .25812 Mdot
.602 .25917 Mdot
.602 .25977 Mdot
.602 .26051 Mdot
.602 .26081 Mdot
.602 .26094 Mdot
.602 .26131 Mdot
.602 .26217 Mdot
.602 .26475 Mdot
.602 .26603 Mdot
.602 .2662 Mdot
.602 .26711 Mdot
.602 .26715 Mdot
.602 .26786 Mdot
.602 .269 Mdot
.602 .26948 Mdot
.602 .27051 Mdot
.602 .27167 Mdot
.602 .27189 Mdot
.602 .27208 Mdot
.602 .27328 Mdot
.602 .27336 Mdot
.602 .27342 Mdot
.602 .27349 Mdot
.602 .27382 Mdot
.602 .27388 Mdot
.602 .27425 Mdot
.602 .27771 Mdot
.602 .27839 Mdot
.602 .27888 Mdot
.602 .27898 Mdot
.602 .27953 Mdot
.602 .28027 Mdot
.602 .28133 Mdot
.602 .28165 Mdot
.602 .28289 Mdot
.602 .2833 Mdot
.602 .28344 Mdot
.602 .28349 Mdot
.602 .28394 Mdot
.602 .2843 Mdot
.602 .28679 Mdot
.602 .28687 Mdot
.602 .28696 Mdot
.602 .2877 Mdot
.602 .28924 Mdot
.602 .28972 Mdot
.602 .29038 Mdot
.602 .29139 Mdot
.602 .29225 Mdot
.602 .29386 Mdot
.602 .29387 Mdot
.602 .29523 Mdot
.602 .29562 Mdot
.602 .29592 Mdot
.602 .29631 Mdot
.602 .29669 Mdot
.602 .29761 Mdot
.602 .30195 Mdot
.602 .30229 Mdot
.602 .30326 Mdot
.602 .30336 Mdot
.602 .30586 Mdot
.602 .30639 Mdot
.602 .30778 Mdot
.602 .30904 Mdot
.602 .30976 Mdot
.602 .31066 Mdot
.602 .31101 Mdot
.602 .31117 Mdot
.602 .31162 Mdot
.602 .31265 Mdot
.602 .31575 Mdot
.602 .3173 Mdot
.602 .3175 Mdot
.602 .3186 Mdot
.602 .31865 Mdot
.602 .3195 Mdot
.602 .32088 Mdot
.602 .32145 Mdot
.602 .32269 Mdot
.602 .32409 Mdot
.602 .32435 Mdot
.602 .32459 Mdot
.602 .32603 Mdot
.602 .32613 Mdot
.602 .32619 Mdot
.602 .32628 Mdot
.602 .32668 Mdot
.602 .32675 Mdot
.602 .3272 Mdot
.602 .33136 Mdot
.602 .33218 Mdot
.602 .33278 Mdot
.602 .33289 Mdot
.602 .33355 Mdot
.602 .33445 Mdot
.602 .33572 Mdot
.602 .33611 Mdot
.602 .3376 Mdot
.602 .33809 Mdot
.602 .33826 Mdot
.602 .33832 Mdot
.602 .33886 Mdot
.602 .3393 Mdot
.602 .34229 Mdot
.602 .34239 Mdot
.602 .3425 Mdot
.602 .34339 Mdot
.602 .34524 Mdot
.602 .34582 Mdot
.602 .34662 Mdot
.602 .34783 Mdot
.602 .34886 Mdot
.602 .3508 Mdot
.602 .35082 Mdot
.602 .35245 Mdot
.602 .35293 Mdot
.602 .35328 Mdot
.602 .35375 Mdot
.602 .35422 Mdot
.602 .35532 Mdot
.602 .36054 Mdot
.602 .36095 Mdot
.602 .36212 Mdot
.602 .36225 Mdot
.602 .36526 Mdot
.602 .36589 Mdot
.602 .36756 Mdot
.602 .36909 Mdot
.602 .36995 Mdot
.604 .01521 Mdot
.604 .01525 Mdot
.604 .01531 Mdot
.604 .01536 Mdot
.604 .01543 Mdot
.604 .01549 Mdot
.604 .01558 Mdot
.604 .01565 Mdot
.604 .01576 Mdot
.604 .01585 Mdot
.604 .01598 Mdot
.604 .01608 Mdot
.604 .01624 Mdot
.604 .01637 Mdot
.604 .01656 Mdot
.604 .01671 Mdot
.604 .01694 Mdot
.604 .01713 Mdot
.604 .0174 Mdot
.604 .01763 Mdot
.604 .01796 Mdot
.604 .01824 Mdot
.604 .01826 Mdot
.604 .01834 Mdot
.604 .01864 Mdot
.604 .01897 Mdot
.604 .01899 Mdot
.604 .01909 Mdot
.604 .01945 Mdot
.604 .01962 Mdot
.604 .01986 Mdot
.604 .01988 Mdot
.604 .02044 Mdot
.604 .02047 Mdot
.604 .02047 Mdot
.604 .02064 Mdot
.604 .02092 Mdot
.604 .02096 Mdot
.604 .02163 Mdot
.604 .02166 Mdot
.604 .02167 Mdot
.604 .02177 Mdot
.604 .02187 Mdot
.604 .02222 Mdot
.604 .02225 Mdot
.604 .02306 Mdot
.604 .02311 Mdot
.604 .02311 Mdot
.604 .02311 Mdot
.604 .02324 Mdot
.604 .02336 Mdot
.604 .02378 Mdot
.604 .02382 Mdot
.604 .02392 Mdot
.604 .02405 Mdot
.604 .02467 Mdot
.604 .0248 Mdot
.604 .02485 Mdot
.604 .02485 Mdot
.604 .02486 Mdot
.604 .02502 Mdot
.604 .02507 Mdot
.604 .02507 Mdot
.604 .02516 Mdot
.604 .02529 Mdot
.604 .02566 Mdot
.604 .02572 Mdot
.604 .02584 Mdot
.604 .02599 Mdot
.604 .02632 Mdot
.604 .02674 Mdot
.604 .02678 Mdot
.604 .0269 Mdot
.604 .02696 Mdot
.604 .02696 Mdot
.604 .02697 Mdot
.604 .02716 Mdot
.604 .02722 Mdot
.604 .02723 Mdot
.604 .02733 Mdot
.604 .02749 Mdot
.604 .02794 Mdot
.604 .028 Mdot
.604 .0281 Mdot
.604 .02815 Mdot
.604 .02833 Mdot
.604 .02874 Mdot
.604 .02924 Mdot
.604 .02929 Mdot
.604 .02943 Mdot
.604 .02951 Mdot
.604 .02951 Mdot
.604 .02952 Mdot
.604 .02975 Mdot
.604 .02983 Mdot
.604 .02983 Mdot
.604 .02996 Mdot
.604 .03005 Mdot
.604 .03015 Mdot
.604 .03045 Mdot
.604 .03069 Mdot
.604 .03077 Mdot
.604 .03088 Mdot
.604 .03089 Mdot
.604 .03094 Mdot
.604 .03116 Mdot
.604 .03165 Mdot
.604 .03179 Mdot
.604 .03226 Mdot
.604 .03232 Mdot
.604 .03249 Mdot
.604 .03259 Mdot
.604 .03259 Mdot
.604 .0326 Mdot
.604 .03274 Mdot
.604 .03285 Mdot
.604 .03287 Mdot
.604 .03292 Mdot
.604 .03297 Mdot
.604 .03297 Mdot
.604 .03313 Mdot
.604 .03318 Mdot
.604 .03324 Mdot
.604 .03336 Mdot
.604 .03372 Mdot
.604 .03401 Mdot
.604 .03411 Mdot
.604 .03425 Mdot
.604 .03425 Mdot
.604 .03432 Mdot
.604 .03459 Mdot
.604 .03518 Mdot
.604 .03534 Mdot
.604 .03591 Mdot
.604 .03599 Mdot
.604 .03611 Mdot
.604 .03619 Mdot
.604 .03631 Mdot
.604 .03631 Mdot
.604 .03632 Mdot
.604 .03649 Mdot
.604 .03662 Mdot
.604 .03665 Mdot
.604 .0367 Mdot
.604 .03676 Mdot
.604 .03677 Mdot
.604 .03696 Mdot
.604 .03702 Mdot
.604 .03709 Mdot
.604 .03719 Mdot
.604 .03721 Mdot
.604 .03724 Mdot
.604 .03761 Mdot
.604 .03767 Mdot
.604 .03803 Mdot
.604 .03814 Mdot
.604 .03831 Mdot
.604 .03831 Mdot
.604 .03835 Mdot
.604 .0384 Mdot
.604 .03872 Mdot
.604 .03943 Mdot
.604 .03963 Mdot
.604 .0399 Mdot
.604 .0401 Mdot
.604 .04032 Mdot
.604 .04041 Mdot
.604 .04047 Mdot
.604 .04056 Mdot
.604 .04066 Mdot
.604 .0408 Mdot
.604 .0408 Mdot
.604 .04081 Mdot
.604 .04092 Mdot
.604 .04101 Mdot
.604 .04118 Mdot
.604 .04121 Mdot
.604 .04128 Mdot
.604 .04135 Mdot
.604 .04136 Mdot
.604 .04158 Mdot
.604 .04166 Mdot
.604 .04174 Mdot
.604 .04187 Mdot
.604 .04189 Mdot
.604 .04192 Mdot
.604 .04237 Mdot
.604 .04245 Mdot
.604 .04287 Mdot
.604 .04301 Mdot
.604 .04322 Mdot
.604 .04322 Mdot
.604 .04327 Mdot
.604 .04332 Mdot
.604 .04371 Mdot
.604 .04457 Mdot
.604 .04481 Mdot
.604 .04514 Mdot
.604 .04538 Mdot
.604 .04565 Mdot
.604 .04576 Mdot
.604 .04583 Mdot
.604 .04594 Mdot
.604 .04606 Mdot
.604 .04622 Mdot
.604 .04622 Mdot
.604 .04624 Mdot
.604 .04637 Mdot
.604 .04648 Mdot
.604 .04668 Mdot
.604 .04672 Mdot
.604 .0468 Mdot
.604 .04689 Mdot
.604 .0469 Mdot
.604 .04717 Mdot
.604 .04726 Mdot
.604 .04726 Mdot
.604 .04736 Mdot
.604 .04751 Mdot
.604 .04754 Mdot
.604 .04758 Mdot
.604 .04813 Mdot
.604 .04821 Mdot
.604 .04828 Mdot
.604 .04873 Mdot
.604 .0489 Mdot
.604 .04902 Mdot
.604 .04915 Mdot
.604 .04915 Mdot
.604 .0492 Mdot
.604 .04927 Mdot
.604 .04965 Mdot
.604 .04974 Mdot
.604 .05079 Mdot
.604 .05107 Mdot
.604 .05111 Mdot
.604 .05147 Mdot
.604 .05176 Mdot
.604 .05176 Mdot
.604 .05208 Mdot
.604 .05221 Mdot
.604 .0523 Mdot
.604 .05244 Mdot
.604 .05257 Mdot
.604 .05278 Mdot
.604 .05278 Mdot
.604 .0528 Mdot
.604 .05296 Mdot
.604 .05309 Mdot
.604 .05333 Mdot
.604 .05338 Mdot
.604 .05347 Mdot
.604 .05358 Mdot
.604 .05359 Mdot
.604 .05362 Mdot
.604 .05392 Mdot
.604 .05403 Mdot
.604 .05404 Mdot
.604 .05415 Mdot
.604 .05431 Mdot
.604 .05433 Mdot
.604 .05437 Mdot
.604 .05442 Mdot
.604 .05508 Mdot
.604 .05518 Mdot
.604 .05526 Mdot
.604 .05581 Mdot
.604 .05601 Mdot
.604 .05615 Mdot
.604 .05625 Mdot
.604 .05631 Mdot
.604 .05631 Mdot
.604 .05638 Mdot
.604 .05646 Mdot
.604 .05692 Mdot
.604 .05703 Mdot
.604 .05765 Mdot
.604 .05829 Mdot
.604 .05863 Mdot
.604 .05863 Mdot
.604 .05868 Mdot
.604 .05875 Mdot
.604 .05912 Mdot
.604 .05916 Mdot
.604 .05919 Mdot
.604 .05946 Mdot
.604 .05947 Mdot
.604 .05984 Mdot
.604 .05985 Mdot
.604 .06001 Mdot
.604 .06012 Mdot
.604 .06012 Mdot
.604 .06028 Mdot
.604 .06045 Mdot
.604 .06064 Mdot
.604 .06069 Mdot
.604 .06069 Mdot
.604 .06072 Mdot
.604 .06091 Mdot
.604 .06107 Mdot
.604 .06137 Mdot
.604 .06142 Mdot
.604 .06154 Mdot
.604 .06167 Mdot
.604 .06168 Mdot
.604 .06171 Mdot
.604 .06208 Mdot
.604 .06221 Mdot
.604 .06221 Mdot
.604 .06236 Mdot
.604 .06255 Mdot
.604 .06257 Mdot
.604 .06262 Mdot
.604 .06268 Mdot
.604 .06347 Mdot
.604 .0636 Mdot
.604 .06369 Mdot
.604 .06435 Mdot
.604 .0646 Mdot
.604 .06477 Mdot
.604 .06489 Mdot
.604 .06496 Mdot
.604 .06496 Mdot
.604 .06504 Mdot
.604 .06508 Mdot
.604 .06515 Mdot
.604 .0657 Mdot
.604 .06583 Mdot
.604 .06611 Mdot
.604 .06658 Mdot
.604 .06735 Mdot
.604 .06777 Mdot
.604 .06777 Mdot
.604 .06782 Mdot
.604 .06791 Mdot
.604 .06835 Mdot
.604 .06839 Mdot
.604 .0684 Mdot
.604 .06845 Mdot
.604 .06877 Mdot
.604 .06877 Mdot
.604 .06923 Mdot
.604 .06924 Mdot
.604 .06943 Mdot
.604 .06956 Mdot
.604 .06956 Mdot
.604 .06976 Mdot
.604 .06996 Mdot
.604 .0702 Mdot
.604 .07026 Mdot
.604 .07026 Mdot
.604 .07029 Mdot
.604 .07052 Mdot
.604 .07072 Mdot
.604 .07107 Mdot
.604 .07114 Mdot
.604 .07127 Mdot
.604 .07142 Mdot
.604 .07143 Mdot
.604 .07144 Mdot
.604 .07148 Mdot
.604 .07193 Mdot
.604 .07209 Mdot
.604 .07209 Mdot
.604 .07215 Mdot
.604 .07227 Mdot
.604 .0725 Mdot
.604 .07253 Mdot
.604 .07259 Mdot
.604 .07265 Mdot
.604 .07361 Mdot
.604 .07377 Mdot
.604 .07388 Mdot
.604 .07468 Mdot
.604 .07497 Mdot
.604 .07518 Mdot
.604 .07533 Mdot
.604 .07541 Mdot
.604 .07542 Mdot
.604 .07551 Mdot
.604 .07556 Mdot
.604 .07563 Mdot
.604 .0763 Mdot
.604 .07646 Mdot
.604 .0768 Mdot
.604 .07726 Mdot
.604 .07737 Mdot
.604 .07815 Mdot
.604 .07828 Mdot
.604 .0783 Mdot
.604 .0788 Mdot
.604 .07881 Mdot
.604 .07887 Mdot
.604 .07897 Mdot
.604 .07951 Mdot
.604 .07955 Mdot
.604 .07957 Mdot
.604 .07962 Mdot
.604 .08001 Mdot
.604 .08002 Mdot
.604 .08057 Mdot
.604 .08058 Mdot
.604 .08082 Mdot
.604 .08097 Mdot
.604 .08097 Mdot
.604 .08121 Mdot
.604 .08145 Mdot
.604 .0816 Mdot
.604 .08162 Mdot
.604 .08174 Mdot
.604 .08181 Mdot
.604 .08181 Mdot
.604 .08185 Mdot
.604 .08204 Mdot
.604 .08212 Mdot
.604 .08236 Mdot
.604 .08272 Mdot
.604 .08279 Mdot
.604 .08287 Mdot
.604 .08304 Mdot
.604 .08321 Mdot
.604 .08323 Mdot
.604 .08324 Mdot
.604 .08329 Mdot
.604 .08383 Mdot
.604 .08402 Mdot
.604 .08403 Mdot
.604 .0841 Mdot
.604 .08424 Mdot
.604 .08452 Mdot
.604 .08456 Mdot
.604 .08462 Mdot
.604 .08471 Mdot
.604 .08586 Mdot
.604 .08605 Mdot
.604 .08618 Mdot
.604 .0863 Mdot
.604 .08656 Mdot
.604 .08668 Mdot
.604 .08702 Mdot
.604 .08715 Mdot
.604 .0875 Mdot
.604 .08776 Mdot
.604 .08794 Mdot
.604 .08803 Mdot
.604 .08804 Mdot
.604 .08816 Mdot
.604 .08821 Mdot
.604 .08831 Mdot
.604 .08912 Mdot
.604 .0893 Mdot
.604 .08972 Mdot
.604 .09027 Mdot
.604 .09041 Mdot
.604 .09134 Mdot
.604 .0915 Mdot
.604 .09153 Mdot
.604 .09213 Mdot
.604 .09214 Mdot
.604 .09221 Mdot
.604 .09234 Mdot
.604 .09299 Mdot
.604 .09304 Mdot
.604 .09306 Mdot
.604 .09312 Mdot
.604 .09359 Mdot
.604 .0936 Mdot
.604 .09426 Mdot
.604 .09428 Mdot
.604 .09457 Mdot
.604 .09475 Mdot
.604 .09475 Mdot
.604 .09504 Mdot
.604 .09534 Mdot
.604 .09551 Mdot
.604 .09554 Mdot
.604 .09568 Mdot
.604 .09577 Mdot
.604 .09577 Mdot
.604 .09582 Mdot
.604 .09604 Mdot
.604 .09615 Mdot
.604 .09644 Mdot
.604 .09687 Mdot
.604 .09695 Mdot
.604 .09705 Mdot
.604 .09725 Mdot
.604 .09746 Mdot
.604 .09748 Mdot
.604 .0975 Mdot
.604 .09756 Mdot
.604 .0982 Mdot
.604 .09844 Mdot
.604 .09845 Mdot
.604 .09853 Mdot
.604 .0987 Mdot
.604 .09904 Mdot
.604 .09908 Mdot
.604 .09916 Mdot
.604 .09926 Mdot
.604 .10066 Mdot
.604 .10089 Mdot
.604 .10105 Mdot
.604 .10119 Mdot
.604 .10151 Mdot
.604 .10165 Mdot
.604 .10206 Mdot
.604 .10222 Mdot
.604 .10264 Mdot
.604 .10295 Mdot
.604 .10317 Mdot
.604 .10329 Mdot
.604 .10329 Mdot
.604 .10344 Mdot
.604 .1035 Mdot
.604 .10361 Mdot
.604 .10459 Mdot
.604 .10482 Mdot
.604 .10532 Mdot
.604 .10599 Mdot
.604 .10615 Mdot
.604 .10728 Mdot
.604 .10747 Mdot
.604 .1075 Mdot
.604 .10823 Mdot
.604 .10824 Mdot
.604 .10833 Mdot
.604 .10848 Mdot
.604 .10927 Mdot
.604 .10933 Mdot
.604 .10936 Mdot
.604 .10943 Mdot
.604 .11 Mdot
.604 .11001 Mdot
.604 .11081 Mdot
.604 .11083 Mdot
.604 .11117 Mdot
.604 .1114 Mdot
.604 .1114 Mdot
.604 .11175 Mdot
.604 .1121 Mdot
.604 .11232 Mdot
.604 .11235 Mdot
.604 .11252 Mdot
.604 .11263 Mdot
.604 .11263 Mdot
.604 .11269 Mdot
.604 .11296 Mdot
.604 .11308 Mdot
.604 .11343 Mdot
.604 .11395 Mdot
.604 .11406 Mdot
.604 .11418 Mdot
.604 .11442 Mdot
.604 .11467 Mdot
.604 .1147 Mdot
.604 .11472 Mdot
.604 .11479 Mdot
.604 .11557 Mdot
.604 .11586 Mdot
.604 .11586 Mdot
.604 .11597 Mdot
.604 .11616 Mdot
.604 .11658 Mdot
.604 .11663 Mdot
.604 .11673 Mdot
.604 .11685 Mdot
.604 .11854 Mdot
.604 .11881 Mdot
.604 .11901 Mdot
.604 .11918 Mdot
.604 .11956 Mdot
.604 .11974 Mdot
.604 .12023 Mdot
.604 .12042 Mdot
.604 .12093 Mdot
.604 .12131 Mdot
.604 .12157 Mdot
.604 .12171 Mdot
.604 .12172 Mdot
.604 .12189 Mdot
.604 .12196 Mdot
.604 .1221 Mdot
.604 .12328 Mdot
.604 .12356 Mdot
.604 .12417 Mdot
.604 .12497 Mdot
.604 .12517 Mdot
.604 .12653 Mdot
.604 .12677 Mdot
.604 .1268 Mdot
.604 .12769 Mdot
.604 .12769 Mdot
.604 .1278 Mdot
.604 .12798 Mdot
.604 .12894 Mdot
.604 .12901 Mdot
.604 .12904 Mdot
.604 .12913 Mdot
.604 .12982 Mdot
.604 .12983 Mdot
.604 .1308 Mdot
.604 .13083 Mdot
.604 .13124 Mdot
.604 .13151 Mdot
.604 .13151 Mdot
.604 .13193 Mdot
.604 .13236 Mdot
.604 .13262 Mdot
.604 .13266 Mdot
.604 .13286 Mdot
.604 .13299 Mdot
.604 .13299 Mdot
.604 .13306 Mdot
.604 .1334 Mdot
.604 .13354 Mdot
.604 .13397 Mdot
.604 .13459 Mdot
.604 .13472 Mdot
.604 .13486 Mdot
.604 .13515 Mdot
.604 .13546 Mdot
.604 .1355 Mdot
.604 .13552 Mdot
.604 .1356 Mdot
.604 .13655 Mdot
.604 .13689 Mdot
.604 .1369 Mdot
.604 .13703 Mdot
.604 .13727 Mdot
.604 .13777 Mdot
.604 .13783 Mdot
.604 .13795 Mdot
.604 .13809 Mdot
.604 .14013 Mdot
.604 .14046 Mdot
.604 .1407 Mdot
.604 .1409 Mdot
.604 .14137 Mdot
.604 .14158 Mdot
.604 .14218 Mdot
.604 .1424 Mdot
.604 .14303 Mdot
.604 .14348 Mdot
.604 .14379 Mdot
.604 .14396 Mdot
.604 .14397 Mdot
.604 .14418 Mdot
.604 .14427 Mdot
.604 .14444 Mdot
.604 .14587 Mdot
.604 .1462 Mdot
.604 .14693 Mdot
.604 .14791 Mdot
.604 .14814 Mdot
.604 .14979 Mdot
.604 .15007 Mdot
.604 .15012 Mdot
.604 .15118 Mdot
.604 .15119 Mdot
.604 .15133 Mdot
.604 .15154 Mdot
.604 .1527 Mdot
.604 .15278 Mdot
.604 .15282 Mdot
.604 .15293 Mdot
.604 .15376 Mdot
.604 .15378 Mdot
.604 .15494 Mdot
.604 .15498 Mdot
.604 .15547 Mdot
.604 .1558 Mdot
.604 .15581 Mdot
.604 .15631 Mdot
.604 .15683 Mdot
.604 .15715 Mdot
.604 .1572 Mdot
.604 .15744 Mdot
.604 .15759 Mdot
.604 .15759 Mdot
.604 .15768 Mdot
.604 .15808 Mdot
.604 .15826 Mdot
.604 .15877 Mdot
.604 .15953 Mdot
.604 .15968 Mdot
.604 .15985 Mdot
.604 .16021 Mdot
.604 .16057 Mdot
.604 .16062 Mdot
.604 .16064 Mdot
.604 .16075 Mdot
.604 .16189 Mdot
.604 .16231 Mdot
.604 .16231 Mdot
.604 .16247 Mdot
.604 .16276 Mdot
.604 .16336 Mdot
.604 .16344 Mdot
.604 .16358 Mdot
.604 .16376 Mdot
.604 .16622 Mdot
.604 .16662 Mdot
.604 .1669 Mdot
.604 .16715 Mdot
.604 .16772 Mdot
.604 .16797 Mdot
.604 .16869 Mdot
.604 .16896 Mdot
.604 .16972 Mdot
.604 .17026 Mdot
.604 .17064 Mdot
.604 .17085 Mdot
.604 .17086 Mdot
.604 .17111 Mdot
.604 .17122 Mdot
.604 .17142 Mdot
.604 .17315 Mdot
.604 .17355 Mdot
.604 .17443 Mdot
.604 .17561 Mdot
.604 .1759 Mdot
.604 .17788 Mdot
.604 .17823 Mdot
.604 .17828 Mdot
.604 .17957 Mdot
.604 .17958 Mdot
.604 .17974 Mdot
.604 .18 Mdot
.604 .1814 Mdot
.604 .1815 Mdot
.604 .18155 Mdot
.604 .18168 Mdot
.604 .18268 Mdot
.604 .1827 Mdot
.604 .18411 Mdot
.604 .18415 Mdot
.604 .18475 Mdot
.604 .18515 Mdot
.604 .18515 Mdot
.604 .18576 Mdot
.604 .18639 Mdot
.604 .18677 Mdot
.604 .18683 Mdot
.604 .18712 Mdot
.604 .18731 Mdot
.604 .18731 Mdot
.604 .18742 Mdot
.604 .1879 Mdot
.604 .18812 Mdot
.604 .18874 Mdot
.604 .18965 Mdot
.604 .18984 Mdot
.604 .19004 Mdot
.604 .19047 Mdot
.604 .19091 Mdot
.604 .19097 Mdot
.604 .191 Mdot
.604 .19112 Mdot
.604 .1925 Mdot
.604 .193 Mdot
.604 .19301 Mdot
.604 .1932 Mdot
.604 .19355 Mdot
.604 .19428 Mdot
.604 .19437 Mdot
.604 .19455 Mdot
.604 .19476 Mdot
.604 .19773 Mdot
.604 .19821 Mdot
.604 .19856 Mdot
.604 .19886 Mdot
.604 .19954 Mdot
.604 .19985 Mdot
.604 .20072 Mdot
.604 .20105 Mdot
.604 .20196 Mdot
.604 .20261 Mdot
.604 .20307 Mdot
.604 .20332 Mdot
.604 .20334 Mdot
.604 .20364 Mdot
.604 .20377 Mdot
.604 .20402 Mdot
.604 .2061 Mdot
.604 .20659 Mdot
.604 .20765 Mdot
.604 .20908 Mdot
.604 .20942 Mdot
.604 .21182 Mdot
.604 .21224 Mdot
.604 .2123 Mdot
.604 .21386 Mdot
.604 .21387 Mdot
.604 .21407 Mdot
.604 .21439 Mdot
.604 .21607 Mdot
.604 .21619 Mdot
.604 .21625 Mdot
.604 .21641 Mdot
.604 .21762 Mdot
.604 .21764 Mdot
.604 .21935 Mdot
.604 .21939 Mdot
.604 .22012 Mdot
.604 .2206 Mdot
.604 .2206 Mdot
.604 .22134 Mdot
.604 .2221 Mdot
.604 .22256 Mdot
.604 .22263 Mdot
.604 .22299 Mdot
.604 .22321 Mdot
.604 .22321 Mdot
.604 .22334 Mdot
.604 .22392 Mdot
.604 .22418 Mdot
.604 .22493 Mdot
.604 .22604 Mdot
.604 .22626 Mdot
.604 .22651 Mdot
.604 .22702 Mdot
.604 .22756 Mdot
.604 .22763 Mdot
.604 .22766 Mdot
.604 .22781 Mdot
.604 .22948 Mdot
.604 .23009 Mdot
.604 .2301 Mdot
.604 .23033 Mdot
.604 .23075 Mdot
.604 .23163 Mdot
.604 .23174 Mdot
.604 .23195 Mdot
.604 .2322 Mdot
.604 .2358 Mdot
.604 .23638 Mdot
.604 .2368 Mdot
.604 .23716 Mdot
.604 .23798 Mdot
.604 .23835 Mdot
.604 .23941 Mdot
.604 .2398 Mdot
.604 .2409 Mdot
.604 .2417 Mdot
.604 .24225 Mdot
.604 .24255 Mdot
.604 .24257 Mdot
.604 .24294 Mdot
.604 .2431 Mdot
.604 .24339 Mdot
.604 .24591 Mdot
.604 .2465 Mdot
.604 .24779 Mdot
.604 .2495 Mdot
.604 .24992 Mdot
.604 .25282 Mdot
.604 .25332 Mdot
.604 .2534 Mdot
.604 .25528 Mdot
.604 .2553 Mdot
.604 .25553 Mdot
.604 .25592 Mdot
.604 .25795 Mdot
.604 .2581 Mdot
.604 .25817 Mdot
.604 .25836 Mdot
.604 .25982 Mdot
.604 .25985 Mdot
.604 .26191 Mdot
.604 .26197 Mdot
.604 .26285 Mdot
.604 .26343 Mdot
.604 .26343 Mdot
.604 .26432 Mdot
.604 .26524 Mdot
.604 .26579 Mdot
.604 .26588 Mdot
.604 .26631 Mdot
.604 .26658 Mdot
.604 .26658 Mdot
.604 .26673 Mdot
.604 .26744 Mdot
.604 .26775 Mdot
.604 .26866 Mdot
.604 .26999 Mdot
.604 .27026 Mdot
.604 .27056 Mdot
.604 .27118 Mdot
.604 .27183 Mdot
.604 .27191 Mdot
.604 .27196 Mdot
.604 .27214 Mdot
.604 .27415 Mdot
.604 .27489 Mdot
.604 .2749 Mdot
.604 .27517 Mdot
.604 .27568 Mdot
.604 .27675 Mdot
.604 .27688 Mdot
.604 .27713 Mdot
.604 .27744 Mdot
.604 .28179 Mdot
.604 .28248 Mdot
.604 .28299 Mdot
.604 .28343 Mdot
.604 .28442 Mdot
.604 .28487 Mdot
.604 .28614 Mdot
.604 .28662 Mdot
.604 .28795 Mdot
.604 .28891 Mdot
.604 .28958 Mdot
.604 .28994 Mdot
.604 .28996 Mdot
.604 .29041 Mdot
.604 .2906 Mdot
.604 .29096 Mdot
.604 .294 Mdot
.604 .29471 Mdot
.604 .29626 Mdot
.604 .29834 Mdot
.604 .29885 Mdot
.604 .30235 Mdot
.604 .30295 Mdot
.604 .30304 Mdot
.604 .30532 Mdot
.604 .30534 Mdot
.604 .30562 Mdot
.604 .30609 Mdot
.604 .30854 Mdot
.604 .30872 Mdot
.604 .3088 Mdot
.604 .30904 Mdot
.604 .3108 Mdot
.604 .31084 Mdot
.604 .31333 Mdot
.604 .3134 Mdot
.604 .31446 Mdot
.604 .31516 Mdot
.604 .31516 Mdot
.604 .31624 Mdot
.604 .31734 Mdot
.604 .31802 Mdot
.604 .31812 Mdot
.604 .31864 Mdot
.604 .31897 Mdot
.604 .31897 Mdot
.604 .31915 Mdot
.604 .32001 Mdot
.604 .32039 Mdot
.604 .32148 Mdot
.604 .32309 Mdot
.604 .32342 Mdot
.604 .32378 Mdot
.604 .32453 Mdot
.604 .32531 Mdot
.604 .32541 Mdot
.604 .32546 Mdot
.604 .32568 Mdot
.604 .32811 Mdot
.604 .329 Mdot
.604 .32902 Mdot
.604 .32935 Mdot
.604 .32996 Mdot
.604 .33125 Mdot
.604 .33141 Mdot
.604 .33172 Mdot
.604 .33209 Mdot
.604 .33734 Mdot
.604 .33818 Mdot
.604 .33879 Mdot
.604 .33932 Mdot
.604 .34052 Mdot
.604 .34106 Mdot
.604 .3426 Mdot
.604 .34318 Mdot
.604 .34478 Mdot
.604 .34594 Mdot
.604 .34675 Mdot
.604 .34719 Mdot
.604 .34722 Mdot
.604 .34775 Mdot
.604 .34798 Mdot
.604 .34842 Mdot
.604 .35209 Mdot
.604 .35294 Mdot
.604 .35483 Mdot
.604 .35733 Mdot
.604 .35794 Mdot
.604 .36217 Mdot
.604 .36291 Mdot
.604 .36302 Mdot
.604 .36577 Mdot
.604 .36578 Mdot
.604 .36613 Mdot
.604 .36669 Mdot
.604 .36965 Mdot
.604 .36987 Mdot
.604 .36997 Mdot
.604 .37025 Mdot
.606 .01521 Mdot
.606 .01532 Mdot
.606 .01545 Mdot
.606 .0156 Mdot
.606 .01568 Mdot
.606 .01579 Mdot
.606 .01589 Mdot
.606 .01602 Mdot
.606 .01614 Mdot
.606 .01629 Mdot
.606 .01644 Mdot
.606 .01663 Mdot
.606 .01681 Mdot
.606 .01703 Mdot
.606 .01725 Mdot
.606 .01752 Mdot
.606 .01779 Mdot
.606 .01812 Mdot
.606 .01844 Mdot
.606 .01844 Mdot
.606 .01877 Mdot
.606 .01884 Mdot
.606 .01923 Mdot
.606 .01923 Mdot
.606 .01963 Mdot
.606 .01972 Mdot
.606 .02019 Mdot
.606 .02019 Mdot
.606 .02026 Mdot
.606 .02033 Mdot
.606 .02054 Mdot
.606 .02067 Mdot
.606 .02078 Mdot
.606 .02135 Mdot
.606 .02135 Mdot
.606 .02144 Mdot
.606 .02147 Mdot
.606 .02152 Mdot
.606 .02178 Mdot
.606 .02194 Mdot
.606 .02206 Mdot
.606 .02275 Mdot
.606 .02276 Mdot
.606 .02286 Mdot
.606 .0229 Mdot
.606 .02296 Mdot
.606 .02327 Mdot
.606 .02347 Mdot
.606 .02362 Mdot
.606 .02411 Mdot
.606 .02446 Mdot
.606 .02446 Mdot
.606 .02459 Mdot
.606 .0246 Mdot
.606 .02464 Mdot
.606 .02471 Mdot
.606 .02509 Mdot
.606 .02532 Mdot
.606 .02546 Mdot
.606 .02548 Mdot
.606 .02551 Mdot
.606 .0261 Mdot
.606 .02652 Mdot
.606 .02669 Mdot
.606 .0267 Mdot
.606 .02674 Mdot
.606 .02683 Mdot
.606 .02729 Mdot
.606 .02742 Mdot
.606 .02757 Mdot
.606 .02774 Mdot
.606 .02776 Mdot
.606 .0278 Mdot
.606 .028 Mdot
.606 .02851 Mdot
.606 .02902 Mdot
.606 .02904 Mdot
.606 .02922 Mdot
.606 .02924 Mdot
.606 .02929 Mdot
.606 .02939 Mdot
.606 .02978 Mdot
.606 .02995 Mdot
.606 .03012 Mdot
.606 .0303 Mdot
.606 .0305 Mdot
.606 .03052 Mdot
.606 .03057 Mdot
.606 .03082 Mdot
.606 .03143 Mdot
.606 .03206 Mdot
.606 .03208 Mdot
.606 .03229 Mdot
.606 .0323 Mdot
.606 .03232 Mdot
.606 .03238 Mdot
.606 .03251 Mdot
.606 .03284 Mdot
.606 .03298 Mdot
.606 .03318 Mdot
.606 .03332 Mdot
.606 .03338 Mdot
.606 .0336 Mdot
.606 .03384 Mdot
.606 .03386 Mdot
.606 .03387 Mdot
.606 .03393 Mdot
.606 .03423 Mdot
.606 .03498 Mdot
.606 .03573 Mdot
.606 .03576 Mdot
.606 .03601 Mdot
.606 .03603 Mdot
.606 .03605 Mdot
.606 .03613 Mdot
.606 .03628 Mdot
.606 .03668 Mdot
.606 .03685 Mdot
.606 .0371 Mdot
.606 .03723 Mdot
.606 .03727 Mdot
.606 .03732 Mdot
.606 .03734 Mdot
.606 .03757 Mdot
.606 .03761 Mdot
.606 .03773 Mdot
.606 .0379 Mdot
.606 .0379 Mdot
.606 .03792 Mdot
.606 .03792 Mdot
.606 .03793 Mdot
.606 .038 Mdot
.606 .03837 Mdot
.606 .03927 Mdot
.606 .03937 Mdot
.606 .0399 Mdot
.606 .04019 Mdot
.606 .04023 Mdot
.606 .04053 Mdot
.606 .04055 Mdot
.606 .04057 Mdot
.606 .04067 Mdot
.606 .04085 Mdot
.606 .04133 Mdot
.606 .04154 Mdot
.606 .04154 Mdot
.606 .04172 Mdot
.606 .04184 Mdot
.606 .04201 Mdot
.606 .04204 Mdot
.606 .04205 Mdot
.606 .04212 Mdot
.606 .04213 Mdot
.606 .04242 Mdot
.606 .04246 Mdot
.606 .04261 Mdot
.606 .04281 Mdot
.606 .04282 Mdot
.606 .04284 Mdot
.606 .04284 Mdot
.606 .04286 Mdot
.606 .04294 Mdot
.606 .04338 Mdot
.606 .04419 Mdot
.606 .04445 Mdot
.606 .04448 Mdot
.606 .0446 Mdot
.606 .04524 Mdot
.606 .04559 Mdot
.606 .04563 Mdot
.606 .04599 Mdot
.606 .046 Mdot
.606 .04602 Mdot
.606 .04605 Mdot
.606 .04617 Mdot
.606 .04639 Mdot
.606 .04698 Mdot
.606 .04716 Mdot
.606 .04723 Mdot
.606 .04723 Mdot
.606 .04745 Mdot
.606 .04759 Mdot
.606 .04779 Mdot
.606 .04784 Mdot
.606 .04784 Mdot
.606 .04793 Mdot
.606 .04794 Mdot
.606 .04829 Mdot
.606 .04834 Mdot
.606 .04852 Mdot
.606 .04877 Mdot
.606 .04877 Mdot
.606 .0488 Mdot
.606 .04881 Mdot
.606 .04882 Mdot
.606 .04892 Mdot
.606 .0492 Mdot
.606 .04946 Mdot
.606 .05043 Mdot
.606 .05076 Mdot
.606 .05079 Mdot
.606 .05094 Mdot
.606 .05146 Mdot
.606 .05171 Mdot
.606 .05213 Mdot
.606 .05219 Mdot
.606 .05224 Mdot
.606 .05229 Mdot
.606 .05263 Mdot
.606 .05263 Mdot
.606 .05266 Mdot
.606 .05269 Mdot
.606 .05284 Mdot
.606 .0531 Mdot
.606 .05382 Mdot
.606 .05404 Mdot
.606 .05412 Mdot
.606 .05412 Mdot
.606 .05433 Mdot
.606 .05433 Mdot
.606 .05434 Mdot
.606 .05439 Mdot
.606 .05447 Mdot
.606 .05457 Mdot
.606 .05481 Mdot
.606 .05486 Mdot
.606 .05487 Mdot
.606 .05496 Mdot
.606 .05497 Mdot
.606 .05499 Mdot
.606 .05541 Mdot
.606 .05547 Mdot
.606 .05568 Mdot
.606 .05574 Mdot
.606 .05599 Mdot
.606 .05599 Mdot
.606 .05603 Mdot
.606 .05603 Mdot
.606 .05605 Mdot
.606 .05618 Mdot
.606 .05651 Mdot
.606 .05672 Mdot
.606 .05682 Mdot
.606 .05801 Mdot
.606 .0584 Mdot
.606 .05844 Mdot
.606 .05862 Mdot
.606 .05914 Mdot
.606 .05924 Mdot
.606 .05955 Mdot
.606 .05967 Mdot
.606 .05976 Mdot
.606 .06007 Mdot
.606 .06013 Mdot
.606 .06019 Mdot
.606 .06026 Mdot
.606 .06066 Mdot
.606 .06067 Mdot
.606 .0607 Mdot
.606 .06072 Mdot
.606 .06074 Mdot
.606 .06075 Mdot
.606 .06092 Mdot
.606 .06098 Mdot
.606 .06124 Mdot
.606 .06211 Mdot
.606 .06238 Mdot
.606 .06247 Mdot
.606 .06248 Mdot
.606 .06273 Mdot
.606 .06273 Mdot
.606 .06274 Mdot
.606 .0628 Mdot
.606 .06289 Mdot
.606 .06301 Mdot
.606 .06331 Mdot
.606 .06337 Mdot
.606 .06338 Mdot
.606 .0635 Mdot
.606 .0635 Mdot
.606 .06353 Mdot
.606 .06404 Mdot
.606 .06411 Mdot
.606 .06437 Mdot
.606 .06443 Mdot
.606 .06474 Mdot
.606 .06474 Mdot
.606 .06479 Mdot
.606 .06479 Mdot
.606 .06482 Mdot
.606 .06497 Mdot
.606 .06521 Mdot
.606 .06537 Mdot
.606 .06563 Mdot
.606 .06575 Mdot
.606 .06584 Mdot
.606 .06718 Mdot
.606 .06766 Mdot
.606 .0677 Mdot
.606 .06792 Mdot
.606 .06793 Mdot
.606 .06796 Mdot
.606 .06848 Mdot
.606 .06856 Mdot
.606 .06868 Mdot
.606 .06897 Mdot
.606 .06905 Mdot
.606 .06921 Mdot
.606 .06931 Mdot
.606 .06968 Mdot
.606 .06976 Mdot
.606 .06983 Mdot
.606 .06991 Mdot
.606 .0704 Mdot
.606 .07042 Mdot
.606 .07045 Mdot
.606 .07048 Mdot
.606 .0705 Mdot
.606 .0705 Mdot
.606 .07072 Mdot
.606 .07079 Mdot
.606 .07103 Mdot
.606 .07106 Mdot
.606 .07111 Mdot
.606 .07142 Mdot
.606 .07146 Mdot
.606 .07168 Mdot
.606 .07215 Mdot
.606 .07248 Mdot
.606 .0726 Mdot
.606 .07261 Mdot
.606 .0729 Mdot
.606 .0729 Mdot
.606 .0729 Mdot
.606 .07292 Mdot
.606 .073 Mdot
.606 .07311 Mdot
.606 .07325 Mdot
.606 .07361 Mdot
.606 .07368 Mdot
.606 .0737 Mdot
.606 .07384 Mdot
.606 .07384 Mdot
.606 .07388 Mdot
.606 .07449 Mdot
.606 .07459 Mdot
.606 .07489 Mdot
.606 .0749 Mdot
.606 .07497 Mdot
.606 .07535 Mdot
.606 .07535 Mdot
.606 .0754 Mdot
.606 .07541 Mdot
.606 .07544 Mdot
.606 .07562 Mdot
.606 .07591 Mdot
.606 .07611 Mdot
.606 .07625 Mdot
.606 .07642 Mdot
.606 .07657 Mdot
.606 .07667 Mdot
.606 .07724 Mdot
.606 .07831 Mdot
.606 .07839 Mdot
.606 .07888 Mdot
.606 .07894 Mdot
.606 .0792 Mdot
.606 .07921 Mdot
.606 .07925 Mdot
.606 .07942 Mdot
.606 .07988 Mdot
.606 .07997 Mdot
.606 .08012 Mdot
.606 .08013 Mdot
.606 .08047 Mdot
.606 .08057 Mdot
.606 .08076 Mdot
.606 .08089 Mdot
.606 .08133 Mdot
.606 .08143 Mdot
.606 .08152 Mdot
.606 .08161 Mdot
.606 .08221 Mdot
.606 .08223 Mdot
.606 .08227 Mdot
.606 .0823 Mdot
.606 .08233 Mdot
.606 .08233 Mdot
.606 .08259 Mdot
.606 .08268 Mdot
.606 .08297 Mdot
.606 .08301 Mdot
.606 .08306 Mdot
.606 .08344 Mdot
.606 .08349 Mdot
.606 .08376 Mdot
.606 .08397 Mdot
.606 .08433 Mdot
.606 .08473 Mdot
.606 .08487 Mdot
.606 .08488 Mdot
.606 .08524 Mdot
.606 .08524 Mdot
.606 .08524 Mdot
.606 .08526 Mdot
.606 .08535 Mdot
.606 .08549 Mdot
.606 .08566 Mdot
.606 .08609 Mdot
.606 .08619 Mdot
.606 .0862 Mdot
.606 .08637 Mdot
.606 .08638 Mdot
.606 .08642 Mdot
.606 .08717 Mdot
.606 .08728 Mdot
.606 .08765 Mdot
.606 .08766 Mdot
.606 .08775 Mdot
.606 .08783 Mdot
.606 .0882 Mdot
.606 .0882 Mdot
.606 .08827 Mdot
.606 .08827 Mdot
.606 .08831 Mdot
.606 .08853 Mdot
.606 .08888 Mdot
.606 .08912 Mdot
.606 .0893 Mdot
.606 .0895 Mdot
.606 .08968 Mdot
.606 .08981 Mdot
.606 .09049 Mdot
.606 .09179 Mdot
.606 .09189 Mdot
.606 .09248 Mdot
.606 .09255 Mdot
.606 .09287 Mdot
.606 .09289 Mdot
.606 .09293 Mdot
.606 .09313 Mdot
.606 .0937 Mdot
.606 .09381 Mdot
.606 .09399 Mdot
.606 .09399 Mdot
.606 .09441 Mdot
.606 .09454 Mdot
.606 .09476 Mdot
.606 .09492 Mdot
.606 .09546 Mdot
.606 .09557 Mdot
.606 .09568 Mdot
.606 .09579 Mdot
.606 .09652 Mdot
.606 .09654 Mdot
.606 .09659 Mdot
.606 .09662 Mdot
.606 .09666 Mdot
.606 .09667 Mdot
.606 .09698 Mdot
.606 .09709 Mdot
.606 .09744 Mdot
.606 .09748 Mdot
.606 .09755 Mdot
.606 .09801 Mdot
.606 .09807 Mdot
.606 .0984 Mdot
.606 .09865 Mdot
.606 .09909 Mdot
.606 .09957 Mdot
.606 .09974 Mdot
.606 .09975 Mdot
.606 .10019 Mdot
.606 .10019 Mdot
.606 .10019 Mdot
.606 .10022 Mdot
.606 .10033 Mdot
.606 .10049 Mdot
.606 .1007 Mdot
.606 .10122 Mdot
.606 .10134 Mdot
.606 .10136 Mdot
.606 .10156 Mdot
.606 .10157 Mdot
.606 .10162 Mdot
.606 .10253 Mdot
.606 .10266 Mdot
.606 .10311 Mdot
.606 .10312 Mdot
.606 .10323 Mdot
.606 .10333 Mdot
.606 .10378 Mdot
.606 .10378 Mdot
.606 .10386 Mdot
.606 .10387 Mdot
.606 .10392 Mdot
.606 .10418 Mdot
.606 .10461 Mdot
.606 .1049 Mdot
.606 .10511 Mdot
.606 .10536 Mdot
.606 .10558 Mdot
.606 .10573 Mdot
.606 .10656 Mdot
.606 .10813 Mdot
.606 .10825 Mdot
.606 .10897 Mdot
.606 .10906 Mdot
.606 .10944 Mdot
.606 .10946 Mdot
.606 .10952 Mdot
.606 .10976 Mdot
.606 .11044 Mdot
.606 .11057 Mdot
.606 .1108 Mdot
.606 .1108 Mdot
.606 .11131 Mdot
.606 .11146 Mdot
.606 .11173 Mdot
.606 .11192 Mdot
.606 .11257 Mdot
.606 .11272 Mdot
.606 .11284 Mdot
.606 .11298 Mdot
.606 .11386 Mdot
.606 .11388 Mdot
.606 .11395 Mdot
.606 .11399 Mdot
.606 .11403 Mdot
.606 .11404 Mdot
.606 .11442 Mdot
.606 .11455 Mdot
.606 .11498 Mdot
.606 .11503 Mdot
.606 .11511 Mdot
.606 .11567 Mdot
.606 .11574 Mdot
.606 .11614 Mdot
.606 .11645 Mdot
.606 .11698 Mdot
.606 .11756 Mdot
.606 .11777 Mdot
.606 .11778 Mdot
.606 .11831 Mdot
.606 .11831 Mdot
.606 .11831 Mdot
.606 .11835 Mdot
.606 .11848 Mdot
.606 .11868 Mdot
.606 .11893 Mdot
.606 .11956 Mdot
.606 .1197 Mdot
.606 .11973 Mdot
.606 .11998 Mdot
.606 .11998 Mdot
.606 .12004 Mdot
.606 .12114 Mdot
.606 .12131 Mdot
.606 .12185 Mdot
.606 .12186 Mdot
.606 .122 Mdot
.606 .12212 Mdot
.606 .12266 Mdot
.606 .12267 Mdot
.606 .12276 Mdot
.606 .12277 Mdot
.606 .12283 Mdot
.606 .12315 Mdot
.606 .12366 Mdot
.606 .12402 Mdot
.606 .12427 Mdot
.606 .12457 Mdot
.606 .12484 Mdot
.606 .12503 Mdot
.606 .12603 Mdot
.606 .12793 Mdot
.606 .12808 Mdot
.606 .12895 Mdot
.606 .12906 Mdot
.606 .12953 Mdot
.606 .12955 Mdot
.606 .12961 Mdot
.606 .12991 Mdot
.606 .13074 Mdot
.606 .13089 Mdot
.606 .13117 Mdot
.606 .13117 Mdot
.606 .13178 Mdot
.606 .13197 Mdot
.606 .1323 Mdot
.606 .13253 Mdot
.606 .13332 Mdot
.606 .13349 Mdot
.606 .13365 Mdot
.606 .13382 Mdot
.606 .13488 Mdot
.606 .13491 Mdot
.606 .13499 Mdot
.606 .13504 Mdot
.606 .13509 Mdot
.606 .1351 Mdot
.606 .13555 Mdot
.606 .13572 Mdot
.606 .13624 Mdot
.606 .1363 Mdot
.606 .1364 Mdot
.606 .13707 Mdot
.606 .13716 Mdot
.606 .13764 Mdot
.606 .13801 Mdot
.606 .13865 Mdot
.606 .13937 Mdot
.606 .13961 Mdot
.606 .13963 Mdot
.606 .14027 Mdot
.606 .14027 Mdot
.606 .14028 Mdot
.606 .14032 Mdot
.606 .14047 Mdot
.606 .14072 Mdot
.606 .14103 Mdot
.606 .14179 Mdot
.606 .14196 Mdot
.606 .14199 Mdot
.606 .14229 Mdot
.606 .1423 Mdot
.606 .14237 Mdot
.606 .1437 Mdot
.606 .1439 Mdot
.606 .14456 Mdot
.606 .14457 Mdot
.606 .14474 Mdot
.606 .14489 Mdot
.606 .14554 Mdot
.606 .14555 Mdot
.606 .14567 Mdot
.606 .14568 Mdot
.606 .14575 Mdot
.606 .14613 Mdot
.606 .14676 Mdot
.606 .14719 Mdot
.606 .1475 Mdot
.606 .14786 Mdot
.606 .14819 Mdot
.606 .14841 Mdot
.606 .14962 Mdot
.606 .15193 Mdot
.606 .15211 Mdot
.606 .15317 Mdot
.606 .1533 Mdot
.606 .15387 Mdot
.606 .15389 Mdot
.606 .15397 Mdot
.606 .15433 Mdot
.606 .15533 Mdot
.606 .15552 Mdot
.606 .15585 Mdot
.606 .15586 Mdot
.606 .1566 Mdot
.606 .15682 Mdot
.606 .15722 Mdot
.606 .15751 Mdot
.606 .15846 Mdot
.606 .15867 Mdot
.606 .15886 Mdot
.606 .15907 Mdot
.606 .16035 Mdot
.606 .16039 Mdot
.606 .16048 Mdot
.606 .16054 Mdot
.606 .16061 Mdot
.606 .16062 Mdot
.606 .16117 Mdot
.606 .16137 Mdot
.606 .162 Mdot
.606 .16207 Mdot
.606 .16219 Mdot
.606 .16301 Mdot
.606 .16311 Mdot
.606 .1637 Mdot
.606 .16415 Mdot
.606 .16493 Mdot
.606 .16579 Mdot
.606 .16609 Mdot
.606 .16611 Mdot
.606 .16689 Mdot
.606 .16689 Mdot
.606 .1669 Mdot
.606 .16694 Mdot
.606 .16713 Mdot
.606 .16743 Mdot
.606 .16781 Mdot
.606 .16873 Mdot
.606 .16894 Mdot
.606 .16897 Mdot
.606 .16934 Mdot
.606 .16934 Mdot
.606 .16944 Mdot
.606 .17105 Mdot
.606 .17129 Mdot
.606 .17209 Mdot
.606 .1721 Mdot
.606 .1723 Mdot
.606 .17249 Mdot
.606 .17328 Mdot
.606 .17329 Mdot
.606 .17343 Mdot
.606 .17344 Mdot
.606 .17353 Mdot
.606 .17399 Mdot
.606 .17475 Mdot
.606 .17527 Mdot
.606 .17565 Mdot
.606 .17609 Mdot
.606 .17648 Mdot
.606 .17675 Mdot
.606 .17823 Mdot
.606 .18103 Mdot
.606 .18124 Mdot
.606 .18252 Mdot
.606 .18267 Mdot
.606 .18337 Mdot
.606 .1834 Mdot
.606 .18349 Mdot
.606 .18393 Mdot
.606 .18515 Mdot
.606 .18538 Mdot
.606 .18577 Mdot
.606 .18578 Mdot
.606 .18668 Mdot
.606 .18695 Mdot
.606 .18743 Mdot
.606 .18778 Mdot
.606 .18894 Mdot
.606 .18919 Mdot
.606 .18942 Mdot
.606 .18967 Mdot
.606 .19123 Mdot
.606 .19127 Mdot
.606 .19139 Mdot
.606 .19146 Mdot
.606 .19154 Mdot
.606 .19155 Mdot
.606 .19222 Mdot
.606 .19246 Mdot
.606 .19323 Mdot
.606 .19331 Mdot
.606 .19346 Mdot
.606 .19445 Mdot
.606 .19458 Mdot
.606 .19529 Mdot
.606 .19583 Mdot
.606 .19678 Mdot
.606 .19782 Mdot
.606 .19818 Mdot
.606 .19821 Mdot
.606 .19915 Mdot
.606 .19915 Mdot
.606 .19916 Mdot
.606 .19922 Mdot
.606 .19945 Mdot
.606 .19981 Mdot
.606 .20026 Mdot
.606 .20138 Mdot
.606 .20163 Mdot
.606 .20167 Mdot
.606 .20212 Mdot
.606 .20213 Mdot
.606 .20224 Mdot
.606 .20419 Mdot
.606 .20449 Mdot
.606 .20546 Mdot
.606 .20547 Mdot
.606 .20571 Mdot
.606 .20594 Mdot
.606 .20689 Mdot
.606 .20691 Mdot
.606 .20707 Mdot
.606 .20709 Mdot
.606 .2072 Mdot
.606 .20776 Mdot
.606 .20868 Mdot
.606 .20931 Mdot
.606 .20977 Mdot
.606 .2103 Mdot
.606 .21078 Mdot
.606 .21111 Mdot
.606 .21289 Mdot
.606 .21628 Mdot
.606 .21655 Mdot
.606 .2181 Mdot
.606 .21828 Mdot
.606 .21912 Mdot
.606 .21916 Mdot
.606 .21928 Mdot
.606 .2198 Mdot
.606 .22128 Mdot
.606 .22156 Mdot
.606 .22204 Mdot
.606 .22205 Mdot
.606 .22314 Mdot
.606 .22347 Mdot
.606 .22405 Mdot
.606 .22447 Mdot
.606 .22587 Mdot
.606 .22618 Mdot
.606 .22646 Mdot
.606 .22676 Mdot
.606 .22865 Mdot
.606 .2287 Mdot
.606 .22884 Mdot
.606 .22893 Mdot
.606 .22903 Mdot
.606 .22904 Mdot
.606 .22985 Mdot
.606 .23015 Mdot
.606 .23107 Mdot
.606 .23117 Mdot
.606 .23135 Mdot
.606 .23256 Mdot
.606 .23271 Mdot
.606 .23357 Mdot
.606 .23423 Mdot
.606 .23537 Mdot
.606 .23664 Mdot
.606 .23708 Mdot
.606 .23711 Mdot
.606 .23825 Mdot
.606 .23825 Mdot
.606 .23826 Mdot
.606 .23833 Mdot
.606 .23861 Mdot
.606 .23904 Mdot
.606 .2396 Mdot
.606 .24096 Mdot
.606 .24126 Mdot
.606 .24131 Mdot
.606 .24184 Mdot
.606 .24186 Mdot
.606 .24199 Mdot
.606 .24436 Mdot
.606 .24472 Mdot
.606 .24589 Mdot
.606 .24591 Mdot
.606 .2462 Mdot
.606 .24648 Mdot
.606 .24764 Mdot
.606 .24765 Mdot
.606 .24785 Mdot
.606 .24788 Mdot
.606 .248 Mdot
.606 .24869 Mdot
.606 .2498 Mdot
.606 .25057 Mdot
.606 .25112 Mdot
.606 .25177 Mdot
.606 .25234 Mdot
.606 .25274 Mdot
.606 .2549 Mdot
.606 .25902 Mdot
.606 .25934 Mdot
.606 .26121 Mdot
.606 .26144 Mdot
.606 .26245 Mdot
.606 .2625 Mdot
.606 .26264 Mdot
.606 .26328 Mdot
.606 .26507 Mdot
.606 .26541 Mdot
.606 .26599 Mdot
.606 .266 Mdot
.606 .26733 Mdot
.606 .26772 Mdot
.606 .26843 Mdot
.606 .26893 Mdot
.606 .27064 Mdot
.606 .27101 Mdot
.606 .27134 Mdot
.606 .27171 Mdot
.606 .27401 Mdot
.606 .27407 Mdot
.606 .27424 Mdot
.606 .27434 Mdot
.606 .27446 Mdot
.606 .27447 Mdot
.606 .27546 Mdot
.606 .27582 Mdot
.606 .27694 Mdot
.606 .27706 Mdot
.606 .27728 Mdot
.606 .27874 Mdot
.606 .27892 Mdot
.606 .27997 Mdot
.606 .28077 Mdot
.606 .28215 Mdot
.606 .28369 Mdot
.606 .28422 Mdot
.606 .28426 Mdot
.606 .28564 Mdot
.606 .28564 Mdot
.606 .28565 Mdot
.606 .28574 Mdot
.606 .28608 Mdot
.606 .2866 Mdot
.606 .28727 Mdot
.606 .28892 Mdot
.606 .28928 Mdot
.606 .28934 Mdot
.606 .29 Mdot
.606 .29001 Mdot
.606 .29017 Mdot
.606 .29305 Mdot
.606 .29348 Mdot
.606 .2949 Mdot
.606 .29493 Mdot
.606 .29528 Mdot
.606 .29561 Mdot
.606 .29702 Mdot
.606 .29703 Mdot
.606 .29728 Mdot
.606 .29731 Mdot
.606 .29746 Mdot
.606 .29829 Mdot
.606 .29964 Mdot
.606 .30057 Mdot
.606 .30124 Mdot
.606 .30202 Mdot
.606 .30272 Mdot
.606 .3032 Mdot
.606 .30582 Mdot
.606 .31081 Mdot
.606 .3112 Mdot
.606 .31347 Mdot
.606 .31374 Mdot
.606 .31497 Mdot
.606 .31503 Mdot
.606 .3152 Mdot
.606 .31597 Mdot
.606 .31814 Mdot
.606 .31855 Mdot
.606 .31926 Mdot
.606 .31927 Mdot
.606 .32088 Mdot
.606 .32136 Mdot
.606 .32222 Mdot
.606 .32283 Mdot
.606 .3249 Mdot
.606 .32535 Mdot
.606 .32575 Mdot
.606 .32619 Mdot
.606 .32898 Mdot
.606 .32905 Mdot
.606 .32926 Mdot
.606 .32938 Mdot
.606 .32952 Mdot
.606 .32954 Mdot
.606 .33074 Mdot
.606 .33117 Mdot
.606 .33253 Mdot
.606 .33268 Mdot
.606 .33294 Mdot
.606 .33471 Mdot
.606 .33493 Mdot
.606 .3362 Mdot
.606 .33717 Mdot
.606 .33885 Mdot
.606 .34071 Mdot
.606 .34135 Mdot
.606 .3414 Mdot
.606 .34308 Mdot
.606 .34308 Mdot
.606 .34309 Mdot
.606 .3432 Mdot
.606 .3436 Mdot
.606 .34424 Mdot
.606 .34506 Mdot
.606 .34705 Mdot
.606 .34749 Mdot
.606 .34757 Mdot
.606 .34836 Mdot
.606 .34837 Mdot
.606 .34857 Mdot
.606 .35206 Mdot
.606 .35258 Mdot
.606 .3543 Mdot
.606 .35433 Mdot
.606 .35476 Mdot
.606 .35516 Mdot
.606 .35686 Mdot
.606 .35689 Mdot
.606 .35718 Mdot
.606 .35721 Mdot
.606 .3574 Mdot
.606 .35841 Mdot
.606 .36005 Mdot
.606 .36117 Mdot
.606 .36198 Mdot
.606 .36293 Mdot
.606 .36378 Mdot
.606 .36436 Mdot
.606 .36754 Mdot
.608 .01562 Mdot
.608 .01581 Mdot
.608 .01605 Mdot
.608 .01634 Mdot
.608 .01643 Mdot
.608 .01669 Mdot
.608 .0168 Mdot
.608 .01712 Mdot
.608 .01725 Mdot
.608 .0174 Mdot
.608 .01763 Mdot
.608 .0178 Mdot
.608 .01797 Mdot
.608 .01826 Mdot
.608 .01847 Mdot
.608 .01868 Mdot
.608 .01888 Mdot
.608 .01903 Mdot
.608 .01918 Mdot
.608 .01928 Mdot
.608 .01953 Mdot
.608 .01978 Mdot
.608 .01996 Mdot
.608 .02012 Mdot
.608 .02014 Mdot
.608 .02026 Mdot
.608 .02032 Mdot
.608 .02057 Mdot
.608 .02065 Mdot
.608 .02088 Mdot
.608 .0211 Mdot
.608 .02128 Mdot
.608 .02131 Mdot
.608 .02146 Mdot
.608 .02154 Mdot
.608 .02184 Mdot
.608 .02193 Mdot
.608 .02221 Mdot
.608 .02248 Mdot
.608 .0227 Mdot
.608 .02274 Mdot
.608 .02292 Mdot
.608 .02301 Mdot
.608 .02338 Mdot
.608 .02349 Mdot
.608 .02383 Mdot
.608 .02415 Mdot
.608 .02442 Mdot
.608 .02443 Mdot
.608 .02447 Mdot
.608 .02469 Mdot
.608 .0248 Mdot
.608 .02514 Mdot
.608 .02524 Mdot
.608 .02525 Mdot
.608 .02538 Mdot
.608 .02552 Mdot
.608 .0258 Mdot
.608 .02619 Mdot
.608 .02651 Mdot
.608 .02653 Mdot
.608 .02658 Mdot
.608 .02685 Mdot
.608 .02698 Mdot
.608 .02727 Mdot
.608 .02739 Mdot
.608 .02752 Mdot
.608 .02753 Mdot
.608 .02769 Mdot
.608 .02785 Mdot
.608 .02819 Mdot
.608 .02867 Mdot
.608 .02903 Mdot
.608 .02906 Mdot
.608 .02908 Mdot
.608 .02914 Mdot
.608 .02947 Mdot
.608 .02962 Mdot
.608 .02963 Mdot
.608 .02968 Mdot
.608 .02998 Mdot
.608 .03013 Mdot
.608 .03028 Mdot
.608 .03029 Mdot
.608 .03049 Mdot
.608 .03068 Mdot
.608 .0311 Mdot
.608 .0311 Mdot
.608 .03132 Mdot
.608 .03147 Mdot
.608 .03169 Mdot
.608 .03212 Mdot
.608 .03216 Mdot
.608 .03218 Mdot
.608 .03225 Mdot
.608 .03265 Mdot
.608 .03284 Mdot
.608 .03285 Mdot
.608 .03291 Mdot
.608 .03328 Mdot
.608 .03346 Mdot
.608 .03364 Mdot
.608 .03366 Mdot
.608 .03389 Mdot
.608 .03413 Mdot
.608 .03464 Mdot
.608 .03464 Mdot
.608 .03472 Mdot
.608 .03491 Mdot
.608 .03509 Mdot
.608 .03535 Mdot
.608 .03588 Mdot
.608 .03593 Mdot
.608 .03595 Mdot
.608 .03604 Mdot
.608 .03653 Mdot
.608 .03675 Mdot
.608 .03677 Mdot
.608 .03684 Mdot
.608 .03729 Mdot
.608 .03751 Mdot
.608 .03773 Mdot
.608 .03775 Mdot
.608 .03804 Mdot
.608 .03809 Mdot
.608 .03833 Mdot
.608 .03894 Mdot
.608 .03895 Mdot
.608 .03904 Mdot
.608 .03927 Mdot
.608 .03949 Mdot
.608 .03981 Mdot
.608 .04045 Mdot
.608 .04051 Mdot
.608 .04054 Mdot
.608 .04055 Mdot
.608 .04065 Mdot
.608 .04105 Mdot
.608 .04108 Mdot
.608 .04124 Mdot
.608 .04151 Mdot
.608 .04153 Mdot
.608 .04162 Mdot
.608 .0419 Mdot
.608 .04217 Mdot
.608 .04244 Mdot
.608 .0427 Mdot
.608 .04273 Mdot
.608 .04298 Mdot
.608 .04299 Mdot
.608 .04308 Mdot
.608 .04314 Mdot
.608 .04343 Mdot
.608 .04413 Mdot
.608 .04418 Mdot
.608 .04418 Mdot
.608 .04429 Mdot
.608 .04458 Mdot
.608 .04484 Mdot
.608 .04523 Mdot
.608 .04601 Mdot
.608 .04608 Mdot
.608 .04612 Mdot
.608 .04613 Mdot
.608 .04625 Mdot
.608 .04674 Mdot
.608 .04677 Mdot
.608 .04697 Mdot
.608 .04705 Mdot
.608 .0473 Mdot
.608 .04732 Mdot
.608 .04743 Mdot
.608 .04778 Mdot
.608 .0481 Mdot
.608 .04842 Mdot
.608 .04875 Mdot
.608 .04878 Mdot
.608 .04908 Mdot
.608 .0491 Mdot
.608 .0492 Mdot
.608 .04928 Mdot
.608 .04963 Mdot
.608 .04968 Mdot
.608 .05048 Mdot
.608 .05054 Mdot
.608 .05055 Mdot
.608 .05068 Mdot
.608 .05103 Mdot
.608 .05135 Mdot
.608 .05182 Mdot
.608 .05277 Mdot
.608 .05286 Mdot
.608 .05289 Mdot
.608 .0529 Mdot
.608 .05292 Mdot
.608 .05305 Mdot
.608 .05306 Mdot
.608 .05315 Mdot
.608 .05366 Mdot
.608 .0537 Mdot
.608 .05387 Mdot
.608 .05393 Mdot
.608 .05404 Mdot
.608 .05412 Mdot
.608 .05433 Mdot
.608 .05434 Mdot
.608 .05436 Mdot
.608 .0545 Mdot
.608 .0545 Mdot
.608 .05492 Mdot
.608 .05531 Mdot
.608 .05561 Mdot
.608 .05571 Mdot
.608 .0559 Mdot
.608 .05593 Mdot
.608 .0561 Mdot
.608 .05613 Mdot
.608 .0565 Mdot
.608 .05653 Mdot
.608 .05665 Mdot
.608 .05674 Mdot
.608 .05686 Mdot
.608 .05717 Mdot
.608 .0572 Mdot
.608 .05724 Mdot
.608 .05821 Mdot
.608 .05828 Mdot
.608 .05829 Mdot
.608 .05845 Mdot
.608 .05887 Mdot
.608 .05926 Mdot
.608 .05983 Mdot
.608 .06099 Mdot
.608 .0611 Mdot
.608 .06113 Mdot
.608 .06115 Mdot
.608 .06117 Mdot
.608 .06134 Mdot
.608 .06134 Mdot
.608 .06145 Mdot
.608 .06207 Mdot
.608 .06212 Mdot
.608 .06222 Mdot
.608 .06232 Mdot
.608 .0624 Mdot
.608 .06253 Mdot
.608 .06263 Mdot
.608 .06264 Mdot
.608 .06289 Mdot
.608 .0629 Mdot
.608 .06293 Mdot
.608 .06309 Mdot
.608 .0631 Mdot
.608 .06349 Mdot
.608 .0636 Mdot
.608 .06408 Mdot
.608 .06439 Mdot
.608 .06444 Mdot
.608 .06456 Mdot
.608 .06479 Mdot
.608 .06484 Mdot
.608 .06504 Mdot
.608 .06507 Mdot
.608 .06508 Mdot
.608 .06553 Mdot
.608 .06556 Mdot
.608 .06571 Mdot
.608 .06582 Mdot
.608 .06596 Mdot
.608 .06617 Mdot
.608 .06634 Mdot
.608 .06637 Mdot
.608 .06642 Mdot
.608 .06706 Mdot
.608 .06707 Mdot
.608 .06736 Mdot
.608 .06761 Mdot
.608 .06769 Mdot
.608 .0677 Mdot
.608 .0679 Mdot
.608 .06841 Mdot
.608 .06889 Mdot
.608 .06924 Mdot
.608 .06931 Mdot
.608 .06943 Mdot
.608 .06958 Mdot
.608 .06958 Mdot
.608 .07098 Mdot
.608 .071 Mdot
.608 .07102 Mdot
.608 .07112 Mdot
.608 .07116 Mdot
.608 .07118 Mdot
.608 .07121 Mdot
.608 .07141 Mdot
.608 .07141 Mdot
.608 .07154 Mdot
.608 .0723 Mdot
.608 .07236 Mdot
.608 .07248 Mdot
.608 .07261 Mdot
.608 .0727 Mdot
.608 .07286 Mdot
.608 .07298 Mdot
.608 .07299 Mdot
.608 .07329 Mdot
.608 .0733 Mdot
.608 .07334 Mdot
.608 .07354 Mdot
.608 .07355 Mdot
.608 .07403 Mdot
.608 .07416 Mdot
.608 .07444 Mdot
.608 .07474 Mdot
.608 .07512 Mdot
.608 .07518 Mdot
.608 .07533 Mdot
.608 .07536 Mdot
.608 .07561 Mdot
.608 .07566 Mdot
.608 .07591 Mdot
.608 .07595 Mdot
.608 .07596 Mdot
.608 .07651 Mdot
.608 .07654 Mdot
.608 .07672 Mdot
.608 .07686 Mdot
.608 .07703 Mdot
.608 .07728 Mdot
.608 .07733 Mdot
.608 .0775 Mdot
.608 .07753 Mdot
.608 .07759 Mdot
.608 .07836 Mdot
.608 .07838 Mdot
.608 .07873 Mdot
.608 .07903 Mdot
.608 .07913 Mdot
.608 .07913 Mdot
.608 .07914 Mdot
.608 .07939 Mdot
.608 .07942 Mdot
.608 .07945 Mdot
.608 .08001 Mdot
.608 .08059 Mdot
.608 .08101 Mdot
.608 .0811 Mdot
.608 .0811 Mdot
.608 .08124 Mdot
.608 .08143 Mdot
.608 .08143 Mdot
.608 .08163 Mdot
.608 .08213 Mdot
.608 .08258 Mdot
.608 .08313 Mdot
.608 .08316 Mdot
.608 .08318 Mdot
.608 .0833 Mdot
.608 .08335 Mdot
.608 .08338 Mdot
.608 .08341 Mdot
.608 .0836 Mdot
.608 .08365 Mdot
.608 .08366 Mdot
.608 .08382 Mdot
.608 .08388 Mdot
.608 .08474 Mdot
.608 .08481 Mdot
.608 .08496 Mdot
.608 .08511 Mdot
.608 .08523 Mdot
.608 .08542 Mdot
.608 .08557 Mdot
.608 .08557 Mdot
.608 .08562 Mdot
.608 .08595 Mdot
.608 .08596 Mdot
.608 .08598 Mdot
.608 .08601 Mdot
.608 .08625 Mdot
.608 .08625 Mdot
.608 .08684 Mdot
.608 .087 Mdot
.608 .08734 Mdot
.608 .0877 Mdot
.608 .0877 Mdot
.608 .08799 Mdot
.608 .08808 Mdot
.608 .08816 Mdot
.608 .08824 Mdot
.608 .08842 Mdot
.608 .08846 Mdot
.608 .08877 Mdot
.608 .08883 Mdot
.608 .08912 Mdot
.608 .08917 Mdot
.608 .08919 Mdot
.608 .08985 Mdot
.608 .08989 Mdot
.608 .09012 Mdot
.608 .09029 Mdot
.608 .09049 Mdot
.608 .0908 Mdot
.608 .09086 Mdot
.608 .09106 Mdot
.608 .0911 Mdot
.608 .09117 Mdot
.608 .09196 Mdot
.608 .09211 Mdot
.608 .09213 Mdot
.608 .09219 Mdot
.608 .09255 Mdot
.608 .09292 Mdot
.608 .09304 Mdot
.608 .09305 Mdot
.608 .09306 Mdot
.608 .09336 Mdot
.608 .0934 Mdot
.608 .09343 Mdot
.608 .09411 Mdot
.608 .09482 Mdot
.608 .09533 Mdot
.608 .09544 Mdot
.608 .09544 Mdot
.608 .09561 Mdot
.608 .09584 Mdot
.608 .09584 Mdot
.608 .09608 Mdot
.608 .09669 Mdot
.608 .09724 Mdot
.608 .09791 Mdot
.608 .09795 Mdot
.608 .09797 Mdot
.608 .09812 Mdot
.608 .09817 Mdot
.608 .09821 Mdot
.608 .09825 Mdot
.608 .09848 Mdot
.608 .09854 Mdot
.608 .09855 Mdot
.608 .09874 Mdot
.608 .09881 Mdot
.608 .09986 Mdot
.608 .09995 Mdot
.608 .10013 Mdot
.608 .10032 Mdot
.608 .10046 Mdot
.608 .10069 Mdot
.608 .10088 Mdot
.608 .10088 Mdot
.608 .10094 Mdot
.608 .10133 Mdot
.608 .10135 Mdot
.608 .10137 Mdot
.608 .1014 Mdot
.608 .1017 Mdot
.608 .1017 Mdot
.608 .10242 Mdot
.608 .10261 Mdot
.608 .10303 Mdot
.608 .10346 Mdot
.608 .10347 Mdot
.608 .10381 Mdot
.608 .10392 Mdot
.608 .10403 Mdot
.608 .10412 Mdot
.608 .10434 Mdot
.608 .10439 Mdot
.608 .10476 Mdot
.608 .10483 Mdot
.608 .10519 Mdot
.608 .10525 Mdot
.608 .10527 Mdot
.608 .10609 Mdot
.608 .10613 Mdot
.608 .1064 Mdot
.608 .10661 Mdot
.608 .10685 Mdot
.608 .10723 Mdot
.608 .10731 Mdot
.608 .10755 Mdot
.608 .1076 Mdot
.608 .10768 Mdot
.608 .10864 Mdot
.608 .10883 Mdot
.608 .10885 Mdot
.608 .10892 Mdot
.608 .10937 Mdot
.608 .10981 Mdot
.608 .10996 Mdot
.608 .10998 Mdot
.608 .11034 Mdot
.608 .1104 Mdot
.608 .11044 Mdot
.608 .11126 Mdot
.608 .11212 Mdot
.608 .11275 Mdot
.608 .11287 Mdot
.608 .11288 Mdot
.608 .11309 Mdot
.608 .11336 Mdot
.608 .11337 Mdot
.608 .11366 Mdot
.608 .1144 Mdot
.608 .11507 Mdot
.608 .11588 Mdot
.608 .11593 Mdot
.608 .11595 Mdot
.608 .11613 Mdot
.608 .1162 Mdot
.608 .11625 Mdot
.608 .11629 Mdot
.608 .11658 Mdot
.608 .11665 Mdot
.608 .11666 Mdot
.608 .11689 Mdot
.608 .11698 Mdot
.608 .11826 Mdot
.608 .11836 Mdot
.608 .11858 Mdot
.608 .11881 Mdot
.608 .11898 Mdot
.608 .11926 Mdot
.608 .11949 Mdot
.608 .11949 Mdot
.608 .11956 Mdot
.608 .12004 Mdot
.608 .12006 Mdot
.608 .12009 Mdot
.608 .12013 Mdot
.608 .12049 Mdot
.608 .12049 Mdot
.608 .12137 Mdot
.608 .1216 Mdot
.608 .1221 Mdot
.608 .12263 Mdot
.608 .12264 Mdot
.608 .12306 Mdot
.608 .12319 Mdot
.608 .12332 Mdot
.608 .12344 Mdot
.608 .1237 Mdot
.608 .12377 Mdot
.608 .12421 Mdot
.608 .1243 Mdot
.608 .12474 Mdot
.608 .12481 Mdot
.608 .12483 Mdot
.608 .12582 Mdot
.608 .12588 Mdot
.608 .12621 Mdot
.608 .12646 Mdot
.608 .12676 Mdot
.608 .12722 Mdot
.608 .12731 Mdot
.608 .1276 Mdot
.608 .12766 Mdot
.608 .12776 Mdot
.608 .12893 Mdot
.608 .12915 Mdot
.608 .12918 Mdot
.608 .12927 Mdot
.608 .12981 Mdot
.608 .13036 Mdot
.608 .13054 Mdot
.608 .13056 Mdot
.608 .131 Mdot
.608 .13107 Mdot
.608 .13111 Mdot
.608 .13212 Mdot
.608 .13316 Mdot
.608 .13392 Mdot
.608 .13407 Mdot
.608 .13408 Mdot
.608 .13434 Mdot
.608 .13467 Mdot
.608 .13467 Mdot
.608 .13503 Mdot
.608 .13593 Mdot
.608 .13674 Mdot
.608 .13773 Mdot
.608 .13779 Mdot
.608 .13782 Mdot
.608 .13804 Mdot
.608 .13812 Mdot
.608 .13818 Mdot
.608 .13823 Mdot
.608 .13858 Mdot
.608 .13867 Mdot
.608 .13868 Mdot
.608 .13896 Mdot
.608 .13907 Mdot
.608 .14062 Mdot
.608 .14075 Mdot
.608 .14102 Mdot
.608 .14129 Mdot
.608 .1415 Mdot
.608 .14184 Mdot
.608 .14212 Mdot
.608 .14212 Mdot
.608 .14221 Mdot
.608 .14279 Mdot
.608 .14281 Mdot
.608 .14285 Mdot
.608 .1429 Mdot
.608 .14334 Mdot
.608 .14334 Mdot
.608 .1444 Mdot
.608 .14469 Mdot
.608 .1453 Mdot
.608 .14594 Mdot
.608 .14595 Mdot
.608 .14646 Mdot
.608 .14663 Mdot
.608 .14678 Mdot
.608 .14692 Mdot
.608 .14724 Mdot
.608 .14732 Mdot
.608 .14786 Mdot
.608 .14797 Mdot
.608 .1485 Mdot
.608 .14859 Mdot
.608 .14862 Mdot
.608 .14982 Mdot
.608 .14989 Mdot
.608 .15029 Mdot
.608 .1506 Mdot
.608 .15096 Mdot
.608 .15152 Mdot
.608 .15163 Mdot
.608 .15198 Mdot
.608 .15206 Mdot
.608 .15218 Mdot
.608 .1536 Mdot
.608 .15387 Mdot
.608 .15391 Mdot
.608 .15401 Mdot
.608 .15467 Mdot
.608 .15533 Mdot
.608 .15556 Mdot
.608 .15558 Mdot
.608 .15611 Mdot
.608 .1562 Mdot
.608 .15625 Mdot
.608 .15747 Mdot
.608 .15874 Mdot
.608 .15967 Mdot
.608 .15986 Mdot
.608 .15987 Mdot
.608 .16018 Mdot
.608 .16058 Mdot
.608 .16059 Mdot
.608 .16101 Mdot
.608 .16211 Mdot
.608 .1631 Mdot
.608 .16431 Mdot
.608 .16437 Mdot
.608 .16441 Mdot
.608 .16468 Mdot
.608 .16477 Mdot
.608 .16485 Mdot
.608 .16491 Mdot
.608 .16533 Mdot
.608 .16544 Mdot
.608 .16545 Mdot
.608 .1658 Mdot
.608 .16593 Mdot
.608 .16782 Mdot
.608 .16797 Mdot
.608 .1683 Mdot
.608 .16863 Mdot
.608 .16889 Mdot
.608 .1693 Mdot
.608 .16964 Mdot
.608 .16964 Mdot
.608 .16975 Mdot
.608 .17046 Mdot
.608 .17048 Mdot
.608 .17053 Mdot
.608 .17059 Mdot
.608 .17112 Mdot
.608 .17113 Mdot
.608 .17241 Mdot
.608 .17276 Mdot
.608 .1735 Mdot
.608 .17429 Mdot
.608 .1743 Mdot
.608 .17492 Mdot
.608 .17512 Mdot
.608 .17531 Mdot
.608 .17548 Mdot
.608 .17586 Mdot
.608 .17596 Mdot
.608 .17662 Mdot
.608 .17675 Mdot
.608 .1774 Mdot
.608 .17751 Mdot
.608 .17754 Mdot
.608 .179 Mdot
.608 .17909 Mdot
.608 .17957 Mdot
.608 .17995 Mdot
.608 .18039 Mdot
.608 .18107 Mdot
.608 .1812 Mdot
.608 .18163 Mdot
.608 .18173 Mdot
.608 .18187 Mdot
.608 .1836 Mdot
.608 .18393 Mdot
.608 .18398 Mdot
.608 .1841 Mdot
.608 .1849 Mdot
.608 .18571 Mdot
.608 .18598 Mdot
.608 .18601 Mdot
.608 .18666 Mdot
.608 .18676 Mdot
.608 .18682 Mdot
.608 .18831 Mdot
.608 .18985 Mdot
.608 .19098 Mdot
.608 .19121 Mdot
.608 .19122 Mdot
.608 .1916 Mdot
.608 .19209 Mdot
.608 .19209 Mdot
.608 .19261 Mdot
.608 .19395 Mdot
.608 .19515 Mdot
.608 .19662 Mdot
.608 .1967 Mdot
.608 .19674 Mdot
.608 .19707 Mdot
.608 .19718 Mdot
.608 .19728 Mdot
.608 .19736 Mdot
.608 .19786 Mdot
.608 .198 Mdot
.608 .19801 Mdot
.608 .19844 Mdot
.608 .19859 Mdot
.608 .20089 Mdot
.608 .20108 Mdot
.608 .20147 Mdot
.608 .20188 Mdot
.608 .20219 Mdot
.608 .20269 Mdot
.608 .2031 Mdot
.608 .20311 Mdot
.608 .20324 Mdot
.608 .2041 Mdot
.608 .20413 Mdot
.608 .20418 Mdot
.608 .20425 Mdot
.608 .20491 Mdot
.608 .20491 Mdot
.608 .20648 Mdot
.608 .2069 Mdot
.608 .2078 Mdot
.608 .20876 Mdot
.608 .20877 Mdot
.608 .20952 Mdot
.608 .20976 Mdot
.608 .20999 Mdot
.608 .2102 Mdot
.608 .21067 Mdot
.608 .21079 Mdot
.608 .21159 Mdot
.608 .21175 Mdot
.608 .21254 Mdot
.608 .21267 Mdot
.608 .21271 Mdot
.608 .21449 Mdot
.608 .21459 Mdot
.608 .21518 Mdot
.608 .21564 Mdot
.608 .21617 Mdot
.608 .217 Mdot
.608 .21716 Mdot
.608 .21769 Mdot
.608 .2178 Mdot
.608 .21798 Mdot
.608 .22008 Mdot
.608 .22048 Mdot
.608 .22054 Mdot
.608 .22069 Mdot
.608 .22166 Mdot
.608 .22264 Mdot
.608 .22297 Mdot
.608 .223 Mdot
.608 .22379 Mdot
.608 .22392 Mdot
.608 .224 Mdot
.608 .22581 Mdot
.608 .22768 Mdot
.608 .22905 Mdot
.608 .22933 Mdot
.608 .22934 Mdot
.608 .2298 Mdot
.608 .2304 Mdot
.608 .23041 Mdot
.608 .23104 Mdot
.608 .23267 Mdot
.608 .23413 Mdot
.608 .23591 Mdot
.608 .236 Mdot
.608 .23606 Mdot
.608 .23646 Mdot
.608 .2366 Mdot
.608 .23671 Mdot
.608 .23681 Mdot
.608 .23742 Mdot
.608 .23759 Mdot
.608 .2376 Mdot
.608 .23812 Mdot
.608 .23831 Mdot
.608 .2411 Mdot
.608 .24133 Mdot
.608 .24181 Mdot
.608 .24231 Mdot
.608 .24269 Mdot
.608 .2433 Mdot
.608 .24379 Mdot
.608 .2438 Mdot
.608 .24396 Mdot
.608 .245 Mdot
.608 .24504 Mdot
.608 .24511 Mdot
.608 .2452 Mdot
.608 .24599 Mdot
.608 .24599 Mdot
.608 .2479 Mdot
.608 .24841 Mdot
.608 .24951 Mdot
.608 .25067 Mdot
.608 .25068 Mdot
.608 .2516 Mdot
.608 .2519 Mdot
.608 .25217 Mdot
.608 .25243 Mdot
.608 .25299 Mdot
.608 .25315 Mdot
.608 .25412 Mdot
.608 .25432 Mdot
.608 .25527 Mdot
.608 .25543 Mdot
.608 .25548 Mdot
.608 .25764 Mdot
.608 .25777 Mdot
.608 .25848 Mdot
.608 .25903 Mdot
.608 .25969 Mdot
.608 .26069 Mdot
.608 .26089 Mdot
.608 .26153 Mdot
.608 .26167 Mdot
.608 .26189 Mdot
.608 .26444 Mdot
.608 .26493 Mdot
.608 .26499 Mdot
.608 .26518 Mdot
.608 .26637 Mdot
.608 .26755 Mdot
.608 .26795 Mdot
.608 .26799 Mdot
.608 .26896 Mdot
.608 .26911 Mdot
.608 .26921 Mdot
.608 .2714 Mdot
.608 .27368 Mdot
.608 .27535 Mdot
.608 .27569 Mdot
.608 .2757 Mdot
.608 .27626 Mdot
.608 .27699 Mdot
.608 .277 Mdot
.608 .27777 Mdot
.608 .27974 Mdot
.608 .28152 Mdot
.608 .28369 Mdot
.608 .2838 Mdot
.608 .28386 Mdot
.608 .28435 Mdot
.608 .28452 Mdot
.608 .28467 Mdot
.608 .28478 Mdot
.608 .28553 Mdot
.608 .28573 Mdot
.608 .28575 Mdot
.608 .28637 Mdot
.608 .2866 Mdot
.608 .29 Mdot
.608 .29028 Mdot
.608 .29086 Mdot
.608 .29147 Mdot
.608 .29193 Mdot
.608 .29267 Mdot
.608 .29327 Mdot
.608 .29328 Mdot
.608 .29347 Mdot
.608 .29475 Mdot
.608 .29479 Mdot
.608 .29487 Mdot
.608 .29498 Mdot
.608 .29594 Mdot
.608 .29595 Mdot
.608 .29826 Mdot
.608 .29889 Mdot
.608 .30022 Mdot
.608 .30164 Mdot
.608 .30165 Mdot
.608 .30277 Mdot
.608 .30313 Mdot
.608 .30347 Mdot
.608 .30377 Mdot
.608 .30446 Mdot
.608 .30465 Mdot
.608 .30583 Mdot
.608 .30607 Mdot
.608 .30723 Mdot
.608 .30743 Mdot
.608 .30749 Mdot
.608 .31011 Mdot
.608 .31027 Mdot
.608 .31114 Mdot
.608 .31181 Mdot
.608 .3126 Mdot
.608 .31382 Mdot
.608 .31406 Mdot
.608 .31484 Mdot
.608 .31501 Mdot
.608 .31527 Mdot
.608 .31838 Mdot
.608 .31897 Mdot
.608 .31905 Mdot
.608 .31928 Mdot
.608 .32072 Mdot
.608 .32217 Mdot
.608 .32265 Mdot
.608 .3227 Mdot
.608 .32387 Mdot
.608 .32405 Mdot
.608 .32418 Mdot
.608 .32685 Mdot
.608 .32962 Mdot
.608 .33164 Mdot
.608 .33206 Mdot
.608 .33208 Mdot
.608 .33276 Mdot
.608 .33364 Mdot
.608 .33365 Mdot
.608 .33459 Mdot
.608 .33699 Mdot
.608 .33915 Mdot
.608 .34179 Mdot
.608 .34193 Mdot
.608 .342 Mdot
.608 .34259 Mdot
.608 .3428 Mdot
.608 .34298 Mdot
.608 .34312 Mdot
.608 .34403 Mdot
.608 .34426 Mdot
.608 .34429 Mdot
.608 .34505 Mdot
.608 .34533 Mdot
.608 .34946 Mdot
.608 .3498 Mdot
.608 .35051 Mdot
.608 .35125 Mdot
.608 .35181 Mdot
.608 .35271 Mdot
.608 .35344 Mdot
.608 .35345 Mdot
.608 .35369 Mdot
.608 .35523 Mdot
.608 .35529 Mdot
.608 .35539 Mdot
.608 .35552 Mdot
.608 .35669 Mdot
.608 .3567 Mdot
.608 .35951 Mdot
.608 .36027 Mdot
.608 .36189 Mdot
.608 .36337 Mdot
.608 .36361 Mdot
.608 .36363 Mdot
.608 .36499 Mdot
.608 .36542 Mdot
.608 .36584 Mdot
.608 .36621 Mdot
.608 .36705 Mdot
.608 .36727 Mdot
.608 .36871 Mdot
.608 .369 Mdot
.608 .37042 Mdot
.608 .37065 Mdot
.608 .37073 Mdot
.608 .37392 Mdot
.608 .37411 Mdot
.61 .01658 Mdot
.61 .01699 Mdot
.61 .01703 Mdot
.61 .01749 Mdot
.61 .01754 Mdot
.61 .0181 Mdot
.61 .01816 Mdot
.61 .01852 Mdot
.61 .01882 Mdot
.61 .01884 Mdot
.61 .01892 Mdot
.61 .01936 Mdot
.61 .01951 Mdot
.61 .01973 Mdot
.61 .01975 Mdot
.61 .01984 Mdot
.61 .02038 Mdot
.61 .02054 Mdot
.61 .02057 Mdot
.61 .02083 Mdot
.61 .02085 Mdot
.61 .02097 Mdot
.61 .02147 Mdot
.61 .02163 Mdot
.61 .02182 Mdot
.61 .02185 Mdot
.61 .02197 Mdot
.61 .02218 Mdot
.61 .02221 Mdot
.61 .02235 Mdot
.61 .02296 Mdot
.61 .02315 Mdot
.61 .02339 Mdot
.61 .02342 Mdot
.61 .02356 Mdot
.61 .02382 Mdot
.61 .02385 Mdot
.61 .02392 Mdot
.61 .02402 Mdot
.61 .02415 Mdot
.61 .02443 Mdot
.61 .02477 Mdot
.61 .025 Mdot
.61 .0253 Mdot
.61 .02534 Mdot
.61 .02551 Mdot
.61 .02558 Mdot
.61 .02582 Mdot
.61 .02586 Mdot
.61 .02594 Mdot
.61 .02599 Mdot
.61 .02607 Mdot
.61 .02623 Mdot
.61 .02656 Mdot
.61 .02698 Mdot
.61 .02762 Mdot
.61 .02768 Mdot
.61 .02789 Mdot
.61 .02797 Mdot
.61 .02826 Mdot
.61 .02832 Mdot
.61 .02841 Mdot
.61 .02847 Mdot
.61 .02857 Mdot
.61 .02876 Mdot
.61 .02917 Mdot
.61 .02935 Mdot
.61 .02943 Mdot
.61 .02968 Mdot
.61 .03046 Mdot
.61 .03053 Mdot
.61 .03078 Mdot
.61 .03088 Mdot
.61 .03124 Mdot
.61 .03131 Mdot
.61 .03142 Mdot
.61 .0315 Mdot
.61 .03162 Mdot
.61 .03185 Mdot
.61 .03235 Mdot
.61 .03257 Mdot
.61 .03267 Mdot
.61 .03298 Mdot
.61 .03318 Mdot
.61 .03333 Mdot
.61 .03356 Mdot
.61 .03393 Mdot
.61 .03401 Mdot
.61 .03407 Mdot
.61 .03432 Mdot
.61 .03444 Mdot
.61 .03481 Mdot
.61 .03488 Mdot
.61 .03496 Mdot
.61 .0351 Mdot
.61 .03519 Mdot
.61 .03534 Mdot
.61 .03562 Mdot
.61 .03606 Mdot
.61 .03623 Mdot
.61 .0365 Mdot
.61 .03662 Mdot
.61 .03699 Mdot
.61 .03724 Mdot
.61 .03737 Mdot
.61 .03742 Mdot
.61 .03758 Mdot
.61 .03761 Mdot
.61 .0377 Mdot
.61 .03816 Mdot
.61 .03825 Mdot
.61 .03833 Mdot
.61 .03863 Mdot
.61 .03878 Mdot
.61 .03924 Mdot
.61 .03932 Mdot
.61 .03936 Mdot
.61 .03941 Mdot
.61 .03958 Mdot
.61 .03967 Mdot
.61 .0397 Mdot
.61 .03987 Mdot
.61 .04021 Mdot
.61 .04075 Mdot
.61 .04097 Mdot
.61 .04098 Mdot
.61 .04113 Mdot
.61 .0412 Mdot
.61 .04129 Mdot
.61 .04144 Mdot
.61 .0419 Mdot
.61 .04205 Mdot
.61 .0422 Mdot
.61 .04222 Mdot
.61 .04227 Mdot
.61 .04235 Mdot
.61 .04242 Mdot
.61 .0426 Mdot
.61 .04264 Mdot
.61 .04276 Mdot
.61 .04331 Mdot
.61 .04333 Mdot
.61 .04343 Mdot
.61 .04352 Mdot
.61 .04389 Mdot
.61 .04407 Mdot
.61 .04463 Mdot
.61 .04473 Mdot
.61 .04478 Mdot
.61 .04485 Mdot
.61 .04502 Mdot
.61 .04505 Mdot
.61 .04516 Mdot
.61 .04519 Mdot
.61 .04541 Mdot
.61 .04582 Mdot
.61 .04619 Mdot
.61 .04648 Mdot
.61 .04674 Mdot
.61 .04676 Mdot
.61 .04694 Mdot
.61 .04703 Mdot
.61 .04714 Mdot
.61 .04732 Mdot
.61 .04788 Mdot
.61 .04807 Mdot
.61 .04824 Mdot
.61 .04827 Mdot
.61 .04834 Mdot
.61 .04843 Mdot
.61 .04852 Mdot
.61 .04874 Mdot
.61 .04879 Mdot
.61 .04893 Mdot
.61 .04961 Mdot
.61 .04963 Mdot
.61 .04974 Mdot
.61 .04986 Mdot
.61 .04998 Mdot
.61 .05031 Mdot
.61 .05042 Mdot
.61 .05053 Mdot
.61 .05068 Mdot
.61 .05079 Mdot
.61 .05121 Mdot
.61 .05133 Mdot
.61 .05139 Mdot
.61 .05148 Mdot
.61 .05169 Mdot
.61 .05173 Mdot
.61 .05185 Mdot
.61 .0519 Mdot
.61 .0521 Mdot
.61 .05216 Mdot
.61 .05267 Mdot
.61 .05277 Mdot
.61 .05312 Mdot
.61 .05347 Mdot
.61 .05358 Mdot
.61 .05366 Mdot
.61 .05379 Mdot
.61 .05381 Mdot
.61 .05403 Mdot
.61 .05414 Mdot
.61 .05427 Mdot
.61 .05449 Mdot
.61 .05517 Mdot
.61 .0554 Mdot
.61 .05562 Mdot
.61 .05565 Mdot
.61 .05573 Mdot
.61 .05585 Mdot
.61 .05595 Mdot
.61 .05601 Mdot
.61 .05623 Mdot
.61 .05628 Mdot
.61 .05641 Mdot
.61 .05646 Mdot
.61 .05728 Mdot
.61 .05731 Mdot
.61 .05745 Mdot
.61 .05759 Mdot
.61 .05774 Mdot
.61 .05776 Mdot
.61 .05814 Mdot
.61 .05826 Mdot
.61 .05828 Mdot
.61 .0584 Mdot
.61 .05859 Mdot
.61 .05873 Mdot
.61 .05924 Mdot
.61 .05939 Mdot
.61 .05946 Mdot
.61 .05956 Mdot
.61 .05983 Mdot
.61 .05987 Mdot
.61 .06002 Mdot
.61 .06008 Mdot
.61 .06032 Mdot
.61 .0604 Mdot
.61 .06042 Mdot
.61 .06046 Mdot
.61 .06102 Mdot
.61 .06112 Mdot
.61 .06114 Mdot
.61 .06128 Mdot
.61 .06157 Mdot
.61 .06163 Mdot
.61 .062 Mdot
.61 .06213 Mdot
.61 .06223 Mdot
.61 .06238 Mdot
.61 .06242 Mdot
.61 .06268 Mdot
.61 .06281 Mdot
.61 .06297 Mdot
.61 .06324 Mdot
.61 .06407 Mdot
.61 .06435 Mdot
.61 .06462 Mdot
.61 .06466 Mdot
.61 .06476 Mdot
.61 .0649 Mdot
.61 .06502 Mdot
.61 .06509 Mdot
.61 .06536 Mdot
.61 .06543 Mdot
.61 .06559 Mdot
.61 .06564 Mdot
.61 .0661 Mdot
.61 .06663 Mdot
.61 .06665 Mdot
.61 .06668 Mdot
.61 .06685 Mdot
.61 .06702 Mdot
.61 .0672 Mdot
.61 .06723 Mdot
.61 .06751 Mdot
.61 .0677 Mdot
.61 .06773 Mdot
.61 .06784 Mdot
.61 .06786 Mdot
.61 .06802 Mdot
.61 .06825 Mdot
.61 .06841 Mdot
.61 .06893 Mdot
.61 .06899 Mdot
.61 .06902 Mdot
.61 .06904 Mdot
.61 .06922 Mdot
.61 .06931 Mdot
.61 .06943 Mdot
.61 .06975 Mdot
.61 .06981 Mdot
.61 .06999 Mdot
.61 .07006 Mdot
.61 .07036 Mdot
.61 .07045 Mdot
.61 .07047 Mdot
.61 .07052 Mdot
.61 .07121 Mdot
.61 .07133 Mdot
.61 .07136 Mdot
.61 .07152 Mdot
.61 .07153 Mdot
.61 .07188 Mdot
.61 .07195 Mdot
.61 .07207 Mdot
.61 .0724 Mdot
.61 .07256 Mdot
.61 .07268 Mdot
.61 .07287 Mdot
.61 .07291 Mdot
.61 .07295 Mdot
.61 .07324 Mdot
.61 .07339 Mdot
.61 .07359 Mdot
.61 .07392 Mdot
.61 .07493 Mdot
.61 .07527 Mdot
.61 .07535 Mdot
.61 .0756 Mdot
.61 .07565 Mdot
.61 .07576 Mdot
.61 .07594 Mdot
.61 .07609 Mdot
.61 .07617 Mdot
.61 .0765 Mdot
.61 .07654 Mdot
.61 .07659 Mdot
.61 .07678 Mdot
.61 .07685 Mdot
.61 .07741 Mdot
.61 .07742 Mdot
.61 .07805 Mdot
.61 .07807 Mdot
.61 .07811 Mdot
.61 .0782 Mdot
.61 .07832 Mdot
.61 .07853 Mdot
.61 .07875 Mdot
.61 .07878 Mdot
.61 .07879 Mdot
.61 .07908 Mdot
.61 .07913 Mdot
.61 .07935 Mdot
.61 .07938 Mdot
.61 .07939 Mdot
.61 .07953 Mdot
.61 .07956 Mdot
.61 .07974 Mdot
.61 .08003 Mdot
.61 .08022 Mdot
.61 .08085 Mdot
.61 .08093 Mdot
.61 .08097 Mdot
.61 .08099 Mdot
.61 .08121 Mdot
.61 .08132 Mdot
.61 .08145 Mdot
.61 .08147 Mdot
.61 .08186 Mdot
.61 .08193 Mdot
.61 .08215 Mdot
.61 .08224 Mdot
.61 .0826 Mdot
.61 .0826 Mdot
.61 .08271 Mdot
.61 .08274 Mdot
.61 .0828 Mdot
.61 .08355 Mdot
.61 .08363 Mdot
.61 .08378 Mdot
.61 .08382 Mdot
.61 .08402 Mdot
.61 .08403 Mdot
.61 .08403 Mdot
.61 .08445 Mdot
.61 .08454 Mdot
.61 .08469 Mdot
.61 .08509 Mdot
.61 .08529 Mdot
.61 .08544 Mdot
.61 .08557 Mdot
.61 .08566 Mdot
.61 .08571 Mdot
.61 .08576 Mdot
.61 .08611 Mdot
.61 .0863 Mdot
.61 .08646 Mdot
.61 .08654 Mdot
.61 .08695 Mdot
.61 .08818 Mdot
.61 .0886 Mdot
.61 .08869 Mdot
.61 .08899 Mdot
.61 .08906 Mdot
.61 .0892 Mdot
.61 .08941 Mdot
.61 .08959 Mdot
.61 .0897 Mdot
.61 .09009 Mdot
.61 .09014 Mdot
.61 .0902 Mdot
.61 .09043 Mdot
.61 .09052 Mdot
.61 .0912 Mdot
.61 .09122 Mdot
.61 .09198 Mdot
.61 .09201 Mdot
.61 .09206 Mdot
.61 .09216 Mdot
.61 .09231 Mdot
.61 .09257 Mdot
.61 .09283 Mdot
.61 .09288 Mdot
.61 .09288 Mdot
.61 .09324 Mdot
.61 .0933 Mdot
.61 .09357 Mdot
.61 .0936 Mdot
.61 .09362 Mdot
.61 .09379 Mdot
.61 .09382 Mdot
.61 .09383 Mdot
.61 .09405 Mdot
.61 .09439 Mdot
.61 .09463 Mdot
.61 .0954 Mdot
.61 .09549 Mdot
.61 .09555 Mdot
.61 .09557 Mdot
.61 .09584 Mdot
.61 .09597 Mdot
.61 .09614 Mdot
.61 .09615 Mdot
.61 .09663 Mdot
.61 .09671 Mdot
.61 .09699 Mdot
.61 .09709 Mdot
.61 .09753 Mdot
.61 .09754 Mdot
.61 .09767 Mdot
.61 .09771 Mdot
.61 .09778 Mdot
.61 .09869 Mdot
.61 .0988 Mdot
.61 .09898 Mdot
.61 .09902 Mdot
.61 .09926 Mdot
.61 .09928 Mdot
.61 .09928 Mdot
.61 .0998 Mdot
.61 .09991 Mdot
.61 .10008 Mdot
.61 .10057 Mdot
.61 .10082 Mdot
.61 .101 Mdot
.61 .10115 Mdot
.61 .10127 Mdot
.61 .10133 Mdot
.61 .10139 Mdot
.61 .10182 Mdot
.61 .10205 Mdot
.61 .10224 Mdot
.61 .10234 Mdot
.61 .10265 Mdot
.61 .10284 Mdot
.61 .10434 Mdot
.61 .10485 Mdot
.61 .10496 Mdot
.61 .10533 Mdot
.61 .10541 Mdot
.61 .10558 Mdot
.61 .10584 Mdot
.61 .10607 Mdot
.61 .10619 Mdot
.61 .10668 Mdot
.61 .10673 Mdot
.61 .1068 Mdot
.61 .10709 Mdot
.61 .10719 Mdot
.61 .10803 Mdot
.61 .10805 Mdot
.61 .10898 Mdot
.61 .10902 Mdot
.61 .10907 Mdot
.61 .1092 Mdot
.61 .10939 Mdot
.61 .10969 Mdot
.61 .11002 Mdot
.61 .11007 Mdot
.61 .11008 Mdot
.61 .11051 Mdot
.61 .11059 Mdot
.61 .11092 Mdot
.61 .11096 Mdot
.61 .11097 Mdot
.61 .11118 Mdot
.61 .11123 Mdot
.61 .11124 Mdot
.61 .1115 Mdot
.61 .11192 Mdot
.61 .11221 Mdot
.61 .11315 Mdot
.61 .11327 Mdot
.61 .11333 Mdot
.61 .11336 Mdot
.61 .11368 Mdot
.61 .11385 Mdot
.61 .11405 Mdot
.61 .11407 Mdot
.61 .11465 Mdot
.61 .11475 Mdot
.61 .11509 Mdot
.61 .11521 Mdot
.61 .11575 Mdot
.61 .11576 Mdot
.61 .11592 Mdot
.61 .11596 Mdot
.61 .11605 Mdot
.61 .11716 Mdot
.61 .11729 Mdot
.61 .11751 Mdot
.61 .11757 Mdot
.61 .11786 Mdot
.61 .11788 Mdot
.61 .11789 Mdot
.61 .11851 Mdot
.61 .11865 Mdot
.61 .11887 Mdot
.61 .11946 Mdot
.61 .11976 Mdot
.61 .11998 Mdot
.61 .12017 Mdot
.61 .12031 Mdot
.61 .12039 Mdot
.61 .12046 Mdot
.61 .12098 Mdot
.61 .12126 Mdot
.61 .1215 Mdot
.61 .12162 Mdot
.61 .122 Mdot
.61 .12222 Mdot
.61 .12406 Mdot
.61 .12468 Mdot
.61 .12482 Mdot
.61 .12527 Mdot
.61 .12536 Mdot
.61 .12557 Mdot
.61 .12588 Mdot
.61 .12617 Mdot
.61 .12632 Mdot
.61 .12691 Mdot
.61 .12698 Mdot
.61 .12706 Mdot
.61 .12741 Mdot
.61 .12754 Mdot
.61 .12856 Mdot
.61 .12858 Mdot
.61 .12972 Mdot
.61 .12976 Mdot
.61 .12983 Mdot
.61 .12999 Mdot
.61 .13021 Mdot
.61 .13059 Mdot
.61 .13099 Mdot
.61 .13105 Mdot
.61 .13106 Mdot
.61 .13159 Mdot
.61 .13168 Mdot
.61 .13208 Mdot
.61 .13213 Mdot
.61 .13215 Mdot
.61 .13241 Mdot
.61 .13246 Mdot
.61 .13247 Mdot
.61 .1328 Mdot
.61 .13331 Mdot
.61 .13366 Mdot
.61 .13481 Mdot
.61 .13495 Mdot
.61 .13502 Mdot
.61 .13506 Mdot
.61 .13545 Mdot
.61 .13566 Mdot
.61 .1359 Mdot
.61 .13593 Mdot
.61 .13664 Mdot
.61 .13676 Mdot
.61 .13717 Mdot
.61 .13732 Mdot
.61 .13798 Mdot
.61 .13799 Mdot
.61 .13819 Mdot
.61 .13824 Mdot
.61 .13835 Mdot
.61 .1397 Mdot
.61 .13986 Mdot
.61 .14013 Mdot
.61 .14019 Mdot
.61 .14056 Mdot
.61 .14058 Mdot
.61 .14059 Mdot
.61 .14135 Mdot
.61 .14151 Mdot
.61 .14178 Mdot
.61 .14251 Mdot
.61 .14287 Mdot
.61 .14313 Mdot
.61 .14337 Mdot
.61 .14355 Mdot
.61 .14364 Mdot
.61 .14373 Mdot
.61 .14436 Mdot
.61 .14471 Mdot
.61 .14499 Mdot
.61 .14514 Mdot
.61 .1456 Mdot
.61 .14588 Mdot
.61 .14811 Mdot
.61 .14887 Mdot
.61 .14904 Mdot
.61 .14959 Mdot
.61 .14971 Mdot
.61 .14996 Mdot
.61 .15034 Mdot
.61 .15069 Mdot
.61 .15087 Mdot
.61 .15159 Mdot
.61 .15168 Mdot
.61 .15178 Mdot
.61 .1522 Mdot
.61 .15236 Mdot
.61 .1536 Mdot
.61 .15363 Mdot
.61 .15502 Mdot
.61 .15507 Mdot
.61 .15516 Mdot
.61 .15535 Mdot
.61 .15562 Mdot
.61 .15608 Mdot
.61 .15657 Mdot
.61 .15664 Mdot
.61 .15666 Mdot
.61 .1573 Mdot
.61 .15742 Mdot
.61 .1579 Mdot
.61 .15796 Mdot
.61 .15799 Mdot
.61 .1583 Mdot
.61 .15836 Mdot
.61 .15838 Mdot
.61 .15877 Mdot
.61 .1594 Mdot
.61 .15983 Mdot
.61 .16123 Mdot
.61 .1614 Mdot
.61 .16149 Mdot
.61 .16153 Mdot
.61 .16202 Mdot
.61 .16227 Mdot
.61 .16257 Mdot
.61 .1626 Mdot
.61 .16346 Mdot
.61 .16361 Mdot
.61 .16411 Mdot
.61 .1643 Mdot
.61 .1651 Mdot
.61 .16511 Mdot
.61 .16535 Mdot
.61 .16541 Mdot
.61 .16554 Mdot
.61 .1672 Mdot
.61 .16739 Mdot
.61 .16772 Mdot
.61 .1678 Mdot
.61 .16824 Mdot
.61 .16827 Mdot
.61 .16828 Mdot
.61 .16921 Mdot
.61 .16941 Mdot
.61 .16973 Mdot
.61 .17062 Mdot
.61 .17106 Mdot
.61 .17139 Mdot
.61 .17167 Mdot
.61 .17189 Mdot
.61 .172 Mdot
.61 .17211 Mdot
.61 .17288 Mdot
.61 .1733 Mdot
.61 .17365 Mdot
.61 .17383 Mdot
.61 .1744 Mdot
.61 .17473 Mdot
.61 .17746 Mdot
.61 .17839 Mdot
.61 .17859 Mdot
.61 .17927 Mdot
.61 .1794 Mdot
.61 .17971 Mdot
.61 .18018 Mdot
.61 .1806 Mdot
.61 .18082 Mdot
.61 .1817 Mdot
.61 .18181 Mdot
.61 .18193 Mdot
.61 .18245 Mdot
.61 .18264 Mdot
.61 .18415 Mdot
.61 .18419 Mdot
.61 .18588 Mdot
.61 .18595 Mdot
.61 .18605 Mdot
.61 .18628 Mdot
.61 .18662 Mdot
.61 .18718 Mdot
.61 .18777 Mdot
.61 .18787 Mdot
.61 .18788 Mdot
.61 .18867 Mdot
.61 .18881 Mdot
.61 .18941 Mdot
.61 .18947 Mdot
.61 .1895 Mdot
.61 .18989 Mdot
.61 .18996 Mdot
.61 .18999 Mdot
.61 .19047 Mdot
.61 .19123 Mdot
.61 .19176 Mdot
.61 .19347 Mdot
.61 .19367 Mdot
.61 .19378 Mdot
.61 .19383 Mdot
.61 .19442 Mdot
.61 .19473 Mdot
.61 .19509 Mdot
.61 .19513 Mdot
.61 .19619 Mdot
.61 .19637 Mdot
.61 .19698 Mdot
.61 .19721 Mdot
.61 .19818 Mdot
.61 .1982 Mdot
.61 .1985 Mdot
.61 .19857 Mdot
.61 .19873 Mdot
.61 .20074 Mdot
.61 .20098 Mdot
.61 .20138 Mdot
.61 .20148 Mdot
.61 .20202 Mdot
.61 .20205 Mdot
.61 .20206 Mdot
.61 .2032 Mdot
.61 .20344 Mdot
.61 .20384 Mdot
.61 .20492 Mdot
.61 .20546 Mdot
.61 .20585 Mdot
.61 .2062 Mdot
.61 .20647 Mdot
.61 .2066 Mdot
.61 .20674 Mdot
.61 .20767 Mdot
.61 .20819 Mdot
.61 .20862 Mdot
.61 .20884 Mdot
.61 .20953 Mdot
.61 .20993 Mdot
.61 .21326 Mdot
.61 .2144 Mdot
.61 .21465 Mdot
.61 .21547 Mdot
.61 .21563 Mdot
.61 .21601 Mdot
.61 .21658 Mdot
.61 .21709 Mdot
.61 .21737 Mdot
.61 .21844 Mdot
.61 .21857 Mdot
.61 .21872 Mdot
.61 .21935 Mdot
.61 .21958 Mdot
.61 .22143 Mdot
.61 .22148 Mdot
.61 .22354 Mdot
.61 .22362 Mdot
.61 .22375 Mdot
.61 .22403 Mdot
.61 .22444 Mdot
.61 .22513 Mdot
.61 .22585 Mdot
.61 .22596 Mdot
.61 .22598 Mdot
.61 .22694 Mdot
.61 .22711 Mdot
.61 .22784 Mdot
.61 .22792 Mdot
.61 .22796 Mdot
.61 .22843 Mdot
.61 .22852 Mdot
.61 .22855 Mdot
.61 .22913 Mdot
.61 .23006 Mdot
.61 .23071 Mdot
.61 .23279 Mdot
.61 .23304 Mdot
.61 .23318 Mdot
.61 .23324 Mdot
.61 .23396 Mdot
.61 .23433 Mdot
.61 .23478 Mdot
.61 .23482 Mdot
.61 .23611 Mdot
.61 .23634 Mdot
.61 .23708 Mdot
.61 .23735 Mdot
.61 .23854 Mdot
.61 .23856 Mdot
.61 .23893 Mdot
.61 .23901 Mdot
.61 .23921 Mdot
.61 .24167 Mdot
.61 .24196 Mdot
.61 .24245 Mdot
.61 .24257 Mdot
.61 .24323 Mdot
.61 .24326 Mdot
.61 .24328 Mdot
.61 .24466 Mdot
.61 .24496 Mdot
.61 .24544 Mdot
.61 .24676 Mdot
.61 .24742 Mdot
.61 .2479 Mdot
.61 .24833 Mdot
.61 .24865 Mdot
.61 .24882 Mdot
.61 .24898 Mdot
.61 .25013 Mdot
.61 .25076 Mdot
.61 .25128 Mdot
.61 .25154 Mdot
.61 .25239 Mdot
.61 .25288 Mdot
.61 .25694 Mdot
.61 .25833 Mdot
.61 .25863 Mdot
.61 .25963 Mdot
.61 .25984 Mdot
.61 .2603 Mdot
.61 .26099 Mdot
.61 .26162 Mdot
.61 .26195 Mdot
.61 .26326 Mdot
.61 .26342 Mdot
.61 .2636 Mdot
.61 .26437 Mdot
.61 .26465 Mdot
.61 .26691 Mdot
.61 .26696 Mdot
.61 .26948 Mdot
.61 .26958 Mdot
.61 .26974 Mdot
.61 .27008 Mdot
.61 .27058 Mdot
.61 .27142 Mdot
.61 .2723 Mdot
.61 .27244 Mdot
.61 .27246 Mdot
.61 .27363 Mdot
.61 .27384 Mdot
.61 .27473 Mdot
.61 .27482 Mdot
.61 .27487 Mdot
.61 .27544 Mdot
.61 .27556 Mdot
.61 .27559 Mdot
.61 .2763 Mdot
.61 .27744 Mdot
.61 .27823 Mdot
.61 .28077 Mdot
.61 .28107 Mdot
.61 .28124 Mdot
.61 .28131 Mdot
.61 .28219 Mdot
.61 .28264 Mdot
.61 .28319 Mdot
.61 .28324 Mdot
.61 .28482 Mdot
.61 .28509 Mdot
.61 .286 Mdot
.61 .28633 Mdot
.61 .28778 Mdot
.61 .28781 Mdot
.61 .28825 Mdot
.61 .28836 Mdot
.61 .2886 Mdot
.61 .2916 Mdot
.61 .29195 Mdot
.61 .29255 Mdot
.61 .29269 Mdot
.61 .2935 Mdot
.61 .29354 Mdot
.61 .29356 Mdot
.61 .29525 Mdot
.61 .29561 Mdot
.61 .2962 Mdot
.61 .29781 Mdot
.61 .29861 Mdot
.61 .29921 Mdot
.61 .29973 Mdot
.61 .30012 Mdot
.61 .30032 Mdot
.61 .30052 Mdot
.61 .30192 Mdot
.61 .30269 Mdot
.61 .30332 Mdot
.61 .30365 Mdot
.61 .30468 Mdot
.61 .30528 Mdot
.61 .31023 Mdot
.61 .31192 Mdot
.61 .31229 Mdot
.61 .31352 Mdot
.61 .31376 Mdot
.61 .31433 Mdot
.61 .31517 Mdot
.61 .31593 Mdot
.61 .31634 Mdot
.61 .31794 Mdot
.61 .31813 Mdot
.61 .31836 Mdot
.61 .3193 Mdot
.61 .31964 Mdot
.61 .32239 Mdot
.61 .32246 Mdot
.61 .32553 Mdot
.61 .32565 Mdot
.61 .32584 Mdot
.61 .32626 Mdot
.61 .32687 Mdot
.61 .32789 Mdot
.61 .32896 Mdot
.61 .32913 Mdot
.61 .32916 Mdot
.61 .3306 Mdot
.61 .33085 Mdot
.61 .33193 Mdot
.61 .33205 Mdot
.61 .33211 Mdot
.61 .3328 Mdot
.61 .33294 Mdot
.61 .33298 Mdot
.61 .33385 Mdot
.61 .33524 Mdot
.61 .3362 Mdot
.61 .3393 Mdot
.61 .33967 Mdot
.61 .33988 Mdot
.61 .33997 Mdot
.61 .34104 Mdot
.61 .34159 Mdot
.61 .34225 Mdot
.61 .34232 Mdot
.61 .34424 Mdot
.61 .34457 Mdot
.61 .34568 Mdot
.61 .34609 Mdot
.61 .34786 Mdot
.61 .34789 Mdot
.61 .34843 Mdot
.61 .34856 Mdot
.61 .34885 Mdot
.61 .35252 Mdot
.61 .35295 Mdot
.61 .35367 Mdot
.61 .35385 Mdot
.61 .35483 Mdot
.61 .35488 Mdot
.61 .35491 Mdot
.61 .35697 Mdot
.61 .35741 Mdot
.61 .35813 Mdot
.61 .3601 Mdot
.61 .36107 Mdot
.61 .36179 Mdot
.61 .36243 Mdot
.61 .36291 Mdot
.61 .36315 Mdot
.61 .3634 Mdot
.61 .3651 Mdot
.61 .36604 Mdot
.61 .36681 Mdot
.61 .36721 Mdot
.61 .36847 Mdot
.61 .3692 Mdot
.61 .37525 Mdot
.612 .01501 Mdot
.612 .01507 Mdot
.612 .01514 Mdot
.612 .01515 Mdot
.612 .01515 Mdot
.612 .01524 Mdot
.612 .01525 Mdot
.612 .01525 Mdot
.612 .01535 Mdot
.612 .01537 Mdot
.612 .01537 Mdot
.612 .0155 Mdot
.612 .01551 Mdot
.612 .01552 Mdot
.612 .01567 Mdot
.612 .01569 Mdot
.612 .0157 Mdot
.612 .01589 Mdot
.612 .01591 Mdot
.612 .01591 Mdot
.612 .01615 Mdot
.612 .01618 Mdot
.612 .01618 Mdot
.612 .01647 Mdot
.612 .01651 Mdot
.612 .01651 Mdot
.612 .01686 Mdot
.612 .01691 Mdot
.612 .01691 Mdot
.612 .01734 Mdot
.612 .0174 Mdot
.612 .01741 Mdot
.612 .01752 Mdot
.612 .01793 Mdot
.612 .018 Mdot
.612 .01801 Mdot
.612 .01815 Mdot
.612 .01865 Mdot
.612 .01874 Mdot
.612 .01875 Mdot
.612 .01892 Mdot
.612 .01925 Mdot
.612 .01943 Mdot
.612 .01954 Mdot
.612 .01964 Mdot
.612 .01965 Mdot
.612 .01972 Mdot
.612 .01987 Mdot
.612 .02027 Mdot
.612 .02048 Mdot
.612 .02061 Mdot
.612 .02074 Mdot
.612 .02076 Mdot
.612 .02084 Mdot
.612 .02102 Mdot
.612 .02112 Mdot
.612 .02151 Mdot
.612 .02177 Mdot
.612 .02194 Mdot
.612 .02209 Mdot
.612 .02211 Mdot
.612 .02221 Mdot
.612 .02243 Mdot
.612 .02255 Mdot
.612 .02304 Mdot
.612 .02308 Mdot
.612 .02318 Mdot
.612 .02335 Mdot
.612 .02355 Mdot
.612 .02375 Mdot
.612 .02377 Mdot
.612 .02389 Mdot
.612 .02414 Mdot
.612 .02416 Mdot
.612 .02431 Mdot
.612 .0249 Mdot
.612 .02495 Mdot
.612 .02507 Mdot
.612 .02529 Mdot
.612 .02553 Mdot
.612 .02577 Mdot
.612 .0258 Mdot
.612 .02595 Mdot
.612 .02616 Mdot
.612 .02625 Mdot
.612 .02628 Mdot
.612 .02646 Mdot
.612 .02691 Mdot
.612 .02718 Mdot
.612 .02724 Mdot
.612 .02739 Mdot
.612 .02766 Mdot
.612 .02791 Mdot
.612 .02796 Mdot
.612 .02825 Mdot
.612 .02828 Mdot
.612 .02846 Mdot
.612 .02872 Mdot
.612 .02883 Mdot
.612 .02886 Mdot
.612 .02887 Mdot
.612 .02909 Mdot
.612 .02964 Mdot
.612 .02974 Mdot
.612 .02997 Mdot
.612 .03005 Mdot
.612 .03023 Mdot
.612 .03056 Mdot
.612 .03076 Mdot
.612 .03087 Mdot
.612 .03092 Mdot
.612 .03128 Mdot
.612 .03132 Mdot
.612 .03154 Mdot
.612 .03162 Mdot
.612 .03186 Mdot
.612 .032 Mdot
.612 .03203 Mdot
.612 .03204 Mdot
.612 .0323 Mdot
.612 .03239 Mdot
.612 .03298 Mdot
.612 .0331 Mdot
.612 .03339 Mdot
.612 .03349 Mdot
.612 .03371 Mdot
.612 .0341 Mdot
.612 .03411 Mdot
.612 .03431 Mdot
.612 .03435 Mdot
.612 .03448 Mdot
.612 .03455 Mdot
.612 .03499 Mdot
.612 .03504 Mdot
.612 .03531 Mdot
.612 .0354 Mdot
.612 .03543 Mdot
.612 .03569 Mdot
.612 .03587 Mdot
.612 .03591 Mdot
.612 .03592 Mdot
.612 .03624 Mdot
.612 .03635 Mdot
.612 .03708 Mdot
.612 .03722 Mdot
.612 .03757 Mdot
.612 .03769 Mdot
.612 .03796 Mdot
.612 .03844 Mdot
.612 .03845 Mdot
.612 .0387 Mdot
.612 .03871 Mdot
.612 .03875 Mdot
.612 .03883 Mdot
.612 .03891 Mdot
.612 .039 Mdot
.612 .03906 Mdot
.612 .03953 Mdot
.612 .03959 Mdot
.612 .03993 Mdot
.612 .04004 Mdot
.612 .04005 Mdot
.612 .04006 Mdot
.612 .04032 Mdot
.612 .04039 Mdot
.612 .0406 Mdot
.612 .04066 Mdot
.612 .04067 Mdot
.612 .04107 Mdot
.612 .04119 Mdot
.612 .04195 Mdot
.612 .04202 Mdot
.612 .04208 Mdot
.612 .04226 Mdot
.612 .04269 Mdot
.612 .04284 Mdot
.612 .04317 Mdot
.612 .04376 Mdot
.612 .04377 Mdot
.612 .04379 Mdot
.612 .04407 Mdot
.612 .04409 Mdot
.612 .04413 Mdot
.612 .04423 Mdot
.612 .04433 Mdot
.612 .04433 Mdot
.612 .04444 Mdot
.612 .04452 Mdot
.612 .04509 Mdot
.612 .04516 Mdot
.612 .04557 Mdot
.612 .04571 Mdot
.612 .04573 Mdot
.612 .04574 Mdot
.612 .04606 Mdot
.612 .04615 Mdot
.612 .0464 Mdot
.612 .04647 Mdot
.612 .04648 Mdot
.612 .04667 Mdot
.612 .04697 Mdot
.612 .04712 Mdot
.612 .04805 Mdot
.612 .04814 Mdot
.612 .04822 Mdot
.612 .04828 Mdot
.612 .04844 Mdot
.612 .04885 Mdot
.612 .04896 Mdot
.612 .04914 Mdot
.612 .04955 Mdot
.612 .05027 Mdot
.612 .05028 Mdot
.612 .0503 Mdot
.612 .05064 Mdot
.612 .05067 Mdot
.612 .05072 Mdot
.612 .05084 Mdot
.612 .05096 Mdot
.612 .05097 Mdot
.612 .0511 Mdot
.612 .05119 Mdot
.612 .05189 Mdot
.612 .05198 Mdot
.612 .05249 Mdot
.612 .05265 Mdot
.612 .05268 Mdot
.612 .05269 Mdot
.612 .05298 Mdot
.612 .05308 Mdot
.612 .05319 Mdot
.612 .0535 Mdot
.612 .05358 Mdot
.612 .05359 Mdot
.612 .05383 Mdot
.612 .05419 Mdot
.612 .05438 Mdot
.612 .0548 Mdot
.612 .05481 Mdot
.612 .05491 Mdot
.612 .05521 Mdot
.612 .05552 Mdot
.612 .05563 Mdot
.612 .05572 Mdot
.612 .0558 Mdot
.612 .05599 Mdot
.612 .05649 Mdot
.612 .0565 Mdot
.612 .05663 Mdot
.612 .05685 Mdot
.612 .05735 Mdot
.612 .05759 Mdot
.612 .05823 Mdot
.612 .05824 Mdot
.612 .05827 Mdot
.612 .05869 Mdot
.612 .05872 Mdot
.612 .05878 Mdot
.612 .05893 Mdot
.612 .05905 Mdot
.612 .05908 Mdot
.612 .05909 Mdot
.612 .05924 Mdot
.612 .05936 Mdot
.612 .05938 Mdot
.612 .05993 Mdot
.612 .06022 Mdot
.612 .06033 Mdot
.612 .06095 Mdot
.612 .06115 Mdot
.612 .06118 Mdot
.612 .0612 Mdot
.612 .06127 Mdot
.612 .06155 Mdot
.612 .06168 Mdot
.612 .0618 Mdot
.612 .06219 Mdot
.612 .06229 Mdot
.612 .0623 Mdot
.612 .06239 Mdot
.612 .06259 Mdot
.612 .0627 Mdot
.612 .06272 Mdot
.612 .06304 Mdot
.612 .06327 Mdot
.612 .06377 Mdot
.612 .06379 Mdot
.612 .06391 Mdot
.612 .06418 Mdot
.612 .06428 Mdot
.612 .06454 Mdot
.612 .06466 Mdot
.612 .06479 Mdot
.612 .0649 Mdot
.612 .06501 Mdot
.612 .06523 Mdot
.612 .06526 Mdot
.612 .06541 Mdot
.612 .06585 Mdot
.612 .06586 Mdot
.612 .06602 Mdot
.612 .06627 Mdot
.612 .06628 Mdot
.612 .0669 Mdot
.612 .06719 Mdot
.612 .06798 Mdot
.612 .06799 Mdot
.612 .06803 Mdot
.612 .0682 Mdot
.612 .06854 Mdot
.612 .06858 Mdot
.612 .06866 Mdot
.612 .06883 Mdot
.612 .06898 Mdot
.612 .06902 Mdot
.612 .06903 Mdot
.612 .06922 Mdot
.612 .06927 Mdot
.612 .06936 Mdot
.612 .06938 Mdot
.612 .07006 Mdot
.612 .07041 Mdot
.612 .07054 Mdot
.612 .07055 Mdot
.612 .0713 Mdot
.612 .07155 Mdot
.612 .07159 Mdot
.612 .07161 Mdot
.612 .07169 Mdot
.612 .07204 Mdot
.612 .07219 Mdot
.612 .07235 Mdot
.612 .07282 Mdot
.612 .07295 Mdot
.612 .07296 Mdot
.612 .07296 Mdot
.612 .07307 Mdot
.612 .07319 Mdot
.612 .07331 Mdot
.612 .07345 Mdot
.612 .07348 Mdot
.612 .07386 Mdot
.612 .07414 Mdot
.612 .07417 Mdot
.612 .07422 Mdot
.612 .07476 Mdot
.612 .07478 Mdot
.612 .07493 Mdot
.612 .07526 Mdot
.612 .07538 Mdot
.612 .0757 Mdot
.612 .07584 Mdot
.612 .07601 Mdot
.612 .07615 Mdot
.612 .07627 Mdot
.612 .07655 Mdot
.612 .07658 Mdot
.612 .07676 Mdot
.612 .0773 Mdot
.612 .07732 Mdot
.612 .07752 Mdot
.612 .07782 Mdot
.612 .07783 Mdot
.612 .07859 Mdot
.612 .07894 Mdot
.612 .07991 Mdot
.612 .07991 Mdot
.612 .07992 Mdot
.612 .07997 Mdot
.612 .08018 Mdot
.612 .0806 Mdot
.612 .08065 Mdot
.612 .08074 Mdot
.612 .08096 Mdot
.612 .08114 Mdot
.612 .08119 Mdot
.612 .08119 Mdot
.612 .08143 Mdot
.612 .08149 Mdot
.612 .0816 Mdot
.612 .08163 Mdot
.612 .08177 Mdot
.612 .08208 Mdot
.612 .08225 Mdot
.612 .08246 Mdot
.612 .08285 Mdot
.612 .08289 Mdot
.612 .08305 Mdot
.612 .08306 Mdot
.612 .08398 Mdot
.612 .08428 Mdot
.612 .08433 Mdot
.612 .08436 Mdot
.612 .08446 Mdot
.612 .08488 Mdot
.612 .08507 Mdot
.612 .08526 Mdot
.612 .08548 Mdot
.612 .08584 Mdot
.612 .08599 Mdot
.612 .08601 Mdot
.612 .08601 Mdot
.612 .08614 Mdot
.612 .08629 Mdot
.612 .08644 Mdot
.612 .08661 Mdot
.612 .08664 Mdot
.612 .08664 Mdot
.612 .08711 Mdot
.612 .08745 Mdot
.612 .08749 Mdot
.612 .08755 Mdot
.612 .08782 Mdot
.612 .08821 Mdot
.612 .08823 Mdot
.612 .08842 Mdot
.612 .08882 Mdot
.612 .08897 Mdot
.612 .08917 Mdot
.612 .08936 Mdot
.612 .08954 Mdot
.612 .08974 Mdot
.612 .08991 Mdot
.612 .09006 Mdot
.612 .0904 Mdot
.612 .09044 Mdot
.612 .09066 Mdot
.612 .09132 Mdot
.612 .09134 Mdot
.612 .09139 Mdot
.612 .09158 Mdot
.612 .09196 Mdot
.612 .09197 Mdot
.612 .09232 Mdot
.612 .09243 Mdot
.612 .0929 Mdot
.612 .09322 Mdot
.612 .09333 Mdot
.612 .09415 Mdot
.612 .09451 Mdot
.612 .09451 Mdot
.612 .09453 Mdot
.612 .09459 Mdot
.612 .09484 Mdot
.612 .09506 Mdot
.612 .09535 Mdot
.612 .09542 Mdot
.612 .09553 Mdot
.612 .09579 Mdot
.612 .09602 Mdot
.612 .09608 Mdot
.612 .09608 Mdot
.612 .09637 Mdot
.612 .09644 Mdot
.612 .09659 Mdot
.612 .09662 Mdot
.612 .09679 Mdot
.612 .09717 Mdot
.612 .09738 Mdot
.612 .09764 Mdot
.612 .09811 Mdot
.612 .09816 Mdot
.612 .09835 Mdot
.612 .09836 Mdot
.612 .09949 Mdot
.612 .09986 Mdot
.612 .09992 Mdot
.612 .09996 Mdot
.612 .10008 Mdot
.612 .1006 Mdot
.612 .10083 Mdot
.612 .10106 Mdot
.612 .10133 Mdot
.612 .10177 Mdot
.612 .10196 Mdot
.612 .10198 Mdot
.612 .10198 Mdot
.612 .10214 Mdot
.612 .10232 Mdot
.612 .1025 Mdot
.612 .10272 Mdot
.612 .10275 Mdot
.612 .10275 Mdot
.612 .10333 Mdot
.612 .10375 Mdot
.612 .10379 Mdot
.612 .10386 Mdot
.612 .1042 Mdot
.612 .10468 Mdot
.612 .1047 Mdot
.612 .10493 Mdot
.612 .10542 Mdot
.612 .10561 Mdot
.612 .10585 Mdot
.612 .10608 Mdot
.612 .10629 Mdot
.612 .10654 Mdot
.612 .10675 Mdot
.612 .10694 Mdot
.612 .10735 Mdot
.612 .1074 Mdot
.612 .10768 Mdot
.612 .10848 Mdot
.612 .1085 Mdot
.612 .10856 Mdot
.612 .1088 Mdot
.612 .10926 Mdot
.612 .10928 Mdot
.612 .10971 Mdot
.612 .10984 Mdot
.612 .11041 Mdot
.612 .1108 Mdot
.612 .11094 Mdot
.612 .11194 Mdot
.612 .11238 Mdot
.612 .11239 Mdot
.612 .11241 Mdot
.612 .11248 Mdot
.612 .11279 Mdot
.612 .11306 Mdot
.612 .11342 Mdot
.612 .1135 Mdot
.612 .11363 Mdot
.612 .11395 Mdot
.612 .11423 Mdot
.612 .1143 Mdot
.612 .11431 Mdot
.612 .11466 Mdot
.612 .11475 Mdot
.612 .11493 Mdot
.612 .11496 Mdot
.612 .11517 Mdot
.612 .11564 Mdot
.612 .1159 Mdot
.612 .11621 Mdot
.612 .1168 Mdot
.612 .11685 Mdot
.612 .11709 Mdot
.612 .1171 Mdot
.612 .11848 Mdot
.612 .11894 Mdot
.612 .11901 Mdot
.612 .11905 Mdot
.612 .1192 Mdot
.612 .11984 Mdot
.612 .12012 Mdot
.612 .12041 Mdot
.612 .12073 Mdot
.612 .12127 Mdot
.612 .1215 Mdot
.612 .12153 Mdot
.612 .12153 Mdot
.612 .12172 Mdot
.612 .12194 Mdot
.612 .12217 Mdot
.612 .12243 Mdot
.612 .12247 Mdot
.612 .12247 Mdot
.612 .12318 Mdot
.612 .12369 Mdot
.612 .12374 Mdot
.612 .12383 Mdot
.612 .12424 Mdot
.612 .12483 Mdot
.612 .12486 Mdot
.612 .12514 Mdot
.612 .12574 Mdot
.612 .12597 Mdot
.612 .12626 Mdot
.612 .12655 Mdot
.612 .12681 Mdot
.612 .12711 Mdot
.612 .12737 Mdot
.612 .1276 Mdot
.612 .12811 Mdot
.612 .12817 Mdot
.612 .1285 Mdot
.612 .12948 Mdot
.612 .12951 Mdot
.612 .12958 Mdot
.612 .12988 Mdot
.612 .13044 Mdot
.612 .13046 Mdot
.612 .13099 Mdot
.612 .13115 Mdot
.612 .13184 Mdot
.612 .13232 Mdot
.612 .13249 Mdot
.612 .13372 Mdot
.612 .13426 Mdot
.612 .13426 Mdot
.612 .13429 Mdot
.612 .13438 Mdot
.612 .13476 Mdot
.612 .13509 Mdot
.612 .13553 Mdot
.612 .13562 Mdot
.612 .13579 Mdot
.612 .13618 Mdot
.612 .13652 Mdot
.612 .13661 Mdot
.612 .13662 Mdot
.612 .13705 Mdot
.612 .13716 Mdot
.612 .13737 Mdot
.612 .13742 Mdot
.612 .13767 Mdot
.612 .13825 Mdot
.612 .13856 Mdot
.612 .13894 Mdot
.612 .13966 Mdot
.612 .13973 Mdot
.612 .14002 Mdot
.612 .14004 Mdot
.612 .14173 Mdot
.612 .14228 Mdot
.612 .14237 Mdot
.612 .14243 Mdot
.612 .1426 Mdot
.612 .14339 Mdot
.612 .14373 Mdot
.612 .14408 Mdot
.612 .14448 Mdot
.612 .14514 Mdot
.612 .14542 Mdot
.612 .14545 Mdot
.612 .14545 Mdot
.612 .14569 Mdot
.612 .14596 Mdot
.612 .14623 Mdot
.612 .14656 Mdot
.612 .1466 Mdot
.612 .14661 Mdot
.612 .14747 Mdot
.612 .1481 Mdot
.612 .14816 Mdot
.612 .14827 Mdot
.612 .14878 Mdot
.612 .14949 Mdot
.612 .14953 Mdot
.612 .14988 Mdot
.612 .15061 Mdot
.612 .15089 Mdot
.612 .15125 Mdot
.612 .1516 Mdot
.612 .15192 Mdot
.612 .15229 Mdot
.612 .1526 Mdot
.612 .15288 Mdot
.612 .15351 Mdot
.612 .15358 Mdot
.612 .15399 Mdot
.612 .15518 Mdot
.612 .15523 Mdot
.612 .15531 Mdot
.612 .15567 Mdot
.612 .15636 Mdot
.612 .15639 Mdot
.612 .15703 Mdot
.612 .15723 Mdot
.612 .15808 Mdot
.612 .15867 Mdot
.612 .15888 Mdot
.612 .16038 Mdot
.612 .16104 Mdot
.612 .16104 Mdot
.612 .16108 Mdot
.612 .16119 Mdot
.612 .16165 Mdot
.612 .16205 Mdot
.612 .16259 Mdot
.612 .16271 Mdot
.612 .16291 Mdot
.612 .16339 Mdot
.612 .1638 Mdot
.612 .16392 Mdot
.612 .16392 Mdot
.612 .16445 Mdot
.612 .16458 Mdot
.612 .16485 Mdot
.612 .1649 Mdot
.612 .16522 Mdot
.612 .16592 Mdot
.612 .16631 Mdot
.612 .16677 Mdot
.612 .16765 Mdot
.612 .16773 Mdot
.612 .16809 Mdot
.612 .16811 Mdot
.612 .17018 Mdot
.612 .17086 Mdot
.612 .17097 Mdot
.612 .17103 Mdot
.612 .17125 Mdot
.612 .17221 Mdot
.612 .17263 Mdot
.612 .17306 Mdot
.612 .17355 Mdot
.612 .17436 Mdot
.612 .1747 Mdot
.612 .17474 Mdot
.612 .17474 Mdot
.612 .17502 Mdot
.612 .17536 Mdot
.612 .17569 Mdot
.612 .17609 Mdot
.612 .17615 Mdot
.612 .17615 Mdot
.612 .17721 Mdot
.612 .17798 Mdot
.612 .17806 Mdot
.612 .17819 Mdot
.612 .17881 Mdot
.612 .17968 Mdot
.612 .17973 Mdot
.612 .18016 Mdot
.612 .18105 Mdot
.612 .18139 Mdot
.612 .18184 Mdot
.612 .18226 Mdot
.612 .18265 Mdot
.612 .1831 Mdot
.612 .18349 Mdot
.612 .18383 Mdot
.612 .18459 Mdot
.612 .18469 Mdot
.612 .18518 Mdot
.612 .18665 Mdot
.612 .1867 Mdot
.612 .1868 Mdot
.612 .18725 Mdot
.612 .18809 Mdot
.612 .18812 Mdot
.612 .18891 Mdot
.612 .18915 Mdot
.612 .19019 Mdot
.612 .19091 Mdot
.612 .19117 Mdot
.612 .19301 Mdot
.612 .19381 Mdot
.612 .19382 Mdot
.612 .19387 Mdot
.612 .194 Mdot
.612 .19457 Mdot
.612 .19506 Mdot
.612 .19571 Mdot
.612 .19586 Mdot
.612 .1961 Mdot
.612 .1967 Mdot
.612 .1972 Mdot
.612 .19734 Mdot
.612 .19735 Mdot
.612 .198 Mdot
.612 .19816 Mdot
.612 .19848 Mdot
.612 .19854 Mdot
.612 .19893 Mdot
.612 .19979 Mdot
.612 .20026 Mdot
.612 .20083 Mdot
.612 .20191 Mdot
.612 .20201 Mdot
.612 .20245 Mdot
.612 .20247 Mdot
.612 .205 Mdot
.612 .20583 Mdot
.612 .20597 Mdot
.612 .20605 Mdot
.612 .20631 Mdot
.612 .20749 Mdot
.612 .208 Mdot
.612 .20853 Mdot
.612 .20913 Mdot
.612 .21012 Mdot
.612 .21053 Mdot
.612 .21058 Mdot
.612 .21093 Mdot
.612 .21135 Mdot
.612 .21175 Mdot
.612 .21223 Mdot
.612 .21231 Mdot
.612 .21231 Mdot
.612 .21361 Mdot
.612 .21455 Mdot
.612 .21465 Mdot
.612 .2148 Mdot
.612 .21557 Mdot
.612 .21664 Mdot
.612 .21669 Mdot
.612 .21721 Mdot
.612 .21831 Mdot
.612 .21873 Mdot
.612 .21927 Mdot
.612 .21979 Mdot
.612 .22027 Mdot
.612 .22082 Mdot
.612 .22129 Mdot
.612 .22171 Mdot
.612 .22265 Mdot
.612 .22276 Mdot
.612 .22337 Mdot
.612 .22516 Mdot
.612 .22522 Mdot
.612 .22535 Mdot
.612 .22589 Mdot
.612 .22693 Mdot
.612 .22697 Mdot
.612 .22793 Mdot
.612 .22823 Mdot
.612 .2295 Mdot
.612 .23038 Mdot
.612 .23069 Mdot
.612 .23294 Mdot
.612 .23393 Mdot
.612 .23394 Mdot
.612 .234 Mdot
.612 .23416 Mdot
.612 .23486 Mdot
.612 .23545 Mdot
.612 .23625 Mdot
.612 .23643 Mdot
.612 .23673 Mdot
.612 .23746 Mdot
.612 .23807 Mdot
.612 .23825 Mdot
.612 .23826 Mdot
.612 .23905 Mdot
.612 .23925 Mdot
.612 .23964 Mdot
.612 .23972 Mdot
.612 .24019 Mdot
.612 .24124 Mdot
.612 .24182 Mdot
.612 .24252 Mdot
.612 .24384 Mdot
.612 .24396 Mdot
.612 .2445 Mdot
.612 .24452 Mdot
.612 .24763 Mdot
.612 .24864 Mdot
.612 .24881 Mdot
.612 .24891 Mdot
.612 .24923 Mdot
.612 .25067 Mdot
.612 .2513 Mdot
.612 .25194 Mdot
.612 .25268 Mdot
.612 .25389 Mdot
.612 .2544 Mdot
.612 .25446 Mdot
.612 .25488 Mdot
.612 .25539 Mdot
.612 .25589 Mdot
.612 .25648 Mdot
.612 .25657 Mdot
.612 .25658 Mdot
.612 .25816 Mdot
.612 .25931 Mdot
.612 .25943 Mdot
.612 .25962 Mdot
.612 .26056 Mdot
.612 .26187 Mdot
.612 .26193 Mdot
.612 .26257 Mdot
.612 .26392 Mdot
.612 .26442 Mdot
.612 .26509 Mdot
.612 .26573 Mdot
.612 .26631 Mdot
.612 .26699 Mdot
.612 .26757 Mdot
.612 .26808 Mdot
.612 .26922 Mdot
.612 .26936 Mdot
.612 .27011 Mdot
.612 .2723 Mdot
.612 .27238 Mdot
.612 .27254 Mdot
.612 .2732 Mdot
.612 .27446 Mdot
.612 .27451 Mdot
.612 .27569 Mdot
.612 .27605 Mdot
.612 .27761 Mdot
.612 .27869 Mdot
.612 .27907 Mdot
.612 .28182 Mdot
.612 .28304 Mdot
.612 .28304 Mdot
.612 .28311 Mdot
.612 .28331 Mdot
.612 .28417 Mdot
.612 .2849 Mdot
.612 .28588 Mdot
.612 .2861 Mdot
.612 .28647 Mdot
.612 .28736 Mdot
.612 .2881 Mdot
.612 .28832 Mdot
.612 .28833 Mdot
.612 .2893 Mdot
.612 .28954 Mdot
.612 .29002 Mdot
.612 .29012 Mdot
.612 .2907 Mdot
.612 .29198 Mdot
.612 .2927 Mdot
.612 .29355 Mdot
.612 .29516 Mdot
.612 .29531 Mdot
.612 .29597 Mdot
.612 .296 Mdot
.612 .2998 Mdot
.612 .30104 Mdot
.612 .30125 Mdot
.612 .30136 Mdot
.612 .30176 Mdot
.612 .30352 Mdot
.612 .30429 Mdot
.612 .30508 Mdot
.612 .30598 Mdot
.612 .30746 Mdot
.612 .30809 Mdot
.612 .30816 Mdot
.612 .30868 Mdot
.612 .3093 Mdot
.612 .30991 Mdot
.612 .31063 Mdot
.612 .31074 Mdot
.612 .31075 Mdot
.612 .31269 Mdot
.612 .3141 Mdot
.612 .31425 Mdot
.612 .31448 Mdot
.612 .31563 Mdot
.612 .31723 Mdot
.612 .31731 Mdot
.612 .31809 Mdot
.612 .31974 Mdot
.612 .32036 Mdot
.612 .32118 Mdot
.612 .32196 Mdot
.612 .32267 Mdot
.612 .3235 Mdot
.612 .3242 Mdot
.612 .32483 Mdot
.612 .32623 Mdot
.612 .3264 Mdot
.612 .32732 Mdot
.612 .33 Mdot
.612 .33009 Mdot
.612 .33029 Mdot
.612 .3311 Mdot
.612 .33265 Mdot
.612 .33271 Mdot
.612 .33415 Mdot
.612 .33459 Mdot
.612 .3365 Mdot
.612 .33782 Mdot
.612 .33829 Mdot
.612 .34166 Mdot
.612 .34314 Mdot
.612 .34315 Mdot
.612 .34324 Mdot
.612 .34348 Mdot
.612 .34452 Mdot
.612 .34542 Mdot
.612 .34662 Mdot
.612 .34689 Mdot
.612 .34734 Mdot
.612 .34843 Mdot
.612 .34934 Mdot
.612 .3496 Mdot
.612 .34962 Mdot
.612 .35081 Mdot
.612 .3511 Mdot
.612 .35169 Mdot
.612 .35181 Mdot
.612 .35252 Mdot
.612 .35409 Mdot
.612 .35496 Mdot
.612 .35601 Mdot
.612 .35798 Mdot
.612 .35817 Mdot
.612 .35897 Mdot
.612 .35901 Mdot
.612 .36366 Mdot
.612 .36518 Mdot
.612 .36543 Mdot
.612 .36557 Mdot
.612 .36606 Mdot
.612 .36821 Mdot
.612 .36916 Mdot
.612 .37013 Mdot
.612 .37123 Mdot
.612 .37304 Mdot
.612 .3738 Mdot
.612 .37389 Mdot
.612 .37453 Mdot
.612 .37529 Mdot
.612 .37604 Mdot
.614 .0167 Mdot
.614 .01716 Mdot
.614 .01771 Mdot
.614 .01805 Mdot
.614 .0181 Mdot
.614 .0184 Mdot
.614 .01875 Mdot
.614 .01881 Mdot
.614 .01888 Mdot
.614 .01924 Mdot
.614 .01967 Mdot
.614 .01974 Mdot
.614 .01982 Mdot
.614 .02027 Mdot
.614 .0208 Mdot
.614 .02089 Mdot
.614 .02089 Mdot
.614 .02099 Mdot
.614 .02106 Mdot
.614 .02154 Mdot
.614 .02181 Mdot
.614 .02219 Mdot
.614 .0223 Mdot
.614 .0223 Mdot
.614 .02242 Mdot
.614 .02251 Mdot
.614 .02309 Mdot
.614 .02343 Mdot
.614 .0239 Mdot
.614 .02403 Mdot
.614 .02403 Mdot
.614 .02418 Mdot
.614 .02429 Mdot
.614 .025 Mdot
.614 .02508 Mdot
.614 .02541 Mdot
.614 .02599 Mdot
.614 .02615 Mdot
.614 .02615 Mdot
.614 .02633 Mdot
.614 .02647 Mdot
.614 .02708 Mdot
.614 .02713 Mdot
.614 .02727 Mdot
.614 .02735 Mdot
.614 .02744 Mdot
.614 .02785 Mdot
.614 .02815 Mdot
.614 .02856 Mdot
.614 .02876 Mdot
.614 .02876 Mdot
.614 .02888 Mdot
.614 .02898 Mdot
.614 .02915 Mdot
.614 .0299 Mdot
.614 .02996 Mdot
.614 .03013 Mdot
.614 .03023 Mdot
.614 .03034 Mdot
.614 .03034 Mdot
.614 .03085 Mdot
.614 .03121 Mdot
.614 .03172 Mdot
.614 .03196 Mdot
.614 .03196 Mdot
.614 .03197 Mdot
.614 .03211 Mdot
.614 .03224 Mdot
.614 .03244 Mdot
.614 .03247 Mdot
.614 .03318 Mdot
.614 .03336 Mdot
.614 .03344 Mdot
.614 .0335 Mdot
.614 .03365 Mdot
.614 .03376 Mdot
.614 .0339 Mdot
.614 .03391 Mdot
.614 .03401 Mdot
.614 .03453 Mdot
.614 .03477 Mdot
.614 .03498 Mdot
.614 .0351 Mdot
.614 .03559 Mdot
.614 .03589 Mdot
.614 .03589 Mdot
.614 .0359 Mdot
.614 .03607 Mdot
.614 .03623 Mdot
.614 .03648 Mdot
.614 .03652 Mdot
.614 .03739 Mdot
.614 .03761 Mdot
.614 .03765 Mdot
.614 .0377 Mdot
.614 .03775 Mdot
.614 .03778 Mdot
.614 .03796 Mdot
.614 .03811 Mdot
.614 .03827 Mdot
.614 .03828 Mdot
.614 .03832 Mdot
.614 .03841 Mdot
.614 .03904 Mdot
.614 .03934 Mdot
.614 .03956 Mdot
.614 .0396 Mdot
.614 .03974 Mdot
.614 .04035 Mdot
.614 .04072 Mdot
.614 .04072 Mdot
.614 .04073 Mdot
.614 .04094 Mdot
.614 .04114 Mdot
.614 .04145 Mdot
.614 .04149 Mdot
.614 .04224 Mdot
.614 .04253 Mdot
.614 .04256 Mdot
.614 .04283 Mdot
.614 .04284 Mdot
.614 .04288 Mdot
.614 .04295 Mdot
.614 .043 Mdot
.614 .04304 Mdot
.614 .04326 Mdot
.614 .04344 Mdot
.614 .04365 Mdot
.614 .04366 Mdot
.614 .0437 Mdot
.614 .04381 Mdot
.614 .04459 Mdot
.614 .04496 Mdot
.614 .04523 Mdot
.614 .04527 Mdot
.614 .04545 Mdot
.614 .0462 Mdot
.614 .04664 Mdot
.614 .04665 Mdot
.614 .04666 Mdot
.614 .04692 Mdot
.614 .04716 Mdot
.614 .04754 Mdot
.614 .04755 Mdot
.614 .0476 Mdot
.614 .04852 Mdot
.614 .04887 Mdot
.614 .04891 Mdot
.614 .04911 Mdot
.614 .04925 Mdot
.614 .04925 Mdot
.614 .0493 Mdot
.614 .04938 Mdot
.614 .04945 Mdot
.614 .0495 Mdot
.614 .04977 Mdot
.614 .04999 Mdot
.614 .05024 Mdot
.614 .05026 Mdot
.614 .05026 Mdot
.614 .0503 Mdot
.614 .05044 Mdot
.614 .0514 Mdot
.614 .05186 Mdot
.614 .05218 Mdot
.614 .05223 Mdot
.614 .05246 Mdot
.614 .05249 Mdot
.614 .05305 Mdot
.614 .05328 Mdot
.614 .0533 Mdot
.614 .05337 Mdot
.614 .05371 Mdot
.614 .05392 Mdot
.614 .05393 Mdot
.614 .05394 Mdot
.614 .05426 Mdot
.614 .05456 Mdot
.614 .05476 Mdot
.614 .05503 Mdot
.614 .05504 Mdot
.614 .0551 Mdot
.614 .05554 Mdot
.614 .05606 Mdot
.614 .05622 Mdot
.614 .05666 Mdot
.614 .05666 Mdot
.614 .05671 Mdot
.614 .05695 Mdot
.614 .05712 Mdot
.614 .05712 Mdot
.614 .05718 Mdot
.614 .05729 Mdot
.614 .05737 Mdot
.614 .05743 Mdot
.614 .05767 Mdot
.614 .05768 Mdot
.614 .05776 Mdot
.614 .05803 Mdot
.614 .0583 Mdot
.614 .05834 Mdot
.614 .05836 Mdot
.614 .05837 Mdot
.614 .05842 Mdot
.614 .05859 Mdot
.614 .05929 Mdot
.614 .05976 Mdot
.614 .06003 Mdot
.614 .06032 Mdot
.614 .06068 Mdot
.614 .06073 Mdot
.614 .06079 Mdot
.614 .06098 Mdot
.614 .06106 Mdot
.614 .0611 Mdot
.614 .06171 Mdot
.614 .0618 Mdot
.614 .06207 Mdot
.614 .06209 Mdot
.614 .06219 Mdot
.614 .06261 Mdot
.614 .06286 Mdot
.614 .06287 Mdot
.614 .06289 Mdot
.614 .063 Mdot
.614 .06309 Mdot
.614 .06328 Mdot
.614 .06365 Mdot
.614 .06385 Mdot
.614 .06389 Mdot
.614 .06422 Mdot
.614 .06423 Mdot
.614 .0643 Mdot
.614 .06481 Mdot
.614 .06484 Mdot
.614 .06549 Mdot
.614 .06569 Mdot
.614 .06622 Mdot
.614 .06623 Mdot
.614 .06628 Mdot
.614 .06641 Mdot
.614 .06658 Mdot
.614 .06679 Mdot
.614 .06679 Mdot
.614 .06687 Mdot
.614 .06699 Mdot
.614 .06709 Mdot
.614 .06717 Mdot
.614 .0673 Mdot
.614 .06747 Mdot
.614 .06748 Mdot
.614 .06758 Mdot
.614 .06791 Mdot
.614 .06824 Mdot
.614 .06829 Mdot
.614 .06831 Mdot
.614 .06832 Mdot
.614 .06838 Mdot
.614 .06859 Mdot
.614 .06899 Mdot
.614 .069 Mdot
.614 .06938 Mdot
.614 .06946 Mdot
.614 .06954 Mdot
.614 .06962 Mdot
.614 .07004 Mdot
.614 .07013 Mdot
.614 .07037 Mdot
.614 .07072 Mdot
.614 .07098 Mdot
.614 .07116 Mdot
.614 .07122 Mdot
.614 .07129 Mdot
.614 .07163 Mdot
.614 .07168 Mdot
.614 .07177 Mdot
.614 .07242 Mdot
.614 .07253 Mdot
.614 .07287 Mdot
.614 .07289 Mdot
.614 .07301 Mdot
.614 .07353 Mdot
.614 .07384 Mdot
.614 .07385 Mdot
.614 .07387 Mdot
.614 .07401 Mdot
.614 .07412 Mdot
.614 .07435 Mdot
.614 .07461 Mdot
.614 .0748 Mdot
.614 .07485 Mdot
.614 .07493 Mdot
.614 .07505 Mdot
.614 .0751 Mdot
.614 .07551 Mdot
.614 .07552 Mdot
.614 .07561 Mdot
.614 .07623 Mdot
.614 .07627 Mdot
.614 .07706 Mdot
.614 .07731 Mdot
.614 .07793 Mdot
.614 .07797 Mdot
.614 .07797 Mdot
.614 .07804 Mdot
.614 .0782 Mdot
.614 .07841 Mdot
.614 .0785 Mdot
.614 .07866 Mdot
.614 .07866 Mdot
.614 .07876 Mdot
.614 .07891 Mdot
.614 .07903 Mdot
.614 .07913 Mdot
.614 .07918 Mdot
.614 .07929 Mdot
.614 .0795 Mdot
.614 .07951 Mdot
.614 .07963 Mdot
.614 .07978 Mdot
.614 .08004 Mdot
.614 .08044 Mdot
.614 .0805 Mdot
.614 .08053 Mdot
.614 .08054 Mdot
.614 .08062 Mdot
.614 .08088 Mdot
.614 .08136 Mdot
.614 .08138 Mdot
.614 .08185 Mdot
.614 .08194 Mdot
.614 .08205 Mdot
.614 .08214 Mdot
.614 .08265 Mdot
.614 .08276 Mdot
.614 .08301 Mdot
.614 .08305 Mdot
.614 .08349 Mdot
.614 .08371 Mdot
.614 .08381 Mdot
.614 .08403 Mdot
.614 .0841 Mdot
.614 .08419 Mdot
.614 .0846 Mdot
.614 .08466 Mdot
.614 .08478 Mdot
.614 .08532 Mdot
.614 .08558 Mdot
.614 .08559 Mdot
.614 .08571 Mdot
.614 .08613 Mdot
.614 .08616 Mdot
.614 .0863 Mdot
.614 .08694 Mdot
.614 .08732 Mdot
.614 .08733 Mdot
.614 .08736 Mdot
.614 .08753 Mdot
.614 .08767 Mdot
.614 .08795 Mdot
.614 .08827 Mdot
.614 .08836 Mdot
.614 .0885 Mdot
.614 .08856 Mdot
.614 .08866 Mdot
.614 .08881 Mdot
.614 .08887 Mdot
.614 .08937 Mdot
.614 .08938 Mdot
.614 .08949 Mdot
.614 .08974 Mdot
.614 .09025 Mdot
.614 .09031 Mdot
.614 .09037 Mdot
.614 .09128 Mdot
.614 .09158 Mdot
.614 .0918 Mdot
.614 .09224 Mdot
.614 .09234 Mdot
.614 .09239 Mdot
.614 .09239 Mdot
.614 .09247 Mdot
.614 .09267 Mdot
.614 .09283 Mdot
.614 .09293 Mdot
.614 .09304 Mdot
.614 .09324 Mdot
.614 .09324 Mdot
.614 .09336 Mdot
.614 .09355 Mdot
.614 .09369 Mdot
.614 .09382 Mdot
.614 .09388 Mdot
.614 .09402 Mdot
.614 .09427 Mdot
.614 .09429 Mdot
.614 .09443 Mdot
.614 .09462 Mdot
.614 .09493 Mdot
.614 .09543 Mdot
.614 .09543 Mdot
.614 .0955 Mdot
.614 .09553 Mdot
.614 .09555 Mdot
.614 .09565 Mdot
.614 .09581 Mdot
.614 .09596 Mdot
.614 .09651 Mdot
.614 .09656 Mdot
.614 .09658 Mdot
.614 .09716 Mdot
.614 .09727 Mdot
.614 .0974 Mdot
.614 .09751 Mdot
.614 .09814 Mdot
.614 .09827 Mdot
.614 .09858 Mdot
.614 .09864 Mdot
.614 .09917 Mdot
.614 .09944 Mdot
.614 .09956 Mdot
.614 .09984 Mdot
.614 .09992 Mdot
.614 .10004 Mdot
.614 .10054 Mdot
.614 .10061 Mdot
.614 .10075 Mdot
.614 .10141 Mdot
.614 .10173 Mdot
.614 .10174 Mdot
.614 .1019 Mdot
.614 .10241 Mdot
.614 .10245 Mdot
.614 .10262 Mdot
.614 .1034 Mdot
.614 .10388 Mdot
.614 .10389 Mdot
.614 .10392 Mdot
.614 .10413 Mdot
.614 .1043 Mdot
.614 .10465 Mdot
.614 .10503 Mdot
.614 .10516 Mdot
.614 .10533 Mdot
.614 .1054 Mdot
.614 .10552 Mdot
.614 .1057 Mdot
.614 .10578 Mdot
.614 .10639 Mdot
.614 .10641 Mdot
.614 .10654 Mdot
.614 .10684 Mdot
.614 .10748 Mdot
.614 .10755 Mdot
.614 .10762 Mdot
.614 .10874 Mdot
.614 .10911 Mdot
.614 .10938 Mdot
.614 .10991 Mdot
.614 .11004 Mdot
.614 .1101 Mdot
.614 .1101 Mdot
.614 .1102 Mdot
.614 .11045 Mdot
.614 .11063 Mdot
.614 .11076 Mdot
.614 .1109 Mdot
.614 .11114 Mdot
.614 .11114 Mdot
.614 .11129 Mdot
.614 .11153 Mdot
.614 .1117 Mdot
.614 .11186 Mdot
.614 .11193 Mdot
.614 .1121 Mdot
.614 .11241 Mdot
.614 .11243 Mdot
.614 .11261 Mdot
.614 .11284 Mdot
.614 .11322 Mdot
.614 .11343 Mdot
.614 .11383 Mdot
.614 .11383 Mdot
.614 .11392 Mdot
.614 .11396 Mdot
.614 .11398 Mdot
.614 .1141 Mdot
.614 .1143 Mdot
.614 .11449 Mdot
.614 .11516 Mdot
.614 .11522 Mdot
.614 .11524 Mdot
.614 .11595 Mdot
.614 .11609 Mdot
.614 .11625 Mdot
.614 .11639 Mdot
.614 .11716 Mdot
.614 .11732 Mdot
.614 .11771 Mdot
.614 .11777 Mdot
.614 .11843 Mdot
.614 .11876 Mdot
.614 .11891 Mdot
.614 .11925 Mdot
.614 .11935 Mdot
.614 .11949 Mdot
.614 .12011 Mdot
.614 .1202 Mdot
.614 .12036 Mdot
.614 .12118 Mdot
.614 .12157 Mdot
.614 .12159 Mdot
.614 .12178 Mdot
.614 .1224 Mdot
.614 .12245 Mdot
.614 .12267 Mdot
.614 .12362 Mdot
.614 .12421 Mdot
.614 .12422 Mdot
.614 .12426 Mdot
.614 .12452 Mdot
.614 .12473 Mdot
.614 .12516 Mdot
.614 .12563 Mdot
.614 .12578 Mdot
.614 .12598 Mdot
.614 .12608 Mdot
.614 .12623 Mdot
.614 .12645 Mdot
.614 .12654 Mdot
.614 .12729 Mdot
.614 .12732 Mdot
.614 .12748 Mdot
.614 .12785 Mdot
.614 .12863 Mdot
.614 .12871 Mdot
.614 .1288 Mdot
.614 .13017 Mdot
.614 .13063 Mdot
.614 .13097 Mdot
.614 .13161 Mdot
.614 .13178 Mdot
.614 .13184 Mdot
.614 .13185 Mdot
.614 .13197 Mdot
.614 .13228 Mdot
.614 .1325 Mdot
.614 .13266 Mdot
.614 .13283 Mdot
.614 .13313 Mdot
.614 .13313 Mdot
.614 .13331 Mdot
.614 .1336 Mdot
.614 .13381 Mdot
.614 .134 Mdot
.614 .13409 Mdot
.614 .1343 Mdot
.614 .13468 Mdot
.614 .13471 Mdot
.614 .13493 Mdot
.614 .13521 Mdot
.614 .13568 Mdot
.614 .13594 Mdot
.614 .13643 Mdot
.614 .13643 Mdot
.614 .13654 Mdot
.614 .13659 Mdot
.614 .13661 Mdot
.614 .13676 Mdot
.614 .13701 Mdot
.614 .13724 Mdot
.614 .13807 Mdot
.614 .13814 Mdot
.614 .13816 Mdot
.614 .13903 Mdot
.614 .1392 Mdot
.614 .1394 Mdot
.614 .13957 Mdot
.614 .14052 Mdot
.614 .14072 Mdot
.614 .14119 Mdot
.614 .14127 Mdot
.614 .14208 Mdot
.614 .14248 Mdot
.614 .14266 Mdot
.614 .14308 Mdot
.614 .14321 Mdot
.614 .14338 Mdot
.614 .14414 Mdot
.614 .14425 Mdot
.614 .14445 Mdot
.614 .14545 Mdot
.614 .14594 Mdot
.614 .14595 Mdot
.614 .14619 Mdot
.614 .14695 Mdot
.614 .14701 Mdot
.614 .14728 Mdot
.614 .14845 Mdot
.614 .14917 Mdot
.614 .14919 Mdot
.614 .14924 Mdot
.614 .14955 Mdot
.614 .14981 Mdot
.614 .15034 Mdot
.614 .15092 Mdot
.614 .1511 Mdot
.614 .15135 Mdot
.614 .15147 Mdot
.614 .15165 Mdot
.614 .15192 Mdot
.614 .15204 Mdot
.614 .15295 Mdot
.614 .15299 Mdot
.614 .15319 Mdot
.614 .15364 Mdot
.614 .1546 Mdot
.614 .1547 Mdot
.614 .15481 Mdot
.614 .1565 Mdot
.614 .15706 Mdot
.614 .15747 Mdot
.614 .15827 Mdot
.614 .15847 Mdot
.614 .15855 Mdot
.614 .15856 Mdot
.614 .15871 Mdot
.614 .15908 Mdot
.614 .15936 Mdot
.614 .15955 Mdot
.614 .15976 Mdot
.614 .16013 Mdot
.614 .16013 Mdot
.614 .16035 Mdot
.614 .1607 Mdot
.614 .16097 Mdot
.614 .1612 Mdot
.614 .16131 Mdot
.614 .16157 Mdot
.614 .16203 Mdot
.614 .16207 Mdot
.614 .16234 Mdot
.614 .16268 Mdot
.614 .16325 Mdot
.614 .16357 Mdot
.614 .16418 Mdot
.614 .16418 Mdot
.614 .16432 Mdot
.614 .16438 Mdot
.614 .1644 Mdot
.614 .16458 Mdot
.614 .16489 Mdot
.614 .16517 Mdot
.614 .16619 Mdot
.614 .16628 Mdot
.614 .16631 Mdot
.614 .16738 Mdot
.614 .16758 Mdot
.614 .16783 Mdot
.614 .16804 Mdot
.614 .1692 Mdot
.614 .16945 Mdot
.614 .17002 Mdot
.614 .17012 Mdot
.614 .17112 Mdot
.614 .17161 Mdot
.614 .17183 Mdot
.614 .17235 Mdot
.614 .1725 Mdot
.614 .17271 Mdot
.614 .17364 Mdot
.614 .17378 Mdot
.614 .17403 Mdot
.614 .17526 Mdot
.614 .17585 Mdot
.614 .17588 Mdot
.614 .17616 Mdot
.614 .1771 Mdot
.614 .17718 Mdot
.614 .17751 Mdot
.614 .17894 Mdot
.614 .17982 Mdot
.614 .17985 Mdot
.614 .17991 Mdot
.614 .1803 Mdot
.614 .18061 Mdot
.614 .18126 Mdot
.614 .18197 Mdot
.614 .1822 Mdot
.614 .18251 Mdot
.614 .18265 Mdot
.614 .18287 Mdot
.614 .18321 Mdot
.614 .18335 Mdot
.614 .18447 Mdot
.614 .18452 Mdot
.614 .18477 Mdot
.614 .18531 Mdot
.614 .18649 Mdot
.614 .18662 Mdot
.614 .18675 Mdot
.614 .18883 Mdot
.614 .18951 Mdot
.614 .19002 Mdot
.614 .191 Mdot
.614 .19125 Mdot
.614 .19134 Mdot
.614 .19135 Mdot
.614 .19154 Mdot
.614 .192 Mdot
.614 .19234 Mdot
.614 .19257 Mdot
.614 .19283 Mdot
.614 .19328 Mdot
.614 .19328 Mdot
.614 .19355 Mdot
.614 .19399 Mdot
.614 .19432 Mdot
.614 .1946 Mdot
.614 .19473 Mdot
.614 .19505 Mdot
.614 .19562 Mdot
.614 .19566 Mdot
.614 .19599 Mdot
.614 .19642 Mdot
.614 .19712 Mdot
.614 .19751 Mdot
.614 .19825 Mdot
.614 .19826 Mdot
.614 .19843 Mdot
.614 .1985 Mdot
.614 .19853 Mdot
.614 .19875 Mdot
.614 .19913 Mdot
.614 .19948 Mdot
.614 .20073 Mdot
.614 .20083 Mdot
.614 .20087 Mdot
.614 .20219 Mdot
.614 .20244 Mdot
.614 .20274 Mdot
.614 .203 Mdot
.614 .20442 Mdot
.614 .20473 Mdot
.614 .20543 Mdot
.614 .20555 Mdot
.614 .20677 Mdot
.614 .20738 Mdot
.614 .20766 Mdot
.614 .20829 Mdot
.614 .20848 Mdot
.614 .20874 Mdot
.614 .20988 Mdot
.614 .21005 Mdot
.614 .21036 Mdot
.614 .21187 Mdot
.614 .21259 Mdot
.614 .21262 Mdot
.614 .21297 Mdot
.614 .21413 Mdot
.614 .21422 Mdot
.614 .21462 Mdot
.614 .21639 Mdot
.614 .21747 Mdot
.614 .2175 Mdot
.614 .21757 Mdot
.614 .21805 Mdot
.614 .21844 Mdot
.614 .21923 Mdot
.614 .2201 Mdot
.614 .22038 Mdot
.614 .22076 Mdot
.614 .22094 Mdot
.614 .22121 Mdot
.614 .22162 Mdot
.614 .2218 Mdot
.614 .22318 Mdot
.614 .22323 Mdot
.614 .22354 Mdot
.614 .22421 Mdot
.614 .22566 Mdot
.614 .22581 Mdot
.614 .22598 Mdot
.614 .22852 Mdot
.614 .22937 Mdot
.614 .22999 Mdot
.614 .23119 Mdot
.614 .2315 Mdot
.614 .23162 Mdot
.614 .23163 Mdot
.614 .23185 Mdot
.614 .23242 Mdot
.614 .23284 Mdot
.614 .23312 Mdot
.614 .23344 Mdot
.614 .23399 Mdot
.614 .234 Mdot
.614 .23433 Mdot
.614 .23487 Mdot
.614 .23526 Mdot
.614 .23562 Mdot
.614 .23578 Mdot
.614 .23617 Mdot
.614 .23687 Mdot
.614 .23692 Mdot
.614 .23733 Mdot
.614 .23784 Mdot
.614 .23871 Mdot
.614 .23919 Mdot
.614 .2401 Mdot
.614 .24011 Mdot
.614 .24031 Mdot
.614 .2404 Mdot
.614 .24044 Mdot
.614 .24071 Mdot
.614 .24118 Mdot
.614 .2416 Mdot
.614 .24314 Mdot
.614 .24327 Mdot
.614 .24331 Mdot
.614 .24493 Mdot
.614 .24524 Mdot
.614 .2456 Mdot
.614 .24593 Mdot
.614 .24767 Mdot
.614 .24805 Mdot
.614 .24892 Mdot
.614 .24906 Mdot
.614 .25056 Mdot
.614 .2513 Mdot
.614 .25165 Mdot
.614 .25242 Mdot
.614 .25265 Mdot
.614 .25297 Mdot
.614 .25438 Mdot
.614 .25459 Mdot
.614 .25496 Mdot
.614 .25682 Mdot
.614 .25771 Mdot
.614 .25774 Mdot
.614 .25817 Mdot
.614 .25959 Mdot
.614 .25971 Mdot
.614 .2602 Mdot
.614 .26237 Mdot
.614 .2637 Mdot
.614 .26373 Mdot
.614 .26382 Mdot
.614 .26441 Mdot
.614 .26489 Mdot
.614 .26586 Mdot
.614 .26693 Mdot
.614 .26727 Mdot
.614 .26774 Mdot
.614 .26795 Mdot
.614 .26829 Mdot
.614 .2688 Mdot
.614 .26901 Mdot
.614 .27071 Mdot
.614 .27077 Mdot
.614 .27115 Mdot
.614 .27198 Mdot
.614 .27375 Mdot
.614 .27394 Mdot
.614 .27414 Mdot
.614 .27727 Mdot
.614 .27831 Mdot
.614 .27907 Mdot
.614 .28055 Mdot
.614 .28092 Mdot
.614 .28107 Mdot
.614 .28108 Mdot
.614 .28136 Mdot
.614 .28205 Mdot
.614 .28257 Mdot
.614 .28292 Mdot
.614 .28331 Mdot
.614 .28399 Mdot
.614 .28399 Mdot
.614 .2844 Mdot
.614 .28506 Mdot
.614 .28555 Mdot
.614 .28598 Mdot
.614 .28618 Mdot
.614 .28666 Mdot
.614 .28752 Mdot
.614 .28758 Mdot
.614 .28808 Mdot
.614 .28872 Mdot
.614 .28978 Mdot
.614 .29037 Mdot
.614 .29149 Mdot
.614 .2915 Mdot
.614 .29175 Mdot
.614 .29186 Mdot
.614 .29191 Mdot
.614 .29224 Mdot
.614 .29281 Mdot
.614 .29333 Mdot
.614 .29522 Mdot
.614 .29538 Mdot
.614 .29543 Mdot
.614 .29742 Mdot
.614 .2978 Mdot
.614 .29825 Mdot
.614 .29865 Mdot
.614 .30079 Mdot
.614 .30125 Mdot
.614 .30232 Mdot
.614 .30249 Mdot
.614 .30434 Mdot
.614 .30525 Mdot
.614 .30567 Mdot
.614 .30662 Mdot
.614 .3069 Mdot
.614 .3073 Mdot
.614 .30902 Mdot
.614 .30928 Mdot
.614 .30974 Mdot
.614 .31202 Mdot
.614 .31311 Mdot
.614 .31316 Mdot
.614 .31368 Mdot
.614 .31543 Mdot
.614 .31557 Mdot
.614 .31617 Mdot
.614 .31884 Mdot
.614 .32047 Mdot
.614 .32051 Mdot
.614 .32062 Mdot
.614 .32134 Mdot
.614 .32193 Mdot
.614 .32312 Mdot
.614 .32444 Mdot
.614 .32486 Mdot
.614 .32543 Mdot
.614 .32569 Mdot
.614 .32611 Mdot
.614 .32673 Mdot
.614 .32699 Mdot
.614 .32907 Mdot
.614 .32915 Mdot
.614 .32961 Mdot
.614 .33063 Mdot
.614 .33281 Mdot
.614 .33305 Mdot
.614 .33329 Mdot
.614 .33714 Mdot
.614 .3384 Mdot
.614 .33934 Mdot
.614 .34116 Mdot
.614 .34162 Mdot
.614 .3418 Mdot
.614 .34181 Mdot
.614 .34215 Mdot
.614 .34301 Mdot
.614 .34364 Mdot
.614 .34407 Mdot
.614 .34455 Mdot
.614 .34538 Mdot
.614 .34539 Mdot
.614 .34589 Mdot
.614 .3467 Mdot
.614 .3473 Mdot
.614 .34783 Mdot
.614 .34807 Mdot
.614 .34866 Mdot
.614 .34972 Mdot
.614 .34979 Mdot
.614 .35041 Mdot
.614 .35119 Mdot
.614 .3525 Mdot
.614 .35322 Mdot
.614 .35459 Mdot
.614 .3546 Mdot
.614 .35492 Mdot
.614 .35505 Mdot
.614 .35511 Mdot
.614 .35552 Mdot
.614 .35621 Mdot
.614 .35686 Mdot
.614 .35917 Mdot
.614 .35937 Mdot
.614 .35943 Mdot
.614 .36188 Mdot
.614 .36234 Mdot
.614 .36289 Mdot
.614 .36338 Mdot
.614 .36601 Mdot
.614 .36658 Mdot
.614 .36789 Mdot
.614 .36811 Mdot
.614 .37037 Mdot
.614 .37149 Mdot
.614 .372 Mdot
.614 .37317 Mdot
.614 .37352 Mdot
.614 .374 Mdot
.614 .37612 Mdot
.614 .37644 Mdot
.614 .37701 Mdot
.616 .01472 Mdot
.616 .01472 Mdot
.616 .01473 Mdot
.616 .01473 Mdot
.616 .01473 Mdot
.616 .01474 Mdot
.616 .01474 Mdot
.616 .01475 Mdot
.616 .01475 Mdot
.616 .01476 Mdot
.616 .01478 Mdot
.616 .01479 Mdot
.616 .01481 Mdot
.616 .01483 Mdot
.616 .01485 Mdot
.616 .01489 Mdot
.616 .01493 Mdot
.616 .01497 Mdot
.616 .01503 Mdot
.616 .01511 Mdot
.616 .0152 Mdot
.616 .01531 Mdot
.616 .01545 Mdot
.616 .01562 Mdot
.616 .01583 Mdot
.616 .01609 Mdot
.616 .01641 Mdot
.616 .0168 Mdot
.616 .01729 Mdot
.616 .01783 Mdot
.616 .01788 Mdot
.616 .01816 Mdot
.616 .01845 Mdot
.616 .01856 Mdot
.616 .01862 Mdot
.616 .01896 Mdot
.616 .01931 Mdot
.616 .01945 Mdot
.616 .01952 Mdot
.616 .01982 Mdot
.616 .01995 Mdot
.616 .02038 Mdot
.616 .02055 Mdot
.616 .02064 Mdot
.616 .02067 Mdot
.616 .021 Mdot
.616 .02116 Mdot
.616 .02169 Mdot
.616 .0219 Mdot
.616 .02201 Mdot
.616 .02205 Mdot
.616 .02246 Mdot
.616 .02265 Mdot
.616 .02331 Mdot
.616 .02357 Mdot
.616 .02371 Mdot
.616 .02375 Mdot
.616 .02401 Mdot
.616 .02426 Mdot
.616 .02436 Mdot
.616 .02436 Mdot
.616 .02449 Mdot
.616 .0253 Mdot
.616 .02562 Mdot
.616 .02579 Mdot
.616 .02584 Mdot
.616 .02597 Mdot
.616 .02617 Mdot
.616 .02648 Mdot
.616 .0266 Mdot
.616 .0266 Mdot
.616 .02676 Mdot
.616 .02677 Mdot
.616 .02695 Mdot
.616 .02776 Mdot
.616 .02815 Mdot
.616 .02836 Mdot
.616 .02843 Mdot
.616 .02858 Mdot
.616 .02882 Mdot
.616 .02896 Mdot
.616 .0292 Mdot
.616 .02936 Mdot
.616 .02936 Mdot
.616 .02956 Mdot
.616 .02957 Mdot
.616 .02979 Mdot
.616 .03078 Mdot
.616 .03127 Mdot
.616 .03153 Mdot
.616 .03161 Mdot
.616 .03161 Mdot
.616 .0318 Mdot
.616 .03198 Mdot
.616 .0321 Mdot
.616 .03227 Mdot
.616 .03243 Mdot
.616 .03257 Mdot
.616 .03275 Mdot
.616 .03275 Mdot
.616 .033 Mdot
.616 .03302 Mdot
.616 .03329 Mdot
.616 .03407 Mdot
.616 .03451 Mdot
.616 .03484 Mdot
.616 .03511 Mdot
.616 .03543 Mdot
.616 .03553 Mdot
.616 .03553 Mdot
.616 .03577 Mdot
.616 .03599 Mdot
.616 .03613 Mdot
.616 .03634 Mdot
.616 .03654 Mdot
.616 .03655 Mdot
.616 .03664 Mdot
.616 .03666 Mdot
.616 .03671 Mdot
.616 .03691 Mdot
.616 .03694 Mdot
.616 .03694 Mdot
.616 .03725 Mdot
.616 .03726 Mdot
.616 .0376 Mdot
.616 .03827 Mdot
.616 .03843 Mdot
.616 .03857 Mdot
.616 .0391 Mdot
.616 .03929 Mdot
.616 .03951 Mdot
.616 .0397 Mdot
.616 .03984 Mdot
.616 .04023 Mdot
.616 .04035 Mdot
.616 .04035 Mdot
.616 .04065 Mdot
.616 .04093 Mdot
.616 .0411 Mdot
.616 .0411 Mdot
.616 .04122 Mdot
.616 .04136 Mdot
.616 .04161 Mdot
.616 .04161 Mdot
.616 .04173 Mdot
.616 .04175 Mdot
.616 .04181 Mdot
.616 .04206 Mdot
.616 .04209 Mdot
.616 .04209 Mdot
.616 .04247 Mdot
.616 .04249 Mdot
.616 .04291 Mdot
.616 .04373 Mdot
.616 .04393 Mdot
.616 .0441 Mdot
.616 .04476 Mdot
.616 .04499 Mdot
.616 .04527 Mdot
.616 .0453 Mdot
.616 .0453 Mdot
.616 .04549 Mdot
.616 .04567 Mdot
.616 .04615 Mdot
.616 .0463 Mdot
.616 .0463 Mdot
.616 .04667 Mdot
.616 .04701 Mdot
.616 .04722 Mdot
.616 .04723 Mdot
.616 .04737 Mdot
.616 .04754 Mdot
.616 .04783 Mdot
.616 .04785 Mdot
.616 .04785 Mdot
.616 .04794 Mdot
.616 .048 Mdot
.616 .04803 Mdot
.616 .04809 Mdot
.616 .0484 Mdot
.616 .04844 Mdot
.616 .04845 Mdot
.616 .04891 Mdot
.616 .04894 Mdot
.616 .04945 Mdot
.616 .04966 Mdot
.616 .05046 Mdot
.616 .0507 Mdot
.616 .05092 Mdot
.616 .05173 Mdot
.616 .05177 Mdot
.616 .05202 Mdot
.616 .05236 Mdot
.616 .05239 Mdot
.616 .05239 Mdot
.616 .05255 Mdot
.616 .05263 Mdot
.616 .05285 Mdot
.616 .05316 Mdot
.616 .05345 Mdot
.616 .05363 Mdot
.616 .05363 Mdot
.616 .05394 Mdot
.616 .05408 Mdot
.616 .0545 Mdot
.616 .05476 Mdot
.616 .05477 Mdot
.616 .05494 Mdot
.616 .05515 Mdot
.616 .05529 Mdot
.616 .05551 Mdot
.616 .05553 Mdot
.616 .05554 Mdot
.616 .05554 Mdot
.616 .0556 Mdot
.616 .0556 Mdot
.616 .05565 Mdot
.616 .05572 Mdot
.616 .05575 Mdot
.616 .05581 Mdot
.616 .05584 Mdot
.616 .05619 Mdot
.616 .05622 Mdot
.616 .05627 Mdot
.616 .05627 Mdot
.616 .05672 Mdot
.616 .05685 Mdot
.616 .05688 Mdot
.616 .05741 Mdot
.616 .0575 Mdot
.616 .05773 Mdot
.616 .05777 Mdot
.616 .05829 Mdot
.616 .05857 Mdot
.616 .05876 Mdot
.616 .05905 Mdot
.616 .05931 Mdot
.616 .05932 Mdot
.616 .05994 Mdot
.616 .06032 Mdot
.616 .06036 Mdot
.616 .06067 Mdot
.616 .06109 Mdot
.616 .06113 Mdot
.616 .06113 Mdot
.616 .06133 Mdot
.616 .06143 Mdot
.616 .0617 Mdot
.616 .06203 Mdot
.616 .06208 Mdot
.616 .06234 Mdot
.616 .06243 Mdot
.616 .06264 Mdot
.616 .06266 Mdot
.616 .06266 Mdot
.616 .06286 Mdot
.616 .06288 Mdot
.616 .06304 Mdot
.616 .06321 Mdot
.616 .06373 Mdot
.616 .06404 Mdot
.616 .06406 Mdot
.616 .06427 Mdot
.616 .06453 Mdot
.616 .06471 Mdot
.616 .0648 Mdot
.616 .06497 Mdot
.616 .065 Mdot
.616 .06501 Mdot
.616 .06501 Mdot
.616 .06504 Mdot
.616 .06508 Mdot
.616 .06509 Mdot
.616 .06515 Mdot
.616 .06523 Mdot
.616 .06527 Mdot
.616 .06534 Mdot
.616 .06538 Mdot
.616 .06581 Mdot
.616 .06585 Mdot
.616 .06591 Mdot
.616 .06591 Mdot
.616 .06615 Mdot
.616 .06618 Mdot
.616 .06632 Mdot
.616 .06634 Mdot
.616 .06647 Mdot
.616 .06662 Mdot
.616 .06666 Mdot
.616 .06732 Mdot
.616 .06735 Mdot
.616 .06743 Mdot
.616 .06771 Mdot
.616 .06776 Mdot
.616 .0684 Mdot
.616 .06857 Mdot
.616 .06874 Mdot
.616 .06887 Mdot
.616 .06897 Mdot
.616 .06934 Mdot
.616 .06966 Mdot
.616 .06966 Mdot
.616 .07043 Mdot
.616 .0709 Mdot
.616 .07095 Mdot
.616 .07134 Mdot
.616 .07185 Mdot
.616 .0719 Mdot
.616 .0719 Mdot
.616 .07215 Mdot
.616 .07227 Mdot
.616 .0726 Mdot
.616 .07301 Mdot
.616 .07307 Mdot
.616 .07339 Mdot
.616 .0735 Mdot
.616 .07376 Mdot
.616 .07378 Mdot
.616 .07378 Mdot
.616 .07403 Mdot
.616 .07405 Mdot
.616 .07418 Mdot
.616 .07425 Mdot
.616 .07446 Mdot
.616 .07448 Mdot
.616 .0751 Mdot
.616 .0751 Mdot
.616 .07549 Mdot
.616 .07551 Mdot
.616 .07577 Mdot
.616 .07609 Mdot
.616 .07631 Mdot
.616 .07642 Mdot
.616 .07663 Mdot
.616 .07667 Mdot
.616 .07668 Mdot
.616 .07668 Mdot
.616 .07671 Mdot
.616 .07677 Mdot
.616 .07677 Mdot
.616 .07685 Mdot
.616 .07696 Mdot
.616 .077 Mdot
.616 .07709 Mdot
.616 .07713 Mdot
.616 .07734 Mdot
.616 .07766 Mdot
.616 .07771 Mdot
.616 .07776 Mdot
.616 .07779 Mdot
.616 .07779 Mdot
.616 .07809 Mdot
.616 .07812 Mdot
.616 .07829 Mdot
.616 .07832 Mdot
.616 .07848 Mdot
.616 .07866 Mdot
.616 .07871 Mdot
.616 .07952 Mdot
.616 .07957 Mdot
.616 .07966 Mdot
.616 .08 Mdot
.616 .08007 Mdot
.616 .08086 Mdot
.616 .08107 Mdot
.616 .08127 Mdot
.616 .08143 Mdot
.616 .08156 Mdot
.616 .08201 Mdot
.616 .08241 Mdot
.616 .08241 Mdot
.616 .08292 Mdot
.616 .08335 Mdot
.616 .08394 Mdot
.616 .084 Mdot
.616 .08405 Mdot
.616 .08431 Mdot
.616 .08447 Mdot
.616 .0851 Mdot
.616 .08517 Mdot
.616 .08517 Mdot
.616 .08547 Mdot
.616 .08562 Mdot
.616 .08566 Mdot
.616 .08603 Mdot
.616 .08653 Mdot
.616 .0866 Mdot
.616 .08669 Mdot
.616 .087 Mdot
.616 .08714 Mdot
.616 .08746 Mdot
.616 .08748 Mdot
.616 .08749 Mdot
.616 .08753 Mdot
.616 .08779 Mdot
.616 .08782 Mdot
.616 .08798 Mdot
.616 .08806 Mdot
.616 .08832 Mdot
.616 .08834 Mdot
.616 .08911 Mdot
.616 .08911 Mdot
.616 .08959 Mdot
.616 .08961 Mdot
.616 .08994 Mdot
.616 .09033 Mdot
.616 .09048 Mdot
.616 .09059 Mdot
.616 .09074 Mdot
.616 .091 Mdot
.616 .09104 Mdot
.616 .09105 Mdot
.616 .09105 Mdot
.616 .09109 Mdot
.616 .09116 Mdot
.616 .09117 Mdot
.616 .09127 Mdot
.616 .0914 Mdot
.616 .09146 Mdot
.616 .09156 Mdot
.616 .09161 Mdot
.616 .09187 Mdot
.616 .09227 Mdot
.616 .09232 Mdot
.616 .09238 Mdot
.616 .09242 Mdot
.616 .09243 Mdot
.616 .09279 Mdot
.616 .09283 Mdot
.616 .09304 Mdot
.616 .09305 Mdot
.616 .09307 Mdot
.616 .09308 Mdot
.616 .09327 Mdot
.616 .0935 Mdot
.616 .09355 Mdot
.616 .09456 Mdot
.616 .09461 Mdot
.616 .09473 Mdot
.616 .09515 Mdot
.616 .09523 Mdot
.616 .0962 Mdot
.616 .09641 Mdot
.616 .09646 Mdot
.616 .09672 Mdot
.616 .09691 Mdot
.616 .09707 Mdot
.616 .09763 Mdot
.616 .09811 Mdot
.616 .09812 Mdot
.616 .09874 Mdot
.616 .09928 Mdot
.616 .1 Mdot
.616 .10007 Mdot
.616 .10014 Mdot
.616 .10046 Mdot
.616 .10066 Mdot
.616 .10143 Mdot
.616 .10151 Mdot
.616 .10151 Mdot
.616 .10189 Mdot
.616 .10207 Mdot
.616 .10211 Mdot
.616 .10258 Mdot
.616 .10319 Mdot
.616 .10328 Mdot
.616 .10339 Mdot
.616 .10377 Mdot
.616 .10395 Mdot
.616 .10434 Mdot
.616 .10436 Mdot
.616 .10437 Mdot
.616 .10443 Mdot
.616 .10474 Mdot
.616 .10478 Mdot
.616 .10498 Mdot
.616 .10507 Mdot
.616 .1054 Mdot
.616 .10543 Mdot
.616 .10637 Mdot
.616 .10637 Mdot
.616 .10696 Mdot
.616 .10699 Mdot
.616 .10739 Mdot
.616 .10787 Mdot
.616 .10806 Mdot
.616 .1082 Mdot
.616 .10838 Mdot
.616 .10869 Mdot
.616 .10875 Mdot
.616 .10876 Mdot
.616 .10876 Mdot
.616 .10881 Mdot
.616 .1089 Mdot
.616 .10891 Mdot
.616 .10903 Mdot
.616 .10918 Mdot
.616 .10926 Mdot
.616 .10939 Mdot
.616 .10945 Mdot
.616 .10977 Mdot
.616 .11026 Mdot
.616 .11033 Mdot
.616 .1104 Mdot
.616 .11045 Mdot
.616 .11045 Mdot
.616 .1109 Mdot
.616 .11095 Mdot
.616 .11121 Mdot
.616 .11122 Mdot
.616 .11125 Mdot
.616 .11126 Mdot
.616 .11149 Mdot
.616 .11178 Mdot
.616 .11184 Mdot
.616 .11308 Mdot
.616 .11315 Mdot
.616 .11329 Mdot
.616 .11381 Mdot
.616 .11391 Mdot
.616 .11511 Mdot
.616 .11537 Mdot
.616 .11543 Mdot
.616 .11574 Mdot
.616 .11598 Mdot
.616 .11618 Mdot
.616 .11686 Mdot
.616 .11746 Mdot
.616 .11746 Mdot
.616 .11824 Mdot
.616 .11889 Mdot
.616 .11978 Mdot
.616 .11988 Mdot
.616 .11996 Mdot
.616 .12035 Mdot
.616 .12059 Mdot
.616 .12155 Mdot
.616 .12165 Mdot
.616 .12165 Mdot
.616 .12211 Mdot
.616 .12234 Mdot
.616 .12239 Mdot
.616 .12297 Mdot
.616 .12372 Mdot
.616 .12383 Mdot
.616 .12396 Mdot
.616 .12443 Mdot
.616 .12465 Mdot
.616 .12513 Mdot
.616 .12516 Mdot
.616 .12517 Mdot
.616 .12524 Mdot
.616 .12563 Mdot
.616 .12567 Mdot
.616 .12592 Mdot
.616 .12604 Mdot
.616 .12644 Mdot
.616 .12647 Mdot
.616 .12764 Mdot
.616 .12764 Mdot
.616 .12836 Mdot
.616 .12839 Mdot
.616 .12889 Mdot
.616 .12949 Mdot
.616 .12971 Mdot
.616 .12989 Mdot
.616 .13011 Mdot
.616 .1305 Mdot
.616 .13057 Mdot
.616 .13058 Mdot
.616 .13058 Mdot
.616 .13064 Mdot
.616 .13075 Mdot
.616 .13076 Mdot
.616 .13091 Mdot
.616 .1311 Mdot
.616 .13119 Mdot
.616 .13135 Mdot
.616 .13143 Mdot
.616 .13182 Mdot
.616 .13242 Mdot
.616 .13251 Mdot
.616 .1326 Mdot
.616 .13266 Mdot
.616 .13267 Mdot
.616 .13322 Mdot
.616 .13328 Mdot
.616 .1336 Mdot
.616 .13361 Mdot
.616 .13365 Mdot
.616 .13366 Mdot
.616 .13395 Mdot
.616 .13429 Mdot
.616 .13438 Mdot
.616 .1359 Mdot
.616 .13598 Mdot
.616 .13616 Mdot
.616 .1368 Mdot
.616 .13692 Mdot
.616 .1384 Mdot
.616 .13872 Mdot
.616 .1388 Mdot
.616 .13918 Mdot
.616 .13947 Mdot
.616 .13972 Mdot
.616 .14056 Mdot
.616 .14129 Mdot
.616 .1413 Mdot
.616 .14226 Mdot
.616 .14306 Mdot
.616 .14416 Mdot
.616 .14427 Mdot
.616 .14437 Mdot
.616 .14486 Mdot
.616 .14516 Mdot
.616 .14634 Mdot
.616 .14646 Mdot
.616 .14646 Mdot
.616 .14703 Mdot
.616 .14731 Mdot
.616 .14737 Mdot
.616 .14808 Mdot
.616 .14901 Mdot
.616 .14915 Mdot
.616 .1493 Mdot
.616 .14988 Mdot
.616 .15015 Mdot
.616 .15075 Mdot
.616 .15079 Mdot
.616 .15079 Mdot
.616 .15088 Mdot
.616 .15136 Mdot
.616 .15141 Mdot
.616 .15172 Mdot
.616 .15186 Mdot
.616 .15236 Mdot
.616 .1524 Mdot
.616 .15384 Mdot
.616 .15384 Mdot
.616 .15473 Mdot
.616 .15477 Mdot
.616 .15537 Mdot
.616 .15611 Mdot
.616 .15639 Mdot
.616 .15661 Mdot
.616 .15688 Mdot
.616 .15736 Mdot
.616 .15744 Mdot
.616 .15746 Mdot
.616 .15747 Mdot
.616 .15754 Mdot
.616 .15767 Mdot
.616 .15786 Mdot
.616 .1581 Mdot
.616 .15822 Mdot
.616 .15841 Mdot
.616 .15851 Mdot
.616 .15899 Mdot
.616 .15973 Mdot
.616 .15984 Mdot
.616 .15995 Mdot
.616 .16002 Mdot
.616 .16003 Mdot
.616 .16071 Mdot
.616 .16079 Mdot
.616 .16118 Mdot
.616 .16119 Mdot
.616 .16124 Mdot
.616 .16125 Mdot
.616 .16161 Mdot
.616 .16204 Mdot
.616 .16214 Mdot
.616 .16401 Mdot
.616 .16412 Mdot
.616 .16434 Mdot
.616 .16513 Mdot
.616 .16527 Mdot
.616 .16709 Mdot
.616 .16749 Mdot
.616 .16758 Mdot
.616 .16806 Mdot
.616 .16842 Mdot
.616 .16872 Mdot
.616 .16975 Mdot
.616 .17066 Mdot
.616 .17067 Mdot
.616 .17185 Mdot
.616 .17284 Mdot
.616 .17419 Mdot
.616 .17433 Mdot
.616 .17446 Mdot
.616 .17505 Mdot
.616 .17542 Mdot
.616 .17687 Mdot
.616 .17702 Mdot
.616 .17702 Mdot
.616 .17772 Mdot
.616 .17807 Mdot
.616 .17815 Mdot
.616 .17902 Mdot
.616 .18017 Mdot
.616 .18033 Mdot
.616 .18053 Mdot
.616 .18124 Mdot
.616 .18157 Mdot
.616 .18231 Mdot
.616 .18236 Mdot
.616 .18236 Mdot
.616 .18247 Mdot
.616 .18306 Mdot
.616 .18313 Mdot
.616 .1835 Mdot
.616 .18368 Mdot
.616 .18429 Mdot
.616 .18434 Mdot
.616 .18611 Mdot
.616 .18611 Mdot
.616 .18721 Mdot
.616 .18726 Mdot
.616 .18801 Mdot
.616 .18892 Mdot
.616 .18926 Mdot
.616 .18952 Mdot
.616 .18986 Mdot
.616 .19045 Mdot
.616 .19056 Mdot
.616 .19058 Mdot
.616 .19058 Mdot
.616 .19067 Mdot
.616 .19084 Mdot
.616 .19107 Mdot
.616 .19137 Mdot
.616 .19151 Mdot
.616 .19175 Mdot
.616 .19187 Mdot
.616 .19247 Mdot
.616 .19338 Mdot
.616 .19351 Mdot
.616 .19364 Mdot
.616 .19373 Mdot
.616 .19374 Mdot
.616 .19458 Mdot
.616 .19468 Mdot
.616 .19516 Mdot
.616 .19518 Mdot
.616 .19524 Mdot
.616 .19525 Mdot
.616 .19569 Mdot
.616 .19622 Mdot
.616 .19634 Mdot
.616 .19865 Mdot
.616 .19878 Mdot
.616 .19905 Mdot
.616 .20002 Mdot
.616 .2002 Mdot
.616 .20244 Mdot
.616 .20293 Mdot
.616 .20305 Mdot
.616 .20363 Mdot
.616 .20408 Mdot
.616 .20444 Mdot
.616 .20572 Mdot
.616 .20684 Mdot
.616 .20685 Mdot
.616 .2083 Mdot
.616 .20952 Mdot
.616 .21119 Mdot
.616 .21136 Mdot
.616 .21152 Mdot
.616 .21225 Mdot
.616 .2127 Mdot
.616 .21449 Mdot
.616 .21468 Mdot
.616 .21468 Mdot
.616 .21554 Mdot
.616 .21597 Mdot
.616 .21606 Mdot
.616 .21714 Mdot
.616 .21855 Mdot
.616 .21876 Mdot
.616 .219 Mdot
.616 .21987 Mdot
.616 .22029 Mdot
.616 .2212 Mdot
.616 .22125 Mdot
.616 .22126 Mdot
.616 .22139 Mdot
.616 .22212 Mdot
.616 .2222 Mdot
.616 .22266 Mdot
.616 .22288 Mdot
.616 .22363 Mdot
.616 .22369 Mdot
.616 .22587 Mdot
.616 .22588 Mdot
.616 .22723 Mdot
.616 .22729 Mdot
.616 .22821 Mdot
.616 .22934 Mdot
.616 .22976 Mdot
.616 .23008 Mdot
.616 .2305 Mdot
.616 .23122 Mdot
.616 .23135 Mdot
.616 .23138 Mdot
.616 .23139 Mdot
.616 .2315 Mdot
.616 .2317 Mdot
.616 .23199 Mdot
.616 .23235 Mdot
.616 .23252 Mdot
.616 .23282 Mdot
.616 .23297 Mdot
.616 .2337 Mdot
.616 .23482 Mdot
.616 .23499 Mdot
.616 .23515 Mdot
.616 .23527 Mdot
.616 .23528 Mdot
.616 .23631 Mdot
.616 .23643 Mdot
.616 .23703 Mdot
.616 .23704 Mdot
.616 .23712 Mdot
.616 .23713 Mdot
.616 .23767 Mdot
.616 .23832 Mdot
.616 .23848 Mdot
.616 .24132 Mdot
.616 .24148 Mdot
.616 .24181 Mdot
.616 .24301 Mdot
.616 .24323 Mdot
.616 .246 Mdot
.616 .2466 Mdot
.616 .24674 Mdot
.616 .24746 Mdot
.616 .24801 Mdot
.616 .24846 Mdot
.616 .25004 Mdot
.616 .25141 Mdot
.616 .25143 Mdot
.616 .25321 Mdot
.616 .25472 Mdot
.616 .25677 Mdot
.616 .25699 Mdot
.616 .25717 Mdot
.616 .25808 Mdot
.616 .25864 Mdot
.616 .26084 Mdot
.616 .26107 Mdot
.616 .26107 Mdot
.616 .26213 Mdot
.616 .26266 Mdot
.616 .26278 Mdot
.616 .2641 Mdot
.616 .26584 Mdot
.616 .26609 Mdot
.616 .26639 Mdot
.616 .26747 Mdot
.616 .26798 Mdot
.616 .2691 Mdot
.616 .26916 Mdot
.616 .26917 Mdot
.616 .26934 Mdot
.616 .27023 Mdot
.616 .27034 Mdot
.616 .27091 Mdot
.616 .27118 Mdot
.616 .2721 Mdot
.616 .27218 Mdot
.616 .27486 Mdot
.616 .27486 Mdot
.616 .27653 Mdot
.616 .27661 Mdot
.616 .27774 Mdot
.616 .27913 Mdot
.616 .27965 Mdot
.616 .28004 Mdot
.616 .28056 Mdot
.616 .28145 Mdot
.616 .28161 Mdot
.616 .28165 Mdot
.616 .28165 Mdot
.616 .28179 Mdot
.616 .28204 Mdot
.616 .28239 Mdot
.616 .28285 Mdot
.616 .28306 Mdot
.616 .28343 Mdot
.616 .28361 Mdot
.616 .2841 Mdot
.616 .28451 Mdot
.616 .28589 Mdot
.616 .28609 Mdot
.616 .28629 Mdot
.616 .28643 Mdot
.616 .28645 Mdot
.616 .28772 Mdot
.616 .28787 Mdot
.616 .2886 Mdot
.616 .28862 Mdot
.616 .28872 Mdot
.616 .28873 Mdot
.616 .2894 Mdot
.616 .2902 Mdot
.616 .29039 Mdot
.616 .2939 Mdot
.616 .29409 Mdot
.616 .2945 Mdot
.616 .29598 Mdot
.616 .29625 Mdot
.616 .29965 Mdot
.616 .3004 Mdot
.616 .30057 Mdot
.616 .30145 Mdot
.616 .30213 Mdot
.616 .30269 Mdot
.616 .30463 Mdot
.616 .30632 Mdot
.616 .30634 Mdot
.616 .30854 Mdot
.616 .3104 Mdot
.616 .31293 Mdot
.616 .31319 Mdot
.616 .31342 Mdot
.616 .31454 Mdot
.616 .31523 Mdot
.616 .31794 Mdot
.616 .31823 Mdot
.616 .31823 Mdot
.616 .31953 Mdot
.616 .32018 Mdot
.616 .32033 Mdot
.616 .32196 Mdot
.616 .32411 Mdot
.616 .32441 Mdot
.616 .32478 Mdot
.616 .32611 Mdot
.616 .32673 Mdot
.616 .32812 Mdot
.616 .3282 Mdot
.616 .32821 Mdot
.616 .32841 Mdot
.616 .32951 Mdot
.616 .32964 Mdot
.616 .33035 Mdot
.616 .33067 Mdot
.616 .33181 Mdot
.616 .33191 Mdot
.616 .33522 Mdot
.616 .33522 Mdot
.616 .33727 Mdot
.616 .33737 Mdot
.616 .33876 Mdot
.616 .34047 Mdot
.616 .34111 Mdot
.616 .3416 Mdot
.616 .34223 Mdot
.616 .34333 Mdot
.616 .34353 Mdot
.616 .34358 Mdot
.616 .34358 Mdot
.616 .34375 Mdot
.616 .34406 Mdot
.616 .34449 Mdot
.616 .34505 Mdot
.616 .34531 Mdot
.616 .34577 Mdot
.616 .34599 Mdot
.616 .34659 Mdot
.616 .3471 Mdot
.616 .3488 Mdot
.616 .34905 Mdot
.616 .3493 Mdot
.616 .34947 Mdot
.616 .34949 Mdot
.616 .35105 Mdot
.616 .35124 Mdot
.616 .35215 Mdot
.616 .35217 Mdot
.616 .35228 Mdot
.616 .3523 Mdot
.616 .35312 Mdot
.616 .35411 Mdot
.616 .35435 Mdot
.616 .35867 Mdot
.616 .35891 Mdot
.616 .35941 Mdot
.616 .36123 Mdot
.616 .36157 Mdot
.616 .36576 Mdot
.616 .36668 Mdot
.616 .36689 Mdot
.616 .36798 Mdot
.616 .36882 Mdot
.616 .3695 Mdot
.616 .37189 Mdot
.616 .37398 Mdot
.616 .374 Mdot
.616 .37671 Mdot
.618 .01678 Mdot
.618 .01689 Mdot
.618 .01727 Mdot
.618 .01727 Mdot
.618 .0174 Mdot
.618 .01787 Mdot
.618 .01788 Mdot
.618 .01803 Mdot
.618 .0186 Mdot
.618 .01861 Mdot
.618 .01862 Mdot
.618 .01881 Mdot
.618 .01952 Mdot
.618 .01953 Mdot
.618 .01954 Mdot
.618 .01978 Mdot
.618 .02016 Mdot
.618 .02065 Mdot
.618 .02067 Mdot
.618 .02068 Mdot
.618 .02068 Mdot
.618 .02098 Mdot
.618 .02144 Mdot
.618 .02172 Mdot
.618 .02205 Mdot
.618 .02207 Mdot
.618 .02209 Mdot
.618 .02209 Mdot
.618 .02246 Mdot
.618 .02303 Mdot
.618 .02337 Mdot
.618 .02337 Mdot
.618 .02378 Mdot
.618 .02381 Mdot
.618 .02383 Mdot
.618 .02383 Mdot
.618 .02418 Mdot
.618 .02428 Mdot
.618 .02465 Mdot
.618 .02499 Mdot
.618 .02542 Mdot
.618 .02542 Mdot
.618 .02592 Mdot
.618 .02596 Mdot
.618 .02598 Mdot
.618 .02598 Mdot
.618 .026 Mdot
.618 .02642 Mdot
.618 .02654 Mdot
.618 .02672 Mdot
.618 .027 Mdot
.618 .02741 Mdot
.618 .02749 Mdot
.618 .02755 Mdot
.618 .02771 Mdot
.618 .02794 Mdot
.618 .02794 Mdot
.618 .02798 Mdot
.618 .02819 Mdot
.618 .02857 Mdot
.618 .02861 Mdot
.618 .02864 Mdot
.618 .02864 Mdot
.618 .02866 Mdot
.618 .02918 Mdot
.618 .02933 Mdot
.618 .02955 Mdot
.618 .02989 Mdot
.618 .03017 Mdot
.618 .03041 Mdot
.618 .0305 Mdot
.618 .03058 Mdot
.618 .03078 Mdot
.618 .03081 Mdot
.618 .03106 Mdot
.618 .03107 Mdot
.618 .03111 Mdot
.618 .03137 Mdot
.618 .03166 Mdot
.618 .03183 Mdot
.618 .03189 Mdot
.618 .03193 Mdot
.618 .03193 Mdot
.618 .03195 Mdot
.618 .03259 Mdot
.618 .03278 Mdot
.618 .03305 Mdot
.618 .03348 Mdot
.618 .03373 Mdot
.618 .03381 Mdot
.618 .03411 Mdot
.618 .03423 Mdot
.618 .03433 Mdot
.618 .03436 Mdot
.618 .03451 Mdot
.618 .03455 Mdot
.618 .03455 Mdot
.618 .03457 Mdot
.618 .03461 Mdot
.618 .03492 Mdot
.618 .03492 Mdot
.618 .03492 Mdot
.618 .03498 Mdot
.618 .0353 Mdot
.618 .03557 Mdot
.618 .03566 Mdot
.618 .03587 Mdot
.618 .03594 Mdot
.618 .03594 Mdot
.618 .03599 Mdot
.618 .03599 Mdot
.618 .03602 Mdot
.618 .03606 Mdot
.618 .03681 Mdot
.618 .03704 Mdot
.618 .03738 Mdot
.618 .0379 Mdot
.618 .03811 Mdot
.618 .03822 Mdot
.618 .03832 Mdot
.618 .03869 Mdot
.618 .03874 Mdot
.618 .03883 Mdot
.618 .03896 Mdot
.618 .039 Mdot
.618 .03919 Mdot
.618 .03923 Mdot
.618 .03923 Mdot
.618 .03926 Mdot
.618 .0393 Mdot
.618 .03968 Mdot
.618 .03969 Mdot
.618 .03969 Mdot
.618 .03977 Mdot
.618 .04016 Mdot
.618 .04043 Mdot
.618 .04049 Mdot
.618 .0406 Mdot
.618 .04087 Mdot
.618 .04095 Mdot
.618 .04095 Mdot
.618 .04101 Mdot
.618 .04101 Mdot
.618 .04105 Mdot
.618 .04109 Mdot
.618 .04155 Mdot
.618 .04167 Mdot
.618 .04171 Mdot
.618 .04202 Mdot
.618 .04231 Mdot
.618 .04273 Mdot
.618 .04286 Mdot
.618 .04338 Mdot
.618 .04363 Mdot
.618 .04377 Mdot
.618 .04389 Mdot
.618 .04435 Mdot
.618 .04441 Mdot
.618 .04449 Mdot
.618 .04452 Mdot
.618 .04468 Mdot
.618 .04473 Mdot
.618 .04496 Mdot
.618 .04501 Mdot
.618 .04502 Mdot
.618 .04505 Mdot
.618 .0451 Mdot
.618 .04557 Mdot
.618 .04558 Mdot
.618 .04559 Mdot
.618 .04568 Mdot
.618 .04616 Mdot
.618 .04636 Mdot
.618 .04642 Mdot
.618 .0465 Mdot
.618 .04655 Mdot
.618 .04657 Mdot
.618 .04671 Mdot
.618 .04704 Mdot
.618 .04714 Mdot
.618 .04715 Mdot
.618 .04722 Mdot
.618 .04722 Mdot
.618 .04726 Mdot
.618 .04732 Mdot
.618 .04788 Mdot
.618 .04803 Mdot
.618 .04808 Mdot
.618 .04847 Mdot
.618 .04878 Mdot
.618 .04883 Mdot
.618 .04905 Mdot
.618 .04934 Mdot
.618 .0495 Mdot
.618 .05014 Mdot
.618 .05046 Mdot
.618 .05063 Mdot
.618 .05078 Mdot
.618 .05093 Mdot
.618 .05135 Mdot
.618 .05142 Mdot
.618 .05151 Mdot
.618 .05154 Mdot
.618 .05156 Mdot
.618 .05175 Mdot
.618 .05181 Mdot
.618 .0521 Mdot
.618 .05216 Mdot
.618 .05217 Mdot
.618 .05218 Mdot
.618 .05221 Mdot
.618 .05228 Mdot
.618 .05231 Mdot
.618 .05286 Mdot
.618 .05287 Mdot
.618 .05287 Mdot
.618 .05298 Mdot
.618 .05333 Mdot
.618 .05359 Mdot
.618 .05383 Mdot
.618 .05389 Mdot
.618 .0539 Mdot
.618 .054 Mdot
.618 .05406 Mdot
.618 .05409 Mdot
.618 .05422 Mdot
.618 .05426 Mdot
.618 .05467 Mdot
.618 .05479 Mdot
.618 .0548 Mdot
.618 .05489 Mdot
.618 .05489 Mdot
.618 .05494 Mdot
.618 .05501 Mdot
.618 .05556 Mdot
.618 .05571 Mdot
.618 .0559 Mdot
.618 .05596 Mdot
.618 .05602 Mdot
.618 .05604 Mdot
.618 .05643 Mdot
.618 .05682 Mdot
.618 .05688 Mdot
.618 .05695 Mdot
.618 .05715 Mdot
.618 .05751 Mdot
.618 .05771 Mdot
.618 .0585 Mdot
.618 .0589 Mdot
.618 .0591 Mdot
.618 .05929 Mdot
.618 .05948 Mdot
.618 .05999 Mdot
.618 .06008 Mdot
.618 .06018 Mdot
.618 .0602 Mdot
.618 .06023 Mdot
.618 .06025 Mdot
.618 .06049 Mdot
.618 .06057 Mdot
.618 .06092 Mdot
.618 .061 Mdot
.618 .06101 Mdot
.618 .06102 Mdot
.618 .06106 Mdot
.618 .06114 Mdot
.618 .06119 Mdot
.618 .06145 Mdot
.618 .06152 Mdot
.618 .06186 Mdot
.618 .06187 Mdot
.618 .06188 Mdot
.618 .06202 Mdot
.618 .06244 Mdot
.618 .06244 Mdot
.618 .06246 Mdot
.618 .06276 Mdot
.618 .06299 Mdot
.618 .06306 Mdot
.618 .06314 Mdot
.618 .06315 Mdot
.618 .06327 Mdot
.618 .06334 Mdot
.618 .06338 Mdot
.618 .06354 Mdot
.618 .0636 Mdot
.618 .06371 Mdot
.618 .0641 Mdot
.618 .06425 Mdot
.618 .06426 Mdot
.618 .06437 Mdot
.618 .06437 Mdot
.618 .06444 Mdot
.618 .06452 Mdot
.618 .0652 Mdot
.618 .06539 Mdot
.618 .06562 Mdot
.618 .06569 Mdot
.618 .06577 Mdot
.618 .06579 Mdot
.618 .06628 Mdot
.618 .06675 Mdot
.618 .06683 Mdot
.618 .06692 Mdot
.618 .06707 Mdot
.618 .06717 Mdot
.618 .06761 Mdot
.618 .06785 Mdot
.618 .06884 Mdot
.618 .06931 Mdot
.618 .06932 Mdot
.618 .06958 Mdot
.618 .06981 Mdot
.618 .07004 Mdot
.618 .07068 Mdot
.618 .07078 Mdot
.618 .0709 Mdot
.618 .07091 Mdot
.618 .07093 Mdot
.618 .07097 Mdot
.618 .071 Mdot
.618 .07129 Mdot
.618 .07139 Mdot
.618 .07182 Mdot
.618 .07192 Mdot
.618 .07194 Mdot
.618 .07195 Mdot
.618 .07195 Mdot
.618 .072 Mdot
.618 .0721 Mdot
.618 .07215 Mdot
.618 .07248 Mdot
.618 .07257 Mdot
.618 .07282 Mdot
.618 .07299 Mdot
.618 .073 Mdot
.618 .07301 Mdot
.618 .07318 Mdot
.618 .07342 Mdot
.618 .0737 Mdot
.618 .07371 Mdot
.618 .07373 Mdot
.618 .07406 Mdot
.618 .0741 Mdot
.618 .07438 Mdot
.618 .07447 Mdot
.618 .07456 Mdot
.618 .07458 Mdot
.618 .07473 Mdot
.618 .07482 Mdot
.618 .07487 Mdot
.618 .07507 Mdot
.618 .07513 Mdot
.618 .07527 Mdot
.618 .07575 Mdot
.618 .07594 Mdot
.618 .07595 Mdot
.618 .07609 Mdot
.618 .07609 Mdot
.618 .07617 Mdot
.618 .07628 Mdot
.618 .07711 Mdot
.618 .07734 Mdot
.618 .0775 Mdot
.618 .07763 Mdot
.618 .07772 Mdot
.618 .07781 Mdot
.618 .07784 Mdot
.618 .07833 Mdot
.618 .07845 Mdot
.618 .07904 Mdot
.618 .07913 Mdot
.618 .07924 Mdot
.618 .07943 Mdot
.618 .07955 Mdot
.618 .08009 Mdot
.618 .08039 Mdot
.618 .08161 Mdot
.618 .08219 Mdot
.618 .08221 Mdot
.618 .08228 Mdot
.618 .08252 Mdot
.618 .08281 Mdot
.618 .08291 Mdot
.618 .0831 Mdot
.618 .08363 Mdot
.618 .08388 Mdot
.618 .08401 Mdot
.618 .08416 Mdot
.618 .08417 Mdot
.618 .0842 Mdot
.618 .08425 Mdot
.618 .08428 Mdot
.618 .08465 Mdot
.618 .08477 Mdot
.618 .08492 Mdot
.618 .0853 Mdot
.618 .08542 Mdot
.618 .08545 Mdot
.618 .08545 Mdot
.618 .08545 Mdot
.618 .08552 Mdot
.618 .08564 Mdot
.618 .08571 Mdot
.618 .08573 Mdot
.618 .08611 Mdot
.618 .08622 Mdot
.618 .08653 Mdot
.618 .08674 Mdot
.618 .08676 Mdot
.618 .08677 Mdot
.618 .08698 Mdot
.618 .08728 Mdot
.618 .08762 Mdot
.618 .08763 Mdot
.618 .08765 Mdot
.618 .08806 Mdot
.618 .08811 Mdot
.618 .08846 Mdot
.618 .08857 Mdot
.618 .08869 Mdot
.618 .08871 Mdot
.618 .0889 Mdot
.618 .089 Mdot
.618 .08906 Mdot
.618 .08931 Mdot
.618 .08939 Mdot
.618 .0894 Mdot
.618 .08956 Mdot
.618 .09016 Mdot
.618 .09039 Mdot
.618 .0904 Mdot
.618 .09057 Mdot
.618 .09058 Mdot
.618 .09067 Mdot
.618 .09081 Mdot
.618 .09142 Mdot
.618 .09183 Mdot
.618 .09213 Mdot
.618 .09232 Mdot
.618 .09248 Mdot
.618 .09259 Mdot
.618 .09271 Mdot
.618 .09274 Mdot
.618 .09334 Mdot
.618 .09349 Mdot
.618 .09421 Mdot
.618 .09433 Mdot
.618 .09446 Mdot
.618 .0947 Mdot
.618 .09485 Mdot
.618 .09552 Mdot
.618 .09589 Mdot
.618 .0974 Mdot
.618 .09811 Mdot
.618 .09814 Mdot
.618 .09822 Mdot
.618 .09853 Mdot
.618 .09888 Mdot
.618 .099 Mdot
.618 .09923 Mdot
.618 .09961 Mdot
.618 .09979 Mdot
.618 .0999 Mdot
.618 .10021 Mdot
.618 .10037 Mdot
.618 .10054 Mdot
.618 .10056 Mdot
.618 .1006 Mdot
.618 .10066 Mdot
.618 .1007 Mdot
.618 .10115 Mdot
.618 .1013 Mdot
.618 .10149 Mdot
.618 .10196 Mdot
.618 .1021 Mdot
.618 .10214 Mdot
.618 .10215 Mdot
.618 .10215 Mdot
.618 .10223 Mdot
.618 .10238 Mdot
.618 .10246 Mdot
.618 .10249 Mdot
.618 .10295 Mdot
.618 .1031 Mdot
.618 .10348 Mdot
.618 .10373 Mdot
.618 .10376 Mdot
.618 .10377 Mdot
.618 .10403 Mdot
.618 .1044 Mdot
.618 .10483 Mdot
.618 .10484 Mdot
.618 .10487 Mdot
.618 .10537 Mdot
.618 .10544 Mdot
.618 .10586 Mdot
.618 .106 Mdot
.618 .10615 Mdot
.618 .10618 Mdot
.618 .10641 Mdot
.618 .10654 Mdot
.618 .10661 Mdot
.618 .10691 Mdot
.618 .10702 Mdot
.618 .10702 Mdot
.618 .10723 Mdot
.618 .10796 Mdot
.618 .10825 Mdot
.618 .10827 Mdot
.618 .10848 Mdot
.618 .10848 Mdot
.618 .1086 Mdot
.618 .10876 Mdot
.618 .10953 Mdot
.618 .11003 Mdot
.618 .11039 Mdot
.618 .11063 Mdot
.618 .11083 Mdot
.618 .11097 Mdot
.618 .11111 Mdot
.618 .11115 Mdot
.618 .11189 Mdot
.618 .11208 Mdot
.618 .11298 Mdot
.618 .11312 Mdot
.618 .11328 Mdot
.618 .11358 Mdot
.618 .11376 Mdot
.618 .11459 Mdot
.618 .11505 Mdot
.618 .11691 Mdot
.618 .11695 Mdot
.618 .1178 Mdot
.618 .11783 Mdot
.618 .11793 Mdot
.618 .11831 Mdot
.618 .11874 Mdot
.618 .11889 Mdot
.618 .11918 Mdot
.618 .11965 Mdot
.618 .11987 Mdot
.618 .12 Mdot
.618 .12038 Mdot
.618 .12058 Mdot
.618 .1208 Mdot
.618 .12082 Mdot
.618 .12086 Mdot
.618 .12094 Mdot
.618 .121 Mdot
.618 .12155 Mdot
.618 .12173 Mdot
.618 .12197 Mdot
.618 .12255 Mdot
.618 .12273 Mdot
.618 .12277 Mdot
.618 .12278 Mdot
.618 .12278 Mdot
.618 .12288 Mdot
.618 .12307 Mdot
.618 .12317 Mdot
.618 .1232 Mdot
.618 .12378 Mdot
.618 .12395 Mdot
.618 .12443 Mdot
.618 .12474 Mdot
.618 .12478 Mdot
.618 .12479 Mdot
.618 .12511 Mdot
.618 .12557 Mdot
.618 .12609 Mdot
.618 .12611 Mdot
.618 .12614 Mdot
.618 .12677 Mdot
.618 .12685 Mdot
.618 .12737 Mdot
.618 .12754 Mdot
.618 .12772 Mdot
.618 .12776 Mdot
.618 .12805 Mdot
.618 .1282 Mdot
.618 .1283 Mdot
.618 .12867 Mdot
.618 .1288 Mdot
.618 .12881 Mdot
.618 .12906 Mdot
.618 .12997 Mdot
.618 .13032 Mdot
.618 .13034 Mdot
.618 .1306 Mdot
.618 .13061 Mdot
.618 .13076 Mdot
.618 .13096 Mdot
.618 .1319 Mdot
.618 .13253 Mdot
.618 .13297 Mdot
.618 .13327 Mdot
.618 .13351 Mdot
.618 .13368 Mdot
.618 .13386 Mdot
.618 .13483 Mdot
.618 .13506 Mdot
.618 .13617 Mdot
.618 .13634 Mdot
.618 .13655 Mdot
.618 .13691 Mdot
.618 .13713 Mdot
.618 .13816 Mdot
.618 .13873 Mdot
.618 .14103 Mdot
.618 .14108 Mdot
.618 .14212 Mdot
.618 .14216 Mdot
.618 .14229 Mdot
.618 .14275 Mdot
.618 .14329 Mdot
.618 .14348 Mdot
.618 .14384 Mdot
.618 .14441 Mdot
.618 .14469 Mdot
.618 .14485 Mdot
.618 .14532 Mdot
.618 .14557 Mdot
.618 .14583 Mdot
.618 .14586 Mdot
.618 .14591 Mdot
.618 .14601 Mdot
.618 .14608 Mdot
.618 .14676 Mdot
.618 .14699 Mdot
.618 .14728 Mdot
.618 .148 Mdot
.618 .14822 Mdot
.618 .14827 Mdot
.618 .14828 Mdot
.618 .14828 Mdot
.618 .14841 Mdot
.618 .14864 Mdot
.618 .14877 Mdot
.618 .14881 Mdot
.618 .14952 Mdot
.618 .14974 Mdot
.618 .15032 Mdot
.618 .15071 Mdot
.618 .15075 Mdot
.618 .15077 Mdot
.618 .15116 Mdot
.618 .15173 Mdot
.618 .15238 Mdot
.618 .1524 Mdot
.618 .15244 Mdot
.618 .15322 Mdot
.618 .15331 Mdot
.618 .15396 Mdot
.618 .15417 Mdot
.618 .15439 Mdot
.618 .15444 Mdot
.618 .15479 Mdot
.618 .15499 Mdot
.618 .1551 Mdot
.618 .15557 Mdot
.618 .15573 Mdot
.618 .15573 Mdot
.618 .15605 Mdot
.618 .15717 Mdot
.618 .15761 Mdot
.618 .15763 Mdot
.618 .15795 Mdot
.618 .15796 Mdot
.618 .15814 Mdot
.618 .15839 Mdot
.618 .15956 Mdot
.618 .16033 Mdot
.618 .16088 Mdot
.618 .16125 Mdot
.618 .16155 Mdot
.618 .16176 Mdot
.618 .16198 Mdot
.618 .16317 Mdot
.618 .16346 Mdot
.618 .16483 Mdot
.618 .16505 Mdot
.618 .1653 Mdot
.618 .16575 Mdot
.618 .16603 Mdot
.618 .1673 Mdot
.618 .168 Mdot
.618 .17084 Mdot
.618 .1709 Mdot
.618 .17219 Mdot
.618 .17224 Mdot
.618 .1724 Mdot
.618 .17297 Mdot
.618 .17364 Mdot
.618 .17386 Mdot
.618 .17431 Mdot
.618 .17502 Mdot
.618 .17536 Mdot
.618 .17556 Mdot
.618 .17614 Mdot
.618 .17645 Mdot
.618 .17678 Mdot
.618 .17681 Mdot
.618 .17688 Mdot
.618 .17699 Mdot
.618 .17708 Mdot
.618 .17793 Mdot
.618 .1782 Mdot
.618 .17857 Mdot
.618 .17946 Mdot
.618 .17972 Mdot
.618 .17979 Mdot
.618 .1798 Mdot
.618 .17981 Mdot
.618 .17996 Mdot
.618 .18024 Mdot
.618 .1804 Mdot
.618 .18045 Mdot
.618 .18133 Mdot
.618 .1816 Mdot
.618 .18233 Mdot
.618 .1828 Mdot
.618 .18286 Mdot
.618 .18287 Mdot
.618 .18336 Mdot
.618 .18406 Mdot
.618 .18487 Mdot
.618 .18489 Mdot
.618 .18495 Mdot
.618 .1859 Mdot
.618 .18602 Mdot
.618 .18682 Mdot
.618 .18708 Mdot
.618 .18736 Mdot
.618 .18742 Mdot
.618 .18785 Mdot
.618 .18809 Mdot
.618 .18823 Mdot
.618 .18881 Mdot
.618 .189 Mdot
.618 .18901 Mdot
.618 .1894 Mdot
.618 .19079 Mdot
.618 .19133 Mdot
.618 .19136 Mdot
.618 .19176 Mdot
.618 .19176 Mdot
.618 .19199 Mdot
.618 .1923 Mdot
.618 .19374 Mdot
.618 .1947 Mdot
.618 .19538 Mdot
.618 .19583 Mdot
.618 .1962 Mdot
.618 .19646 Mdot
.618 .19673 Mdot
.618 .19821 Mdot
.618 .19856 Mdot
.618 .20026 Mdot
.618 .20052 Mdot
.618 .20084 Mdot
.618 .20139 Mdot
.618 .20173 Mdot
.618 .20331 Mdot
.618 .20417 Mdot
.618 .20768 Mdot
.618 .20776 Mdot
.618 .20936 Mdot
.618 .20941 Mdot
.618 .20961 Mdot
.618 .21032 Mdot
.618 .21114 Mdot
.618 .21142 Mdot
.618 .21197 Mdot
.618 .21285 Mdot
.618 .21328 Mdot
.618 .21352 Mdot
.618 .21424 Mdot
.618 .21462 Mdot
.618 .21503 Mdot
.618 .21506 Mdot
.618 .21515 Mdot
.618 .21529 Mdot
.618 .2154 Mdot
.618 .21645 Mdot
.618 .21679 Mdot
.618 .21724 Mdot
.618 .21833 Mdot
.618 .21867 Mdot
.618 .21875 Mdot
.618 .21876 Mdot
.618 .21877 Mdot
.618 .21896 Mdot
.618 .21931 Mdot
.618 .2195 Mdot
.618 .21956 Mdot
.618 .22065 Mdot
.618 .22098 Mdot
.618 .22188 Mdot
.618 .22247 Mdot
.618 .22254 Mdot
.618 .22256 Mdot
.618 .22317 Mdot
.618 .22403 Mdot
.618 .22502 Mdot
.618 .22505 Mdot
.618 .22512 Mdot
.618 .2263 Mdot
.618 .22645 Mdot
.618 .22744 Mdot
.618 .22776 Mdot
.618 .2281 Mdot
.618 .22817 Mdot
.618 .22871 Mdot
.618 .22901 Mdot
.618 .22918 Mdot
.618 .22989 Mdot
.618 .23014 Mdot
.618 .23015 Mdot
.618 .23063 Mdot
.618 .23234 Mdot
.618 .23301 Mdot
.618 .23305 Mdot
.618 .23354 Mdot
.618 .23355 Mdot
.618 .23383 Mdot
.618 .23421 Mdot
.618 .23599 Mdot
.618 .23717 Mdot
.618 .23802 Mdot
.618 .23857 Mdot
.618 .23903 Mdot
.618 .23935 Mdot
.618 .23969 Mdot
.618 .24151 Mdot
.618 .24195 Mdot
.618 .24404 Mdot
.618 .24438 Mdot
.618 .24476 Mdot
.618 .24544 Mdot
.618 .24587 Mdot
.618 .24781 Mdot
.618 .24889 Mdot
.618 .25322 Mdot
.618 .25332 Mdot
.618 .25529 Mdot
.618 .25536 Mdot
.618 .25561 Mdot
.618 .25648 Mdot
.618 .2575 Mdot
.618 .25785 Mdot
.618 .25852 Mdot
.618 .25961 Mdot
.618 .26014 Mdot
.618 .26044 Mdot
.618 .26132 Mdot
.618 .2618 Mdot
.618 .2623 Mdot
.618 .26234 Mdot
.618 .26245 Mdot
.618 .26262 Mdot
.618 .26276 Mdot
.618 .26405 Mdot
.618 .26447 Mdot
.618 .26503 Mdot
.618 .26639 Mdot
.618 .2668 Mdot
.618 .2669 Mdot
.618 .26692 Mdot
.618 .26692 Mdot
.618 .26716 Mdot
.618 .26759 Mdot
.618 .26783 Mdot
.618 .26791 Mdot
.618 .26925 Mdot
.618 .26966 Mdot
.618 .27077 Mdot
.618 .27151 Mdot
.618 .27159 Mdot
.618 .27161 Mdot
.618 .27236 Mdot
.618 .27343 Mdot
.618 .27465 Mdot
.618 .27469 Mdot
.618 .27477 Mdot
.618 .27624 Mdot
.618 .27641 Mdot
.618 .27764 Mdot
.618 .27804 Mdot
.618 .27846 Mdot
.618 .27855 Mdot
.618 .27921 Mdot
.618 .27958 Mdot
.618 .2798 Mdot
.618 .28067 Mdot
.618 .28098 Mdot
.618 .28099 Mdot
.618 .28159 Mdot
.618 .2837 Mdot
.618 .28453 Mdot
.618 .28458 Mdot
.618 .28518 Mdot
.618 .28519 Mdot
.618 .28554 Mdot
.618 .28601 Mdot
.618 .28821 Mdot
.618 .28967 Mdot
.618 .29071 Mdot
.618 .2914 Mdot
.618 .29197 Mdot
.618 .29237 Mdot
.618 .29278 Mdot
.618 .29504 Mdot
.618 .29558 Mdot
.618 .29817 Mdot
.618 .29858 Mdot
.618 .29905 Mdot
.618 .2999 Mdot
.618 .30042 Mdot
.618 .30282 Mdot
.618 .30415 Mdot
.618 .30951 Mdot
.618 .30963 Mdot
.618 .31207 Mdot
.618 .31215 Mdot
.618 .31246 Mdot
.618 .31354 Mdot
.618 .3148 Mdot
.618 .31522 Mdot
.618 .31606 Mdot
.618 .3174 Mdot
.618 .31806 Mdot
.618 .31844 Mdot
.618 .31952 Mdot
.618 .32011 Mdot
.618 .32073 Mdot
.618 .32078 Mdot
.618 .32091 Mdot
.618 .32113 Mdot
.618 .3213 Mdot
.618 .3229 Mdot
.618 .32342 Mdot
.618 .32411 Mdot
.618 .32578 Mdot
.618 .32629 Mdot
.618 .32641 Mdot
.618 .32644 Mdot
.618 .32645 Mdot
.618 .32674 Mdot
.618 .32727 Mdot
.618 .32757 Mdot
.618 .32766 Mdot
.618 .32933 Mdot
.618 .32983 Mdot
.618 .3312 Mdot
.618 .33211 Mdot
.618 .33221 Mdot
.618 .33224 Mdot
.618 .33316 Mdot
.618 .33448 Mdot
.618 .336 Mdot
.618 .33605 Mdot
.618 .33615 Mdot
.618 .33796 Mdot
.618 .33818 Mdot
.618 .3397 Mdot
.618 .34019 Mdot
.618 .34071 Mdot
.618 .34081 Mdot
.618 .34163 Mdot
.618 .34209 Mdot
.618 .34236 Mdot
.618 .34344 Mdot
.618 .34381 Mdot
.618 .34383 Mdot
.618 .34457 Mdot
.618 .34718 Mdot
.618 .3482 Mdot
.618 .34827 Mdot
.618 .34901 Mdot
.618 .34902 Mdot
.618 .34945 Mdot
.618 .35004 Mdot
.618 .35276 Mdot
.618 .35456 Mdot
.618 .35585 Mdot
.618 .3567 Mdot
.618 .35741 Mdot
.618 .35789 Mdot
.618 .35841 Mdot
.618 .36119 Mdot
.618 .36186 Mdot
.618 .36506 Mdot
.618 .36557 Mdot
.618 .36616 Mdot
.618 .3672 Mdot
.618 .36785 Mdot
.618 .37082 Mdot
.618 .37246 Mdot
.618 .37908 Mdot
.618 .37923 Mdot
.62 .01481 Mdot
.62 .01484 Mdot
.62 .01487 Mdot
.62 .0149 Mdot
.62 .01495 Mdot
.62 .015 Mdot
.62 .01507 Mdot
.62 .01516 Mdot
.62 .01527 Mdot
.62 .0154 Mdot
.62 .01556 Mdot
.62 .01577 Mdot
.62 .01595 Mdot
.62 .01602 Mdot
.62 .01625 Mdot
.62 .01633 Mdot
.62 .01636 Mdot
.62 .01661 Mdot
.62 .01672 Mdot
.62 .01675 Mdot
.62 .01707 Mdot
.62 .0172 Mdot
.62 .01724 Mdot
.62 .01733 Mdot
.62 .0174 Mdot
.62 .01763 Mdot
.62 .0178 Mdot
.62 .01785 Mdot
.62 .01796 Mdot
.62 .01797 Mdot
.62 .01804 Mdot
.62 .01808 Mdot
.62 .01833 Mdot
.62 .01854 Mdot
.62 .0186 Mdot
.62 .01874 Mdot
.62 .01875 Mdot
.62 .01884 Mdot
.62 .01888 Mdot
.62 .01907 Mdot
.62 .0192 Mdot
.62 .01946 Mdot
.62 .01954 Mdot
.62 .0197 Mdot
.62 .01972 Mdot
.62 .01983 Mdot
.62 .01989 Mdot
.62 .02012 Mdot
.62 .02028 Mdot
.62 .02034 Mdot
.62 .02059 Mdot
.62 .02069 Mdot
.62 .0209 Mdot
.62 .02092 Mdot
.62 .02096 Mdot
.62 .02105 Mdot
.62 .02107 Mdot
.62 .02113 Mdot
.62 .02141 Mdot
.62 .02161 Mdot
.62 .02169 Mdot
.62 .02176 Mdot
.62 .02199 Mdot
.62 .02201 Mdot
.62 .02213 Mdot
.62 .02238 Mdot
.62 .0224 Mdot
.62 .02246 Mdot
.62 .02257 Mdot
.62 .0226 Mdot
.62 .02267 Mdot
.62 .02302 Mdot
.62 .02327 Mdot
.62 .02337 Mdot
.62 .02345 Mdot
.62 .02347 Mdot
.62 .02374 Mdot
.62 .02376 Mdot
.62 .02391 Mdot
.62 .02422 Mdot
.62 .02425 Mdot
.62 .02432 Mdot
.62 .02446 Mdot
.62 .02449 Mdot
.62 .02457 Mdot
.62 .02502 Mdot
.62 .02523 Mdot
.62 .02532 Mdot
.62 .02544 Mdot
.62 .02554 Mdot
.62 .02557 Mdot
.62 .02562 Mdot
.62 .0259 Mdot
.62 .02593 Mdot
.62 .02612 Mdot
.62 .0265 Mdot
.62 .02654 Mdot
.62 .02663 Mdot
.62 .02665 Mdot
.62 .0268 Mdot
.62 .02684 Mdot
.62 .02684 Mdot
.62 .02694 Mdot
.62 .027 Mdot
.62 .02749 Mdot
.62 .02775 Mdot
.62 .02786 Mdot
.62 .02788 Mdot
.62 .02802 Mdot
.62 .02809 Mdot
.62 .02814 Mdot
.62 .02818 Mdot
.62 .02824 Mdot
.62 .02859 Mdot
.62 .02862 Mdot
.62 .02885 Mdot
.62 .02933 Mdot
.62 .02937 Mdot
.62 .02949 Mdot
.62 .02952 Mdot
.62 .0297 Mdot
.62 .02975 Mdot
.62 .02975 Mdot
.62 .02987 Mdot
.62 .02995 Mdot
.62 .03 Mdot
.62 .03047 Mdot
.62 .03055 Mdot
.62 .03088 Mdot
.62 .03102 Mdot
.62 .03104 Mdot
.62 .03121 Mdot
.62 .0313 Mdot
.62 .03137 Mdot
.62 .03141 Mdot
.62 .03143 Mdot
.62 .03148 Mdot
.62 .03185 Mdot
.62 .03188 Mdot
.62 .03191 Mdot
.62 .03195 Mdot
.62 .03202 Mdot
.62 .03224 Mdot
.62 .03284 Mdot
.62 .03289 Mdot
.62 .03304 Mdot
.62 .03307 Mdot
.62 .03311 Mdot
.62 .0333 Mdot
.62 .03336 Mdot
.62 .03336 Mdot
.62 .03351 Mdot
.62 .0336 Mdot
.62 .03366 Mdot
.62 .03387 Mdot
.62 .03425 Mdot
.62 .03435 Mdot
.62 .03475 Mdot
.62 .03493 Mdot
.62 .03495 Mdot
.62 .03495 Mdot
.62 .03517 Mdot
.62 .03528 Mdot
.62 .03536 Mdot
.62 .03541 Mdot
.62 .03544 Mdot
.62 .03551 Mdot
.62 .03591 Mdot
.62 .03597 Mdot
.62 .036 Mdot
.62 .03604 Mdot
.62 .03609 Mdot
.62 .03617 Mdot
.62 .03645 Mdot
.62 .03719 Mdot
.62 .03725 Mdot
.62 .03736 Mdot
.62 .03743 Mdot
.62 .03748 Mdot
.62 .03752 Mdot
.62 .03776 Mdot
.62 .03783 Mdot
.62 .03784 Mdot
.62 .03802 Mdot
.62 .03814 Mdot
.62 .03821 Mdot
.62 .03847 Mdot
.62 .03894 Mdot
.62 .03907 Mdot
.62 .03956 Mdot
.62 .03979 Mdot
.62 .03981 Mdot
.62 .03981 Mdot
.62 .04008 Mdot
.62 .04022 Mdot
.62 .04032 Mdot
.62 .04038 Mdot
.62 .04041 Mdot
.62 .0405 Mdot
.62 .04066 Mdot
.62 .04099 Mdot
.62 .04107 Mdot
.62 .04111 Mdot
.62 .04116 Mdot
.62 .04122 Mdot
.62 .04132 Mdot
.62 .04167 Mdot
.62 .04258 Mdot
.62 .04266 Mdot
.62 .04266 Mdot
.62 .04279 Mdot
.62 .04289 Mdot
.62 .04294 Mdot
.62 .04299 Mdot
.62 .04329 Mdot
.62 .04338 Mdot
.62 .04339 Mdot
.62 .04362 Mdot
.62 .04376 Mdot
.62 .04385 Mdot
.62 .04417 Mdot
.62 .04475 Mdot
.62 .04491 Mdot
.62 .04503 Mdot
.62 .04513 Mdot
.62 .04553 Mdot
.62 .0458 Mdot
.62 .04583 Mdot
.62 .04584 Mdot
.62 .04617 Mdot
.62 .04634 Mdot
.62 .04646 Mdot
.62 .04654 Mdot
.62 .04658 Mdot
.62 .04668 Mdot
.62 .04689 Mdot
.62 .04713 Mdot
.62 .0473 Mdot
.62 .04739 Mdot
.62 .04744 Mdot
.62 .04751 Mdot
.62 .04758 Mdot
.62 .04771 Mdot
.62 .04814 Mdot
.62 .04867 Mdot
.62 .04927 Mdot
.62 .04936 Mdot
.62 .04937 Mdot
.62 .04942 Mdot
.62 .04953 Mdot
.62 .04965 Mdot
.62 .04972 Mdot
.62 .04978 Mdot
.62 .04994 Mdot
.62 .05014 Mdot
.62 .05026 Mdot
.62 .05027 Mdot
.62 .05055 Mdot
.62 .05073 Mdot
.62 .05084 Mdot
.62 .05124 Mdot
.62 .05196 Mdot
.62 .05216 Mdot
.62 .05231 Mdot
.62 .05238 Mdot
.62 .05242 Mdot
.62 .05292 Mdot
.62 .05327 Mdot
.62 .05329 Mdot
.62 .0533 Mdot
.62 .05372 Mdot
.62 .05386 Mdot
.62 .05393 Mdot
.62 .05408 Mdot
.62 .05418 Mdot
.62 .05422 Mdot
.62 .05436 Mdot
.62 .05461 Mdot
.62 .05491 Mdot
.62 .05512 Mdot
.62 .05524 Mdot
.62 .05526 Mdot
.62 .05529 Mdot
.62 .05538 Mdot
.62 .05547 Mdot
.62 .05563 Mdot
.62 .05616 Mdot
.62 .05682 Mdot
.62 .05757 Mdot
.62 .05768 Mdot
.62 .05769 Mdot
.62 .05775 Mdot
.62 .05788 Mdot
.62 .05803 Mdot
.62 .05812 Mdot
.62 .0582 Mdot
.62 .05839 Mdot
.62 .05864 Mdot
.62 .05879 Mdot
.62 .05881 Mdot
.62 .05891 Mdot
.62 .05915 Mdot
.62 .05921 Mdot
.62 .05932 Mdot
.62 .05937 Mdot
.62 .05952 Mdot
.62 .06001 Mdot
.62 .06063 Mdot
.62 .0609 Mdot
.62 .06115 Mdot
.62 .06133 Mdot
.62 .06141 Mdot
.62 .06147 Mdot
.62 .06209 Mdot
.62 .06252 Mdot
.62 .06255 Mdot
.62 .06257 Mdot
.62 .06308 Mdot
.62 .06326 Mdot
.62 .06334 Mdot
.62 .06353 Mdot
.62 .06365 Mdot
.62 .06371 Mdot
.62 .06376 Mdot
.62 .06387 Mdot
.62 .06419 Mdot
.62 .06455 Mdot
.62 .06482 Mdot
.62 .06496 Mdot
.62 .06499 Mdot
.62 .06503 Mdot
.62 .06514 Mdot
.62 .06525 Mdot
.62 .06526 Mdot
.62 .06545 Mdot
.62 .06596 Mdot
.62 .0661 Mdot
.62 .06693 Mdot
.62 .06733 Mdot
.62 .06763 Mdot
.62 .06785 Mdot
.62 .06799 Mdot
.62 .068 Mdot
.62 .06808 Mdot
.62 .06824 Mdot
.62 .06843 Mdot
.62 .06853 Mdot
.62 .06863 Mdot
.62 .06866 Mdot
.62 .06888 Mdot
.62 .06913 Mdot
.62 .06919 Mdot
.62 .06936 Mdot
.62 .06939 Mdot
.62 .06951 Mdot
.62 .06954 Mdot
.62 .06982 Mdot
.62 .06989 Mdot
.62 .07003 Mdot
.62 .07009 Mdot
.62 .07009 Mdot
.62 .07027 Mdot
.62 .07053 Mdot
.62 .07088 Mdot
.62 .07165 Mdot
.62 .07199 Mdot
.62 .07229 Mdot
.62 .07251 Mdot
.62 .07262 Mdot
.62 .0727 Mdot
.62 .07305 Mdot
.62 .07326 Mdot
.62 .07346 Mdot
.62 .07399 Mdot
.62 .07403 Mdot
.62 .07405 Mdot
.62 .07469 Mdot
.62 .07491 Mdot
.62 .07501 Mdot
.62 .07525 Mdot
.62 .0754 Mdot
.62 .07547 Mdot
.62 .07553 Mdot
.62 .0756 Mdot
.62 .07567 Mdot
.62 .07603 Mdot
.62 .07606 Mdot
.62 .0764 Mdot
.62 .07651 Mdot
.62 .07684 Mdot
.62 .07702 Mdot
.62 .07706 Mdot
.62 .07711 Mdot
.62 .07724 Mdot
.62 .07739 Mdot
.62 .07763 Mdot
.62 .07826 Mdot
.62 .07844 Mdot
.62 .07866 Mdot
.62 .07946 Mdot
.62 .0799 Mdot
.62 .07996 Mdot
.62 .08018 Mdot
.62 .08033 Mdot
.62 .08053 Mdot
.62 .0806 Mdot
.62 .08078 Mdot
.62 .08079 Mdot
.62 .08089 Mdot
.62 .08109 Mdot
.62 .08132 Mdot
.62 .08143 Mdot
.62 .08145 Mdot
.62 .08157 Mdot
.62 .08161 Mdot
.62 .08188 Mdot
.62 .08219 Mdot
.62 .08226 Mdot
.62 .08245 Mdot
.62 .08248 Mdot
.62 .08251 Mdot
.62 .08267 Mdot
.62 .0827 Mdot
.62 .08304 Mdot
.62 .08313 Mdot
.62 .0833 Mdot
.62 .08338 Mdot
.62 .08338 Mdot
.62 .0836 Mdot
.62 .08393 Mdot
.62 .0841 Mdot
.62 .08436 Mdot
.62 .08531 Mdot
.62 .08573 Mdot
.62 .08611 Mdot
.62 .08639 Mdot
.62 .08652 Mdot
.62 .08661 Mdot
.62 .08705 Mdot
.62 .08731 Mdot
.62 .08756 Mdot
.62 .08822 Mdot
.62 .08827 Mdot
.62 .08829 Mdot
.62 .08852 Mdot
.62 .08908 Mdot
.62 .08935 Mdot
.62 .08948 Mdot
.62 .08972 Mdot
.62 .08978 Mdot
.62 .08996 Mdot
.62 .09005 Mdot
.62 .09012 Mdot
.62 .09022 Mdot
.62 .0903 Mdot
.62 .09075 Mdot
.62 .09078 Mdot
.62 .0912 Mdot
.62 .09128 Mdot
.62 .09135 Mdot
.62 .09175 Mdot
.62 .09197 Mdot
.62 .09202 Mdot
.62 .09209 Mdot
.62 .09225 Mdot
.62 .09243 Mdot
.62 .09272 Mdot
.62 .09352 Mdot
.62 .09373 Mdot
.62 .09401 Mdot
.62 .095 Mdot
.62 .09555 Mdot
.62 .09562 Mdot
.62 .09589 Mdot
.62 .09607 Mdot
.62 .09633 Mdot
.62 .09642 Mdot
.62 .09663 Mdot
.62 .09665 Mdot
.62 .09677 Mdot
.62 .0968 Mdot
.62 .09702 Mdot
.62 .0973 Mdot
.62 .09744 Mdot
.62 .09746 Mdot
.62 .09762 Mdot
.62 .09767 Mdot
.62 .098 Mdot
.62 .09838 Mdot
.62 .09847 Mdot
.62 .0987 Mdot
.62 .09874 Mdot
.62 .09878 Mdot
.62 .09897 Mdot
.62 .09902 Mdot
.62 .09944 Mdot
.62 .09955 Mdot
.62 .09976 Mdot
.62 .09986 Mdot
.62 .09986 Mdot
.62 .09989 Mdot
.62 .10013 Mdot
.62 .1003 Mdot
.62 .10054 Mdot
.62 .10075 Mdot
.62 .10108 Mdot
.62 .10181 Mdot
.62 .10225 Mdot
.62 .10278 Mdot
.62 .10324 Mdot
.62 .10359 Mdot
.62 .10375 Mdot
.62 .10387 Mdot
.62 .10441 Mdot
.62 .10474 Mdot
.62 .10505 Mdot
.62 .10586 Mdot
.62 .10592 Mdot
.62 .10595 Mdot
.62 .10624 Mdot
.62 .10693 Mdot
.62 .10727 Mdot
.62 .10742 Mdot
.62 .10773 Mdot
.62 .10779 Mdot
.62 .10802 Mdot
.62 .10812 Mdot
.62 .10822 Mdot
.62 .10834 Mdot
.62 .10844 Mdot
.62 .10899 Mdot
.62 .10904 Mdot
.62 .10956 Mdot
.62 .10966 Mdot
.62 .10974 Mdot
.62 .11024 Mdot
.62 .11051 Mdot
.62 .11058 Mdot
.62 .11065 Mdot
.62 .11085 Mdot
.62 .11108 Mdot
.62 .11145 Mdot
.62 .11243 Mdot
.62 .11269 Mdot
.62 .11304 Mdot
.62 .11426 Mdot
.62 .11495 Mdot
.62 .11504 Mdot
.62 .11537 Mdot
.62 .1156 Mdot
.62 .11591 Mdot
.62 .11603 Mdot
.62 .11629 Mdot
.62 .11631 Mdot
.62 .11647 Mdot
.62 .1165 Mdot
.62 .11677 Mdot
.62 .11712 Mdot
.62 .11729 Mdot
.62 .11732 Mdot
.62 .11751 Mdot
.62 .11758 Mdot
.62 .11798 Mdot
.62 .11847 Mdot
.62 .11857 Mdot
.62 .11886 Mdot
.62 .11891 Mdot
.62 .11895 Mdot
.62 .1192 Mdot
.62 .11925 Mdot
.62 .11978 Mdot
.62 .11991 Mdot
.62 .12017 Mdot
.62 .12029 Mdot
.62 .1203 Mdot
.62 .12033 Mdot
.62 .12063 Mdot
.62 .12084 Mdot
.62 .12114 Mdot
.62 .1214 Mdot
.62 .1218 Mdot
.62 .12271 Mdot
.62 .12326 Mdot
.62 .12391 Mdot
.62 .12449 Mdot
.62 .12492 Mdot
.62 .12512 Mdot
.62 .12526 Mdot
.62 .12593 Mdot
.62 .12634 Mdot
.62 .12673 Mdot
.62 .12773 Mdot
.62 .12781 Mdot
.62 .12784 Mdot
.62 .1282 Mdot
.62 .12906 Mdot
.62 .12948 Mdot
.62 .12967 Mdot
.62 .13005 Mdot
.62 .13013 Mdot
.62 .13041 Mdot
.62 .13054 Mdot
.62 .13066 Mdot
.62 .13081 Mdot
.62 .13093 Mdot
.62 .13162 Mdot
.62 .13168 Mdot
.62 .13232 Mdot
.62 .13244 Mdot
.62 .13254 Mdot
.62 .13316 Mdot
.62 .13351 Mdot
.62 .13358 Mdot
.62 .13368 Mdot
.62 .13393 Mdot
.62 .13421 Mdot
.62 .13466 Mdot
.62 .13588 Mdot
.62 .13621 Mdot
.62 .13664 Mdot
.62 .13815 Mdot
.62 .13901 Mdot
.62 .13912 Mdot
.62 .13953 Mdot
.62 .13981 Mdot
.62 .1402 Mdot
.62 .14034 Mdot
.62 .14067 Mdot
.62 .14069 Mdot
.62 .14089 Mdot
.62 .14093 Mdot
.62 .14127 Mdot
.62 .1417 Mdot
.62 .14191 Mdot
.62 .14195 Mdot
.62 .14218 Mdot
.62 .14226 Mdot
.62 .14277 Mdot
.62 .14337 Mdot
.62 .1435 Mdot
.62 .14385 Mdot
.62 .14392 Mdot
.62 .14397 Mdot
.62 .14427 Mdot
.62 .14434 Mdot
.62 .14499 Mdot
.62 .14515 Mdot
.62 .14548 Mdot
.62 .14563 Mdot
.62 .14564 Mdot
.62 .14568 Mdot
.62 .14605 Mdot
.62 .14632 Mdot
.62 .14668 Mdot
.62 .14701 Mdot
.62 .1475 Mdot
.62 .14863 Mdot
.62 .14931 Mdot
.62 .15012 Mdot
.62 .15084 Mdot
.62 .15136 Mdot
.62 .15162 Mdot
.62 .1518 Mdot
.62 .15263 Mdot
.62 .15313 Mdot
.62 .15361 Mdot
.62 .15485 Mdot
.62 .15496 Mdot
.62 .155 Mdot
.62 .15544 Mdot
.62 .15651 Mdot
.62 .15702 Mdot
.62 .15726 Mdot
.62 .15773 Mdot
.62 .15783 Mdot
.62 .15818 Mdot
.62 .15834 Mdot
.62 .15848 Mdot
.62 .15867 Mdot
.62 .15882 Mdot
.62 .15968 Mdot
.62 .15975 Mdot
.62 .16055 Mdot
.62 .1607 Mdot
.62 .16082 Mdot
.62 .16159 Mdot
.62 .16202 Mdot
.62 .16211 Mdot
.62 .16223 Mdot
.62 .16254 Mdot
.62 .16288 Mdot
.62 .16345 Mdot
.62 .16496 Mdot
.62 .16537 Mdot
.62 .1659 Mdot
.62 .16778 Mdot
.62 .16883 Mdot
.62 .16898 Mdot
.62 .16949 Mdot
.62 .16984 Mdot
.62 .17032 Mdot
.62 .17049 Mdot
.62 .1709 Mdot
.62 .17093 Mdot
.62 .17117 Mdot
.62 .17122 Mdot
.62 .17164 Mdot
.62 .17218 Mdot
.62 .17244 Mdot
.62 .17249 Mdot
.62 .17278 Mdot
.62 .17287 Mdot
.62 .1735 Mdot
.62 .17424 Mdot
.62 .17441 Mdot
.62 .17485 Mdot
.62 .17493 Mdot
.62 .17499 Mdot
.62 .17536 Mdot
.62 .17545 Mdot
.62 .17626 Mdot
.62 .17646 Mdot
.62 .17686 Mdot
.62 .17705 Mdot
.62 .17706 Mdot
.62 .17712 Mdot
.62 .17757 Mdot
.62 .1779 Mdot
.62 .17835 Mdot
.62 .17876 Mdot
.62 .17937 Mdot
.62 .18077 Mdot
.62 .18162 Mdot
.62 .18262 Mdot
.62 .18351 Mdot
.62 .18416 Mdot
.62 .18448 Mdot
.62 .1847 Mdot
.62 .18573 Mdot
.62 .18635 Mdot
.62 .18695 Mdot
.62 .18849 Mdot
.62 .18862 Mdot
.62 .18866 Mdot
.62 .18922 Mdot
.62 .19054 Mdot
.62 .19117 Mdot
.62 .19147 Mdot
.62 .19205 Mdot
.62 .19218 Mdot
.62 .19262 Mdot
.62 .19281 Mdot
.62 .19299 Mdot
.62 .19322 Mdot
.62 .19341 Mdot
.62 .19447 Mdot
.62 .19456 Mdot
.62 .19555 Mdot
.62 .19573 Mdot
.62 .19589 Mdot
.62 .19684 Mdot
.62 .19737 Mdot
.62 .19749 Mdot
.62 .19763 Mdot
.62 .19801 Mdot
.62 .19844 Mdot
.62 .19914 Mdot
.62 .20102 Mdot
.62 .20152 Mdot
.62 .20218 Mdot
.62 .20452 Mdot
.62 .20582 Mdot
.62 .206 Mdot
.62 .20663 Mdot
.62 .20707 Mdot
.62 .20766 Mdot
.62 .20788 Mdot
.62 .20839 Mdot
.62 .20842 Mdot
.62 .20872 Mdot
.62 .20878 Mdot
.62 .2093 Mdot
.62 .20997 Mdot
.62 .21029 Mdot
.62 .21035 Mdot
.62 .21071 Mdot
.62 .21083 Mdot
.62 .21161 Mdot
.62 .21253 Mdot
.62 .21273 Mdot
.62 .21328 Mdot
.62 .21338 Mdot
.62 .21346 Mdot
.62 .21392 Mdot
.62 .21403 Mdot
.62 .21503 Mdot
.62 .21528 Mdot
.62 .21578 Mdot
.62 .216 Mdot
.62 .21602 Mdot
.62 .21609 Mdot
.62 .21666 Mdot
.62 .21706 Mdot
.62 .21763 Mdot
.62 .21813 Mdot
.62 .21889 Mdot
.62 .22062 Mdot
.62 .22167 Mdot
.62 .22292 Mdot
.62 .22402 Mdot
.62 .22483 Mdot
.62 .22522 Mdot
.62 .22549 Mdot
.62 .22677 Mdot
.62 .22755 Mdot
.62 .22828 Mdot
.62 .23019 Mdot
.62 .23035 Mdot
.62 .23041 Mdot
.62 .2311 Mdot
.62 .23274 Mdot
.62 .23352 Mdot
.62 .23389 Mdot
.62 .23461 Mdot
.62 .23477 Mdot
.62 .23531 Mdot
.62 .23556 Mdot
.62 .23577 Mdot
.62 .23606 Mdot
.62 .23629 Mdot
.62 .23761 Mdot
.62 .23772 Mdot
.62 .23895 Mdot
.62 .23917 Mdot
.62 .23937 Mdot
.62 .24055 Mdot
.62 .24121 Mdot
.62 .24135 Mdot
.62 .24154 Mdot
.62 .24201 Mdot
.62 .24254 Mdot
.62 .24341 Mdot
.62 .24573 Mdot
.62 .24636 Mdot
.62 .24717 Mdot
.62 .25007 Mdot
.62 .25169 Mdot
.62 .25191 Mdot
.62 .2527 Mdot
.62 .25323 Mdot
.62 .25397 Mdot
.62 .25424 Mdot
.62 .25487 Mdot
.62 .25491 Mdot
.62 .25528 Mdot
.62 .25535 Mdot
.62 .256 Mdot
.62 .25683 Mdot
.62 .25723 Mdot
.62 .2573 Mdot
.62 .25775 Mdot
.62 .2579 Mdot
.62 .25886 Mdot
.62 .26 Mdot
.62 .26026 Mdot
.62 .26093 Mdot
.62 .26106 Mdot
.62 .26116 Mdot
.62 .26173 Mdot
.62 .26187 Mdot
.62 .26311 Mdot
.62 .26341 Mdot
.62 .26404 Mdot
.62 .26431 Mdot
.62 .26433 Mdot
.62 .26442 Mdot
.62 .26513 Mdot
.62 .26563 Mdot
.62 .26633 Mdot
.62 .26695 Mdot
.62 .26789 Mdot
.62 .27004 Mdot
.62 .27134 Mdot
.62 .27288 Mdot
.62 .27295 Mdot
.62 .27425 Mdot
.62 .27525 Mdot
.62 .27574 Mdot
.62 .27608 Mdot
.62 .27766 Mdot
.62 .27863 Mdot
.62 .27954 Mdot
.62 .28191 Mdot
.62 .2821 Mdot
.62 .28218 Mdot
.62 .28303 Mdot
.62 .28506 Mdot
.62 .28604 Mdot
.62 .2865 Mdot
.62 .28739 Mdot
.62 .28758 Mdot
.62 .28825 Mdot
.62 .28856 Mdot
.62 .28883 Mdot
.62 .28918 Mdot
.62 .28947 Mdot
.62 .29111 Mdot
.62 .29124 Mdot
.62 .29277 Mdot
.62 .29305 Mdot
.62 .29328 Mdot
.62 .29476 Mdot
.62 .29556 Mdot
.62 .29574 Mdot
.62 .29597 Mdot
.62 .29656 Mdot
.62 .29722 Mdot
.62 .29829 Mdot
.62 .30117 Mdot
.62 .30195 Mdot
.62 .30296 Mdot
.62 .30655 Mdot
.62 .30856 Mdot
.62 .30883 Mdot
.62 .30981 Mdot
.62 .31048 Mdot
.62 .31139 Mdot
.62 .31172 Mdot
.62 .31251 Mdot
.62 .31256 Mdot
.62 .31302 Mdot
.62 .31311 Mdot
.62 .31391 Mdot
.62 .31493 Mdot
.62 .31544 Mdot
.62 .31552 Mdot
.62 .31608 Mdot
.62 .31626 Mdot
.62 .31746 Mdot
.62 .31887 Mdot
.62 .31919 Mdot
.62 .32002 Mdot
.62 .32018 Mdot
.62 .3203 Mdot
.62 .32101 Mdot
.62 .32118 Mdot
.62 .32272 Mdot
.62 .3231 Mdot
.62 .32387 Mdot
.62 .32422 Mdot
.62 .32424 Mdot
.62 .32435 Mdot
.62 .32523 Mdot
.62 .32585 Mdot
.62 .32671 Mdot
.62 .32749 Mdot
.62 .32865 Mdot
.62 .33132 Mdot
.62 .33293 Mdot
.62 .33484 Mdot
.62 .33492 Mdot
.62 .33654 Mdot
.62 .33778 Mdot
.62 .33839 Mdot
.62 .3388 Mdot
.62 .34077 Mdot
.62 .34197 Mdot
.62 .3431 Mdot
.62 .34604 Mdot
.62 .34628 Mdot
.62 .34637 Mdot
.62 .34742 Mdot
.62 .34994 Mdot
.62 .35116 Mdot
.62 .35173 Mdot
.62 .35283 Mdot
.62 .35307 Mdot
.62 .3539 Mdot
.62 .35428 Mdot
.62 .35461 Mdot
.62 .35505 Mdot
.62 .35541 Mdot
.62 .35744 Mdot
.62 .35761 Mdot
.62 .3595 Mdot
.62 .35984 Mdot
.62 .36014 Mdot
.62 .36197 Mdot
.62 .36297 Mdot
.62 .36319 Mdot
.62 .36347 Mdot
.62 .3642 Mdot
.62 .36502 Mdot
.62 .36635 Mdot
.62 .36992 Mdot
.62 .37089 Mdot
.62 .37214 Mdot
.62 .37659 Mdot
.62 .37909 Mdot
.62 .37942 Mdot
.62 .38063 Mdot
.622 .01596 Mdot
.622 .01626 Mdot
.622 .01663 Mdot
.622 .01695 Mdot
.622 .0171 Mdot
.622 .0175 Mdot
.622 .01768 Mdot
.622 .018 Mdot
.622 .01818 Mdot
.622 .01841 Mdot
.622 .0187 Mdot
.622 .0188 Mdot
.622 .01902 Mdot
.622 .01931 Mdot
.622 .01967 Mdot
.622 .0198 Mdot
.622 .02007 Mdot
.622 .02043 Mdot
.622 .02088 Mdot
.622 .02098 Mdot
.622 .02104 Mdot
.622 .02138 Mdot
.622 .0215 Mdot
.622 .02183 Mdot
.622 .02238 Mdot
.622 .02242 Mdot
.622 .02251 Mdot
.622 .02258 Mdot
.622 .023 Mdot
.622 .02315 Mdot
.622 .02344 Mdot
.622 .02356 Mdot
.622 .02425 Mdot
.622 .02429 Mdot
.622 .02442 Mdot
.622 .0245 Mdot
.622 .02503 Mdot
.622 .02521 Mdot
.622 .02557 Mdot
.622 .02572 Mdot
.622 .02648 Mdot
.622 .02658 Mdot
.622 .02663 Mdot
.622 .02678 Mdot
.622 .02689 Mdot
.622 .02705 Mdot
.622 .02709 Mdot
.622 .02734 Mdot
.622 .02754 Mdot
.622 .02769 Mdot
.622 .02777 Mdot
.622 .02822 Mdot
.622 .02841 Mdot
.622 .02855 Mdot
.622 .02871 Mdot
.622 .02935 Mdot
.622 .02947 Mdot
.622 .02954 Mdot
.622 .02973 Mdot
.622 .02986 Mdot
.622 .03002 Mdot
.622 .03006 Mdot
.622 .03012 Mdot
.622 .03041 Mdot
.622 .03067 Mdot
.622 .03085 Mdot
.622 .03096 Mdot
.622 .03152 Mdot
.622 .03175 Mdot
.622 .03193 Mdot
.622 .03212 Mdot
.622 .03231 Mdot
.622 .03267 Mdot
.622 .03292 Mdot
.622 .03307 Mdot
.622 .03316 Mdot
.622 .03339 Mdot
.622 .03355 Mdot
.622 .03376 Mdot
.622 .0338 Mdot
.622 .03387 Mdot
.622 .03392 Mdot
.622 .03425 Mdot
.622 .03456 Mdot
.622 .03479 Mdot
.622 .03492 Mdot
.622 .03562 Mdot
.622 .03562 Mdot
.622 .0359 Mdot
.622 .03612 Mdot
.622 .03637 Mdot
.622 .03661 Mdot
.622 .03705 Mdot
.622 .03714 Mdot
.622 .03737 Mdot
.622 .03755 Mdot
.622 .03764 Mdot
.622 .03766 Mdot
.622 .03795 Mdot
.622 .03815 Mdot
.622 .0384 Mdot
.622 .03846 Mdot
.622 .03855 Mdot
.622 .03856 Mdot
.622 .0386 Mdot
.622 .03884 Mdot
.622 .03888 Mdot
.622 .03901 Mdot
.622 .03933 Mdot
.622 .03941 Mdot
.622 .03943 Mdot
.622 .03969 Mdot
.622 .03985 Mdot
.622 .04054 Mdot
.622 .04066 Mdot
.622 .04072 Mdot
.622 .04072 Mdot
.622 .04107 Mdot
.622 .04135 Mdot
.622 .04158 Mdot
.622 .04166 Mdot
.622 .04195 Mdot
.622 .0425 Mdot
.622 .04261 Mdot
.622 .04289 Mdot
.622 .04313 Mdot
.622 .04323 Mdot
.622 .04325 Mdot
.622 .04362 Mdot
.622 .04386 Mdot
.622 .04387 Mdot
.622 .04418 Mdot
.622 .04426 Mdot
.622 .04436 Mdot
.622 .04438 Mdot
.622 .04443 Mdot
.622 .04473 Mdot
.622 .04494 Mdot
.622 .04534 Mdot
.622 .04543 Mdot
.622 .04546 Mdot
.622 .04578 Mdot
.622 .04598 Mdot
.622 .04684 Mdot
.622 .04699 Mdot
.622 .04706 Mdot
.622 .04707 Mdot
.622 .04724 Mdot
.622 .0473 Mdot
.622 .0475 Mdot
.622 .04768 Mdot
.622 .04785 Mdot
.622 .04814 Mdot
.622 .04823 Mdot
.622 .0486 Mdot
.622 .04909 Mdot
.622 .04915 Mdot
.622 .04928 Mdot
.622 .04941 Mdot
.622 .04977 Mdot
.622 .05006 Mdot
.622 .05019 Mdot
.622 .05022 Mdot
.622 .05067 Mdot
.622 .05097 Mdot
.622 .05098 Mdot
.622 .05137 Mdot
.622 .05146 Mdot
.622 .0516 Mdot
.622 .05161 Mdot
.622 .05162 Mdot
.622 .05168 Mdot
.622 .05206 Mdot
.622 .05212 Mdot
.622 .05231 Mdot
.622 .05265 Mdot
.622 .05281 Mdot
.622 .05293 Mdot
.622 .05296 Mdot
.622 .05336 Mdot
.622 .05361 Mdot
.622 .05411 Mdot
.622 .05425 Mdot
.622 .05438 Mdot
.622 .05468 Mdot
.622 .05475 Mdot
.622 .05487 Mdot
.622 .05495 Mdot
.622 .05496 Mdot
.622 .05501 Mdot
.622 .05518 Mdot
.622 .05525 Mdot
.622 .0555 Mdot
.622 .05573 Mdot
.622 .05593 Mdot
.622 .0563 Mdot
.622 .05641 Mdot
.622 .05686 Mdot
.622 .05702 Mdot
.622 .05748 Mdot
.622 .05755 Mdot
.622 .05772 Mdot
.622 .05788 Mdot
.622 .05832 Mdot
.622 .05868 Mdot
.622 .05884 Mdot
.622 .05888 Mdot
.622 .05894 Mdot
.622 .05907 Mdot
.622 .05918 Mdot
.622 .05944 Mdot
.622 .05982 Mdot
.622 .05983 Mdot
.622 .05987 Mdot
.622 .06031 Mdot
.622 .06043 Mdot
.622 .0606 Mdot
.622 .06061 Mdot
.622 .06063 Mdot
.622 .0607 Mdot
.622 .06117 Mdot
.622 .06124 Mdot
.622 .06144 Mdot
.622 .06149 Mdot
.622 .06163 Mdot
.622 .0619 Mdot
.622 .06203 Mdot
.622 .0621 Mdot
.622 .06225 Mdot
.622 .0623 Mdot
.622 .06279 Mdot
.622 .0631 Mdot
.622 .06327 Mdot
.622 .06373 Mdot
.622 .06389 Mdot
.622 .06406 Mdot
.622 .06443 Mdot
.622 .06452 Mdot
.622 .06467 Mdot
.622 .06477 Mdot
.622 .06478 Mdot
.622 .06484 Mdot
.622 .06505 Mdot
.622 .06514 Mdot
.622 .06545 Mdot
.622 .06571 Mdot
.622 .06574 Mdot
.622 .06599 Mdot
.622 .06644 Mdot
.622 .06658 Mdot
.622 .06673 Mdot
.622 .06683 Mdot
.622 .06715 Mdot
.622 .06735 Mdot
.622 .06749 Mdot
.622 .06792 Mdot
.622 .068 Mdot
.622 .06821 Mdot
.622 .06823 Mdot
.622 .06841 Mdot
.622 .06879 Mdot
.622 .06896 Mdot
.622 .0692 Mdot
.622 .06941 Mdot
.622 .06961 Mdot
.622 .06966 Mdot
.622 .06973 Mdot
.622 .06989 Mdot
.622 .07003 Mdot
.622 .07035 Mdot
.622 .07083 Mdot
.622 .07084 Mdot
.622 .07089 Mdot
.622 .07144 Mdot
.622 .07159 Mdot
.622 .07179 Mdot
.622 .07181 Mdot
.622 .07183 Mdot
.622 .07192 Mdot
.622 .0722 Mdot
.622 .0725 Mdot
.622 .0726 Mdot
.622 .07282 Mdot
.622 .07284 Mdot
.622 .0729 Mdot
.622 .07307 Mdot
.622 .07342 Mdot
.622 .07356 Mdot
.622 .07357 Mdot
.622 .07367 Mdot
.622 .07385 Mdot
.622 .07391 Mdot
.622 .07452 Mdot
.622 .07491 Mdot
.622 .07511 Mdot
.622 .07569 Mdot
.622 .07589 Mdot
.622 .0761 Mdot
.622 .07634 Mdot
.622 .07657 Mdot
.622 .07668 Mdot
.622 .07685 Mdot
.622 .07698 Mdot
.622 .077 Mdot
.622 .07707 Mdot
.622 .07734 Mdot
.622 .07744 Mdot
.622 .07783 Mdot
.622 .07783 Mdot
.622 .07815 Mdot
.622 .07818 Mdot
.622 .0785 Mdot
.622 .07906 Mdot
.622 .07924 Mdot
.622 .07942 Mdot
.622 .07954 Mdot
.622 .07994 Mdot
.622 .08003 Mdot
.622 .08019 Mdot
.622 .08037 Mdot
.622 .0809 Mdot
.622 .08101 Mdot
.622 .08126 Mdot
.622 .08129 Mdot
.622 .08152 Mdot
.622 .08192 Mdot
.622 .08198 Mdot
.622 .0822 Mdot
.622 .08249 Mdot
.622 .08276 Mdot
.622 .08301 Mdot
.622 .08306 Mdot
.622 .08316 Mdot
.622 .08335 Mdot
.622 .08337 Mdot
.622 .08353 Mdot
.622 .08393 Mdot
.622 .08452 Mdot
.622 .08453 Mdot
.622 .0846 Mdot
.622 .08484 Mdot
.622 .08528 Mdot
.622 .08537 Mdot
.622 .08546 Mdot
.622 .08572 Mdot
.622 .08574 Mdot
.622 .08576 Mdot
.622 .08583 Mdot
.622 .08587 Mdot
.622 .08622 Mdot
.622 .08658 Mdot
.622 .0866 Mdot
.622 .08672 Mdot
.622 .087 Mdot
.622 .08703 Mdot
.622 .0871 Mdot
.622 .08731 Mdot
.622 .08774 Mdot
.622 .08792 Mdot
.622 .08793 Mdot
.622 .08805 Mdot
.622 .08818 Mdot
.622 .08828 Mdot
.622 .08835 Mdot
.622 .08887 Mdot
.622 .08898 Mdot
.622 .08911 Mdot
.622 .08959 Mdot
.622 .08985 Mdot
.622 .09024 Mdot
.622 .09056 Mdot
.622 .09082 Mdot
.622 .09108 Mdot
.622 .09117 Mdot
.622 .09125 Mdot
.622 .09138 Mdot
.622 .09166 Mdot
.622 .09178 Mdot
.622 .0918 Mdot
.622 .09202 Mdot
.622 .09218 Mdot
.622 .09219 Mdot
.622 .09228 Mdot
.622 .09262 Mdot
.622 .09275 Mdot
.622 .09322 Mdot
.622 .09324 Mdot
.622 .09363 Mdot
.622 .09367 Mdot
.622 .09369 Mdot
.622 .09406 Mdot
.622 .09443 Mdot
.622 .09477 Mdot
.622 .09498 Mdot
.622 .09521 Mdot
.622 .09536 Mdot
.622 .09586 Mdot
.622 .09597 Mdot
.622 .09617 Mdot
.622 .09639 Mdot
.622 .09705 Mdot
.622 .09717 Mdot
.622 .09718 Mdot
.622 .09723 Mdot
.622 .0975 Mdot
.622 .09753 Mdot
.622 .09782 Mdot
.622 .09831 Mdot
.622 .09839 Mdot
.622 .09866 Mdot
.622 .09903 Mdot
.622 .09936 Mdot
.622 .09947 Mdot
.622 .09967 Mdot
.622 .09973 Mdot
.622 .09974 Mdot
.622 .09984 Mdot
.622 .09986 Mdot
.622 .1001 Mdot
.622 .10012 Mdot
.622 .10032 Mdot
.622 .10082 Mdot
.622 .10155 Mdot
.622 .10156 Mdot
.622 .10165 Mdot
.622 .10195 Mdot
.622 .10197 Mdot
.622 .1025 Mdot
.622 .10261 Mdot
.622 .10272 Mdot
.622 .10304 Mdot
.622 .10307 Mdot
.622 .1031 Mdot
.622 .10318 Mdot
.622 .10324 Mdot
.622 .10367 Mdot
.622 .10409 Mdot
.622 .10412 Mdot
.622 .10414 Mdot
.622 .10429 Mdot
.622 .10463 Mdot
.622 .10467 Mdot
.622 .10476 Mdot
.622 .10503 Mdot
.622 .10556 Mdot
.622 .10578 Mdot
.622 .1058 Mdot
.622 .10594 Mdot
.622 .1061 Mdot
.622 .10622 Mdot
.622 .10631 Mdot
.622 .10696 Mdot
.622 .1071 Mdot
.622 .10726 Mdot
.622 .10786 Mdot
.622 .10819 Mdot
.622 .10866 Mdot
.622 .10907 Mdot
.622 .10939 Mdot
.622 .10971 Mdot
.622 .10982 Mdot
.622 .10992 Mdot
.622 .11008 Mdot
.622 .11043 Mdot
.622 .11058 Mdot
.622 .1106 Mdot
.622 .11088 Mdot
.622 .11108 Mdot
.622 .1111 Mdot
.622 .11121 Mdot
.622 .11163 Mdot
.622 .11179 Mdot
.622 .11238 Mdot
.622 .11239 Mdot
.622 .11288 Mdot
.622 .11294 Mdot
.622 .11296 Mdot
.622 .11342 Mdot
.622 .11388 Mdot
.622 .1143 Mdot
.622 .11457 Mdot
.622 .11485 Mdot
.622 .11504 Mdot
.622 .11565 Mdot
.622 .11579 Mdot
.622 .11604 Mdot
.622 .11632 Mdot
.622 .11714 Mdot
.622 .11729 Mdot
.622 .1173 Mdot
.622 .11737 Mdot
.622 .1177 Mdot
.622 .11774 Mdot
.622 .11809 Mdot
.622 .11871 Mdot
.622 .11881 Mdot
.622 .11914 Mdot
.622 .1196 Mdot
.622 .12001 Mdot
.622 .12015 Mdot
.622 .1204 Mdot
.622 .12047 Mdot
.622 .12048 Mdot
.622 .1206 Mdot
.622 .12063 Mdot
.622 .12093 Mdot
.622 .12096 Mdot
.622 .12121 Mdot
.622 .12183 Mdot
.622 .12274 Mdot
.622 .12275 Mdot
.622 .12286 Mdot
.622 .12324 Mdot
.622 .12325 Mdot
.622 .12392 Mdot
.622 .12406 Mdot
.622 .1242 Mdot
.622 .12459 Mdot
.622 .12463 Mdot
.622 .12467 Mdot
.622 .12477 Mdot
.622 .12483 Mdot
.622 .12538 Mdot
.622 .1259 Mdot
.622 .12593 Mdot
.622 .12596 Mdot
.622 .12615 Mdot
.622 .12657 Mdot
.622 .12662 Mdot
.622 .12673 Mdot
.622 .12706 Mdot
.622 .12772 Mdot
.622 .128 Mdot
.622 .12802 Mdot
.622 .1282 Mdot
.622 .1284 Mdot
.622 .12855 Mdot
.622 .12866 Mdot
.622 .12947 Mdot
.622 .12964 Mdot
.622 .12984 Mdot
.622 .13059 Mdot
.622 .13099 Mdot
.622 .13159 Mdot
.622 .1321 Mdot
.622 .13249 Mdot
.622 .13288 Mdot
.622 .13303 Mdot
.622 .13315 Mdot
.622 .13335 Mdot
.622 .13379 Mdot
.622 .13397 Mdot
.622 .134 Mdot
.622 .13434 Mdot
.622 .13459 Mdot
.622 .13461 Mdot
.622 .13476 Mdot
.622 .13527 Mdot
.622 .13547 Mdot
.622 .13621 Mdot
.622 .13623 Mdot
.622 .13683 Mdot
.622 .1369 Mdot
.622 .13693 Mdot
.622 .13751 Mdot
.622 .13808 Mdot
.622 .1386 Mdot
.622 .13893 Mdot
.622 .13928 Mdot
.622 .13952 Mdot
.622 .14028 Mdot
.622 .14046 Mdot
.622 .14076 Mdot
.622 .14111 Mdot
.622 .14213 Mdot
.622 .14232 Mdot
.622 .14233 Mdot
.622 .14242 Mdot
.622 .14282 Mdot
.622 .14288 Mdot
.622 .14332 Mdot
.622 .14409 Mdot
.622 .14421 Mdot
.622 .14462 Mdot
.622 .1452 Mdot
.622 .14571 Mdot
.622 .14587 Mdot
.622 .14618 Mdot
.622 .14628 Mdot
.622 .14629 Mdot
.622 .14644 Mdot
.622 .14648 Mdot
.622 .14685 Mdot
.622 .14689 Mdot
.622 .1472 Mdot
.622 .14796 Mdot
.622 .1491 Mdot
.622 .14912 Mdot
.622 .14925 Mdot
.622 .14972 Mdot
.622 .14974 Mdot
.622 .15056 Mdot
.622 .15073 Mdot
.622 .15091 Mdot
.622 .1514 Mdot
.622 .15145 Mdot
.622 .15149 Mdot
.622 .15162 Mdot
.622 .1517 Mdot
.622 .15238 Mdot
.622 .15302 Mdot
.622 .15307 Mdot
.622 .15311 Mdot
.622 .15334 Mdot
.622 .15386 Mdot
.622 .15393 Mdot
.622 .15406 Mdot
.622 .15448 Mdot
.622 .1553 Mdot
.622 .15564 Mdot
.622 .15567 Mdot
.622 .15589 Mdot
.622 .15614 Mdot
.622 .15633 Mdot
.622 .15647 Mdot
.622 .15747 Mdot
.622 .15768 Mdot
.622 .15793 Mdot
.622 .15886 Mdot
.622 .15936 Mdot
.622 .1601 Mdot
.622 .16074 Mdot
.622 .16122 Mdot
.622 .16172 Mdot
.622 .1619 Mdot
.622 .16205 Mdot
.622 .1623 Mdot
.622 .16284 Mdot
.622 .16307 Mdot
.622 .16311 Mdot
.622 .16353 Mdot
.622 .16384 Mdot
.622 .16387 Mdot
.622 .16405 Mdot
.622 .16469 Mdot
.622 .16494 Mdot
.622 .16586 Mdot
.622 .16588 Mdot
.622 .16663 Mdot
.622 .16672 Mdot
.622 .16675 Mdot
.622 .16747 Mdot
.622 .16818 Mdot
.622 .16882 Mdot
.622 .16924 Mdot
.622 .16968 Mdot
.622 .16997 Mdot
.622 .17092 Mdot
.622 .17114 Mdot
.622 .17152 Mdot
.622 .17195 Mdot
.622 .17322 Mdot
.622 .17346 Mdot
.622 .17347 Mdot
.622 .17357 Mdot
.622 .17408 Mdot
.622 .17415 Mdot
.622 .1747 Mdot
.622 .17565 Mdot
.622 .1758 Mdot
.622 .17632 Mdot
.622 .17703 Mdot
.622 .17767 Mdot
.622 .17788 Mdot
.622 .17826 Mdot
.622 .17838 Mdot
.622 .1784 Mdot
.622 .17858 Mdot
.622 .17863 Mdot
.622 .17909 Mdot
.622 .17914 Mdot
.622 .17952 Mdot
.622 .18048 Mdot
.622 .18189 Mdot
.622 .18191 Mdot
.622 .18207 Mdot
.622 .18266 Mdot
.622 .18268 Mdot
.622 .18371 Mdot
.622 .18392 Mdot
.622 .18414 Mdot
.622 .18476 Mdot
.622 .18481 Mdot
.622 .18487 Mdot
.622 .18502 Mdot
.622 .18513 Mdot
.622 .18597 Mdot
.622 .18677 Mdot
.622 .18682 Mdot
.622 .18687 Mdot
.622 .18716 Mdot
.622 .18782 Mdot
.622 .18789 Mdot
.622 .18806 Mdot
.622 .18858 Mdot
.622 .1896 Mdot
.622 .19002 Mdot
.622 .19006 Mdot
.622 .19034 Mdot
.622 .19065 Mdot
.622 .19088 Mdot
.622 .19105 Mdot
.622 .19231 Mdot
.622 .19257 Mdot
.622 .19288 Mdot
.622 .19404 Mdot
.622 .19466 Mdot
.622 .19558 Mdot
.622 .19637 Mdot
.622 .19697 Mdot
.622 .19759 Mdot
.622 .19781 Mdot
.622 .198 Mdot
.622 .19831 Mdot
.622 .19898 Mdot
.622 .19927 Mdot
.622 .19931 Mdot
.622 .19984 Mdot
.622 .20023 Mdot
.622 .20026 Mdot
.622 .20048 Mdot
.622 .20128 Mdot
.622 .20159 Mdot
.622 .20274 Mdot
.622 .20276 Mdot
.622 .20369 Mdot
.622 .2038 Mdot
.622 .20385 Mdot
.622 .20474 Mdot
.622 .20562 Mdot
.622 .20642 Mdot
.622 .20694 Mdot
.622 .20749 Mdot
.622 .20785 Mdot
.622 .20904 Mdot
.622 .2093 Mdot
.622 .20978 Mdot
.622 .21032 Mdot
.622 .21189 Mdot
.622 .21219 Mdot
.622 .21221 Mdot
.622 .21234 Mdot
.622 .21297 Mdot
.622 .21305 Mdot
.622 .21373 Mdot
.622 .21492 Mdot
.622 .21511 Mdot
.622 .21575 Mdot
.622 .21664 Mdot
.622 .21743 Mdot
.622 .21769 Mdot
.622 .21817 Mdot
.622 .21831 Mdot
.622 .21833 Mdot
.622 .21857 Mdot
.622 .21862 Mdot
.622 .2192 Mdot
.622 .21926 Mdot
.622 .21974 Mdot
.622 .22092 Mdot
.622 .22268 Mdot
.622 .22271 Mdot
.622 .22291 Mdot
.622 .22364 Mdot
.622 .22367 Mdot
.622 .22495 Mdot
.622 .22521 Mdot
.622 .22548 Mdot
.622 .22625 Mdot
.622 .22632 Mdot
.622 .22638 Mdot
.622 .22658 Mdot
.622 .22671 Mdot
.622 .22776 Mdot
.622 .22875 Mdot
.622 .22882 Mdot
.622 .22888 Mdot
.622 .22924 Mdot
.622 .23005 Mdot
.622 .23015 Mdot
.622 .23036 Mdot
.622 .231 Mdot
.622 .23227 Mdot
.622 .2328 Mdot
.622 .23285 Mdot
.622 .2332 Mdot
.622 .23358 Mdot
.622 .23387 Mdot
.622 .23408 Mdot
.622 .23564 Mdot
.622 .23596 Mdot
.622 .23635 Mdot
.622 .23779 Mdot
.622 .23856 Mdot
.622 .23971 Mdot
.622 .24069 Mdot
.622 .24144 Mdot
.622 .24221 Mdot
.622 .24248 Mdot
.622 .24272 Mdot
.622 .24311 Mdot
.622 .24394 Mdot
.622 .2443 Mdot
.622 .24436 Mdot
.622 .24501 Mdot
.622 .24549 Mdot
.622 .24553 Mdot
.622 .24581 Mdot
.622 .2468 Mdot
.622 .24719 Mdot
.622 .24861 Mdot
.622 .24864 Mdot
.622 .24981 Mdot
.622 .24994 Mdot
.622 .25 Mdot
.622 .2511 Mdot
.622 .25221 Mdot
.622 .2532 Mdot
.622 .25385 Mdot
.622 .25452 Mdot
.622 .25497 Mdot
.622 .25645 Mdot
.622 .25678 Mdot
.622 .25738 Mdot
.622 .25804 Mdot
.622 .26 Mdot
.622 .26037 Mdot
.622 .2604 Mdot
.622 .26056 Mdot
.622 .26134 Mdot
.622 .26144 Mdot
.622 .26229 Mdot
.622 .26377 Mdot
.622 .264 Mdot
.622 .26481 Mdot
.622 .26591 Mdot
.622 .26689 Mdot
.622 .26721 Mdot
.622 .26781 Mdot
.622 .26799 Mdot
.622 .26802 Mdot
.622 .26831 Mdot
.622 .26837 Mdot
.622 .26909 Mdot
.622 .26917 Mdot
.622 .26976 Mdot
.622 .27124 Mdot
.622 .27342 Mdot
.622 .27346 Mdot
.622 .2737 Mdot
.622 .27462 Mdot
.622 .27465 Mdot
.622 .27624 Mdot
.622 .27657 Mdot
.622 .27691 Mdot
.622 .27786 Mdot
.622 .27795 Mdot
.622 .27803 Mdot
.622 .27827 Mdot
.622 .27844 Mdot
.622 .27974 Mdot
.622 .28098 Mdot
.622 .28106 Mdot
.622 .28114 Mdot
.622 .28158 Mdot
.622 .2826 Mdot
.622 .28271 Mdot
.622 .28297 Mdot
.622 .28377 Mdot
.622 .28535 Mdot
.622 .28601 Mdot
.622 .28607 Mdot
.622 .2865 Mdot
.622 .28698 Mdot
.622 .28734 Mdot
.622 .28761 Mdot
.622 .28955 Mdot
.622 .28995 Mdot
.622 .29043 Mdot
.622 .29222 Mdot
.622 .29318 Mdot
.622 .29461 Mdot
.622 .29583 Mdot
.622 .29677 Mdot
.622 .29772 Mdot
.622 .29806 Mdot
.622 .29835 Mdot
.622 .29884 Mdot
.622 .29987 Mdot
.622 .30032 Mdot
.622 .30039 Mdot
.622 .3012 Mdot
.622 .3018 Mdot
.622 .30185 Mdot
.622 .3022 Mdot
.622 .30343 Mdot
.622 .30391 Mdot
.622 .30568 Mdot
.622 .30572 Mdot
.622 .30717 Mdot
.622 .30734 Mdot
.622 .3074 Mdot
.622 .30878 Mdot
.622 .31015 Mdot
.622 .31139 Mdot
.622 .31219 Mdot
.622 .31304 Mdot
.622 .3136 Mdot
.622 .31544 Mdot
.622 .31585 Mdot
.622 .31659 Mdot
.622 .31741 Mdot
.622 .31985 Mdot
.622 .32031 Mdot
.622 .32035 Mdot
.622 .32054 Mdot
.622 .32152 Mdot
.622 .32165 Mdot
.622 .3227 Mdot
.622 .32454 Mdot
.622 .32483 Mdot
.622 .32583 Mdot
.622 .3272 Mdot
.622 .32842 Mdot
.622 .32882 Mdot
.622 .32957 Mdot
.622 .32979 Mdot
.622 .32982 Mdot
.622 .33018 Mdot
.622 .33026 Mdot
.622 .33116 Mdot
.622 .33125 Mdot
.622 .332 Mdot
.622 .33383 Mdot
.622 .33654 Mdot
.622 .33659 Mdot
.622 .3369 Mdot
.622 .33803 Mdot
.622 .33808 Mdot
.622 .34005 Mdot
.622 .34046 Mdot
.622 .34089 Mdot
.622 .34207 Mdot
.622 .34217 Mdot
.622 .34228 Mdot
.622 .34258 Mdot
.622 .34279 Mdot
.622 .34441 Mdot
.622 .34595 Mdot
.622 .34605 Mdot
.622 .34614 Mdot
.622 .3467 Mdot
.622 .34796 Mdot
.622 .34811 Mdot
.622 .34843 Mdot
.622 .34943 Mdot
.622 .35139 Mdot
.622 .35221 Mdot
.622 .35229 Mdot
.622 .35282 Mdot
.622 .35341 Mdot
.622 .35386 Mdot
.622 .35419 Mdot
.622 .3566 Mdot
.622 .3571 Mdot
.622 .3577 Mdot
.622 .35993 Mdot
.622 .36113 Mdot
.622 .3629 Mdot
.622 .36442 Mdot
.622 .36559 Mdot
.622 .36677 Mdot
.622 .36719 Mdot
.622 .36756 Mdot
.622 .36817 Mdot
.622 .36945 Mdot
.622 .37001 Mdot
.622 .37009 Mdot
.622 .3711 Mdot
.622 .37185 Mdot
.622 .37192 Mdot
.622 .37234 Mdot
.622 .37388 Mdot
.622 .37448 Mdot
.622 .37668 Mdot
.622 .37673 Mdot
.622 .37853 Mdot
.622 .37874 Mdot
.622 .37882 Mdot
.622 .38053 Mdot
.622 .38224 Mdot
.624 .015 Mdot
.624 .01507 Mdot
.624 .01516 Mdot
.624 .01527 Mdot
.624 .01541 Mdot
.624 .01558 Mdot
.624 .0158 Mdot
.624 .01598 Mdot
.624 .01606 Mdot
.624 .0162 Mdot
.624 .0163 Mdot
.624 .0164 Mdot
.624 .01656 Mdot
.624 .01669 Mdot
.624 .01682 Mdot
.624 .01702 Mdot
.624 .01718 Mdot
.624 .01734 Mdot
.624 .01759 Mdot
.624 .01779 Mdot
.624 .01799 Mdot
.624 .01831 Mdot
.624 .01855 Mdot
.624 .0188 Mdot
.624 .0192 Mdot
.624 .0195 Mdot
.624 .01981 Mdot
.624 .01984 Mdot
.624 .02031 Mdot
.624 .02042 Mdot
.624 .02063 Mdot
.624 .02069 Mdot
.624 .02108 Mdot
.624 .02112 Mdot
.624 .02122 Mdot
.624 .0217 Mdot
.624 .02184 Mdot
.624 .0221 Mdot
.624 .02217 Mdot
.624 .0222 Mdot
.624 .02265 Mdot
.624 .0227 Mdot
.624 .0227 Mdot
.624 .02284 Mdot
.624 .02343 Mdot
.624 .0236 Mdot
.624 .02368 Mdot
.624 .02393 Mdot
.624 .02396 Mdot
.624 .02402 Mdot
.624 .02405 Mdot
.624 .02462 Mdot
.624 .02468 Mdot
.624 .02468 Mdot
.624 .02485 Mdot
.624 .02512 Mdot
.624 .02541 Mdot
.624 .02559 Mdot
.624 .02581 Mdot
.624 .0259 Mdot
.624 .02607 Mdot
.624 .02622 Mdot
.624 .02626 Mdot
.624 .02633 Mdot
.624 .02636 Mdot
.624 .02637 Mdot
.624 .02675 Mdot
.624 .02708 Mdot
.624 .02715 Mdot
.624 .02716 Mdot
.624 .02737 Mdot
.624 .0277 Mdot
.624 .02806 Mdot
.624 .02807 Mdot
.624 .02829 Mdot
.624 .02856 Mdot
.624 .02868 Mdot
.624 .02888 Mdot
.624 .02907 Mdot
.624 .02908 Mdot
.624 .02912 Mdot
.624 .02921 Mdot
.624 .02925 Mdot
.624 .02926 Mdot
.624 .02974 Mdot
.624 .02988 Mdot
.624 .03015 Mdot
.624 .03024 Mdot
.624 .03024 Mdot
.624 .0305 Mdot
.624 .03087 Mdot
.624 .03092 Mdot
.624 .03137 Mdot
.624 .03138 Mdot
.624 .03165 Mdot
.624 .03199 Mdot
.624 .03214 Mdot
.624 .0324 Mdot
.624 .03263 Mdot
.624 .03264 Mdot
.624 .03269 Mdot
.624 .03281 Mdot
.624 .03285 Mdot
.624 .03287 Mdot
.624 .03316 Mdot
.624 .03317 Mdot
.624 .03346 Mdot
.624 .03352 Mdot
.624 .03364 Mdot
.624 .03397 Mdot
.624 .03401 Mdot
.624 .03409 Mdot
.624 .03409 Mdot
.624 .03442 Mdot
.624 .03488 Mdot
.624 .03494 Mdot
.624 .0355 Mdot
.624 .03551 Mdot
.624 .03585 Mdot
.624 .03628 Mdot
.624 .03646 Mdot
.624 .03678 Mdot
.624 .03708 Mdot
.624 .03708 Mdot
.624 .03715 Mdot
.624 .0373 Mdot
.624 .03735 Mdot
.624 .03737 Mdot
.624 .03773 Mdot
.624 .03774 Mdot
.624 .03794 Mdot
.624 .03811 Mdot
.624 .03818 Mdot
.624 .03833 Mdot
.624 .03875 Mdot
.624 .03879 Mdot
.624 .03882 Mdot
.624 .03889 Mdot
.624 .0389 Mdot
.624 .03931 Mdot
.624 .03988 Mdot
.624 .03996 Mdot
.624 .04059 Mdot
.624 .04065 Mdot
.624 .04067 Mdot
.624 .04109 Mdot
.624 .04129 Mdot
.624 .04163 Mdot
.624 .04186 Mdot
.624 .04225 Mdot
.624 .04262 Mdot
.624 .04263 Mdot
.624 .04271 Mdot
.624 .0429 Mdot
.624 .04297 Mdot
.624 .04299 Mdot
.624 .04332 Mdot
.624 .04344 Mdot
.624 .04346 Mdot
.624 .0437 Mdot
.624 .04391 Mdot
.624 .04401 Mdot
.624 .04408 Mdot
.624 .04416 Mdot
.624 .04419 Mdot
.624 .04471 Mdot
.624 .04477 Mdot
.624 .0448 Mdot
.624 .04488 Mdot
.624 .04489 Mdot
.624 .04538 Mdot
.624 .0454 Mdot
.624 .04581 Mdot
.624 .04612 Mdot
.624 .04622 Mdot
.624 .047 Mdot
.624 .04709 Mdot
.624 .04711 Mdot
.624 .04748 Mdot
.624 .04763 Mdot
.624 .04789 Mdot
.624 .04799 Mdot
.624 .0483 Mdot
.624 .04859 Mdot
.624 .04866 Mdot
.624 .04901 Mdot
.624 .04908 Mdot
.624 .0493 Mdot
.624 .04954 Mdot
.624 .04955 Mdot
.624 .04966 Mdot
.624 .04989 Mdot
.624 .04997 Mdot
.624 .05 Mdot
.624 .05031 Mdot
.624 .05041 Mdot
.624 .05056 Mdot
.624 .05058 Mdot
.624 .05089 Mdot
.624 .05115 Mdot
.624 .05127 Mdot
.624 .05137 Mdot
.624 .05146 Mdot
.624 .0515 Mdot
.624 .05177 Mdot
.624 .05215 Mdot
.624 .05222 Mdot
.624 .05222 Mdot
.624 .05226 Mdot
.624 .05237 Mdot
.624 .05238 Mdot
.624 .05288 Mdot
.624 .05299 Mdot
.624 .05302 Mdot
.624 .05352 Mdot
.624 .05391 Mdot
.624 .05403 Mdot
.624 .05404 Mdot
.624 .05501 Mdot
.624 .05512 Mdot
.624 .05514 Mdot
.624 .0556 Mdot
.624 .05562 Mdot
.624 .05569 Mdot
.624 .0558 Mdot
.624 .05599 Mdot
.624 .05611 Mdot
.624 .05625 Mdot
.624 .05654 Mdot
.624 .05663 Mdot
.624 .05699 Mdot
.624 .05708 Mdot
.624 .05751 Mdot
.624 .05761 Mdot
.624 .05788 Mdot
.624 .05818 Mdot
.624 .05819 Mdot
.624 .05832 Mdot
.624 .05861 Mdot
.624 .05872 Mdot
.624 .05875 Mdot
.624 .05914 Mdot
.624 .05927 Mdot
.624 .05944 Mdot
.624 .05945 Mdot
.624 .05948 Mdot
.624 .05986 Mdot
.624 .06019 Mdot
.624 .06033 Mdot
.624 .06046 Mdot
.624 .06058 Mdot
.624 .06062 Mdot
.624 .06096 Mdot
.624 .06143 Mdot
.624 .06152 Mdot
.624 .06152 Mdot
.624 .06157 Mdot
.624 .0617 Mdot
.624 .06172 Mdot
.624 .06235 Mdot
.624 .06248 Mdot
.624 .06251 Mdot
.624 .06251 Mdot
.624 .06315 Mdot
.624 .06363 Mdot
.624 .06378 Mdot
.624 .06379 Mdot
.624 .06382 Mdot
.624 .06493 Mdot
.624 .065 Mdot
.624 .06513 Mdot
.624 .06516 Mdot
.624 .06574 Mdot
.624 .06577 Mdot
.624 .06585 Mdot
.624 .06598 Mdot
.624 .06599 Mdot
.624 .06605 Mdot
.624 .06622 Mdot
.624 .06638 Mdot
.624 .06642 Mdot
.624 .06655 Mdot
.624 .06692 Mdot
.624 .06703 Mdot
.624 .06747 Mdot
.624 .06747 Mdot
.624 .06752 Mdot
.624 .06759 Mdot
.624 .06812 Mdot
.624 .06824 Mdot
.624 .06858 Mdot
.624 .06896 Mdot
.624 .06897 Mdot
.624 .06914 Mdot
.624 .06949 Mdot
.624 .06958 Mdot
.624 .06963 Mdot
.624 .06967 Mdot
.624 .07016 Mdot
.624 .07032 Mdot
.624 .07053 Mdot
.624 .07054 Mdot
.624 .07058 Mdot
.624 .07066 Mdot
.624 .07105 Mdot
.624 .07147 Mdot
.624 .07165 Mdot
.624 .0718 Mdot
.624 .07195 Mdot
.624 .072 Mdot
.624 .07243 Mdot
.624 .07302 Mdot
.624 .07313 Mdot
.624 .07313 Mdot
.624 .07319 Mdot
.624 .07336 Mdot
.624 .07338 Mdot
.624 .07387 Mdot
.624 .07416 Mdot
.624 .07432 Mdot
.624 .07436 Mdot
.624 .07437 Mdot
.624 .07469 Mdot
.624 .07472 Mdot
.624 .07516 Mdot
.624 .07517 Mdot
.624 .07577 Mdot
.624 .07588 Mdot
.624 .07595 Mdot
.624 .07597 Mdot
.624 .076 Mdot
.624 .07637 Mdot
.624 .07652 Mdot
.624 .07738 Mdot
.624 .07747 Mdot
.624 .07764 Mdot
.624 .07767 Mdot
.624 .07839 Mdot
.624 .07843 Mdot
.624 .07853 Mdot
.624 .07869 Mdot
.624 .0787 Mdot
.624 .07878 Mdot
.624 .07899 Mdot
.624 .07919 Mdot
.624 .07924 Mdot
.624 .0794 Mdot
.624 .07986 Mdot
.624 .08 Mdot
.624 .08017 Mdot
.624 .08056 Mdot
.624 .08056 Mdot
.624 .08062 Mdot
.624 .0807 Mdot
.624 .08137 Mdot
.624 .08152 Mdot
.624 .08194 Mdot
.624 .08228 Mdot
.624 .08241 Mdot
.624 .08243 Mdot
.624 .08263 Mdot
.624 .08308 Mdot
.624 .08319 Mdot
.624 .08325 Mdot
.624 .0833 Mdot
.624 .08347 Mdot
.624 .08372 Mdot
.624 .0838 Mdot
.624 .08391 Mdot
.624 .08411 Mdot
.624 .08437 Mdot
.624 .08439 Mdot
.624 .08444 Mdot
.624 .08453 Mdot
.624 .08502 Mdot
.624 .08554 Mdot
.624 .08577 Mdot
.624 .08596 Mdot
.624 .08613 Mdot
.624 .08615 Mdot
.624 .08621 Mdot
.624 .08639 Mdot
.624 .0864 Mdot
.624 .08675 Mdot
.624 .08693 Mdot
.624 .08748 Mdot
.624 .08761 Mdot
.624 .08762 Mdot
.624 .0877 Mdot
.624 .0879 Mdot
.624 .08793 Mdot
.624 .08855 Mdot
.624 .08891 Mdot
.624 .08911 Mdot
.624 .08915 Mdot
.624 .08916 Mdot
.624 .08956 Mdot
.624 .0896 Mdot
.624 .0896 Mdot
.624 .08969 Mdot
.624 .09015 Mdot
.624 .09016 Mdot
.624 .09091 Mdot
.624 .09104 Mdot
.624 .09113 Mdot
.624 .09116 Mdot
.624 .0912 Mdot
.624 .09165 Mdot
.624 .09184 Mdot
.624 .09293 Mdot
.624 .09304 Mdot
.624 .09324 Mdot
.624 .09329 Mdot
.624 .09406 Mdot
.624 .09418 Mdot
.624 .09423 Mdot
.624 .09435 Mdot
.624 .09456 Mdot
.624 .09457 Mdot
.624 .09467 Mdot
.624 .09488 Mdot
.624 .09494 Mdot
.624 .09518 Mdot
.624 .09524 Mdot
.624 .09538 Mdot
.624 .09544 Mdot
.624 .09553 Mdot
.624 .09581 Mdot
.624 .09602 Mdot
.624 .09619 Mdot
.624 .0964 Mdot
.624 .09689 Mdot
.624 .09689 Mdot
.624 .09696 Mdot
.624 .09707 Mdot
.624 .0979 Mdot
.624 .09809 Mdot
.624 .09846 Mdot
.624 .09861 Mdot
.624 .09904 Mdot
.624 .0992 Mdot
.624 .09922 Mdot
.624 .09948 Mdot
.624 .09957 Mdot
.624 .09992 Mdot
.624 .10003 Mdot
.624 .10017 Mdot
.624 .10025 Mdot
.624 .10031 Mdot
.624 .10052 Mdot
.624 .10083 Mdot
.624 .10093 Mdot
.624 .10107 Mdot
.624 .10131 Mdot
.624 .10165 Mdot
.624 .10166 Mdot
.624 .10173 Mdot
.624 .10185 Mdot
.624 .10246 Mdot
.624 .10311 Mdot
.624 .10339 Mdot
.624 .10362 Mdot
.624 .10385 Mdot
.624 .10386 Mdot
.624 .10394 Mdot
.624 .10416 Mdot
.624 .10417 Mdot
.624 .10461 Mdot
.624 .10484 Mdot
.624 .10552 Mdot
.624 .10569 Mdot
.624 .1057 Mdot
.624 .1058 Mdot
.624 .10595 Mdot
.624 .10605 Mdot
.624 .10608 Mdot
.624 .10686 Mdot
.624 .1073 Mdot
.624 .10756 Mdot
.624 .10761 Mdot
.624 .10763 Mdot
.624 .10812 Mdot
.624 .10817 Mdot
.624 .10818 Mdot
.624 .10829 Mdot
.624 .10886 Mdot
.624 .10888 Mdot
.624 .1098 Mdot
.624 .10997 Mdot
.624 .11008 Mdot
.624 .11011 Mdot
.624 .11017 Mdot
.624 .11074 Mdot
.624 .11097 Mdot
.624 .11232 Mdot
.624 .11246 Mdot
.624 .11272 Mdot
.624 .11277 Mdot
.624 .11374 Mdot
.624 .11389 Mdot
.624 .11395 Mdot
.624 .11411 Mdot
.624 .11436 Mdot
.624 .11437 Mdot
.624 .1145 Mdot
.624 .11476 Mdot
.624 .11483 Mdot
.624 .11514 Mdot
.624 .11521 Mdot
.624 .11539 Mdot
.624 .11547 Mdot
.624 .11557 Mdot
.624 .11592 Mdot
.624 .11618 Mdot
.624 .1164 Mdot
.624 .11666 Mdot
.624 .11726 Mdot
.624 .11727 Mdot
.624 .11736 Mdot
.624 .11749 Mdot
.624 .11853 Mdot
.624 .11876 Mdot
.624 .11923 Mdot
.624 .11942 Mdot
.624 .11995 Mdot
.624 .12016 Mdot
.624 .12018 Mdot
.624 .1205 Mdot
.624 .12061 Mdot
.624 .12105 Mdot
.624 .12119 Mdot
.624 .12137 Mdot
.624 .12146 Mdot
.624 .12154 Mdot
.624 .1218 Mdot
.624 .12219 Mdot
.624 .12231 Mdot
.624 .12248 Mdot
.624 .12279 Mdot
.624 .12321 Mdot
.624 .12323 Mdot
.624 .12331 Mdot
.624 .12345 Mdot
.624 .12422 Mdot
.624 .12503 Mdot
.624 .12538 Mdot
.624 .12567 Mdot
.624 .12595 Mdot
.624 .12597 Mdot
.624 .12607 Mdot
.624 .12635 Mdot
.624 .12636 Mdot
.624 .12691 Mdot
.624 .12719 Mdot
.624 .12804 Mdot
.624 .12826 Mdot
.624 .12826 Mdot
.624 .12838 Mdot
.624 .12857 Mdot
.624 .1287 Mdot
.624 .12874 Mdot
.624 .12971 Mdot
.624 .13027 Mdot
.624 .13058 Mdot
.624 .13065 Mdot
.624 .13067 Mdot
.624 .13129 Mdot
.624 .13135 Mdot
.624 .13136 Mdot
.624 .1315 Mdot
.624 .1322 Mdot
.624 .13223 Mdot
.624 .13338 Mdot
.624 .1336 Mdot
.624 .13373 Mdot
.624 .13377 Mdot
.624 .13385 Mdot
.624 .13455 Mdot
.624 .13484 Mdot
.624 .13653 Mdot
.624 .1367 Mdot
.624 .13702 Mdot
.624 .13709 Mdot
.624 .1383 Mdot
.624 .13849 Mdot
.624 .13856 Mdot
.624 .13875 Mdot
.624 .13908 Mdot
.624 .13909 Mdot
.624 .13924 Mdot
.624 .13957 Mdot
.624 .13966 Mdot
.624 .14004 Mdot
.624 .14014 Mdot
.624 .14035 Mdot
.624 .14045 Mdot
.624 .14058 Mdot
.624 .14101 Mdot
.624 .14135 Mdot
.624 .14161 Mdot
.624 .14194 Mdot
.624 .1427 Mdot
.624 .1427 Mdot
.624 .14282 Mdot
.624 .14298 Mdot
.624 .14428 Mdot
.624 .14457 Mdot
.624 .14515 Mdot
.624 .14538 Mdot
.624 .14605 Mdot
.624 .1463 Mdot
.624 .14633 Mdot
.624 .14673 Mdot
.624 .14688 Mdot
.624 .14743 Mdot
.624 .1476 Mdot
.624 .14782 Mdot
.624 .14793 Mdot
.624 .14803 Mdot
.624 .14836 Mdot
.624 .14885 Mdot
.624 .14899 Mdot
.624 .14921 Mdot
.624 .14959 Mdot
.624 .15012 Mdot
.624 .15014 Mdot
.624 .15024 Mdot
.624 .15042 Mdot
.624 .15138 Mdot
.624 .15239 Mdot
.624 .15283 Mdot
.624 .15319 Mdot
.624 .15354 Mdot
.624 .15356 Mdot
.624 .15368 Mdot
.624 .15403 Mdot
.624 .15405 Mdot
.624 .15473 Mdot
.624 .15508 Mdot
.624 .15615 Mdot
.624 .15641 Mdot
.624 .15643 Mdot
.624 .15657 Mdot
.624 .15681 Mdot
.624 .15697 Mdot
.624 .15702 Mdot
.624 .15822 Mdot
.624 .15892 Mdot
.624 .15932 Mdot
.624 .1594 Mdot
.624 .15942 Mdot
.624 .1602 Mdot
.624 .16028 Mdot
.624 .16028 Mdot
.624 .16046 Mdot
.624 .16134 Mdot
.624 .16137 Mdot
.624 .16281 Mdot
.624 .16308 Mdot
.624 .16325 Mdot
.624 .1633 Mdot
.624 .16339 Mdot
.624 .16427 Mdot
.624 .16463 Mdot
.624 .16674 Mdot
.624 .16695 Mdot
.624 .16736 Mdot
.624 .16744 Mdot
.624 .16895 Mdot
.624 .16919 Mdot
.624 .16927 Mdot
.624 .16952 Mdot
.624 .16992 Mdot
.624 .17012 Mdot
.624 .17053 Mdot
.624 .17065 Mdot
.624 .17112 Mdot
.624 .17124 Mdot
.624 .17151 Mdot
.624 .17163 Mdot
.624 .17179 Mdot
.624 .17234 Mdot
.624 .17275 Mdot
.624 .17308 Mdot
.624 .17349 Mdot
.624 .17443 Mdot
.624 .17444 Mdot
.624 .17459 Mdot
.624 .17479 Mdot
.624 .17641 Mdot
.624 .17677 Mdot
.624 .1775 Mdot
.624 .17779 Mdot
.624 .17862 Mdot
.624 .17894 Mdot
.624 .17897 Mdot
.624 .17947 Mdot
.624 .17965 Mdot
.624 .18034 Mdot
.624 .18055 Mdot
.624 .18083 Mdot
.624 .18097 Mdot
.624 .18109 Mdot
.624 .18151 Mdot
.624 .18211 Mdot
.624 .18229 Mdot
.624 .18257 Mdot
.624 .18304 Mdot
.624 .1837 Mdot
.624 .18372 Mdot
.624 .18385 Mdot
.624 .18408 Mdot
.624 .18527 Mdot
.624 .18653 Mdot
.624 .18708 Mdot
.624 .18753 Mdot
.624 .18797 Mdot
.624 .18799 Mdot
.624 .18815 Mdot
.624 .18858 Mdot
.624 .1886 Mdot
.624 .18945 Mdot
.624 .18989 Mdot
.624 .19122 Mdot
.624 .19155 Mdot
.624 .19157 Mdot
.624 .19175 Mdot
.624 .19205 Mdot
.624 .19225 Mdot
.624 .19231 Mdot
.624 .19381 Mdot
.624 .19469 Mdot
.624 .19518 Mdot
.624 .19528 Mdot
.624 .19531 Mdot
.624 .19627 Mdot
.624 .19638 Mdot
.624 .19638 Mdot
.624 .1966 Mdot
.624 .1977 Mdot
.624 .19774 Mdot
.624 .19954 Mdot
.624 .19988 Mdot
.624 .20009 Mdot
.624 .20015 Mdot
.624 .20026 Mdot
.624 .20136 Mdot
.624 .20181 Mdot
.624 .20444 Mdot
.624 .20471 Mdot
.624 .20521 Mdot
.624 .20532 Mdot
.624 .2072 Mdot
.624 .20749 Mdot
.624 .2076 Mdot
.624 .20791 Mdot
.624 .20841 Mdot
.624 .20867 Mdot
.624 .20917 Mdot
.624 .20932 Mdot
.624 .20991 Mdot
.624 .21006 Mdot
.624 .2104 Mdot
.624 .21055 Mdot
.624 .21075 Mdot
.624 .21143 Mdot
.624 .21195 Mdot
.624 .21236 Mdot
.624 .21287 Mdot
.624 .21404 Mdot
.624 .21405 Mdot
.624 .21423 Mdot
.624 .21448 Mdot
.624 .21651 Mdot
.624 .21696 Mdot
.624 .21787 Mdot
.624 .21823 Mdot
.624 .21927 Mdot
.624 .21967 Mdot
.624 .21971 Mdot
.624 .22033 Mdot
.624 .22056 Mdot
.624 .22141 Mdot
.624 .22168 Mdot
.624 .22202 Mdot
.624 .2222 Mdot
.624 .22235 Mdot
.624 .22287 Mdot
.624 .22362 Mdot
.624 .22385 Mdot
.624 .22419 Mdot
.624 .22479 Mdot
.624 .2256 Mdot
.624 .22564 Mdot
.624 .22579 Mdot
.624 .22608 Mdot
.624 .22757 Mdot
.624 .22914 Mdot
.624 .22982 Mdot
.624 .23039 Mdot
.624 .23093 Mdot
.624 .23097 Mdot
.624 .23116 Mdot
.624 .2317 Mdot
.624 .23173 Mdot
.624 .23279 Mdot
.624 .23334 Mdot
.624 .23499 Mdot
.624 .23541 Mdot
.624 .23543 Mdot
.624 .23566 Mdot
.624 .23602 Mdot
.624 .23627 Mdot
.624 .23635 Mdot
.624 .23823 Mdot
.624 .23932 Mdot
.624 .23993 Mdot
.624 .24006 Mdot
.624 .2401 Mdot
.624 .2413 Mdot
.624 .24143 Mdot
.624 .24144 Mdot
.624 .24171 Mdot
.624 .24309 Mdot
.624 .24313 Mdot
.624 .24538 Mdot
.624 .2458 Mdot
.624 .24606 Mdot
.624 .24613 Mdot
.624 .24628 Mdot
.624 .24764 Mdot
.624 .24821 Mdot
.624 .25149 Mdot
.624 .25182 Mdot
.624 .25245 Mdot
.624 .25259 Mdot
.624 .25493 Mdot
.624 .2553 Mdot
.624 .25544 Mdot
.624 .25582 Mdot
.624 .25644 Mdot
.624 .25677 Mdot
.624 .2574 Mdot
.624 .25758 Mdot
.624 .25832 Mdot
.624 .2585 Mdot
.624 .25893 Mdot
.624 .25912 Mdot
.624 .25937 Mdot
.624 .26021 Mdot
.624 .26086 Mdot
.624 .26137 Mdot
.624 .26201 Mdot
.624 .26348 Mdot
.624 .26349 Mdot
.624 .26371 Mdot
.624 .26403 Mdot
.624 .26655 Mdot
.624 .26712 Mdot
.624 .26825 Mdot
.624 .2687 Mdot
.624 .27 Mdot
.624 .27049 Mdot
.624 .27055 Mdot
.624 .27133 Mdot
.624 .2716 Mdot
.624 .27267 Mdot
.624 .27301 Mdot
.624 .27344 Mdot
.624 .27366 Mdot
.624 .27384 Mdot
.624 .27449 Mdot
.624 .27543 Mdot
.624 .27572 Mdot
.624 .27615 Mdot
.624 .27689 Mdot
.624 .2779 Mdot
.624 .27795 Mdot
.624 .27814 Mdot
.624 .2785 Mdot
.624 .28035 Mdot
.624 .28232 Mdot
.624 .28317 Mdot
.624 .28388 Mdot
.624 .28455 Mdot
.624 .2846 Mdot
.624 .28483 Mdot
.624 .28551 Mdot
.624 .28554 Mdot
.624 .28687 Mdot
.624 .28756 Mdot
.624 .28962 Mdot
.624 .29014 Mdot
.624 .29017 Mdot
.624 .29046 Mdot
.624 .29091 Mdot
.624 .29122 Mdot
.624 .29132 Mdot
.624 .29366 Mdot
.624 .29502 Mdot
.624 .29578 Mdot
.624 .29594 Mdot
.624 .29599 Mdot
.624 .29749 Mdot
.624 .29766 Mdot
.624 .29766 Mdot
.624 .298 Mdot
.624 .29972 Mdot
.624 .29978 Mdot
.624 .30258 Mdot
.624 .30311 Mdot
.624 .30343 Mdot
.624 .30352 Mdot
.624 .3037 Mdot
.624 .30541 Mdot
.624 .30612 Mdot
.624 .31021 Mdot
.624 .31063 Mdot
.624 .31141 Mdot
.624 .31158 Mdot
.624 .31451 Mdot
.624 .31497 Mdot
.624 .31514 Mdot
.624 .31561 Mdot
.624 .31639 Mdot
.624 .31679 Mdot
.624 .31758 Mdot
.624 .31781 Mdot
.624 .31873 Mdot
.624 .31896 Mdot
.624 .31949 Mdot
.624 .31973 Mdot
.624 .32004 Mdot
.624 .3211 Mdot
.624 .3219 Mdot
.624 .32255 Mdot
.624 .32334 Mdot
.624 .32517 Mdot
.624 .32518 Mdot
.624 .32547 Mdot
.624 .32586 Mdot
.624 .329 Mdot
.624 .32971 Mdot
.624 .33113 Mdot
.624 .33169 Mdot
.624 .33332 Mdot
.624 .33393 Mdot
.624 .33399 Mdot
.624 .33497 Mdot
.624 .33531 Mdot
.624 .33665 Mdot
.624 .33706 Mdot
.624 .3376 Mdot
.624 .33787 Mdot
.624 .33811 Mdot
.624 .33892 Mdot
.624 .34009 Mdot
.624 .34045 Mdot
.624 .34098 Mdot
.624 .34191 Mdot
.624 .34317 Mdot
.624 .34323 Mdot
.624 .34347 Mdot
.624 .34391 Mdot
.624 .34623 Mdot
.624 .34869 Mdot
.624 .34975 Mdot
.624 .35063 Mdot
.624 .35147 Mdot
.624 .35153 Mdot
.624 .35182 Mdot
.624 .35267 Mdot
.624 .35271 Mdot
.624 .35436 Mdot
.624 .35522 Mdot
.624 .3578 Mdot
.624 .35845 Mdot
.624 .35848 Mdot
.624 .35884 Mdot
.624 .3594 Mdot
.624 .3598 Mdot
.624 .35992 Mdot
.624 .36284 Mdot
.624 .36454 Mdot
.624 .36549 Mdot
.624 .36569 Mdot
.624 .36575 Mdot
.624 .36762 Mdot
.624 .36783 Mdot
.624 .36783 Mdot
.624 .36826 Mdot
.624 .3704 Mdot
.624 .37048 Mdot
.624 .37398 Mdot
.624 .37463 Mdot
.624 .37503 Mdot
.624 .37515 Mdot
.624 .37537 Mdot
.624 .3775 Mdot
.624 .37839 Mdot
.624 .3835 Mdot
.626 .01613 Mdot
.626 .01649 Mdot
.626 .01694 Mdot
.626 .0175 Mdot
.626 .01812 Mdot
.626 .0182 Mdot
.626 .01898 Mdot
.626 .01908 Mdot
.626 .01928 Mdot
.626 .02005 Mdot
.626 .02017 Mdot
.626 .02018 Mdot
.626 .02043 Mdot
.626 .0214 Mdot
.626 .02154 Mdot
.626 .02155 Mdot
.626 .02187 Mdot
.626 .0223 Mdot
.626 .02308 Mdot
.626 .02326 Mdot
.626 .02328 Mdot
.626 .02342 Mdot
.626 .02364 Mdot
.626 .02368 Mdot
.626 .0238 Mdot
.626 .02421 Mdot
.626 .0247 Mdot
.626 .02508 Mdot
.626 .02519 Mdot
.626 .02521 Mdot
.626 .02542 Mdot
.626 .02543 Mdot
.626 .02548 Mdot
.626 .02562 Mdot
.626 .02589 Mdot
.626 .02594 Mdot
.626 .02604 Mdot
.626 .0261 Mdot
.626 .02617 Mdot
.626 .02638 Mdot
.626 .02645 Mdot
.626 .02659 Mdot
.626 .02661 Mdot
.626 .02703 Mdot
.626 .02721 Mdot
.626 .02759 Mdot
.626 .02769 Mdot
.626 .02783 Mdot
.626 .02785 Mdot
.626 .02811 Mdot
.626 .02814 Mdot
.626 .0282 Mdot
.626 .02836 Mdot
.626 .0287 Mdot
.626 .02877 Mdot
.626 .02889 Mdot
.626 .02896 Mdot
.626 .02906 Mdot
.626 .02932 Mdot
.626 .02941 Mdot
.626 .02959 Mdot
.626 .0296 Mdot
.626 .03013 Mdot
.626 .03036 Mdot
.626 .03083 Mdot
.626 .03096 Mdot
.626 .03114 Mdot
.626 .03115 Mdot
.626 .03117 Mdot
.626 .03119 Mdot
.626 .03149 Mdot
.626 .03152 Mdot
.626 .03159 Mdot
.626 .0318 Mdot
.626 .03223 Mdot
.626 .03231 Mdot
.626 .03246 Mdot
.626 .03255 Mdot
.626 .03268 Mdot
.626 .03279 Mdot
.626 .03299 Mdot
.626 .03311 Mdot
.626 .03334 Mdot
.626 .03335 Mdot
.626 .03402 Mdot
.626 .03414 Mdot
.626 .0343 Mdot
.626 .03459 Mdot
.626 .03489 Mdot
.626 .03506 Mdot
.626 .03521 Mdot
.626 .03528 Mdot
.626 .03529 Mdot
.626 .03531 Mdot
.626 .03534 Mdot
.626 .03572 Mdot
.626 .03575 Mdot
.626 .03585 Mdot
.626 .03608 Mdot
.626 .03611 Mdot
.626 .03664 Mdot
.626 .03674 Mdot
.626 .03694 Mdot
.626 .03696 Mdot
.626 .03705 Mdot
.626 .0372 Mdot
.626 .03735 Mdot
.626 .0376 Mdot
.626 .03774 Mdot
.626 .03803 Mdot
.626 .03805 Mdot
.626 .03854 Mdot
.626 .03888 Mdot
.626 .03904 Mdot
.626 .03924 Mdot
.626 .03959 Mdot
.626 .03998 Mdot
.626 .04018 Mdot
.626 .04038 Mdot
.626 .04046 Mdot
.626 .04047 Mdot
.626 .0405 Mdot
.626 .04054 Mdot
.626 .04101 Mdot
.626 .04105 Mdot
.626 .04117 Mdot
.626 .04128 Mdot
.626 .04146 Mdot
.626 .0415 Mdot
.626 .04183 Mdot
.626 .04217 Mdot
.626 .04219 Mdot
.626 .04229 Mdot
.626 .04254 Mdot
.626 .04256 Mdot
.626 .04268 Mdot
.626 .04282 Mdot
.626 .04287 Mdot
.626 .04305 Mdot
.626 .04337 Mdot
.626 .04355 Mdot
.626 .04375 Mdot
.626 .0439 Mdot
.626 .04393 Mdot
.626 .04454 Mdot
.626 .04497 Mdot
.626 .04517 Mdot
.626 .04542 Mdot
.626 .04586 Mdot
.626 .04635 Mdot
.626 .0466 Mdot
.626 .0468 Mdot
.626 .04685 Mdot
.626 .04693 Mdot
.626 .04695 Mdot
.626 .04696 Mdot
.626 .047 Mdot
.626 .04705 Mdot
.626 .04735 Mdot
.626 .04764 Mdot
.626 .04769 Mdot
.626 .04784 Mdot
.626 .04797 Mdot
.626 .0482 Mdot
.626 .04825 Mdot
.626 .04828 Mdot
.626 .04841 Mdot
.626 .04867 Mdot
.626 .04909 Mdot
.626 .04912 Mdot
.626 .04924 Mdot
.626 .04955 Mdot
.626 .04958 Mdot
.626 .04972 Mdot
.626 .0499 Mdot
.626 .04997 Mdot
.626 .05001 Mdot
.626 .05019 Mdot
.626 .05059 Mdot
.626 .05081 Mdot
.626 .05107 Mdot
.626 .05126 Mdot
.626 .05129 Mdot
.626 .05178 Mdot
.626 .05206 Mdot
.626 .0521 Mdot
.626 .0526 Mdot
.626 .05284 Mdot
.626 .05315 Mdot
.626 .05355 Mdot
.626 .05371 Mdot
.626 .05432 Mdot
.626 .05464 Mdot
.626 .05489 Mdot
.626 .05493 Mdot
.626 .05494 Mdot
.626 .05504 Mdot
.626 .05507 Mdot
.626 .05509 Mdot
.626 .05514 Mdot
.626 .05519 Mdot
.626 .05557 Mdot
.626 .05557 Mdot
.626 .05593 Mdot
.626 .056 Mdot
.626 .05618 Mdot
.626 .05635 Mdot
.626 .05664 Mdot
.626 .0567 Mdot
.626 .05674 Mdot
.626 .0569 Mdot
.626 .05722 Mdot
.626 .05724 Mdot
.626 .05756 Mdot
.626 .05775 Mdot
.626 .05778 Mdot
.626 .05794 Mdot
.626 .05833 Mdot
.626 .05836 Mdot
.626 .05855 Mdot
.626 .05877 Mdot
.626 .05885 Mdot
.626 .0589 Mdot
.626 .05903 Mdot
.626 .05913 Mdot
.626 .05931 Mdot
.626 .05963 Mdot
.626 .05991 Mdot
.626 .06023 Mdot
.626 .06047 Mdot
.626 .06051 Mdot
.626 .0609 Mdot
.626 .06112 Mdot
.626 .0614 Mdot
.626 .06144 Mdot
.626 .06147 Mdot
.626 .06152 Mdot
.626 .06215 Mdot
.626 .06218 Mdot
.626 .06245 Mdot
.626 .06268 Mdot
.626 .06284 Mdot
.626 .06314 Mdot
.626 .06333 Mdot
.626 .06354 Mdot
.626 .06388 Mdot
.626 .0643 Mdot
.626 .06441 Mdot
.626 .0647 Mdot
.626 .06484 Mdot
.626 .06501 Mdot
.626 .06506 Mdot
.626 .06508 Mdot
.626 .06521 Mdot
.626 .06524 Mdot
.626 .06526 Mdot
.626 .06532 Mdot
.626 .06539 Mdot
.626 .06587 Mdot
.626 .06587 Mdot
.626 .06632 Mdot
.626 .0664 Mdot
.626 .06652 Mdot
.626 .06663 Mdot
.626 .06684 Mdot
.626 .06721 Mdot
.626 .06728 Mdot
.626 .06733 Mdot
.626 .06753 Mdot
.626 .06794 Mdot
.626 .06795 Mdot
.626 .06836 Mdot
.626 .0686 Mdot
.626 .06864 Mdot
.626 .06883 Mdot
.626 .06901 Mdot
.626 .06932 Mdot
.626 .06936 Mdot
.626 .06955 Mdot
.626 .06959 Mdot
.626 .06987 Mdot
.626 .06997 Mdot
.626 .07004 Mdot
.626 .0702 Mdot
.626 .07032 Mdot
.626 .07055 Mdot
.626 .07095 Mdot
.626 .0713 Mdot
.626 .0717 Mdot
.626 .072 Mdot
.626 .07205 Mdot
.626 .0722 Mdot
.626 .07254 Mdot
.626 .07282 Mdot
.626 .07316 Mdot
.626 .07322 Mdot
.626 .07325 Mdot
.626 .07332 Mdot
.626 .0741 Mdot
.626 .07414 Mdot
.626 .07448 Mdot
.626 .07477 Mdot
.626 .07497 Mdot
.626 .07521 Mdot
.626 .07534 Mdot
.626 .07558 Mdot
.626 .07585 Mdot
.626 .07627 Mdot
.626 .0766 Mdot
.626 .07679 Mdot
.626 .07694 Mdot
.626 .07729 Mdot
.626 .07748 Mdot
.626 .07751 Mdot
.626 .07769 Mdot
.626 .07775 Mdot
.626 .07777 Mdot
.626 .07791 Mdot
.626 .07793 Mdot
.626 .07797 Mdot
.626 .07798 Mdot
.626 .078 Mdot
.626 .07807 Mdot
.626 .07817 Mdot
.626 .07876 Mdot
.626 .07876 Mdot
.626 .07903 Mdot
.626 .07925 Mdot
.626 .07933 Mdot
.626 .07943 Mdot
.626 .07957 Mdot
.626 .07972 Mdot
.626 .07998 Mdot
.626 .08043 Mdot
.626 .08053 Mdot
.626 .08059 Mdot
.626 .08069 Mdot
.626 .08084 Mdot
.626 .08135 Mdot
.626 .08137 Mdot
.626 .08162 Mdot
.626 .08188 Mdot
.626 .08217 Mdot
.626 .08223 Mdot
.626 .08247 Mdot
.626 .08269 Mdot
.626 .08308 Mdot
.626 .08313 Mdot
.626 .08337 Mdot
.626 .08342 Mdot
.626 .08368 Mdot
.626 .08377 Mdot
.626 .08377 Mdot
.626 .0839 Mdot
.626 .08398 Mdot
.626 .08405 Mdot
.626 .08418 Mdot
.626 .08434 Mdot
.626 .08461 Mdot
.626 .08512 Mdot
.626 .08556 Mdot
.626 .08605 Mdot
.626 .08628 Mdot
.626 .08644 Mdot
.626 .0865 Mdot
.626 .08669 Mdot
.626 .08672 Mdot
.626 .08696 Mdot
.626 .08712 Mdot
.626 .08746 Mdot
.626 .08747 Mdot
.626 .08752 Mdot
.626 .08789 Mdot
.626 .08796 Mdot
.626 .088 Mdot
.626 .08809 Mdot
.626 .08906 Mdot
.626 .08912 Mdot
.626 .08954 Mdot
.626 .0899 Mdot
.626 .09015 Mdot
.626 .09046 Mdot
.626 .09062 Mdot
.626 .09092 Mdot
.626 .09125 Mdot
.626 .09178 Mdot
.626 .09219 Mdot
.626 .09243 Mdot
.626 .09262 Mdot
.626 .09306 Mdot
.626 .09329 Mdot
.626 .09334 Mdot
.626 .09337 Mdot
.626 .09356 Mdot
.626 .09364 Mdot
.626 .09366 Mdot
.626 .09372 Mdot
.626 .09383 Mdot
.626 .09386 Mdot
.626 .0939 Mdot
.626 .09392 Mdot
.626 .09395 Mdot
.626 .09404 Mdot
.626 .09416 Mdot
.626 .09489 Mdot
.626 .0949 Mdot
.626 .09523 Mdot
.626 .09552 Mdot
.626 .09561 Mdot
.626 .09574 Mdot
.626 .09592 Mdot
.626 .0961 Mdot
.626 .09628 Mdot
.626 .09643 Mdot
.626 .09699 Mdot
.626 .09711 Mdot
.626 .09718 Mdot
.626 .09731 Mdot
.626 .09751 Mdot
.626 .09814 Mdot
.626 .09817 Mdot
.626 .09825 Mdot
.626 .09845 Mdot
.626 .09847 Mdot
.626 .09881 Mdot
.626 .09917 Mdot
.626 .09924 Mdot
.626 .09954 Mdot
.626 .09983 Mdot
.626 .09996 Mdot
.626 .1003 Mdot
.626 .10037 Mdot
.626 .10068 Mdot
.626 .10073 Mdot
.626 .10106 Mdot
.626 .10117 Mdot
.626 .10118 Mdot
.626 .10133 Mdot
.626 .10143 Mdot
.626 .10153 Mdot
.626 .10168 Mdot
.626 .10179 Mdot
.626 .10188 Mdot
.626 .10223 Mdot
.626 .10275 Mdot
.626 .10286 Mdot
.626 .10341 Mdot
.626 .10403 Mdot
.626 .10432 Mdot
.626 .10451 Mdot
.626 .10459 Mdot
.626 .1046 Mdot
.626 .10482 Mdot
.626 .10487 Mdot
.626 .10517 Mdot
.626 .10536 Mdot
.626 .10579 Mdot
.626 .10581 Mdot
.626 .10587 Mdot
.626 .10633 Mdot
.626 .10642 Mdot
.626 .10647 Mdot
.626 .10657 Mdot
.626 .10658 Mdot
.626 .1078 Mdot
.626 .10787 Mdot
.626 .1084 Mdot
.626 .10885 Mdot
.626 .10916 Mdot
.626 .10954 Mdot
.626 .10974 Mdot
.626 .11013 Mdot
.626 .11054 Mdot
.626 .1112 Mdot
.626 .11172 Mdot
.626 .11202 Mdot
.626 .11225 Mdot
.626 .1128 Mdot
.626 .11309 Mdot
.626 .11315 Mdot
.626 .11319 Mdot
.626 .11342 Mdot
.626 .11352 Mdot
.626 .11356 Mdot
.626 .11363 Mdot
.626 .11377 Mdot
.626 .11381 Mdot
.626 .11386 Mdot
.626 .11388 Mdot
.626 .11392 Mdot
.626 .11403 Mdot
.626 .11417 Mdot
.626 .1151 Mdot
.626 .11511 Mdot
.626 .11553 Mdot
.626 .11588 Mdot
.626 .11599 Mdot
.626 .11615 Mdot
.626 .11638 Mdot
.626 .11661 Mdot
.626 .11684 Mdot
.626 .11702 Mdot
.626 .11773 Mdot
.626 .11787 Mdot
.626 .11797 Mdot
.626 .11813 Mdot
.626 .11837 Mdot
.626 .11916 Mdot
.626 .1192 Mdot
.626 .11931 Mdot
.626 .11955 Mdot
.626 .11958 Mdot
.626 .12 Mdot
.626 .12046 Mdot
.626 .12054 Mdot
.626 .12091 Mdot
.626 .12127 Mdot
.626 .12144 Mdot
.626 .12187 Mdot
.626 .12196 Mdot
.626 .12234 Mdot
.626 .12241 Mdot
.626 .12282 Mdot
.626 .12295 Mdot
.626 .12296 Mdot
.626 .12316 Mdot
.626 .12329 Mdot
.626 .1234 Mdot
.626 .1236 Mdot
.626 .12374 Mdot
.626 .12385 Mdot
.626 .12428 Mdot
.626 .12493 Mdot
.626 .12507 Mdot
.626 .12576 Mdot
.626 .12654 Mdot
.626 .1269 Mdot
.626 .12714 Mdot
.626 .12724 Mdot
.626 .12725 Mdot
.626 .12753 Mdot
.626 .12759 Mdot
.626 .12796 Mdot
.626 .1282 Mdot
.626 .12874 Mdot
.626 .12876 Mdot
.626 .12884 Mdot
.626 .12941 Mdot
.626 .12953 Mdot
.626 .12959 Mdot
.626 .12972 Mdot
.626 .12974 Mdot
.626 .13125 Mdot
.626 .13135 Mdot
.626 .13201 Mdot
.626 .13257 Mdot
.626 .13297 Mdot
.626 .13344 Mdot
.626 .13369 Mdot
.626 .13417 Mdot
.626 .13469 Mdot
.626 .13552 Mdot
.626 .13616 Mdot
.626 .13654 Mdot
.626 .13683 Mdot
.626 .13752 Mdot
.626 .13788 Mdot
.626 .13796 Mdot
.626 .13801 Mdot
.626 .1383 Mdot
.626 .13842 Mdot
.626 .13847 Mdot
.626 .13855 Mdot
.626 .13873 Mdot
.626 .13878 Mdot
.626 .13884 Mdot
.626 .13887 Mdot
.626 .13892 Mdot
.626 .13906 Mdot
.626 .13924 Mdot
.626 .1404 Mdot
.626 .14041 Mdot
.626 .14093 Mdot
.626 .14137 Mdot
.626 .14151 Mdot
.626 .14172 Mdot
.626 .142 Mdot
.626 .14228 Mdot
.626 .1428 Mdot
.626 .14369 Mdot
.626 .14387 Mdot
.626 .14399 Mdot
.626 .14419 Mdot
.626 .14449 Mdot
.626 .14548 Mdot
.626 .14553 Mdot
.626 .14566 Mdot
.626 .14596 Mdot
.626 .14601 Mdot
.626 .14653 Mdot
.626 .1471 Mdot
.626 .14721 Mdot
.626 .14768 Mdot
.626 .14813 Mdot
.626 .14833 Mdot
.626 .14888 Mdot
.626 .14898 Mdot
.626 .14946 Mdot
.626 .14955 Mdot
.626 .15007 Mdot
.626 .15023 Mdot
.626 .15024 Mdot
.626 .15048 Mdot
.626 .15065 Mdot
.626 .15079 Mdot
.626 .15104 Mdot
.626 .15121 Mdot
.626 .15135 Mdot
.626 .15189 Mdot
.626 .1527 Mdot
.626 .15288 Mdot
.626 .15374 Mdot
.626 .15472 Mdot
.626 .15517 Mdot
.626 .15547 Mdot
.626 .1556 Mdot
.626 .15561 Mdot
.626 .15596 Mdot
.626 .15603 Mdot
.626 .1565 Mdot
.626 .1568 Mdot
.626 .15747 Mdot
.626 .1575 Mdot
.626 .15759 Mdot
.626 .15832 Mdot
.626 .15846 Mdot
.626 .15854 Mdot
.626 .15871 Mdot
.626 .15872 Mdot
.626 .16062 Mdot
.626 .16074 Mdot
.626 .16157 Mdot
.626 .16221 Mdot
.626 .16227 Mdot
.626 .16276 Mdot
.626 .16336 Mdot
.626 .16367 Mdot
.626 .16427 Mdot
.626 .16492 Mdot
.626 .16596 Mdot
.626 .16677 Mdot
.626 .16724 Mdot
.626 .1676 Mdot
.626 .16847 Mdot
.626 .16892 Mdot
.626 .16901 Mdot
.626 .16908 Mdot
.626 .16944 Mdot
.626 .1696 Mdot
.626 .16965 Mdot
.626 .16976 Mdot
.626 .16999 Mdot
.626 .17004 Mdot
.626 .17013 Mdot
.626 .17016 Mdot
.626 .17021 Mdot
.626 .17039 Mdot
.626 .17062 Mdot
.626 .17207 Mdot
.626 .17208 Mdot
.626 .17274 Mdot
.626 .17329 Mdot
.626 .17347 Mdot
.626 .17372 Mdot
.626 .17407 Mdot
.626 .17443 Mdot
.626 .17508 Mdot
.626 .17619 Mdot
.626 .17642 Mdot
.626 .17656 Mdot
.626 .17682 Mdot
.626 .1772 Mdot
.626 .17844 Mdot
.626 .17849 Mdot
.626 .17866 Mdot
.626 .17904 Mdot
.626 .17909 Mdot
.626 .17974 Mdot
.626 .18046 Mdot
.626 .1806 Mdot
.626 .18118 Mdot
.626 .18175 Mdot
.626 .18201 Mdot
.626 .18269 Mdot
.626 .18282 Mdot
.626 .18341 Mdot
.626 .18353 Mdot
.626 .18418 Mdot
.626 .18438 Mdot
.626 .1844 Mdot
.626 .1847 Mdot
.626 .1849 Mdot
.626 .18509 Mdot
.626 .18539 Mdot
.626 .18561 Mdot
.626 .18578 Mdot
.626 .18646 Mdot
.626 .18748 Mdot
.626 .1877 Mdot
.626 .18878 Mdot
.626 .19 Mdot
.626 .19057 Mdot
.626 .19094 Mdot
.626 .1911 Mdot
.626 .19112 Mdot
.626 .19155 Mdot
.626 .19165 Mdot
.626 .19223 Mdot
.626 .19261 Mdot
.626 .19345 Mdot
.626 .19349 Mdot
.626 .1936 Mdot
.626 .19451 Mdot
.626 .19469 Mdot
.626 .19478 Mdot
.626 .19499 Mdot
.626 .19501 Mdot
.626 .19739 Mdot
.626 .19753 Mdot
.626 .19858 Mdot
.626 .19938 Mdot
.626 .19946 Mdot
.626 .20007 Mdot
.626 .20082 Mdot
.626 .20121 Mdot
.626 .20196 Mdot
.626 .20277 Mdot
.626 .20407 Mdot
.626 .20508 Mdot
.626 .20567 Mdot
.626 .20613 Mdot
.626 .20721 Mdot
.626 .20778 Mdot
.626 .20789 Mdot
.626 .20798 Mdot
.626 .20843 Mdot
.626 .20863 Mdot
.626 .20869 Mdot
.626 .20883 Mdot
.626 .20912 Mdot
.626 .20919 Mdot
.626 .20929 Mdot
.626 .20933 Mdot
.626 .2094 Mdot
.626 .20962 Mdot
.626 .20991 Mdot
.626 .21172 Mdot
.626 .21174 Mdot
.626 .21256 Mdot
.626 .21325 Mdot
.626 .21347 Mdot
.626 .21379 Mdot
.626 .21423 Mdot
.626 .21468 Mdot
.626 .21549 Mdot
.626 .21688 Mdot
.626 .21717 Mdot
.626 .21735 Mdot
.626 .21767 Mdot
.626 .21814 Mdot
.626 .2197 Mdot
.626 .21976 Mdot
.626 .21998 Mdot
.626 .22045 Mdot
.626 .22052 Mdot
.626 .22133 Mdot
.626 .22223 Mdot
.626 .2224 Mdot
.626 .22313 Mdot
.626 .22384 Mdot
.626 .22416 Mdot
.626 .22501 Mdot
.626 .22518 Mdot
.626 .22593 Mdot
.626 .22607 Mdot
.626 .22688 Mdot
.626 .22713 Mdot
.626 .22716 Mdot
.626 .22753 Mdot
.626 .22779 Mdot
.626 .22802 Mdot
.626 .2284 Mdot
.626 .22867 Mdot
.626 .22889 Mdot
.626 .22974 Mdot
.626 .23101 Mdot
.626 .23129 Mdot
.626 .23264 Mdot
.626 .23417 Mdot
.626 .23488 Mdot
.626 .23535 Mdot
.626 .23555 Mdot
.626 .23558 Mdot
.626 .23612 Mdot
.626 .23623 Mdot
.626 .23696 Mdot
.626 .23744 Mdot
.626 .23849 Mdot
.626 .23854 Mdot
.626 .23868 Mdot
.626 .23981 Mdot
.626 .24004 Mdot
.626 .24016 Mdot
.626 .24042 Mdot
.626 .24044 Mdot
.626 .24343 Mdot
.626 .2436 Mdot
.626 .24491 Mdot
.626 .24591 Mdot
.626 .24601 Mdot
.626 .24678 Mdot
.626 .24772 Mdot
.626 .2482 Mdot
.626 .24915 Mdot
.626 .25016 Mdot
.626 .25179 Mdot
.626 .25306 Mdot
.626 .2538 Mdot
.626 .25436 Mdot
.626 .25572 Mdot
.626 .25644 Mdot
.626 .25658 Mdot
.626 .25668 Mdot
.626 .25725 Mdot
.626 .25749 Mdot
.626 .25758 Mdot
.626 .25775 Mdot
.626 .25811 Mdot
.626 .25819 Mdot
.626 .25832 Mdot
.626 .25837 Mdot
.626 .25846 Mdot
.626 .25874 Mdot
.626 .25909 Mdot
.626 .26136 Mdot
.626 .26139 Mdot
.626 .26241 Mdot
.626 .26328 Mdot
.626 .26356 Mdot
.626 .26396 Mdot
.626 .26451 Mdot
.626 .26507 Mdot
.626 .26608 Mdot
.626 .26783 Mdot
.626 .26818 Mdot
.626 .26841 Mdot
.626 .26881 Mdot
.626 .2694 Mdot
.626 .27135 Mdot
.626 .27143 Mdot
.626 .2717 Mdot
.626 .27229 Mdot
.626 .27238 Mdot
.626 .2734 Mdot
.626 .27453 Mdot
.626 .27473 Mdot
.626 .27566 Mdot
.626 .27654 Mdot
.626 .27695 Mdot
.626 .27801 Mdot
.626 .27822 Mdot
.626 .27915 Mdot
.626 .27933 Mdot
.626 .28035 Mdot
.626 .28066 Mdot
.626 .28069 Mdot
.626 .28116 Mdot
.626 .28148 Mdot
.626 .28177 Mdot
.626 .28225 Mdot
.626 .28259 Mdot
.626 .28286 Mdot
.626 .28393 Mdot
.626 .28552 Mdot
.626 .28587 Mdot
.626 .28756 Mdot
.626 .28948 Mdot
.626 .29036 Mdot
.626 .29094 Mdot
.626 .2912 Mdot
.626 .29123 Mdot
.626 .29191 Mdot
.626 .29205 Mdot
.626 .29297 Mdot
.626 .29356 Mdot
.626 .29488 Mdot
.626 .29494 Mdot
.626 .29512 Mdot
.626 .29654 Mdot
.626 .29682 Mdot
.626 .29697 Mdot
.626 .2973 Mdot
.626 .29733 Mdot
.626 .30106 Mdot
.626 .30128 Mdot
.626 .30292 Mdot
.626 .30418 Mdot
.626 .3043 Mdot
.626 .30526 Mdot
.626 .30643 Mdot
.626 .30704 Mdot
.626 .30823 Mdot
.626 .30949 Mdot
.626 .31153 Mdot
.626 .31312 Mdot
.626 .31404 Mdot
.626 .31475 Mdot
.626 .31646 Mdot
.626 .31735 Mdot
.626 .31752 Mdot
.626 .31766 Mdot
.626 .31837 Mdot
.626 .31867 Mdot
.626 .31878 Mdot
.626 .319 Mdot
.626 .31944 Mdot
.626 .31955 Mdot
.626 .31971 Mdot
.626 .31977 Mdot
.626 .31988 Mdot
.626 .32023 Mdot
.626 .32068 Mdot
.626 .32352 Mdot
.626 .32355 Mdot
.626 .32483 Mdot
.626 .32591 Mdot
.626 .32627 Mdot
.626 .32677 Mdot
.626 .32746 Mdot
.626 .32816 Mdot
.626 .32942 Mdot
.626 .33161 Mdot
.626 .33206 Mdot
.626 .33234 Mdot
.626 .33284 Mdot
.626 .33359 Mdot
.626 .33603 Mdot
.626 .33612 Mdot
.626 .33646 Mdot
.626 .3372 Mdot
.626 .33731 Mdot
.626 .33859 Mdot
.626 .34 Mdot
.626 .34026 Mdot
.626 .34141 Mdot
.626 .34252 Mdot
.626 .34303 Mdot
.626 .34436 Mdot
.626 .34462 Mdot
.626 .34579 Mdot
.626 .34601 Mdot
.626 .34729 Mdot
.626 .34768 Mdot
.626 .34772 Mdot
.626 .34831 Mdot
.626 .34871 Mdot
.626 .34907 Mdot
.626 .34966 Mdot
.626 .35009 Mdot
.626 .35043 Mdot
.626 .35177 Mdot
.626 .35376 Mdot
.626 .3542 Mdot
.626 .35631 Mdot
.626 .35872 Mdot
.626 .35982 Mdot
.626 .36055 Mdot
.626 .36087 Mdot
.626 .36092 Mdot
.626 .36176 Mdot
.626 .36194 Mdot
.626 .36309 Mdot
.626 .36383 Mdot
.626 .36548 Mdot
.626 .36555 Mdot
.626 .36578 Mdot
.626 .36756 Mdot
.626 .36791 Mdot
.626 .3681 Mdot
.626 .36851 Mdot
.626 .36855 Mdot
.626 .37322 Mdot
.626 .3735 Mdot
.626 .37555 Mdot
.626 .37712 Mdot
.626 .37727 Mdot
.626 .37848 Mdot
.626 .37995 Mdot
.626 .38071 Mdot
.626 .38219 Mdot
.626 .38377 Mdot
.628 .01577 Mdot
.628 .01603 Mdot
.628 .01605 Mdot
.628 .01609 Mdot
.628 .01637 Mdot
.628 .01639 Mdot
.628 .01642 Mdot
.628 .01644 Mdot
.628 .0168 Mdot
.628 .01681 Mdot
.628 .01686 Mdot
.628 .01688 Mdot
.628 .01714 Mdot
.628 .01733 Mdot
.628 .01735 Mdot
.628 .01741 Mdot
.628 .01744 Mdot
.628 .01777 Mdot
.628 .01787 Mdot
.628 .018 Mdot
.628 .01803 Mdot
.628 .0181 Mdot
.628 .01813 Mdot
.628 .01855 Mdot
.628 .01868 Mdot
.628 .01881 Mdot
.628 .01884 Mdot
.628 .01887 Mdot
.628 .01897 Mdot
.628 .01901 Mdot
.628 .01953 Mdot
.628 .01969 Mdot
.628 .01985 Mdot
.628 .0199 Mdot
.628 .01994 Mdot
.628 .02005 Mdot
.628 .02011 Mdot
.628 .02076 Mdot
.628 .02097 Mdot
.628 .02117 Mdot
.628 .02122 Mdot
.628 .02128 Mdot
.628 .02142 Mdot
.628 .02149 Mdot
.628 .02154 Mdot
.628 .02231 Mdot
.628 .02246 Mdot
.628 .02257 Mdot
.628 .02282 Mdot
.628 .02289 Mdot
.628 .02296 Mdot
.628 .02314 Mdot
.628 .02322 Mdot
.628 .02329 Mdot
.628 .0239 Mdot
.628 .02425 Mdot
.628 .02444 Mdot
.628 .02458 Mdot
.628 .02487 Mdot
.628 .0249 Mdot
.628 .02498 Mdot
.628 .02507 Mdot
.628 .02529 Mdot
.628 .0254 Mdot
.628 .02549 Mdot
.628 .02626 Mdot
.628 .02651 Mdot
.628 .02657 Mdot
.628 .02669 Mdot
.628 .02693 Mdot
.628 .0271 Mdot
.628 .02747 Mdot
.628 .0275 Mdot
.628 .02761 Mdot
.628 .02772 Mdot
.628 .02798 Mdot
.628 .028 Mdot
.628 .02813 Mdot
.628 .02825 Mdot
.628 .0291 Mdot
.628 .02921 Mdot
.628 .02952 Mdot
.628 .0296 Mdot
.628 .02976 Mdot
.628 .02997 Mdot
.628 .03006 Mdot
.628 .03027 Mdot
.628 .03073 Mdot
.628 .03078 Mdot
.628 .03091 Mdot
.628 .03105 Mdot
.628 .03137 Mdot
.628 .0314 Mdot
.628 .03157 Mdot
.628 .03171 Mdot
.628 .03235 Mdot
.628 .03279 Mdot
.628 .03281 Mdot
.628 .03292 Mdot
.628 .03332 Mdot
.628 .03341 Mdot
.628 .03361 Mdot
.628 .03387 Mdot
.628 .03388 Mdot
.628 .03399 Mdot
.628 .03411 Mdot
.628 .03425 Mdot
.628 .0343 Mdot
.628 .03483 Mdot
.628 .03489 Mdot
.628 .03506 Mdot
.628 .03523 Mdot
.628 .03564 Mdot
.628 .03567 Mdot
.628 .03588 Mdot
.628 .03606 Mdot
.628 .03686 Mdot
.628 .0371 Mdot
.628 .03741 Mdot
.628 .03744 Mdot
.628 .03758 Mdot
.628 .03808 Mdot
.628 .0382 Mdot
.628 .03844 Mdot
.628 .03878 Mdot
.628 .03878 Mdot
.628 .03892 Mdot
.628 .03908 Mdot
.628 .03925 Mdot
.628 .03931 Mdot
.628 .03947 Mdot
.628 .03998 Mdot
.628 .04005 Mdot
.628 .04008 Mdot
.628 .04026 Mdot
.628 .04042 Mdot
.628 .04048 Mdot
.628 .04099 Mdot
.628 .04104 Mdot
.628 .0413 Mdot
.628 .04152 Mdot
.628 .04157 Mdot
.628 .0422 Mdot
.628 .04246 Mdot
.628 .04254 Mdot
.628 .04283 Mdot
.628 .04322 Mdot
.628 .04326 Mdot
.628 .04344 Mdot
.628 .04406 Mdot
.628 .04421 Mdot
.628 .04452 Mdot
.628 .04494 Mdot
.628 .04495 Mdot
.628 .04509 Mdot
.628 .04512 Mdot
.628 .04531 Mdot
.628 .04554 Mdot
.628 .04561 Mdot
.628 .04581 Mdot
.628 .04645 Mdot
.628 .04654 Mdot
.628 .04658 Mdot
.628 .0468 Mdot
.628 .047 Mdot
.628 .04707 Mdot
.628 .04717 Mdot
.628 .04762 Mdot
.628 .04772 Mdot
.628 .04778 Mdot
.628 .04806 Mdot
.628 .0481 Mdot
.628 .04833 Mdot
.628 .04839 Mdot
.628 .04845 Mdot
.628 .04905 Mdot
.628 .04924 Mdot
.628 .04956 Mdot
.628 .04966 Mdot
.628 .04973 Mdot
.628 .04984 Mdot
.628 .05002 Mdot
.628 .05052 Mdot
.628 .05057 Mdot
.628 .05079 Mdot
.628 .05157 Mdot
.628 .05176 Mdot
.628 .0518 Mdot
.628 .05215 Mdot
.628 .05258 Mdot
.628 .05268 Mdot
.628 .05268 Mdot
.628 .05272 Mdot
.628 .05287 Mdot
.628 .0529 Mdot
.628 .05305 Mdot
.628 .05315 Mdot
.628 .05343 Mdot
.628 .05352 Mdot
.628 .05367 Mdot
.628 .05377 Mdot
.628 .05458 Mdot
.628 .05469 Mdot
.628 .05473 Mdot
.628 .05502 Mdot
.628 .05526 Mdot
.628 .05536 Mdot
.628 .05548 Mdot
.628 .05584 Mdot
.628 .05605 Mdot
.628 .05617 Mdot
.628 .05624 Mdot
.628 .05631 Mdot
.628 .05652 Mdot
.628 .0566 Mdot
.628 .05665 Mdot
.628 .05694 Mdot
.628 .05701 Mdot
.628 .05708 Mdot
.628 .05727 Mdot
.628 .05765 Mdot
.628 .05785 Mdot
.628 .05808 Mdot
.628 .05848 Mdot
.628 .0586 Mdot
.628 .05869 Mdot
.628 .05883 Mdot
.628 .05906 Mdot
.628 .05906 Mdot
.628 .05969 Mdot
.628 .05975 Mdot
.628 .06003 Mdot
.628 .06088 Mdot
.628 .06101 Mdot
.628 .06124 Mdot
.628 .0613 Mdot
.628 .06173 Mdot
.628 .06227 Mdot
.628 .0624 Mdot
.628 .0624 Mdot
.628 .06244 Mdot
.628 .06263 Mdot
.628 .06268 Mdot
.628 .06277 Mdot
.628 .06286 Mdot
.628 .06298 Mdot
.628 .06334 Mdot
.628 .06345 Mdot
.628 .06364 Mdot
.628 .06376 Mdot
.628 .06442 Mdot
.628 .06472 Mdot
.628 .06478 Mdot
.628 .06492 Mdot
.628 .06498 Mdot
.628 .06533 Mdot
.628 .06564 Mdot
.628 .06576 Mdot
.628 .06591 Mdot
.628 .06636 Mdot
.628 .06663 Mdot
.628 .06678 Mdot
.628 .06687 Mdot
.628 .06696 Mdot
.628 .06697 Mdot
.628 .06723 Mdot
.628 .06733 Mdot
.628 .06739 Mdot
.628 .06774 Mdot
.628 .06783 Mdot
.628 .06793 Mdot
.628 .06816 Mdot
.628 .06839 Mdot
.628 .06864 Mdot
.628 .06889 Mdot
.628 .06918 Mdot
.628 .06969 Mdot
.628 .06984 Mdot
.628 .06995 Mdot
.628 .07012 Mdot
.628 .07041 Mdot
.628 .07041 Mdot
.628 .07096 Mdot
.628 .0712 Mdot
.628 .07128 Mdot
.628 .07163 Mdot
.628 .07212 Mdot
.628 .07269 Mdot
.628 .07286 Mdot
.628 .07301 Mdot
.628 .07316 Mdot
.628 .07322 Mdot
.628 .07376 Mdot
.628 .07433 Mdot
.628 .07444 Mdot
.628 .0746 Mdot
.628 .07461 Mdot
.628 .07466 Mdot
.628 .0749 Mdot
.628 .07496 Mdot
.628 .07507 Mdot
.628 .07519 Mdot
.628 .07534 Mdot
.628 .07578 Mdot
.628 .07593 Mdot
.628 .07616 Mdot
.628 .07632 Mdot
.628 .07658 Mdot
.628 .07659 Mdot
.628 .077 Mdot
.628 .07714 Mdot
.628 .07753 Mdot
.628 .0776 Mdot
.628 .07777 Mdot
.628 .07784 Mdot
.628 .07829 Mdot
.628 .07868 Mdot
.628 .07878 Mdot
.628 .07883 Mdot
.628 .07902 Mdot
.628 .07916 Mdot
.628 .07958 Mdot
.628 .07992 Mdot
.628 .08011 Mdot
.628 .08022 Mdot
.628 .08033 Mdot
.628 .08035 Mdot
.628 .08067 Mdot
.628 .08079 Mdot
.628 .08082 Mdot
.628 .08087 Mdot
.628 .08132 Mdot
.628 .08143 Mdot
.628 .08155 Mdot
.628 .08184 Mdot
.628 .08213 Mdot
.628 .08244 Mdot
.628 .08271 Mdot
.628 .08275 Mdot
.628 .08312 Mdot
.628 .08335 Mdot
.628 .08376 Mdot
.628 .08395 Mdot
.628 .08409 Mdot
.628 .08431 Mdot
.628 .08467 Mdot
.628 .08467 Mdot
.628 .08509 Mdot
.628 .08535 Mdot
.628 .08566 Mdot
.628 .08576 Mdot
.628 .08604 Mdot
.628 .0862 Mdot
.628 .08681 Mdot
.628 .08754 Mdot
.628 .08774 Mdot
.628 .08793 Mdot
.628 .08812 Mdot
.628 .0882 Mdot
.628 .08888 Mdot
.628 .08959 Mdot
.628 .08973 Mdot
.628 .08985 Mdot
.628 .08993 Mdot
.628 .08995 Mdot
.628 .09001 Mdot
.628 .09031 Mdot
.628 .09038 Mdot
.628 .09052 Mdot
.628 .09067 Mdot
.628 .09086 Mdot
.628 .09142 Mdot
.628 .0916 Mdot
.628 .09189 Mdot
.628 .09209 Mdot
.628 .09242 Mdot
.628 .09243 Mdot
.628 .09272 Mdot
.628 .09295 Mdot
.628 .09312 Mdot
.628 .09361 Mdot
.628 .0937 Mdot
.628 .09392 Mdot
.628 .09396 Mdot
.628 .094 Mdot
.628 .09434 Mdot
.628 .09457 Mdot
.628 .09505 Mdot
.628 .09518 Mdot
.628 .09524 Mdot
.628 .09548 Mdot
.628 .09561 Mdot
.628 .09566 Mdot
.628 .09619 Mdot
.628 .09661 Mdot
.628 .0967 Mdot
.628 .09679 Mdot
.628 .09685 Mdot
.628 .09699 Mdot
.628 .09713 Mdot
.628 .09715 Mdot
.628 .09755 Mdot
.628 .09771 Mdot
.628 .09774 Mdot
.628 .09781 Mdot
.628 .09793 Mdot
.628 .09837 Mdot
.628 .09847 Mdot
.628 .09851 Mdot
.628 .09866 Mdot
.628 .09874 Mdot
.628 .09902 Mdot
.628 .09939 Mdot
.628 .09978 Mdot
.628 .10011 Mdot
.628 .10017 Mdot
.628 .10063 Mdot
.628 .10092 Mdot
.628 .10144 Mdot
.628 .10167 Mdot
.628 .10185 Mdot
.628 .10212 Mdot
.628 .10258 Mdot
.628 .10258 Mdot
.628 .10266 Mdot
.628 .10302 Mdot
.628 .1031 Mdot
.628 .10344 Mdot
.628 .10382 Mdot
.628 .10395 Mdot
.628 .1043 Mdot
.628 .1045 Mdot
.628 .10527 Mdot
.628 .1061 Mdot
.628 .10618 Mdot
.628 .10644 Mdot
.628 .10666 Mdot
.628 .10668 Mdot
.628 .10691 Mdot
.628 .10702 Mdot
.628 .10707 Mdot
.628 .10787 Mdot
.628 .10794 Mdot
.628 .10856 Mdot
.628 .10868 Mdot
.628 .10876 Mdot
.628 .10894 Mdot
.628 .10906 Mdot
.628 .10909 Mdot
.628 .10916 Mdot
.628 .10919 Mdot
.628 .10919 Mdot
.628 .10921 Mdot
.628 .10927 Mdot
.628 .10928 Mdot
.628 .10958 Mdot
.628 .10965 Mdot
.628 .10966 Mdot
.628 .10975 Mdot
.628 .10993 Mdot
.628 .11012 Mdot
.628 .11035 Mdot
.628 .11105 Mdot
.628 .11128 Mdot
.628 .11165 Mdot
.628 .1119 Mdot
.628 .11232 Mdot
.628 .11233 Mdot
.628 .11269 Mdot
.628 .11298 Mdot
.628 .1132 Mdot
.628 .1138 Mdot
.628 .11392 Mdot
.628 .11419 Mdot
.628 .11425 Mdot
.628 .1143 Mdot
.628 .11473 Mdot
.628 .11501 Mdot
.628 .11562 Mdot
.628 .11577 Mdot
.628 .11586 Mdot
.628 .11615 Mdot
.628 .11631 Mdot
.628 .11638 Mdot
.628 .11705 Mdot
.628 .11758 Mdot
.628 .11769 Mdot
.628 .11781 Mdot
.628 .11787 Mdot
.628 .11806 Mdot
.628 .11823 Mdot
.628 .11826 Mdot
.628 .11876 Mdot
.628 .11896 Mdot
.628 .11899 Mdot
.628 .11908 Mdot
.628 .11923 Mdot
.628 .11979 Mdot
.628 .11991 Mdot
.628 .11996 Mdot
.628 .12015 Mdot
.628 .12025 Mdot
.628 .12061 Mdot
.628 .12107 Mdot
.628 .12155 Mdot
.628 .12197 Mdot
.628 .12205 Mdot
.628 .12262 Mdot
.628 .12298 Mdot
.628 .12364 Mdot
.628 .12393 Mdot
.628 .12416 Mdot
.628 .1245 Mdot
.628 .12507 Mdot
.628 .12507 Mdot
.628 .12518 Mdot
.628 .12563 Mdot
.628 .12573 Mdot
.628 .12615 Mdot
.628 .12663 Mdot
.628 .12679 Mdot
.628 .12724 Mdot
.628 .12748 Mdot
.628 .12845 Mdot
.628 .1295 Mdot
.628 .12959 Mdot
.628 .12992 Mdot
.628 .1302 Mdot
.628 .13022 Mdot
.628 .13051 Mdot
.628 .13064 Mdot
.628 .13071 Mdot
.628 .13171 Mdot
.628 .13181 Mdot
.628 .13259 Mdot
.628 .13273 Mdot
.628 .13284 Mdot
.628 .13306 Mdot
.628 .13322 Mdot
.628 .13325 Mdot
.628 .13334 Mdot
.628 .13337 Mdot
.628 .13338 Mdot
.628 .1334 Mdot
.628 .13348 Mdot
.628 .13349 Mdot
.628 .13386 Mdot
.628 .13395 Mdot
.628 .13397 Mdot
.628 .13407 Mdot
.628 .13431 Mdot
.628 .13454 Mdot
.628 .13484 Mdot
.628 .13571 Mdot
.628 .13601 Mdot
.628 .13647 Mdot
.628 .13678 Mdot
.628 .1373 Mdot
.628 .13732 Mdot
.628 .13777 Mdot
.628 .13813 Mdot
.628 .13841 Mdot
.628 .13917 Mdot
.628 .13932 Mdot
.628 .13966 Mdot
.628 .13973 Mdot
.628 .13979 Mdot
.628 .14033 Mdot
.628 .14069 Mdot
.628 .14145 Mdot
.628 .14164 Mdot
.628 .14175 Mdot
.628 .14212 Mdot
.628 .14232 Mdot
.628 .1424 Mdot
.628 .14325 Mdot
.628 .14391 Mdot
.628 .14406 Mdot
.628 .1442 Mdot
.628 .14428 Mdot
.628 .14451 Mdot
.628 .14473 Mdot
.628 .14476 Mdot
.628 .14539 Mdot
.628 .14564 Mdot
.628 .14569 Mdot
.628 .14579 Mdot
.628 .14599 Mdot
.628 .14668 Mdot
.628 .14684 Mdot
.628 .1469 Mdot
.628 .14714 Mdot
.628 .14726 Mdot
.628 .14772 Mdot
.628 .1483 Mdot
.628 .1489 Mdot
.628 .14943 Mdot
.628 .14953 Mdot
.628 .15025 Mdot
.628 .1507 Mdot
.628 .15152 Mdot
.628 .15189 Mdot
.628 .15218 Mdot
.628 .1526 Mdot
.628 .15332 Mdot
.628 .15332 Mdot
.628 .15346 Mdot
.628 .15402 Mdot
.628 .15415 Mdot
.628 .15468 Mdot
.628 .15528 Mdot
.628 .15549 Mdot
.628 .15604 Mdot
.628 .15635 Mdot
.628 .15757 Mdot
.628 .15888 Mdot
.628 .159 Mdot
.628 .15941 Mdot
.628 .15976 Mdot
.628 .15979 Mdot
.628 .16015 Mdot
.628 .16032 Mdot
.628 .16041 Mdot
.628 .16167 Mdot
.628 .16178 Mdot
.628 .16277 Mdot
.628 .16294 Mdot
.628 .16308 Mdot
.628 .16335 Mdot
.628 .16355 Mdot
.628 .16359 Mdot
.628 .16371 Mdot
.628 .16375 Mdot
.628 .16375 Mdot
.628 .16378 Mdot
.628 .16388 Mdot
.628 .1639 Mdot
.628 .16437 Mdot
.628 .16448 Mdot
.628 .1645 Mdot
.628 .16463 Mdot
.628 .16492 Mdot
.628 .16521 Mdot
.628 .16559 Mdot
.628 .16669 Mdot
.628 .16706 Mdot
.628 .16764 Mdot
.628 .16802 Mdot
.628 .16868 Mdot
.628 .16871 Mdot
.628 .16927 Mdot
.628 .16973 Mdot
.628 .17007 Mdot
.628 .17103 Mdot
.628 .17122 Mdot
.628 .17164 Mdot
.628 .17174 Mdot
.628 .17181 Mdot
.628 .17249 Mdot
.628 .17294 Mdot
.628 .17389 Mdot
.628 .17414 Mdot
.628 .17427 Mdot
.628 .17474 Mdot
.628 .17499 Mdot
.628 .17509 Mdot
.628 .17615 Mdot
.628 .17698 Mdot
.628 .17717 Mdot
.628 .17735 Mdot
.628 .17745 Mdot
.628 .17774 Mdot
.628 .17801 Mdot
.628 .17806 Mdot
.628 .17885 Mdot
.628 .17916 Mdot
.628 .17921 Mdot
.628 .17935 Mdot
.628 .1796 Mdot
.628 .18047 Mdot
.628 .18066 Mdot
.628 .18074 Mdot
.628 .18104 Mdot
.628 .1812 Mdot
.628 .18176 Mdot
.628 .18249 Mdot
.628 .18325 Mdot
.628 .18392 Mdot
.628 .18404 Mdot
.628 .18494 Mdot
.628 .18551 Mdot
.628 .18654 Mdot
.628 .18701 Mdot
.628 .18737 Mdot
.628 .1879 Mdot
.628 .18881 Mdot
.628 .18881 Mdot
.628 .18897 Mdot
.628 .18969 Mdot
.628 .18984 Mdot
.628 .19051 Mdot
.628 .19127 Mdot
.628 .19152 Mdot
.628 .19222 Mdot
.628 .19261 Mdot
.628 .19414 Mdot
.628 .19579 Mdot
.628 .19594 Mdot
.628 .19645 Mdot
.628 .19689 Mdot
.628 .19693 Mdot
.628 .19738 Mdot
.628 .1976 Mdot
.628 .19771 Mdot
.628 .19928 Mdot
.628 .19943 Mdot
.628 .20067 Mdot
.628 .20089 Mdot
.628 .20106 Mdot
.628 .2014 Mdot
.628 .20166 Mdot
.628 .2017 Mdot
.628 .20186 Mdot
.628 .2019 Mdot
.628 .20191 Mdot
.628 .20194 Mdot
.628 .20206 Mdot
.628 .20209 Mdot
.628 .20268 Mdot
.628 .20282 Mdot
.628 .20284 Mdot
.628 .20301 Mdot
.628 .20337 Mdot
.628 .20374 Mdot
.628 .20421 Mdot
.628 .20559 Mdot
.628 .20606 Mdot
.628 .20679 Mdot
.628 .20727 Mdot
.628 .2081 Mdot
.628 .20813 Mdot
.628 .20884 Mdot
.628 .20941 Mdot
.628 .20985 Mdot
.628 .21105 Mdot
.628 .21128 Mdot
.628 .21182 Mdot
.628 .21194 Mdot
.628 .21203 Mdot
.628 .21344 Mdot
.628 .21464 Mdot
.628 .21495 Mdot
.628 .21512 Mdot
.628 .2157 Mdot
.628 .21602 Mdot
.628 .21615 Mdot
.628 .21748 Mdot
.628 .21853 Mdot
.628 .21876 Mdot
.628 .21898 Mdot
.628 .21911 Mdot
.628 .21948 Mdot
.628 .21982 Mdot
.628 .21987 Mdot
.628 .22087 Mdot
.628 .22126 Mdot
.628 .22133 Mdot
.628 .22149 Mdot
.628 .22181 Mdot
.628 .2229 Mdot
.628 .22314 Mdot
.628 .22325 Mdot
.628 .22362 Mdot
.628 .22381 Mdot
.628 .22453 Mdot
.628 .22544 Mdot
.628 .2264 Mdot
.628 .22723 Mdot
.628 .22739 Mdot
.628 .22852 Mdot
.628 .22924 Mdot
.628 .23053 Mdot
.628 .23112 Mdot
.628 .23157 Mdot
.628 .23224 Mdot
.628 .23337 Mdot
.628 .23338 Mdot
.628 .23358 Mdot
.628 .23448 Mdot
.628 .23467 Mdot
.628 .23551 Mdot
.628 .23646 Mdot
.628 .23679 Mdot
.628 .23766 Mdot
.628 .23815 Mdot
.628 .24007 Mdot
.628 .24152 Mdot
.628 .24214 Mdot
.628 .24233 Mdot
.628 .24297 Mdot
.628 .24353 Mdot
.628 .24357 Mdot
.628 .24415 Mdot
.628 .24442 Mdot
.628 .24455 Mdot
.628 .24653 Mdot
.628 .24672 Mdot
.628 .24827 Mdot
.628 .24855 Mdot
.628 .24876 Mdot
.628 .2492 Mdot
.628 .24951 Mdot
.628 .24957 Mdot
.628 .24976 Mdot
.628 .24982 Mdot
.628 .24983 Mdot
.628 .24987 Mdot
.628 .25003 Mdot
.628 .25006 Mdot
.628 .2508 Mdot
.628 .25097 Mdot
.628 .251 Mdot
.628 .25121 Mdot
.628 .25167 Mdot
.628 .25213 Mdot
.628 .25272 Mdot
.628 .25446 Mdot
.628 .25504 Mdot
.628 .25596 Mdot
.628 .25657 Mdot
.628 .2576 Mdot
.628 .25764 Mdot
.628 .25854 Mdot
.628 .25925 Mdot
.628 .2598 Mdot
.628 .26131 Mdot
.628 .2616 Mdot
.628 .26228 Mdot
.628 .26242 Mdot
.628 .26254 Mdot
.628 .26432 Mdot
.628 .26582 Mdot
.628 .26621 Mdot
.628 .26642 Mdot
.628 .26715 Mdot
.628 .26755 Mdot
.628 .26772 Mdot
.628 .26939 Mdot
.628 .2707 Mdot
.628 .27099 Mdot
.628 .27127 Mdot
.628 .27144 Mdot
.628 .2719 Mdot
.628 .27233 Mdot
.628 .27239 Mdot
.628 .27364 Mdot
.628 .27413 Mdot
.628 .27422 Mdot
.628 .27443 Mdot
.628 .27482 Mdot
.628 .2762 Mdot
.628 .2765 Mdot
.628 .27663 Mdot
.628 .2771 Mdot
.628 .27734 Mdot
.628 .27824 Mdot
.628 .27939 Mdot
.628 .28059 Mdot
.628 .28164 Mdot
.628 .28183 Mdot
.628 .28326 Mdot
.628 .28416 Mdot
.628 .28578 Mdot
.628 .28652 Mdot
.628 .28708 Mdot
.628 .28792 Mdot
.628 .28935 Mdot
.628 .28935 Mdot
.628 .28961 Mdot
.628 .29074 Mdot
.628 .29098 Mdot
.628 .29203 Mdot
.628 .29323 Mdot
.628 .29364 Mdot
.628 .29474 Mdot
.628 .29534 Mdot
.628 .29776 Mdot
.628 .29958 Mdot
.628 .30037 Mdot
.628 .3006 Mdot
.628 .30141 Mdot
.628 .3021 Mdot
.628 .30216 Mdot
.628 .30288 Mdot
.628 .30322 Mdot
.628 .30339 Mdot
.628 .30588 Mdot
.628 .30611 Mdot
.628 .30806 Mdot
.628 .30841 Mdot
.628 .30867 Mdot
.628 .30923 Mdot
.628 .30962 Mdot
.628 .30969 Mdot
.628 .30994 Mdot
.628 .31 Mdot
.628 .31001 Mdot
.628 .31007 Mdot
.628 .31026 Mdot
.628 .31031 Mdot
.628 .31123 Mdot
.628 .31146 Mdot
.628 .31149 Mdot
.628 .31176 Mdot
.628 .31233 Mdot
.628 .31291 Mdot
.628 .31365 Mdot
.628 .31583 Mdot
.628 .31656 Mdot
.628 .31771 Mdot
.628 .31848 Mdot
.628 .31978 Mdot
.628 .31983 Mdot
.628 .32095 Mdot
.628 .32185 Mdot
.628 .32254 Mdot
.628 .32444 Mdot
.628 .3248 Mdot
.628 .32565 Mdot
.628 .32584 Mdot
.628 .32599 Mdot
.628 .32822 Mdot
.628 .33011 Mdot
.628 .33059 Mdot
.628 .33086 Mdot
.628 .33178 Mdot
.628 .33228 Mdot
.628 .33249 Mdot
.628 .33458 Mdot
.628 .33623 Mdot
.628 .3366 Mdot
.628 .33695 Mdot
.628 .33716 Mdot
.628 .33774 Mdot
.628 .33827 Mdot
.628 .33836 Mdot
.628 .33993 Mdot
.628 .34054 Mdot
.628 .34065 Mdot
.628 .34092 Mdot
.628 .34141 Mdot
.628 .34314 Mdot
.628 .34351 Mdot
.628 .34368 Mdot
.628 .34427 Mdot
.628 .34458 Mdot
.628 .3457 Mdot
.628 .34715 Mdot
.628 .34866 Mdot
.628 .34997 Mdot
.628 .35021 Mdot
.628 .352 Mdot
.628 .35313 Mdot
.628 .35517 Mdot
.628 .3561 Mdot
.628 .35681 Mdot
.628 .35786 Mdot
.628 .35965 Mdot
.628 .35966 Mdot
.628 .35999 Mdot
.628 .3614 Mdot
.628 .36171 Mdot
.628 .36302 Mdot
.628 .36453 Mdot
.628 .36504 Mdot
.628 .36642 Mdot
.628 .36719 Mdot
.628 .37022 Mdot
.628 .3725 Mdot
.628 .37349 Mdot
.628 .37379 Mdot
.628 .3748 Mdot
.628 .37567 Mdot
.628 .37575 Mdot
.628 .37665 Mdot
.628 .37708 Mdot
.628 .37729 Mdot
.628 .38042 Mdot
.628 .3807 Mdot
.628 .38316 Mdot
.628 .3836 Mdot
.628 .38393 Mdot
.628 .38462 Mdot
.628 .38512 Mdot
.628 .38521 Mdot
.628 .38551 Mdot
.628 .3856 Mdot
.628 .38561 Mdot
.628 .38568 Mdot
.628 .38592 Mdot
.628 .38598 Mdot
.63 .01495 Mdot
.63 .01502 Mdot
.63 .01509 Mdot
.63 .01519 Mdot
.63 .01532 Mdot
.63 .01547 Mdot
.63 .01567 Mdot
.63 .01592 Mdot
.63 .01623 Mdot
.63 .01643 Mdot
.63 .01662 Mdot
.63 .01687 Mdot
.63 .01712 Mdot
.63 .01717 Mdot
.63 .01743 Mdot
.63 .01775 Mdot
.63 .0178 Mdot
.63 .01814 Mdot
.63 .01853 Mdot
.63 .01854 Mdot
.63 .01861 Mdot
.63 .01903 Mdot
.63 .01938 Mdot
.63 .01953 Mdot
.63 .01953 Mdot
.63 .01962 Mdot
.63 .02015 Mdot
.63 .0203 Mdot
.63 .02059 Mdot
.63 .02078 Mdot
.63 .02078 Mdot
.63 .02089 Mdot
.63 .02108 Mdot
.63 .02156 Mdot
.63 .02175 Mdot
.63 .02212 Mdot
.63 .02235 Mdot
.63 .02236 Mdot
.63 .0225 Mdot
.63 .02274 Mdot
.63 .02289 Mdot
.63 .02334 Mdot
.63 .02357 Mdot
.63 .0238 Mdot
.63 .02404 Mdot
.63 .02434 Mdot
.63 .02435 Mdot
.63 .02438 Mdot
.63 .02453 Mdot
.63 .02482 Mdot
.63 .02502 Mdot
.63 .02558 Mdot
.63 .02588 Mdot
.63 .02591 Mdot
.63 .02617 Mdot
.63 .02647 Mdot
.63 .02684 Mdot
.63 .02685 Mdot
.63 .0269 Mdot
.63 .02708 Mdot
.63 .02745 Mdot
.63 .02769 Mdot
.63 .02805 Mdot
.63 .02815 Mdot
.63 .02841 Mdot
.63 .02878 Mdot
.63 .02882 Mdot
.63 .02888 Mdot
.63 .02914 Mdot
.63 .02952 Mdot
.63 .03 Mdot
.63 .03001 Mdot
.63 .03006 Mdot
.63 .03029 Mdot
.63 .03059 Mdot
.63 .03076 Mdot
.63 .031 Mdot
.63 .03107 Mdot
.63 .03152 Mdot
.63 .03162 Mdot
.63 .03164 Mdot
.63 .03197 Mdot
.63 .0323 Mdot
.63 .03244 Mdot
.63 .03249 Mdot
.63 .03257 Mdot
.63 .03289 Mdot
.63 .03337 Mdot
.63 .03359 Mdot
.63 .03397 Mdot
.63 .03399 Mdot
.63 .03402 Mdot
.63 .03405 Mdot
.63 .03434 Mdot
.63 .03472 Mdot
.63 .03493 Mdot
.63 .03518 Mdot
.63 .03523 Mdot
.63 .03532 Mdot
.63 .03589 Mdot
.63 .03601 Mdot
.63 .03604 Mdot
.63 .03646 Mdot
.63 .03687 Mdot
.63 .03704 Mdot
.63 .03711 Mdot
.63 .03721 Mdot
.63 .03743 Mdot
.63 .03762 Mdot
.63 .03809 Mdot
.63 .03822 Mdot
.63 .03849 Mdot
.63 .03897 Mdot
.63 .039 Mdot
.63 .03904 Mdot
.63 .03908 Mdot
.63 .03944 Mdot
.63 .03993 Mdot
.63 .04019 Mdot
.63 .0405 Mdot
.63 .04054 Mdot
.63 .04056 Mdot
.63 .04068 Mdot
.63 .04073 Mdot
.63 .04123 Mdot
.63 .04139 Mdot
.63 .04155 Mdot
.63 .04159 Mdot
.63 .042 Mdot
.63 .04211 Mdot
.63 .04224 Mdot
.63 .04263 Mdot
.63 .04285 Mdot
.63 .04294 Mdot
.63 .04305 Mdot
.63 .04334 Mdot
.63 .04358 Mdot
.63 .04417 Mdot
.63 .04433 Mdot
.63 .04468 Mdot
.63 .04528 Mdot
.63 .04531 Mdot
.63 .04536 Mdot
.63 .04542 Mdot
.63 .04582 Mdot
.63 .04587 Mdot
.63 .0462 Mdot
.63 .04648 Mdot
.63 .04681 Mdot
.63 .0472 Mdot
.63 .04725 Mdot
.63 .04728 Mdot
.63 .04743 Mdot
.63 .0475 Mdot
.63 .04813 Mdot
.63 .04833 Mdot
.63 .0485 Mdot
.63 .04853 Mdot
.63 .04857 Mdot
.63 .04859 Mdot
.63 .04873 Mdot
.63 .04909 Mdot
.63 .04923 Mdot
.63 .0494 Mdot
.63 .04988 Mdot
.63 .05 Mdot
.63 .05017 Mdot
.63 .05027 Mdot
.63 .05042 Mdot
.63 .05075 Mdot
.63 .05078 Mdot
.63 .05108 Mdot
.63 .05158 Mdot
.63 .05182 Mdot
.63 .05203 Mdot
.63 .05246 Mdot
.63 .05323 Mdot
.63 .05327 Mdot
.63 .05333 Mdot
.63 .0534 Mdot
.63 .05353 Mdot
.63 .05391 Mdot
.63 .05397 Mdot
.63 .05423 Mdot
.63 .05438 Mdot
.63 .05474 Mdot
.63 .055 Mdot
.63 .05501 Mdot
.63 .05515 Mdot
.63 .05565 Mdot
.63 .05565 Mdot
.63 .05571 Mdot
.63 .05575 Mdot
.63 .05593 Mdot
.63 .05601 Mdot
.63 .05602 Mdot
.63 .05681 Mdot
.63 .05707 Mdot
.63 .05728 Mdot
.63 .05732 Mdot
.63 .05738 Mdot
.63 .0574 Mdot
.63 .05757 Mdot
.63 .05788 Mdot
.63 .05803 Mdot
.63 .05821 Mdot
.63 .05842 Mdot
.63 .05852 Mdot
.63 .0586 Mdot
.63 .05873 Mdot
.63 .05903 Mdot
.63 .05917 Mdot
.63 .05938 Mdot
.63 .05952 Mdot
.63 .05971 Mdot
.63 .06013 Mdot
.63 .06016 Mdot
.63 .06053 Mdot
.63 .06116 Mdot
.63 .06147 Mdot
.63 .06147 Mdot
.63 .06174 Mdot
.63 .06196 Mdot
.63 .06228 Mdot
.63 .06324 Mdot
.63 .06329 Mdot
.63 .06337 Mdot
.63 .06346 Mdot
.63 .06362 Mdot
.63 .0641 Mdot
.63 .06418 Mdot
.63 .06451 Mdot
.63 .0647 Mdot
.63 .06514 Mdot
.63 .06548 Mdot
.63 .06549 Mdot
.63 .06567 Mdot
.63 .06629 Mdot
.63 .06629 Mdot
.63 .06637 Mdot
.63 .06642 Mdot
.63 .06665 Mdot
.63 .06673 Mdot
.63 .06674 Mdot
.63 .06676 Mdot
.63 .06776 Mdot
.63 .06808 Mdot
.63 .06835 Mdot
.63 .0684 Mdot
.63 .06847 Mdot
.63 .0685 Mdot
.63 .06871 Mdot
.63 .06911 Mdot
.63 .06929 Mdot
.63 .06935 Mdot
.63 .0695 Mdot
.63 .06951 Mdot
.63 .06978 Mdot
.63 .06991 Mdot
.63 .07002 Mdot
.63 .07017 Mdot
.63 .07055 Mdot
.63 .07073 Mdot
.63 .07084 Mdot
.63 .071 Mdot
.63 .07117 Mdot
.63 .0714 Mdot
.63 .07147 Mdot
.63 .07188 Mdot
.63 .07193 Mdot
.63 .07198 Mdot
.63 .07242 Mdot
.63 .07245 Mdot
.63 .0727 Mdot
.63 .0729 Mdot
.63 .07324 Mdot
.63 .07362 Mdot
.63 .07363 Mdot
.63 .07396 Mdot
.63 .07424 Mdot
.63 .07436 Mdot
.63 .07465 Mdot
.63 .07479 Mdot
.63 .07547 Mdot
.63 .07586 Mdot
.63 .07592 Mdot
.63 .07602 Mdot
.63 .07613 Mdot
.63 .07633 Mdot
.63 .07694 Mdot
.63 .07704 Mdot
.63 .07746 Mdot
.63 .07753 Mdot
.63 .07769 Mdot
.63 .07826 Mdot
.63 .07868 Mdot
.63 .07869 Mdot
.63 .07891 Mdot
.63 .07903 Mdot
.63 .07947 Mdot
.63 .0797 Mdot
.63 .0797 Mdot
.63 .0798 Mdot
.63 .07986 Mdot
.63 .08016 Mdot
.63 .08026 Mdot
.63 .08027 Mdot
.63 .08029 Mdot
.63 .08072 Mdot
.63 .0808 Mdot
.63 .08155 Mdot
.63 .08196 Mdot
.63 .08198 Mdot
.63 .08229 Mdot
.63 .08236 Mdot
.63 .08244 Mdot
.63 .08249 Mdot
.63 .08275 Mdot
.63 .08292 Mdot
.63 .08325 Mdot
.63 .08348 Mdot
.63 .08355 Mdot
.63 .08375 Mdot
.63 .08376 Mdot
.63 .08395 Mdot
.63 .0841 Mdot
.63 .08426 Mdot
.63 .08439 Mdot
.63 .08459 Mdot
.63 .08482 Mdot
.63 .08507 Mdot
.63 .08529 Mdot
.63 .08543 Mdot
.63 .08563 Mdot
.63 .08584 Mdot
.63 .08605 Mdot
.63 .08614 Mdot
.63 .08623 Mdot
.63 .08674 Mdot
.63 .08681 Mdot
.63 .08687 Mdot
.63 .08742 Mdot
.63 .08746 Mdot
.63 .08749 Mdot
.63 .08777 Mdot
.63 .08802 Mdot
.63 .08846 Mdot
.63 .08894 Mdot
.63 .08895 Mdot
.63 .08909 Mdot
.63 .08937 Mdot
.63 .08953 Mdot
.63 .08971 Mdot
.63 .08987 Mdot
.63 .09023 Mdot
.63 .09041 Mdot
.63 .09052 Mdot
.63 .09125 Mdot
.63 .09127 Mdot
.63 .09142 Mdot
.63 .09176 Mdot
.63 .09184 Mdot
.63 .09196 Mdot
.63 .09209 Mdot
.63 .09235 Mdot
.63 .09244 Mdot
.63 .09267 Mdot
.63 .09311 Mdot
.63 .09324 Mdot
.63 .09373 Mdot
.63 .09377 Mdot
.63 .09387 Mdot
.63 .09402 Mdot
.63 .09407 Mdot
.63 .09478 Mdot
.63 .09485 Mdot
.63 .09531 Mdot
.63 .09533 Mdot
.63 .09535 Mdot
.63 .09561 Mdot
.63 .09576 Mdot
.63 .09592 Mdot
.63 .09631 Mdot
.63 .09645 Mdot
.63 .0966 Mdot
.63 .0966 Mdot
.63 .09673 Mdot
.63 .0968 Mdot
.63 .09717 Mdot
.63 .0973 Mdot
.63 .09731 Mdot
.63 .09734 Mdot
.63 .09788 Mdot
.63 .09798 Mdot
.63 .09892 Mdot
.63 .09944 Mdot
.63 .09947 Mdot
.63 .09974 Mdot
.63 .09986 Mdot
.63 .09995 Mdot
.63 .10005 Mdot
.63 .10011 Mdot
.63 .10015 Mdot
.63 .10044 Mdot
.63 .10052 Mdot
.63 .10066 Mdot
.63 .10107 Mdot
.63 .10136 Mdot
.63 .10145 Mdot
.63 .1017 Mdot
.63 .10171 Mdot
.63 .10195 Mdot
.63 .10214 Mdot
.63 .10234 Mdot
.63 .10251 Mdot
.63 .10276 Mdot
.63 .10304 Mdot
.63 .10336 Mdot
.63 .10364 Mdot
.63 .10379 Mdot
.63 .10382 Mdot
.63 .10402 Mdot
.63 .10407 Mdot
.63 .10428 Mdot
.63 .10434 Mdot
.63 .1045 Mdot
.63 .1046 Mdot
.63 .10471 Mdot
.63 .10482 Mdot
.63 .10547 Mdot
.63 .10555 Mdot
.63 .10563 Mdot
.63 .10627 Mdot
.63 .10632 Mdot
.63 .10637 Mdot
.63 .10642 Mdot
.63 .10677 Mdot
.63 .10709 Mdot
.63 .10763 Mdot
.63 .10788 Mdot
.63 .10824 Mdot
.63 .10825 Mdot
.63 .10843 Mdot
.63 .10877 Mdot
.63 .10898 Mdot
.63 .10921 Mdot
.63 .10941 Mdot
.63 .10986 Mdot
.63 .11009 Mdot
.63 .11024 Mdot
.63 .11062 Mdot
.63 .11115 Mdot
.63 .11118 Mdot
.63 .11136 Mdot
.63 .11179 Mdot
.63 .11189 Mdot
.63 .11204 Mdot
.63 .11221 Mdot
.63 .11254 Mdot
.63 .11264 Mdot
.63 .11293 Mdot
.63 .1135 Mdot
.63 .11366 Mdot
.63 .11427 Mdot
.63 .11432 Mdot
.63 .11445 Mdot
.63 .11464 Mdot
.63 .1147 Mdot
.63 .11559 Mdot
.63 .11569 Mdot
.63 .11626 Mdot
.63 .11629 Mdot
.63 .11632 Mdot
.63 .11664 Mdot
.63 .11683 Mdot
.63 .11703 Mdot
.63 .11752 Mdot
.63 .1177 Mdot
.63 .11789 Mdot
.63 .11789 Mdot
.63 .11805 Mdot
.63 .11814 Mdot
.63 .11861 Mdot
.63 .11877 Mdot
.63 .11879 Mdot
.63 .11882 Mdot
.63 .1195 Mdot
.63 .11963 Mdot
.63 .12082 Mdot
.63 .12147 Mdot
.63 .12151 Mdot
.63 .12185 Mdot
.63 .122 Mdot
.63 .12211 Mdot
.63 .12224 Mdot
.63 .12231 Mdot
.63 .12236 Mdot
.63 .12273 Mdot
.63 .12283 Mdot
.63 .123 Mdot
.63 .12352 Mdot
.63 .12389 Mdot
.63 .124 Mdot
.63 .12431 Mdot
.63 .12433 Mdot
.63 .12463 Mdot
.63 .12487 Mdot
.63 .12512 Mdot
.63 .12534 Mdot
.63 .12565 Mdot
.63 .12601 Mdot
.63 .12641 Mdot
.63 .12676 Mdot
.63 .12695 Mdot
.63 .12699 Mdot
.63 .12724 Mdot
.63 .1273 Mdot
.63 .12757 Mdot
.63 .12764 Mdot
.63 .12785 Mdot
.63 .12797 Mdot
.63 .12811 Mdot
.63 .12824 Mdot
.63 .12907 Mdot
.63 .12917 Mdot
.63 .12926 Mdot
.63 .13008 Mdot
.63 .13014 Mdot
.63 .1302 Mdot
.63 .13026 Mdot
.63 .1307 Mdot
.63 .1311 Mdot
.63 .13179 Mdot
.63 .1321 Mdot
.63 .13255 Mdot
.63 .13257 Mdot
.63 .1328 Mdot
.63 .13323 Mdot
.63 .13349 Mdot
.63 .13378 Mdot
.63 .13403 Mdot
.63 .1346 Mdot
.63 .13489 Mdot
.63 .13507 Mdot
.63 .13555 Mdot
.63 .13623 Mdot
.63 .13626 Mdot
.63 .13649 Mdot
.63 .13703 Mdot
.63 .13715 Mdot
.63 .13735 Mdot
.63 .13756 Mdot
.63 .13797 Mdot
.63 .13811 Mdot
.63 .13847 Mdot
.63 .13918 Mdot
.63 .13939 Mdot
.63 .14016 Mdot
.63 .14022 Mdot
.63 .14038 Mdot
.63 .14062 Mdot
.63 .14069 Mdot
.63 .14182 Mdot
.63 .14194 Mdot
.63 .14266 Mdot
.63 .14269 Mdot
.63 .14274 Mdot
.63 .14314 Mdot
.63 .14338 Mdot
.63 .14363 Mdot
.63 .14425 Mdot
.63 .14447 Mdot
.63 .14471 Mdot
.63 .14472 Mdot
.63 .14492 Mdot
.63 .14503 Mdot
.63 .14562 Mdot
.63 .14582 Mdot
.63 .14585 Mdot
.63 .14589 Mdot
.63 .14675 Mdot
.63 .1469 Mdot
.63 .14841 Mdot
.63 .14923 Mdot
.63 .14928 Mdot
.63 .1497 Mdot
.63 .1499 Mdot
.63 .15003 Mdot
.63 .1502 Mdot
.63 .15028 Mdot
.63 .15035 Mdot
.63 .15081 Mdot
.63 .15094 Mdot
.63 .15116 Mdot
.63 .15181 Mdot
.63 .15228 Mdot
.63 .15242 Mdot
.63 .15281 Mdot
.63 .15283 Mdot
.63 .15321 Mdot
.63 .1535 Mdot
.63 .15383 Mdot
.63 .1541 Mdot
.63 .15449 Mdot
.63 .15494 Mdot
.63 .15545 Mdot
.63 .1559 Mdot
.63 .15613 Mdot
.63 .15618 Mdot
.63 .1565 Mdot
.63 .15657 Mdot
.63 .15691 Mdot
.63 .157 Mdot
.63 .15726 Mdot
.63 .15742 Mdot
.63 .1576 Mdot
.63 .15776 Mdot
.63 .1588 Mdot
.63 .15893 Mdot
.63 .15905 Mdot
.63 .16007 Mdot
.63 .16015 Mdot
.63 .16023 Mdot
.63 .1603 Mdot
.63 .16086 Mdot
.63 .16136 Mdot
.63 .16222 Mdot
.63 .16262 Mdot
.63 .16319 Mdot
.63 .16321 Mdot
.63 .1635 Mdot
.63 .16404 Mdot
.63 .16438 Mdot
.63 .16474 Mdot
.63 .16505 Mdot
.63 .16577 Mdot
.63 .16613 Mdot
.63 .16636 Mdot
.63 .16697 Mdot
.63 .16782 Mdot
.63 .16786 Mdot
.63 .16815 Mdot
.63 .16883 Mdot
.63 .16899 Mdot
.63 .16923 Mdot
.63 .1695 Mdot
.63 .17002 Mdot
.63 .17019 Mdot
.63 .17065 Mdot
.63 .17154 Mdot
.63 .1718 Mdot
.63 .17277 Mdot
.63 .17285 Mdot
.63 .17305 Mdot
.63 .17335 Mdot
.63 .17345 Mdot
.63 .17487 Mdot
.63 .17502 Mdot
.63 .17593 Mdot
.63 .17597 Mdot
.63 .17602 Mdot
.63 .17653 Mdot
.63 .17683 Mdot
.63 .17715 Mdot
.63 .17793 Mdot
.63 .17821 Mdot
.63 .17851 Mdot
.63 .17852 Mdot
.63 .17877 Mdot
.63 .17891 Mdot
.63 .17965 Mdot
.63 .17991 Mdot
.63 .17994 Mdot
.63 .17999 Mdot
.63 .18108 Mdot
.63 .18127 Mdot
.63 .18317 Mdot
.63 .1842 Mdot
.63 .18427 Mdot
.63 .1848 Mdot
.63 .18505 Mdot
.63 .18521 Mdot
.63 .18542 Mdot
.63 .18553 Mdot
.63 .18561 Mdot
.63 .18619 Mdot
.63 .18636 Mdot
.63 .18663 Mdot
.63 .18745 Mdot
.63 .18805 Mdot
.63 .18822 Mdot
.63 .18871 Mdot
.63 .18875 Mdot
.63 .18922 Mdot
.63 .18959 Mdot
.63 .19 Mdot
.63 .19034 Mdot
.63 .19083 Mdot
.63 .1914 Mdot
.63 .19204 Mdot
.63 .19261 Mdot
.63 .19289 Mdot
.63 .19296 Mdot
.63 .19336 Mdot
.63 .19346 Mdot
.63 .19388 Mdot
.63 .19399 Mdot
.63 .19432 Mdot
.63 .19452 Mdot
.63 .19475 Mdot
.63 .19495 Mdot
.63 .19626 Mdot
.63 .19642 Mdot
.63 .19657 Mdot
.63 .19787 Mdot
.63 .19796 Mdot
.63 .19806 Mdot
.63 .19815 Mdot
.63 .19885 Mdot
.63 .19949 Mdot
.63 .20058 Mdot
.63 .20108 Mdot
.63 .20179 Mdot
.63 .20181 Mdot
.63 .20218 Mdot
.63 .20287 Mdot
.63 .20329 Mdot
.63 .20375 Mdot
.63 .20414 Mdot
.63 .20505 Mdot
.63 .2055 Mdot
.63 .20579 Mdot
.63 .20656 Mdot
.63 .20763 Mdot
.63 .20767 Mdot
.63 .20804 Mdot
.63 .2089 Mdot
.63 .2091 Mdot
.63 .20941 Mdot
.63 .20975 Mdot
.63 .21039 Mdot
.63 .21061 Mdot
.63 .21119 Mdot
.63 .21232 Mdot
.63 .21264 Mdot
.63 .21387 Mdot
.63 .21396 Mdot
.63 .21421 Mdot
.63 .2146 Mdot
.63 .21472 Mdot
.63 .21651 Mdot
.63 .2167 Mdot
.63 .21785 Mdot
.63 .2179 Mdot
.63 .21796 Mdot
.63 .2186 Mdot
.63 .21898 Mdot
.63 .21939 Mdot
.63 .22036 Mdot
.63 .22071 Mdot
.63 .2211 Mdot
.63 .2211 Mdot
.63 .22142 Mdot
.63 .2216 Mdot
.63 .22254 Mdot
.63 .22286 Mdot
.63 .2229 Mdot
.63 .22296 Mdot
.63 .22433 Mdot
.63 .22458 Mdot
.63 .22696 Mdot
.63 .22827 Mdot
.63 .22835 Mdot
.63 .22902 Mdot
.63 .22933 Mdot
.63 .22954 Mdot
.63 .2298 Mdot
.63 .22994 Mdot
.63 .23004 Mdot
.63 .23078 Mdot
.63 .23099 Mdot
.63 .23133 Mdot
.63 .23236 Mdot
.63 .23311 Mdot
.63 .23333 Mdot
.63 .23395 Mdot
.63 .23399 Mdot
.63 .23459 Mdot
.63 .23506 Mdot
.63 .23557 Mdot
.63 .236 Mdot
.63 .23662 Mdot
.63 .23734 Mdot
.63 .23814 Mdot
.63 .23886 Mdot
.63 .23922 Mdot
.63 .2393 Mdot
.63 .23981 Mdot
.63 .23993 Mdot
.63 .24046 Mdot
.63 .2406 Mdot
.63 .24102 Mdot
.63 .24127 Mdot
.63 .24155 Mdot
.63 .24182 Mdot
.63 .24346 Mdot
.63 .24367 Mdot
.63 .24385 Mdot
.63 .24549 Mdot
.63 .2456 Mdot
.63 .24573 Mdot
.63 .24584 Mdot
.63 .24673 Mdot
.63 .24753 Mdot
.63 .2489 Mdot
.63 .24953 Mdot
.63 .25046 Mdot
.63 .25093 Mdot
.63 .25179 Mdot
.63 .25232 Mdot
.63 .2529 Mdot
.63 .25339 Mdot
.63 .25453 Mdot
.63 .25511 Mdot
.63 .25547 Mdot
.63 .25643 Mdot
.63 .25778 Mdot
.63 .25784 Mdot
.63 .25831 Mdot
.63 .25938 Mdot
.63 .25964 Mdot
.63 .26003 Mdot
.63 .26046 Mdot
.63 .26127 Mdot
.63 .26154 Mdot
.63 .26227 Mdot
.63 .26369 Mdot
.63 .26411 Mdot
.63 .26565 Mdot
.63 .26577 Mdot
.63 .26608 Mdot
.63 .26657 Mdot
.63 .26672 Mdot
.63 .26897 Mdot
.63 .26921 Mdot
.63 .27066 Mdot
.63 .27072 Mdot
.63 .27081 Mdot
.63 .27161 Mdot
.63 .27208 Mdot
.63 .2726 Mdot
.63 .27383 Mdot
.63 .27427 Mdot
.63 .27476 Mdot
.63 .27477 Mdot
.63 .27517 Mdot
.63 .27539 Mdot
.63 .27657 Mdot
.63 .27697 Mdot
.63 .27703 Mdot
.63 .27711 Mdot
.63 .27883 Mdot
.63 .27914 Mdot
.63 .28215 Mdot
.63 .2838 Mdot
.63 .28389 Mdot
.63 .28474 Mdot
.63 .28513 Mdot
.63 .28539 Mdot
.63 .28573 Mdot
.63 .2859 Mdot
.63 .28603 Mdot
.63 .28695 Mdot
.63 .28722 Mdot
.63 .28765 Mdot
.63 .28895 Mdot
.63 .2899 Mdot
.63 .29017 Mdot
.63 .29096 Mdot
.63 .29101 Mdot
.63 .29175 Mdot
.63 .29235 Mdot
.63 .29299 Mdot
.63 .29354 Mdot
.63 .29432 Mdot
.63 .29522 Mdot
.63 .29623 Mdot
.63 .29713 Mdot
.63 .29759 Mdot
.63 .2977 Mdot
.63 .29834 Mdot
.63 .29848 Mdot
.63 .29915 Mdot
.63 .29933 Mdot
.63 .29986 Mdot
.63 .30018 Mdot
.63 .30053 Mdot
.63 .30086 Mdot
.63 .30294 Mdot
.63 .30319 Mdot
.63 .30343 Mdot
.63 .30549 Mdot
.63 .30564 Mdot
.63 .3058 Mdot
.63 .30594 Mdot
.63 .30705 Mdot
.63 .30806 Mdot
.63 .30979 Mdot
.63 .31059 Mdot
.63 .31175 Mdot
.63 .31234 Mdot
.63 .31343 Mdot
.63 .3141 Mdot
.63 .31483 Mdot
.63 .31545 Mdot
.63 .31688 Mdot
.63 .31761 Mdot
.63 .31807 Mdot
.63 .31928 Mdot
.63 .32098 Mdot
.63 .32106 Mdot
.63 .32164 Mdot
.63 .323 Mdot
.63 .32332 Mdot
.63 .32381 Mdot
.63 .32435 Mdot
.63 .32537 Mdot
.63 .32572 Mdot
.63 .32664 Mdot
.63 .32843 Mdot
.63 .32895 Mdot
.63 .33089 Mdot
.63 .33104 Mdot
.63 .33144 Mdot
.63 .33205 Mdot
.63 .33224 Mdot
.63 .33508 Mdot
.63 .33538 Mdot
.63 .33721 Mdot
.63 .33728 Mdot
.63 .33739 Mdot
.63 .3384 Mdot
.63 .339 Mdot
.63 .33965 Mdot
.63 .3412 Mdot
.63 .34176 Mdot
.63 .34237 Mdot
.63 .34238 Mdot
.63 .34288 Mdot
.63 .34317 Mdot
.63 .34466 Mdot
.63 .34516 Mdot
.63 .34523 Mdot
.63 .34533 Mdot
.63 .3475 Mdot
.63 .34789 Mdot
.63 .35168 Mdot
.63 .35376 Mdot
.63 .35388 Mdot
.63 .35494 Mdot
.63 .35544 Mdot
.63 .35577 Mdot
.63 .35619 Mdot
.63 .35641 Mdot
.63 .35657 Mdot
.63 .35773 Mdot
.63 .35807 Mdot
.63 .35862 Mdot
.63 .36025 Mdot
.63 .36144 Mdot
.63 .36179 Mdot
.63 .36278 Mdot
.63 .36284 Mdot
.63 .36378 Mdot
.63 .36453 Mdot
.63 .36534 Mdot
.63 .36603 Mdot
.63 .36701 Mdot
.63 .36816 Mdot
.63 .36943 Mdot
.63 .37056 Mdot
.63 .37114 Mdot
.63 .37127 Mdot
.63 .37208 Mdot
.63 .37226 Mdot
.63 .37311 Mdot
.63 .37334 Mdot
.63 .374 Mdot
.63 .37439 Mdot
.63 .37484 Mdot
.63 .37526 Mdot
.63 .37788 Mdot
.63 .3782 Mdot
.63 .3785 Mdot
.63 .38109 Mdot
.63 .38128 Mdot
.63 .38148 Mdot
.63 .38166 Mdot
.63 .38306 Mdot
.63 .38434 Mdot
.63 .38651 Mdot
.632 .01692 Mdot
.632 .01711 Mdot
.632 .01751 Mdot
.632 .01774 Mdot
.632 .01824 Mdot
.632 .01854 Mdot
.632 .01894 Mdot
.632 .01917 Mdot
.632 .01955 Mdot
.632 .02001 Mdot
.632 .02006 Mdot
.632 .02035 Mdot
.632 .02082 Mdot
.632 .02096 Mdot
.632 .02116 Mdot
.632 .02141 Mdot
.632 .02147 Mdot
.632 .02184 Mdot
.632 .02196 Mdot
.632 .02206 Mdot
.632 .02243 Mdot
.632 .0226 Mdot
.632 .02286 Mdot
.632 .02297 Mdot
.632 .02318 Mdot
.632 .02325 Mdot
.632 .02334 Mdot
.632 .02357 Mdot
.632 .02372 Mdot
.632 .02387 Mdot
.632 .02399 Mdot
.632 .02447 Mdot
.632 .02469 Mdot
.632 .02502 Mdot
.632 .02505 Mdot
.632 .02515 Mdot
.632 .02541 Mdot
.632 .0255 Mdot
.632 .02562 Mdot
.632 .02591 Mdot
.632 .02591 Mdot
.632 .02603 Mdot
.632 .0261 Mdot
.632 .02629 Mdot
.632 .02644 Mdot
.632 .02705 Mdot
.632 .02732 Mdot
.632 .02774 Mdot
.632 .02778 Mdot
.632 .0279 Mdot
.632 .02824 Mdot
.632 .02835 Mdot
.632 .0285 Mdot
.632 .02886 Mdot
.632 .02887 Mdot
.632 .02902 Mdot
.632 .0291 Mdot
.632 .02934 Mdot
.632 .02954 Mdot
.632 .02961 Mdot
.632 .0303 Mdot
.632 .03054 Mdot
.632 .03065 Mdot
.632 .03117 Mdot
.632 .03124 Mdot
.632 .03139 Mdot
.632 .03156 Mdot
.632 .03181 Mdot
.632 .03195 Mdot
.632 .03214 Mdot
.632 .03217 Mdot
.632 .0326 Mdot
.632 .03261 Mdot
.632 .0328 Mdot
.632 .0329 Mdot
.632 .03291 Mdot
.632 .0332 Mdot
.632 .03345 Mdot
.632 .03354 Mdot
.632 .03409 Mdot
.632 .03442 Mdot
.632 .03472 Mdot
.632 .03485 Mdot
.632 .0349 Mdot
.632 .03552 Mdot
.632 .0356 Mdot
.632 .03579 Mdot
.632 .03598 Mdot
.632 .03601 Mdot
.632 .03632 Mdot
.632 .0365 Mdot
.632 .03674 Mdot
.632 .03677 Mdot
.632 .0368 Mdot
.632 .03705 Mdot
.632 .03732 Mdot
.632 .03733 Mdot
.632 .03757 Mdot
.632 .0377 Mdot
.632 .03772 Mdot
.632 .03808 Mdot
.632 .0384 Mdot
.632 .03851 Mdot
.632 .0392 Mdot
.632 .03962 Mdot
.632 .04 Mdot
.632 .04017 Mdot
.632 .04017 Mdot
.632 .04023 Mdot
.632 .04099 Mdot
.632 .04101 Mdot
.632 .04102 Mdot
.632 .04111 Mdot
.632 .04135 Mdot
.632 .04159 Mdot
.632 .04163 Mdot
.632 .04202 Mdot
.632 .04225 Mdot
.632 .04255 Mdot
.632 .0426 Mdot
.632 .04263 Mdot
.632 .04295 Mdot
.632 .04329 Mdot
.632 .0433 Mdot
.632 .04361 Mdot
.632 .04377 Mdot
.632 .04379 Mdot
.632 .04425 Mdot
.632 .04465 Mdot
.632 .0448 Mdot
.632 .04567 Mdot
.632 .04619 Mdot
.632 .04635 Mdot
.632 .04667 Mdot
.632 .04689 Mdot
.632 .04689 Mdot
.632 .04697 Mdot
.632 .04728 Mdot
.632 .04732 Mdot
.632 .04793 Mdot
.632 .04795 Mdot
.632 .04797 Mdot
.632 .04808 Mdot
.632 .04827 Mdot
.632 .04838 Mdot
.632 .04869 Mdot
.632 .04873 Mdot
.632 .04923 Mdot
.632 .04952 Mdot
.632 .04976 Mdot
.632 .04979 Mdot
.632 .0499 Mdot
.632 .04996 Mdot
.632 .05 Mdot
.632 .05041 Mdot
.632 .05083 Mdot
.632 .05085 Mdot
.632 .05123 Mdot
.632 .05144 Mdot
.632 .05147 Mdot
.632 .05205 Mdot
.632 .05255 Mdot
.632 .05274 Mdot
.632 .05365 Mdot
.632 .05384 Mdot
.632 .0545 Mdot
.632 .0547 Mdot
.632 .0551 Mdot
.632 .05535 Mdot
.632 .05538 Mdot
.632 .05538 Mdot
.632 .05548 Mdot
.632 .05572 Mdot
.632 .05588 Mdot
.632 .05592 Mdot
.632 .05636 Mdot
.632 .0567 Mdot
.632 .05672 Mdot
.632 .05675 Mdot
.632 .05688 Mdot
.632 .0571 Mdot
.632 .05713 Mdot
.632 .05723 Mdot
.632 .05725 Mdot
.632 .05727 Mdot
.632 .05766 Mdot
.632 .05771 Mdot
.632 .05805 Mdot
.632 .05834 Mdot
.632 .0587 Mdot
.632 .05901 Mdot
.632 .05905 Mdot
.632 .05918 Mdot
.632 .05926 Mdot
.632 .05932 Mdot
.632 .05983 Mdot
.632 .05994 Mdot
.632 .06036 Mdot
.632 .06038 Mdot
.632 .06088 Mdot
.632 .0611 Mdot
.632 .06114 Mdot
.632 .06117 Mdot
.632 .06145 Mdot
.632 .0619 Mdot
.632 .06254 Mdot
.632 .06277 Mdot
.632 .06393 Mdot
.632 .06405 Mdot
.632 .06417 Mdot
.632 .06435 Mdot
.632 .06435 Mdot
.632 .065 Mdot
.632 .06515 Mdot
.632 .06526 Mdot
.632 .06536 Mdot
.632 .06577 Mdot
.632 .06608 Mdot
.632 .06612 Mdot
.632 .06612 Mdot
.632 .06622 Mdot
.632 .06624 Mdot
.632 .06655 Mdot
.632 .06675 Mdot
.632 .0668 Mdot
.632 .06735 Mdot
.632 .06778 Mdot
.632 .06781 Mdot
.632 .06785 Mdot
.632 .0679 Mdot
.632 .06802 Mdot
.632 .06829 Mdot
.632 .06833 Mdot
.632 .06845 Mdot
.632 .06847 Mdot
.632 .0685 Mdot
.632 .069 Mdot
.632 .06907 Mdot
.632 .0695 Mdot
.632 .06951 Mdot
.632 .06986 Mdot
.632 .06999 Mdot
.632 .07032 Mdot
.632 .0707 Mdot
.632 .07075 Mdot
.632 .07092 Mdot
.632 .07102 Mdot
.632 .07109 Mdot
.632 .07144 Mdot
.632 .07174 Mdot
.632 .07188 Mdot
.632 .07241 Mdot
.632 .07244 Mdot
.632 .07306 Mdot
.632 .07334 Mdot
.632 .0734 Mdot
.632 .07343 Mdot
.632 .07379 Mdot
.632 .07436 Mdot
.632 .0745 Mdot
.632 .07466 Mdot
.632 .07505 Mdot
.632 .07517 Mdot
.632 .07546 Mdot
.632 .07693 Mdot
.632 .07708 Mdot
.632 .07722 Mdot
.632 .07745 Mdot
.632 .07746 Mdot
.632 .07805 Mdot
.632 .07828 Mdot
.632 .07831 Mdot
.632 .07846 Mdot
.632 .07858 Mdot
.632 .0786 Mdot
.632 .07872 Mdot
.632 .07901 Mdot
.632 .07925 Mdot
.632 .07964 Mdot
.632 .07969 Mdot
.632 .07969 Mdot
.632 .07981 Mdot
.632 .07984 Mdot
.632 .07998 Mdot
.632 .08024 Mdot
.632 .08048 Mdot
.632 .08056 Mdot
.632 .08078 Mdot
.632 .08125 Mdot
.632 .08179 Mdot
.632 .08183 Mdot
.632 .08187 Mdot
.632 .08194 Mdot
.632 .08209 Mdot
.632 .08221 Mdot
.632 .08243 Mdot
.632 .08248 Mdot
.632 .08252 Mdot
.632 .08264 Mdot
.632 .08267 Mdot
.632 .0827 Mdot
.632 .08278 Mdot
.632 .08333 Mdot
.632 .08342 Mdot
.632 .08354 Mdot
.632 .08374 Mdot
.632 .08396 Mdot
.632 .08398 Mdot
.632 .08398 Mdot
.632 .08442 Mdot
.632 .08447 Mdot
.632 .08458 Mdot
.632 .08498 Mdot
.632 .085 Mdot
.632 .08548 Mdot
.632 .08555 Mdot
.632 .08576 Mdot
.632 .08588 Mdot
.632 .08597 Mdot
.632 .08641 Mdot
.632 .08679 Mdot
.632 .08698 Mdot
.632 .08764 Mdot
.632 .08768 Mdot
.632 .08804 Mdot
.632 .08847 Mdot
.632 .08862 Mdot
.632 .08882 Mdot
.632 .08889 Mdot
.632 .08893 Mdot
.632 .08939 Mdot
.632 .08941 Mdot
.632 .09011 Mdot
.632 .09029 Mdot
.632 .09048 Mdot
.632 .09075 Mdot
.632 .09097 Mdot
.632 .09113 Mdot
.632 .09134 Mdot
.632 .0915 Mdot
.632 .09215 Mdot
.632 .09231 Mdot
.632 .09232 Mdot
.632 .09335 Mdot
.632 .09353 Mdot
.632 .09354 Mdot
.632 .09372 Mdot
.632 .09401 Mdot
.632 .09402 Mdot
.632 .09477 Mdot
.632 .09506 Mdot
.632 .0951 Mdot
.632 .09517 Mdot
.632 .09529 Mdot
.632 .09544 Mdot
.632 .09546 Mdot
.632 .09547 Mdot
.632 .09562 Mdot
.632 .09599 Mdot
.632 .09621 Mdot
.632 .09628 Mdot
.632 .09679 Mdot
.632 .09684 Mdot
.632 .09684 Mdot
.632 .097 Mdot
.632 .09704 Mdot
.632 .09721 Mdot
.632 .09753 Mdot
.632 .09785 Mdot
.632 .09794 Mdot
.632 .09822 Mdot
.632 .09881 Mdot
.632 .09884 Mdot
.632 .09892 Mdot
.632 .0995 Mdot
.632 .09955 Mdot
.632 .0996 Mdot
.632 .09969 Mdot
.632 .09988 Mdot
.632 .10003 Mdot
.632 .10031 Mdot
.632 .10037 Mdot
.632 .10042 Mdot
.632 .10057 Mdot
.632 .10061 Mdot
.632 .10065 Mdot
.632 .10075 Mdot
.632 .10085 Mdot
.632 .10144 Mdot
.632 .10155 Mdot
.632 .10171 Mdot
.632 .10196 Mdot
.632 .10208 Mdot
.632 .10224 Mdot
.632 .10227 Mdot
.632 .10227 Mdot
.632 .10251 Mdot
.632 .10282 Mdot
.632 .10288 Mdot
.632 .10303 Mdot
.632 .10354 Mdot
.632 .10355 Mdot
.632 .10392 Mdot
.632 .10416 Mdot
.632 .10425 Mdot
.632 .10452 Mdot
.632 .10467 Mdot
.632 .1047 Mdot
.632 .10479 Mdot
.632 .10482 Mdot
.632 .10529 Mdot
.632 .10534 Mdot
.632 .10548 Mdot
.632 .10582 Mdot
.632 .10606 Mdot
.632 .1069 Mdot
.632 .10694 Mdot
.632 .10739 Mdot
.632 .10789 Mdot
.632 .10794 Mdot
.632 .10813 Mdot
.632 .10816 Mdot
.632 .10838 Mdot
.632 .10847 Mdot
.632 .10853 Mdot
.632 .10889 Mdot
.632 .1091 Mdot
.632 .10913 Mdot
.632 .11001 Mdot
.632 .11024 Mdot
.632 .11049 Mdot
.632 .11063 Mdot
.632 .11082 Mdot
.632 .11111 Mdot
.632 .11131 Mdot
.632 .11157 Mdot
.632 .11177 Mdot
.632 .11183 Mdot
.632 .1126 Mdot
.632 .1128 Mdot
.632 .11281 Mdot
.632 .11411 Mdot
.632 .11434 Mdot
.632 .11435 Mdot
.632 .11458 Mdot
.632 .11495 Mdot
.632 .11496 Mdot
.632 .1159 Mdot
.632 .11627 Mdot
.632 .11632 Mdot
.632 .11641 Mdot
.632 .11657 Mdot
.632 .11675 Mdot
.632 .11678 Mdot
.632 .11678 Mdot
.632 .11698 Mdot
.632 .11745 Mdot
.632 .11773 Mdot
.632 .11782 Mdot
.632 .11845 Mdot
.632 .11853 Mdot
.632 .11853 Mdot
.632 .11872 Mdot
.632 .11877 Mdot
.632 .11898 Mdot
.632 .1194 Mdot
.632 .11979 Mdot
.632 .11991 Mdot
.632 .12026 Mdot
.632 .12102 Mdot
.632 .12105 Mdot
.632 .12115 Mdot
.632 .12189 Mdot
.632 .12195 Mdot
.632 .12201 Mdot
.632 .12212 Mdot
.632 .12236 Mdot
.632 .12255 Mdot
.632 .12291 Mdot
.632 .12298 Mdot
.632 .12304 Mdot
.632 .12323 Mdot
.632 .12328 Mdot
.632 .12334 Mdot
.632 .12346 Mdot
.632 .12359 Mdot
.632 .12433 Mdot
.632 .12448 Mdot
.632 .12467 Mdot
.632 .125 Mdot
.632 .12514 Mdot
.632 .12534 Mdot
.632 .12538 Mdot
.632 .12538 Mdot
.632 .12568 Mdot
.632 .12608 Mdot
.632 .12615 Mdot
.632 .12634 Mdot
.632 .12698 Mdot
.632 .127 Mdot
.632 .12748 Mdot
.632 .12778 Mdot
.632 .12788 Mdot
.632 .12823 Mdot
.632 .12842 Mdot
.632 .12845 Mdot
.632 .12856 Mdot
.632 .12861 Mdot
.632 .1292 Mdot
.632 .12927 Mdot
.632 .12945 Mdot
.632 .12988 Mdot
.632 .13017 Mdot
.632 .13123 Mdot
.632 .13129 Mdot
.632 .13186 Mdot
.632 .13248 Mdot
.632 .13255 Mdot
.632 .13279 Mdot
.632 .13282 Mdot
.632 .13311 Mdot
.632 .13322 Mdot
.632 .13329 Mdot
.632 .13375 Mdot
.632 .13402 Mdot
.632 .13406 Mdot
.632 .13517 Mdot
.632 .13545 Mdot
.632 .13577 Mdot
.632 .13596 Mdot
.632 .13619 Mdot
.632 .13655 Mdot
.632 .13681 Mdot
.632 .13714 Mdot
.632 .13739 Mdot
.632 .13747 Mdot
.632 .13844 Mdot
.632 .13869 Mdot
.632 .1387 Mdot
.632 .14035 Mdot
.632 .14064 Mdot
.632 .14065 Mdot
.632 .14095 Mdot
.632 .14141 Mdot
.632 .14142 Mdot
.632 .14262 Mdot
.632 .14308 Mdot
.632 .14314 Mdot
.632 .14326 Mdot
.632 .14346 Mdot
.632 .14368 Mdot
.632 .14372 Mdot
.632 .14373 Mdot
.632 .14398 Mdot
.632 .14457 Mdot
.632 .14492 Mdot
.632 .14503 Mdot
.632 .14584 Mdot
.632 .14593 Mdot
.632 .14593 Mdot
.632 .14618 Mdot
.632 .14624 Mdot
.632 .14651 Mdot
.632 .14703 Mdot
.632 .14753 Mdot
.632 .14768 Mdot
.632 .14813 Mdot
.632 .14908 Mdot
.632 .14913 Mdot
.632 .14925 Mdot
.632 .15018 Mdot
.632 .15026 Mdot
.632 .15034 Mdot
.632 .15048 Mdot
.632 .15078 Mdot
.632 .15102 Mdot
.632 .15147 Mdot
.632 .15156 Mdot
.632 .15164 Mdot
.632 .15188 Mdot
.632 .15194 Mdot
.632 .15202 Mdot
.632 .15217 Mdot
.632 .15233 Mdot
.632 .15327 Mdot
.632 .15345 Mdot
.632 .1537 Mdot
.632 .15411 Mdot
.632 .1543 Mdot
.632 .15455 Mdot
.632 .1546 Mdot
.632 .1546 Mdot
.632 .15498 Mdot
.632 .15548 Mdot
.632 .15557 Mdot
.632 .15581 Mdot
.632 .15662 Mdot
.632 .15665 Mdot
.632 .15724 Mdot
.632 .15763 Mdot
.632 .15776 Mdot
.632 .1582 Mdot
.632 .15844 Mdot
.632 .15848 Mdot
.632 .15862 Mdot
.632 .15868 Mdot
.632 .15943 Mdot
.632 .15951 Mdot
.632 .15974 Mdot
.632 .16028 Mdot
.632 .16065 Mdot
.632 .16199 Mdot
.632 .16207 Mdot
.632 .16278 Mdot
.632 .16357 Mdot
.632 .16365 Mdot
.632 .16397 Mdot
.632 .164 Mdot
.632 .16436 Mdot
.632 .16451 Mdot
.632 .1646 Mdot
.632 .16518 Mdot
.632 .16551 Mdot
.632 .16556 Mdot
.632 .16696 Mdot
.632 .16733 Mdot
.632 .16773 Mdot
.632 .16797 Mdot
.632 .16826 Mdot
.632 .16872 Mdot
.632 .16904 Mdot
.632 .16946 Mdot
.632 .16978 Mdot
.632 .16988 Mdot
.632 .1711 Mdot
.632 .17142 Mdot
.632 .17144 Mdot
.632 .17352 Mdot
.632 .17389 Mdot
.632 .1739 Mdot
.632 .17427 Mdot
.632 .17486 Mdot
.632 .17487 Mdot
.632 .17638 Mdot
.632 .17697 Mdot
.632 .17705 Mdot
.632 .17719 Mdot
.632 .17744 Mdot
.632 .17773 Mdot
.632 .17778 Mdot
.632 .17779 Mdot
.632 .17811 Mdot
.632 .17885 Mdot
.632 .1793 Mdot
.632 .17944 Mdot
.632 .18046 Mdot
.632 .18057 Mdot
.632 .18057 Mdot
.632 .18089 Mdot
.632 .18097 Mdot
.632 .1813 Mdot
.632 .18196 Mdot
.632 .1826 Mdot
.632 .18278 Mdot
.632 .18335 Mdot
.632 .18455 Mdot
.632 .18461 Mdot
.632 .18476 Mdot
.632 .18594 Mdot
.632 .18604 Mdot
.632 .18615 Mdot
.632 .18632 Mdot
.632 .1867 Mdot
.632 .18701 Mdot
.632 .18757 Mdot
.632 .18769 Mdot
.632 .18779 Mdot
.632 .18809 Mdot
.632 .18817 Mdot
.632 .18826 Mdot
.632 .18845 Mdot
.632 .18866 Mdot
.632 .18985 Mdot
.632 .19008 Mdot
.632 .19039 Mdot
.632 .19091 Mdot
.632 .19115 Mdot
.632 .19147 Mdot
.632 .19153 Mdot
.632 .19153 Mdot
.632 .19201 Mdot
.632 .19265 Mdot
.632 .19276 Mdot
.632 .19306 Mdot
.632 .19409 Mdot
.632 .19412 Mdot
.632 .19487 Mdot
.632 .19535 Mdot
.632 .19552 Mdot
.632 .19608 Mdot
.632 .19638 Mdot
.632 .19643 Mdot
.632 .19661 Mdot
.632 .19669 Mdot
.632 .19763 Mdot
.632 .19773 Mdot
.632 .19802 Mdot
.632 .19871 Mdot
.632 .19918 Mdot
.632 .20088 Mdot
.632 .20097 Mdot
.632 .20187 Mdot
.632 .20287 Mdot
.632 .20297 Mdot
.632 .20337 Mdot
.632 .20342 Mdot
.632 .20387 Mdot
.632 .20405 Mdot
.632 .20417 Mdot
.632 .2049 Mdot
.632 .20532 Mdot
.632 .20539 Mdot
.632 .20716 Mdot
.632 .20762 Mdot
.632 .20812 Mdot
.632 .20842 Mdot
.632 .20879 Mdot
.632 .20938 Mdot
.632 .20978 Mdot
.632 .21031 Mdot
.632 .21072 Mdot
.632 .21084 Mdot
.632 .21239 Mdot
.632 .21279 Mdot
.632 .21281 Mdot
.632 .21545 Mdot
.632 .21591 Mdot
.632 .21593 Mdot
.632 .2164 Mdot
.632 .21713 Mdot
.632 .21715 Mdot
.632 .21906 Mdot
.632 .21981 Mdot
.632 .21991 Mdot
.632 .22009 Mdot
.632 .2204 Mdot
.632 .22077 Mdot
.632 .22083 Mdot
.632 .22084 Mdot
.632 .22124 Mdot
.632 .22218 Mdot
.632 .22275 Mdot
.632 .22293 Mdot
.632 .22421 Mdot
.632 .22436 Mdot
.632 .22436 Mdot
.632 .22476 Mdot
.632 .22486 Mdot
.632 .22528 Mdot
.632 .22612 Mdot
.632 .22692 Mdot
.632 .22715 Mdot
.632 .22787 Mdot
.632 .22939 Mdot
.632 .22946 Mdot
.632 .22966 Mdot
.632 .23114 Mdot
.632 .23127 Mdot
.632 .23141 Mdot
.632 .23162 Mdot
.632 .2321 Mdot
.632 .2325 Mdot
.632 .2332 Mdot
.632 .23336 Mdot
.632 .23349 Mdot
.632 .23386 Mdot
.632 .23396 Mdot
.632 .23408 Mdot
.632 .23432 Mdot
.632 .23458 Mdot
.632 .23609 Mdot
.632 .23638 Mdot
.632 .23677 Mdot
.632 .23743 Mdot
.632 .23773 Mdot
.632 .23813 Mdot
.632 .23821 Mdot
.632 .23821 Mdot
.632 .23881 Mdot
.632 .23962 Mdot
.632 .23977 Mdot
.632 .24014 Mdot
.632 .24144 Mdot
.632 .24148 Mdot
.632 .24243 Mdot
.632 .24304 Mdot
.632 .24325 Mdot
.632 .24396 Mdot
.632 .24434 Mdot
.632 .2444 Mdot
.632 .24463 Mdot
.632 .24473 Mdot
.632 .24592 Mdot
.632 .24605 Mdot
.632 .24642 Mdot
.632 .24728 Mdot
.632 .24787 Mdot
.632 .25002 Mdot
.632 .25014 Mdot
.632 .25128 Mdot
.632 .25255 Mdot
.632 .25268 Mdot
.632 .25317 Mdot
.632 .25323 Mdot
.632 .25381 Mdot
.632 .25404 Mdot
.632 .25418 Mdot
.632 .25511 Mdot
.632 .25565 Mdot
.632 .25572 Mdot
.632 .25796 Mdot
.632 .25854 Mdot
.632 .25918 Mdot
.632 .25956 Mdot
.632 .26003 Mdot
.632 .26077 Mdot
.632 .26127 Mdot
.632 .26195 Mdot
.632 .26246 Mdot
.632 .26262 Mdot
.632 .26457 Mdot
.632 .26509 Mdot
.632 .26511 Mdot
.632 .26844 Mdot
.632 .26902 Mdot
.632 .26905 Mdot
.632 .26964 Mdot
.632 .27057 Mdot
.632 .27059 Mdot
.632 .27301 Mdot
.632 .27408 Mdot
.632 .27431 Mdot
.632 .2747 Mdot
.632 .27517 Mdot
.632 .27525 Mdot
.632 .27526 Mdot
.632 .27577 Mdot
.632 .27695 Mdot
.632 .27767 Mdot
.632 .27789 Mdot
.632 .27952 Mdot
.632 .27971 Mdot
.632 .27971 Mdot
.632 .28021 Mdot
.632 .28034 Mdot
.632 .28087 Mdot
.632 .28193 Mdot
.632 .28294 Mdot
.632 .28324 Mdot
.632 .28414 Mdot
.632 .28606 Mdot
.632 .28616 Mdot
.632 .2864 Mdot
.632 .28828 Mdot
.632 .28844 Mdot
.632 .28861 Mdot
.632 .28889 Mdot
.632 .28949 Mdot
.632 .28999 Mdot
.632 .29089 Mdot
.632 .29108 Mdot
.632 .29124 Mdot
.632 .29172 Mdot
.632 .29184 Mdot
.632 .29199 Mdot
.632 .2923 Mdot
.632 .29262 Mdot
.632 .29453 Mdot
.632 .2949 Mdot
.632 .29539 Mdot
.632 .29623 Mdot
.632 .2966 Mdot
.632 .29711 Mdot
.632 .29721 Mdot
.632 .29721 Mdot
.632 .29797 Mdot
.632 .299 Mdot
.632 .29918 Mdot
.632 .29965 Mdot
.632 .3013 Mdot
.632 .30134 Mdot
.632 .30255 Mdot
.632 .30332 Mdot
.632 .30359 Mdot
.632 .30448 Mdot
.632 .30496 Mdot
.632 .30504 Mdot
.632 .30533 Mdot
.632 .30545 Mdot
.632 .30696 Mdot
.632 .30712 Mdot
.632 .30758 Mdot
.632 .30868 Mdot
.632 .30943 Mdot
.632 .31214 Mdot
.632 .31229 Mdot
.632 .31374 Mdot
.632 .31533 Mdot
.632 .3155 Mdot
.632 .31613 Mdot
.632 .3162 Mdot
.632 .31693 Mdot
.632 .31722 Mdot
.632 .3174 Mdot
.632 .31858 Mdot
.632 .31925 Mdot
.632 .31935 Mdot
.632 .32218 Mdot
.632 .32291 Mdot
.632 .32372 Mdot
.632 .3242 Mdot
.632 .32479 Mdot
.632 .32572 Mdot
.632 .32637 Mdot
.632 .32722 Mdot
.632 .32787 Mdot
.632 .32807 Mdot
.632 .33053 Mdot
.632 .33119 Mdot
.632 .33121 Mdot
.632 .33542 Mdot
.632 .33616 Mdot
.632 .33619 Mdot
.632 .33694 Mdot
.632 .33812 Mdot
.632 .33814 Mdot
.632 .3412 Mdot
.632 .34255 Mdot
.632 .34284 Mdot
.632 .34334 Mdot
.632 .34393 Mdot
.632 .34403 Mdot
.632 .34404 Mdot
.632 .34468 Mdot
.632 .34618 Mdot
.632 .34709 Mdot
.632 .34737 Mdot
.632 .34943 Mdot
.632 .34966 Mdot
.632 .34967 Mdot
.632 .3503 Mdot
.632 .35046 Mdot
.632 .35114 Mdot
.632 .35247 Mdot
.632 .35375 Mdot
.632 .35413 Mdot
.632 .35527 Mdot
.632 .3577 Mdot
.632 .35782 Mdot
.632 .35813 Mdot
.632 .3605 Mdot
.632 .36071 Mdot
.632 .36092 Mdot
.632 .36127 Mdot
.632 .36203 Mdot
.632 .36266 Mdot
.632 .3638 Mdot
.632 .36404 Mdot
.632 .36424 Mdot
.632 .36484 Mdot
.632 .36501 Mdot
.632 .3652 Mdot
.632 .36558 Mdot
.632 .36599 Mdot
.632 .3684 Mdot
.632 .36887 Mdot
.632 .36949 Mdot
.632 .37055 Mdot
.632 .37102 Mdot
.632 .37166 Mdot
.632 .37179 Mdot
.632 .37179 Mdot
.632 .37275 Mdot
.632 .37405 Mdot
.632 .37428 Mdot
.632 .37487 Mdot
.632 .37695 Mdot
.632 .37701 Mdot
.632 .37854 Mdot
.632 .37951 Mdot
.632 .37985 Mdot
.632 .38097 Mdot
.632 .38158 Mdot
.632 .38168 Mdot
.632 .38205 Mdot
.632 .38221 Mdot
.632 .38411 Mdot
.632 .38432 Mdot
.632 .3849 Mdot
.632 .38628 Mdot
.632 .38723 Mdot
.634 .01542 Mdot
.634 .01547 Mdot
.634 .01561 Mdot
.634 .01567 Mdot
.634 .01585 Mdot
.634 .01593 Mdot
.634 .01615 Mdot
.634 .01625 Mdot
.634 .0163 Mdot
.634 .01653 Mdot
.634 .01661 Mdot
.634 .01669 Mdot
.634 .01672 Mdot
.634 .01702 Mdot
.634 .01712 Mdot
.634 .01722 Mdot
.634 .01726 Mdot
.634 .01729 Mdot
.634 .01764 Mdot
.634 .01776 Mdot
.634 .01789 Mdot
.634 .01794 Mdot
.634 .01798 Mdot
.634 .01842 Mdot
.634 .01858 Mdot
.634 .01874 Mdot
.634 .0188 Mdot
.634 .01885 Mdot
.634 .01902 Mdot
.634 .01912 Mdot
.634 .01942 Mdot
.634 .01962 Mdot
.634 .01982 Mdot
.634 .0199 Mdot
.634 .01996 Mdot
.634 .02 Mdot
.634 .02018 Mdot
.634 .02031 Mdot
.634 .02066 Mdot
.634 .02068 Mdot
.634 .02071 Mdot
.634 .02093 Mdot
.634 .02094 Mdot
.634 .02119 Mdot
.634 .02129 Mdot
.634 .02137 Mdot
.634 .02141 Mdot
.634 .02164 Mdot
.634 .0218 Mdot
.634 .02225 Mdot
.634 .02228 Mdot
.634 .02231 Mdot
.634 .0226 Mdot
.634 .02261 Mdot
.634 .02293 Mdot
.634 .02305 Mdot
.634 .02315 Mdot
.634 .02321 Mdot
.634 .0235 Mdot
.634 .0237 Mdot
.634 .02427 Mdot
.634 .0243 Mdot
.634 .02435 Mdot
.634 .02471 Mdot
.634 .02473 Mdot
.634 .02501 Mdot
.634 .02513 Mdot
.634 .02528 Mdot
.634 .02541 Mdot
.634 .02548 Mdot
.634 .02585 Mdot
.634 .02611 Mdot
.634 .02648 Mdot
.634 .02683 Mdot
.634 .02687 Mdot
.634 .02693 Mdot
.634 .02735 Mdot
.634 .02739 Mdot
.634 .02741 Mdot
.634 .02755 Mdot
.634 .02777 Mdot
.634 .02792 Mdot
.634 .02812 Mdot
.634 .02828 Mdot
.634 .02837 Mdot
.634 .0284 Mdot
.634 .02884 Mdot
.634 .029 Mdot
.634 .02917 Mdot
.634 .02963 Mdot
.634 .02969 Mdot
.634 .03007 Mdot
.634 .03013 Mdot
.634 .0302 Mdot
.634 .03074 Mdot
.634 .03079 Mdot
.634 .03082 Mdot
.634 .03098 Mdot
.634 .03127 Mdot
.634 .03145 Mdot
.634 .03168 Mdot
.634 .03171 Mdot
.634 .03192 Mdot
.634 .03203 Mdot
.634 .03207 Mdot
.634 .03212 Mdot
.634 .03263 Mdot
.634 .03283 Mdot
.634 .03304 Mdot
.634 .03362 Mdot
.634 .0337 Mdot
.634 .03419 Mdot
.634 .03426 Mdot
.634 .03436 Mdot
.634 .03467 Mdot
.634 .03504 Mdot
.634 .03509 Mdot
.634 .03513 Mdot
.634 .03534 Mdot
.634 .0357 Mdot
.634 .03594 Mdot
.634 .03622 Mdot
.634 .03626 Mdot
.634 .03653 Mdot
.634 .03657 Mdot
.634 .03667 Mdot
.634 .03672 Mdot
.634 .03678 Mdot
.634 .03742 Mdot
.634 .03768 Mdot
.634 .03795 Mdot
.634 .03858 Mdot
.634 .03869 Mdot
.634 .03879 Mdot
.634 .03898 Mdot
.634 .03941 Mdot
.634 .0395 Mdot
.634 .03962 Mdot
.634 .03965 Mdot
.634 .04002 Mdot
.634 .04048 Mdot
.634 .04055 Mdot
.634 .0406 Mdot
.634 .04087 Mdot
.634 .04117 Mdot
.634 .04133 Mdot
.634 .04163 Mdot
.634 .04182 Mdot
.634 .04199 Mdot
.634 .04203 Mdot
.634 .04237 Mdot
.634 .04242 Mdot
.634 .04255 Mdot
.634 .04262 Mdot
.634 .04269 Mdot
.634 .0431 Mdot
.634 .04351 Mdot
.634 .04384 Mdot
.634 .04418 Mdot
.634 .04498 Mdot
.634 .04512 Mdot
.634 .04524 Mdot
.634 .04548 Mdot
.634 .0455 Mdot
.634 .04602 Mdot
.634 .04614 Mdot
.634 .04629 Mdot
.634 .04633 Mdot
.634 .0468 Mdot
.634 .04728 Mdot
.634 .04739 Mdot
.634 .04745 Mdot
.634 .04748 Mdot
.634 .04754 Mdot
.634 .04788 Mdot
.634 .04826 Mdot
.634 .04846 Mdot
.634 .04884 Mdot
.634 .04908 Mdot
.634 .0493 Mdot
.634 .04936 Mdot
.634 .04979 Mdot
.634 .04985 Mdot
.634 .05001 Mdot
.634 .0501 Mdot
.634 .05016 Mdot
.634 .05019 Mdot
.634 .0507 Mdot
.634 .05123 Mdot
.634 .05164 Mdot
.634 .05207 Mdot
.634 .05213 Mdot
.634 .05309 Mdot
.634 .05326 Mdot
.634 .05343 Mdot
.634 .05355 Mdot
.634 .05373 Mdot
.634 .05375 Mdot
.634 .05399 Mdot
.634 .05423 Mdot
.634 .05442 Mdot
.634 .05456 Mdot
.634 .05476 Mdot
.634 .0548 Mdot
.634 .05484 Mdot
.634 .05528 Mdot
.634 .0554 Mdot
.634 .05572 Mdot
.634 .05601 Mdot
.634 .05614 Mdot
.634 .05622 Mdot
.634 .05626 Mdot
.634 .05634 Mdot
.634 .05647 Mdot
.634 .05677 Mdot
.634 .0571 Mdot
.634 .05725 Mdot
.634 .05741 Mdot
.634 .0575 Mdot
.634 .05783 Mdot
.634 .05799 Mdot
.634 .05829 Mdot
.634 .05856 Mdot
.634 .05864 Mdot
.634 .05894 Mdot
.634 .05896 Mdot
.634 .05918 Mdot
.634 .05919 Mdot
.634 .05926 Mdot
.634 .05947 Mdot
.634 .05958 Mdot
.634 .05966 Mdot
.634 .0597 Mdot
.634 .06035 Mdot
.634 .06073 Mdot
.634 .06101 Mdot
.634 .06154 Mdot
.634 .06182 Mdot
.634 .06208 Mdot
.634 .06216 Mdot
.634 .06338 Mdot
.634 .0636 Mdot
.634 .0638 Mdot
.634 .06396 Mdot
.634 .06405 Mdot
.634 .06418 Mdot
.634 .06421 Mdot
.634 .06439 Mdot
.634 .06452 Mdot
.634 .06482 Mdot
.634 .06506 Mdot
.634 .06524 Mdot
.634 .06549 Mdot
.634 .06555 Mdot
.634 .06559 Mdot
.634 .06616 Mdot
.634 .0663 Mdot
.634 .06636 Mdot
.634 .06671 Mdot
.634 .06707 Mdot
.634 .06725 Mdot
.634 .06734 Mdot
.634 .06739 Mdot
.634 .06749 Mdot
.634 .06766 Mdot
.634 .06789 Mdot
.634 .06805 Mdot
.634 .06815 Mdot
.634 .06846 Mdot
.634 .06865 Mdot
.634 .06885 Mdot
.634 .06897 Mdot
.634 .06938 Mdot
.634 .06958 Mdot
.634 .06997 Mdot
.634 .07001 Mdot
.634 .07031 Mdot
.634 .07041 Mdot
.634 .07054 Mdot
.634 .07079 Mdot
.634 .07082 Mdot
.634 .07092 Mdot
.634 .0711 Mdot
.634 .07111 Mdot
.634 .0712 Mdot
.634 .07146 Mdot
.634 .07161 Mdot
.634 .07171 Mdot
.634 .07175 Mdot
.634 .07258 Mdot
.634 .07271 Mdot
.634 .07306 Mdot
.634 .07342 Mdot
.634 .07409 Mdot
.634 .07445 Mdot
.634 .07478 Mdot
.634 .07487 Mdot
.634 .07569 Mdot
.634 .07642 Mdot
.634 .0767 Mdot
.634 .07689 Mdot
.634 .07695 Mdot
.634 .07716 Mdot
.634 .07727 Mdot
.634 .07744 Mdot
.634 .07744 Mdot
.634 .07747 Mdot
.634 .0777 Mdot
.634 .07787 Mdot
.634 .07825 Mdot
.634 .07855 Mdot
.634 .07878 Mdot
.634 .07881 Mdot
.634 .07909 Mdot
.634 .07917 Mdot
.634 .07923 Mdot
.634 .07994 Mdot
.634 .08012 Mdot
.634 .0802 Mdot
.634 .08041 Mdot
.634 .08065 Mdot
.634 .0811 Mdot
.634 .08132 Mdot
.634 .08145 Mdot
.634 .08145 Mdot
.634 .08151 Mdot
.634 .08163 Mdot
.634 .08185 Mdot
.634 .08214 Mdot
.634 .08234 Mdot
.634 .08247 Mdot
.634 .08286 Mdot
.634 .08311 Mdot
.634 .08336 Mdot
.634 .08345 Mdot
.634 .08351 Mdot
.634 .08403 Mdot
.634 .08429 Mdot
.634 .08469 Mdot
.634 .08478 Mdot
.634 .08483 Mdot
.634 .08493 Mdot
.634 .08521 Mdot
.634 .08534 Mdot
.634 .08549 Mdot
.634 .08574 Mdot
.634 .08576 Mdot
.634 .08582 Mdot
.634 .08585 Mdot
.634 .08599 Mdot
.634 .08615 Mdot
.634 .08621 Mdot
.634 .08623 Mdot
.634 .08634 Mdot
.634 .08667 Mdot
.634 .08669 Mdot
.634 .08686 Mdot
.634 .08698 Mdot
.634 .08699 Mdot
.634 .08704 Mdot
.634 .08809 Mdot
.634 .08825 Mdot
.634 .08845 Mdot
.634 .0887 Mdot
.634 .08916 Mdot
.634 .09 Mdot
.634 .09038 Mdot
.634 .09046 Mdot
.634 .09087 Mdot
.634 .091 Mdot
.634 .0917 Mdot
.634 .09203 Mdot
.634 .09258 Mdot
.634 .09295 Mdot
.634 .09331 Mdot
.634 .09355 Mdot
.634 .09364 Mdot
.634 .0939 Mdot
.634 .09403 Mdot
.634 .09425 Mdot
.634 .09425 Mdot
.634 .09429 Mdot
.634 .09458 Mdot
.634 .09479 Mdot
.634 .09521 Mdot
.634 .09528 Mdot
.634 .09565 Mdot
.634 .09594 Mdot
.634 .09599 Mdot
.634 .09635 Mdot
.634 .09645 Mdot
.634 .09652 Mdot
.634 .09686 Mdot
.634 .09742 Mdot
.634 .09765 Mdot
.634 .09775 Mdot
.634 .09802 Mdot
.634 .09832 Mdot
.634 .09852 Mdot
.634 .0989 Mdot
.634 .09913 Mdot
.634 .09918 Mdot
.634 .09933 Mdot
.634 .09933 Mdot
.634 .09941 Mdot
.634 .09951 Mdot
.634 .09957 Mdot
.634 .09985 Mdot
.634 .10021 Mdot
.634 .10046 Mdot
.634 .10063 Mdot
.634 .10113 Mdot
.634 .10144 Mdot
.634 .10175 Mdot
.634 .10187 Mdot
.634 .10194 Mdot
.634 .10261 Mdot
.634 .10294 Mdot
.634 .103 Mdot
.634 .10344 Mdot
.634 .10356 Mdot
.634 .10362 Mdot
.634 .10374 Mdot
.634 .10411 Mdot
.634 .10427 Mdot
.634 .10446 Mdot
.634 .10474 Mdot
.634 .10477 Mdot
.634 .1048 Mdot
.634 .10488 Mdot
.634 .10492 Mdot
.634 .10509 Mdot
.634 .1051 Mdot
.634 .1053 Mdot
.634 .10538 Mdot
.634 .10539 Mdot
.634 .10554 Mdot
.634 .10596 Mdot
.634 .10598 Mdot
.634 .10619 Mdot
.634 .10635 Mdot
.634 .10636 Mdot
.634 .10642 Mdot
.634 .1074 Mdot
.634 .10775 Mdot
.634 .10796 Mdot
.634 .10801 Mdot
.634 .10821 Mdot
.634 .10836 Mdot
.634 .10852 Mdot
.634 .109 Mdot
.634 .10911 Mdot
.634 .11018 Mdot
.634 .11066 Mdot
.634 .11076 Mdot
.634 .11092 Mdot
.634 .11128 Mdot
.634 .11144 Mdot
.634 .11175 Mdot
.634 .11233 Mdot
.634 .11275 Mdot
.634 .11279 Mdot
.634 .11345 Mdot
.634 .11392 Mdot
.634 .11426 Mdot
.634 .11437 Mdot
.634 .11443 Mdot
.634 .11457 Mdot
.634 .11468 Mdot
.634 .11479 Mdot
.634 .11497 Mdot
.634 .11512 Mdot
.634 .11519 Mdot
.634 .11529 Mdot
.634 .11556 Mdot
.634 .11556 Mdot
.634 .11562 Mdot
.634 .11599 Mdot
.634 .11625 Mdot
.634 .11679 Mdot
.634 .11687 Mdot
.634 .11735 Mdot
.634 .11771 Mdot
.634 .11778 Mdot
.634 .11822 Mdot
.634 .11835 Mdot
.634 .11844 Mdot
.634 .11887 Mdot
.634 .11959 Mdot
.634 .11988 Mdot
.634 .12001 Mdot
.634 .12034 Mdot
.634 .12073 Mdot
.634 .12098 Mdot
.634 .12146 Mdot
.634 .12175 Mdot
.634 .12181 Mdot
.634 .12201 Mdot
.634 .12201 Mdot
.634 .12211 Mdot
.634 .12224 Mdot
.634 .12231 Mdot
.634 .12266 Mdot
.634 .12312 Mdot
.634 .12344 Mdot
.634 .12365 Mdot
.634 .12429 Mdot
.634 .12468 Mdot
.634 .12508 Mdot
.634 .12523 Mdot
.634 .12532 Mdot
.634 .12616 Mdot
.634 .12658 Mdot
.634 .12667 Mdot
.634 .12722 Mdot
.634 .12736 Mdot
.634 .12745 Mdot
.634 .1276 Mdot
.634 .12807 Mdot
.634 .12826 Mdot
.634 .12852 Mdot
.634 .12887 Mdot
.634 .12891 Mdot
.634 .12894 Mdot
.634 .12904 Mdot
.634 .12909 Mdot
.634 .12931 Mdot
.634 .12932 Mdot
.634 .12958 Mdot
.634 .12967 Mdot
.634 .1297 Mdot
.634 .12988 Mdot
.634 .13041 Mdot
.634 .13044 Mdot
.634 .13071 Mdot
.634 .13091 Mdot
.634 .13092 Mdot
.634 .13099 Mdot
.634 .13223 Mdot
.634 .13268 Mdot
.634 .13295 Mdot
.634 .13301 Mdot
.634 .13327 Mdot
.634 .13345 Mdot
.634 .13366 Mdot
.634 .13427 Mdot
.634 .1344 Mdot
.634 .13576 Mdot
.634 .13638 Mdot
.634 .1365 Mdot
.634 .1367 Mdot
.634 .13717 Mdot
.634 .13736 Mdot
.634 .13775 Mdot
.634 .13849 Mdot
.634 .13903 Mdot
.634 .13908 Mdot
.634 .13991 Mdot
.634 .14051 Mdot
.634 .14094 Mdot
.634 .14108 Mdot
.634 .14115 Mdot
.634 .14134 Mdot
.634 .14147 Mdot
.634 .1416 Mdot
.634 .14183 Mdot
.634 .14202 Mdot
.634 .14212 Mdot
.634 .14225 Mdot
.634 .14259 Mdot
.634 .14259 Mdot
.634 .14266 Mdot
.634 .14313 Mdot
.634 .14347 Mdot
.634 .14414 Mdot
.634 .14425 Mdot
.634 .14485 Mdot
.634 .14532 Mdot
.634 .1454 Mdot
.634 .14596 Mdot
.634 .14612 Mdot
.634 .14624 Mdot
.634 .14679 Mdot
.634 .1477 Mdot
.634 .14806 Mdot
.634 .14823 Mdot
.634 .14865 Mdot
.634 .14914 Mdot
.634 .14945 Mdot
.634 .15006 Mdot
.634 .15044 Mdot
.634 .15051 Mdot
.634 .15076 Mdot
.634 .15077 Mdot
.634 .15089 Mdot
.634 .15105 Mdot
.634 .15114 Mdot
.634 .15159 Mdot
.634 .15218 Mdot
.634 .15258 Mdot
.634 .15285 Mdot
.634 .15365 Mdot
.634 .15415 Mdot
.634 .15466 Mdot
.634 .15485 Mdot
.634 .15496 Mdot
.634 .15603 Mdot
.634 .15656 Mdot
.634 .15667 Mdot
.634 .15737 Mdot
.634 .15755 Mdot
.634 .15766 Mdot
.634 .15786 Mdot
.634 .15844 Mdot
.634 .1587 Mdot
.634 .15902 Mdot
.634 .15946 Mdot
.634 .15951 Mdot
.634 .15956 Mdot
.634 .15968 Mdot
.634 .15975 Mdot
.634 .16002 Mdot
.634 .16004 Mdot
.634 .16036 Mdot
.634 .16048 Mdot
.634 .16051 Mdot
.634 .16074 Mdot
.634 .16141 Mdot
.634 .16145 Mdot
.634 .16179 Mdot
.634 .16205 Mdot
.634 .16207 Mdot
.634 .16216 Mdot
.634 .16373 Mdot
.634 .1643 Mdot
.634 .16464 Mdot
.634 .16471 Mdot
.634 .16504 Mdot
.634 .16527 Mdot
.634 .16554 Mdot
.634 .16631 Mdot
.634 .16648 Mdot
.634 .1682 Mdot
.634 .16898 Mdot
.634 .16913 Mdot
.634 .16939 Mdot
.634 .16998 Mdot
.634 .17023 Mdot
.634 .17073 Mdot
.634 .17166 Mdot
.634 .17234 Mdot
.634 .17241 Mdot
.634 .17346 Mdot
.634 .17422 Mdot
.634 .17477 Mdot
.634 .17494 Mdot
.634 .17503 Mdot
.634 .17527 Mdot
.634 .17544 Mdot
.634 .17561 Mdot
.634 .1759 Mdot
.634 .17614 Mdot
.634 .17626 Mdot
.634 .17642 Mdot
.634 .17686 Mdot
.634 .17686 Mdot
.634 .17695 Mdot
.634 .17755 Mdot
.634 .17797 Mdot
.634 .17883 Mdot
.634 .17896 Mdot
.634 .17973 Mdot
.634 .18032 Mdot
.634 .18042 Mdot
.634 .18114 Mdot
.634 .18134 Mdot
.634 .18149 Mdot
.634 .18218 Mdot
.634 .18334 Mdot
.634 .1838 Mdot
.634 .18401 Mdot
.634 .18454 Mdot
.634 .18516 Mdot
.634 .18556 Mdot
.634 .18634 Mdot
.634 .18682 Mdot
.634 .18691 Mdot
.634 .18722 Mdot
.634 .18723 Mdot
.634 .18738 Mdot
.634 .18759 Mdot
.634 .18771 Mdot
.634 .18827 Mdot
.634 .18902 Mdot
.634 .18953 Mdot
.634 .18987 Mdot
.634 .19089 Mdot
.634 .19152 Mdot
.634 .19216 Mdot
.634 .1924 Mdot
.634 .19255 Mdot
.634 .1939 Mdot
.634 .19457 Mdot
.634 .19471 Mdot
.634 .1956 Mdot
.634 .19584 Mdot
.634 .19597 Mdot
.634 .19622 Mdot
.634 .19696 Mdot
.634 .19728 Mdot
.634 .19769 Mdot
.634 .19826 Mdot
.634 .19832 Mdot
.634 .19838 Mdot
.634 .19853 Mdot
.634 .19862 Mdot
.634 .19896 Mdot
.634 .19899 Mdot
.634 .19939 Mdot
.634 .19955 Mdot
.634 .19959 Mdot
.634 .19988 Mdot
.634 .20073 Mdot
.634 .20078 Mdot
.634 .20121 Mdot
.634 .20153 Mdot
.634 .20156 Mdot
.634 .20167 Mdot
.634 .20367 Mdot
.634 .20439 Mdot
.634 .20482 Mdot
.634 .20491 Mdot
.634 .20533 Mdot
.634 .20562 Mdot
.634 .20596 Mdot
.634 .20694 Mdot
.634 .20715 Mdot
.634 .20933 Mdot
.634 .21032 Mdot
.634 .21052 Mdot
.634 .21085 Mdot
.634 .21159 Mdot
.634 .21191 Mdot
.634 .21254 Mdot
.634 .21372 Mdot
.634 .21459 Mdot
.634 .21467 Mdot
.634 .216 Mdot
.634 .21697 Mdot
.634 .21767 Mdot
.634 .21788 Mdot
.634 .218 Mdot
.634 .2183 Mdot
.634 .21852 Mdot
.634 .21873 Mdot
.634 .2191 Mdot
.634 .21941 Mdot
.634 .21956 Mdot
.634 .21976 Mdot
.634 .22031 Mdot
.634 .22032 Mdot
.634 .22043 Mdot
.634 .22119 Mdot
.634 .22172 Mdot
.634 .22281 Mdot
.634 .22298 Mdot
.634 .22395 Mdot
.634 .2247 Mdot
.634 .22483 Mdot
.634 .22574 Mdot
.634 .226 Mdot
.634 .22619 Mdot
.634 .22706 Mdot
.634 .22853 Mdot
.634 .22911 Mdot
.634 .22938 Mdot
.634 .23006 Mdot
.634 .23084 Mdot
.634 .23135 Mdot
.634 .23233 Mdot
.634 .23294 Mdot
.634 .23306 Mdot
.634 .23345 Mdot
.634 .23346 Mdot
.634 .23366 Mdot
.634 .23392 Mdot
.634 .23407 Mdot
.634 .23478 Mdot
.634 .23573 Mdot
.634 .23638 Mdot
.634 .23681 Mdot
.634 .2381 Mdot
.634 .23891 Mdot
.634 .23972 Mdot
.634 .24002 Mdot
.634 .24021 Mdot
.634 .24192 Mdot
.634 .24278 Mdot
.634 .24295 Mdot
.634 .24408 Mdot
.634 .24438 Mdot
.634 .24455 Mdot
.634 .24486 Mdot
.634 .2458 Mdot
.634 .24621 Mdot
.634 .24672 Mdot
.634 .24745 Mdot
.634 .24753 Mdot
.634 .2476 Mdot
.634 .24779 Mdot
.634 .2479 Mdot
.634 .24834 Mdot
.634 .24837 Mdot
.634 .24889 Mdot
.634 .24908 Mdot
.634 .24913 Mdot
.634 .2495 Mdot
.634 .25058 Mdot
.634 .25064 Mdot
.634 .25119 Mdot
.634 .2516 Mdot
.634 .25163 Mdot
.634 .25178 Mdot
.634 .2543 Mdot
.634 .25522 Mdot
.634 .25576 Mdot
.634 .25588 Mdot
.634 .25642 Mdot
.634 .25679 Mdot
.634 .25722 Mdot
.634 .25845 Mdot
.634 .25872 Mdot
.634 .26149 Mdot
.634 .26275 Mdot
.634 .26299 Mdot
.634 .26341 Mdot
.634 .26436 Mdot
.634 .26476 Mdot
.634 .26555 Mdot
.634 .26705 Mdot
.634 .26816 Mdot
.634 .26826 Mdot
.634 .26995 Mdot
.634 .27117 Mdot
.634 .27206 Mdot
.634 .27233 Mdot
.634 .27248 Mdot
.634 .27286 Mdot
.634 .27313 Mdot
.634 .27341 Mdot
.634 .27387 Mdot
.634 .27426 Mdot
.634 .27446 Mdot
.634 .27472 Mdot
.634 .27541 Mdot
.634 .27542 Mdot
.634 .27557 Mdot
.634 .27652 Mdot
.634 .2772 Mdot
.634 .27859 Mdot
.634 .2788 Mdot
.634 .28002 Mdot
.634 .28097 Mdot
.634 .28114 Mdot
.634 .28229 Mdot
.634 .28262 Mdot
.634 .28286 Mdot
.634 .28397 Mdot
.634 .28583 Mdot
.634 .28657 Mdot
.634 .28691 Mdot
.634 .28777 Mdot
.634 .28876 Mdot
.634 .28941 Mdot
.634 .29065 Mdot
.634 .29142 Mdot
.634 .29157 Mdot
.634 .29208 Mdot
.634 .29209 Mdot
.634 .29233 Mdot
.634 .29267 Mdot
.634 .29285 Mdot
.634 .29376 Mdot
.634 .29496 Mdot
.634 .29578 Mdot
.634 .29633 Mdot
.634 .29797 Mdot
.634 .29899 Mdot
.634 .30002 Mdot
.634 .30041 Mdot
.634 .30064 Mdot
.634 .30281 Mdot
.634 .3039 Mdot
.634 .30412 Mdot
.634 .30555 Mdot
.634 .30593 Mdot
.634 .30614 Mdot
.634 .30654 Mdot
.634 .30774 Mdot
.634 .30825 Mdot
.634 .3089 Mdot
.634 .30982 Mdot
.634 .30992 Mdot
.634 .31001 Mdot
.634 .31025 Mdot
.634 .31039 Mdot
.634 .31095 Mdot
.634 .31099 Mdot
.634 .31164 Mdot
.634 .31189 Mdot
.634 .31195 Mdot
.634 .31243 Mdot
.634 .31379 Mdot
.634 .31387 Mdot
.634 .31456 Mdot
.634 .31508 Mdot
.634 .31512 Mdot
.634 .31531 Mdot
.634 .31851 Mdot
.634 .31967 Mdot
.634 .32036 Mdot
.634 .32052 Mdot
.634 .32119 Mdot
.634 .32166 Mdot
.634 .32221 Mdot
.634 .32377 Mdot
.634 .32412 Mdot
.634 .32763 Mdot
.634 .32922 Mdot
.634 .32953 Mdot
.634 .33006 Mdot
.634 .33126 Mdot
.634 .33177 Mdot
.634 .33278 Mdot
.634 .33467 Mdot
.634 .33608 Mdot
.634 .33621 Mdot
.634 .33835 Mdot
.634 .3399 Mdot
.634 .34103 Mdot
.634 .34137 Mdot
.634 .34156 Mdot
.634 .34204 Mdot
.634 .34239 Mdot
.634 .34274 Mdot
.634 .34333 Mdot
.634 .34382 Mdot
.634 .34407 Mdot
.634 .3444 Mdot
.634 .34527 Mdot
.634 .34529 Mdot
.634 .34547 Mdot
.634 .34668 Mdot
.634 .34755 Mdot
.634 .3493 Mdot
.634 .34957 Mdot
.634 .35113 Mdot
.634 .35233 Mdot
.634 .35254 Mdot
.634 .35401 Mdot
.634 .35442 Mdot
.634 .35472 Mdot
.634 .35613 Mdot
.634 .35848 Mdot
.634 .35943 Mdot
.634 .35986 Mdot
.634 .36095 Mdot
.634 .36221 Mdot
.634 .36303 Mdot
.634 .3646 Mdot
.634 .36558 Mdot
.634 .36577 Mdot
.634 .36641 Mdot
.634 .36643 Mdot
.634 .36674 Mdot
.634 .36716 Mdot
.634 .3674 Mdot
.634 .36855 Mdot
.634 .37007 Mdot
.634 .37111 Mdot
.634 .3718 Mdot
.634 .37388 Mdot
.634 .37518 Mdot
.634 .37649 Mdot
.634 .37697 Mdot
.634 .37727 Mdot
.634 .38002 Mdot
.634 .3814 Mdot
.634 .38168 Mdot
.634 .38349 Mdot
.634 .38397 Mdot
.634 .38425 Mdot
.634 .38475 Mdot
.634 .38627 Mdot
.634 .38692 Mdot
.634 .38775 Mdot
.634 .3889 Mdot
.634 .38903 Mdot
.634 .38915 Mdot
.634 .38946 Mdot
.634 .38964 Mdot
.636 .0149 Mdot
.636 .01495 Mdot
.636 .01502 Mdot
.636 .0151 Mdot
.636 .01521 Mdot
.636 .01534 Mdot
.636 .01551 Mdot
.636 .0157 Mdot
.636 .01573 Mdot
.636 .01597 Mdot
.636 .016 Mdot
.636 .01631 Mdot
.636 .01635 Mdot
.636 .01674 Mdot
.636 .01676 Mdot
.636 .0168 Mdot
.636 .01729 Mdot
.636 .01731 Mdot
.636 .01737 Mdot
.636 .01799 Mdot
.636 .01802 Mdot
.636 .01809 Mdot
.636 .01888 Mdot
.636 .01892 Mdot
.636 .01892 Mdot
.636 .019 Mdot
.636 .02001 Mdot
.636 .02006 Mdot
.636 .02007 Mdot
.636 .02017 Mdot
.636 .0208 Mdot
.636 .02145 Mdot
.636 .02151 Mdot
.636 .02152 Mdot
.636 .02165 Mdot
.636 .02246 Mdot
.636 .02328 Mdot
.636 .02336 Mdot
.636 .02337 Mdot
.636 .02354 Mdot
.636 .02456 Mdot
.636 .02561 Mdot
.636 .02571 Mdot
.636 .02573 Mdot
.636 .02591 Mdot
.636 .02594 Mdot
.636 .02674 Mdot
.636 .02695 Mdot
.636 .02724 Mdot
.636 .02858 Mdot
.636 .0287 Mdot
.636 .02872 Mdot
.636 .02895 Mdot
.636 .02899 Mdot
.636 .02981 Mdot
.636 .03001 Mdot
.636 .03028 Mdot
.636 .03065 Mdot
.636 .03071 Mdot
.636 .03096 Mdot
.636 .03212 Mdot
.636 .03235 Mdot
.636 .03251 Mdot
.636 .03253 Mdot
.636 .03282 Mdot
.636 .03288 Mdot
.636 .03391 Mdot
.636 .03392 Mdot
.636 .03399 Mdot
.636 .03417 Mdot
.636 .03451 Mdot
.636 .03464 Mdot
.636 .03499 Mdot
.636 .03506 Mdot
.636 .03525 Mdot
.636 .03534 Mdot
.636 .03538 Mdot
.636 .03555 Mdot
.636 .03573 Mdot
.636 .03685 Mdot
.636 .03715 Mdot
.636 .03735 Mdot
.636 .03738 Mdot
.636 .03775 Mdot
.636 .03782 Mdot
.636 .03914 Mdot
.636 .03914 Mdot
.636 .03915 Mdot
.636 .03923 Mdot
.636 .03946 Mdot
.636 .03963 Mdot
.636 .0399 Mdot
.636 .04006 Mdot
.636 .0405 Mdot
.636 .0406 Mdot
.636 .04062 Mdot
.636 .04084 Mdot
.636 .0409 Mdot
.636 .04096 Mdot
.636 .041 Mdot
.636 .04107 Mdot
.636 .04121 Mdot
.636 .04145 Mdot
.636 .04274 Mdot
.636 .04287 Mdot
.636 .04325 Mdot
.636 .0435 Mdot
.636 .04353 Mdot
.636 .04354 Mdot
.636 .04401 Mdot
.636 .0441 Mdot
.636 .04432 Mdot
.636 .045 Mdot
.636 .04521 Mdot
.636 .04578 Mdot
.636 .04578 Mdot
.636 .04579 Mdot
.636 .0459 Mdot
.636 .04619 Mdot
.636 .04641 Mdot
.636 .04654 Mdot
.636 .04675 Mdot
.636 .04695 Mdot
.636 .04751 Mdot
.636 .04764 Mdot
.636 .04766 Mdot
.636 .04795 Mdot
.636 .04802 Mdot
.636 .04809 Mdot
.636 .04811 Mdot
.636 .04815 Mdot
.636 .04824 Mdot
.636 .04842 Mdot
.636 .04872 Mdot
.636 .04882 Mdot
.636 .05 Mdot
.636 .05037 Mdot
.636 .05037 Mdot
.636 .05053 Mdot
.636 .05097 Mdot
.636 .05101 Mdot
.636 .05133 Mdot
.636 .05137 Mdot
.636 .05138 Mdot
.636 .05182 Mdot
.636 .05185 Mdot
.636 .05198 Mdot
.636 .0521 Mdot
.636 .05225 Mdot
.636 .05237 Mdot
.636 .0529 Mdot
.636 .05312 Mdot
.636 .05324 Mdot
.636 .05335 Mdot
.636 .0535 Mdot
.636 .05423 Mdot
.636 .05423 Mdot
.636 .05425 Mdot
.636 .05438 Mdot
.636 .05475 Mdot
.636 .05482 Mdot
.636 .05503 Mdot
.636 .0552 Mdot
.636 .05546 Mdot
.636 .05572 Mdot
.636 .05615 Mdot
.636 .05643 Mdot
.636 .0566 Mdot
.636 .05662 Mdot
.636 .05699 Mdot
.636 .05709 Mdot
.636 .05717 Mdot
.636 .0572 Mdot
.636 .05724 Mdot
.636 .05735 Mdot
.636 .05759 Mdot
.636 .05797 Mdot
.636 .05809 Mdot
.636 .05914 Mdot
.636 .05959 Mdot
.636 .06006 Mdot
.636 .06007 Mdot
.636 .06015 Mdot
.636 .06027 Mdot
.636 .06083 Mdot
.636 .06088 Mdot
.636 .06129 Mdot
.636 .06133 Mdot
.636 .06136 Mdot
.636 .06177 Mdot
.636 .06191 Mdot
.636 .06195 Mdot
.636 .06202 Mdot
.636 .06212 Mdot
.636 .06227 Mdot
.636 .06246 Mdot
.636 .06261 Mdot
.636 .06329 Mdot
.636 .06357 Mdot
.636 .0636 Mdot
.636 .06372 Mdot
.636 .06376 Mdot
.636 .06386 Mdot
.636 .06405 Mdot
.636 .0645 Mdot
.636 .06478 Mdot
.636 .06497 Mdot
.636 .06498 Mdot
.636 .065 Mdot
.636 .06506 Mdot
.636 .06517 Mdot
.636 .06564 Mdot
.636 .06572 Mdot
.636 .06579 Mdot
.636 .066 Mdot
.636 .06612 Mdot
.636 .06621 Mdot
.636 .06655 Mdot
.636 .06667 Mdot
.636 .06687 Mdot
.636 .06704 Mdot
.636 .0674 Mdot
.636 .06742 Mdot
.636 .06778 Mdot
.636 .06799 Mdot
.636 .06802 Mdot
.636 .06849 Mdot
.636 .06861 Mdot
.636 .06871 Mdot
.636 .06872 Mdot
.636 .06875 Mdot
.636 .0688 Mdot
.636 .06883 Mdot
.636 .06895 Mdot
.636 .06925 Mdot
.636 .06962 Mdot
.636 .06974 Mdot
.636 .06989 Mdot
.636 .07123 Mdot
.636 .0718 Mdot
.636 .0724 Mdot
.636 .07241 Mdot
.636 .0725 Mdot
.636 .07261 Mdot
.636 .07266 Mdot
.636 .07337 Mdot
.636 .07344 Mdot
.636 .07396 Mdot
.636 .07401 Mdot
.636 .07404 Mdot
.636 .07457 Mdot
.636 .07474 Mdot
.636 .0748 Mdot
.636 .07489 Mdot
.636 .07501 Mdot
.636 .07501 Mdot
.636 .07517 Mdot
.636 .0752 Mdot
.636 .07545 Mdot
.636 .07564 Mdot
.636 .0765 Mdot
.636 .07673 Mdot
.636 .07675 Mdot
.636 .07686 Mdot
.636 .0769 Mdot
.636 .07694 Mdot
.636 .07705 Mdot
.636 .0771 Mdot
.636 .07723 Mdot
.636 .07747 Mdot
.636 .07749 Mdot
.636 .07804 Mdot
.636 .07839 Mdot
.636 .07842 Mdot
.636 .07864 Mdot
.636 .07865 Mdot
.636 .07867 Mdot
.636 .07876 Mdot
.636 .07889 Mdot
.636 .07949 Mdot
.636 .0796 Mdot
.636 .07969 Mdot
.636 .07995 Mdot
.636 .08011 Mdot
.636 .08021 Mdot
.636 .08064 Mdot
.636 .0808 Mdot
.636 .08106 Mdot
.636 .08127 Mdot
.636 .08173 Mdot
.636 .08176 Mdot
.636 .08221 Mdot
.636 .08248 Mdot
.636 .08252 Mdot
.636 .08252 Mdot
.636 .08311 Mdot
.636 .08326 Mdot
.636 .08327 Mdot
.636 .08339 Mdot
.636 .08341 Mdot
.636 .08345 Mdot
.636 .08352 Mdot
.636 .08354 Mdot
.636 .0837 Mdot
.636 .08388 Mdot
.636 .08408 Mdot
.636 .08456 Mdot
.636 .0847 Mdot
.636 .0849 Mdot
.636 .08565 Mdot
.636 .0866 Mdot
.636 .08675 Mdot
.636 .08679 Mdot
.636 .08732 Mdot
.636 .08749 Mdot
.636 .08775 Mdot
.636 .08809 Mdot
.636 .0881 Mdot
.636 .08822 Mdot
.636 .08835 Mdot
.636 .08842 Mdot
.636 .08933 Mdot
.636 .08941 Mdot
.636 .09007 Mdot
.636 .09014 Mdot
.636 .09018 Mdot
.636 .09043 Mdot
.636 .09085 Mdot
.636 .09107 Mdot
.636 .09114 Mdot
.636 .09125 Mdot
.636 .09141 Mdot
.636 .09141 Mdot
.636 .09149 Mdot
.636 .09161 Mdot
.636 .09165 Mdot
.636 .09197 Mdot
.636 .09221 Mdot
.636 .09326 Mdot
.636 .0933 Mdot
.636 .0936 Mdot
.636 .09362 Mdot
.636 .09376 Mdot
.636 .09381 Mdot
.636 .09387 Mdot
.636 .094 Mdot
.636 .09406 Mdot
.636 .09423 Mdot
.636 .09454 Mdot
.636 .09457 Mdot
.636 .09471 Mdot
.636 .09527 Mdot
.636 .09571 Mdot
.636 .09574 Mdot
.636 .09603 Mdot
.636 .09604 Mdot
.636 .09607 Mdot
.636 .09617 Mdot
.636 .09635 Mdot
.636 .09711 Mdot
.636 .09724 Mdot
.636 .09736 Mdot
.636 .09769 Mdot
.636 .09789 Mdot
.636 .0979 Mdot
.636 .09803 Mdot
.636 .09808 Mdot
.636 .09858 Mdot
.636 .09877 Mdot
.636 .0991 Mdot
.636 .09937 Mdot
.636 .09996 Mdot
.636 .1 Mdot
.636 .10057 Mdot
.636 .10091 Mdot
.636 .10096 Mdot
.636 .10097 Mdot
.636 .10119 Mdot
.636 .10171 Mdot
.636 .1019 Mdot
.636 .10192 Mdot
.636 .10207 Mdot
.636 .1021 Mdot
.636 .10215 Mdot
.636 .10223 Mdot
.636 .10227 Mdot
.636 .10247 Mdot
.636 .1027 Mdot
.636 .10295 Mdot
.636 .10299 Mdot
.636 .10328 Mdot
.636 .10331 Mdot
.636 .10355 Mdot
.636 .10374 Mdot
.636 .10399 Mdot
.636 .1045 Mdot
.636 .10495 Mdot
.636 .10615 Mdot
.636 .10635 Mdot
.636 .1064 Mdot
.636 .10707 Mdot
.636 .10729 Mdot
.636 .10734 Mdot
.636 .10762 Mdot
.636 .10804 Mdot
.636 .10806 Mdot
.636 .10821 Mdot
.636 .10836 Mdot
.636 .10838 Mdot
.636 .10843 Mdot
.636 .10847 Mdot
.636 .10928 Mdot
.636 .10939 Mdot
.636 .10963 Mdot
.636 .10969 Mdot
.636 .10973 Mdot
.636 .11013 Mdot
.636 .11031 Mdot
.636 .11057 Mdot
.636 .11066 Mdot
.636 .11071 Mdot
.636 .11102 Mdot
.636 .1114 Mdot
.636 .11156 Mdot
.636 .11184 Mdot
.636 .11193 Mdot
.636 .11207 Mdot
.636 .11227 Mdot
.636 .11228 Mdot
.636 .11237 Mdot
.636 .11253 Mdot
.636 .11258 Mdot
.636 .11263 Mdot
.636 .11298 Mdot
.636 .11329 Mdot
.636 .114 Mdot
.636 .11424 Mdot
.636 .11462 Mdot
.636 .11468 Mdot
.636 .11505 Mdot
.636 .11509 Mdot
.636 .11526 Mdot
.636 .11533 Mdot
.636 .1154 Mdot
.636 .11557 Mdot
.636 .11565 Mdot
.636 .11578 Mdot
.636 .11586 Mdot
.636 .11595 Mdot
.636 .11626 Mdot
.636 .11629 Mdot
.636 .11647 Mdot
.636 .11718 Mdot
.636 .11775 Mdot
.636 .11778 Mdot
.636 .11815 Mdot
.636 .11816 Mdot
.636 .1182 Mdot
.636 .11833 Mdot
.636 .11855 Mdot
.636 .11952 Mdot
.636 .11969 Mdot
.636 .11984 Mdot
.636 .12026 Mdot
.636 .12052 Mdot
.636 .12053 Mdot
.636 .12069 Mdot
.636 .12075 Mdot
.636 .12139 Mdot
.636 .12164 Mdot
.636 .12205 Mdot
.636 .1224 Mdot
.636 .12315 Mdot
.636 .12319 Mdot
.636 .12393 Mdot
.636 .12435 Mdot
.636 .12442 Mdot
.636 .12443 Mdot
.636 .12471 Mdot
.636 .12538 Mdot
.636 .12562 Mdot
.636 .12563 Mdot
.636 .12583 Mdot
.636 .12586 Mdot
.636 .12593 Mdot
.636 .12604 Mdot
.636 .12608 Mdot
.636 .12634 Mdot
.636 .12663 Mdot
.636 .12695 Mdot
.636 .12701 Mdot
.636 .12737 Mdot
.636 .12741 Mdot
.636 .12772 Mdot
.636 .12796 Mdot
.636 .12828 Mdot
.636 .12893 Mdot
.636 .12949 Mdot
.636 .13102 Mdot
.636 .13127 Mdot
.636 .13134 Mdot
.636 .13219 Mdot
.636 .13247 Mdot
.636 .13254 Mdot
.636 .13289 Mdot
.636 .13343 Mdot
.636 .13345 Mdot
.636 .13365 Mdot
.636 .13383 Mdot
.636 .13386 Mdot
.636 .13392 Mdot
.636 .13397 Mdot
.636 .135 Mdot
.636 .13515 Mdot
.636 .13544 Mdot
.636 .13553 Mdot
.636 .13558 Mdot
.636 .13608 Mdot
.636 .13631 Mdot
.636 .13655 Mdot
.636 .13664 Mdot
.636 .13676 Mdot
.636 .13682 Mdot
.636 .13722 Mdot
.636 .13769 Mdot
.636 .1379 Mdot
.636 .13826 Mdot
.636 .13837 Mdot
.636 .13855 Mdot
.636 .1388 Mdot
.636 .13881 Mdot
.636 .13893 Mdot
.636 .13913 Mdot
.636 .1392 Mdot
.636 .13927 Mdot
.636 .1397 Mdot
.636 .14011 Mdot
.636 .141 Mdot
.636 .14131 Mdot
.636 .14179 Mdot
.636 .14187 Mdot
.636 .14234 Mdot
.636 .14239 Mdot
.636 .14261 Mdot
.636 .1427 Mdot
.636 .14278 Mdot
.636 .143 Mdot
.636 .1431 Mdot
.636 .14326 Mdot
.636 .14337 Mdot
.636 .14348 Mdot
.636 .14388 Mdot
.636 .14391 Mdot
.636 .14415 Mdot
.636 .14505 Mdot
.636 .14577 Mdot
.636 .14582 Mdot
.636 .14629 Mdot
.636 .14629 Mdot
.636 .14635 Mdot
.636 .14651 Mdot
.636 .14679 Mdot
.636 .14802 Mdot
.636 .14825 Mdot
.636 .14843 Mdot
.636 .14897 Mdot
.636 .1493 Mdot
.636 .14931 Mdot
.636 .14952 Mdot
.636 .1496 Mdot
.636 .1504 Mdot
.636 .15072 Mdot
.636 .15125 Mdot
.636 .15169 Mdot
.636 .15264 Mdot
.636 .1527 Mdot
.636 .15363 Mdot
.636 .15417 Mdot
.636 .15426 Mdot
.636 .15427 Mdot
.636 .15463 Mdot
.636 .15548 Mdot
.636 .15578 Mdot
.636 .1558 Mdot
.636 .15606 Mdot
.636 .15609 Mdot
.636 .15618 Mdot
.636 .15631 Mdot
.636 .15637 Mdot
.636 .1567 Mdot
.636 .15707 Mdot
.636 .15748 Mdot
.636 .15755 Mdot
.636 .15801 Mdot
.636 .15806 Mdot
.636 .15846 Mdot
.636 .15876 Mdot
.636 .15916 Mdot
.636 .15999 Mdot
.636 .16071 Mdot
.636 .16266 Mdot
.636 .16298 Mdot
.636 .16306 Mdot
.636 .16415 Mdot
.636 .16449 Mdot
.636 .16459 Mdot
.636 .16503 Mdot
.636 .16572 Mdot
.636 .16575 Mdot
.636 .16599 Mdot
.636 .16623 Mdot
.636 .16626 Mdot
.636 .16634 Mdot
.636 .16641 Mdot
.636 .16771 Mdot
.636 .1679 Mdot
.636 .16828 Mdot
.636 .16839 Mdot
.636 .16845 Mdot
.636 .16909 Mdot
.636 .16939 Mdot
.636 .16969 Mdot
.636 .16981 Mdot
.636 .16995 Mdot
.636 .17003 Mdot
.636 .17054 Mdot
.636 .17114 Mdot
.636 .17141 Mdot
.636 .17186 Mdot
.636 .172 Mdot
.636 .17223 Mdot
.636 .17256 Mdot
.636 .17257 Mdot
.636 .17272 Mdot
.636 .17297 Mdot
.636 .17306 Mdot
.636 .17314 Mdot
.636 .1737 Mdot
.636 .17421 Mdot
.636 .17535 Mdot
.636 .17574 Mdot
.636 .17636 Mdot
.636 .17645 Mdot
.636 .17706 Mdot
.636 .17712 Mdot
.636 .1774 Mdot
.636 .17751 Mdot
.636 .17762 Mdot
.636 .1779 Mdot
.636 .17802 Mdot
.636 .17823 Mdot
.636 .17837 Mdot
.636 .17851 Mdot
.636 .17901 Mdot
.636 .17905 Mdot
.636 .17936 Mdot
.636 .1805 Mdot
.636 .18142 Mdot
.636 .18148 Mdot
.636 .18207 Mdot
.636 .18208 Mdot
.636 .18215 Mdot
.636 .18236 Mdot
.636 .18272 Mdot
.636 .18428 Mdot
.636 .18457 Mdot
.636 .18481 Mdot
.636 .18548 Mdot
.636 .1859 Mdot
.636 .18592 Mdot
.636 .18618 Mdot
.636 .18628 Mdot
.636 .18731 Mdot
.636 .18771 Mdot
.636 .18839 Mdot
.636 .18894 Mdot
.636 .19016 Mdot
.636 .19023 Mdot
.636 .19142 Mdot
.636 .19211 Mdot
.636 .19221 Mdot
.636 .19223 Mdot
.636 .19268 Mdot
.636 .19377 Mdot
.636 .19415 Mdot
.636 .19418 Mdot
.636 .1945 Mdot
.636 .19455 Mdot
.636 .19466 Mdot
.636 .19483 Mdot
.636 .1949 Mdot
.636 .19531 Mdot
.636 .19579 Mdot
.636 .19631 Mdot
.636 .1964 Mdot
.636 .19699 Mdot
.636 .19705 Mdot
.636 .19755 Mdot
.636 .19794 Mdot
.636 .19845 Mdot
.636 .19951 Mdot
.636 .20042 Mdot
.636 .2029 Mdot
.636 .2033 Mdot
.636 .20341 Mdot
.636 .2048 Mdot
.636 .20523 Mdot
.636 .20535 Mdot
.636 .20592 Mdot
.636 .20679 Mdot
.636 .20683 Mdot
.636 .20714 Mdot
.636 .20744 Mdot
.636 .20749 Mdot
.636 .20758 Mdot
.636 .20767 Mdot
.636 .20933 Mdot
.636 .20957 Mdot
.636 .21005 Mdot
.636 .21019 Mdot
.636 .21027 Mdot
.636 .21108 Mdot
.636 .21146 Mdot
.636 .21185 Mdot
.636 .21199 Mdot
.636 .21218 Mdot
.636 .21228 Mdot
.636 .21293 Mdot
.636 .21369 Mdot
.636 .21403 Mdot
.636 .2146 Mdot
.636 .21479 Mdot
.636 .21508 Mdot
.636 .21549 Mdot
.636 .2155 Mdot
.636 .2157 Mdot
.636 .21602 Mdot
.636 .21612 Mdot
.636 .21624 Mdot
.636 .21695 Mdot
.636 .2176 Mdot
.636 .21905 Mdot
.636 .21954 Mdot
.636 .22033 Mdot
.636 .22045 Mdot
.636 .22122 Mdot
.636 .22129 Mdot
.636 .22165 Mdot
.636 .22179 Mdot
.636 .22192 Mdot
.636 .22228 Mdot
.636 .22244 Mdot
.636 .2227 Mdot
.636 .22288 Mdot
.636 .22306 Mdot
.636 .2237 Mdot
.636 .22375 Mdot
.636 .22414 Mdot
.636 .22559 Mdot
.636 .22676 Mdot
.636 .22683 Mdot
.636 .22759 Mdot
.636 .2276 Mdot
.636 .2277 Mdot
.636 .22796 Mdot
.636 .22841 Mdot
.636 .23041 Mdot
.636 .23077 Mdot
.636 .23107 Mdot
.636 .23193 Mdot
.636 .23246 Mdot
.636 .23248 Mdot
.636 .23282 Mdot
.636 .23295 Mdot
.636 .23425 Mdot
.636 .23477 Mdot
.636 .23562 Mdot
.636 .23633 Mdot
.636 .23788 Mdot
.636 .23797 Mdot
.636 .23948 Mdot
.636 .24036 Mdot
.636 .24049 Mdot
.636 .24051 Mdot
.636 .24109 Mdot
.636 .24247 Mdot
.636 .24296 Mdot
.636 .243 Mdot
.636 .24341 Mdot
.636 .24346 Mdot
.636 .24361 Mdot
.636 .24382 Mdot
.636 .24391 Mdot
.636 .24444 Mdot
.636 .24504 Mdot
.636 .2457 Mdot
.636 .24582 Mdot
.636 .24657 Mdot
.636 .24665 Mdot
.636 .24728 Mdot
.636 .24778 Mdot
.636 .24843 Mdot
.636 .24977 Mdot
.636 .25093 Mdot
.636 .25409 Mdot
.636 .2546 Mdot
.636 .25473 Mdot
.636 .2565 Mdot
.636 .25706 Mdot
.636 .25721 Mdot
.636 .25792 Mdot
.636 .25904 Mdot
.636 .25908 Mdot
.636 .25948 Mdot
.636 .25986 Mdot
.636 .25992 Mdot
.636 .26004 Mdot
.636 .26016 Mdot
.636 .26226 Mdot
.636 .26257 Mdot
.636 .26318 Mdot
.636 .26335 Mdot
.636 .26346 Mdot
.636 .26449 Mdot
.636 .26498 Mdot
.636 .26547 Mdot
.636 .26589 Mdot
.636 .26602 Mdot
.636 .26684 Mdot
.636 .26781 Mdot
.636 .26825 Mdot
.636 .26897 Mdot
.636 .26921 Mdot
.636 .26958 Mdot
.636 .2701 Mdot
.636 .27012 Mdot
.636 .27037 Mdot
.636 .27077 Mdot
.636 .27091 Mdot
.636 .27105 Mdot
.636 .27195 Mdot
.636 .27278 Mdot
.636 .27463 Mdot
.636 .27525 Mdot
.636 .27625 Mdot
.636 .2764 Mdot
.636 .27738 Mdot
.636 .27748 Mdot
.636 .27794 Mdot
.636 .27811 Mdot
.636 .27829 Mdot
.636 .27874 Mdot
.636 .27894 Mdot
.636 .27928 Mdot
.636 .27951 Mdot
.636 .27973 Mdot
.636 .28054 Mdot
.636 .28061 Mdot
.636 .2811 Mdot
.636 .28295 Mdot
.636 .28444 Mdot
.636 .28453 Mdot
.636 .2855 Mdot
.636 .28551 Mdot
.636 .28563 Mdot
.636 .28597 Mdot
.636 .28654 Mdot
.636 .28907 Mdot
.636 .28953 Mdot
.636 .28992 Mdot
.636 .29101 Mdot
.636 .29169 Mdot
.636 .29172 Mdot
.636 .29215 Mdot
.636 .29231 Mdot
.636 .29396 Mdot
.636 .29462 Mdot
.636 .29571 Mdot
.636 .29661 Mdot
.636 .29858 Mdot
.636 .29869 Mdot
.636 .30061 Mdot
.636 .30173 Mdot
.636 .30191 Mdot
.636 .30193 Mdot
.636 .30266 Mdot
.636 .30442 Mdot
.636 .30505 Mdot
.636 .30509 Mdot
.636 .30561 Mdot
.636 .30568 Mdot
.636 .30587 Mdot
.636 .30614 Mdot
.636 .30625 Mdot
.636 .30692 Mdot
.636 .30769 Mdot
.636 .30853 Mdot
.636 .30868 Mdot
.636 .30963 Mdot
.636 .30974 Mdot
.636 .31054 Mdot
.636 .31117 Mdot
.636 .312 Mdot
.636 .3137 Mdot
.636 .31518 Mdot
.636 .31919 Mdot
.636 .31985 Mdot
.636 .32002 Mdot
.636 .32226 Mdot
.636 .32297 Mdot
.636 .32317 Mdot
.636 .32408 Mdot
.636 .3255 Mdot
.636 .32555 Mdot
.636 .32606 Mdot
.636 .32654 Mdot
.636 .32661 Mdot
.636 .32677 Mdot
.636 .32692 Mdot
.636 .32959 Mdot
.636 .32999 Mdot
.636 .33076 Mdot
.636 .33098 Mdot
.636 .33111 Mdot
.636 .33243 Mdot
.636 .33305 Mdot
.636 .33367 Mdot
.636 .33421 Mdot
.636 .33437 Mdot
.636 .33542 Mdot
.636 .33665 Mdot
.636 .33721 Mdot
.636 .33813 Mdot
.636 .33843 Mdot
.636 .3389 Mdot
.636 .33956 Mdot
.636 .33959 Mdot
.636 .3399 Mdot
.636 .34042 Mdot
.636 .34059 Mdot
.636 .34077 Mdot
.636 .34192 Mdot
.636 .34297 Mdot
.636 .34532 Mdot
.636 .34611 Mdot
.636 .34739 Mdot
.636 .34758 Mdot
.636 .34883 Mdot
.636 .34895 Mdot
.636 .34954 Mdot
.636 .34975 Mdot
.636 .34998 Mdot
.636 .35055 Mdot
.636 .35081 Mdot
.636 .35124 Mdot
.636 .35153 Mdot
.636 .35182 Mdot
.636 .35284 Mdot
.636 .35294 Mdot
.636 .35356 Mdot
.636 .35591 Mdot
.636 .3578 Mdot
.636 .35792 Mdot
.636 .35915 Mdot
.636 .35917 Mdot
.636 .35932 Mdot
.636 .35975 Mdot
.636 .36048 Mdot
.636 .3637 Mdot
.636 .36428 Mdot
.636 .36477 Mdot
.636 .36616 Mdot
.636 .36703 Mdot
.636 .36706 Mdot
.636 .36761 Mdot
.636 .36782 Mdot
.636 .36992 Mdot
.636 .37075 Mdot
.636 .37214 Mdot
.636 .37329 Mdot
.636 .37579 Mdot
.636 .37593 Mdot
.636 .37838 Mdot
.636 .3798 Mdot
.636 .38002 Mdot
.636 .38005 Mdot
.636 .38098 Mdot
.636 .38322 Mdot
.636 .38402 Mdot
.636 .38407 Mdot
.636 .38474 Mdot
.636 .38483 Mdot
.636 .38506 Mdot
.636 .38541 Mdot
.636 .38555 Mdot
.636 .3864 Mdot
.636 .38737 Mdot
.636 .38845 Mdot
.636 .38864 Mdot
.636 .38985 Mdot
.636 .38998 Mdot
.638 .01568 Mdot
.638 .01595 Mdot
.638 .01629 Mdot
.638 .01631 Mdot
.638 .01673 Mdot
.638 .01675 Mdot
.638 .0168 Mdot
.638 .01728 Mdot
.638 .01731 Mdot
.638 .01731 Mdot
.638 .01738 Mdot
.638 .01799 Mdot
.638 .01802 Mdot
.638 .01802 Mdot
.638 .01811 Mdot
.638 .01889 Mdot
.638 .01893 Mdot
.638 .01894 Mdot
.638 .01905 Mdot
.638 .01905 Mdot
.638 .02004 Mdot
.638 .0201 Mdot
.638 .0201 Mdot
.638 .02024 Mdot
.638 .02025 Mdot
.638 .02089 Mdot
.638 .02151 Mdot
.638 .02158 Mdot
.638 .02159 Mdot
.638 .02177 Mdot
.638 .02178 Mdot
.638 .02259 Mdot
.638 .02339 Mdot
.638 .02348 Mdot
.638 .02349 Mdot
.638 .02371 Mdot
.638 .02373 Mdot
.638 .02434 Mdot
.638 .02438 Mdot
.638 .02445 Mdot
.638 .02458 Mdot
.638 .02476 Mdot
.638 .02542 Mdot
.638 .02579 Mdot
.638 .0259 Mdot
.638 .02591 Mdot
.638 .0262 Mdot
.638 .02622 Mdot
.638 .02639 Mdot
.638 .02656 Mdot
.638 .02697 Mdot
.638 .027 Mdot
.638 .02704 Mdot
.638 .02714 Mdot
.638 .0273 Mdot
.638 .02754 Mdot
.638 .02838 Mdot
.638 .02869 Mdot
.638 .02884 Mdot
.638 .02898 Mdot
.638 .029 Mdot
.638 .02937 Mdot
.638 .02939 Mdot
.638 .02962 Mdot
.638 .02983 Mdot
.638 .03035 Mdot
.638 .03039 Mdot
.638 .03045 Mdot
.638 .03047 Mdot
.638 .03057 Mdot
.638 .03065 Mdot
.638 .03077 Mdot
.638 .03108 Mdot
.638 .0314 Mdot
.638 .03215 Mdot
.638 .03254 Mdot
.638 .03274 Mdot
.638 .03292 Mdot
.638 .03294 Mdot
.638 .03317 Mdot
.638 .03339 Mdot
.638 .03341 Mdot
.638 .03344 Mdot
.638 .0336 Mdot
.638 .03366 Mdot
.638 .03373 Mdot
.638 .03401 Mdot
.638 .03411 Mdot
.638 .03466 Mdot
.638 .03472 Mdot
.638 .03479 Mdot
.638 .03481 Mdot
.638 .03495 Mdot
.638 .03505 Mdot
.638 .0352 Mdot
.638 .03559 Mdot
.638 .03601 Mdot
.638 .03652 Mdot
.638 .03696 Mdot
.638 .03742 Mdot
.638 .03746 Mdot
.638 .03772 Mdot
.638 .03794 Mdot
.638 .03797 Mdot
.638 .03827 Mdot
.638 .03854 Mdot
.638 .03857 Mdot
.638 .03861 Mdot
.638 .03881 Mdot
.638 .03889 Mdot
.638 .03898 Mdot
.638 .03925 Mdot
.638 .03933 Mdot
.638 .03946 Mdot
.638 .03978 Mdot
.638 .04017 Mdot
.638 .04024 Mdot
.638 .04033 Mdot
.638 .04036 Mdot
.638 .04053 Mdot
.638 .04067 Mdot
.638 .04085 Mdot
.638 .04136 Mdot
.638 .04188 Mdot
.638 .04211 Mdot
.638 .04253 Mdot
.638 .0431 Mdot
.638 .04358 Mdot
.638 .04358 Mdot
.638 .04369 Mdot
.638 .04374 Mdot
.638 .04406 Mdot
.638 .04435 Mdot
.638 .04477 Mdot
.638 .0448 Mdot
.638 .04512 Mdot
.638 .04516 Mdot
.638 .0452 Mdot
.638 .04546 Mdot
.638 .04556 Mdot
.638 .04567 Mdot
.638 .04603 Mdot
.638 .04612 Mdot
.638 .04629 Mdot
.638 .0467 Mdot
.638 .04673 Mdot
.638 .04717 Mdot
.638 .04719 Mdot
.638 .04728 Mdot
.638 .04737 Mdot
.638 .0474 Mdot
.638 .04744 Mdot
.638 .04766 Mdot
.638 .04783 Mdot
.638 .04807 Mdot
.638 .04871 Mdot
.638 .04891 Mdot
.638 .04932 Mdot
.638 .04938 Mdot
.638 .04967 Mdot
.638 .05021 Mdot
.638 .05094 Mdot
.638 .05155 Mdot
.638 .05155 Mdot
.638 .05168 Mdot
.638 .05175 Mdot
.638 .05188 Mdot
.638 .05216 Mdot
.638 .05253 Mdot
.638 .05294 Mdot
.638 .05307 Mdot
.638 .05311 Mdot
.638 .05351 Mdot
.638 .05356 Mdot
.638 .05362 Mdot
.638 .05394 Mdot
.638 .05402 Mdot
.638 .05407 Mdot
.638 .05422 Mdot
.638 .05439 Mdot
.638 .05467 Mdot
.638 .05479 Mdot
.638 .055 Mdot
.638 .05552 Mdot
.638 .05553 Mdot
.638 .05557 Mdot
.638 .05612 Mdot
.638 .05615 Mdot
.638 .05627 Mdot
.638 .05638 Mdot
.638 .05642 Mdot
.638 .05647 Mdot
.638 .05675 Mdot
.638 .05697 Mdot
.638 .05727 Mdot
.638 .05809 Mdot
.638 .05835 Mdot
.638 .05855 Mdot
.638 .05887 Mdot
.638 .0589 Mdot
.638 .0589 Mdot
.638 .05895 Mdot
.638 .05932 Mdot
.638 .05953 Mdot
.638 .06001 Mdot
.638 .06001 Mdot
.638 .06041 Mdot
.638 .06093 Mdot
.638 .06105 Mdot
.638 .06121 Mdot
.638 .06172 Mdot
.638 .06172 Mdot
.638 .06189 Mdot
.638 .06198 Mdot
.638 .06214 Mdot
.638 .0625 Mdot
.638 .06266 Mdot
.638 .06297 Mdot
.638 .06349 Mdot
.638 .06365 Mdot
.638 .06371 Mdot
.638 .06422 Mdot
.638 .06428 Mdot
.638 .06435 Mdot
.638 .06477 Mdot
.638 .06487 Mdot
.638 .06494 Mdot
.638 .06512 Mdot
.638 .06535 Mdot
.638 .0657 Mdot
.638 .06584 Mdot
.638 .06586 Mdot
.638 .06593 Mdot
.638 .06612 Mdot
.638 .0666 Mdot
.638 .06679 Mdot
.638 .06679 Mdot
.638 .06684 Mdot
.638 .06738 Mdot
.638 .06755 Mdot
.638 .06759 Mdot
.638 .06773 Mdot
.638 .06788 Mdot
.638 .06793 Mdot
.638 .06799 Mdot
.638 .06835 Mdot
.638 .06863 Mdot
.638 .0687 Mdot
.638 .06902 Mdot
.638 .06981 Mdot
.638 .07006 Mdot
.638 .07015 Mdot
.638 .07039 Mdot
.638 .07064 Mdot
.638 .07103 Mdot
.638 .07106 Mdot
.638 .07109 Mdot
.638 .0711 Mdot
.638 .07116 Mdot
.638 .07163 Mdot
.638 .07189 Mdot
.638 .07251 Mdot
.638 .07251 Mdot
.638 .07302 Mdot
.638 .07333 Mdot
.638 .07369 Mdot
.638 .07384 Mdot
.638 .07405 Mdot
.638 .07469 Mdot
.638 .07469 Mdot
.638 .07478 Mdot
.638 .0749 Mdot
.638 .07502 Mdot
.638 .07522 Mdot
.638 .07569 Mdot
.638 .0759 Mdot
.638 .07624 Mdot
.638 .07629 Mdot
.638 .07674 Mdot
.638 .07695 Mdot
.638 .07716 Mdot
.638 .07723 Mdot
.638 .07738 Mdot
.638 .07782 Mdot
.638 .07789 Mdot
.638 .07796 Mdot
.638 .07805 Mdot
.638 .07858 Mdot
.638 .07871 Mdot
.638 .0788 Mdot
.638 .07903 Mdot
.638 .07932 Mdot
.638 .07977 Mdot
.638 .07995 Mdot
.638 .07997 Mdot
.638 .08006 Mdot
.638 .0803 Mdot
.638 .08087 Mdot
.638 .08093 Mdot
.638 .08116 Mdot
.638 .08116 Mdot
.638 .08123 Mdot
.638 .08137 Mdot
.638 .0819 Mdot
.638 .08192 Mdot
.638 .08214 Mdot
.638 .08219 Mdot
.638 .08237 Mdot
.638 .08253 Mdot
.638 .08255 Mdot
.638 .08262 Mdot
.638 .0827 Mdot
.638 .08316 Mdot
.638 .08351 Mdot
.638 .0836 Mdot
.638 .08401 Mdot
.638 .08434 Mdot
.638 .08497 Mdot
.638 .08501 Mdot
.638 .08516 Mdot
.638 .08534 Mdot
.638 .08544 Mdot
.638 .08576 Mdot
.638 .08608 Mdot
.638 .08625 Mdot
.638 .08657 Mdot
.638 .08661 Mdot
.638 .08665 Mdot
.638 .08666 Mdot
.638 .08674 Mdot
.638 .08718 Mdot
.638 .08734 Mdot
.638 .08768 Mdot
.638 .08777 Mdot
.638 .08819 Mdot
.638 .08846 Mdot
.638 .08846 Mdot
.638 .08868 Mdot
.638 .08911 Mdot
.638 .08943 Mdot
.638 .0895 Mdot
.638 .08997 Mdot
.638 .09016 Mdot
.638 .09042 Mdot
.638 .09124 Mdot
.638 .09124 Mdot
.638 .09136 Mdot
.638 .09144 Mdot
.638 .09152 Mdot
.638 .09166 Mdot
.638 .09193 Mdot
.638 .09252 Mdot
.638 .09278 Mdot
.638 .09322 Mdot
.638 .09328 Mdot
.638 .09386 Mdot
.638 .09413 Mdot
.638 .09439 Mdot
.638 .09448 Mdot
.638 .0946 Mdot
.638 .09468 Mdot
.638 .09523 Mdot
.638 .09532 Mdot
.638 .09542 Mdot
.638 .09553 Mdot
.638 .09586 Mdot
.638 .09601 Mdot
.638 .09621 Mdot
.638 .09638 Mdot
.638 .09648 Mdot
.638 .09656 Mdot
.638 .09665 Mdot
.638 .09679 Mdot
.638 .09715 Mdot
.638 .09772 Mdot
.638 .09795 Mdot
.638 .09798 Mdot
.638 .09808 Mdot
.638 .0981 Mdot
.638 .09836 Mdot
.638 .09841 Mdot
.638 .09913 Mdot
.638 .0992 Mdot
.638 .0995 Mdot
.638 .0995 Mdot
.638 .09959 Mdot
.638 .09976 Mdot
.638 .10044 Mdot
.638 .10046 Mdot
.638 .10074 Mdot
.638 .10081 Mdot
.638 .10104 Mdot
.638 .10124 Mdot
.638 .10127 Mdot
.638 .10136 Mdot
.638 .10146 Mdot
.638 .10205 Mdot
.638 .10235 Mdot
.638 .1025 Mdot
.638 .10261 Mdot
.638 .10273 Mdot
.638 .10313 Mdot
.638 .10356 Mdot
.638 .10436 Mdot
.638 .10437 Mdot
.638 .10438 Mdot
.638 .10441 Mdot
.638 .10461 Mdot
.638 .10483 Mdot
.638 .10487 Mdot
.638 .10497 Mdot
.638 .10536 Mdot
.638 .10578 Mdot
.638 .10582 Mdot
.638 .10599 Mdot
.638 .1064 Mdot
.638 .10645 Mdot
.638 .1065 Mdot
.638 .10652 Mdot
.638 .10662 Mdot
.638 .10718 Mdot
.638 .10739 Mdot
.638 .10781 Mdot
.638 .10793 Mdot
.638 .10847 Mdot
.638 .10882 Mdot
.638 .10882 Mdot
.638 .1091 Mdot
.638 .10954 Mdot
.638 .10965 Mdot
.638 .10969 Mdot
.638 .11005 Mdot
.638 .11014 Mdot
.638 .11074 Mdot
.638 .11098 Mdot
.638 .11123 Mdot
.638 .11132 Mdot
.638 .11158 Mdot
.638 .11236 Mdot
.638 .11236 Mdot
.638 .11251 Mdot
.638 .11262 Mdot
.638 .11271 Mdot
.638 .11286 Mdot
.638 .1129 Mdot
.638 .11324 Mdot
.638 .11397 Mdot
.638 .11399 Mdot
.638 .11415 Mdot
.638 .11433 Mdot
.638 .11463 Mdot
.638 .11489 Mdot
.638 .11497 Mdot
.638 .11517 Mdot
.638 .11571 Mdot
.638 .11604 Mdot
.638 .11638 Mdot
.638 .1165 Mdot
.638 .11665 Mdot
.638 .11675 Mdot
.638 .11745 Mdot
.638 .11757 Mdot
.638 .11769 Mdot
.638 .11784 Mdot
.638 .11826 Mdot
.638 .1184 Mdot
.638 .11845 Mdot
.638 .1187 Mdot
.638 .11892 Mdot
.638 .11905 Mdot
.638 .11915 Mdot
.638 .11926 Mdot
.638 .11944 Mdot
.638 .1199 Mdot
.638 .12063 Mdot
.638 .12093 Mdot
.638 .12096 Mdot
.638 .12109 Mdot
.638 .12111 Mdot
.638 .12144 Mdot
.638 .12151 Mdot
.638 .12243 Mdot
.638 .12252 Mdot
.638 .1229 Mdot
.638 .1229 Mdot
.638 .12301 Mdot
.638 .12323 Mdot
.638 .1241 Mdot
.638 .12413 Mdot
.638 .12449 Mdot
.638 .12457 Mdot
.638 .12487 Mdot
.638 .12512 Mdot
.638 .12516 Mdot
.638 .12528 Mdot
.638 .1254 Mdot
.638 .12615 Mdot
.638 .12654 Mdot
.638 .12672 Mdot
.638 .12687 Mdot
.638 .12702 Mdot
.638 .12754 Mdot
.638 .12808 Mdot
.638 .1291 Mdot
.638 .12911 Mdot
.638 .12913 Mdot
.638 .12917 Mdot
.638 .12942 Mdot
.638 .12971 Mdot
.638 .12976 Mdot
.638 .12987 Mdot
.638 .13038 Mdot
.638 .13091 Mdot
.638 .13096 Mdot
.638 .13119 Mdot
.638 .13171 Mdot
.638 .13177 Mdot
.638 .13183 Mdot
.638 .13185 Mdot
.638 .13198 Mdot
.638 .1327 Mdot
.638 .13296 Mdot
.638 .13351 Mdot
.638 .13366 Mdot
.638 .13435 Mdot
.638 .13479 Mdot
.638 .13479 Mdot
.638 .13515 Mdot
.638 .13572 Mdot
.638 .13585 Mdot
.638 .13591 Mdot
.638 .13636 Mdot
.638 .13648 Mdot
.638 .13724 Mdot
.638 .13755 Mdot
.638 .13787 Mdot
.638 .13798 Mdot
.638 .13832 Mdot
.638 .13931 Mdot
.638 .13932 Mdot
.638 .1395 Mdot
.638 .13964 Mdot
.638 .13976 Mdot
.638 .13995 Mdot
.638 .14 Mdot
.638 .14043 Mdot
.638 .14137 Mdot
.638 .14139 Mdot
.638 .14159 Mdot
.638 .14182 Mdot
.638 .14221 Mdot
.638 .14254 Mdot
.638 .14264 Mdot
.638 .1429 Mdot
.638 .14358 Mdot
.638 .14401 Mdot
.638 .14444 Mdot
.638 .14459 Mdot
.638 .14478 Mdot
.638 .14491 Mdot
.638 .14581 Mdot
.638 .14596 Mdot
.638 .14611 Mdot
.638 .1463 Mdot
.638 .14684 Mdot
.638 .14702 Mdot
.638 .14708 Mdot
.638 .1474 Mdot
.638 .14767 Mdot
.638 .14785 Mdot
.638 .14798 Mdot
.638 .14812 Mdot
.638 .14834 Mdot
.638 .14894 Mdot
.638 .14987 Mdot
.638 .15024 Mdot
.638 .15029 Mdot
.638 .15045 Mdot
.638 .15047 Mdot
.638 .1509 Mdot
.638 .15098 Mdot
.638 .15216 Mdot
.638 .15227 Mdot
.638 .15275 Mdot
.638 .15276 Mdot
.638 .15291 Mdot
.638 .15319 Mdot
.638 .15429 Mdot
.638 .15433 Mdot
.638 .15479 Mdot
.638 .15489 Mdot
.638 .15527 Mdot
.638 .1556 Mdot
.638 .15565 Mdot
.638 .15579 Mdot
.638 .15595 Mdot
.638 .15691 Mdot
.638 .1574 Mdot
.638 .15764 Mdot
.638 .15782 Mdot
.638 .15801 Mdot
.638 .15867 Mdot
.638 .15937 Mdot
.638 .16067 Mdot
.638 .16068 Mdot
.638 .16071 Mdot
.638 .16076 Mdot
.638 .16108 Mdot
.638 .16144 Mdot
.638 .16151 Mdot
.638 .16166 Mdot
.638 .16231 Mdot
.638 .16298 Mdot
.638 .16305 Mdot
.638 .16333 Mdot
.638 .164 Mdot
.638 .16408 Mdot
.638 .16416 Mdot
.638 .16418 Mdot
.638 .16435 Mdot
.638 .16526 Mdot
.638 .1656 Mdot
.638 .16629 Mdot
.638 .16649 Mdot
.638 .16737 Mdot
.638 .16793 Mdot
.638 .16793 Mdot
.638 .16839 Mdot
.638 .16911 Mdot
.638 .16928 Mdot
.638 .16935 Mdot
.638 .16994 Mdot
.638 .17009 Mdot
.638 .17106 Mdot
.638 .17146 Mdot
.638 .17186 Mdot
.638 .172 Mdot
.638 .17243 Mdot
.638 .17357 Mdot
.638 .1737 Mdot
.638 .17371 Mdot
.638 .17394 Mdot
.638 .17412 Mdot
.638 .17427 Mdot
.638 .17452 Mdot
.638 .17458 Mdot
.638 .17512 Mdot
.638 .17632 Mdot
.638 .17636 Mdot
.638 .17661 Mdot
.638 .1769 Mdot
.638 .1774 Mdot
.638 .17782 Mdot
.638 .17795 Mdot
.638 .17828 Mdot
.638 .17915 Mdot
.638 .17969 Mdot
.638 .18025 Mdot
.638 .18043 Mdot
.638 .18068 Mdot
.638 .18084 Mdot
.638 .18199 Mdot
.638 .18218 Mdot
.638 .18238 Mdot
.638 .18262 Mdot
.638 .1833 Mdot
.638 .18354 Mdot
.638 .18361 Mdot
.638 .18402 Mdot
.638 .18437 Mdot
.638 .1846 Mdot
.638 .18475 Mdot
.638 .18494 Mdot
.638 .18522 Mdot
.638 .18598 Mdot
.638 .18717 Mdot
.638 .18765 Mdot
.638 .1877 Mdot
.638 .18791 Mdot
.638 .18794 Mdot
.638 .18848 Mdot
.638 .18859 Mdot
.638 .1901 Mdot
.638 .19024 Mdot
.638 .19085 Mdot
.638 .19086 Mdot
.638 .19105 Mdot
.638 .1914 Mdot
.638 .19281 Mdot
.638 .19286 Mdot
.638 .19345 Mdot
.638 .19358 Mdot
.638 .19406 Mdot
.638 .19448 Mdot
.638 .19455 Mdot
.638 .19473 Mdot
.638 .19493 Mdot
.638 .19615 Mdot
.638 .19678 Mdot
.638 .19708 Mdot
.638 .19732 Mdot
.638 .19757 Mdot
.638 .19841 Mdot
.638 .19929 Mdot
.638 .20095 Mdot
.638 .20097 Mdot
.638 .20101 Mdot
.638 .20106 Mdot
.638 .20147 Mdot
.638 .20194 Mdot
.638 .20202 Mdot
.638 .20221 Mdot
.638 .20304 Mdot
.638 .2039 Mdot
.638 .20399 Mdot
.638 .20435 Mdot
.638 .2052 Mdot
.638 .20531 Mdot
.638 .20541 Mdot
.638 .20544 Mdot
.638 .20565 Mdot
.638 .20681 Mdot
.638 .20725 Mdot
.638 .20813 Mdot
.638 .20838 Mdot
.638 .2095 Mdot
.638 .21021 Mdot
.638 .21021 Mdot
.638 .2108 Mdot
.638 .21173 Mdot
.638 .21194 Mdot
.638 .21203 Mdot
.638 .21278 Mdot
.638 .21297 Mdot
.638 .21421 Mdot
.638 .21472 Mdot
.638 .21524 Mdot
.638 .21542 Mdot
.638 .21596 Mdot
.638 .21742 Mdot
.638 .21758 Mdot
.638 .21759 Mdot
.638 .21789 Mdot
.638 .21812 Mdot
.638 .21831 Mdot
.638 .21862 Mdot
.638 .2187 Mdot
.638 .2194 Mdot
.638 .22093 Mdot
.638 .22097 Mdot
.638 .22129 Mdot
.638 .22167 Mdot
.638 .2223 Mdot
.638 .22283 Mdot
.638 .223 Mdot
.638 .22342 Mdot
.638 .22453 Mdot
.638 .22523 Mdot
.638 .22593 Mdot
.638 .22617 Mdot
.638 .22648 Mdot
.638 .22669 Mdot
.638 .22816 Mdot
.638 .2284 Mdot
.638 .22865 Mdot
.638 .22896 Mdot
.638 .22983 Mdot
.638 .23014 Mdot
.638 .23023 Mdot
.638 .23075 Mdot
.638 .2312 Mdot
.638 .23148 Mdot
.638 .23169 Mdot
.638 .23192 Mdot
.638 .23228 Mdot
.638 .23325 Mdot
.638 .23477 Mdot
.638 .23538 Mdot
.638 .23545 Mdot
.638 .23571 Mdot
.638 .23576 Mdot
.638 .23644 Mdot
.638 .23658 Mdot
.638 .2385 Mdot
.638 .23868 Mdot
.638 .23947 Mdot
.638 .23948 Mdot
.638 .23971 Mdot
.638 .24017 Mdot
.638 .24196 Mdot
.638 .24203 Mdot
.638 .24278 Mdot
.638 .24294 Mdot
.638 .24356 Mdot
.638 .24409 Mdot
.638 .24418 Mdot
.638 .24441 Mdot
.638 .24467 Mdot
.638 .24623 Mdot
.638 .24703 Mdot
.638 .24742 Mdot
.638 .24772 Mdot
.638 .24803 Mdot
.638 .2491 Mdot
.638 .25023 Mdot
.638 .25235 Mdot
.638 .25237 Mdot
.638 .25242 Mdot
.638 .2525 Mdot
.638 .25302 Mdot
.638 .25361 Mdot
.638 .25372 Mdot
.638 .25396 Mdot
.638 .25502 Mdot
.638 .25611 Mdot
.638 .25623 Mdot
.638 .25669 Mdot
.638 .25778 Mdot
.638 .25791 Mdot
.638 .25804 Mdot
.638 .25808 Mdot
.638 .25835 Mdot
.638 .25983 Mdot
.638 .26038 Mdot
.638 .26151 Mdot
.638 .26183 Mdot
.638 .26327 Mdot
.638 .26417 Mdot
.638 .26417 Mdot
.638 .26492 Mdot
.638 .2661 Mdot
.638 .26637 Mdot
.638 .26649 Mdot
.638 .26744 Mdot
.638 .26769 Mdot
.638 .26927 Mdot
.638 .26992 Mdot
.638 .27058 Mdot
.638 .27081 Mdot
.638 .27151 Mdot
.638 .27336 Mdot
.638 .27357 Mdot
.638 .27358 Mdot
.638 .27396 Mdot
.638 .27426 Mdot
.638 .2745 Mdot
.638 .2749 Mdot
.638 .275 Mdot
.638 .27589 Mdot
.638 .27784 Mdot
.638 .27789 Mdot
.638 .27831 Mdot
.638 .27879 Mdot
.638 .2796 Mdot
.638 .28028 Mdot
.638 .28048 Mdot
.638 .28103 Mdot
.638 .28244 Mdot
.638 .28333 Mdot
.638 .28423 Mdot
.638 .28454 Mdot
.638 .28493 Mdot
.638 .2852 Mdot
.638 .28707 Mdot
.638 .28738 Mdot
.638 .2877 Mdot
.638 .28809 Mdot
.638 .2892 Mdot
.638 .28959 Mdot
.638 .28971 Mdot
.638 .29038 Mdot
.638 .29095 Mdot
.638 .29131 Mdot
.638 .29157 Mdot
.638 .29187 Mdot
.638 .29233 Mdot
.638 .29357 Mdot
.638 .2955 Mdot
.638 .29628 Mdot
.638 .29637 Mdot
.638 .29671 Mdot
.638 .29676 Mdot
.638 .29764 Mdot
.638 .29781 Mdot
.638 .30026 Mdot
.638 .3005 Mdot
.638 .3015 Mdot
.638 .30151 Mdot
.638 .30181 Mdot
.638 .30239 Mdot
.638 .30468 Mdot
.638 .30477 Mdot
.638 .30572 Mdot
.638 .30593 Mdot
.638 .30672 Mdot
.638 .3074 Mdot
.638 .30751 Mdot
.638 .30781 Mdot
.638 .30814 Mdot
.638 .31012 Mdot
.638 .31115 Mdot
.638 .31164 Mdot
.638 .31203 Mdot
.638 .31243 Mdot
.638 .3138 Mdot
.638 .31523 Mdot
.638 .31794 Mdot
.638 .31797 Mdot
.638 .31803 Mdot
.638 .31812 Mdot
.638 .31879 Mdot
.638 .31955 Mdot
.638 .31968 Mdot
.638 .32 Mdot
.638 .32135 Mdot
.638 .32274 Mdot
.638 .32289 Mdot
.638 .32347 Mdot
.638 .32486 Mdot
.638 .32503 Mdot
.638 .32519 Mdot
.638 .32524 Mdot
.638 .32559 Mdot
.638 .32748 Mdot
.638 .32819 Mdot
.638 .32963 Mdot
.638 .33004 Mdot
.638 .33187 Mdot
.638 .33302 Mdot
.638 .33302 Mdot
.638 .33398 Mdot
.638 .33549 Mdot
.638 .33583 Mdot
.638 .33599 Mdot
.638 .33719 Mdot
.638 .33752 Mdot
.638 .33952 Mdot
.638 .34035 Mdot
.638 .3412 Mdot
.638 .34149 Mdot
.638 .34238 Mdot
.638 .34475 Mdot
.638 .34502 Mdot
.638 .34503 Mdot
.638 .34551 Mdot
.638 .34589 Mdot
.638 .34621 Mdot
.638 .34671 Mdot
.638 .34684 Mdot
.638 .34797 Mdot
.638 .35046 Mdot
.638 .35053 Mdot
.638 .35106 Mdot
.638 .35167 Mdot
.638 .3527 Mdot
.638 .35357 Mdot
.638 .35384 Mdot
.638 .35453 Mdot
.638 .35633 Mdot
.638 .35747 Mdot
.638 .35861 Mdot
.638 .35901 Mdot
.638 .35951 Mdot
.638 .35985 Mdot
.638 .36224 Mdot
.638 .36263 Mdot
.638 .36305 Mdot
.638 .36354 Mdot
.638 .36496 Mdot
.638 .36546 Mdot
.638 .36561 Mdot
.638 .36646 Mdot
.638 .36719 Mdot
.638 .36765 Mdot
.638 .36798 Mdot
.638 .36836 Mdot
.638 .36895 Mdot
.638 .37053 Mdot
.638 .373 Mdot
.638 .37399 Mdot
.638 .37411 Mdot
.638 .37454 Mdot
.638 .37461 Mdot
.638 .37573 Mdot
.638 .37595 Mdot
.638 .37908 Mdot
.638 .37937 Mdot
.638 .38065 Mdot
.638 .38067 Mdot
.638 .38105 Mdot
.638 .38179 Mdot
.638 .38471 Mdot
.638 .38483 Mdot
.638 .38604 Mdot
.638 .38631 Mdot
.638 .38731 Mdot
.638 .38818 Mdot
.638 .38832 Mdot
.638 .3887 Mdot
.638 .38913 Mdot
.638 .39166 Mdot
.64 .01477 Mdot
.64 .01479 Mdot
.64 .01481 Mdot
.64 .01484 Mdot
.64 .01487 Mdot
.64 .01492 Mdot
.64 .01497 Mdot
.64 .01505 Mdot
.64 .01514 Mdot
.64 .01515 Mdot
.64 .01526 Mdot
.64 .01528 Mdot
.64 .01533 Mdot
.64 .01541 Mdot
.64 .01543 Mdot
.64 .0155 Mdot
.64 .01561 Mdot
.64 .01563 Mdot
.64 .01572 Mdot
.64 .01583 Mdot
.64 .01586 Mdot
.64 .01589 Mdot
.64 .016 Mdot
.64 .01614 Mdot
.64 .01617 Mdot
.64 .01622 Mdot
.64 .01636 Mdot
.64 .01653 Mdot
.64 .01658 Mdot
.64 .01664 Mdot
.64 .01671 Mdot
.64 .01682 Mdot
.64 .01704 Mdot
.64 .01711 Mdot
.64 .01718 Mdot
.64 .01726 Mdot
.64 .01741 Mdot
.64 .0177 Mdot
.64 .01778 Mdot
.64 .01787 Mdot
.64 .01798 Mdot
.64 .01817 Mdot
.64 .01853 Mdot
.64 .01863 Mdot
.64 .01876 Mdot
.64 .01889 Mdot
.64 .01914 Mdot
.64 .0194 Mdot
.64 .0196 Mdot
.64 .01973 Mdot
.64 .01989 Mdot
.64 .02006 Mdot
.64 .02038 Mdot
.64 .02071 Mdot
.64 .02097 Mdot
.64 .02113 Mdot
.64 .02134 Mdot
.64 .02155 Mdot
.64 .02196 Mdot
.64 .02239 Mdot
.64 .02251 Mdot
.64 .02272 Mdot
.64 .02293 Mdot
.64 .0232 Mdot
.64 .02336 Mdot
.64 .02347 Mdot
.64 .02364 Mdot
.64 .02399 Mdot
.64 .02454 Mdot
.64 .02469 Mdot
.64 .02479 Mdot
.64 .02496 Mdot
.64 .02523 Mdot
.64 .02542 Mdot
.64 .02557 Mdot
.64 .02577 Mdot
.64 .02592 Mdot
.64 .02614 Mdot
.64 .02659 Mdot
.64 .02668 Mdot
.64 .02729 Mdot
.64 .02749 Mdot
.64 .02761 Mdot
.64 .02783 Mdot
.64 .02818 Mdot
.64 .02842 Mdot
.64 .02861 Mdot
.64 .02881 Mdot
.64 .02887 Mdot
.64 .02905 Mdot
.64 .02916 Mdot
.64 .02933 Mdot
.64 .02991 Mdot
.64 .03003 Mdot
.64 .03035 Mdot
.64 .03081 Mdot
.64 .03081 Mdot
.64 .03106 Mdot
.64 .03116 Mdot
.64 .03122 Mdot
.64 .0315 Mdot
.64 .03154 Mdot
.64 .03186 Mdot
.64 .03195 Mdot
.64 .03226 Mdot
.64 .0325 Mdot
.64 .03275 Mdot
.64 .03283 Mdot
.64 .03307 Mdot
.64 .0332 Mdot
.64 .03343 Mdot
.64 .03374 Mdot
.64 .03417 Mdot
.64 .03431 Mdot
.64 .03468 Mdot
.64 .03473 Mdot
.64 .03474 Mdot
.64 .03531 Mdot
.64 .03532 Mdot
.64 .03564 Mdot
.64 .03577 Mdot
.64 .03584 Mdot
.64 .0362 Mdot
.64 .03626 Mdot
.64 .03666 Mdot
.64 .03677 Mdot
.64 .03717 Mdot
.64 .03748 Mdot
.64 .0378 Mdot
.64 .03791 Mdot
.64 .0381 Mdot
.64 .03821 Mdot
.64 .03837 Mdot
.64 .03867 Mdot
.64 .03907 Mdot
.64 .03951 Mdot
.64 .03962 Mdot
.64 .03979 Mdot
.64 .0398 Mdot
.64 .04028 Mdot
.64 .04033 Mdot
.64 .04035 Mdot
.64 .04102 Mdot
.64 .04108 Mdot
.64 .04109 Mdot
.64 .0415 Mdot
.64 .04167 Mdot
.64 .04175 Mdot
.64 .04221 Mdot
.64 .04229 Mdot
.64 .04281 Mdot
.64 .04295 Mdot
.64 .04346 Mdot
.64 .04352 Mdot
.64 .04359 Mdot
.64 .04384 Mdot
.64 .04386 Mdot
.64 .04426 Mdot
.64 .0444 Mdot
.64 .04465 Mdot
.64 .04479 Mdot
.64 .04485 Mdot
.64 .045 Mdot
.64 .04537 Mdot
.64 .04581 Mdot
.64 .04589 Mdot
.64 .04646 Mdot
.64 .04659 Mdot
.64 .04681 Mdot
.64 .04682 Mdot
.64 .04743 Mdot
.64 .0475 Mdot
.64 .04753 Mdot
.64 .04768 Mdot
.64 .04779 Mdot
.64 .0481 Mdot
.64 .0482 Mdot
.64 .04838 Mdot
.64 .04846 Mdot
.64 .04847 Mdot
.64 .049 Mdot
.64 .04921 Mdot
.64 .04933 Mdot
.64 .04991 Mdot
.64 .05001 Mdot
.64 .05067 Mdot
.64 .05085 Mdot
.64 .05089 Mdot
.64 .05151 Mdot
.64 .05159 Mdot
.64 .05168 Mdot
.64 .0518 Mdot
.64 .05199 Mdot
.64 .05202 Mdot
.64 .05215 Mdot
.64 .05254 Mdot
.64 .05272 Mdot
.64 .05291 Mdot
.64 .05303 Mdot
.64 .05321 Mdot
.64 .05329 Mdot
.64 .05348 Mdot
.64 .05372 Mdot
.64 .05396 Mdot
.64 .05451 Mdot
.64 .05462 Mdot
.64 .05471 Mdot
.64 .05535 Mdot
.64 .05551 Mdot
.64 .0558 Mdot
.64 .05582 Mdot
.64 .05587 Mdot
.64 .05659 Mdot
.64 .05669 Mdot
.64 .05672 Mdot
.64 .05691 Mdot
.64 .05705 Mdot
.64 .05744 Mdot
.64 .05749 Mdot
.64 .05757 Mdot
.64 .05781 Mdot
.64 .05791 Mdot
.64 .05792 Mdot
.64 .0586 Mdot
.64 .05887 Mdot
.64 .05902 Mdot
.64 .05932 Mdot
.64 .05977 Mdot
.64 .05989 Mdot
.64 .06021 Mdot
.64 .06074 Mdot
.64 .06075 Mdot
.64 .06083 Mdot
.64 .06097 Mdot
.64 .06102 Mdot
.64 .06182 Mdot
.64 .06191 Mdot
.64 .06203 Mdot
.64 .06209 Mdot
.64 .06218 Mdot
.64 .06243 Mdot
.64 .06246 Mdot
.64 .06263 Mdot
.64 .06289 Mdot
.64 .06313 Mdot
.64 .06332 Mdot
.64 .06335 Mdot
.64 .0636 Mdot
.64 .06368 Mdot
.64 .06376 Mdot
.64 .06395 Mdot
.64 .06399 Mdot
.64 .0641 Mdot
.64 .06433 Mdot
.64 .06464 Mdot
.64 .06495 Mdot
.64 .06566 Mdot
.64 .06579 Mdot
.64 .0659 Mdot
.64 .06672 Mdot
.64 .06694 Mdot
.64 .0673 Mdot
.64 .06732 Mdot
.64 .06739 Mdot
.64 .06832 Mdot
.64 .06844 Mdot
.64 .06848 Mdot
.64 .06872 Mdot
.64 .0689 Mdot
.64 .06941 Mdot
.64 .06947 Mdot
.64 .06957 Mdot
.64 .06962 Mdot
.64 .06988 Mdot
.64 .07001 Mdot
.64 .07002 Mdot
.64 .07068 Mdot
.64 .07089 Mdot
.64 .07124 Mdot
.64 .07142 Mdot
.64 .07155 Mdot
.64 .07181 Mdot
.64 .07226 Mdot
.64 .07238 Mdot
.64 .07254 Mdot
.64 .07265 Mdot
.64 .07295 Mdot
.64 .07318 Mdot
.64 .07363 Mdot
.64 .07364 Mdot
.64 .07374 Mdot
.64 .07392 Mdot
.64 .07398 Mdot
.64 .07403 Mdot
.64 .07501 Mdot
.64 .07513 Mdot
.64 .07528 Mdot
.64 .07535 Mdot
.64 .07547 Mdot
.64 .07579 Mdot
.64 .07583 Mdot
.64 .07604 Mdot
.64 .07633 Mdot
.64 .07638 Mdot
.64 .07662 Mdot
.64 .07668 Mdot
.64 .07692 Mdot
.64 .07697 Mdot
.64 .07729 Mdot
.64 .07739 Mdot
.64 .07749 Mdot
.64 .07774 Mdot
.64 .07778 Mdot
.64 .07792 Mdot
.64 .07817 Mdot
.64 .07823 Mdot
.64 .07861 Mdot
.64 .07901 Mdot
.64 .07963 Mdot
.64 .07992 Mdot
.64 .08009 Mdot
.64 .08022 Mdot
.64 .08024 Mdot
.64 .08059 Mdot
.64 .08129 Mdot
.64 .08144 Mdot
.64 .08156 Mdot
.64 .08196 Mdot
.64 .08202 Mdot
.64 .08205 Mdot
.64 .08214 Mdot
.64 .0823 Mdot
.64 .08278 Mdot
.64 .08333 Mdot
.64 .08348 Mdot
.64 .08353 Mdot
.64 .08385 Mdot
.64 .08407 Mdot
.64 .08451 Mdot
.64 .08472 Mdot
.64 .0848 Mdot
.64 .08487 Mdot
.64 .08493 Mdot
.64 .08499 Mdot
.64 .08533 Mdot
.64 .08549 Mdot
.64 .0855 Mdot
.64 .08635 Mdot
.64 .0864 Mdot
.64 .08662 Mdot
.64 .08706 Mdot
.64 .08712 Mdot
.64 .0873 Mdot
.64 .08747 Mdot
.64 .0878 Mdot
.64 .08788 Mdot
.64 .08837 Mdot
.64 .08853 Mdot
.64 .08859 Mdot
.64 .08873 Mdot
.64 .08887 Mdot
.64 .08905 Mdot
.64 .08926 Mdot
.64 .08954 Mdot
.64 .09003 Mdot
.64 .09012 Mdot
.64 .09014 Mdot
.64 .09036 Mdot
.64 .0905 Mdot
.64 .09058 Mdot
.64 .09064 Mdot
.64 .09069 Mdot
.64 .0917 Mdot
.64 .09189 Mdot
.64 .09204 Mdot
.64 .09224 Mdot
.64 .09233 Mdot
.64 .09248 Mdot
.64 .09289 Mdot
.64 .09294 Mdot
.64 .09322 Mdot
.64 .09348 Mdot
.64 .09358 Mdot
.64 .09365 Mdot
.64 .09389 Mdot
.64 .09395 Mdot
.64 .09404 Mdot
.64 .09434 Mdot
.64 .09441 Mdot
.64 .09481 Mdot
.64 .09494 Mdot
.64 .09507 Mdot
.64 .09515 Mdot
.64 .09538 Mdot
.64 .09544 Mdot
.64 .09562 Mdot
.64 .09594 Mdot
.64 .09601 Mdot
.64 .0965 Mdot
.64 .09668 Mdot
.64 .09702 Mdot
.64 .09764 Mdot
.64 .0978 Mdot
.64 .09818 Mdot
.64 .0984 Mdot
.64 .09857 Mdot
.64 .09858 Mdot
.64 .09903 Mdot
.64 .09956 Mdot
.64 .09993 Mdot
.64 .10013 Mdot
.64 .10027 Mdot
.64 .10048 Mdot
.64 .10078 Mdot
.64 .10087 Mdot
.64 .10091 Mdot
.64 .10102 Mdot
.64 .10122 Mdot
.64 .10183 Mdot
.64 .10254 Mdot
.64 .10273 Mdot
.64 .1028 Mdot
.64 .10306 Mdot
.64 .1032 Mdot
.64 .10349 Mdot
.64 .10397 Mdot
.64 .10405 Mdot
.64 .10432 Mdot
.64 .10443 Mdot
.64 .10451 Mdot
.64 .1046 Mdot
.64 .10467 Mdot
.64 .1051 Mdot
.64 .10531 Mdot
.64 .10532 Mdot
.64 .10609 Mdot
.64 .10641 Mdot
.64 .10647 Mdot
.64 .10675 Mdot
.64 .10732 Mdot
.64 .10734 Mdot
.64 .10739 Mdot
.64 .10762 Mdot
.64 .10784 Mdot
.64 .10826 Mdot
.64 .10829 Mdot
.64 .10836 Mdot
.64 .10838 Mdot
.64 .10899 Mdot
.64 .1092 Mdot
.64 .10928 Mdot
.64 .10945 Mdot
.64 .10964 Mdot
.64 .10986 Mdot
.64 .11013 Mdot
.64 .1105 Mdot
.64 .11091 Mdot
.64 .11111 Mdot
.64 .11124 Mdot
.64 .11125 Mdot
.64 .11154 Mdot
.64 .11172 Mdot
.64 .11182 Mdot
.64 .1119 Mdot
.64 .11196 Mdot
.64 .11325 Mdot
.64 .11349 Mdot
.64 .11369 Mdot
.64 .11385 Mdot
.64 .11394 Mdot
.64 .11406 Mdot
.64 .11426 Mdot
.64 .11478 Mdot
.64 .11484 Mdot
.64 .1152 Mdot
.64 .11553 Mdot
.64 .11566 Mdot
.64 .11575 Mdot
.64 .11594 Mdot
.64 .11606 Mdot
.64 .11614 Mdot
.64 .11625 Mdot
.64 .11664 Mdot
.64 .11672 Mdot
.64 .11707 Mdot
.64 .11723 Mdot
.64 .1174 Mdot
.64 .11757 Mdot
.64 .11767 Mdot
.64 .11789 Mdot
.64 .11797 Mdot
.64 .11804 Mdot
.64 .11827 Mdot
.64 .11868 Mdot
.64 .11877 Mdot
.64 .11906 Mdot
.64 .11941 Mdot
.64 .11962 Mdot
.64 .12006 Mdot
.64 .12086 Mdot
.64 .12106 Mdot
.64 .12155 Mdot
.64 .12183 Mdot
.64 .12205 Mdot
.64 .12207 Mdot
.64 .12264 Mdot
.64 .12331 Mdot
.64 .12379 Mdot
.64 .12404 Mdot
.64 .12423 Mdot
.64 .12449 Mdot
.64 .12488 Mdot
.64 .12499 Mdot
.64 .12504 Mdot
.64 .12519 Mdot
.64 .12544 Mdot
.64 .12623 Mdot
.64 .12713 Mdot
.64 .12738 Mdot
.64 .12746 Mdot
.64 .1278 Mdot
.64 .12798 Mdot
.64 .12835 Mdot
.64 .12897 Mdot
.64 .12907 Mdot
.64 .12942 Mdot
.64 .12955 Mdot
.64 .12965 Mdot
.64 .12976 Mdot
.64 .12985 Mdot
.64 .1304 Mdot
.64 .13068 Mdot
.64 .13069 Mdot
.64 .13167 Mdot
.64 .13208 Mdot
.64 .13216 Mdot
.64 .13252 Mdot
.64 .13325 Mdot
.64 .13327 Mdot
.64 .13334 Mdot
.64 .13364 Mdot
.64 .13391 Mdot
.64 .13446 Mdot
.64 .13449 Mdot
.64 .13458 Mdot
.64 .13461 Mdot
.64 .13539 Mdot
.64 .13566 Mdot
.64 .13576 Mdot
.64 .13598 Mdot
.64 .13622 Mdot
.64 .1365 Mdot
.64 .13684 Mdot
.64 .13732 Mdot
.64 .13785 Mdot
.64 .13811 Mdot
.64 .13826 Mdot
.64 .13829 Mdot
.64 .13865 Mdot
.64 .13889 Mdot
.64 .13901 Mdot
.64 .13912 Mdot
.64 .13919 Mdot
.64 .14084 Mdot
.64 .14115 Mdot
.64 .14141 Mdot
.64 .14161 Mdot
.64 .14173 Mdot
.64 .14188 Mdot
.64 .14213 Mdot
.64 .1428 Mdot
.64 .14288 Mdot
.64 .14333 Mdot
.64 .14376 Mdot
.64 .14393 Mdot
.64 .14404 Mdot
.64 .14429 Mdot
.64 .14443 Mdot
.64 .14453 Mdot
.64 .14467 Mdot
.64 .14518 Mdot
.64 .14528 Mdot
.64 .14573 Mdot
.64 .14594 Mdot
.64 .14616 Mdot
.64 .14637 Mdot
.64 .1465 Mdot
.64 .14678 Mdot
.64 .14688 Mdot
.64 .14698 Mdot
.64 .14727 Mdot
.64 .14779 Mdot
.64 .14791 Mdot
.64 .14827 Mdot
.64 .14872 Mdot
.64 .149 Mdot
.64 .14956 Mdot
.64 .15058 Mdot
.64 .15084 Mdot
.64 .15146 Mdot
.64 .15182 Mdot
.64 .1521 Mdot
.64 .15213 Mdot
.64 .15286 Mdot
.64 .15372 Mdot
.64 .15433 Mdot
.64 .15465 Mdot
.64 .15489 Mdot
.64 .15523 Mdot
.64 .15573 Mdot
.64 .15587 Mdot
.64 .15594 Mdot
.64 .15612 Mdot
.64 .15645 Mdot
.64 .15745 Mdot
.64 .15861 Mdot
.64 .15893 Mdot
.64 .15903 Mdot
.64 .15946 Mdot
.64 .1597 Mdot
.64 .16016 Mdot
.64 .16096 Mdot
.64 .16109 Mdot
.64 .16153 Mdot
.64 .1617 Mdot
.64 .16183 Mdot
.64 .16198 Mdot
.64 .16209 Mdot
.64 .1628 Mdot
.64 .16315 Mdot
.64 .16317 Mdot
.64 .16442 Mdot
.64 .16495 Mdot
.64 .16505 Mdot
.64 .16551 Mdot
.64 .16644 Mdot
.64 .16647 Mdot
.64 .16656 Mdot
.64 .16693 Mdot
.64 .16729 Mdot
.64 .16799 Mdot
.64 .16803 Mdot
.64 .16814 Mdot
.64 .16818 Mdot
.64 .16918 Mdot
.64 .16952 Mdot
.64 .16965 Mdot
.64 .16993 Mdot
.64 .17024 Mdot
.64 .1706 Mdot
.64 .17104 Mdot
.64 .17164 Mdot
.64 .17232 Mdot
.64 .17266 Mdot
.64 .17286 Mdot
.64 .17289 Mdot
.64 .17335 Mdot
.64 .17365 Mdot
.64 .17381 Mdot
.64 .17395 Mdot
.64 .17405 Mdot
.64 .17616 Mdot
.64 .17656 Mdot
.64 .17688 Mdot
.64 .17714 Mdot
.64 .17729 Mdot
.64 .17748 Mdot
.64 .1778 Mdot
.64 .17866 Mdot
.64 .17877 Mdot
.64 .17935 Mdot
.64 .17989 Mdot
.64 .18011 Mdot
.64 .18025 Mdot
.64 .18056 Mdot
.64 .18076 Mdot
.64 .18088 Mdot
.64 .18106 Mdot
.64 .18171 Mdot
.64 .18184 Mdot
.64 .18241 Mdot
.64 .18268 Mdot
.64 .18296 Mdot
.64 .18323 Mdot
.64 .1834 Mdot
.64 .18376 Mdot
.64 .18389 Mdot
.64 .18401 Mdot
.64 .18439 Mdot
.64 .18505 Mdot
.64 .1852 Mdot
.64 .18567 Mdot
.64 .18624 Mdot
.64 .1866 Mdot
.64 .18731 Mdot
.64 .18862 Mdot
.64 .18896 Mdot
.64 .18975 Mdot
.64 .19021 Mdot
.64 .19057 Mdot
.64 .1906 Mdot
.64 .19154 Mdot
.64 .19264 Mdot
.64 .19342 Mdot
.64 .19384 Mdot
.64 .19414 Mdot
.64 .19458 Mdot
.64 .19521 Mdot
.64 .19539 Mdot
.64 .19548 Mdot
.64 .19571 Mdot
.64 .19613 Mdot
.64 .19742 Mdot
.64 .1989 Mdot
.64 .1993 Mdot
.64 .19944 Mdot
.64 .19999 Mdot
.64 .20029 Mdot
.64 .20089 Mdot
.64 .2019 Mdot
.64 .20207 Mdot
.64 .20264 Mdot
.64 .20286 Mdot
.64 .20303 Mdot
.64 .20321 Mdot
.64 .20336 Mdot
.64 .20426 Mdot
.64 .20471 Mdot
.64 .20473 Mdot
.64 .20634 Mdot
.64 .20701 Mdot
.64 .20714 Mdot
.64 .20773 Mdot
.64 .20892 Mdot
.64 .20896 Mdot
.64 .20907 Mdot
.64 .20956 Mdot
.64 .21001 Mdot
.64 .2109 Mdot
.64 .21095 Mdot
.64 .2111 Mdot
.64 .21115 Mdot
.64 .21243 Mdot
.64 .21287 Mdot
.64 .21303 Mdot
.64 .2134 Mdot
.64 .21378 Mdot
.64 .21425 Mdot
.64 .21481 Mdot
.64 .21558 Mdot
.64 .21646 Mdot
.64 .21688 Mdot
.64 .21714 Mdot
.64 .21717 Mdot
.64 .21777 Mdot
.64 .21816 Mdot
.64 .21836 Mdot
.64 .21853 Mdot
.64 .21866 Mdot
.64 .22136 Mdot
.64 .22187 Mdot
.64 .22229 Mdot
.64 .22262 Mdot
.64 .22281 Mdot
.64 .22306 Mdot
.64 .22347 Mdot
.64 .22456 Mdot
.64 .2247 Mdot
.64 .22544 Mdot
.64 .22614 Mdot
.64 .22642 Mdot
.64 .2266 Mdot
.64 .227 Mdot
.64 .22725 Mdot
.64 .22741 Mdot
.64 .22764 Mdot
.64 .22847 Mdot
.64 .22864 Mdot
.64 .22937 Mdot
.64 .22971 Mdot
.64 .23007 Mdot
.64 .23041 Mdot
.64 .23063 Mdot
.64 .2311 Mdot
.64 .23125 Mdot
.64 .23141 Mdot
.64 .23189 Mdot
.64 .23274 Mdot
.64 .23294 Mdot
.64 .23354 Mdot
.64 .23427 Mdot
.64 .23473 Mdot
.64 .23564 Mdot
.64 .23731 Mdot
.64 .23775 Mdot
.64 .23875 Mdot
.64 .23935 Mdot
.64 .2398 Mdot
.64 .23985 Mdot
.64 .24105 Mdot
.64 .24246 Mdot
.64 .24345 Mdot
.64 .24399 Mdot
.64 .24438 Mdot
.64 .24494 Mdot
.64 .24575 Mdot
.64 .24598 Mdot
.64 .24609 Mdot
.64 .24639 Mdot
.64 .24693 Mdot
.64 .24858 Mdot
.64 .25047 Mdot
.64 .25099 Mdot
.64 .25116 Mdot
.64 .25186 Mdot
.64 .25225 Mdot
.64 .25302 Mdot
.64 .25432 Mdot
.64 .25453 Mdot
.64 .25526 Mdot
.64 .25554 Mdot
.64 .25576 Mdot
.64 .25599 Mdot
.64 .25618 Mdot
.64 .25733 Mdot
.64 .2579 Mdot
.64 .25794 Mdot
.64 .25999 Mdot
.64 .26085 Mdot
.64 .26102 Mdot
.64 .26177 Mdot
.64 .2633 Mdot
.64 .26334 Mdot
.64 .26349 Mdot
.64 .26411 Mdot
.64 .26469 Mdot
.64 .26584 Mdot
.64 .2659 Mdot
.64 .26609 Mdot
.64 .26615 Mdot
.64 .2678 Mdot
.64 .26835 Mdot
.64 .26856 Mdot
.64 .26903 Mdot
.64 .26952 Mdot
.64 .27012 Mdot
.64 .27083 Mdot
.64 .27183 Mdot
.64 .27294 Mdot
.64 .27348 Mdot
.64 .27381 Mdot
.64 .27386 Mdot
.64 .27463 Mdot
.64 .27512 Mdot
.64 .27538 Mdot
.64 .2756 Mdot
.64 .27577 Mdot
.64 .27923 Mdot
.64 .27987 Mdot
.64 .28041 Mdot
.64 .28084 Mdot
.64 .28108 Mdot
.64 .2814 Mdot
.64 .28192 Mdot
.64 .28332 Mdot
.64 .2835 Mdot
.64 .28444 Mdot
.64 .28533 Mdot
.64 .2857 Mdot
.64 .28592 Mdot
.64 .28644 Mdot
.64 .28676 Mdot
.64 .28697 Mdot
.64 .28726 Mdot
.64 .28832 Mdot
.64 .28853 Mdot
.64 .28947 Mdot
.64 .28991 Mdot
.64 .29037 Mdot
.64 .29081 Mdot
.64 .29109 Mdot
.64 .29168 Mdot
.64 .29189 Mdot
.64 .29209 Mdot
.64 .2927 Mdot
.64 .29379 Mdot
.64 .29404 Mdot
.64 .29481 Mdot
.64 .29574 Mdot
.64 .29633 Mdot
.64 .2975 Mdot
.64 .29964 Mdot
.64 .30019 Mdot
.64 .30148 Mdot
.64 .30225 Mdot
.64 .30283 Mdot
.64 .30289 Mdot
.64 .30443 Mdot
.64 .30623 Mdot
.64 .3075 Mdot
.64 .30819 Mdot
.64 .30869 Mdot
.64 .3094 Mdot
.64 .31044 Mdot
.64 .31074 Mdot
.64 .31088 Mdot
.64 .31126 Mdot
.64 .31195 Mdot
.64 .31406 Mdot
.64 .31649 Mdot
.64 .31715 Mdot
.64 .31737 Mdot
.64 .31827 Mdot
.64 .31876 Mdot
.64 .31974 Mdot
.64 .3214 Mdot
.64 .32168 Mdot
.64 .32261 Mdot
.64 .32297 Mdot
.64 .32325 Mdot
.64 .32354 Mdot
.64 .32379 Mdot
.64 .32526 Mdot
.64 .326 Mdot
.64 .32604 Mdot
.64 .32867 Mdot
.64 .32977 Mdot
.64 .32999 Mdot
.64 .33095 Mdot
.64 .3329 Mdot
.64 .33296 Mdot
.64 .33315 Mdot
.64 .33394 Mdot
.64 .33469 Mdot
.64 .33615 Mdot
.64 .33623 Mdot
.64 .33648 Mdot
.64 .33655 Mdot
.64 .33866 Mdot
.64 .33937 Mdot
.64 .33964 Mdot
.64 .34023 Mdot
.64 .34086 Mdot
.64 .34164 Mdot
.64 .34255 Mdot
.64 .34382 Mdot
.64 .34525 Mdot
.64 .34594 Mdot
.64 .34636 Mdot
.64 .34642 Mdot
.64 .34741 Mdot
.64 .34803 Mdot
.64 .34837 Mdot
.64 .34865 Mdot
.64 .34886 Mdot
.64 .35329 Mdot
.64 .35412 Mdot
.64 .3548 Mdot
.64 .35535 Mdot
.64 .35566 Mdot
.64 .35607 Mdot
.64 .35674 Mdot
.64 .35853 Mdot
.64 .35876 Mdot
.64 .35997 Mdot
.64 .36111 Mdot
.64 .36158 Mdot
.64 .36186 Mdot
.64 .36253 Mdot
.64 .36293 Mdot
.64 .3632 Mdot
.64 .36357 Mdot
.64 .36492 Mdot
.64 .3652 Mdot
.64 .3664 Mdot
.64 .36696 Mdot
.64 .36755 Mdot
.64 .36811 Mdot
.64 .36847 Mdot
.64 .36923 Mdot
.64 .36949 Mdot
.64 .36975 Mdot
.64 .37054 Mdot
.64 .37193 Mdot
.64 .37225 Mdot
.64 .37324 Mdot
.64 .37443 Mdot
.64 .37518 Mdot
.64 .37668 Mdot
.64 .37942 Mdot
.64 .38013 Mdot
.64 .38178 Mdot
.64 .38276 Mdot
.64 .3835 Mdot
.64 .38357 Mdot
.64 .38555 Mdot
.64 .38785 Mdot
.64 .38948 Mdot
.64 .39036 Mdot
.64 .391 Mdot
.64 .39191 Mdot
.642 .01543 Mdot
.642 .01563 Mdot
.642 .01589 Mdot
.642 .01623 Mdot
.642 .01666 Mdot
.642 .01721 Mdot
.642 .01792 Mdot
.642 .0182 Mdot
.642 .01882 Mdot
.642 .01897 Mdot
.642 .01919 Mdot
.642 .01961 Mdot
.642 .01999 Mdot
.642 .02018 Mdot
.642 .02046 Mdot
.642 .021 Mdot
.642 .02149 Mdot
.642 .02173 Mdot
.642 .02209 Mdot
.642 .02228 Mdot
.642 .02249 Mdot
.642 .02278 Mdot
.642 .02325 Mdot
.642 .02341 Mdot
.642 .02373 Mdot
.642 .02395 Mdot
.642 .02418 Mdot
.642 .02443 Mdot
.642 .02457 Mdot
.642 .0247 Mdot
.642 .02508 Mdot
.642 .02568 Mdot
.642 .02568 Mdot
.642 .02588 Mdot
.642 .02629 Mdot
.642 .02657 Mdot
.642 .02673 Mdot
.642 .02687 Mdot
.642 .02697 Mdot
.642 .02718 Mdot
.642 .02737 Mdot
.642 .02753 Mdot
.642 .02759 Mdot
.642 .02783 Mdot
.642 .02802 Mdot
.642 .02879 Mdot
.642 .02879 Mdot
.642 .02906 Mdot
.642 .02933 Mdot
.642 .02957 Mdot
.642 .02994 Mdot
.642 .03014 Mdot
.642 .03032 Mdot
.642 .03037 Mdot
.642 .03045 Mdot
.642 .03072 Mdot
.642 .03082 Mdot
.642 .03097 Mdot
.642 .03117 Mdot
.642 .03125 Mdot
.642 .03156 Mdot
.642 .0318 Mdot
.642 .03237 Mdot
.642 .03252 Mdot
.642 .03276 Mdot
.642 .03279 Mdot
.642 .03279 Mdot
.642 .03313 Mdot
.642 .0334 Mdot
.642 .03348 Mdot
.642 .03379 Mdot
.642 .03387 Mdot
.642 .03426 Mdot
.642 .03452 Mdot
.642 .03475 Mdot
.642 .03482 Mdot
.642 .03492 Mdot
.642 .03527 Mdot
.642 .03539 Mdot
.642 .03558 Mdot
.642 .03585 Mdot
.642 .03594 Mdot
.642 .03634 Mdot
.642 .03665 Mdot
.642 .03735 Mdot
.642 .03739 Mdot
.642 .03758 Mdot
.642 .03789 Mdot
.642 .03792 Mdot
.642 .03793 Mdot
.642 .03816 Mdot
.642 .03836 Mdot
.642 .03841 Mdot
.642 .03871 Mdot
.642 .03881 Mdot
.642 .03881 Mdot
.642 .03921 Mdot
.642 .0393 Mdot
.642 .03981 Mdot
.642 .04014 Mdot
.642 .04044 Mdot
.642 .04053 Mdot
.642 .04065 Mdot
.642 .04074 Mdot
.642 .04111 Mdot
.642 .04126 Mdot
.642 .04151 Mdot
.642 .04185 Mdot
.642 .04197 Mdot
.642 .04204 Mdot
.642 .04248 Mdot
.642 .04288 Mdot
.642 .04316 Mdot
.642 .04377 Mdot
.642 .04383 Mdot
.642 .04407 Mdot
.642 .04447 Mdot
.642 .04452 Mdot
.642 .04452 Mdot
.642 .04481 Mdot
.642 .04507 Mdot
.642 .04514 Mdot
.642 .04552 Mdot
.642 .04566 Mdot
.642 .04566 Mdot
.642 .04617 Mdot
.642 .04629 Mdot
.642 .04664 Mdot
.642 .04694 Mdot
.642 .04737 Mdot
.642 .04774 Mdot
.642 .04783 Mdot
.642 .04786 Mdot
.642 .04802 Mdot
.642 .04813 Mdot
.642 .0486 Mdot
.642 .0488 Mdot
.642 .04912 Mdot
.642 .04955 Mdot
.642 .04971 Mdot
.642 .0498 Mdot
.642 .05023 Mdot
.642 .05036 Mdot
.642 .05087 Mdot
.642 .05087 Mdot
.642 .05124 Mdot
.642 .05203 Mdot
.642 .0521 Mdot
.642 .0524 Mdot
.642 .05292 Mdot
.642 .05298 Mdot
.642 .05298 Mdot
.642 .05336 Mdot
.642 .05369 Mdot
.642 .05377 Mdot
.642 .05378 Mdot
.642 .0541 Mdot
.642 .05427 Mdot
.642 .05444 Mdot
.642 .05445 Mdot
.642 .0551 Mdot
.642 .05525 Mdot
.642 .05564 Mdot
.642 .05571 Mdot
.642 .05609 Mdot
.642 .05664 Mdot
.642 .05712 Mdot
.642 .05724 Mdot
.642 .05728 Mdot
.642 .05748 Mdot
.642 .05762 Mdot
.642 .05823 Mdot
.642 .05848 Mdot
.642 .05889 Mdot
.642 .05905 Mdot
.642 .05941 Mdot
.642 .05945 Mdot
.642 .05965 Mdot
.642 .05977 Mdot
.642 .06031 Mdot
.642 .06049 Mdot
.642 .06114 Mdot
.642 .06114 Mdot
.642 .06123 Mdot
.642 .0613 Mdot
.642 .06161 Mdot
.642 .06241 Mdot
.642 .06262 Mdot
.642 .06271 Mdot
.642 .06311 Mdot
.642 .06377 Mdot
.642 .06385 Mdot
.642 .06385 Mdot
.642 .06434 Mdot
.642 .06476 Mdot
.642 .06486 Mdot
.642 .06487 Mdot
.642 .06522 Mdot
.642 .06528 Mdot
.642 .06528 Mdot
.642 .06543 Mdot
.642 .06548 Mdot
.642 .0655 Mdot
.642 .06573 Mdot
.642 .06573 Mdot
.642 .06593 Mdot
.642 .06596 Mdot
.642 .06658 Mdot
.642 .06677 Mdot
.642 .06726 Mdot
.642 .06735 Mdot
.642 .06759 Mdot
.642 .06773 Mdot
.642 .06785 Mdot
.642 .06828 Mdot
.642 .06849 Mdot
.642 .06855 Mdot
.642 .0687 Mdot
.642 .06917 Mdot
.642 .06928 Mdot
.642 .06931 Mdot
.642 .06937 Mdot
.642 .06963 Mdot
.642 .0698 Mdot
.642 .07043 Mdot
.642 .07059 Mdot
.642 .07091 Mdot
.642 .071 Mdot
.642 .07143 Mdot
.642 .07164 Mdot
.642 .07211 Mdot
.642 .07215 Mdot
.642 .07241 Mdot
.642 .07256 Mdot
.642 .07326 Mdot
.642 .07349 Mdot
.642 .07433 Mdot
.642 .07433 Mdot
.642 .07444 Mdot
.642 .07453 Mdot
.642 .07493 Mdot
.642 .07545 Mdot
.642 .07547 Mdot
.642 .07595 Mdot
.642 .07623 Mdot
.642 .0763 Mdot
.642 .07635 Mdot
.642 .07685 Mdot
.642 .07694 Mdot
.642 .07742 Mdot
.642 .0777 Mdot
.642 .0778 Mdot
.642 .07781 Mdot
.642 .07843 Mdot
.642 .07898 Mdot
.642 .0791 Mdot
.642 .07912 Mdot
.642 .07917 Mdot
.642 .07919 Mdot
.642 .07957 Mdot
.642 .07964 Mdot
.642 .07964 Mdot
.642 .07983 Mdot
.642 .07989 Mdot
.642 .0799 Mdot
.642 .07993 Mdot
.642 .08021 Mdot
.642 .08022 Mdot
.642 .08047 Mdot
.642 .08051 Mdot
.642 .08082 Mdot
.642 .0813 Mdot
.642 .08155 Mdot
.642 .08218 Mdot
.642 .0823 Mdot
.642 .0826 Mdot
.642 .08279 Mdot
.642 .08294 Mdot
.642 .08308 Mdot
.642 .08324 Mdot
.642 .08342 Mdot
.642 .0835 Mdot
.642 .08377 Mdot
.642 .08379 Mdot
.642 .08383 Mdot
.642 .08395 Mdot
.642 .08403 Mdot
.642 .08463 Mdot
.642 .08477 Mdot
.642 .08482 Mdot
.642 .08489 Mdot
.642 .08522 Mdot
.642 .08545 Mdot
.642 .08625 Mdot
.642 .08645 Mdot
.642 .08687 Mdot
.642 .08698 Mdot
.642 .08749 Mdot
.642 .08754 Mdot
.642 .08781 Mdot
.642 .0884 Mdot
.642 .08847 Mdot
.642 .08879 Mdot
.642 .08899 Mdot
.642 .08949 Mdot
.642 .08951 Mdot
.642 .08989 Mdot
.642 .09004 Mdot
.642 .09008 Mdot
.642 .09018 Mdot
.642 .09038 Mdot
.642 .09125 Mdot
.642 .09126 Mdot
.642 .0914 Mdot
.642 .09151 Mdot
.642 .0916 Mdot
.642 .0919 Mdot
.642 .0919 Mdot
.642 .09203 Mdot
.642 .09264 Mdot
.642 .0927 Mdot
.642 .09273 Mdot
.642 .09335 Mdot
.642 .0937 Mdot
.642 .09379 Mdot
.642 .09385 Mdot
.642 .09411 Mdot
.642 .0945 Mdot
.642 .09462 Mdot
.642 .09479 Mdot
.642 .09523 Mdot
.642 .09559 Mdot
.642 .09572 Mdot
.642 .09572 Mdot
.642 .09581 Mdot
.642 .09653 Mdot
.642 .09723 Mdot
.642 .09738 Mdot
.642 .09741 Mdot
.642 .09748 Mdot
.642 .0975 Mdot
.642 .09799 Mdot
.642 .09807 Mdot
.642 .09808 Mdot
.642 .09832 Mdot
.642 .09835 Mdot
.642 .0984 Mdot
.642 .09842 Mdot
.642 .09845 Mdot
.642 .09881 Mdot
.642 .09882 Mdot
.642 .09915 Mdot
.642 .0992 Mdot
.642 .0996 Mdot
.642 .10021 Mdot
.642 .10039 Mdot
.642 .10053 Mdot
.642 .10113 Mdot
.642 .10117 Mdot
.642 .10134 Mdot
.642 .1015 Mdot
.642 .10164 Mdot
.642 .10188 Mdot
.642 .10212 Mdot
.642 .10217 Mdot
.642 .10231 Mdot
.642 .10236 Mdot
.642 .1027 Mdot
.642 .10293 Mdot
.642 .10303 Mdot
.642 .10338 Mdot
.642 .10341 Mdot
.642 .10346 Mdot
.642 .10361 Mdot
.642 .10371 Mdot
.642 .10449 Mdot
.642 .10467 Mdot
.642 .10473 Mdot
.642 .10482 Mdot
.642 .10524 Mdot
.642 .10554 Mdot
.642 .10578 Mdot
.642 .10656 Mdot
.642 .10683 Mdot
.642 .10736 Mdot
.642 .10751 Mdot
.642 .10815 Mdot
.642 .10823 Mdot
.642 .10857 Mdot
.642 .10933 Mdot
.642 .10941 Mdot
.642 .10982 Mdot
.642 .10983 Mdot
.642 .11008 Mdot
.642 .11071 Mdot
.642 .11072 Mdot
.642 .11075 Mdot
.642 .11077 Mdot
.642 .11087 Mdot
.642 .11124 Mdot
.642 .11127 Mdot
.642 .11139 Mdot
.642 .11144 Mdot
.642 .11148 Mdot
.642 .11161 Mdot
.642 .11187 Mdot
.642 .112 Mdot
.642 .11299 Mdot
.642 .113 Mdot
.642 .11318 Mdot
.642 .11332 Mdot
.642 .11343 Mdot
.642 .11382 Mdot
.642 .11383 Mdot
.642 .11398 Mdot
.642 .11419 Mdot
.642 .11469 Mdot
.642 .11473 Mdot
.642 .11477 Mdot
.642 .11485 Mdot
.642 .11489 Mdot
.642 .11568 Mdot
.642 .11612 Mdot
.642 .11613 Mdot
.642 .11625 Mdot
.642 .11626 Mdot
.642 .11632 Mdot
.642 .11659 Mdot
.642 .11666 Mdot
.642 .11666 Mdot
.642 .11683 Mdot
.642 .11716 Mdot
.642 .11731 Mdot
.642 .11753 Mdot
.642 .1181 Mdot
.642 .11856 Mdot
.642 .11872 Mdot
.642 .11873 Mdot
.642 .11883 Mdot
.642 .11895 Mdot
.642 .119 Mdot
.642 .11976 Mdot
.642 .12066 Mdot
.642 .12086 Mdot
.642 .12087 Mdot
.642 .12089 Mdot
.642 .12098 Mdot
.642 .12101 Mdot
.642 .12115 Mdot
.642 .12164 Mdot
.642 .12175 Mdot
.642 .12176 Mdot
.642 .12207 Mdot
.642 .1221 Mdot
.642 .12217 Mdot
.642 .12219 Mdot
.642 .12222 Mdot
.642 .1227 Mdot
.642 .12271 Mdot
.642 .12313 Mdot
.642 .12319 Mdot
.642 .1237 Mdot
.642 .1245 Mdot
.642 .12472 Mdot
.642 .1249 Mdot
.642 .12567 Mdot
.642 .12573 Mdot
.642 .12595 Mdot
.642 .12614 Mdot
.642 .12632 Mdot
.642 .12664 Mdot
.642 .12694 Mdot
.642 .12701 Mdot
.642 .12719 Mdot
.642 .12726 Mdot
.642 .12769 Mdot
.642 .12799 Mdot
.642 .12811 Mdot
.642 .12856 Mdot
.642 .1286 Mdot
.642 .12867 Mdot
.642 .12885 Mdot
.642 .12899 Mdot
.642 .12998 Mdot
.642 .13022 Mdot
.642 .13029 Mdot
.642 .1304 Mdot
.642 .13096 Mdot
.642 .13133 Mdot
.642 .13165 Mdot
.642 .13265 Mdot
.642 .13299 Mdot
.642 .13367 Mdot
.642 .13386 Mdot
.642 .13469 Mdot
.642 .13478 Mdot
.642 .13522 Mdot
.642 .1362 Mdot
.642 .13631 Mdot
.642 .13683 Mdot
.642 .13685 Mdot
.642 .13716 Mdot
.642 .13797 Mdot
.642 .13799 Mdot
.642 .13803 Mdot
.642 .13804 Mdot
.642 .13817 Mdot
.642 .13865 Mdot
.642 .13869 Mdot
.642 .13885 Mdot
.642 .13891 Mdot
.642 .13897 Mdot
.642 .13913 Mdot
.642 .13946 Mdot
.642 .13963 Mdot
.642 .1409 Mdot
.642 .14091 Mdot
.642 .14114 Mdot
.642 .14133 Mdot
.642 .14147 Mdot
.642 .14197 Mdot
.642 .14197 Mdot
.642 .14218 Mdot
.642 .14244 Mdot
.642 .14309 Mdot
.642 .14313 Mdot
.642 .14318 Mdot
.642 .14329 Mdot
.642 .14334 Mdot
.642 .14435 Mdot
.642 .14492 Mdot
.642 .14493 Mdot
.642 .14508 Mdot
.642 .14509 Mdot
.642 .14518 Mdot
.642 .14553 Mdot
.642 .14561 Mdot
.642 .14562 Mdot
.642 .14583 Mdot
.642 .14625 Mdot
.642 .14644 Mdot
.642 .14673 Mdot
.642 .14746 Mdot
.642 .14805 Mdot
.642 .14826 Mdot
.642 .14827 Mdot
.642 .1484 Mdot
.642 .14856 Mdot
.642 .14861 Mdot
.642 .14959 Mdot
.642 .15075 Mdot
.642 .151 Mdot
.642 .15102 Mdot
.642 .15105 Mdot
.642 .15116 Mdot
.642 .1512 Mdot
.642 .15137 Mdot
.642 .152 Mdot
.642 .15215 Mdot
.642 .15216 Mdot
.642 .15256 Mdot
.642 .15259 Mdot
.642 .15269 Mdot
.642 .15271 Mdot
.642 .15276 Mdot
.642 .15337 Mdot
.642 .15338 Mdot
.642 .15392 Mdot
.642 .15399 Mdot
.642 .15466 Mdot
.642 .15567 Mdot
.642 .15596 Mdot
.642 .15619 Mdot
.642 .15718 Mdot
.642 .15725 Mdot
.642 .15753 Mdot
.642 .15779 Mdot
.642 .15802 Mdot
.642 .15843 Mdot
.642 .15881 Mdot
.642 .1589 Mdot
.642 .15913 Mdot
.642 .15922 Mdot
.642 .15977 Mdot
.642 .16015 Mdot
.642 .16032 Mdot
.642 .16089 Mdot
.642 .16094 Mdot
.642 .16103 Mdot
.642 .16127 Mdot
.642 .16144 Mdot
.642 .16272 Mdot
.642 .16302 Mdot
.642 .16311 Mdot
.642 .16326 Mdot
.642 .16397 Mdot
.642 .16445 Mdot
.642 .16486 Mdot
.642 .16614 Mdot
.642 .16658 Mdot
.642 .16746 Mdot
.642 .1677 Mdot
.642 .16876 Mdot
.642 .16888 Mdot
.642 .16945 Mdot
.642 .1707 Mdot
.642 .17084 Mdot
.642 .17151 Mdot
.642 .17153 Mdot
.642 .17194 Mdot
.642 .17298 Mdot
.642 .173 Mdot
.642 .17305 Mdot
.642 .17307 Mdot
.642 .17324 Mdot
.642 .17385 Mdot
.642 .1739 Mdot
.642 .1741 Mdot
.642 .17418 Mdot
.642 .17425 Mdot
.642 .17447 Mdot
.642 .17489 Mdot
.642 .1751 Mdot
.642 .17674 Mdot
.642 .17675 Mdot
.642 .17705 Mdot
.642 .17729 Mdot
.642 .17746 Mdot
.642 .17811 Mdot
.642 .17811 Mdot
.642 .17838 Mdot
.642 .17871 Mdot
.642 .17955 Mdot
.642 .1796 Mdot
.642 .17967 Mdot
.642 .17981 Mdot
.642 .17986 Mdot
.642 .18117 Mdot
.642 .1819 Mdot
.642 .18191 Mdot
.642 .18211 Mdot
.642 .18212 Mdot
.642 .18223 Mdot
.642 .18268 Mdot
.642 .18279 Mdot
.642 .18279 Mdot
.642 .18306 Mdot
.642 .1836 Mdot
.642 .18385 Mdot
.642 .18423 Mdot
.642 .18516 Mdot
.642 .18591 Mdot
.642 .18618 Mdot
.642 .1862 Mdot
.642 .18637 Mdot
.642 .18657 Mdot
.642 .18664 Mdot
.642 .1879 Mdot
.642 .18938 Mdot
.642 .18971 Mdot
.642 .18973 Mdot
.642 .18977 Mdot
.642 .18992 Mdot
.642 .18996 Mdot
.642 .19018 Mdot
.642 .19099 Mdot
.642 .19118 Mdot
.642 .19119 Mdot
.642 .1917 Mdot
.642 .19175 Mdot
.642 .19188 Mdot
.642 .1919 Mdot
.642 .19196 Mdot
.642 .19274 Mdot
.642 .19276 Mdot
.642 .19345 Mdot
.642 .19355 Mdot
.642 .1944 Mdot
.642 .19571 Mdot
.642 .19607 Mdot
.642 .19637 Mdot
.642 .19763 Mdot
.642 .19773 Mdot
.642 .1981 Mdot
.642 .19842 Mdot
.642 .19872 Mdot
.642 .19924 Mdot
.642 .19974 Mdot
.642 .19985 Mdot
.642 .20014 Mdot
.642 .20026 Mdot
.642 .20097 Mdot
.642 .20146 Mdot
.642 .20167 Mdot
.642 .2024 Mdot
.642 .20247 Mdot
.642 .20259 Mdot
.642 .20289 Mdot
.642 .20311 Mdot
.642 .20475 Mdot
.642 .20514 Mdot
.642 .20526 Mdot
.642 .20545 Mdot
.642 .20635 Mdot
.642 .20697 Mdot
.642 .2075 Mdot
.642 .20914 Mdot
.642 .20971 Mdot
.642 .21084 Mdot
.642 .21114 Mdot
.642 .21251 Mdot
.642 .21267 Mdot
.642 .21339 Mdot
.642 .21501 Mdot
.642 .21518 Mdot
.642 .21604 Mdot
.642 .21607 Mdot
.642 .21659 Mdot
.642 .21792 Mdot
.642 .21795 Mdot
.642 .21802 Mdot
.642 .21804 Mdot
.642 .21825 Mdot
.642 .21904 Mdot
.642 .21911 Mdot
.642 .21937 Mdot
.642 .21947 Mdot
.642 .21956 Mdot
.642 .21984 Mdot
.642 .22038 Mdot
.642 .22065 Mdot
.642 .22275 Mdot
.642 .22276 Mdot
.642 .22315 Mdot
.642 .22346 Mdot
.642 .22369 Mdot
.642 .22451 Mdot
.642 .22452 Mdot
.642 .22486 Mdot
.642 .22529 Mdot
.642 .22636 Mdot
.642 .22643 Mdot
.642 .22652 Mdot
.642 .22669 Mdot
.642 .22677 Mdot
.642 .22844 Mdot
.642 .22938 Mdot
.642 .2294 Mdot
.642 .22965 Mdot
.642 .22966 Mdot
.642 .22981 Mdot
.642 .23038 Mdot
.642 .23052 Mdot
.642 .23053 Mdot
.642 .23087 Mdot
.642 .23157 Mdot
.642 .23189 Mdot
.642 .23237 Mdot
.642 .23357 Mdot
.642 .23453 Mdot
.642 .23488 Mdot
.642 .2349 Mdot
.642 .23512 Mdot
.642 .23538 Mdot
.642 .23547 Mdot
.642 .23708 Mdot
.642 .23899 Mdot
.642 .23941 Mdot
.642 .23944 Mdot
.642 .23948 Mdot
.642 .23967 Mdot
.642 .23973 Mdot
.642 .24002 Mdot
.642 .24105 Mdot
.642 .24129 Mdot
.642 .24131 Mdot
.642 .24197 Mdot
.642 .24203 Mdot
.642 .24219 Mdot
.642 .24222 Mdot
.642 .2423 Mdot
.642 .2433 Mdot
.642 .24332 Mdot
.642 .24421 Mdot
.642 .24434 Mdot
.642 .24543 Mdot
.642 .24711 Mdot
.642 .24758 Mdot
.642 .24796 Mdot
.642 .24958 Mdot
.642 .24971 Mdot
.642 .25018 Mdot
.642 .2506 Mdot
.642 .25098 Mdot
.642 .25165 Mdot
.642 .25228 Mdot
.642 .25243 Mdot
.642 .25281 Mdot
.642 .25295 Mdot
.642 .25386 Mdot
.642 .25449 Mdot
.642 .25476 Mdot
.642 .25571 Mdot
.642 .2558 Mdot
.642 .25594 Mdot
.642 .25633 Mdot
.642 .25661 Mdot
.642 .25872 Mdot
.642 .25921 Mdot
.642 .25937 Mdot
.642 .25961 Mdot
.642 .26078 Mdot
.642 .26157 Mdot
.642 .26225 Mdot
.642 .26436 Mdot
.642 .26508 Mdot
.642 .26654 Mdot
.642 .26693 Mdot
.642 .26868 Mdot
.642 .26888 Mdot
.642 .26982 Mdot
.642 .27189 Mdot
.642 .27211 Mdot
.642 .27321 Mdot
.642 .27325 Mdot
.642 .27393 Mdot
.642 .27563 Mdot
.642 .27566 Mdot
.642 .27576 Mdot
.642 .27579 Mdot
.642 .27606 Mdot
.642 .27707 Mdot
.642 .27715 Mdot
.642 .27749 Mdot
.642 .27762 Mdot
.642 .27774 Mdot
.642 .27809 Mdot
.642 .27879 Mdot
.642 .27913 Mdot
.642 .28184 Mdot
.642 .28185 Mdot
.642 .28235 Mdot
.642 .28274 Mdot
.642 .28303 Mdot
.642 .28409 Mdot
.642 .2841 Mdot
.642 .28454 Mdot
.642 .28509 Mdot
.642 .28646 Mdot
.642 .28656 Mdot
.642 .28667 Mdot
.642 .2869 Mdot
.642 .28699 Mdot
.642 .28914 Mdot
.642 .29035 Mdot
.642 .29036 Mdot
.642 .29069 Mdot
.642 .29071 Mdot
.642 .29089 Mdot
.642 .29163 Mdot
.642 .29181 Mdot
.642 .29182 Mdot
.642 .29226 Mdot
.642 .29316 Mdot
.642 .29357 Mdot
.642 .29418 Mdot
.642 .29572 Mdot
.642 .29696 Mdot
.642 .29741 Mdot
.642 .29744 Mdot
.642 .29772 Mdot
.642 .29804 Mdot
.642 .29816 Mdot
.642 .30024 Mdot
.642 .30268 Mdot
.642 .30322 Mdot
.642 .30326 Mdot
.642 .30332 Mdot
.642 .30356 Mdot
.642 .30364 Mdot
.642 .304 Mdot
.642 .30533 Mdot
.642 .30564 Mdot
.642 .30566 Mdot
.642 .30651 Mdot
.642 .30659 Mdot
.642 .30679 Mdot
.642 .30683 Mdot
.642 .30693 Mdot
.642 .30822 Mdot
.642 .30825 Mdot
.642 .30939 Mdot
.642 .30955 Mdot
.642 .31095 Mdot
.642 .31311 Mdot
.642 .31371 Mdot
.642 .31421 Mdot
.642 .31629 Mdot
.642 .31645 Mdot
.642 .31705 Mdot
.642 .31759 Mdot
.642 .31807 Mdot
.642 .31894 Mdot
.642 .31975 Mdot
.642 .31994 Mdot
.642 .32042 Mdot
.642 .32061 Mdot
.642 .32178 Mdot
.642 .32259 Mdot
.642 .32294 Mdot
.642 .32415 Mdot
.642 .32426 Mdot
.642 .32445 Mdot
.642 .32495 Mdot
.642 .32531 Mdot
.642 .32802 Mdot
.642 .32865 Mdot
.642 .32885 Mdot
.642 .32916 Mdot
.642 .33066 Mdot
.642 .33168 Mdot
.642 .33255 Mdot
.642 .33526 Mdot
.642 .33619 Mdot
.642 .33805 Mdot
.642 .33856 Mdot
.642 .34081 Mdot
.642 .34107 Mdot
.642 .34227 Mdot
.642 .34493 Mdot
.642 .34521 Mdot
.642 .34662 Mdot
.642 .34668 Mdot
.642 .34754 Mdot
.642 .34973 Mdot
.642 .34977 Mdot
.642 .34989 Mdot
.642 .34993 Mdot
.642 .35028 Mdot
.642 .35157 Mdot
.642 .35168 Mdot
.642 .35212 Mdot
.642 .35228 Mdot
.642 .35244 Mdot
.642 .35289 Mdot
.642 .35378 Mdot
.642 .35423 Mdot
.642 .3577 Mdot
.642 .35772 Mdot
.642 .35836 Mdot
.642 .35886 Mdot
.642 .35923 Mdot
.642 .3606 Mdot
.642 .36061 Mdot
.642 .36117 Mdot
.642 .36188 Mdot
.642 .36364 Mdot
.642 .36376 Mdot
.642 .3639 Mdot
.642 .36419 Mdot
.642 .36431 Mdot
.642 .36707 Mdot
.642 .36863 Mdot
.642 .36865 Mdot
.642 .36906 Mdot
.642 .36909 Mdot
.642 .36933 Mdot
.642 .37027 Mdot
.642 .37051 Mdot
.642 .37051 Mdot
.642 .37108 Mdot
.642 .37223 Mdot
.642 .37276 Mdot
.642 .37355 Mdot
.642 .37553 Mdot
.642 .37712 Mdot
.642 .37769 Mdot
.642 .37773 Mdot
.642 .37809 Mdot
.642 .37851 Mdot
.642 .37866 Mdot
.642 .38132 Mdot
.642 .38446 Mdot
.642 .38516 Mdot
.642 .3852 Mdot
.642 .38528 Mdot
.642 .38559 Mdot
.642 .38569 Mdot
.642 .38616 Mdot
.642 .38787 Mdot
.642 .38826 Mdot
.642 .38829 Mdot
.642 .38937 Mdot
.642 .38948 Mdot
.642 .38974 Mdot
.642 .38979 Mdot
.642 .38992 Mdot
.642 .39158 Mdot
.642 .39161 Mdot
.642 .39307 Mdot
.642 .39329 Mdot
.644 .01478 Mdot
.644 .0148 Mdot
.644 .01482 Mdot
.644 .01485 Mdot
.644 .01489 Mdot
.644 .01494 Mdot
.644 .01501 Mdot
.644 .01509 Mdot
.644 .01512 Mdot
.644 .0152 Mdot
.644 .01523 Mdot
.644 .01534 Mdot
.644 .01538 Mdot
.644 .01552 Mdot
.644 .01557 Mdot
.644 .01575 Mdot
.644 .01582 Mdot
.644 .01605 Mdot
.644 .01614 Mdot
.644 .01618 Mdot
.644 .01643 Mdot
.644 .01655 Mdot
.644 .01661 Mdot
.644 .01692 Mdot
.644 .01708 Mdot
.644 .01715 Mdot
.644 .01756 Mdot
.644 .01776 Mdot
.644 .01785 Mdot
.644 .01838 Mdot
.644 .01864 Mdot
.644 .0187 Mdot
.644 .01876 Mdot
.644 .01943 Mdot
.644 .01977 Mdot
.644 .01985 Mdot
.644 .01992 Mdot
.644 .02079 Mdot
.644 .02123 Mdot
.644 .02132 Mdot
.644 .02142 Mdot
.644 .02206 Mdot
.644 .02254 Mdot
.644 .0231 Mdot
.644 .02323 Mdot
.644 .02336 Mdot
.644 .02418 Mdot
.644 .02464 Mdot
.644 .02479 Mdot
.644 .02504 Mdot
.644 .02552 Mdot
.644 .02568 Mdot
.644 .02584 Mdot
.644 .02691 Mdot
.644 .02728 Mdot
.644 .02749 Mdot
.644 .0277 Mdot
.644 .02801 Mdot
.644 .02863 Mdot
.644 .02884 Mdot
.644 .02905 Mdot
.644 .02969 Mdot
.644 .03027 Mdot
.644 .03042 Mdot
.644 .0309 Mdot
.644 .03118 Mdot
.644 .03143 Mdot
.644 .03145 Mdot
.644 .03169 Mdot
.644 .03184 Mdot
.644 .03233 Mdot
.644 .03246 Mdot
.644 .03263 Mdot
.644 .0329 Mdot
.644 .03318 Mdot
.644 .03383 Mdot
.644 .034 Mdot
.644 .03405 Mdot
.644 .03476 Mdot
.644 .03494 Mdot
.644 .03557 Mdot
.644 .03591 Mdot
.644 .03592 Mdot
.644 .03599 Mdot
.644 .036 Mdot
.644 .03625 Mdot
.644 .03627 Mdot
.644 .03658 Mdot
.644 .03678 Mdot
.644 .03687 Mdot
.644 .03741 Mdot
.644 .03757 Mdot
.644 .03779 Mdot
.644 .03814 Mdot
.644 .03849 Mdot
.644 .0393 Mdot
.644 .03934 Mdot
.644 .03956 Mdot
.644 .03962 Mdot
.644 .04053 Mdot
.644 .04077 Mdot
.644 .04102 Mdot
.644 .04157 Mdot
.644 .04202 Mdot
.644 .04202 Mdot
.644 .04212 Mdot
.644 .04213 Mdot
.644 .0422 Mdot
.644 .04245 Mdot
.644 .04247 Mdot
.644 .04281 Mdot
.644 .04288 Mdot
.644 .04313 Mdot
.644 .04325 Mdot
.644 .0435 Mdot
.644 .04354 Mdot
.644 .04366 Mdot
.644 .04394 Mdot
.644 .04416 Mdot
.644 .04444 Mdot
.644 .04475 Mdot
.644 .04489 Mdot
.644 .04489 Mdot
.644 .04534 Mdot
.644 .04638 Mdot
.644 .04643 Mdot
.644 .04671 Mdot
.644 .04679 Mdot
.644 .04743 Mdot
.644 .04796 Mdot
.644 .04827 Mdot
.644 .0486 Mdot
.644 .0493 Mdot
.644 .04988 Mdot
.644 .04989 Mdot
.644 .05002 Mdot
.644 .05003 Mdot
.644 .05008 Mdot
.644 .05012 Mdot
.644 .05044 Mdot
.644 .05047 Mdot
.644 .05091 Mdot
.644 .05099 Mdot
.644 .05131 Mdot
.644 .05147 Mdot
.644 .0516 Mdot
.644 .05179 Mdot
.644 .05184 Mdot
.644 .052 Mdot
.644 .05219 Mdot
.644 .05236 Mdot
.644 .05264 Mdot
.644 .053 Mdot
.644 .05339 Mdot
.644 .05358 Mdot
.644 .05358 Mdot
.644 .05416 Mdot
.644 .05477 Mdot
.644 .05547 Mdot
.644 .05549 Mdot
.644 .05556 Mdot
.644 .05593 Mdot
.644 .05594 Mdot
.644 .05602 Mdot
.644 .05672 Mdot
.644 .05685 Mdot
.644 .05753 Mdot
.644 .0576 Mdot
.644 .05793 Mdot
.644 .05836 Mdot
.644 .05879 Mdot
.644 .05908 Mdot
.644 .05927 Mdot
.644 .05963 Mdot
.644 .06001 Mdot
.644 .06002 Mdot
.644 .06018 Mdot
.644 .0602 Mdot
.644 .06026 Mdot
.644 .06031 Mdot
.644 .06073 Mdot
.644 .06076 Mdot
.644 .06133 Mdot
.644 .06144 Mdot
.644 .06185 Mdot
.644 .06205 Mdot
.644 .06222 Mdot
.644 .06247 Mdot
.644 .06254 Mdot
.644 .06274 Mdot
.644 .06298 Mdot
.644 .0632 Mdot
.644 .06356 Mdot
.644 .06388 Mdot
.644 .06399 Mdot
.644 .06402 Mdot
.644 .06453 Mdot
.644 .06477 Mdot
.644 .06478 Mdot
.644 .06552 Mdot
.644 .06631 Mdot
.644 .06666 Mdot
.644 .06705 Mdot
.644 .06721 Mdot
.644 .06724 Mdot
.644 .06732 Mdot
.644 .0678 Mdot
.644 .06781 Mdot
.644 .06792 Mdot
.644 .06824 Mdot
.644 .06847 Mdot
.644 .06848 Mdot
.644 .0688 Mdot
.644 .06882 Mdot
.644 .06898 Mdot
.644 .06967 Mdot
.644 .06987 Mdot
.644 .06994 Mdot
.644 .07038 Mdot
.644 .07054 Mdot
.644 .07082 Mdot
.644 .07093 Mdot
.644 .07149 Mdot
.644 .07185 Mdot
.644 .07206 Mdot
.644 .0721 Mdot
.644 .07257 Mdot
.644 .07305 Mdot
.644 .07306 Mdot
.644 .07328 Mdot
.644 .0733 Mdot
.644 .07338 Mdot
.644 .07344 Mdot
.644 .07398 Mdot
.644 .07403 Mdot
.644 .07418 Mdot
.644 .07472 Mdot
.644 .07475 Mdot
.644 .07481 Mdot
.644 .0749 Mdot
.644 .07517 Mdot
.644 .07543 Mdot
.644 .07569 Mdot
.644 .07572 Mdot
.644 .0758 Mdot
.644 .0759 Mdot
.644 .07622 Mdot
.644 .07631 Mdot
.644 .07657 Mdot
.644 .07688 Mdot
.644 .07717 Mdot
.644 .07744 Mdot
.644 .0776 Mdot
.644 .07762 Mdot
.644 .07804 Mdot
.644 .07818 Mdot
.644 .07818 Mdot
.644 .07823 Mdot
.644 .07868 Mdot
.644 .07888 Mdot
.644 .07918 Mdot
.644 .0792 Mdot
.644 .08016 Mdot
.644 .08117 Mdot
.644 .08162 Mdot
.644 .08202 Mdot
.644 .08212 Mdot
.644 .08232 Mdot
.644 .08237 Mdot
.644 .08247 Mdot
.644 .08273 Mdot
.644 .08308 Mdot
.644 .0831 Mdot
.644 .0831 Mdot
.644 .08325 Mdot
.644 .08366 Mdot
.644 .08395 Mdot
.644 .08397 Mdot
.644 .08415 Mdot
.644 .08426 Mdot
.644 .08437 Mdot
.644 .08438 Mdot
.644 .0844 Mdot
.644 .08461 Mdot
.644 .08504 Mdot
.644 .08549 Mdot
.644 .08575 Mdot
.644 .08585 Mdot
.644 .08641 Mdot
.644 .08662 Mdot
.644 .08677 Mdot
.644 .08697 Mdot
.644 .08702 Mdot
.644 .08712 Mdot
.644 .08784 Mdot
.644 .08831 Mdot
.644 .08838 Mdot
.644 .08858 Mdot
.644 .08862 Mdot
.644 .08862 Mdot
.644 .08902 Mdot
.644 .08923 Mdot
.644 .08959 Mdot
.644 .08968 Mdot
.644 .08976 Mdot
.644 .08985 Mdot
.644 .08987 Mdot
.644 .09014 Mdot
.644 .09017 Mdot
.644 .09027 Mdot
.644 .09036 Mdot
.644 .09104 Mdot
.644 .09111 Mdot
.644 .09129 Mdot
.644 .0913 Mdot
.644 .09132 Mdot
.644 .09173 Mdot
.644 .09201 Mdot
.644 .09205 Mdot
.644 .09211 Mdot
.644 .09223 Mdot
.644 .09258 Mdot
.644 .09291 Mdot
.644 .09325 Mdot
.644 .09328 Mdot
.644 .09339 Mdot
.644 .09353 Mdot
.644 .09372 Mdot
.644 .09394 Mdot
.644 .09405 Mdot
.644 .09438 Mdot
.644 .09478 Mdot
.644 .09516 Mdot
.644 .0955 Mdot
.644 .09568 Mdot
.644 .09571 Mdot
.644 .09574 Mdot
.644 .0959 Mdot
.644 .09628 Mdot
.644 .09645 Mdot
.644 .09646 Mdot
.644 .09652 Mdot
.644 .09652 Mdot
.644 .09711 Mdot
.644 .09732 Mdot
.644 .09736 Mdot
.644 .09775 Mdot
.644 .09777 Mdot
.644 .09845 Mdot
.644 .099 Mdot
.644 .09974 Mdot
.644 .1003 Mdot
.644 .10039 Mdot
.644 .10088 Mdot
.644 .10141 Mdot
.644 .10154 Mdot
.644 .10179 Mdot
.644 .10185 Mdot
.644 .10199 Mdot
.644 .10232 Mdot
.644 .10236 Mdot
.644 .10277 Mdot
.644 .10279 Mdot
.644 .10279 Mdot
.644 .10298 Mdot
.644 .10351 Mdot
.644 .10389 Mdot
.644 .10392 Mdot
.644 .10415 Mdot
.644 .10428 Mdot
.644 .10444 Mdot
.644 .10444 Mdot
.644 .10447 Mdot
.644 .10471 Mdot
.644 .10474 Mdot
.644 .10529 Mdot
.644 .10588 Mdot
.644 .10621 Mdot
.644 .10634 Mdot
.644 .1069 Mdot
.644 .10706 Mdot
.644 .10716 Mdot
.644 .10733 Mdot
.644 .10752 Mdot
.644 .10778 Mdot
.644 .10785 Mdot
.644 .10797 Mdot
.644 .1089 Mdot
.644 .10892 Mdot
.644 .10951 Mdot
.644 .10959 Mdot
.644 .10985 Mdot
.644 .1099 Mdot
.644 .10991 Mdot
.644 .10998 Mdot
.644 .11017 Mdot
.644 .11036 Mdot
.644 .11042 Mdot
.644 .11069 Mdot
.644 .11115 Mdot
.644 .11127 Mdot
.644 .11129 Mdot
.644 .11137 Mdot
.644 .11149 Mdot
.644 .11151 Mdot
.644 .11187 Mdot
.644 .1119 Mdot
.644 .11203 Mdot
.644 .11214 Mdot
.644 .11287 Mdot
.644 .11303 Mdot
.644 .11311 Mdot
.644 .11334 Mdot
.644 .11336 Mdot
.644 .11339 Mdot
.644 .11353 Mdot
.644 .11391 Mdot
.644 .11397 Mdot
.644 .11426 Mdot
.644 .11432 Mdot
.644 .1144 Mdot
.644 .11453 Mdot
.644 .11455 Mdot
.644 .11457 Mdot
.644 .1149 Mdot
.644 .11491 Mdot
.644 .115 Mdot
.644 .11543 Mdot
.644 .11586 Mdot
.644 .11591 Mdot
.644 .11605 Mdot
.644 .11622 Mdot
.644 .11647 Mdot
.644 .11675 Mdot
.644 .1169 Mdot
.644 .11733 Mdot
.644 .11784 Mdot
.644 .11832 Mdot
.644 .11838 Mdot
.644 .11876 Mdot
.644 .119 Mdot
.644 .11904 Mdot
.644 .11908 Mdot
.644 .11928 Mdot
.644 .11963 Mdot
.644 .11977 Mdot
.644 .11987 Mdot
.644 .11999 Mdot
.644 .12 Mdot
.644 .12007 Mdot
.644 .12008 Mdot
.644 .12084 Mdot
.644 .12111 Mdot
.644 .12116 Mdot
.644 .12167 Mdot
.644 .12169 Mdot
.644 .12217 Mdot
.644 .12227 Mdot
.644 .12257 Mdot
.644 .12328 Mdot
.644 .12423 Mdot
.644 .12495 Mdot
.644 .12507 Mdot
.644 .1257 Mdot
.644 .12638 Mdot
.644 .12654 Mdot
.644 .12687 Mdot
.644 .12694 Mdot
.644 .12712 Mdot
.644 .12755 Mdot
.644 .12761 Mdot
.644 .12813 Mdot
.644 .12816 Mdot
.644 .12816 Mdot
.644 .1284 Mdot
.644 .12909 Mdot
.644 .12958 Mdot
.644 .12991 Mdot
.644 .13008 Mdot
.644 .13027 Mdot
.644 .13029 Mdot
.644 .13032 Mdot
.644 .13063 Mdot
.644 .13067 Mdot
.644 .13138 Mdot
.644 .13213 Mdot
.644 .13256 Mdot
.644 .13272 Mdot
.644 .13345 Mdot
.644 .13365 Mdot
.644 .13378 Mdot
.644 .134 Mdot
.644 .13425 Mdot
.644 .13459 Mdot
.644 .13467 Mdot
.644 .13483 Mdot
.644 .13602 Mdot
.644 .13605 Mdot
.644 .13681 Mdot
.644 .13692 Mdot
.644 .13725 Mdot
.644 .13732 Mdot
.644 .13732 Mdot
.644 .13741 Mdot
.644 .13766 Mdot
.644 .1379 Mdot
.644 .13798 Mdot
.644 .13833 Mdot
.644 .13893 Mdot
.644 .13908 Mdot
.644 .13911 Mdot
.644 .13921 Mdot
.644 .13936 Mdot
.644 .13939 Mdot
.644 .13985 Mdot
.644 .13989 Mdot
.644 .14006 Mdot
.644 .1402 Mdot
.644 .14114 Mdot
.644 .14134 Mdot
.644 .14145 Mdot
.644 .14174 Mdot
.644 .14177 Mdot
.644 .14181 Mdot
.644 .14199 Mdot
.644 .14248 Mdot
.644 .14255 Mdot
.644 .14293 Mdot
.644 .143 Mdot
.644 .14312 Mdot
.644 .14328 Mdot
.644 .1433 Mdot
.644 .14332 Mdot
.644 .14376 Mdot
.644 .14377 Mdot
.644 .14388 Mdot
.644 .14444 Mdot
.644 .14499 Mdot
.644 .14506 Mdot
.644 .14523 Mdot
.644 .14546 Mdot
.644 .14578 Mdot
.644 .14614 Mdot
.644 .14632 Mdot
.644 .14688 Mdot
.644 .14754 Mdot
.644 .14816 Mdot
.644 .14823 Mdot
.644 .14873 Mdot
.644 .14903 Mdot
.644 .14908 Mdot
.644 .14914 Mdot
.644 .1494 Mdot
.644 .14985 Mdot
.644 .15003 Mdot
.644 .15015 Mdot
.644 .15031 Mdot
.644 .15032 Mdot
.644 .15042 Mdot
.644 .15042 Mdot
.644 .1514 Mdot
.644 .15175 Mdot
.644 .15182 Mdot
.644 .15247 Mdot
.644 .1525 Mdot
.644 .15312 Mdot
.644 .15324 Mdot
.644 .15363 Mdot
.644 .15454 Mdot
.644 .15577 Mdot
.644 .1567 Mdot
.644 .15685 Mdot
.644 .15766 Mdot
.644 .15854 Mdot
.644 .15875 Mdot
.644 .15918 Mdot
.644 .15926 Mdot
.644 .1595 Mdot
.644 .16004 Mdot
.644 .16012 Mdot
.644 .1608 Mdot
.644 .16083 Mdot
.644 .16083 Mdot
.644 .16115 Mdot
.644 .16203 Mdot
.644 .16266 Mdot
.644 .16308 Mdot
.644 .16331 Mdot
.644 .16356 Mdot
.644 .16357 Mdot
.644 .16361 Mdot
.644 .16401 Mdot
.644 .16406 Mdot
.644 .16498 Mdot
.644 .16594 Mdot
.644 .1665 Mdot
.644 .16671 Mdot
.644 .16765 Mdot
.644 .1679 Mdot
.644 .16807 Mdot
.644 .16836 Mdot
.644 .16868 Mdot
.644 .16911 Mdot
.644 .16922 Mdot
.644 .16942 Mdot
.644 .17096 Mdot
.644 .171 Mdot
.644 .17197 Mdot
.644 .17211 Mdot
.644 .17255 Mdot
.644 .17263 Mdot
.644 .17263 Mdot
.644 .17275 Mdot
.644 .17306 Mdot
.644 .17338 Mdot
.644 .17348 Mdot
.644 .17393 Mdot
.644 .1747 Mdot
.644 .1749 Mdot
.644 .17493 Mdot
.644 .17506 Mdot
.644 .17526 Mdot
.644 .17529 Mdot
.644 .17589 Mdot
.644 .17595 Mdot
.644 .17616 Mdot
.644 .17634 Mdot
.644 .17755 Mdot
.644 .17781 Mdot
.644 .17794 Mdot
.644 .17833 Mdot
.644 .17836 Mdot
.644 .17841 Mdot
.644 .17865 Mdot
.644 .17928 Mdot
.644 .17937 Mdot
.644 .17986 Mdot
.644 .17995 Mdot
.644 .18009 Mdot
.644 .1803 Mdot
.644 .18034 Mdot
.644 .18036 Mdot
.644 .18092 Mdot
.644 .18093 Mdot
.644 .18108 Mdot
.644 .1818 Mdot
.644 .18251 Mdot
.644 .1826 Mdot
.644 .18282 Mdot
.644 .18311 Mdot
.644 .18352 Mdot
.644 .18399 Mdot
.644 .18423 Mdot
.644 .18494 Mdot
.644 .1858 Mdot
.644 .18659 Mdot
.644 .18669 Mdot
.644 .18733 Mdot
.644 .18771 Mdot
.644 .18778 Mdot
.644 .18785 Mdot
.644 .18819 Mdot
.644 .18876 Mdot
.644 .189 Mdot
.644 .18916 Mdot
.644 .18936 Mdot
.644 .18938 Mdot
.644 .1895 Mdot
.644 .1895 Mdot
.644 .19076 Mdot
.644 .19122 Mdot
.644 .1913 Mdot
.644 .19214 Mdot
.644 .19218 Mdot
.644 .19298 Mdot
.644 .19314 Mdot
.644 .19364 Mdot
.644 .19481 Mdot
.644 .19639 Mdot
.644 .19759 Mdot
.644 .19778 Mdot
.644 .19883 Mdot
.644 .19996 Mdot
.644 .20023 Mdot
.644 .20078 Mdot
.644 .2009 Mdot
.644 .2012 Mdot
.644 .2019 Mdot
.644 .202 Mdot
.644 .20287 Mdot
.644 .20291 Mdot
.644 .20291 Mdot
.644 .20332 Mdot
.644 .20445 Mdot
.644 .20526 Mdot
.644 .20581 Mdot
.644 .2061 Mdot
.644 .20642 Mdot
.644 .20644 Mdot
.644 .2065 Mdot
.644 .207 Mdot
.644 .20707 Mdot
.644 .20826 Mdot
.644 .2095 Mdot
.644 .21021 Mdot
.644 .21049 Mdot
.644 .2117 Mdot
.644 .21202 Mdot
.644 .21224 Mdot
.644 .21261 Mdot
.644 .21302 Mdot
.644 .21358 Mdot
.644 .21371 Mdot
.644 .21397 Mdot
.644 .21596 Mdot
.644 .21601 Mdot
.644 .21726 Mdot
.644 .21744 Mdot
.644 .218 Mdot
.644 .21811 Mdot
.644 .21811 Mdot
.644 .21826 Mdot
.644 .21867 Mdot
.644 .21908 Mdot
.644 .21921 Mdot
.644 .21979 Mdot
.644 .22078 Mdot
.644 .22103 Mdot
.644 .22107 Mdot
.644 .22124 Mdot
.644 .2215 Mdot
.644 .22154 Mdot
.644 .2223 Mdot
.644 .22238 Mdot
.644 .22265 Mdot
.644 .22289 Mdot
.644 .22445 Mdot
.644 .22478 Mdot
.644 .22495 Mdot
.644 .22545 Mdot
.644 .2255 Mdot
.644 .22555 Mdot
.644 .22586 Mdot
.644 .22667 Mdot
.644 .22679 Mdot
.644 .22742 Mdot
.644 .22754 Mdot
.644 .22772 Mdot
.644 .22799 Mdot
.644 .22804 Mdot
.644 .22807 Mdot
.644 .22879 Mdot
.644 .2288 Mdot
.644 .22899 Mdot
.644 .22992 Mdot
.644 .23084 Mdot
.644 .23095 Mdot
.644 .23123 Mdot
.644 .23161 Mdot
.644 .23214 Mdot
.644 .23274 Mdot
.644 .23305 Mdot
.644 .23397 Mdot
.644 .23507 Mdot
.644 .23609 Mdot
.644 .23621 Mdot
.644 .23704 Mdot
.644 .23753 Mdot
.644 .23762 Mdot
.644 .23771 Mdot
.644 .23815 Mdot
.644 .23889 Mdot
.644 .2392 Mdot
.644 .2394 Mdot
.644 .23966 Mdot
.644 .23968 Mdot
.644 .23984 Mdot
.644 .23984 Mdot
.644 .24146 Mdot
.644 .24205 Mdot
.644 .24216 Mdot
.644 .24324 Mdot
.644 .24328 Mdot
.644 .24432 Mdot
.644 .24452 Mdot
.644 .24517 Mdot
.644 .24668 Mdot
.644 .24871 Mdot
.644 .25026 Mdot
.644 .2505 Mdot
.644 .25186 Mdot
.644 .25331 Mdot
.644 .25366 Mdot
.644 .25437 Mdot
.644 .25452 Mdot
.644 .2549 Mdot
.644 .2558 Mdot
.644 .25594 Mdot
.644 .25706 Mdot
.644 .25711 Mdot
.644 .25711 Mdot
.644 .25764 Mdot
.644 .2591 Mdot
.644 .26014 Mdot
.644 .26085 Mdot
.644 .26122 Mdot
.644 .26163 Mdot
.644 .26166 Mdot
.644 .26173 Mdot
.644 .26238 Mdot
.644 .26247 Mdot
.644 .264 Mdot
.644 .2656 Mdot
.644 .26651 Mdot
.644 .26687 Mdot
.644 .26843 Mdot
.644 .26885 Mdot
.644 .26913 Mdot
.644 .2696 Mdot
.644 .27013 Mdot
.644 .27085 Mdot
.644 .27102 Mdot
.644 .27136 Mdot
.644 .27392 Mdot
.644 .27398 Mdot
.644 .27559 Mdot
.644 .27583 Mdot
.644 .27655 Mdot
.644 .27668 Mdot
.644 .27669 Mdot
.644 .27688 Mdot
.644 .27741 Mdot
.644 .27793 Mdot
.644 .2781 Mdot
.644 .27885 Mdot
.644 .28013 Mdot
.644 .28045 Mdot
.644 .2805 Mdot
.644 .28072 Mdot
.644 .28105 Mdot
.644 .2811 Mdot
.644 .28209 Mdot
.644 .28219 Mdot
.644 .28254 Mdot
.644 .28284 Mdot
.644 .28485 Mdot
.644 .28528 Mdot
.644 .2855 Mdot
.644 .28614 Mdot
.644 .2862 Mdot
.644 .28627 Mdot
.644 .28667 Mdot
.644 .28772 Mdot
.644 .28787 Mdot
.644 .28868 Mdot
.644 .28883 Mdot
.644 .28907 Mdot
.644 .28942 Mdot
.644 .28947 Mdot
.644 .28952 Mdot
.644 .29044 Mdot
.644 .29046 Mdot
.644 .29071 Mdot
.644 .2919 Mdot
.644 .29309 Mdot
.644 .29322 Mdot
.644 .29359 Mdot
.644 .29407 Mdot
.644 .29476 Mdot
.644 .29553 Mdot
.644 .29593 Mdot
.644 .29712 Mdot
.644 .29853 Mdot
.644 .29985 Mdot
.644 .30001 Mdot
.644 .30107 Mdot
.644 .3017 Mdot
.644 .30182 Mdot
.644 .30193 Mdot
.644 .3025 Mdot
.644 .30345 Mdot
.644 .30385 Mdot
.644 .30411 Mdot
.644 .30445 Mdot
.644 .30447 Mdot
.644 .30467 Mdot
.644 .30468 Mdot
.644 .30677 Mdot
.644 .30752 Mdot
.644 .30767 Mdot
.644 .30906 Mdot
.644 .30911 Mdot
.644 .31045 Mdot
.644 .31071 Mdot
.644 .31154 Mdot
.644 .31349 Mdot
.644 .3161 Mdot
.644 .3181 Mdot
.644 .31841 Mdot
.644 .32015 Mdot
.644 .32202 Mdot
.644 .32248 Mdot
.644 .32339 Mdot
.644 .32358 Mdot
.644 .32408 Mdot
.644 .32524 Mdot
.644 .32541 Mdot
.644 .32685 Mdot
.644 .32692 Mdot
.644 .32692 Mdot
.644 .3276 Mdot
.644 .32948 Mdot
.644 .33082 Mdot
.644 .33174 Mdot
.644 .33221 Mdot
.644 .33275 Mdot
.644 .33278 Mdot
.644 .33287 Mdot
.644 .33371 Mdot
.644 .33383 Mdot
.644 .33579 Mdot
.644 .33785 Mdot
.644 .33903 Mdot
.644 .33949 Mdot
.644 .3415 Mdot
.644 .34204 Mdot
.644 .3424 Mdot
.644 .34301 Mdot
.644 .34369 Mdot
.644 .34462 Mdot
.644 .34484 Mdot
.644 .34527 Mdot
.644 .34857 Mdot
.644 .34865 Mdot
.644 .35072 Mdot
.644 .35103 Mdot
.644 .35195 Mdot
.644 .35213 Mdot
.644 .35214 Mdot
.644 .35239 Mdot
.644 .35306 Mdot
.644 .35374 Mdot
.644 .35395 Mdot
.644 .35492 Mdot
.644 .35656 Mdot
.644 .35699 Mdot
.644 .35705 Mdot
.644 .35733 Mdot
.644 .35776 Mdot
.644 .35782 Mdot
.644 .35909 Mdot
.644 .35922 Mdot
.644 .35967 Mdot
.644 .36006 Mdot
.644 .36266 Mdot
.644 .3632 Mdot
.644 .36349 Mdot
.644 .36431 Mdot
.644 .36439 Mdot
.644 .36448 Mdot
.644 .365 Mdot
.644 .36634 Mdot
.644 .36654 Mdot
.644 .36759 Mdot
.644 .36778 Mdot
.644 .36809 Mdot
.644 .36853 Mdot
.644 .3686 Mdot
.644 .36866 Mdot
.644 .36985 Mdot
.644 .36988 Mdot
.644 .37019 Mdot
.644 .37173 Mdot
.644 .37326 Mdot
.644 .37343 Mdot
.644 .37391 Mdot
.644 .37453 Mdot
.644 .37541 Mdot
.644 .37641 Mdot
.644 .37692 Mdot
.644 .37845 Mdot
.644 .38027 Mdot
.644 .38197 Mdot
.644 .38217 Mdot
.644 .38354 Mdot
.644 .38436 Mdot
.644 .3845 Mdot
.644 .38465 Mdot
.644 .38538 Mdot
.644 .38661 Mdot
.644 .38712 Mdot
.644 .38746 Mdot
.644 .38789 Mdot
.644 .38792 Mdot
.644 .38818 Mdot
.644 .38819 Mdot
.644 .39088 Mdot
.644 .39185 Mdot
.644 .39204 Mdot
.644 .39383 Mdot
.644 .3939 Mdot
.646 .01488 Mdot
.646 .01493 Mdot
.646 .01499 Mdot
.646 .01507 Mdot
.646 .01518 Mdot
.646 .01531 Mdot
.646 .01548 Mdot
.646 .01571 Mdot
.646 .016 Mdot
.646 .0161 Mdot
.646 .01634 Mdot
.646 .01637 Mdot
.646 .0165 Mdot
.646 .01681 Mdot
.646 .01684 Mdot
.646 .01686 Mdot
.646 .01702 Mdot
.646 .01742 Mdot
.646 .01746 Mdot
.646 .01748 Mdot
.646 .01768 Mdot
.646 .01769 Mdot
.646 .01769 Mdot
.646 .01821 Mdot
.646 .01827 Mdot
.646 .01829 Mdot
.646 .01855 Mdot
.646 .01856 Mdot
.646 .01857 Mdot
.646 .01863 Mdot
.646 .01873 Mdot
.646 .01923 Mdot
.646 .01931 Mdot
.646 .01933 Mdot
.646 .01935 Mdot
.646 .01967 Mdot
.646 .01968 Mdot
.646 .01969 Mdot
.646 .01977 Mdot
.646 .0199 Mdot
.646 .02012 Mdot
.646 .02039 Mdot
.646 .02055 Mdot
.646 .02065 Mdot
.646 .02068 Mdot
.646 .02071 Mdot
.646 .02103 Mdot
.646 .02108 Mdot
.646 .02112 Mdot
.646 .02113 Mdot
.646 .02114 Mdot
.646 .02125 Mdot
.646 .02139 Mdot
.646 .02141 Mdot
.646 .02169 Mdot
.646 .02204 Mdot
.646 .02215 Mdot
.646 .02226 Mdot
.646 .02238 Mdot
.646 .02242 Mdot
.646 .02246 Mdot
.646 .02287 Mdot
.646 .02294 Mdot
.646 .02299 Mdot
.646 .023 Mdot
.646 .02302 Mdot
.646 .02315 Mdot
.646 .02333 Mdot
.646 .02336 Mdot
.646 .02373 Mdot
.646 .02418 Mdot
.646 .02432 Mdot
.646 .02446 Mdot
.646 .02461 Mdot
.646 .02467 Mdot
.646 .02472 Mdot
.646 .02525 Mdot
.646 .02534 Mdot
.646 .02538 Mdot
.646 .0254 Mdot
.646 .02542 Mdot
.646 .02544 Mdot
.646 .02562 Mdot
.646 .02585 Mdot
.646 .02589 Mdot
.646 .02637 Mdot
.646 .02642 Mdot
.646 .02676 Mdot
.646 .02694 Mdot
.646 .02712 Mdot
.646 .0273 Mdot
.646 .0274 Mdot
.646 .0275 Mdot
.646 .02758 Mdot
.646 .02764 Mdot
.646 .02767 Mdot
.646 .02784 Mdot
.646 .02786 Mdot
.646 .02805 Mdot
.646 .02832 Mdot
.646 .02844 Mdot
.646 .02849 Mdot
.646 .02853 Mdot
.646 .02855 Mdot
.646 .02858 Mdot
.646 .02865 Mdot
.646 .0288 Mdot
.646 .02901 Mdot
.646 .0291 Mdot
.646 .02915 Mdot
.646 .02977 Mdot
.646 .02984 Mdot
.646 .03028 Mdot
.646 .03051 Mdot
.646 .03074 Mdot
.646 .03098 Mdot
.646 .03111 Mdot
.646 .03124 Mdot
.646 .03133 Mdot
.646 .03142 Mdot
.646 .03145 Mdot
.646 .03167 Mdot
.646 .0317 Mdot
.646 .03195 Mdot
.646 .03216 Mdot
.646 .0323 Mdot
.646 .03238 Mdot
.646 .03245 Mdot
.646 .03251 Mdot
.646 .03256 Mdot
.646 .03259 Mdot
.646 .03262 Mdot
.646 .03272 Mdot
.646 .03291 Mdot
.646 .03319 Mdot
.646 .0333 Mdot
.646 .03337 Mdot
.646 .03416 Mdot
.646 .03426 Mdot
.646 .03483 Mdot
.646 .03483 Mdot
.646 .03513 Mdot
.646 .03542 Mdot
.646 .03573 Mdot
.646 .0359 Mdot
.646 .03606 Mdot
.646 .03618 Mdot
.646 .03623 Mdot
.646 .0363 Mdot
.646 .03633 Mdot
.646 .03662 Mdot
.646 .03666 Mdot
.646 .03698 Mdot
.646 .03725 Mdot
.646 .03731 Mdot
.646 .03743 Mdot
.646 .03754 Mdot
.646 .03763 Mdot
.646 .03771 Mdot
.646 .03777 Mdot
.646 .03781 Mdot
.646 .03785 Mdot
.646 .03797 Mdot
.646 .03823 Mdot
.646 .03858 Mdot
.646 .03873 Mdot
.646 .03881 Mdot
.646 .03984 Mdot
.646 .03997 Mdot
.646 .0407 Mdot
.646 .0407 Mdot
.646 .04109 Mdot
.646 .04147 Mdot
.646 .04186 Mdot
.646 .04208 Mdot
.646 .0423 Mdot
.646 .04235 Mdot
.646 .04245 Mdot
.646 .04252 Mdot
.646 .0426 Mdot
.646 .04265 Mdot
.646 .04302 Mdot
.646 .04307 Mdot
.646 .04337 Mdot
.646 .04348 Mdot
.646 .04383 Mdot
.646 .0439 Mdot
.646 .04407 Mdot
.646 .0442 Mdot
.646 .04432 Mdot
.646 .04442 Mdot
.646 .0445 Mdot
.646 .04455 Mdot
.646 .04461 Mdot
.646 .04463 Mdot
.646 .04476 Mdot
.646 .04509 Mdot
.646 .04527 Mdot
.646 .04555 Mdot
.646 .04574 Mdot
.646 .04585 Mdot
.646 .04718 Mdot
.646 .04734 Mdot
.646 .04828 Mdot
.646 .04829 Mdot
.646 .04879 Mdot
.646 .04928 Mdot
.646 .04979 Mdot
.646 .05007 Mdot
.646 .05035 Mdot
.646 .05042 Mdot
.646 .05055 Mdot
.646 .05063 Mdot
.646 .05074 Mdot
.646 .0508 Mdot
.646 .05117 Mdot
.646 .05128 Mdot
.646 .05135 Mdot
.646 .05149 Mdot
.646 .05162 Mdot
.646 .05173 Mdot
.646 .05188 Mdot
.646 .0521 Mdot
.646 .05234 Mdot
.646 .05242 Mdot
.646 .05264 Mdot
.646 .05281 Mdot
.646 .05296 Mdot
.646 .05309 Mdot
.646 .05319 Mdot
.646 .0532 Mdot
.646 .05326 Mdot
.646 .05334 Mdot
.646 .05336 Mdot
.646 .05343 Mdot
.646 .05354 Mdot
.646 .05396 Mdot
.646 .05413 Mdot
.646 .05419 Mdot
.646 .05456 Mdot
.646 .0548 Mdot
.646 .05494 Mdot
.646 .05555 Mdot
.646 .05666 Mdot
.646 .05687 Mdot
.646 .05809 Mdot
.646 .05809 Mdot
.646 .05817 Mdot
.646 .05874 Mdot
.646 .05937 Mdot
.646 .06003 Mdot
.646 .06004 Mdot
.646 .06039 Mdot
.646 .06076 Mdot
.646 .06085 Mdot
.646 .06101 Mdot
.646 .06112 Mdot
.646 .06126 Mdot
.646 .06134 Mdot
.646 .06181 Mdot
.646 .06196 Mdot
.646 .06205 Mdot
.646 .06223 Mdot
.646 .06239 Mdot
.646 .06254 Mdot
.646 .06274 Mdot
.646 .06302 Mdot
.646 .06332 Mdot
.646 .06343 Mdot
.646 .06371 Mdot
.646 .06394 Mdot
.646 .06413 Mdot
.646 .0643 Mdot
.646 .0643 Mdot
.646 .06442 Mdot
.646 .06443 Mdot
.646 .06452 Mdot
.646 .06461 Mdot
.646 .06465 Mdot
.646 .06473 Mdot
.646 .06487 Mdot
.646 .06543 Mdot
.646 .06564 Mdot
.646 .06571 Mdot
.646 .06619 Mdot
.646 .06651 Mdot
.646 .06669 Mdot
.646 .06748 Mdot
.646 .06777 Mdot
.646 .06785 Mdot
.646 .06861 Mdot
.646 .06865 Mdot
.646 .06873 Mdot
.646 .0689 Mdot
.646 .06899 Mdot
.646 .06918 Mdot
.646 .06951 Mdot
.646 .07075 Mdot
.646 .07076 Mdot
.646 .07086 Mdot
.646 .07159 Mdot
.646 .07241 Mdot
.646 .07272 Mdot
.646 .07326 Mdot
.646 .07328 Mdot
.646 .07373 Mdot
.646 .0742 Mdot
.646 .07431 Mdot
.646 .07432 Mdot
.646 .07435 Mdot
.646 .07453 Mdot
.646 .07467 Mdot
.646 .07485 Mdot
.646 .07552 Mdot
.646 .07556 Mdot
.646 .07575 Mdot
.646 .07587 Mdot
.646 .0761 Mdot
.646 .07632 Mdot
.646 .07651 Mdot
.646 .07676 Mdot
.646 .07712 Mdot
.646 .07752 Mdot
.646 .07766 Mdot
.646 .07802 Mdot
.646 .07831 Mdot
.646 .07855 Mdot
.646 .07878 Mdot
.646 .07878 Mdot
.646 .07894 Mdot
.646 .07895 Mdot
.646 .07906 Mdot
.646 .07918 Mdot
.646 .07923 Mdot
.646 .07933 Mdot
.646 .07952 Mdot
.646 .08023 Mdot
.646 .08047 Mdot
.646 .08047 Mdot
.646 .0805 Mdot
.646 .0806 Mdot
.646 .08066 Mdot
.646 .08119 Mdot
.646 .08122 Mdot
.646 .08163 Mdot
.646 .08187 Mdot
.646 .08204 Mdot
.646 .08288 Mdot
.646 .08305 Mdot
.646 .08326 Mdot
.646 .08337 Mdot
.646 .08435 Mdot
.646 .0844 Mdot
.646 .08451 Mdot
.646 .08473 Mdot
.646 .08484 Mdot
.646 .08508 Mdot
.646 .08552 Mdot
.646 .08711 Mdot
.646 .08713 Mdot
.646 .08725 Mdot
.646 .08726 Mdot
.646 .08727 Mdot
.646 .08732 Mdot
.646 .0874 Mdot
.646 .0882 Mdot
.646 .0884 Mdot
.646 .08926 Mdot
.646 .08935 Mdot
.646 .08966 Mdot
.646 .09036 Mdot
.646 .09038 Mdot
.646 .0907 Mdot
.646 .09093 Mdot
.646 .09097 Mdot
.646 .09158 Mdot
.646 .09171 Mdot
.646 .09172 Mdot
.646 .09176 Mdot
.646 .092 Mdot
.646 .09218 Mdot
.646 .09241 Mdot
.646 .09327 Mdot
.646 .09333 Mdot
.646 .09357 Mdot
.646 .09373 Mdot
.646 .09403 Mdot
.646 .0943 Mdot
.646 .09455 Mdot
.646 .09459 Mdot
.646 .09488 Mdot
.646 .09535 Mdot
.646 .0954 Mdot
.646 .09545 Mdot
.646 .09572 Mdot
.646 .09585 Mdot
.646 .09604 Mdot
.646 .0965 Mdot
.646 .09654 Mdot
.646 .09688 Mdot
.646 .09714 Mdot
.646 .0972 Mdot
.646 .09749 Mdot
.646 .09749 Mdot
.646 .09769 Mdot
.646 .09771 Mdot
.646 .09784 Mdot
.646 .09801 Mdot
.646 .09807 Mdot
.646 .0982 Mdot
.646 .09822 Mdot
.646 .09844 Mdot
.646 .09936 Mdot
.646 .09957 Mdot
.646 .09967 Mdot
.646 .09967 Mdot
.646 .09971 Mdot
.646 .09984 Mdot
.646 .09992 Mdot
.646 .1006 Mdot
.646 .10064 Mdot
.646 .10117 Mdot
.646 .10147 Mdot
.646 .1017 Mdot
.646 .10279 Mdot
.646 .10301 Mdot
.646 .10328 Mdot
.646 .10341 Mdot
.646 .10468 Mdot
.646 .10475 Mdot
.646 .10478 Mdot
.646 .10488 Mdot
.646 .10512 Mdot
.646 .10517 Mdot
.646 .10532 Mdot
.646 .10563 Mdot
.646 .10619 Mdot
.646 .10659 Mdot
.646 .10751 Mdot
.646 .10825 Mdot
.646 .10827 Mdot
.646 .10843 Mdot
.646 .10844 Mdot
.646 .10846 Mdot
.646 .10852 Mdot
.646 .10863 Mdot
.646 .10932 Mdot
.646 .10966 Mdot
.646 .10967 Mdot
.646 .10992 Mdot
.646 .11098 Mdot
.646 .11098 Mdot
.646 .11103 Mdot
.646 .11114 Mdot
.646 .11132 Mdot
.646 .11154 Mdot
.646 .11244 Mdot
.646 .11245 Mdot
.646 .11246 Mdot
.646 .11247 Mdot
.646 .11269 Mdot
.646 .11289 Mdot
.646 .11318 Mdot
.646 .11323 Mdot
.646 .11402 Mdot
.646 .11419 Mdot
.646 .1142 Mdot
.646 .11426 Mdot
.646 .11444 Mdot
.646 .11457 Mdot
.646 .1148 Mdot
.646 .11509 Mdot
.646 .11621 Mdot
.646 .11628 Mdot
.646 .1166 Mdot
.646 .1168 Mdot
.646 .11719 Mdot
.646 .11726 Mdot
.646 .11754 Mdot
.646 .11754 Mdot
.646 .11786 Mdot
.646 .11786 Mdot
.646 .11791 Mdot
.646 .11829 Mdot
.646 .11889 Mdot
.646 .11895 Mdot
.646 .11902 Mdot
.646 .11937 Mdot
.646 .1195 Mdot
.646 .11955 Mdot
.646 .11979 Mdot
.646 .12006 Mdot
.646 .1203 Mdot
.646 .12038 Mdot
.646 .12043 Mdot
.646 .12088 Mdot
.646 .12121 Mdot
.646 .12128 Mdot
.646 .12142 Mdot
.646 .12165 Mdot
.646 .12166 Mdot
.646 .12192 Mdot
.646 .12194 Mdot
.646 .12212 Mdot
.646 .12233 Mdot
.646 .1224 Mdot
.646 .12258 Mdot
.646 .1226 Mdot
.646 .12268 Mdot
.646 .12289 Mdot
.646 .12379 Mdot
.646 .12408 Mdot
.646 .12418 Mdot
.646 .12435 Mdot
.646 .12443 Mdot
.646 .12447 Mdot
.646 .12448 Mdot
.646 .12453 Mdot
.646 .1247 Mdot
.646 .1248 Mdot
.646 .12567 Mdot
.646 .12574 Mdot
.646 .12642 Mdot
.646 .12681 Mdot
.646 .1271 Mdot
.646 .12851 Mdot
.646 .12879 Mdot
.646 .12914 Mdot
.646 .12932 Mdot
.646 .13095 Mdot
.646 .13104 Mdot
.646 .13108 Mdot
.646 .13121 Mdot
.646 .13152 Mdot
.646 .13158 Mdot
.646 .13178 Mdot
.646 .13217 Mdot
.646 .1329 Mdot
.646 .13342 Mdot
.646 .1346 Mdot
.646 .13557 Mdot
.646 .13559 Mdot
.646 .1358 Mdot
.646 .13581 Mdot
.646 .13583 Mdot
.646 .13591 Mdot
.646 .13605 Mdot
.646 .13694 Mdot
.646 .13738 Mdot
.646 .13739 Mdot
.646 .13772 Mdot
.646 .13909 Mdot
.646 .13909 Mdot
.646 .13915 Mdot
.646 .13929 Mdot
.646 .13953 Mdot
.646 .13981 Mdot
.646 .14098 Mdot
.646 .14098 Mdot
.646 .141 Mdot
.646 .14102 Mdot
.646 .1413 Mdot
.646 .14156 Mdot
.646 .14194 Mdot
.646 .142 Mdot
.646 .14302 Mdot
.646 .14324 Mdot
.646 .14325 Mdot
.646 .14333 Mdot
.646 .14356 Mdot
.646 .14373 Mdot
.646 .14402 Mdot
.646 .1444 Mdot
.646 .14585 Mdot
.646 .14594 Mdot
.646 .14635 Mdot
.646 .1466 Mdot
.646 .14711 Mdot
.646 .1472 Mdot
.646 .14757 Mdot
.646 .14757 Mdot
.646 .14798 Mdot
.646 .14798 Mdot
.646 .14804 Mdot
.646 .14853 Mdot
.646 .14931 Mdot
.646 .14939 Mdot
.646 .14948 Mdot
.646 .14993 Mdot
.646 .15009 Mdot
.646 .15016 Mdot
.646 .15047 Mdot
.646 .15082 Mdot
.646 .15113 Mdot
.646 .15123 Mdot
.646 .1513 Mdot
.646 .15187 Mdot
.646 .15231 Mdot
.646 .1524 Mdot
.646 .15258 Mdot
.646 .15288 Mdot
.646 .15288 Mdot
.646 .15322 Mdot
.646 .15325 Mdot
.646 .15348 Mdot
.646 .15375 Mdot
.646 .15385 Mdot
.646 .15408 Mdot
.646 .1541 Mdot
.646 .15421 Mdot
.646 .15448 Mdot
.646 .15564 Mdot
.646 .15602 Mdot
.646 .15614 Mdot
.646 .15637 Mdot
.646 .15646 Mdot
.646 .15652 Mdot
.646 .15653 Mdot
.646 .1566 Mdot
.646 .15681 Mdot
.646 .15695 Mdot
.646 .15808 Mdot
.646 .15815 Mdot
.646 .15903 Mdot
.646 .15954 Mdot
.646 .15992 Mdot
.646 .16173 Mdot
.646 .1621 Mdot
.646 .16255 Mdot
.646 .16278 Mdot
.646 .1649 Mdot
.646 .16501 Mdot
.646 .16506 Mdot
.646 .16523 Mdot
.646 .16562 Mdot
.646 .16571 Mdot
.646 .16596 Mdot
.646 .16647 Mdot
.646 .16741 Mdot
.646 .16808 Mdot
.646 .16961 Mdot
.646 .17086 Mdot
.646 .17088 Mdot
.646 .17116 Mdot
.646 .17117 Mdot
.646 .1712 Mdot
.646 .17129 Mdot
.646 .17148 Mdot
.646 .17263 Mdot
.646 .1732 Mdot
.646 .17322 Mdot
.646 .17364 Mdot
.646 .17541 Mdot
.646 .17541 Mdot
.646 .17548 Mdot
.646 .17567 Mdot
.646 .17598 Mdot
.646 .17634 Mdot
.646 .17785 Mdot
.646 .17785 Mdot
.646 .17787 Mdot
.646 .1779 Mdot
.646 .17826 Mdot
.646 .1786 Mdot
.646 .17909 Mdot
.646 .17917 Mdot
.646 .18048 Mdot
.646 .18077 Mdot
.646 .18079 Mdot
.646 .18089 Mdot
.646 .18118 Mdot
.646 .1814 Mdot
.646 .18178 Mdot
.646 .18227 Mdot
.646 .18414 Mdot
.646 .18426 Mdot
.646 .18479 Mdot
.646 .18512 Mdot
.646 .18577 Mdot
.646 .18589 Mdot
.646 .18636 Mdot
.646 .18636 Mdot
.646 .18689 Mdot
.646 .18689 Mdot
.646 .18698 Mdot
.646 .1876 Mdot
.646 .18862 Mdot
.646 .18872 Mdot
.646 .18883 Mdot
.646 .18942 Mdot
.646 .18962 Mdot
.646 .18971 Mdot
.646 .19011 Mdot
.646 .19056 Mdot
.646 .19096 Mdot
.646 .1911 Mdot
.646 .19119 Mdot
.646 .19192 Mdot
.646 .19249 Mdot
.646 .1926 Mdot
.646 .19283 Mdot
.646 .19322 Mdot
.646 .19323 Mdot
.646 .19366 Mdot
.646 .19371 Mdot
.646 .194 Mdot
.646 .19435 Mdot
.646 .19448 Mdot
.646 .19477 Mdot
.646 .1948 Mdot
.646 .19494 Mdot
.646 .19529 Mdot
.646 .19679 Mdot
.646 .19728 Mdot
.646 .19743 Mdot
.646 .19773 Mdot
.646 .19785 Mdot
.646 .19793 Mdot
.646 .19794 Mdot
.646 .19803 Mdot
.646 .19831 Mdot
.646 .19848 Mdot
.646 .19994 Mdot
.646 .20004 Mdot
.646 .20117 Mdot
.646 .20182 Mdot
.646 .20232 Mdot
.646 .20466 Mdot
.646 .20513 Mdot
.646 .20572 Mdot
.646 .20601 Mdot
.646 .20875 Mdot
.646 .2089 Mdot
.646 .20896 Mdot
.646 .20918 Mdot
.646 .20969 Mdot
.646 .2098 Mdot
.646 .21012 Mdot
.646 .21078 Mdot
.646 .212 Mdot
.646 .21287 Mdot
.646 .21484 Mdot
.646 .21645 Mdot
.646 .21649 Mdot
.646 .21684 Mdot
.646 .21686 Mdot
.646 .21689 Mdot
.646 .21702 Mdot
.646 .21726 Mdot
.646 .21874 Mdot
.646 .21948 Mdot
.646 .2195 Mdot
.646 .22004 Mdot
.646 .22234 Mdot
.646 .22234 Mdot
.646 .22243 Mdot
.646 .22267 Mdot
.646 .22307 Mdot
.646 .22353 Mdot
.646 .22548 Mdot
.646 .22549 Mdot
.646 .22551 Mdot
.646 .22555 Mdot
.646 .22601 Mdot
.646 .22645 Mdot
.646 .22708 Mdot
.646 .22719 Mdot
.646 .22888 Mdot
.646 .22926 Mdot
.646 .22928 Mdot
.646 .22941 Mdot
.646 .22979 Mdot
.646 .23007 Mdot
.646 .23056 Mdot
.646 .23119 Mdot
.646 .23361 Mdot
.646 .23377 Mdot
.646 .23445 Mdot
.646 .23487 Mdot
.646 .23571 Mdot
.646 .23587 Mdot
.646 .23648 Mdot
.646 .23649 Mdot
.646 .23716 Mdot
.646 .23717 Mdot
.646 .23728 Mdot
.646 .23809 Mdot
.646 .2394 Mdot
.646 .23953 Mdot
.646 .23967 Mdot
.646 .24043 Mdot
.646 .24069 Mdot
.646 .2408 Mdot
.646 .24132 Mdot
.646 .24191 Mdot
.646 .24242 Mdot
.646 .2426 Mdot
.646 .24272 Mdot
.646 .24367 Mdot
.646 .2444 Mdot
.646 .24454 Mdot
.646 .24485 Mdot
.646 .24535 Mdot
.646 .24535 Mdot
.646 .24591 Mdot
.646 .24597 Mdot
.646 .24635 Mdot
.646 .24681 Mdot
.646 .24697 Mdot
.646 .24735 Mdot
.646 .24738 Mdot
.646 .24757 Mdot
.646 .24802 Mdot
.646 .24996 Mdot
.646 .25058 Mdot
.646 .25079 Mdot
.646 .25117 Mdot
.646 .25133 Mdot
.646 .25143 Mdot
.646 .25145 Mdot
.646 .25156 Mdot
.646 .25192 Mdot
.646 .25214 Mdot
.646 .25402 Mdot
.646 .25415 Mdot
.646 .25562 Mdot
.646 .25646 Mdot
.646 .2571 Mdot
.646 .26013 Mdot
.646 .26073 Mdot
.646 .26149 Mdot
.646 .26187 Mdot
.646 .26541 Mdot
.646 .2656 Mdot
.646 .26568 Mdot
.646 .26597 Mdot
.646 .26662 Mdot
.646 .26676 Mdot
.646 .26718 Mdot
.646 .26803 Mdot
.646 .2696 Mdot
.646 .27073 Mdot
.646 .27328 Mdot
.646 .27535 Mdot
.646 .2754 Mdot
.646 .27586 Mdot
.646 .27588 Mdot
.646 .27593 Mdot
.646 .27609 Mdot
.646 .2764 Mdot
.646 .27832 Mdot
.646 .27927 Mdot
.646 .2793 Mdot
.646 .28 Mdot
.646 .28296 Mdot
.646 .28296 Mdot
.646 .28308 Mdot
.646 .28339 Mdot
.646 .2839 Mdot
.646 .28451 Mdot
.646 .28703 Mdot
.646 .28704 Mdot
.646 .28706 Mdot
.646 .28712 Mdot
.646 .28771 Mdot
.646 .28828 Mdot
.646 .28909 Mdot
.646 .28923 Mdot
.646 .29142 Mdot
.646 .2919 Mdot
.646 .29193 Mdot
.646 .2921 Mdot
.646 .29259 Mdot
.646 .29295 Mdot
.646 .29359 Mdot
.646 .29441 Mdot
.646 .29753 Mdot
.646 .29773 Mdot
.646 .29861 Mdot
.646 .29916 Mdot
.646 .30024 Mdot
.646 .30045 Mdot
.646 .30124 Mdot
.646 .30124 Mdot
.646 .30212 Mdot
.646 .30212 Mdot
.646 .30226 Mdot
.646 .30331 Mdot
.646 .305 Mdot
.646 .30517 Mdot
.646 .30536 Mdot
.646 .30634 Mdot
.646 .30668 Mdot
.646 .30682 Mdot
.646 .30749 Mdot
.646 .30825 Mdot
.646 .30891 Mdot
.646 .30914 Mdot
.646 .3093 Mdot
.646 .31052 Mdot
.646 .31147 Mdot
.646 .31165 Mdot
.646 .31204 Mdot
.646 .31269 Mdot
.646 .3127 Mdot
.646 .31342 Mdot
.646 .3135 Mdot
.646 .31399 Mdot
.646 .31458 Mdot
.646 .31478 Mdot
.646 .31528 Mdot
.646 .31532 Mdot
.646 .31556 Mdot
.646 .31615 Mdot
.646 .31865 Mdot
.646 .31946 Mdot
.646 .31972 Mdot
.646 .32022 Mdot
.646 .32042 Mdot
.646 .32055 Mdot
.646 .32057 Mdot
.646 .32072 Mdot
.646 .32118 Mdot
.646 .32146 Mdot
.646 .3239 Mdot
.646 .32407 Mdot
.646 .32596 Mdot
.646 .32705 Mdot
.646 .32788 Mdot
.646 .33179 Mdot
.646 .33257 Mdot
.646 .33355 Mdot
.646 .33404 Mdot
.646 .33861 Mdot
.646 .33886 Mdot
.646 .33896 Mdot
.646 .33933 Mdot
.646 .34017 Mdot
.646 .34036 Mdot
.646 .3409 Mdot
.646 .342 Mdot
.646 .34403 Mdot
.646 .34548 Mdot
.646 .34877 Mdot
.646 .35146 Mdot
.646 .35152 Mdot
.646 .35211 Mdot
.646 .35214 Mdot
.646 .35221 Mdot
.646 .35241 Mdot
.646 .35281 Mdot
.646 .35529 Mdot
.646 .35652 Mdot
.646 .35655 Mdot
.646 .35746 Mdot
.646 .36129 Mdot
.646 .36129 Mdot
.646 .36144 Mdot
.646 .36185 Mdot
.646 .36251 Mdot
.646 .36329 Mdot
.646 .36655 Mdot
.646 .36656 Mdot
.646 .36659 Mdot
.646 .36666 Mdot
.646 .36743 Mdot
.646 .36816 Mdot
.646 .36921 Mdot
.646 .36939 Mdot
.646 .37222 Mdot
.646 .37284 Mdot
.646 .37288 Mdot
.646 .37309 Mdot
.646 .37373 Mdot
.646 .3742 Mdot
.646 .37502 Mdot
.646 .37608 Mdot
.646 .38011 Mdot
.646 .38037 Mdot
.646 .38151 Mdot
.646 .38222 Mdot
.646 .38362 Mdot
.646 .38389 Mdot
.646 .38491 Mdot
.646 .38491 Mdot
.646 .38517 Mdot
.646 .38604 Mdot
.646 .38605 Mdot
.646 .38623 Mdot
.646 .38758 Mdot
.646 .38977 Mdot
.646 .38998 Mdot
.646 .39023 Mdot
.646 .3915 Mdot
.646 .39193 Mdot
.646 .39212 Mdot
.646 .39299 Mdot
.646 .39396 Mdot
.646 .39482 Mdot
.646 .39512 Mdot
.646 .39531 Mdot
.648 .01509 Mdot
.648 .0152 Mdot
.648 .01534 Mdot
.648 .01538 Mdot
.648 .01553 Mdot
.648 .01558 Mdot
.648 .01565 Mdot
.648 .01577 Mdot
.648 .01583 Mdot
.648 .01585 Mdot
.648 .01592 Mdot
.648 .01603 Mdot
.648 .01608 Mdot
.648 .01616 Mdot
.648 .01618 Mdot
.648 .01628 Mdot
.648 .0164 Mdot
.648 .01642 Mdot
.648 .01649 Mdot
.648 .01659 Mdot
.648 .01662 Mdot
.648 .01674 Mdot
.648 .0169 Mdot
.648 .01693 Mdot
.648 .01701 Mdot
.648 .01712 Mdot
.648 .01715 Mdot
.648 .01718 Mdot
.648 .01734 Mdot
.648 .01755 Mdot
.648 .01759 Mdot
.648 .01769 Mdot
.648 .01784 Mdot
.648 .01787 Mdot
.648 .01791 Mdot
.648 .01812 Mdot
.648 .01833 Mdot
.648 .01839 Mdot
.648 .01844 Mdot
.648 .01857 Mdot
.648 .01872 Mdot
.648 .01876 Mdot
.648 .01881 Mdot
.648 .01885 Mdot
.648 .01912 Mdot
.648 .01939 Mdot
.648 .01947 Mdot
.648 .01954 Mdot
.648 .01965 Mdot
.648 .01971 Mdot
.648 .01991 Mdot
.648 .01996 Mdot
.648 .02002 Mdot
.648 .02008 Mdot
.648 .02043 Mdot
.648 .02078 Mdot
.648 .02088 Mdot
.648 .02097 Mdot
.648 .02112 Mdot
.648 .02119 Mdot
.648 .02145 Mdot
.648 .02149 Mdot
.648 .02151 Mdot
.648 .02158 Mdot
.648 .02167 Mdot
.648 .02176 Mdot
.648 .02201 Mdot
.648 .02212 Mdot
.648 .02257 Mdot
.648 .02271 Mdot
.648 .02282 Mdot
.648 .02301 Mdot
.648 .0231 Mdot
.648 .02344 Mdot
.648 .0235 Mdot
.648 .02352 Mdot
.648 .02362 Mdot
.648 .02372 Mdot
.648 .02385 Mdot
.648 .02417 Mdot
.648 .02431 Mdot
.648 .02441 Mdot
.648 .0249 Mdot
.648 .02507 Mdot
.648 .02521 Mdot
.648 .02543 Mdot
.648 .02547 Mdot
.648 .02559 Mdot
.648 .02602 Mdot
.648 .0261 Mdot
.648 .02613 Mdot
.648 .02625 Mdot
.648 .02639 Mdot
.648 .02655 Mdot
.648 .02673 Mdot
.648 .02697 Mdot
.648 .02715 Mdot
.648 .02728 Mdot
.648 .02739 Mdot
.648 .02766 Mdot
.648 .02792 Mdot
.648 .02814 Mdot
.648 .02832 Mdot
.648 .0286 Mdot
.648 .02865 Mdot
.648 .02881 Mdot
.648 .02937 Mdot
.648 .02947 Mdot
.648 .0295 Mdot
.648 .02967 Mdot
.648 .02985 Mdot
.648 .03006 Mdot
.648 .03029 Mdot
.648 .0306 Mdot
.648 .03083 Mdot
.648 .03085 Mdot
.648 .031 Mdot
.648 .03114 Mdot
.648 .03143 Mdot
.648 .03149 Mdot
.648 .0315 Mdot
.648 .03182 Mdot
.648 .03196 Mdot
.648 .03211 Mdot
.648 .03221 Mdot
.648 .03235 Mdot
.648 .03271 Mdot
.648 .03277 Mdot
.648 .03298 Mdot
.648 .0337 Mdot
.648 .03383 Mdot
.648 .03388 Mdot
.648 .03409 Mdot
.648 .03433 Mdot
.648 .0346 Mdot
.648 .03489 Mdot
.648 .0353 Mdot
.648 .0356 Mdot
.648 .03562 Mdot
.648 .03564 Mdot
.648 .03582 Mdot
.648 .036 Mdot
.648 .03638 Mdot
.648 .03646 Mdot
.648 .03646 Mdot
.648 .03689 Mdot
.648 .03691 Mdot
.648 .03707 Mdot
.648 .03726 Mdot
.648 .03739 Mdot
.648 .03757 Mdot
.648 .03784 Mdot
.648 .03804 Mdot
.648 .03812 Mdot
.648 .03838 Mdot
.648 .0387 Mdot
.648 .03932 Mdot
.648 .03949 Mdot
.648 .03956 Mdot
.648 .03983 Mdot
.648 .04002 Mdot
.648 .04013 Mdot
.648 .04048 Mdot
.648 .04087 Mdot
.648 .04133 Mdot
.648 .04139 Mdot
.648 .04149 Mdot
.648 .04155 Mdot
.648 .04178 Mdot
.648 .04181 Mdot
.648 .04183 Mdot
.648 .04183 Mdot
.648 .04207 Mdot
.648 .0423 Mdot
.648 .04237 Mdot
.648 .04279 Mdot
.648 .04289 Mdot
.648 .0429 Mdot
.648 .04345 Mdot
.648 .04348 Mdot
.648 .04368 Mdot
.648 .04393 Mdot
.648 .04411 Mdot
.648 .04433 Mdot
.648 .04467 Mdot
.648 .04469 Mdot
.648 .04495 Mdot
.648 .04504 Mdot
.648 .04539 Mdot
.648 .0458 Mdot
.648 .0461 Mdot
.648 .04661 Mdot
.648 .04682 Mdot
.648 .04691 Mdot
.648 .04708 Mdot
.648 .04727 Mdot
.648 .04751 Mdot
.648 .04765 Mdot
.648 .04811 Mdot
.648 .04861 Mdot
.648 .04921 Mdot
.648 .04929 Mdot
.648 .04942 Mdot
.648 .04949 Mdot
.648 .0498 Mdot
.648 .04983 Mdot
.648 .04985 Mdot
.648 .04986 Mdot
.648 .05016 Mdot
.648 .05046 Mdot
.648 .05056 Mdot
.648 .05102 Mdot
.648 .0511 Mdot
.648 .05123 Mdot
.648 .05125 Mdot
.648 .05196 Mdot
.648 .052 Mdot
.648 .05226 Mdot
.648 .05257 Mdot
.648 .05281 Mdot
.648 .0531 Mdot
.648 .05343 Mdot
.648 .05353 Mdot
.648 .05356 Mdot
.648 .0539 Mdot
.648 .05402 Mdot
.648 .05447 Mdot
.648 .05501 Mdot
.648 .05539 Mdot
.648 .05562 Mdot
.648 .05605 Mdot
.648 .05633 Mdot
.648 .05633 Mdot
.648 .05644 Mdot
.648 .05667 Mdot
.648 .0569 Mdot
.648 .05722 Mdot
.648 .0574 Mdot
.648 .05781 Mdot
.648 .05784 Mdot
.648 .058 Mdot
.648 .05864 Mdot
.648 .05942 Mdot
.648 .05953 Mdot
.648 .05969 Mdot
.648 .05978 Mdot
.648 .06018 Mdot
.648 .06023 Mdot
.648 .06026 Mdot
.648 .06026 Mdot
.648 .06054 Mdot
.648 .06066 Mdot
.648 .06074 Mdot
.648 .06074 Mdot
.648 .06102 Mdot
.648 .06104 Mdot
.648 .06117 Mdot
.648 .06176 Mdot
.648 .06185 Mdot
.648 .06187 Mdot
.648 .06204 Mdot
.648 .06206 Mdot
.648 .06298 Mdot
.648 .06303 Mdot
.648 .06308 Mdot
.648 .06337 Mdot
.648 .06378 Mdot
.648 .06408 Mdot
.648 .06421 Mdot
.648 .06446 Mdot
.648 .06489 Mdot
.648 .06496 Mdot
.648 .06497 Mdot
.648 .06506 Mdot
.648 .06549 Mdot
.648 .06565 Mdot
.648 .06624 Mdot
.648 .06663 Mdot
.648 .06693 Mdot
.648 .06743 Mdot
.648 .06773 Mdot
.648 .06828 Mdot
.648 .06828 Mdot
.648 .06865 Mdot
.648 .06865 Mdot
.648 .06879 Mdot
.648 .06894 Mdot
.648 .06908 Mdot
.648 .06939 Mdot
.648 .06959 Mdot
.648 .0698 Mdot
.648 .06992 Mdot
.648 .06996 Mdot
.648 .07004 Mdot
.648 .07057 Mdot
.648 .0706 Mdot
.648 .07081 Mdot
.648 .07084 Mdot
.648 .0712 Mdot
.648 .07164 Mdot
.648 .07181 Mdot
.648 .07265 Mdot
.648 .07279 Mdot
.648 .073 Mdot
.648 .07312 Mdot
.648 .07364 Mdot
.648 .0737 Mdot
.648 .07374 Mdot
.648 .07374 Mdot
.648 .07411 Mdot
.648 .07425 Mdot
.648 .07436 Mdot
.648 .07436 Mdot
.648 .07473 Mdot
.648 .07475 Mdot
.648 .07492 Mdot
.648 .07569 Mdot
.648 .0758 Mdot
.648 .07582 Mdot
.648 .07605 Mdot
.648 .07606 Mdot
.648 .07607 Mdot
.648 .07628 Mdot
.648 .07727 Mdot
.648 .07733 Mdot
.648 .07739 Mdot
.648 .07777 Mdot
.648 .07792 Mdot
.648 .07822 Mdot
.648 .0783 Mdot
.648 .0787 Mdot
.648 .07886 Mdot
.648 .07907 Mdot
.648 .07918 Mdot
.648 .07974 Mdot
.648 .07984 Mdot
.648 .07985 Mdot
.648 .07992 Mdot
.648 .07997 Mdot
.648 .08052 Mdot
.648 .08073 Mdot
.648 .08102 Mdot
.648 .08149 Mdot
.648 .08162 Mdot
.648 .08199 Mdot
.648 .08239 Mdot
.648 .08303 Mdot
.648 .08342 Mdot
.648 .08413 Mdot
.648 .08414 Mdot
.648 .08458 Mdot
.648 .08461 Mdot
.648 .08461 Mdot
.648 .08479 Mdot
.648 .08499 Mdot
.648 .08518 Mdot
.648 .08557 Mdot
.648 .08584 Mdot
.648 .08595 Mdot
.648 .08605 Mdot
.648 .08611 Mdot
.648 .08626 Mdot
.648 .08631 Mdot
.648 .08641 Mdot
.648 .08711 Mdot
.648 .08714 Mdot
.648 .08741 Mdot
.648 .08746 Mdot
.648 .08791 Mdot
.648 .08849 Mdot
.648 .08872 Mdot
.648 .0898 Mdot
.648 .08998 Mdot
.648 .09025 Mdot
.648 .09041 Mdot
.648 .09108 Mdot
.648 .09116 Mdot
.648 .09121 Mdot
.648 .09122 Mdot
.648 .09169 Mdot
.648 .09188 Mdot
.648 .09201 Mdot
.648 .09201 Mdot
.648 .0925 Mdot
.648 .09253 Mdot
.648 .09258 Mdot
.648 .09274 Mdot
.648 .09372 Mdot
.648 .09374 Mdot
.648 .09389 Mdot
.648 .09391 Mdot
.648 .0942 Mdot
.648 .09421 Mdot
.648 .09423 Mdot
.648 .0945 Mdot
.648 .09537 Mdot
.648 .09578 Mdot
.648 .09587 Mdot
.648 .09594 Mdot
.648 .09635 Mdot
.648 .09643 Mdot
.648 .09663 Mdot
.648 .09702 Mdot
.648 .09713 Mdot
.648 .09763 Mdot
.648 .09785 Mdot
.648 .09812 Mdot
.648 .09826 Mdot
.648 .09899 Mdot
.648 .09911 Mdot
.648 .09913 Mdot
.648 .09923 Mdot
.648 .09928 Mdot
.648 .1 Mdot
.648 .10027 Mdot
.648 .10047 Mdot
.648 .10065 Mdot
.648 .10093 Mdot
.648 .10124 Mdot
.648 .10125 Mdot
.648 .10131 Mdot
.648 .10142 Mdot
.648 .10191 Mdot
.648 .10242 Mdot
.648 .10325 Mdot
.648 .10376 Mdot
.648 .10422 Mdot
.648 .10437 Mdot
.648 .10468 Mdot
.648 .10469 Mdot
.648 .10526 Mdot
.648 .1053 Mdot
.648 .1053 Mdot
.648 .10536 Mdot
.648 .10554 Mdot
.648 .10579 Mdot
.648 .10603 Mdot
.648 .10619 Mdot
.648 .10619 Mdot
.648 .10654 Mdot
.648 .10689 Mdot
.648 .10703 Mdot
.648 .10717 Mdot
.648 .10724 Mdot
.648 .10725 Mdot
.648 .10743 Mdot
.648 .10751 Mdot
.648 .10764 Mdot
.648 .10853 Mdot
.648 .10858 Mdot
.648 .10893 Mdot
.648 .10899 Mdot
.648 .10917 Mdot
.648 .10935 Mdot
.648 .10958 Mdot
.648 .10971 Mdot
.648 .11033 Mdot
.648 .11062 Mdot
.648 .11064 Mdot
.648 .11202 Mdot
.648 .11226 Mdot
.648 .11261 Mdot
.648 .11282 Mdot
.648 .11368 Mdot
.648 .11378 Mdot
.648 .11385 Mdot
.648 .11386 Mdot
.648 .11448 Mdot
.648 .11451 Mdot
.648 .11472 Mdot
.648 .11489 Mdot
.648 .11489 Mdot
.648 .11512 Mdot
.648 .11552 Mdot
.648 .11556 Mdot
.648 .11563 Mdot
.648 .11583 Mdot
.648 .11665 Mdot
.648 .11678 Mdot
.648 .1171 Mdot
.648 .11713 Mdot
.648 .11732 Mdot
.648 .11735 Mdot
.648 .11771 Mdot
.648 .11773 Mdot
.648 .11775 Mdot
.648 .11777 Mdot
.648 .11785 Mdot
.648 .11811 Mdot
.648 .11924 Mdot
.648 .11952 Mdot
.648 .11963 Mdot
.648 .11971 Mdot
.648 .11978 Mdot
.648 .11983 Mdot
.648 .11989 Mdot
.648 .11999 Mdot
.648 .12018 Mdot
.648 .12051 Mdot
.648 .12062 Mdot
.648 .12088 Mdot
.648 .12138 Mdot
.648 .12145 Mdot
.648 .12152 Mdot
.648 .12218 Mdot
.648 .12246 Mdot
.648 .12281 Mdot
.648 .12299 Mdot
.648 .12394 Mdot
.648 .1241 Mdot
.648 .12412 Mdot
.648 .12424 Mdot
.648 .12431 Mdot
.648 .12525 Mdot
.648 .1256 Mdot
.648 .12585 Mdot
.648 .12609 Mdot
.648 .12645 Mdot
.648 .1268 Mdot
.648 .12685 Mdot
.648 .12686 Mdot
.648 .12694 Mdot
.648 .12709 Mdot
.648 .12772 Mdot
.648 .12811 Mdot
.648 .12838 Mdot
.648 .12945 Mdot
.648 .13011 Mdot
.648 .13071 Mdot
.648 .13091 Mdot
.648 .13131 Mdot
.648 .13132 Mdot
.648 .13206 Mdot
.648 .13211 Mdot
.648 .13211 Mdot
.648 .13219 Mdot
.648 .13242 Mdot
.648 .13275 Mdot
.648 .13306 Mdot
.648 .13327 Mdot
.648 .13327 Mdot
.648 .13372 Mdot
.648 .13418 Mdot
.648 .13436 Mdot
.648 .13454 Mdot
.648 .13462 Mdot
.648 .13464 Mdot
.648 .13488 Mdot
.648 .13497 Mdot
.648 .13514 Mdot
.648 .1363 Mdot
.648 .13636 Mdot
.648 .13681 Mdot
.648 .13689 Mdot
.648 .13713 Mdot
.648 .13736 Mdot
.648 .13766 Mdot
.648 .13782 Mdot
.648 .13863 Mdot
.648 .13901 Mdot
.648 .13904 Mdot
.648 .14082 Mdot
.648 .14113 Mdot
.648 .14159 Mdot
.648 .14185 Mdot
.648 .14298 Mdot
.648 .14311 Mdot
.648 .14319 Mdot
.648 .14321 Mdot
.648 .14401 Mdot
.648 .14405 Mdot
.648 .14432 Mdot
.648 .14455 Mdot
.648 .14455 Mdot
.648 .14483 Mdot
.648 .14536 Mdot
.648 .14541 Mdot
.648 .14551 Mdot
.648 .14576 Mdot
.648 .14682 Mdot
.648 .14699 Mdot
.648 .1474 Mdot
.648 .14744 Mdot
.648 .14769 Mdot
.648 .14773 Mdot
.648 .14819 Mdot
.648 .14822 Mdot
.648 .14824 Mdot
.648 .14828 Mdot
.648 .14837 Mdot
.648 .14872 Mdot
.648 .15018 Mdot
.648 .15054 Mdot
.648 .15068 Mdot
.648 .15079 Mdot
.648 .15088 Mdot
.648 .15095 Mdot
.648 .15102 Mdot
.648 .15115 Mdot
.648 .1514 Mdot
.648 .15183 Mdot
.648 .15197 Mdot
.648 .1523 Mdot
.648 .15295 Mdot
.648 .15305 Mdot
.648 .15314 Mdot
.648 .15399 Mdot
.648 .15435 Mdot
.648 .15481 Mdot
.648 .15504 Mdot
.648 .15627 Mdot
.648 .15647 Mdot
.648 .1565 Mdot
.648 .15666 Mdot
.648 .15675 Mdot
.648 .15797 Mdot
.648 .15842 Mdot
.648 .15875 Mdot
.648 .15905 Mdot
.648 .15952 Mdot
.648 .15998 Mdot
.648 .16004 Mdot
.648 .16006 Mdot
.648 .16016 Mdot
.648 .16035 Mdot
.648 .16117 Mdot
.648 .16167 Mdot
.648 .16202 Mdot
.648 .16342 Mdot
.648 .16427 Mdot
.648 .16505 Mdot
.648 .1653 Mdot
.648 .16583 Mdot
.648 .16583 Mdot
.648 .16679 Mdot
.648 .16686 Mdot
.648 .16686 Mdot
.648 .16696 Mdot
.648 .16726 Mdot
.648 .16769 Mdot
.648 .16809 Mdot
.648 .16836 Mdot
.648 .16836 Mdot
.648 .16895 Mdot
.648 .16954 Mdot
.648 .16977 Mdot
.648 .17 Mdot
.648 .17012 Mdot
.648 .17013 Mdot
.648 .17044 Mdot
.648 .17057 Mdot
.648 .17079 Mdot
.648 .17229 Mdot
.648 .17237 Mdot
.648 .17295 Mdot
.648 .17306 Mdot
.648 .17336 Mdot
.648 .17366 Mdot
.648 .17405 Mdot
.648 .17426 Mdot
.648 .17531 Mdot
.648 .1758 Mdot
.648 .17584 Mdot
.648 .17815 Mdot
.648 .17855 Mdot
.648 .17914 Mdot
.648 .17949 Mdot
.648 .18095 Mdot
.648 .18111 Mdot
.648 .18122 Mdot
.648 .18124 Mdot
.648 .18228 Mdot
.648 .18233 Mdot
.648 .18268 Mdot
.648 .18297 Mdot
.648 .18298 Mdot
.648 .18335 Mdot
.648 .18403 Mdot
.648 .18409 Mdot
.648 .18422 Mdot
.648 .18455 Mdot
.648 .18592 Mdot
.648 .18614 Mdot
.648 .18668 Mdot
.648 .18673 Mdot
.648 .18706 Mdot
.648 .18711 Mdot
.648 .1877 Mdot
.648 .18774 Mdot
.648 .18777 Mdot
.648 .18781 Mdot
.648 .18793 Mdot
.648 .18838 Mdot
.648 .19028 Mdot
.648 .19074 Mdot
.648 .19093 Mdot
.648 .19106 Mdot
.648 .19118 Mdot
.648 .19128 Mdot
.648 .19136 Mdot
.648 .19153 Mdot
.648 .19186 Mdot
.648 .19241 Mdot
.648 .1926 Mdot
.648 .19302 Mdot
.648 .19387 Mdot
.648 .19399 Mdot
.648 .19411 Mdot
.648 .19521 Mdot
.648 .19568 Mdot
.648 .19628 Mdot
.648 .19658 Mdot
.648 .19817 Mdot
.648 .19843 Mdot
.648 .19847 Mdot
.648 .19868 Mdot
.648 .1988 Mdot
.648 .20037 Mdot
.648 .20095 Mdot
.648 .20138 Mdot
.648 .20178 Mdot
.648 .20238 Mdot
.648 .20298 Mdot
.648 .20306 Mdot
.648 .20308 Mdot
.648 .20321 Mdot
.648 .20346 Mdot
.648 .20452 Mdot
.648 .20517 Mdot
.648 .20563 Mdot
.648 .20743 Mdot
.648 .20854 Mdot
.648 .20955 Mdot
.648 .20987 Mdot
.648 .21056 Mdot
.648 .21057 Mdot
.648 .21181 Mdot
.648 .2119 Mdot
.648 .2119 Mdot
.648 .21203 Mdot
.648 .21241 Mdot
.648 .21297 Mdot
.648 .21349 Mdot
.648 .21384 Mdot
.648 .21384 Mdot
.648 .2146 Mdot
.648 .21536 Mdot
.648 .21567 Mdot
.648 .21597 Mdot
.648 .21612 Mdot
.648 .21614 Mdot
.648 .21654 Mdot
.648 .2167 Mdot
.648 .21699 Mdot
.648 .21894 Mdot
.648 .21904 Mdot
.648 .21979 Mdot
.648 .21993 Mdot
.648 .22032 Mdot
.648 .22071 Mdot
.648 .22122 Mdot
.648 .22149 Mdot
.648 .22285 Mdot
.648 .22348 Mdot
.648 .22353 Mdot
.648 .22653 Mdot
.648 .22705 Mdot
.648 .22781 Mdot
.648 .22826 Mdot
.648 .23015 Mdot
.648 .23036 Mdot
.648 .2305 Mdot
.648 .23054 Mdot
.648 .23187 Mdot
.648 .23194 Mdot
.648 .2324 Mdot
.648 .23278 Mdot
.648 .23278 Mdot
.648 .23326 Mdot
.648 .23415 Mdot
.648 .23423 Mdot
.648 .23439 Mdot
.648 .23482 Mdot
.648 .2366 Mdot
.648 .23688 Mdot
.648 .23758 Mdot
.648 .23764 Mdot
.648 .23807 Mdot
.648 .23813 Mdot
.648 .2389 Mdot
.648 .23895 Mdot
.648 .23899 Mdot
.648 .23905 Mdot
.648 .23921 Mdot
.648 .23979 Mdot
.648 .24225 Mdot
.648 .24285 Mdot
.648 .24309 Mdot
.648 .24326 Mdot
.648 .24342 Mdot
.648 .24354 Mdot
.648 .24365 Mdot
.648 .24387 Mdot
.648 .2443 Mdot
.648 .24501 Mdot
.648 .24525 Mdot
.648 .2458 Mdot
.648 .2469 Mdot
.648 .24706 Mdot
.648 .24721 Mdot
.648 .24864 Mdot
.648 .24924 Mdot
.648 .25002 Mdot
.648 .25041 Mdot
.648 .25247 Mdot
.648 .25281 Mdot
.648 .25286 Mdot
.648 .25313 Mdot
.648 .25328 Mdot
.648 .25532 Mdot
.648 .25608 Mdot
.648 .25663 Mdot
.648 .25715 Mdot
.648 .25793 Mdot
.648 .25871 Mdot
.648 .25881 Mdot
.648 .25884 Mdot
.648 .25901 Mdot
.648 .25933 Mdot
.648 .2607 Mdot
.648 .26155 Mdot
.648 .26214 Mdot
.648 .26448 Mdot
.648 .26591 Mdot
.648 .26722 Mdot
.648 .26764 Mdot
.648 .26852 Mdot
.648 .26854 Mdot
.648 .27015 Mdot
.648 .27026 Mdot
.648 .27026 Mdot
.648 .27044 Mdot
.648 .27093 Mdot
.648 .27166 Mdot
.648 .27233 Mdot
.648 .27278 Mdot
.648 .27279 Mdot
.648 .27377 Mdot
.648 .27476 Mdot
.648 .27515 Mdot
.648 .27554 Mdot
.648 .27573 Mdot
.648 .27576 Mdot
.648 .27628 Mdot
.648 .27649 Mdot
.648 .27686 Mdot
.648 .27939 Mdot
.648 .27952 Mdot
.648 .28049 Mdot
.648 .28067 Mdot
.648 .28118 Mdot
.648 .28169 Mdot
.648 .28234 Mdot
.648 .2827 Mdot
.648 .28446 Mdot
.648 .28527 Mdot
.648 .28534 Mdot
.648 .28923 Mdot
.648 .2899 Mdot
.648 .29088 Mdot
.648 .29147 Mdot
.648 .29392 Mdot
.648 .29419 Mdot
.648 .29438 Mdot
.648 .29442 Mdot
.648 .29615 Mdot
.648 .29624 Mdot
.648 .29683 Mdot
.648 .29733 Mdot
.648 .29733 Mdot
.648 .29795 Mdot
.648 .2991 Mdot
.648 .29921 Mdot
.648 .29942 Mdot
.648 .29998 Mdot
.648 .30228 Mdot
.648 .30264 Mdot
.648 .30355 Mdot
.648 .30363 Mdot
.648 .30418 Mdot
.648 .30427 Mdot
.648 .30526 Mdot
.648 .30533 Mdot
.648 .30537 Mdot
.648 .30545 Mdot
.648 .30566 Mdot
.648 .30641 Mdot
.648 .3096 Mdot
.648 .31038 Mdot
.648 .31068 Mdot
.648 .31091 Mdot
.648 .31111 Mdot
.648 .31127 Mdot
.648 .31141 Mdot
.648 .3117 Mdot
.648 .31225 Mdot
.648 .31318 Mdot
.648 .31349 Mdot
.648 .31421 Mdot
.648 .31562 Mdot
.648 .31583 Mdot
.648 .31603 Mdot
.648 .31788 Mdot
.648 .31866 Mdot
.648 .31967 Mdot
.648 .32017 Mdot
.648 .32284 Mdot
.648 .32329 Mdot
.648 .32335 Mdot
.648 .3237 Mdot
.648 .3239 Mdot
.648 .32654 Mdot
.648 .32752 Mdot
.648 .32824 Mdot
.648 .32891 Mdot
.648 .32992 Mdot
.648 .33093 Mdot
.648 .33106 Mdot
.648 .3311 Mdot
.648 .33132 Mdot
.648 .33174 Mdot
.648 .33351 Mdot
.648 .33461 Mdot
.648 .33537 Mdot
.648 .33841 Mdot
.648 .34027 Mdot
.648 .34196 Mdot
.648 .34251 Mdot
.648 .34365 Mdot
.648 .34367 Mdot
.648 .34576 Mdot
.648 .34591 Mdot
.648 .34591 Mdot
.648 .34613 Mdot
.648 .34677 Mdot
.648 .34771 Mdot
.648 .34859 Mdot
.648 .34917 Mdot
.648 .34918 Mdot
.648 .35045 Mdot
.648 .35173 Mdot
.648 .35224 Mdot
.648 .35274 Mdot
.648 .35299 Mdot
.648 .35302 Mdot
.648 .35371 Mdot
.648 .35398 Mdot
.648 .35445 Mdot
.648 .35773 Mdot
.648 .3579 Mdot
.648 .35917 Mdot
.648 .3594 Mdot
.648 .36005 Mdot
.648 .36071 Mdot
.648 .36156 Mdot
.648 .36202 Mdot
.648 .3643 Mdot
.648 .36536 Mdot
.648 .36544 Mdot
.648 .37048 Mdot
.648 .37135 Mdot
.648 .37263 Mdot
.648 .37339 Mdot
.648 .37656 Mdot
.648 .37692 Mdot
.648 .37716 Mdot
.648 .37721 Mdot
.648 .37946 Mdot
.648 .37957 Mdot
.648 .38034 Mdot
.648 .38098 Mdot
.648 .38098 Mdot
.648 .38179 Mdot
.648 .38328 Mdot
.648 .38342 Mdot
.648 .38369 Mdot
.648 .38441 Mdot
.648 .3874 Mdot
.648 .38787 Mdot
.648 .38905 Mdot
.648 .38915 Mdot
.648 .38986 Mdot
.648 .38997 Mdot
.648 .39126 Mdot
.648 .39135 Mdot
.648 .39141 Mdot
.648 .39151 Mdot
.648 .39178 Mdot
.648 .39276 Mdot
.648 .39688 Mdot
.648 .39789 Mdot
.65 .01609 Mdot
.65 .0165 Mdot
.65 .01704 Mdot
.65 .01773 Mdot
.65 .01864 Mdot
.65 .01881 Mdot
.65 .01953 Mdot
.65 .01966 Mdot
.65 .01981 Mdot
.65 .02004 Mdot
.65 .02035 Mdot
.65 .02094 Mdot
.65 .02098 Mdot
.65 .02115 Mdot
.65 .02129 Mdot
.65 .02134 Mdot
.65 .02163 Mdot
.65 .02164 Mdot
.65 .02171 Mdot
.65 .02195 Mdot
.65 .02204 Mdot
.65 .0228 Mdot
.65 .02286 Mdot
.65 .02303 Mdot
.65 .02308 Mdot
.65 .02326 Mdot
.65 .02333 Mdot
.65 .0237 Mdot
.65 .02371 Mdot
.65 .02381 Mdot
.65 .02392 Mdot
.65 .02413 Mdot
.65 .02424 Mdot
.65 .02513 Mdot
.65 .02523 Mdot
.65 .0253 Mdot
.65 .02552 Mdot
.65 .02559 Mdot
.65 .02574 Mdot
.65 .02583 Mdot
.65 .02591 Mdot
.65 .0264 Mdot
.65 .02641 Mdot
.65 .02654 Mdot
.65 .02668 Mdot
.65 .02695 Mdot
.65 .02709 Mdot
.65 .02802 Mdot
.65 .02825 Mdot
.65 .02838 Mdot
.65 .02848 Mdot
.65 .02876 Mdot
.65 .02885 Mdot
.65 .02905 Mdot
.65 .02916 Mdot
.65 .02927 Mdot
.65 .0299 Mdot
.65 .02992 Mdot
.65 .03009 Mdot
.65 .03027 Mdot
.65 .03062 Mdot
.65 .0308 Mdot
.65 .03201 Mdot
.65 .03224 Mdot
.65 .03232 Mdot
.65 .03248 Mdot
.65 .0326 Mdot
.65 .03298 Mdot
.65 .03309 Mdot
.65 .03319 Mdot
.65 .03335 Mdot
.65 .0335 Mdot
.65 .03364 Mdot
.65 .03446 Mdot
.65 .03448 Mdot
.65 .0346 Mdot
.65 .0347 Mdot
.65 .03494 Mdot
.65 .0353 Mdot
.65 .03539 Mdot
.65 .0355 Mdot
.65 .03563 Mdot
.65 .03648 Mdot
.65 .03655 Mdot
.65 .03719 Mdot
.65 .03732 Mdot
.65 .0375 Mdot
.65 .0376 Mdot
.65 .03781 Mdot
.65 .03797 Mdot
.65 .03846 Mdot
.65 .03857 Mdot
.65 .0386 Mdot
.65 .03871 Mdot
.65 .03873 Mdot
.65 .03894 Mdot
.65 .03913 Mdot
.65 .03932 Mdot
.65 .04038 Mdot
.65 .04039 Mdot
.65 .04041 Mdot
.65 .04056 Mdot
.65 .04069 Mdot
.65 .0407 Mdot
.65 .041 Mdot
.65 .04143 Mdot
.65 .04148 Mdot
.65 .04159 Mdot
.65 .04173 Mdot
.65 .04191 Mdot
.65 .04296 Mdot
.65 .04301 Mdot
.65 .04307 Mdot
.65 .0431 Mdot
.65 .04311 Mdot
.65 .04394 Mdot
.65 .04411 Mdot
.65 .04424 Mdot
.65 .04434 Mdot
.65 .04446 Mdot
.65 .04465 Mdot
.65 .04474 Mdot
.65 .04495 Mdot
.65 .04556 Mdot
.65 .04558 Mdot
.65 .04571 Mdot
.65 .04573 Mdot
.65 .04577 Mdot
.65 .0459 Mdot
.65 .04593 Mdot
.65 .04621 Mdot
.65 .04646 Mdot
.65 .0467 Mdot
.65 .0471 Mdot
.65 .04749 Mdot
.65 .04809 Mdot
.65 .04809 Mdot
.65 .04812 Mdot
.65 .04831 Mdot
.65 .04848 Mdot
.65 .0485 Mdot
.65 .04884 Mdot
.65 .04889 Mdot
.65 .04944 Mdot
.65 .04951 Mdot
.65 .04965 Mdot
.65 .04984 Mdot
.65 .04992 Mdot
.65 .05006 Mdot
.65 .05019 Mdot
.65 .05143 Mdot
.65 .05149 Mdot
.65 .05158 Mdot
.65 .05161 Mdot
.65 .05162 Mdot
.65 .05262 Mdot
.65 .0527 Mdot
.65 .05292 Mdot
.65 .05309 Mdot
.65 .05322 Mdot
.65 .05338 Mdot
.65 .05341 Mdot
.65 .05363 Mdot
.65 .05375 Mdot
.65 .05402 Mdot
.65 .05481 Mdot
.65 .05484 Mdot
.65 .05501 Mdot
.65 .05503 Mdot
.65 .05509 Mdot
.65 .05526 Mdot
.65 .05529 Mdot
.65 .05553 Mdot
.65 .05556 Mdot
.65 .05566 Mdot
.65 .05582 Mdot
.65 .05598 Mdot
.65 .05629 Mdot
.65 .05682 Mdot
.65 .05732 Mdot
.65 .05766 Mdot
.65 .05789 Mdot
.65 .0581 Mdot
.65 .05811 Mdot
.65 .05814 Mdot
.65 .05839 Mdot
.65 .05846 Mdot
.65 .05861 Mdot
.65 .05863 Mdot
.65 .05907 Mdot
.65 .05914 Mdot
.65 .05986 Mdot
.65 .05995 Mdot
.65 .06014 Mdot
.65 .06028 Mdot
.65 .06038 Mdot
.65 .06048 Mdot
.65 .06064 Mdot
.65 .06067 Mdot
.65 .06083 Mdot
.65 .062 Mdot
.65 .06243 Mdot
.65 .06244 Mdot
.65 .06253 Mdot
.65 .06264 Mdot
.65 .06268 Mdot
.65 .06269 Mdot
.65 .06311 Mdot
.65 .06347 Mdot
.65 .06399 Mdot
.65 .0641 Mdot
.65 .06436 Mdot
.65 .06438 Mdot
.65 .06451 Mdot
.65 .06461 Mdot
.65 .06478 Mdot
.65 .06498 Mdot
.65 .06502 Mdot
.65 .0653 Mdot
.65 .06546 Mdot
.65 .06581 Mdot
.65 .06615 Mdot
.65 .06619 Mdot
.65 .06684 Mdot
.65 .06688 Mdot
.65 .0671 Mdot
.65 .06713 Mdot
.65 .0672 Mdot
.65 .06742 Mdot
.65 .06747 Mdot
.65 .06777 Mdot
.65 .06781 Mdot
.65 .06792 Mdot
.65 .06794 Mdot
.65 .06815 Mdot
.65 .06836 Mdot
.65 .06877 Mdot
.65 .06925 Mdot
.65 .06945 Mdot
.65 .0701 Mdot
.65 .07054 Mdot
.65 .07084 Mdot
.65 .07111 Mdot
.65 .07112 Mdot
.65 .07117 Mdot
.65 .07124 Mdot
.65 .07149 Mdot
.65 .07158 Mdot
.65 .07178 Mdot
.65 .07181 Mdot
.65 .07238 Mdot
.65 .07247 Mdot
.65 .07341 Mdot
.65 .07352 Mdot
.65 .07376 Mdot
.65 .07395 Mdot
.65 .07407 Mdot
.65 .07421 Mdot
.65 .07442 Mdot
.65 .07445 Mdot
.65 .07466 Mdot
.65 .07518 Mdot
.65 .07578 Mdot
.65 .07619 Mdot
.65 .07674 Mdot
.65 .07676 Mdot
.65 .07687 Mdot
.65 .07696 Mdot
.65 .07702 Mdot
.65 .07707 Mdot
.65 .07709 Mdot
.65 .07763 Mdot
.65 .07773 Mdot
.65 .07809 Mdot
.65 .07877 Mdot
.65 .07892 Mdot
.65 .07925 Mdot
.65 .07929 Mdot
.65 .07945 Mdot
.65 .07958 Mdot
.65 .0798 Mdot
.65 .08006 Mdot
.65 .08011 Mdot
.65 .08047 Mdot
.65 .08068 Mdot
.65 .08091 Mdot
.65 .08113 Mdot
.65 .08158 Mdot
.65 .08163 Mdot
.65 .08214 Mdot
.65 .08248 Mdot
.65 .08252 Mdot
.65 .08282 Mdot
.65 .08285 Mdot
.65 .08294 Mdot
.65 .08324 Mdot
.65 .08329 Mdot
.65 .08369 Mdot
.65 .08374 Mdot
.65 .08388 Mdot
.65 .08391 Mdot
.65 .08418 Mdot
.65 .08445 Mdot
.65 .08498 Mdot
.65 .08561 Mdot
.65 .0857 Mdot
.65 .08586 Mdot
.65 .08589 Mdot
.65 .08672 Mdot
.65 .08729 Mdot
.65 .08768 Mdot
.65 .08803 Mdot
.65 .08805 Mdot
.65 .08811 Mdot
.65 .08819 Mdot
.65 .0882 Mdot
.65 .08853 Mdot
.65 .08864 Mdot
.65 .0889 Mdot
.65 .08894 Mdot
.65 .08968 Mdot
.65 .08979 Mdot
.65 .09024 Mdot
.65 .09036 Mdot
.65 .09046 Mdot
.65 .09085 Mdot
.65 .09101 Mdot
.65 .09116 Mdot
.65 .09136 Mdot
.65 .09144 Mdot
.65 .09148 Mdot
.65 .09172 Mdot
.65 .09188 Mdot
.65 .09205 Mdot
.65 .09233 Mdot
.65 .09237 Mdot
.65 .09265 Mdot
.65 .09333 Mdot
.65 .0935 Mdot
.65 .0941 Mdot
.65 .09422 Mdot
.65 .09464 Mdot
.65 .09535 Mdot
.65 .09538 Mdot
.65 .09552 Mdot
.65 .09564 Mdot
.65 .09571 Mdot
.65 .09578 Mdot
.65 .0958 Mdot
.65 .09585 Mdot
.65 .09607 Mdot
.65 .09626 Mdot
.65 .09651 Mdot
.65 .09664 Mdot
.65 .09711 Mdot
.65 .09798 Mdot
.65 .09818 Mdot
.65 .09862 Mdot
.65 .09866 Mdot
.65 .09886 Mdot
.65 .09888 Mdot
.65 .09903 Mdot
.65 .09932 Mdot
.65 .09967 Mdot
.65 .09973 Mdot
.65 .09989 Mdot
.65 .1002 Mdot
.65 .10047 Mdot
.65 .10055 Mdot
.65 .10074 Mdot
.65 .10077 Mdot
.65 .10106 Mdot
.65 .10142 Mdot
.65 .10164 Mdot
.65 .1017 Mdot
.65 .10237 Mdot
.65 .10281 Mdot
.65 .10287 Mdot
.65 .10325 Mdot
.65 .1033 Mdot
.65 .10341 Mdot
.65 .10379 Mdot
.65 .10387 Mdot
.65 .10424 Mdot
.65 .10438 Mdot
.65 .10445 Mdot
.65 .10464 Mdot
.65 .10467 Mdot
.65 .10501 Mdot
.65 .10501 Mdot
.65 .10537 Mdot
.65 .10565 Mdot
.65 .10606 Mdot
.65 .10688 Mdot
.65 .107 Mdot
.65 .10721 Mdot
.65 .10725 Mdot
.65 .10741 Mdot
.65 .10807 Mdot
.65 .10832 Mdot
.65 .10906 Mdot
.65 .1091 Mdot
.65 .10957 Mdot
.65 .11 Mdot
.65 .11002 Mdot
.65 .11004 Mdot
.65 .11012 Mdot
.65 .11023 Mdot
.65 .11025 Mdot
.65 .11067 Mdot
.65 .11082 Mdot
.65 .11116 Mdot
.65 .11121 Mdot
.65 .11124 Mdot
.65 .11178 Mdot
.65 .112 Mdot
.65 .11213 Mdot
.65 .11217 Mdot
.65 .11231 Mdot
.65 .1129 Mdot
.65 .11306 Mdot
.65 .11319 Mdot
.65 .11355 Mdot
.65 .11369 Mdot
.65 .1139 Mdot
.65 .11409 Mdot
.65 .11435 Mdot
.65 .11446 Mdot
.65 .1145 Mdot
.65 .11453 Mdot
.65 .11483 Mdot
.65 .11503 Mdot
.65 .11526 Mdot
.65 .11562 Mdot
.65 .11562 Mdot
.65 .11567 Mdot
.65 .11603 Mdot
.65 .11691 Mdot
.65 .11713 Mdot
.65 .11738 Mdot
.65 .11738 Mdot
.65 .11763 Mdot
.65 .11791 Mdot
.65 .11808 Mdot
.65 .11861 Mdot
.65 .11934 Mdot
.65 .11954 Mdot
.65 .11957 Mdot
.65 .11976 Mdot
.65 .11992 Mdot
.65 .12001 Mdot
.65 .1201 Mdot
.65 .12013 Mdot
.65 .12019 Mdot
.65 .12048 Mdot
.65 .12072 Mdot
.65 .12105 Mdot
.65 .12121 Mdot
.65 .12182 Mdot
.65 .12296 Mdot
.65 .12322 Mdot
.65 .1236 Mdot
.65 .12379 Mdot
.65 .12384 Mdot
.65 .1241 Mdot
.65 .12412 Mdot
.65 .12433 Mdot
.65 .12467 Mdot
.65 .1247 Mdot
.65 .12516 Mdot
.65 .12524 Mdot
.65 .12544 Mdot
.65 .12585 Mdot
.65 .12588 Mdot
.65 .12589 Mdot
.65 .12619 Mdot
.65 .1263 Mdot
.65 .12655 Mdot
.65 .12659 Mdot
.65 .12696 Mdot
.65 .12707 Mdot
.65 .12743 Mdot
.65 .12772 Mdot
.65 .12779 Mdot
.65 .12845 Mdot
.65 .12866 Mdot
.65 .12923 Mdot
.65 .12924 Mdot
.65 .12931 Mdot
.65 .12981 Mdot
.65 .12987 Mdot
.65 .13002 Mdot
.65 .13051 Mdot
.65 .13061 Mdot
.65 .13109 Mdot
.65 .13128 Mdot
.65 .13137 Mdot
.65 .13161 Mdot
.65 .13165 Mdot
.65 .13209 Mdot
.65 .1321 Mdot
.65 .13257 Mdot
.65 .13293 Mdot
.65 .13347 Mdot
.65 .13453 Mdot
.65 .13469 Mdot
.65 .13496 Mdot
.65 .13501 Mdot
.65 .13521 Mdot
.65 .13607 Mdot
.65 .1364 Mdot
.65 .13736 Mdot
.65 .13741 Mdot
.65 .13803 Mdot
.65 .13858 Mdot
.65 .13862 Mdot
.65 .13864 Mdot
.65 .13875 Mdot
.65 .13888 Mdot
.65 .13891 Mdot
.65 .13946 Mdot
.65 .13966 Mdot
.65 .14009 Mdot
.65 .14015 Mdot
.65 .1402 Mdot
.65 .1409 Mdot
.65 .14118 Mdot
.65 .14136 Mdot
.65 .14141 Mdot
.65 .14159 Mdot
.65 .14235 Mdot
.65 .14256 Mdot
.65 .14273 Mdot
.65 .14321 Mdot
.65 .14338 Mdot
.65 .14366 Mdot
.65 .1439 Mdot
.65 .14424 Mdot
.65 .14438 Mdot
.65 .14444 Mdot
.65 .14448 Mdot
.65 .14486 Mdot
.65 .14513 Mdot
.65 .14542 Mdot
.65 .14589 Mdot
.65 .14589 Mdot
.65 .14596 Mdot
.65 .14642 Mdot
.65 .14757 Mdot
.65 .14785 Mdot
.65 .14818 Mdot
.65 .14818 Mdot
.65 .1485 Mdot
.65 .14887 Mdot
.65 .14908 Mdot
.65 .14978 Mdot
.65 .15073 Mdot
.65 .15099 Mdot
.65 .15103 Mdot
.65 .15127 Mdot
.65 .15148 Mdot
.65 .1516 Mdot
.65 .15172 Mdot
.65 .15175 Mdot
.65 .15183 Mdot
.65 .15221 Mdot
.65 .15252 Mdot
.65 .15295 Mdot
.65 .15316 Mdot
.65 .15396 Mdot
.65 .15544 Mdot
.65 .15577 Mdot
.65 .15626 Mdot
.65 .15651 Mdot
.65 .15658 Mdot
.65 .15692 Mdot
.65 .15695 Mdot
.65 .15721 Mdot
.65 .15765 Mdot
.65 .1577 Mdot
.65 .15829 Mdot
.65 .1584 Mdot
.65 .15865 Mdot
.65 .15919 Mdot
.65 .15923 Mdot
.65 .15924 Mdot
.65 .15964 Mdot
.65 .15978 Mdot
.65 .1601 Mdot
.65 .16015 Mdot
.65 .16064 Mdot
.65 .16077 Mdot
.65 .16125 Mdot
.65 .16162 Mdot
.65 .16172 Mdot
.65 .16257 Mdot
.65 .16285 Mdot
.65 .16359 Mdot
.65 .1636 Mdot
.65 .16369 Mdot
.65 .16433 Mdot
.65 .16442 Mdot
.65 .16462 Mdot
.65 .16525 Mdot
.65 .16538 Mdot
.65 .166 Mdot
.65 .16624 Mdot
.65 .16637 Mdot
.65 .16668 Mdot
.65 .16674 Mdot
.65 .16731 Mdot
.65 .16732 Mdot
.65 .16793 Mdot
.65 .16839 Mdot
.65 .16909 Mdot
.65 .17047 Mdot
.65 .17068 Mdot
.65 .17103 Mdot
.65 .17109 Mdot
.65 .17136 Mdot
.65 .17248 Mdot
.65 .17291 Mdot
.65 .17415 Mdot
.65 .17422 Mdot
.65 .17502 Mdot
.65 .17574 Mdot
.65 .17579 Mdot
.65 .17582 Mdot
.65 .17596 Mdot
.65 .17613 Mdot
.65 .17616 Mdot
.65 .17688 Mdot
.65 .17714 Mdot
.65 .17771 Mdot
.65 .17778 Mdot
.65 .17785 Mdot
.65 .17876 Mdot
.65 .17912 Mdot
.65 .17935 Mdot
.65 .17942 Mdot
.65 .17966 Mdot
.65 .18064 Mdot
.65 .18091 Mdot
.65 .18114 Mdot
.65 .18175 Mdot
.65 .18198 Mdot
.65 .18234 Mdot
.65 .18266 Mdot
.65 .1831 Mdot
.65 .18329 Mdot
.65 .18336 Mdot
.65 .18341 Mdot
.65 .18391 Mdot
.65 .18425 Mdot
.65 .18463 Mdot
.65 .18525 Mdot
.65 .18525 Mdot
.65 .18533 Mdot
.65 .18593 Mdot
.65 .18742 Mdot
.65 .1878 Mdot
.65 .18822 Mdot
.65 .18822 Mdot
.65 .18864 Mdot
.65 .18912 Mdot
.65 .18939 Mdot
.65 .1903 Mdot
.65 .19154 Mdot
.65 .19187 Mdot
.65 .19193 Mdot
.65 .19224 Mdot
.65 .19251 Mdot
.65 .19267 Mdot
.65 .19282 Mdot
.65 .19286 Mdot
.65 .19297 Mdot
.65 .19346 Mdot
.65 .19386 Mdot
.65 .19441 Mdot
.65 .19469 Mdot
.65 .19573 Mdot
.65 .19765 Mdot
.65 .19808 Mdot
.65 .19872 Mdot
.65 .19905 Mdot
.65 .19913 Mdot
.65 .19958 Mdot
.65 .19961 Mdot
.65 .19996 Mdot
.65 .20053 Mdot
.65 .20059 Mdot
.65 .20136 Mdot
.65 .2015 Mdot
.65 .20183 Mdot
.65 .20253 Mdot
.65 .20258 Mdot
.65 .20259 Mdot
.65 .20311 Mdot
.65 .2033 Mdot
.65 .20371 Mdot
.65 .20378 Mdot
.65 .20441 Mdot
.65 .20459 Mdot
.65 .20521 Mdot
.65 .2057 Mdot
.65 .20582 Mdot
.65 .20693 Mdot
.65 .20729 Mdot
.65 .20825 Mdot
.65 .20827 Mdot
.65 .20838 Mdot
.65 .20922 Mdot
.65 .20933 Mdot
.65 .20959 Mdot
.65 .21042 Mdot
.65 .21058 Mdot
.65 .2112 Mdot
.65 .21139 Mdot
.65 .2117 Mdot
.65 .21186 Mdot
.65 .21227 Mdot
.65 .21234 Mdot
.65 .21309 Mdot
.65 .2131 Mdot
.65 .21389 Mdot
.65 .2145 Mdot
.65 .2154 Mdot
.65 .2172 Mdot
.65 .21747 Mdot
.65 .21792 Mdot
.65 .21801 Mdot
.65 .21836 Mdot
.65 .21981 Mdot
.65 .22036 Mdot
.65 .22199 Mdot
.65 .22207 Mdot
.65 .22312 Mdot
.65 .22405 Mdot
.65 .22411 Mdot
.65 .22415 Mdot
.65 .22433 Mdot
.65 .22456 Mdot
.65 .2246 Mdot
.65 .22553 Mdot
.65 .22586 Mdot
.65 .2266 Mdot
.65 .22671 Mdot
.65 .22679 Mdot
.65 .22797 Mdot
.65 .22844 Mdot
.65 .22874 Mdot
.65 .22883 Mdot
.65 .22914 Mdot
.65 .23042 Mdot
.65 .23077 Mdot
.65 .23106 Mdot
.65 .23186 Mdot
.65 .23216 Mdot
.65 .23263 Mdot
.65 .23304 Mdot
.65 .23361 Mdot
.65 .23386 Mdot
.65 .23395 Mdot
.65 .23402 Mdot
.65 .23466 Mdot
.65 .23511 Mdot
.65 .2356 Mdot
.65 .2364 Mdot
.65 .23641 Mdot
.65 .23652 Mdot
.65 .2373 Mdot
.65 .23923 Mdot
.65 .23972 Mdot
.65 .24027 Mdot
.65 .24028 Mdot
.65 .24081 Mdot
.65 .24144 Mdot
.65 .2418 Mdot
.65 .24297 Mdot
.65 .24459 Mdot
.65 .24501 Mdot
.65 .24509 Mdot
.65 .2455 Mdot
.65 .24584 Mdot
.65 .24605 Mdot
.65 .24625 Mdot
.65 .2463 Mdot
.65 .24645 Mdot
.65 .24708 Mdot
.65 .24761 Mdot
.65 .24832 Mdot
.65 .24869 Mdot
.65 .25003 Mdot
.65 .25253 Mdot
.65 .25309 Mdot
.65 .25393 Mdot
.65 .25434 Mdot
.65 .25446 Mdot
.65 .25504 Mdot
.65 .25508 Mdot
.65 .25554 Mdot
.65 .25628 Mdot
.65 .25636 Mdot
.65 .25735 Mdot
.65 .25754 Mdot
.65 .25797 Mdot
.65 .25887 Mdot
.65 .25894 Mdot
.65 .25896 Mdot
.65 .25963 Mdot
.65 .25987 Mdot
.65 .26041 Mdot
.65 .2605 Mdot
.65 .26132 Mdot
.65 .26155 Mdot
.65 .26235 Mdot
.65 .26299 Mdot
.65 .26315 Mdot
.65 .26459 Mdot
.65 .26506 Mdot
.65 .26631 Mdot
.65 .26633 Mdot
.65 .26648 Mdot
.65 .26757 Mdot
.65 .26771 Mdot
.65 .26805 Mdot
.65 .26913 Mdot
.65 .26934 Mdot
.65 .27014 Mdot
.65 .27039 Mdot
.65 .2708 Mdot
.65 .27101 Mdot
.65 .27154 Mdot
.65 .27163 Mdot
.65 .2726 Mdot
.65 .27262 Mdot
.65 .27365 Mdot
.65 .27443 Mdot
.65 .27561 Mdot
.65 .27794 Mdot
.65 .27829 Mdot
.65 .27889 Mdot
.65 .279 Mdot
.65 .27945 Mdot
.65 .28133 Mdot
.65 .28206 Mdot
.65 .28417 Mdot
.65 .28428 Mdot
.65 .28564 Mdot
.65 .28685 Mdot
.65 .28692 Mdot
.65 .28698 Mdot
.65 .28721 Mdot
.65 .28751 Mdot
.65 .28756 Mdot
.65 .28878 Mdot
.65 .28921 Mdot
.65 .29017 Mdot
.65 .2903 Mdot
.65 .29041 Mdot
.65 .29195 Mdot
.65 .29256 Mdot
.65 .29295 Mdot
.65 .29306 Mdot
.65 .29347 Mdot
.65 .29513 Mdot
.65 .29559 Mdot
.65 .29597 Mdot
.65 .29701 Mdot
.65 .2974 Mdot
.65 .29801 Mdot
.65 .29854 Mdot
.65 .29928 Mdot
.65 .2996 Mdot
.65 .29972 Mdot
.65 .29981 Mdot
.65 .30065 Mdot
.65 .30123 Mdot
.65 .30187 Mdot
.65 .30291 Mdot
.65 .30291 Mdot
.65 .30306 Mdot
.65 .30407 Mdot
.65 .30659 Mdot
.65 .30722 Mdot
.65 .30794 Mdot
.65 .30794 Mdot
.65 .30864 Mdot
.65 .30946 Mdot
.65 .30992 Mdot
.65 .31145 Mdot
.65 .31355 Mdot
.65 .3141 Mdot
.65 .3142 Mdot
.65 .31473 Mdot
.65 .31518 Mdot
.65 .31545 Mdot
.65 .31571 Mdot
.65 .31578 Mdot
.65 .31596 Mdot
.65 .31679 Mdot
.65 .31748 Mdot
.65 .31841 Mdot
.65 .31888 Mdot
.65 .32063 Mdot
.65 .32388 Mdot
.65 .3246 Mdot
.65 .32569 Mdot
.65 .32623 Mdot
.65 .32638 Mdot
.65 .32714 Mdot
.65 .3272 Mdot
.65 .32779 Mdot
.65 .32875 Mdot
.65 .32885 Mdot
.65 .33015 Mdot
.65 .33039 Mdot
.65 .33095 Mdot
.65 .33212 Mdot
.65 .33221 Mdot
.65 .33223 Mdot
.65 .33311 Mdot
.65 .33342 Mdot
.65 .33412 Mdot
.65 .33424 Mdot
.65 .33531 Mdot
.65 .33561 Mdot
.65 .33664 Mdot
.65 .33747 Mdot
.65 .33768 Mdot
.65 .33955 Mdot
.65 .34016 Mdot
.65 .34179 Mdot
.65 .34182 Mdot
.65 .34201 Mdot
.65 .34343 Mdot
.65 .34361 Mdot
.65 .34405 Mdot
.65 .34545 Mdot
.65 .34573 Mdot
.65 .34677 Mdot
.65 .3471 Mdot
.65 .34763 Mdot
.65 .3479 Mdot
.65 .34858 Mdot
.65 .3487 Mdot
.65 .34996 Mdot
.65 .34999 Mdot
.65 .35133 Mdot
.65 .35235 Mdot
.65 .35388 Mdot
.65 .35691 Mdot
.65 .35737 Mdot
.65 .35828 Mdot
.65 .35887 Mdot
.65 .36132 Mdot
.65 .36226 Mdot
.65 .365 Mdot
.65 .36515 Mdot
.65 .36691 Mdot
.65 .36849 Mdot
.65 .36859 Mdot
.65 .36867 Mdot
.65 .36896 Mdot
.65 .36935 Mdot
.65 .36942 Mdot
.65 .371 Mdot
.65 .37156 Mdot
.65 .37281 Mdot
.65 .37298 Mdot
.65 .37312 Mdot
.65 .37512 Mdot
.65 .37591 Mdot
.65 .37642 Mdot
.65 .37657 Mdot
.65 .37709 Mdot
.65 .37926 Mdot
.65 .37985 Mdot
.65 .38035 Mdot
.65 .3817 Mdot
.65 .3822 Mdot
.65 .383 Mdot
.65 .38369 Mdot
.65 .38465 Mdot
.65 .38506 Mdot
.65 .38523 Mdot
.65 .38533 Mdot
.65 .38643 Mdot
.65 .38718 Mdot
.65 .38802 Mdot
.65 .38937 Mdot
.65 .38937 Mdot
.65 .38956 Mdot
.65 .39088 Mdot
.65 .39415 Mdot
.65 .39497 Mdot
.65 .39591 Mdot
.65 .39591 Mdot
.65 .39682 Mdot
.65 .39788 Mdot
.65 .39849 Mdot
.652 .01535 Mdot
.652 .01555 Mdot
.652 .01566 Mdot
.652 .0158 Mdot
.652 .01595 Mdot
.652 .01613 Mdot
.652 .01633 Mdot
.652 .01656 Mdot
.652 .01682 Mdot
.652 .01698 Mdot
.652 .01712 Mdot
.652 .01745 Mdot
.652 .01766 Mdot
.652 .01785 Mdot
.652 .01829 Mdot
.652 .01856 Mdot
.652 .0188 Mdot
.652 .01937 Mdot
.652 .01973 Mdot
.652 .02004 Mdot
.652 .02041 Mdot
.652 .02076 Mdot
.652 .02079 Mdot
.652 .02112 Mdot
.652 .02125 Mdot
.652 .02149 Mdot
.652 .02166 Mdot
.652 .02174 Mdot
.652 .02189 Mdot
.652 .02214 Mdot
.652 .02245 Mdot
.652 .02259 Mdot
.652 .02264 Mdot
.652 .02306 Mdot
.652 .02324 Mdot
.652 .02355 Mdot
.652 .02377 Mdot
.652 .02388 Mdot
.652 .02408 Mdot
.652 .02427 Mdot
.652 .0244 Mdot
.652 .02481 Mdot
.652 .02499 Mdot
.652 .02504 Mdot
.652 .0256 Mdot
.652 .02575 Mdot
.652 .02583 Mdot
.652 .02603 Mdot
.652 .02612 Mdot
.652 .02624 Mdot
.652 .02653 Mdot
.652 .02667 Mdot
.652 .02692 Mdot
.652 .02717 Mdot
.652 .0273 Mdot
.652 .02735 Mdot
.652 .02735 Mdot
.652 .02787 Mdot
.652 .02793 Mdot
.652 .02811 Mdot
.652 .02818 Mdot
.652 .02852 Mdot
.652 .02883 Mdot
.652 .02891 Mdot
.652 .029 Mdot
.652 .02911 Mdot
.652 .02921 Mdot
.652 .02947 Mdot
.652 .02958 Mdot
.652 .02974 Mdot
.652 .03012 Mdot
.652 .03017 Mdot
.652 .03026 Mdot
.652 .0303 Mdot
.652 .03063 Mdot
.652 .03096 Mdot
.652 .03112 Mdot
.652 .03119 Mdot
.652 .03119 Mdot
.652 .03187 Mdot
.652 .03195 Mdot
.652 .03218 Mdot
.652 .03228 Mdot
.652 .03246 Mdot
.652 .03272 Mdot
.652 .03313 Mdot
.652 .03323 Mdot
.652 .03334 Mdot
.652 .03348 Mdot
.652 .03361 Mdot
.652 .03396 Mdot
.652 .0341 Mdot
.652 .03431 Mdot
.652 .03468 Mdot
.652 .0348 Mdot
.652 .03487 Mdot
.652 .03497 Mdot
.652 .03498 Mdot
.652 .03504 Mdot
.652 .03547 Mdot
.652 .0359 Mdot
.652 .03611 Mdot
.652 .03619 Mdot
.652 .0362 Mdot
.652 .03709 Mdot
.652 .03719 Mdot
.652 .03734 Mdot
.652 .03749 Mdot
.652 .03762 Mdot
.652 .03785 Mdot
.652 .0382 Mdot
.652 .03872 Mdot
.652 .03885 Mdot
.652 .03901 Mdot
.652 .03919 Mdot
.652 .03936 Mdot
.652 .03981 Mdot
.652 .03999 Mdot
.652 .04026 Mdot
.652 .04074 Mdot
.652 .04091 Mdot
.652 .04099 Mdot
.652 .04112 Mdot
.652 .04114 Mdot
.652 .04122 Mdot
.652 .04178 Mdot
.652 .04231 Mdot
.652 .04234 Mdot
.652 .04261 Mdot
.652 .04272 Mdot
.652 .04273 Mdot
.652 .04293 Mdot
.652 .04382 Mdot
.652 .04389 Mdot
.652 .04394 Mdot
.652 .04402 Mdot
.652 .04421 Mdot
.652 .04422 Mdot
.652 .04441 Mdot
.652 .04458 Mdot
.652 .04458 Mdot
.652 .04472 Mdot
.652 .04489 Mdot
.652 .04507 Mdot
.652 .04533 Mdot
.652 .04569 Mdot
.652 .04602 Mdot
.652 .04619 Mdot
.652 .04639 Mdot
.652 .04663 Mdot
.652 .04685 Mdot
.652 .04744 Mdot
.652 .04768 Mdot
.652 .04803 Mdot
.652 .0485 Mdot
.652 .04856 Mdot
.652 .04887 Mdot
.652 .04898 Mdot
.652 .04915 Mdot
.652 .04918 Mdot
.652 .04928 Mdot
.652 .05001 Mdot
.652 .05029 Mdot
.652 .0507 Mdot
.652 .05074 Mdot
.652 .05109 Mdot
.652 .05124 Mdot
.652 .05124 Mdot
.652 .05135 Mdot
.652 .05151 Mdot
.652 .05267 Mdot
.652 .05275 Mdot
.652 .05276 Mdot
.652 .05282 Mdot
.652 .05292 Mdot
.652 .05318 Mdot
.652 .05319 Mdot
.652 .05344 Mdot
.652 .05366 Mdot
.652 .05366 Mdot
.652 .05371 Mdot
.652 .05373 Mdot
.652 .05384 Mdot
.652 .05406 Mdot
.652 .05429 Mdot
.652 .0543 Mdot
.652 .05447 Mdot
.652 .05464 Mdot
.652 .0551 Mdot
.652 .05554 Mdot
.652 .05568 Mdot
.652 .05576 Mdot
.652 .05602 Mdot
.652 .05633 Mdot
.652 .05662 Mdot
.652 .05729 Mdot
.652 .05739 Mdot
.652 .0577 Mdot
.652 .05809 Mdot
.652 .05812 Mdot
.652 .05816 Mdot
.652 .05843 Mdot
.652 .05877 Mdot
.652 .05885 Mdot
.652 .05925 Mdot
.652 .0594 Mdot
.652 .05948 Mdot
.652 .05962 Mdot
.652 .05965 Mdot
.652 .05978 Mdot
.652 .05989 Mdot
.652 .06058 Mdot
.652 .06067 Mdot
.652 .06074 Mdot
.652 .06075 Mdot
.652 .06082 Mdot
.652 .0611 Mdot
.652 .06164 Mdot
.652 .06169 Mdot
.652 .06198 Mdot
.652 .06215 Mdot
.652 .06234 Mdot
.652 .06234 Mdot
.652 .06249 Mdot
.652 .06254 Mdot
.652 .06269 Mdot
.652 .06414 Mdot
.652 .06421 Mdot
.652 .06432 Mdot
.652 .06433 Mdot
.652 .06441 Mdot
.652 .06442 Mdot
.652 .06454 Mdot
.652 .06487 Mdot
.652 .06488 Mdot
.652 .06522 Mdot
.652 .0655 Mdot
.652 .0655 Mdot
.652 .06557 Mdot
.652 .06559 Mdot
.652 .06573 Mdot
.652 .06593 Mdot
.652 .06602 Mdot
.652 .06632 Mdot
.652 .06633 Mdot
.652 .06655 Mdot
.652 .06678 Mdot
.652 .06726 Mdot
.652 .06738 Mdot
.652 .0676 Mdot
.652 .06795 Mdot
.652 .06813 Mdot
.652 .06824 Mdot
.652 .0684 Mdot
.652 .06858 Mdot
.652 .06898 Mdot
.652 .06935 Mdot
.652 .06944 Mdot
.652 .07024 Mdot
.652 .07036 Mdot
.652 .07071 Mdot
.652 .07076 Mdot
.652 .07128 Mdot
.652 .0713 Mdot
.652 .07131 Mdot
.652 .07136 Mdot
.652 .07172 Mdot
.652 .07216 Mdot
.652 .07227 Mdot
.652 .07279 Mdot
.652 .07298 Mdot
.652 .07309 Mdot
.652 .07327 Mdot
.652 .07331 Mdot
.652 .07349 Mdot
.652 .07363 Mdot
.652 .07419 Mdot
.652 .07453 Mdot
.652 .07463 Mdot
.652 .07473 Mdot
.652 .07474 Mdot
.652 .07484 Mdot
.652 .07521 Mdot
.652 .07574 Mdot
.652 .07591 Mdot
.652 .07597 Mdot
.652 .07634 Mdot
.652 .07658 Mdot
.652 .07662 Mdot
.652 .07663 Mdot
.652 .07682 Mdot
.652 .07682 Mdot
.652 .07701 Mdot
.652 .07708 Mdot
.652 .07726 Mdot
.652 .07728 Mdot
.652 .07797 Mdot
.652 .07916 Mdot
.652 .07926 Mdot
.652 .07939 Mdot
.652 .07941 Mdot
.652 .07946 Mdot
.652 .07951 Mdot
.652 .07953 Mdot
.652 .07969 Mdot
.652 .08012 Mdot
.652 .08013 Mdot
.652 .08057 Mdot
.652 .08094 Mdot
.652 .08094 Mdot
.652 .08103 Mdot
.652 .08106 Mdot
.652 .08124 Mdot
.652 .0815 Mdot
.652 .08162 Mdot
.652 .08201 Mdot
.652 .08202 Mdot
.652 .08205 Mdot
.652 .08231 Mdot
.652 .08261 Mdot
.652 .08284 Mdot
.652 .08323 Mdot
.652 .08339 Mdot
.652 .08368 Mdot
.652 .08413 Mdot
.652 .08437 Mdot
.652 .08451 Mdot
.652 .08461 Mdot
.652 .08472 Mdot
.652 .08495 Mdot
.652 .08548 Mdot
.652 .08576 Mdot
.652 .08594 Mdot
.652 .08596 Mdot
.652 .08608 Mdot
.652 .0867 Mdot
.652 .08712 Mdot
.652 .08728 Mdot
.652 .08773 Mdot
.652 .0878 Mdot
.652 .08847 Mdot
.652 .08851 Mdot
.652 .08852 Mdot
.652 .08859 Mdot
.652 .08905 Mdot
.652 .08962 Mdot
.652 .08977 Mdot
.652 .09045 Mdot
.652 .09065 Mdot
.652 .0907 Mdot
.652 .09083 Mdot
.652 .09107 Mdot
.652 .09112 Mdot
.652 .09135 Mdot
.652 .09154 Mdot
.652 .09228 Mdot
.652 .09271 Mdot
.652 .09285 Mdot
.652 .09298 Mdot
.652 .09299 Mdot
.652 .09312 Mdot
.652 .09333 Mdot
.652 .0936 Mdot
.652 .0943 Mdot
.652 .09437 Mdot
.652 .09451 Mdot
.652 .09457 Mdot
.652 .0946 Mdot
.652 .09508 Mdot
.652 .09538 Mdot
.652 .09544 Mdot
.652 .09546 Mdot
.652 .0957 Mdot
.652 .09571 Mdot
.652 .09595 Mdot
.652 .09604 Mdot
.652 .09628 Mdot
.652 .0963 Mdot
.652 .0972 Mdot
.652 .09726 Mdot
.652 .09774 Mdot
.652 .09875 Mdot
.652 .09888 Mdot
.652 .09906 Mdot
.652 .09908 Mdot
.652 .09914 Mdot
.652 .09921 Mdot
.652 .09924 Mdot
.652 .09931 Mdot
.652 .09944 Mdot
.652 .10001 Mdot
.652 .10002 Mdot
.652 .10059 Mdot
.652 .10107 Mdot
.652 .10107 Mdot
.652 .10119 Mdot
.652 .10122 Mdot
.652 .10147 Mdot
.652 .1018 Mdot
.652 .10196 Mdot
.652 .10203 Mdot
.652 .10224 Mdot
.652 .10233 Mdot
.652 .10247 Mdot
.652 .10248 Mdot
.652 .10252 Mdot
.652 .10275 Mdot
.652 .10286 Mdot
.652 .10325 Mdot
.652 .10355 Mdot
.652 .10406 Mdot
.652 .10427 Mdot
.652 .10465 Mdot
.652 .10523 Mdot
.652 .10555 Mdot
.652 .10573 Mdot
.652 .10573 Mdot
.652 .10586 Mdot
.652 .106 Mdot
.652 .1063 Mdot
.652 .10699 Mdot
.652 .10735 Mdot
.652 .10759 Mdot
.652 .10762 Mdot
.652 .10778 Mdot
.652 .10858 Mdot
.652 .10913 Mdot
.652 .10934 Mdot
.652 .10938 Mdot
.652 .10992 Mdot
.652 .11002 Mdot
.652 .11034 Mdot
.652 .1109 Mdot
.652 .11094 Mdot
.652 .11096 Mdot
.652 .11104 Mdot
.652 .11165 Mdot
.652 .11239 Mdot
.652 .11259 Mdot
.652 .11347 Mdot
.652 .11373 Mdot
.652 .11379 Mdot
.652 .11397 Mdot
.652 .11428 Mdot
.652 .11435 Mdot
.652 .11465 Mdot
.652 .1147 Mdot
.652 .11489 Mdot
.652 .11585 Mdot
.652 .11599 Mdot
.652 .11628 Mdot
.652 .11642 Mdot
.652 .1166 Mdot
.652 .11677 Mdot
.652 .11679 Mdot
.652 .11696 Mdot
.652 .11715 Mdot
.652 .11723 Mdot
.652 .11758 Mdot
.652 .11849 Mdot
.652 .11858 Mdot
.652 .11867 Mdot
.652 .11877 Mdot
.652 .11884 Mdot
.652 .11888 Mdot
.652 .11903 Mdot
.652 .11951 Mdot
.652 .1199 Mdot
.652 .11998 Mdot
.652 .12 Mdot
.652 .12031 Mdot
.652 .12033 Mdot
.652 .12048 Mdot
.652 .12064 Mdot
.652 .12072 Mdot
.652 .12077 Mdot
.652 .12108 Mdot
.652 .1211 Mdot
.652 .12168 Mdot
.652 .12227 Mdot
.652 .12235 Mdot
.652 .12298 Mdot
.652 .1243 Mdot
.652 .12446 Mdot
.652 .1247 Mdot
.652 .12473 Mdot
.652 .1248 Mdot
.652 .1249 Mdot
.652 .12493 Mdot
.652 .12503 Mdot
.652 .12519 Mdot
.652 .12594 Mdot
.652 .12595 Mdot
.652 .12641 Mdot
.652 .12669 Mdot
.652 .12707 Mdot
.652 .12732 Mdot
.652 .12732 Mdot
.652 .12747 Mdot
.652 .12752 Mdot
.652 .12784 Mdot
.652 .12827 Mdot
.652 .12848 Mdot
.652 .12849 Mdot
.652 .12857 Mdot
.652 .12885 Mdot
.652 .12896 Mdot
.652 .12914 Mdot
.652 .12916 Mdot
.652 .12919 Mdot
.652 .12921 Mdot
.652 .12951 Mdot
.652 .12966 Mdot
.652 .13008 Mdot
.652 .13016 Mdot
.652 .13056 Mdot
.652 .13091 Mdot
.652 .131 Mdot
.652 .13122 Mdot
.652 .13149 Mdot
.652 .13183 Mdot
.652 .13199 Mdot
.652 .13275 Mdot
.652 .13316 Mdot
.652 .1334 Mdot
.652 .1334 Mdot
.652 .13357 Mdot
.652 .13375 Mdot
.652 .13415 Mdot
.652 .13505 Mdot
.652 .13551 Mdot
.652 .13582 Mdot
.652 .13587 Mdot
.652 .13607 Mdot
.652 .13712 Mdot
.652 .13783 Mdot
.652 .1381 Mdot
.652 .13816 Mdot
.652 .13887 Mdot
.652 .139 Mdot
.652 .13941 Mdot
.652 .14013 Mdot
.652 .14019 Mdot
.652 .14021 Mdot
.652 .14033 Mdot
.652 .14112 Mdot
.652 .14208 Mdot
.652 .14234 Mdot
.652 .14349 Mdot
.652 .14384 Mdot
.652 .14391 Mdot
.652 .14414 Mdot
.652 .14455 Mdot
.652 .14464 Mdot
.652 .14503 Mdot
.652 .14509 Mdot
.652 .14535 Mdot
.652 .1466 Mdot
.652 .14677 Mdot
.652 .14715 Mdot
.652 .14734 Mdot
.652 .14758 Mdot
.652 .14779 Mdot
.652 .14782 Mdot
.652 .14804 Mdot
.652 .14828 Mdot
.652 .14839 Mdot
.652 .14885 Mdot
.652 .15003 Mdot
.652 .15015 Mdot
.652 .15028 Mdot
.652 .15041 Mdot
.652 .1505 Mdot
.652 .15055 Mdot
.652 .15074 Mdot
.652 .15137 Mdot
.652 .15188 Mdot
.652 .15198 Mdot
.652 .15201 Mdot
.652 .15242 Mdot
.652 .15243 Mdot
.652 .15263 Mdot
.652 .15284 Mdot
.652 .15295 Mdot
.652 .15301 Mdot
.652 .15341 Mdot
.652 .15344 Mdot
.652 .1542 Mdot
.652 .15497 Mdot
.652 .15507 Mdot
.652 .15589 Mdot
.652 .15761 Mdot
.652 .15782 Mdot
.652 .15813 Mdot
.652 .15817 Mdot
.652 .15827 Mdot
.652 .15839 Mdot
.652 .15844 Mdot
.652 .15856 Mdot
.652 .15878 Mdot
.652 .15975 Mdot
.652 .15977 Mdot
.652 .16037 Mdot
.652 .16073 Mdot
.652 .16122 Mdot
.652 .16155 Mdot
.652 .16156 Mdot
.652 .16175 Mdot
.652 .16181 Mdot
.652 .16223 Mdot
.652 .16279 Mdot
.652 .16307 Mdot
.652 .16308 Mdot
.652 .16318 Mdot
.652 .16355 Mdot
.652 .16369 Mdot
.652 .16393 Mdot
.652 .16396 Mdot
.652 .16399 Mdot
.652 .16401 Mdot
.652 .16441 Mdot
.652 .16461 Mdot
.652 .16516 Mdot
.652 .16526 Mdot
.652 .16578 Mdot
.652 .16624 Mdot
.652 .16636 Mdot
.652 .16663 Mdot
.652 .16699 Mdot
.652 .16743 Mdot
.652 .16764 Mdot
.652 .16864 Mdot
.652 .16917 Mdot
.652 .16947 Mdot
.652 .16948 Mdot
.652 .1697 Mdot
.652 .16994 Mdot
.652 .17046 Mdot
.652 .17163 Mdot
.652 .17224 Mdot
.652 .17263 Mdot
.652 .1727 Mdot
.652 .17296 Mdot
.652 .17433 Mdot
.652 .17525 Mdot
.652 .17561 Mdot
.652 .17568 Mdot
.652 .17661 Mdot
.652 .17678 Mdot
.652 .17732 Mdot
.652 .17826 Mdot
.652 .17834 Mdot
.652 .17836 Mdot
.652 .17851 Mdot
.652 .17954 Mdot
.652 .1808 Mdot
.652 .18114 Mdot
.652 .18264 Mdot
.652 .18309 Mdot
.652 .18319 Mdot
.652 .18349 Mdot
.652 .18402 Mdot
.652 .18414 Mdot
.652 .18464 Mdot
.652 .18473 Mdot
.652 .18506 Mdot
.652 .18669 Mdot
.652 .18692 Mdot
.652 .18741 Mdot
.652 .18765 Mdot
.652 .18796 Mdot
.652 .18825 Mdot
.652 .18828 Mdot
.652 .18857 Mdot
.652 .18889 Mdot
.652 .18903 Mdot
.652 .18962 Mdot
.652 .19117 Mdot
.652 .19133 Mdot
.652 .19149 Mdot
.652 .19166 Mdot
.652 .19177 Mdot
.652 .19184 Mdot
.652 .19209 Mdot
.652 .19291 Mdot
.652 .19358 Mdot
.652 .19371 Mdot
.652 .19374 Mdot
.652 .19428 Mdot
.652 .1943 Mdot
.652 .19456 Mdot
.652 .19483 Mdot
.652 .19497 Mdot
.652 .19505 Mdot
.652 .19557 Mdot
.652 .19561 Mdot
.652 .19661 Mdot
.652 .1976 Mdot
.652 .19774 Mdot
.652 .1988 Mdot
.652 .20105 Mdot
.652 .20133 Mdot
.652 .20173 Mdot
.652 .20178 Mdot
.652 .20191 Mdot
.652 .20207 Mdot
.652 .20213 Mdot
.652 .20229 Mdot
.652 .20257 Mdot
.652 .20384 Mdot
.652 .20387 Mdot
.652 .20465 Mdot
.652 .20512 Mdot
.652 .20576 Mdot
.652 .20619 Mdot
.652 .2062 Mdot
.652 .20645 Mdot
.652 .20653 Mdot
.652 .20708 Mdot
.652 .20781 Mdot
.652 .20816 Mdot
.652 .20818 Mdot
.652 .20832 Mdot
.652 .20879 Mdot
.652 .20898 Mdot
.652 .20929 Mdot
.652 .20933 Mdot
.652 .20936 Mdot
.652 .2094 Mdot
.652 .20992 Mdot
.652 .21017 Mdot
.652 .21089 Mdot
.652 .21102 Mdot
.652 .2117 Mdot
.652 .2123 Mdot
.652 .21245 Mdot
.652 .21281 Mdot
.652 .21328 Mdot
.652 .21385 Mdot
.652 .21412 Mdot
.652 .21543 Mdot
.652 .21613 Mdot
.652 .21652 Mdot
.652 .21653 Mdot
.652 .21681 Mdot
.652 .21713 Mdot
.652 .2178 Mdot
.652 .21933 Mdot
.652 .22012 Mdot
.652 .22064 Mdot
.652 .22072 Mdot
.652 .22107 Mdot
.652 .22285 Mdot
.652 .22406 Mdot
.652 .22452 Mdot
.652 .22461 Mdot
.652 .22583 Mdot
.652 .22604 Mdot
.652 .22675 Mdot
.652 .22798 Mdot
.652 .22808 Mdot
.652 .22811 Mdot
.652 .22831 Mdot
.652 .22965 Mdot
.652 .23129 Mdot
.652 .23173 Mdot
.652 .23369 Mdot
.652 .23428 Mdot
.652 .23441 Mdot
.652 .2348 Mdot
.652 .23549 Mdot
.652 .23565 Mdot
.652 .2363 Mdot
.652 .23641 Mdot
.652 .23684 Mdot
.652 .23898 Mdot
.652 .23927 Mdot
.652 .23991 Mdot
.652 .24023 Mdot
.652 .24063 Mdot
.652 .24101 Mdot
.652 .24105 Mdot
.652 .24142 Mdot
.652 .24184 Mdot
.652 .24202 Mdot
.652 .24279 Mdot
.652 .24481 Mdot
.652 .24502 Mdot
.652 .24523 Mdot
.652 .24545 Mdot
.652 .2456 Mdot
.652 .24569 Mdot
.652 .24602 Mdot
.652 .24708 Mdot
.652 .24796 Mdot
.652 .24812 Mdot
.652 .24817 Mdot
.652 .24886 Mdot
.652 .24889 Mdot
.652 .24924 Mdot
.652 .24959 Mdot
.652 .24977 Mdot
.652 .24987 Mdot
.652 .25055 Mdot
.652 .2506 Mdot
.652 .2519 Mdot
.652 .2532 Mdot
.652 .25337 Mdot
.652 .25477 Mdot
.652 .2577 Mdot
.652 .25806 Mdot
.652 .25858 Mdot
.652 .25865 Mdot
.652 .25881 Mdot
.652 .25903 Mdot
.652 .25911 Mdot
.652 .25932 Mdot
.652 .25968 Mdot
.652 .26133 Mdot
.652 .26137 Mdot
.652 .26239 Mdot
.652 .26301 Mdot
.652 .26383 Mdot
.652 .2644 Mdot
.652 .26441 Mdot
.652 .26474 Mdot
.652 .26484 Mdot
.652 .26556 Mdot
.652 .2665 Mdot
.652 .26697 Mdot
.652 .26699 Mdot
.652 .26717 Mdot
.652 .26779 Mdot
.652 .26803 Mdot
.652 .26844 Mdot
.652 .26849 Mdot
.652 .26854 Mdot
.652 .26858 Mdot
.652 .26926 Mdot
.652 .26959 Mdot
.652 .27053 Mdot
.652 .2707 Mdot
.652 .27158 Mdot
.652 .27236 Mdot
.652 .27257 Mdot
.652 .27304 Mdot
.652 .27365 Mdot
.652 .27439 Mdot
.652 .27474 Mdot
.652 .27644 Mdot
.652 .27735 Mdot
.652 .27787 Mdot
.652 .27788 Mdot
.652 .27825 Mdot
.652 .27866 Mdot
.652 .27954 Mdot
.652 .28153 Mdot
.652 .28257 Mdot
.652 .28324 Mdot
.652 .28335 Mdot
.652 .2838 Mdot
.652 .28612 Mdot
.652 .2877 Mdot
.652 .28831 Mdot
.652 .28842 Mdot
.652 .29001 Mdot
.652 .29029 Mdot
.652 .29121 Mdot
.652 .29281 Mdot
.652 .29294 Mdot
.652 .29299 Mdot
.652 .29324 Mdot
.652 .29499 Mdot
.652 .29713 Mdot
.652 .2977 Mdot
.652 .30026 Mdot
.652 .30102 Mdot
.652 .30119 Mdot
.652 .3017 Mdot
.652 .3026 Mdot
.652 .30281 Mdot
.652 .30366 Mdot
.652 .30381 Mdot
.652 .30437 Mdot
.652 .30715 Mdot
.652 .30754 Mdot
.652 .30837 Mdot
.652 .30878 Mdot
.652 .30931 Mdot
.652 .3098 Mdot
.652 .30985 Mdot
.652 .31034 Mdot
.652 .31088 Mdot
.652 .31112 Mdot
.652 .31213 Mdot
.652 .31477 Mdot
.652 .31503 Mdot
.652 .31531 Mdot
.652 .31559 Mdot
.652 .31579 Mdot
.652 .3159 Mdot
.652 .31633 Mdot
.652 .31772 Mdot
.652 .31886 Mdot
.652 .31908 Mdot
.652 .31914 Mdot
.652 .32004 Mdot
.652 .32008 Mdot
.652 .32053 Mdot
.652 .32099 Mdot
.652 .32122 Mdot
.652 .32135 Mdot
.652 .32225 Mdot
.652 .32231 Mdot
.652 .324 Mdot
.652 .3257 Mdot
.652 .32593 Mdot
.652 .32774 Mdot
.652 .33156 Mdot
.652 .33203 Mdot
.652 .33272 Mdot
.652 .33281 Mdot
.652 .33302 Mdot
.652 .3333 Mdot
.652 .33341 Mdot
.652 .33367 Mdot
.652 .33415 Mdot
.652 .3363 Mdot
.652 .33635 Mdot
.652 .33768 Mdot
.652 .33849 Mdot
.652 .33957 Mdot
.652 .3403 Mdot
.652 .34031 Mdot
.652 .34074 Mdot
.652 .34088 Mdot
.652 .34181 Mdot
.652 .34305 Mdot
.652 .34366 Mdot
.652 .34368 Mdot
.652 .34392 Mdot
.652 .34472 Mdot
.652 .34504 Mdot
.652 .34557 Mdot
.652 .34563 Mdot
.652 .3457 Mdot
.652 .34576 Mdot
.652 .34664 Mdot
.652 .34707 Mdot
.652 .3483 Mdot
.652 .34852 Mdot
.652 .34967 Mdot
.652 .35069 Mdot
.652 .35095 Mdot
.652 .35157 Mdot
.652 .35237 Mdot
.652 .35333 Mdot
.652 .35379 Mdot
.652 .35601 Mdot
.652 .3572 Mdot
.652 .35787 Mdot
.652 .35788 Mdot
.652 .35836 Mdot
.652 .3589 Mdot
.652 .36004 Mdot
.652 .36264 Mdot
.652 .364 Mdot
.652 .36488 Mdot
.652 .36501 Mdot
.652 .3656 Mdot
.652 .36863 Mdot
.652 .37068 Mdot
.652 .37148 Mdot
.652 .37163 Mdot
.652 .37369 Mdot
.652 .37406 Mdot
.652 .37527 Mdot
.652 .37735 Mdot
.652 .37752 Mdot
.652 .37758 Mdot
.652 .37791 Mdot
.652 .38019 Mdot
.652 .38299 Mdot
.652 .38373 Mdot
.652 .38707 Mdot
.652 .38806 Mdot
.652 .38828 Mdot
.652 .38895 Mdot
.652 .39012 Mdot
.652 .39039 Mdot
.652 .39151 Mdot
.652 .39169 Mdot
.652 .39243 Mdot
.652 .39605 Mdot
.652 .39655 Mdot
.652 .39765 Mdot
.652 .39818 Mdot
.652 .39887 Mdot
.652 .3995 Mdot
.652 .39957 Mdot
.652 .40021 Mdot
.654 .01514 Mdot
.654 .01521 Mdot
.654 .01527 Mdot
.654 .01537 Mdot
.654 .01544 Mdot
.654 .01557 Mdot
.654 .01567 Mdot
.654 .01583 Mdot
.654 .01596 Mdot
.654 .01617 Mdot
.654 .01634 Mdot
.654 .01662 Mdot
.654 .01684 Mdot
.654 .01716 Mdot
.654 .0172 Mdot
.654 .0175 Mdot
.654 .0177 Mdot
.654 .01791 Mdot
.654 .01797 Mdot
.654 .01836 Mdot
.654 .01862 Mdot
.654 .0189 Mdot
.654 .01897 Mdot
.654 .01948 Mdot
.654 .01965 Mdot
.654 .01983 Mdot
.654 .02018 Mdot
.654 .02019 Mdot
.654 .02028 Mdot
.654 .02071 Mdot
.654 .02095 Mdot
.654 .02117 Mdot
.654 .0214 Mdot
.654 .02141 Mdot
.654 .02187 Mdot
.654 .02187 Mdot
.654 .022 Mdot
.654 .02256 Mdot
.654 .02287 Mdot
.654 .02316 Mdot
.654 .02335 Mdot
.654 .02346 Mdot
.654 .02346 Mdot
.654 .02347 Mdot
.654 .02407 Mdot
.654 .02408 Mdot
.654 .02424 Mdot
.654 .02497 Mdot
.654 .02519 Mdot
.654 .02538 Mdot
.654 .02576 Mdot
.654 .02601 Mdot
.654 .02601 Mdot
.654 .02615 Mdot
.654 .02615 Mdot
.654 .02617 Mdot
.654 .02695 Mdot
.654 .02696 Mdot
.654 .02718 Mdot
.654 .02793 Mdot
.654 .0281 Mdot
.654 .02813 Mdot
.654 .02842 Mdot
.654 .02866 Mdot
.654 .02911 Mdot
.654 .02916 Mdot
.654 .02925 Mdot
.654 .0293 Mdot
.654 .02934 Mdot
.654 .02948 Mdot
.654 .02948 Mdot
.654 .0295 Mdot
.654 .02961 Mdot
.654 .02967 Mdot
.654 .02968 Mdot
.654 .0297 Mdot
.654 .03072 Mdot
.654 .03073 Mdot
.654 .03101 Mdot
.654 .03171 Mdot
.654 .032 Mdot
.654 .03223 Mdot
.654 .03226 Mdot
.654 .03264 Mdot
.654 .03295 Mdot
.654 .03347 Mdot
.654 .03354 Mdot
.654 .03361 Mdot
.654 .03372 Mdot
.654 .03379 Mdot
.654 .03384 Mdot
.654 .03403 Mdot
.654 .03403 Mdot
.654 .03405 Mdot
.654 .0342 Mdot
.654 .03427 Mdot
.654 .03428 Mdot
.654 .03432 Mdot
.654 .03534 Mdot
.654 .03565 Mdot
.654 .03566 Mdot
.654 .03604 Mdot
.654 .03673 Mdot
.654 .03694 Mdot
.654 .03696 Mdot
.654 .03715 Mdot
.654 .03733 Mdot
.654 .03762 Mdot
.654 .03767 Mdot
.654 .03816 Mdot
.654 .03848 Mdot
.654 .03857 Mdot
.654 .03924 Mdot
.654 .03934 Mdot
.654 .03943 Mdot
.654 .03958 Mdot
.654 .03967 Mdot
.654 .03973 Mdot
.654 .03998 Mdot
.654 .03998 Mdot
.654 .04001 Mdot
.654 .0402 Mdot
.654 .0403 Mdot
.654 .04031 Mdot
.654 .04035 Mdot
.654 .04097 Mdot
.654 .0417 Mdot
.654 .0421 Mdot
.654 .04212 Mdot
.654 .0426 Mdot
.654 .04351 Mdot
.654 .04378 Mdot
.654 .04381 Mdot
.654 .04394 Mdot
.654 .04406 Mdot
.654 .04429 Mdot
.654 .04461 Mdot
.654 .04468 Mdot
.654 .04474 Mdot
.654 .04538 Mdot
.654 .0458 Mdot
.654 .04592 Mdot
.654 .04624 Mdot
.654 .0468 Mdot
.654 .04692 Mdot
.654 .04704 Mdot
.654 .04724 Mdot
.654 .04735 Mdot
.654 .04744 Mdot
.654 .04776 Mdot
.654 .04777 Mdot
.654 .0478 Mdot
.654 .04804 Mdot
.654 .04818 Mdot
.654 .04819 Mdot
.654 .04825 Mdot
.654 .04891 Mdot
.654 .04906 Mdot
.654 .05 Mdot
.654 .05001 Mdot
.654 .05053 Mdot
.654 .05055 Mdot
.654 .05056 Mdot
.654 .0509 Mdot
.654 .05119 Mdot
.654 .05183 Mdot
.654 .05237 Mdot
.654 .05274 Mdot
.654 .05278 Mdot
.654 .05294 Mdot
.654 .05309 Mdot
.654 .0534 Mdot
.654 .05381 Mdot
.654 .0539 Mdot
.654 .05398 Mdot
.654 .05404 Mdot
.654 .05411 Mdot
.654 .05423 Mdot
.654 .0545 Mdot
.654 .05482 Mdot
.654 .05537 Mdot
.654 .05545 Mdot
.654 .05553 Mdot
.654 .05594 Mdot
.654 .05635 Mdot
.654 .05668 Mdot
.654 .05684 Mdot
.654 .057 Mdot
.654 .05725 Mdot
.654 .05741 Mdot
.654 .05752 Mdot
.654 .05794 Mdot
.654 .05795 Mdot
.654 .05799 Mdot
.654 .0583 Mdot
.654 .05831 Mdot
.654 .05848 Mdot
.654 .0585 Mdot
.654 .05858 Mdot
.654 .05945 Mdot
.654 .05963 Mdot
.654 .06086 Mdot
.654 .06088 Mdot
.654 .06154 Mdot
.654 .06156 Mdot
.654 .06158 Mdot
.654 .06159 Mdot
.654 .06204 Mdot
.654 .06243 Mdot
.654 .06327 Mdot
.654 .06397 Mdot
.654 .06408 Mdot
.654 .06445 Mdot
.654 .06445 Mdot
.654 .0645 Mdot
.654 .06472 Mdot
.654 .06491 Mdot
.654 .06532 Mdot
.654 .06586 Mdot
.654 .06598 Mdot
.654 .06608 Mdot
.654 .06613 Mdot
.654 .06616 Mdot
.654 .06621 Mdot
.654 .06625 Mdot
.654 .0664 Mdot
.654 .06645 Mdot
.654 .06675 Mdot
.654 .06714 Mdot
.654 .06717 Mdot
.654 .06789 Mdot
.654 .06799 Mdot
.654 .068 Mdot
.654 .0681 Mdot
.654 .06843 Mdot
.654 .06864 Mdot
.654 .06871 Mdot
.654 .06918 Mdot
.654 .06918 Mdot
.654 .06948 Mdot
.654 .0696 Mdot
.654 .06982 Mdot
.654 .07002 Mdot
.654 .07035 Mdot
.654 .07056 Mdot
.654 .0707 Mdot
.654 .07077 Mdot
.654 .07123 Mdot
.654 .07126 Mdot
.654 .07126 Mdot
.654 .07131 Mdot
.654 .07172 Mdot
.654 .07174 Mdot
.654 .07197 Mdot
.654 .07199 Mdot
.654 .07209 Mdot
.654 .07322 Mdot
.654 .07347 Mdot
.654 .07382 Mdot
.654 .07451 Mdot
.654 .07508 Mdot
.654 .07509 Mdot
.654 .07596 Mdot
.654 .07599 Mdot
.654 .07602 Mdot
.654 .07603 Mdot
.654 .07662 Mdot
.654 .07712 Mdot
.654 .07716 Mdot
.654 .07739 Mdot
.654 .07822 Mdot
.654 .07832 Mdot
.654 .07898 Mdot
.654 .07915 Mdot
.654 .07928 Mdot
.654 .07976 Mdot
.654 .07977 Mdot
.654 .07983 Mdot
.654 .08012 Mdot
.654 .08037 Mdot
.654 .08091 Mdot
.654 .08161 Mdot
.654 .08176 Mdot
.654 .08189 Mdot
.654 .08196 Mdot
.654 .082 Mdot
.654 .08207 Mdot
.654 .08212 Mdot
.654 .08232 Mdot
.654 .08239 Mdot
.654 .08278 Mdot
.654 .08329 Mdot
.654 .08333 Mdot
.654 .08357 Mdot
.654 .08427 Mdot
.654 .0844 Mdot
.654 .08441 Mdot
.654 .08442 Mdot
.654 .08448 Mdot
.654 .08454 Mdot
.654 .08455 Mdot
.654 .08497 Mdot
.654 .08498 Mdot
.654 .08525 Mdot
.654 .08535 Mdot
.654 .08535 Mdot
.654 .08539 Mdot
.654 .08595 Mdot
.654 .08596 Mdot
.654 .08635 Mdot
.654 .08651 Mdot
.654 .08679 Mdot
.654 .08705 Mdot
.654 .08707 Mdot
.654 .08749 Mdot
.654 .08776 Mdot
.654 .08794 Mdot
.654 .08804 Mdot
.654 .08814 Mdot
.654 .08822 Mdot
.654 .08863 Mdot
.654 .08867 Mdot
.654 .08868 Mdot
.654 .08875 Mdot
.654 .08928 Mdot
.654 .0893 Mdot
.654 .0896 Mdot
.654 .08963 Mdot
.654 .08976 Mdot
.654 .09 Mdot
.654 .09061 Mdot
.654 .09066 Mdot
.654 .09092 Mdot
.654 .09124 Mdot
.654 .09157 Mdot
.654 .09203 Mdot
.654 .09293 Mdot
.654 .09328 Mdot
.654 .09367 Mdot
.654 .09369 Mdot
.654 .09458 Mdot
.654 .09462 Mdot
.654 .09482 Mdot
.654 .09486 Mdot
.654 .0949 Mdot
.654 .09492 Mdot
.654 .09569 Mdot
.654 .09634 Mdot
.654 .09639 Mdot
.654 .09642 Mdot
.654 .09669 Mdot
.654 .09719 Mdot
.654 .09778 Mdot
.654 .09791 Mdot
.654 .09824 Mdot
.654 .09877 Mdot
.654 .09899 Mdot
.654 .09917 Mdot
.654 .0998 Mdot
.654 .09981 Mdot
.654 .09984 Mdot
.654 .09989 Mdot
.654 .10008 Mdot
.654 .10026 Mdot
.654 .1006 Mdot
.654 .10129 Mdot
.654 .1018 Mdot
.654 .10188 Mdot
.654 .10221 Mdot
.654 .10223 Mdot
.654 .10241 Mdot
.654 .10259 Mdot
.654 .10267 Mdot
.654 .10273 Mdot
.654 .10282 Mdot
.654 .10288 Mdot
.654 .10314 Mdot
.654 .10323 Mdot
.654 .10375 Mdot
.654 .10441 Mdot
.654 .10446 Mdot
.654 .10465 Mdot
.654 .10478 Mdot
.654 .10569 Mdot
.654 .10586 Mdot
.654 .10588 Mdot
.654 .10589 Mdot
.654 .10597 Mdot
.654 .10605 Mdot
.654 .10606 Mdot
.654 .10639 Mdot
.654 .10661 Mdot
.654 .10662 Mdot
.654 .10698 Mdot
.654 .1071 Mdot
.654 .10711 Mdot
.654 .10716 Mdot
.654 .10763 Mdot
.654 .10789 Mdot
.654 .1079 Mdot
.654 .10826 Mdot
.654 .10841 Mdot
.654 .10862 Mdot
.654 .10894 Mdot
.654 .10899 Mdot
.654 .10934 Mdot
.654 .10935 Mdot
.654 .10942 Mdot
.654 .1099 Mdot
.654 .11025 Mdot
.654 .1105 Mdot
.654 .11062 Mdot
.654 .11076 Mdot
.654 .11086 Mdot
.654 .1114 Mdot
.654 .11145 Mdot
.654 .11146 Mdot
.654 .11155 Mdot
.654 .11214 Mdot
.654 .11224 Mdot
.654 .11227 Mdot
.654 .1124 Mdot
.654 .11243 Mdot
.654 .11266 Mdot
.654 .11271 Mdot
.654 .11287 Mdot
.654 .11288 Mdot
.654 .11319 Mdot
.654 .11399 Mdot
.654 .11405 Mdot
.654 .11439 Mdot
.654 .11482 Mdot
.654 .11524 Mdot
.654 .11584 Mdot
.654 .11586 Mdot
.654 .11637 Mdot
.654 .11651 Mdot
.654 .11702 Mdot
.654 .11716 Mdot
.654 .1173 Mdot
.654 .11748 Mdot
.654 .11799 Mdot
.654 .11801 Mdot
.654 .11847 Mdot
.654 .11868 Mdot
.654 .11918 Mdot
.654 .11923 Mdot
.654 .11949 Mdot
.654 .11953 Mdot
.654 .11954 Mdot
.654 .11955 Mdot
.654 .11959 Mdot
.654 .11962 Mdot
.654 .12063 Mdot
.654 .12112 Mdot
.654 .12148 Mdot
.654 .12154 Mdot
.654 .12159 Mdot
.654 .12194 Mdot
.654 .12259 Mdot
.654 .12337 Mdot
.654 .12354 Mdot
.654 .12396 Mdot
.654 .12466 Mdot
.654 .12495 Mdot
.654 .12509 Mdot
.654 .12518 Mdot
.654 .12543 Mdot
.654 .126 Mdot
.654 .12602 Mdot
.654 .12605 Mdot
.654 .12612 Mdot
.654 .12637 Mdot
.654 .12661 Mdot
.654 .12705 Mdot
.654 .12712 Mdot
.654 .12796 Mdot
.654 .12863 Mdot
.654 .12872 Mdot
.654 .12916 Mdot
.654 .12918 Mdot
.654 .12924 Mdot
.654 .12943 Mdot
.654 .12965 Mdot
.654 .12976 Mdot
.654 .12984 Mdot
.654 .12996 Mdot
.654 .13004 Mdot
.654 .13037 Mdot
.654 .13049 Mdot
.654 .13117 Mdot
.654 .13135 Mdot
.654 .13204 Mdot
.654 .1321 Mdot
.654 .13235 Mdot
.654 .13252 Mdot
.654 .13372 Mdot
.654 .13394 Mdot
.654 .13395 Mdot
.654 .13397 Mdot
.654 .13408 Mdot
.654 .13418 Mdot
.654 .13419 Mdot
.654 .13463 Mdot
.654 .13491 Mdot
.654 .13493 Mdot
.654 .1354 Mdot
.654 .13555 Mdot
.654 .13557 Mdot
.654 .13564 Mdot
.654 .13625 Mdot
.654 .13659 Mdot
.654 .1366 Mdot
.654 .13707 Mdot
.654 .13727 Mdot
.654 .13755 Mdot
.654 .13796 Mdot
.654 .13803 Mdot
.654 .13848 Mdot
.654 .1385 Mdot
.654 .13859 Mdot
.654 .13922 Mdot
.654 .13968 Mdot
.654 .14 Mdot
.654 .14017 Mdot
.654 .14034 Mdot
.654 .14047 Mdot
.654 .14118 Mdot
.654 .14125 Mdot
.654 .14125 Mdot
.654 .14137 Mdot
.654 .14215 Mdot
.654 .14228 Mdot
.654 .14232 Mdot
.654 .14249 Mdot
.654 .14253 Mdot
.654 .14283 Mdot
.654 .14289 Mdot
.654 .14311 Mdot
.654 .14311 Mdot
.654 .14352 Mdot
.654 .14456 Mdot
.654 .14465 Mdot
.654 .14509 Mdot
.654 .14565 Mdot
.654 .1462 Mdot
.654 .14699 Mdot
.654 .14701 Mdot
.654 .14768 Mdot
.654 .14787 Mdot
.654 .14853 Mdot
.654 .14871 Mdot
.654 .14889 Mdot
.654 .14913 Mdot
.654 .14979 Mdot
.654 .14983 Mdot
.654 .15042 Mdot
.654 .1507 Mdot
.654 .15136 Mdot
.654 .15142 Mdot
.654 .15176 Mdot
.654 .15181 Mdot
.654 .15183 Mdot
.654 .15184 Mdot
.654 .1519 Mdot
.654 .15193 Mdot
.654 .15265 Mdot
.654 .15325 Mdot
.654 .15389 Mdot
.654 .15436 Mdot
.654 .15445 Mdot
.654 .15451 Mdot
.654 .15496 Mdot
.654 .15581 Mdot
.654 .15683 Mdot
.654 .15706 Mdot
.654 .15761 Mdot
.654 .15853 Mdot
.654 .1589 Mdot
.654 .15909 Mdot
.654 .15921 Mdot
.654 .15953 Mdot
.654 .16028 Mdot
.654 .1603 Mdot
.654 .16034 Mdot
.654 .16044 Mdot
.654 .16076 Mdot
.654 .16107 Mdot
.654 .16165 Mdot
.654 .16173 Mdot
.654 .16284 Mdot
.654 .16371 Mdot
.654 .16384 Mdot
.654 .16441 Mdot
.654 .16444 Mdot
.654 .16452 Mdot
.654 .16476 Mdot
.654 .16505 Mdot
.654 .1652 Mdot
.654 .16529 Mdot
.654 .16545 Mdot
.654 .16556 Mdot
.654 .166 Mdot
.654 .16615 Mdot
.654 .16704 Mdot
.654 .16727 Mdot
.654 .16818 Mdot
.654 .16826 Mdot
.654 .16858 Mdot
.654 .1688 Mdot
.654 .17037 Mdot
.654 .17066 Mdot
.654 .17068 Mdot
.654 .1707 Mdot
.654 .17085 Mdot
.654 .17098 Mdot
.654 .17099 Mdot
.654 .17156 Mdot
.654 .17193 Mdot
.654 .17196 Mdot
.654 .17257 Mdot
.654 .17277 Mdot
.654 .17279 Mdot
.654 .17288 Mdot
.654 .17369 Mdot
.654 .17413 Mdot
.654 .17414 Mdot
.654 .17476 Mdot
.654 .17502 Mdot
.654 .17538 Mdot
.654 .17593 Mdot
.654 .17601 Mdot
.654 .1766 Mdot
.654 .17662 Mdot
.654 .17674 Mdot
.654 .17757 Mdot
.654 .17817 Mdot
.654 .17859 Mdot
.654 .1788 Mdot
.654 .17904 Mdot
.654 .1792 Mdot
.654 .18013 Mdot
.654 .18022 Mdot
.654 .18023 Mdot
.654 .18038 Mdot
.654 .1814 Mdot
.654 .18157 Mdot
.654 .18162 Mdot
.654 .18184 Mdot
.654 .18189 Mdot
.654 .18229 Mdot
.654 .18236 Mdot
.654 .18265 Mdot
.654 .18266 Mdot
.654 .1832 Mdot
.654 .18455 Mdot
.654 .18467 Mdot
.654 .18525 Mdot
.654 .18597 Mdot
.654 .18669 Mdot
.654 .18773 Mdot
.654 .18776 Mdot
.654 .18863 Mdot
.654 .18888 Mdot
.654 .18975 Mdot
.654 .18998 Mdot
.654 .19022 Mdot
.654 .19053 Mdot
.654 .1914 Mdot
.654 .19145 Mdot
.654 .19222 Mdot
.654 .19259 Mdot
.654 .19345 Mdot
.654 .19352 Mdot
.654 .19397 Mdot
.654 .19403 Mdot
.654 .19406 Mdot
.654 .19408 Mdot
.654 .19415 Mdot
.654 .1942 Mdot
.654 .19513 Mdot
.654 .19592 Mdot
.654 .19676 Mdot
.654 .19738 Mdot
.654 .19748 Mdot
.654 .19756 Mdot
.654 .19816 Mdot
.654 .19927 Mdot
.654 .2006 Mdot
.654 .2009 Mdot
.654 .20163 Mdot
.654 .20282 Mdot
.654 .20331 Mdot
.654 .20355 Mdot
.654 .20371 Mdot
.654 .20413 Mdot
.654 .20512 Mdot
.654 .20515 Mdot
.654 .2052 Mdot
.654 .20532 Mdot
.654 .20574 Mdot
.654 .20615 Mdot
.654 .2069 Mdot
.654 .20702 Mdot
.654 .20846 Mdot
.654 .2096 Mdot
.654 .20977 Mdot
.654 .21051 Mdot
.654 .21055 Mdot
.654 .21066 Mdot
.654 .21097 Mdot
.654 .21135 Mdot
.654 .21155 Mdot
.654 .21167 Mdot
.654 .21188 Mdot
.654 .21201 Mdot
.654 .21259 Mdot
.654 .21279 Mdot
.654 .21395 Mdot
.654 .21426 Mdot
.654 .21544 Mdot
.654 .21555 Mdot
.654 .21596 Mdot
.654 .21626 Mdot
.654 .21831 Mdot
.654 .21869 Mdot
.654 .21872 Mdot
.654 .21875 Mdot
.654 .21893 Mdot
.654 .21911 Mdot
.654 .21912 Mdot
.654 .21987 Mdot
.654 .22035 Mdot
.654 .22039 Mdot
.654 .22118 Mdot
.654 .22146 Mdot
.654 .22148 Mdot
.654 .22159 Mdot
.654 .22265 Mdot
.654 .22323 Mdot
.654 .22325 Mdot
.654 .22405 Mdot
.654 .22439 Mdot
.654 .22486 Mdot
.654 .22558 Mdot
.654 .22569 Mdot
.654 .22646 Mdot
.654 .22649 Mdot
.654 .22665 Mdot
.654 .22773 Mdot
.654 .22851 Mdot
.654 .22906 Mdot
.654 .22934 Mdot
.654 .22965 Mdot
.654 .22986 Mdot
.654 .23108 Mdot
.654 .23119 Mdot
.654 .23121 Mdot
.654 .23141 Mdot
.654 .23274 Mdot
.654 .23297 Mdot
.654 .23303 Mdot
.654 .23332 Mdot
.654 .23338 Mdot
.654 .2339 Mdot
.654 .234 Mdot
.654 .23438 Mdot
.654 .23438 Mdot
.654 .23509 Mdot
.654 .23686 Mdot
.654 .23701 Mdot
.654 .23777 Mdot
.654 .23872 Mdot
.654 .23966 Mdot
.654 .24102 Mdot
.654 .24106 Mdot
.654 .2422 Mdot
.654 .24252 Mdot
.654 .24366 Mdot
.654 .24397 Mdot
.654 .24427 Mdot
.654 .24469 Mdot
.654 .24582 Mdot
.654 .24588 Mdot
.654 .24689 Mdot
.654 .24737 Mdot
.654 .2485 Mdot
.654 .2486 Mdot
.654 .24918 Mdot
.654 .24926 Mdot
.654 .2493 Mdot
.654 .24932 Mdot
.654 .24941 Mdot
.654 .24948 Mdot
.654 .2507 Mdot
.654 .25173 Mdot
.654 .25283 Mdot
.654 .25364 Mdot
.654 .25377 Mdot
.654 .25388 Mdot
.654 .25466 Mdot
.654 .25612 Mdot
.654 .25785 Mdot
.654 .25824 Mdot
.654 .2592 Mdot
.654 .26076 Mdot
.654 .26139 Mdot
.654 .26171 Mdot
.654 .26192 Mdot
.654 .26247 Mdot
.654 .26376 Mdot
.654 .2638 Mdot
.654 .26387 Mdot
.654 .26403 Mdot
.654 .26458 Mdot
.654 .26511 Mdot
.654 .2661 Mdot
.654 .26624 Mdot
.654 .26814 Mdot
.654 .26962 Mdot
.654 .26984 Mdot
.654 .27082 Mdot
.654 .27087 Mdot
.654 .27101 Mdot
.654 .27142 Mdot
.654 .27192 Mdot
.654 .27217 Mdot
.654 .27233 Mdot
.654 .27261 Mdot
.654 .27278 Mdot
.654 .27354 Mdot
.654 .2738 Mdot
.654 .27532 Mdot
.654 .27572 Mdot
.654 .27727 Mdot
.654 .2774 Mdot
.654 .27795 Mdot
.654 .27833 Mdot
.654 .28102 Mdot
.654 .28151 Mdot
.654 .28155 Mdot
.654 .28159 Mdot
.654 .28183 Mdot
.654 .28206 Mdot
.654 .28208 Mdot
.654 .28306 Mdot
.654 .28369 Mdot
.654 .28373 Mdot
.654 .28478 Mdot
.654 .28513 Mdot
.654 .28516 Mdot
.654 .28531 Mdot
.654 .28669 Mdot
.654 .28745 Mdot
.654 .28747 Mdot
.654 .28853 Mdot
.654 .28898 Mdot
.654 .28959 Mdot
.654 .29052 Mdot
.654 .29067 Mdot
.654 .29167 Mdot
.654 .29172 Mdot
.654 .29192 Mdot
.654 .29334 Mdot
.654 .29436 Mdot
.654 .29508 Mdot
.654 .29545 Mdot
.654 .29585 Mdot
.654 .29613 Mdot
.654 .29772 Mdot
.654 .29787 Mdot
.654 .29788 Mdot
.654 .29815 Mdot
.654 .29989 Mdot
.654 .30019 Mdot
.654 .30027 Mdot
.654 .30065 Mdot
.654 .30073 Mdot
.654 .30141 Mdot
.654 .30154 Mdot
.654 .30203 Mdot
.654 .30204 Mdot
.654 .30296 Mdot
.654 .30529 Mdot
.654 .30548 Mdot
.654 .30647 Mdot
.654 .30771 Mdot
.654 .30894 Mdot
.654 .31072 Mdot
.654 .31078 Mdot
.654 .31227 Mdot
.654 .31268 Mdot
.654 .31417 Mdot
.654 .31458 Mdot
.654 .31498 Mdot
.654 .31552 Mdot
.654 .317 Mdot
.654 .31708 Mdot
.654 .3184 Mdot
.654 .31903 Mdot
.654 .3205 Mdot
.654 .32063 Mdot
.654 .3214 Mdot
.654 .32151 Mdot
.654 .32155 Mdot
.654 .32158 Mdot
.654 .3217 Mdot
.654 .32178 Mdot
.654 .32339 Mdot
.654 .32473 Mdot
.654 .32617 Mdot
.654 .32722 Mdot
.654 .3274 Mdot
.654 .32755 Mdot
.654 .32856 Mdot
.654 .33047 Mdot
.654 .33274 Mdot
.654 .33325 Mdot
.654 .33449 Mdot
.654 .33654 Mdot
.654 .33737 Mdot
.654 .33779 Mdot
.654 .33806 Mdot
.654 .33877 Mdot
.654 .34046 Mdot
.654 .34052 Mdot
.654 .34061 Mdot
.654 .34081 Mdot
.654 .34154 Mdot
.654 .34223 Mdot
.654 .34372 Mdot
.654 .34619 Mdot
.654 .34814 Mdot
.654 .34842 Mdot
.654 .3497 Mdot
.654 .34977 Mdot
.654 .34995 Mdot
.654 .35048 Mdot
.654 .35113 Mdot
.654 .35147 Mdot
.654 .35168 Mdot
.654 .35204 Mdot
.654 .35227 Mdot
.654 .35325 Mdot
.654 .3536 Mdot
.654 .35559 Mdot
.654 .35611 Mdot
.654 .35813 Mdot
.654 .35831 Mdot
.654 .35903 Mdot
.654 .35953 Mdot
.654 .36304 Mdot
.654 .36369 Mdot
.654 .36374 Mdot
.654 .36379 Mdot
.654 .36411 Mdot
.654 .3644 Mdot
.654 .36443 Mdot
.654 .36571 Mdot
.654 .36653 Mdot
.654 .36659 Mdot
.654 .36796 Mdot
.654 .36842 Mdot
.654 .36846 Mdot
.654 .36866 Mdot
.654 .37046 Mdot
.654 .37146 Mdot
.654 .37148 Mdot
.654 .37286 Mdot
.654 .37345 Mdot
.654 .37425 Mdot
.654 .37547 Mdot
.654 .37566 Mdot
.654 .37698 Mdot
.654 .37703 Mdot
.654 .3773 Mdot
.654 .37915 Mdot
.654 .38049 Mdot
.654 .38143 Mdot
.654 .38191 Mdot
.654 .38244 Mdot
.654 .3828 Mdot
.654 .38488 Mdot
.654 .38508 Mdot
.654 .3851 Mdot
.654 .38544 Mdot
.654 .38773 Mdot
.654 .38811 Mdot
.654 .38822 Mdot
.654 .38872 Mdot
.654 .38882 Mdot
.654 .38972 Mdot
.654 .38988 Mdot
.654 .39053 Mdot
.654 .39054 Mdot
.654 .39175 Mdot
.654 .39478 Mdot
.654 .39504 Mdot
.654 .39633 Mdot
.654 .39796 Mdot
.654 .39957 Mdot
.656 .01596 Mdot
.656 .01635 Mdot
.656 .01652 Mdot
.656 .01686 Mdot
.656 .01709 Mdot
.656 .01753 Mdot
.656 .01783 Mdot
.656 .01789 Mdot
.656 .01807 Mdot
.656 .01841 Mdot
.656 .0188 Mdot
.656 .01888 Mdot
.656 .01911 Mdot
.656 .01956 Mdot
.656 .02008 Mdot
.656 .02018 Mdot
.656 .02049 Mdot
.656 .02097 Mdot
.656 .02107 Mdot
.656 .02175 Mdot
.656 .02188 Mdot
.656 .02201 Mdot
.656 .02218 Mdot
.656 .02229 Mdot
.656 .02292 Mdot
.656 .02299 Mdot
.656 .02305 Mdot
.656 .02378 Mdot
.656 .02395 Mdot
.656 .02412 Mdot
.656 .02429 Mdot
.656 .02451 Mdot
.656 .02465 Mdot
.656 .02547 Mdot
.656 .02557 Mdot
.656 .02565 Mdot
.656 .02661 Mdot
.656 .02683 Mdot
.656 .02699 Mdot
.656 .02705 Mdot
.656 .02728 Mdot
.656 .02744 Mdot
.656 .02756 Mdot
.656 .02768 Mdot
.656 .02775 Mdot
.656 .02832 Mdot
.656 .02883 Mdot
.656 .02895 Mdot
.656 .02906 Mdot
.656 .02998 Mdot
.656 .03032 Mdot
.656 .03061 Mdot
.656 .03082 Mdot
.656 .0309 Mdot
.656 .0311 Mdot
.656 .0312 Mdot
.656 .03141 Mdot
.656 .03157 Mdot
.656 .03172 Mdot
.656 .03182 Mdot
.656 .03188 Mdot
.656 .03256 Mdot
.656 .03265 Mdot
.656 .03265 Mdot
.656 .03324 Mdot
.656 .03339 Mdot
.656 .03354 Mdot
.656 .03474 Mdot
.656 .0349 Mdot
.656 .03518 Mdot
.656 .03556 Mdot
.656 .03571 Mdot
.656 .03584 Mdot
.656 .03594 Mdot
.656 .03607 Mdot
.656 .03622 Mdot
.656 .03634 Mdot
.656 .03662 Mdot
.656 .03672 Mdot
.656 .03682 Mdot
.656 .03699 Mdot
.656 .03702 Mdot
.656 .03716 Mdot
.656 .03723 Mdot
.656 .03813 Mdot
.656 .03824 Mdot
.656 .03825 Mdot
.656 .0386 Mdot
.656 .03883 Mdot
.656 .03901 Mdot
.656 .03922 Mdot
.656 .03941 Mdot
.656 .04014 Mdot
.656 .04098 Mdot
.656 .0412 Mdot
.656 .04157 Mdot
.656 .04207 Mdot
.656 .04226 Mdot
.656 .04244 Mdot
.656 .04257 Mdot
.656 .04273 Mdot
.656 .04293 Mdot
.656 .04305 Mdot
.656 .04309 Mdot
.656 .04346 Mdot
.656 .04359 Mdot
.656 .04372 Mdot
.656 .04393 Mdot
.656 .04398 Mdot
.656 .04402 Mdot
.656 .04416 Mdot
.656 .04425 Mdot
.656 .04543 Mdot
.656 .04559 Mdot
.656 .04559 Mdot
.656 .0457 Mdot
.656 .04582 Mdot
.656 .04588 Mdot
.656 .04601 Mdot
.656 .04606 Mdot
.656 .04635 Mdot
.656 .04659 Mdot
.656 .04687 Mdot
.656 .04711 Mdot
.656 .04771 Mdot
.656 .04808 Mdot
.656 .04918 Mdot
.656 .04946 Mdot
.656 .04995 Mdot
.656 .04995 Mdot
.656 .05022 Mdot
.656 .05033 Mdot
.656 .05047 Mdot
.656 .0506 Mdot
.656 .05085 Mdot
.656 .05108 Mdot
.656 .05126 Mdot
.656 .05148 Mdot
.656 .05172 Mdot
.656 .05173 Mdot
.656 .05189 Mdot
.656 .05194 Mdot
.656 .05243 Mdot
.656 .0526 Mdot
.656 .05277 Mdot
.656 .05299 Mdot
.656 .05305 Mdot
.656 .05312 Mdot
.656 .05314 Mdot
.656 .05316 Mdot
.656 .05334 Mdot
.656 .05347 Mdot
.656 .05468 Mdot
.656 .05494 Mdot
.656 .05502 Mdot
.656 .05522 Mdot
.656 .05523 Mdot
.656 .05537 Mdot
.656 .05553 Mdot
.656 .0556 Mdot
.656 .05561 Mdot
.656 .05577 Mdot
.656 .05583 Mdot
.656 .05623 Mdot
.656 .05654 Mdot
.656 .0569 Mdot
.656 .0572 Mdot
.656 .05722 Mdot
.656 .05801 Mdot
.656 .05819 Mdot
.656 .05849 Mdot
.656 .05993 Mdot
.656 .0603 Mdot
.656 .06035 Mdot
.656 .06094 Mdot
.656 .06094 Mdot
.656 .0612 Mdot
.656 .06129 Mdot
.656 .06133 Mdot
.656 .06144 Mdot
.656 .06162 Mdot
.656 .06165 Mdot
.656 .0618 Mdot
.656 .06213 Mdot
.656 .06243 Mdot
.656 .06266 Mdot
.656 .06294 Mdot
.656 .06312 Mdot
.656 .06326 Mdot
.656 .06328 Mdot
.656 .06348 Mdot
.656 .06355 Mdot
.656 .06385 Mdot
.656 .0642 Mdot
.656 .06441 Mdot
.656 .0646 Mdot
.656 .06465 Mdot
.656 .06475 Mdot
.656 .06493 Mdot
.656 .065 Mdot
.656 .06501 Mdot
.656 .0651 Mdot
.656 .06513 Mdot
.656 .06516 Mdot
.656 .06517 Mdot
.656 .06526 Mdot
.656 .0654 Mdot
.656 .06556 Mdot
.656 .06604 Mdot
.656 .06715 Mdot
.656 .06749 Mdot
.656 .06759 Mdot
.656 .06764 Mdot
.656 .06785 Mdot
.656 .06787 Mdot
.656 .06806 Mdot
.656 .06826 Mdot
.656 .06826 Mdot
.656 .06835 Mdot
.656 .06836 Mdot
.656 .06836 Mdot
.656 .06858 Mdot
.656 .06866 Mdot
.656 .06912 Mdot
.656 .06918 Mdot
.656 .06944 Mdot
.656 .06959 Mdot
.656 .06965 Mdot
.656 .06972 Mdot
.656 .07006 Mdot
.656 .07045 Mdot
.656 .07049 Mdot
.656 .07051 Mdot
.656 .07151 Mdot
.656 .07173 Mdot
.656 .07175 Mdot
.656 .07215 Mdot
.656 .07296 Mdot
.656 .07319 Mdot
.656 .07404 Mdot
.656 .07452 Mdot
.656 .07459 Mdot
.656 .07537 Mdot
.656 .07537 Mdot
.656 .0757 Mdot
.656 .07582 Mdot
.656 .07588 Mdot
.656 .07602 Mdot
.656 .07626 Mdot
.656 .07629 Mdot
.656 .07649 Mdot
.656 .07692 Mdot
.656 .07732 Mdot
.656 .07736 Mdot
.656 .07762 Mdot
.656 .07799 Mdot
.656 .07822 Mdot
.656 .07841 Mdot
.656 .07843 Mdot
.656 .0787 Mdot
.656 .07879 Mdot
.656 .0788 Mdot
.656 .07918 Mdot
.656 .07963 Mdot
.656 .07992 Mdot
.656 .08016 Mdot
.656 .0802 Mdot
.656 .08023 Mdot
.656 .08036 Mdot
.656 .0806 Mdot
.656 .08069 Mdot
.656 .0807 Mdot
.656 .08082 Mdot
.656 .08087 Mdot
.656 .0809 Mdot
.656 .08091 Mdot
.656 .08103 Mdot
.656 .08121 Mdot
.656 .08143 Mdot
.656 .08205 Mdot
.656 .0835 Mdot
.656 .08396 Mdot
.656 .08409 Mdot
.656 .08415 Mdot
.656 .08427 Mdot
.656 .08443 Mdot
.656 .08445 Mdot
.656 .0847 Mdot
.656 .08497 Mdot
.656 .08497 Mdot
.656 .08509 Mdot
.656 .0851 Mdot
.656 .0851 Mdot
.656 .08539 Mdot
.656 .08549 Mdot
.656 .08609 Mdot
.656 .08617 Mdot
.656 .08651 Mdot
.656 .08671 Mdot
.656 .08678 Mdot
.656 .08688 Mdot
.656 .08688 Mdot
.656 .08709 Mdot
.656 .08733 Mdot
.656 .08784 Mdot
.656 .08789 Mdot
.656 .08792 Mdot
.656 .08923 Mdot
.656 .0894 Mdot
.656 .08952 Mdot
.656 .08954 Mdot
.656 .09006 Mdot
.656 .09012 Mdot
.656 .09102 Mdot
.656 .09113 Mdot
.656 .0914 Mdot
.656 .09143 Mdot
.656 .09221 Mdot
.656 .09255 Mdot
.656 .09318 Mdot
.656 .09327 Mdot
.656 .09332 Mdot
.656 .09344 Mdot
.656 .09429 Mdot
.656 .09429 Mdot
.656 .09473 Mdot
.656 .09489 Mdot
.656 .09496 Mdot
.656 .09509 Mdot
.656 .09514 Mdot
.656 .09546 Mdot
.656 .0955 Mdot
.656 .09576 Mdot
.656 .09633 Mdot
.656 .09685 Mdot
.656 .09687 Mdot
.656 .09688 Mdot
.656 .09691 Mdot
.656 .09724 Mdot
.656 .09768 Mdot
.656 .09774 Mdot
.656 .09776 Mdot
.656 .09778 Mdot
.656 .09803 Mdot
.656 .09828 Mdot
.656 .09831 Mdot
.656 .09861 Mdot
.656 .09866 Mdot
.656 .09878 Mdot
.656 .09879 Mdot
.656 .0993 Mdot
.656 .09972 Mdot
.656 .09989 Mdot
.656 .10026 Mdot
.656 .10041 Mdot
.656 .10058 Mdot
.656 .10063 Mdot
.656 .10067 Mdot
.656 .10084 Mdot
.656 .10115 Mdot
.656 .10127 Mdot
.656 .10129 Mdot
.656 .10144 Mdot
.656 .1015 Mdot
.656 .10154 Mdot
.656 .10156 Mdot
.656 .10171 Mdot
.656 .10195 Mdot
.656 .10219 Mdot
.656 .10224 Mdot
.656 .10306 Mdot
.656 .10441 Mdot
.656 .10492 Mdot
.656 .10497 Mdot
.656 .10542 Mdot
.656 .10556 Mdot
.656 .10574 Mdot
.656 .10581 Mdot
.656 .10597 Mdot
.656 .10619 Mdot
.656 .10621 Mdot
.656 .10653 Mdot
.656 .10688 Mdot
.656 .10689 Mdot
.656 .10704 Mdot
.656 .10706 Mdot
.656 .10706 Mdot
.656 .10722 Mdot
.656 .10744 Mdot
.656 .10758 Mdot
.656 .10793 Mdot
.656 .10836 Mdot
.656 .10846 Mdot
.656 .10856 Mdot
.656 .10891 Mdot
.656 .10905 Mdot
.656 .10917 Mdot
.656 .10927 Mdot
.656 .10939 Mdot
.656 .1094 Mdot
.656 .10967 Mdot
.656 .10969 Mdot
.656 .10969 Mdot
.656 .10998 Mdot
.656 .11066 Mdot
.656 .11072 Mdot
.656 .11076 Mdot
.656 .11111 Mdot
.656 .11117 Mdot
.656 .11121 Mdot
.656 .11248 Mdot
.656 .11269 Mdot
.656 .11271 Mdot
.656 .11286 Mdot
.656 .11289 Mdot
.656 .11357 Mdot
.656 .11364 Mdot
.656 .11483 Mdot
.656 .11497 Mdot
.656 .11532 Mdot
.656 .11537 Mdot
.656 .11611 Mdot
.656 .11638 Mdot
.656 .11642 Mdot
.656 .11663 Mdot
.656 .11684 Mdot
.656 .11766 Mdot
.656 .11778 Mdot
.656 .11784 Mdot
.656 .118 Mdot
.656 .11843 Mdot
.656 .11872 Mdot
.656 .11892 Mdot
.656 .11912 Mdot
.656 .11912 Mdot
.656 .1197 Mdot
.656 .11991 Mdot
.656 .12 Mdot
.656 .12017 Mdot
.656 .12023 Mdot
.656 .12065 Mdot
.656 .12071 Mdot
.656 .12105 Mdot
.656 .12179 Mdot
.656 .12248 Mdot
.656 .12251 Mdot
.656 .12252 Mdot
.656 .12256 Mdot
.656 .12299 Mdot
.656 .12357 Mdot
.656 .12364 Mdot
.656 .12367 Mdot
.656 .1237 Mdot
.656 .12402 Mdot
.656 .12435 Mdot
.656 .12439 Mdot
.656 .12478 Mdot
.656 .12485 Mdot
.656 .12501 Mdot
.656 .12502 Mdot
.656 .12543 Mdot
.656 .12569 Mdot
.656 .12624 Mdot
.656 .12646 Mdot
.656 .1265 Mdot
.656 .12658 Mdot
.656 .12696 Mdot
.656 .12715 Mdot
.656 .12734 Mdot
.656 .12738 Mdot
.656 .12744 Mdot
.656 .12748 Mdot
.656 .12751 Mdot
.656 .12771 Mdot
.656 .12812 Mdot
.656 .12828 Mdot
.656 .1283 Mdot
.656 .1285 Mdot
.656 .12858 Mdot
.656 .12864 Mdot
.656 .12865 Mdot
.656 .12886 Mdot
.656 .12917 Mdot
.656 .12949 Mdot
.656 .12955 Mdot
.656 .13062 Mdot
.656 .13099 Mdot
.656 .13135 Mdot
.656 .1324 Mdot
.656 .13307 Mdot
.656 .13312 Mdot
.656 .13372 Mdot
.656 .1339 Mdot
.656 .13413 Mdot
.656 .13423 Mdot
.656 .13444 Mdot
.656 .13472 Mdot
.656 .13476 Mdot
.656 .13518 Mdot
.656 .13564 Mdot
.656 .13564 Mdot
.656 .13585 Mdot
.656 .13587 Mdot
.656 .13587 Mdot
.656 .13609 Mdot
.656 .13637 Mdot
.656 .13655 Mdot
.656 .13701 Mdot
.656 .13758 Mdot
.656 .13771 Mdot
.656 .13784 Mdot
.656 .1383 Mdot
.656 .13848 Mdot
.656 .13865 Mdot
.656 .13877 Mdot
.656 .13894 Mdot
.656 .13894 Mdot
.656 .1393 Mdot
.656 .13932 Mdot
.656 .13933 Mdot
.656 .13971 Mdot
.656 .14059 Mdot
.656 .14067 Mdot
.656 .14072 Mdot
.656 .14118 Mdot
.656 .14126 Mdot
.656 .14131 Mdot
.656 .14299 Mdot
.656 .14326 Mdot
.656 .14328 Mdot
.656 .14348 Mdot
.656 .14352 Mdot
.656 .14442 Mdot
.656 .14451 Mdot
.656 .14606 Mdot
.656 .14625 Mdot
.656 .14671 Mdot
.656 .14677 Mdot
.656 .14775 Mdot
.656 .1481 Mdot
.656 .14816 Mdot
.656 .14843 Mdot
.656 .1487 Mdot
.656 .14978 Mdot
.656 .14994 Mdot
.656 .15001 Mdot
.656 .15023 Mdot
.656 .15079 Mdot
.656 .15117 Mdot
.656 .15143 Mdot
.656 .15169 Mdot
.656 .15169 Mdot
.656 .15245 Mdot
.656 .15273 Mdot
.656 .15285 Mdot
.656 .15307 Mdot
.656 .15316 Mdot
.656 .1537 Mdot
.656 .15378 Mdot
.656 .15422 Mdot
.656 .1552 Mdot
.656 .1561 Mdot
.656 .15614 Mdot
.656 .15616 Mdot
.656 .1562 Mdot
.656 .15678 Mdot
.656 .15753 Mdot
.656 .15762 Mdot
.656 .15766 Mdot
.656 .15771 Mdot
.656 .15813 Mdot
.656 .15856 Mdot
.656 .15861 Mdot
.656 .15913 Mdot
.656 .15922 Mdot
.656 .15942 Mdot
.656 .15944 Mdot
.656 .15998 Mdot
.656 .16031 Mdot
.656 .16104 Mdot
.656 .16133 Mdot
.656 .16137 Mdot
.656 .16148 Mdot
.656 .16197 Mdot
.656 .16222 Mdot
.656 .16248 Mdot
.656 .16253 Mdot
.656 .16261 Mdot
.656 .16267 Mdot
.656 .1627 Mdot
.656 .16296 Mdot
.656 .1635 Mdot
.656 .16371 Mdot
.656 .16374 Mdot
.656 .164 Mdot
.656 .16411 Mdot
.656 .16418 Mdot
.656 .1642 Mdot
.656 .16447 Mdot
.656 .16488 Mdot
.656 .1653 Mdot
.656 .16537 Mdot
.656 .16678 Mdot
.656 .16727 Mdot
.656 .16774 Mdot
.656 .16911 Mdot
.656 .16999 Mdot
.656 .17007 Mdot
.656 .17085 Mdot
.656 .17109 Mdot
.656 .17139 Mdot
.656 .17152 Mdot
.656 .17179 Mdot
.656 .17217 Mdot
.656 .17221 Mdot
.656 .17277 Mdot
.656 .17337 Mdot
.656 .17337 Mdot
.656 .17364 Mdot
.656 .17367 Mdot
.656 .17368 Mdot
.656 .17395 Mdot
.656 .17433 Mdot
.656 .17456 Mdot
.656 .17516 Mdot
.656 .17591 Mdot
.656 .17608 Mdot
.656 .17625 Mdot
.656 .17686 Mdot
.656 .1771 Mdot
.656 .17731 Mdot
.656 .17748 Mdot
.656 .17769 Mdot
.656 .17769 Mdot
.656 .17817 Mdot
.656 .17819 Mdot
.656 .1782 Mdot
.656 .17871 Mdot
.656 .17986 Mdot
.656 .17997 Mdot
.656 .18004 Mdot
.656 .18064 Mdot
.656 .18074 Mdot
.656 .18081 Mdot
.656 .18301 Mdot
.656 .18337 Mdot
.656 .18339 Mdot
.656 .18365 Mdot
.656 .18371 Mdot
.656 .18488 Mdot
.656 .185 Mdot
.656 .18704 Mdot
.656 .18729 Mdot
.656 .18789 Mdot
.656 .18797 Mdot
.656 .18926 Mdot
.656 .18972 Mdot
.656 .18979 Mdot
.656 .19015 Mdot
.656 .1905 Mdot
.656 .19192 Mdot
.656 .19212 Mdot
.656 .19223 Mdot
.656 .19251 Mdot
.656 .19325 Mdot
.656 .19375 Mdot
.656 .19409 Mdot
.656 .19443 Mdot
.656 .19443 Mdot
.656 .19543 Mdot
.656 .19578 Mdot
.656 .19594 Mdot
.656 .19623 Mdot
.656 .19635 Mdot
.656 .19707 Mdot
.656 .19717 Mdot
.656 .19775 Mdot
.656 .19903 Mdot
.656 .20021 Mdot
.656 .20026 Mdot
.656 .20029 Mdot
.656 .20035 Mdot
.656 .2011 Mdot
.656 .20209 Mdot
.656 .20221 Mdot
.656 .20226 Mdot
.656 .20232 Mdot
.656 .20287 Mdot
.656 .20344 Mdot
.656 .2035 Mdot
.656 .20418 Mdot
.656 .2043 Mdot
.656 .20457 Mdot
.656 .20459 Mdot
.656 .2053 Mdot
.656 .20574 Mdot
.656 .2067 Mdot
.656 .20707 Mdot
.656 .20713 Mdot
.656 .20727 Mdot
.656 .20792 Mdot
.656 .20825 Mdot
.656 .20858 Mdot
.656 .20864 Mdot
.656 .20875 Mdot
.656 .20883 Mdot
.656 .20887 Mdot
.656 .20921 Mdot
.656 .20992 Mdot
.656 .2102 Mdot
.656 .21024 Mdot
.656 .21058 Mdot
.656 .21072 Mdot
.656 .21081 Mdot
.656 .21084 Mdot
.656 .21119 Mdot
.656 .21173 Mdot
.656 .21228 Mdot
.656 .21238 Mdot
.656 .21423 Mdot
.656 .21486 Mdot
.656 .21549 Mdot
.656 .21729 Mdot
.656 .21844 Mdot
.656 .21854 Mdot
.656 .21956 Mdot
.656 .21988 Mdot
.656 .22028 Mdot
.656 .22044 Mdot
.656 .2208 Mdot
.656 .22129 Mdot
.656 .22135 Mdot
.656 .22208 Mdot
.656 .22287 Mdot
.656 .22287 Mdot
.656 .22323 Mdot
.656 .22326 Mdot
.656 .22327 Mdot
.656 .22364 Mdot
.656 .22413 Mdot
.656 .22443 Mdot
.656 .22522 Mdot
.656 .22621 Mdot
.656 .22643 Mdot
.656 .22665 Mdot
.656 .22745 Mdot
.656 .22776 Mdot
.656 .22804 Mdot
.656 .22826 Mdot
.656 .22854 Mdot
.656 .22854 Mdot
.656 .22917 Mdot
.656 .2292 Mdot
.656 .22921 Mdot
.656 .22987 Mdot
.656 .23139 Mdot
.656 .23152 Mdot
.656 .23162 Mdot
.656 .23241 Mdot
.656 .23254 Mdot
.656 .23263 Mdot
.656 .23551 Mdot
.656 .23598 Mdot
.656 .23602 Mdot
.656 .23636 Mdot
.656 .23643 Mdot
.656 .23797 Mdot
.656 .23813 Mdot
.656 .24081 Mdot
.656 .24113 Mdot
.656 .24192 Mdot
.656 .24203 Mdot
.656 .24371 Mdot
.656 .24432 Mdot
.656 .24442 Mdot
.656 .24489 Mdot
.656 .24535 Mdot
.656 .24721 Mdot
.656 .24748 Mdot
.656 .24761 Mdot
.656 .24798 Mdot
.656 .24895 Mdot
.656 .2496 Mdot
.656 .25005 Mdot
.656 .2505 Mdot
.656 .2505 Mdot
.656 .25181 Mdot
.656 .25228 Mdot
.656 .25249 Mdot
.656 .25287 Mdot
.656 .25302 Mdot
.656 .25396 Mdot
.656 .25409 Mdot
.656 .25485 Mdot
.656 .25654 Mdot
.656 .25808 Mdot
.656 .25815 Mdot
.656 .25819 Mdot
.656 .25826 Mdot
.656 .25925 Mdot
.656 .26055 Mdot
.656 .26071 Mdot
.656 .26077 Mdot
.656 .26085 Mdot
.656 .26158 Mdot
.656 .26232 Mdot
.656 .26241 Mdot
.656 .2633 Mdot
.656 .26345 Mdot
.656 .2638 Mdot
.656 .26384 Mdot
.656 .26476 Mdot
.656 .26534 Mdot
.656 .26659 Mdot
.656 .26709 Mdot
.656 .26716 Mdot
.656 .26735 Mdot
.656 .2682 Mdot
.656 .26863 Mdot
.656 .26906 Mdot
.656 .26915 Mdot
.656 .26929 Mdot
.656 .26939 Mdot
.656 .26944 Mdot
.656 .2699 Mdot
.656 .27083 Mdot
.656 .27119 Mdot
.656 .27124 Mdot
.656 .27169 Mdot
.656 .27187 Mdot
.656 .27199 Mdot
.656 .27204 Mdot
.656 .2725 Mdot
.656 .2732 Mdot
.656 .27392 Mdot
.656 .27405 Mdot
.656 .27648 Mdot
.656 .27731 Mdot
.656 .27813 Mdot
.656 .28049 Mdot
.656 .28201 Mdot
.656 .28213 Mdot
.656 .28347 Mdot
.656 .28389 Mdot
.656 .28441 Mdot
.656 .28463 Mdot
.656 .2851 Mdot
.656 .28574 Mdot
.656 .28582 Mdot
.656 .28677 Mdot
.656 .28781 Mdot
.656 .28782 Mdot
.656 .28828 Mdot
.656 .28832 Mdot
.656 .28834 Mdot
.656 .28882 Mdot
.656 .28947 Mdot
.656 .28986 Mdot
.656 .2909 Mdot
.656 .29219 Mdot
.656 .29249 Mdot
.656 .29278 Mdot
.656 .29382 Mdot
.656 .29423 Mdot
.656 .2946 Mdot
.656 .29488 Mdot
.656 .29525 Mdot
.656 .29526 Mdot
.656 .29608 Mdot
.656 .29611 Mdot
.656 .29614 Mdot
.656 .297 Mdot
.656 .29899 Mdot
.656 .29917 Mdot
.656 .29929 Mdot
.656 .30033 Mdot
.656 .3005 Mdot
.656 .30062 Mdot
.656 .3044 Mdot
.656 .30502 Mdot
.656 .30507 Mdot
.656 .30551 Mdot
.656 .30561 Mdot
.656 .30763 Mdot
.656 .30784 Mdot
.656 .31135 Mdot
.656 .31178 Mdot
.656 .31281 Mdot
.656 .31295 Mdot
.656 .31516 Mdot
.656 .31596 Mdot
.656 .31608 Mdot
.656 .3167 Mdot
.656 .3173 Mdot
.656 .31975 Mdot
.656 .3201 Mdot
.656 .32027 Mdot
.656 .32076 Mdot
.656 .32203 Mdot
.656 .32289 Mdot
.656 .32348 Mdot
.656 .32407 Mdot
.656 .32407 Mdot
.656 .32578 Mdot
.656 .3264 Mdot
.656 .32667 Mdot
.656 .32717 Mdot
.656 .32737 Mdot
.656 .3286 Mdot
.656 .32878 Mdot
.656 .32978 Mdot
.656 .33199 Mdot
.656 .33402 Mdot
.656 .33411 Mdot
.656 .33415 Mdot
.656 .33425 Mdot
.656 .33555 Mdot
.656 .33725 Mdot
.656 .33745 Mdot
.656 .33754 Mdot
.656 .33765 Mdot
.656 .3386 Mdot
.656 .33957 Mdot
.656 .33969 Mdot
.656 .34085 Mdot
.656 .34106 Mdot
.656 .34156 Mdot
.656 .34278 Mdot
.656 .34353 Mdot
.656 .34518 Mdot
.656 .34583 Mdot
.656 .34593 Mdot
.656 .34617 Mdot
.656 .34729 Mdot
.656 .34785 Mdot
.656 .34842 Mdot
.656 .34853 Mdot
.656 .34872 Mdot
.656 .34885 Mdot
.656 .34892 Mdot
.656 .34951 Mdot
.656 .35073 Mdot
.656 .35121 Mdot
.656 .35128 Mdot
.656 .35186 Mdot
.656 .35211 Mdot
.656 .35226 Mdot
.656 .35232 Mdot
.656 .35292 Mdot
.656 .35385 Mdot
.656 .35479 Mdot
.656 .35496 Mdot
.656 .35815 Mdot
.656 .35924 Mdot
.656 .36031 Mdot
.656 .36341 Mdot
.656 .3654 Mdot
.656 .36556 Mdot
.656 .36732 Mdot
.656 .36787 Mdot
.656 .36855 Mdot
.656 .36884 Mdot
.656 .36946 Mdot
.656 .37031 Mdot
.656 .3704 Mdot
.656 .37166 Mdot
.656 .37302 Mdot
.656 .37303 Mdot
.656 .37363 Mdot
.656 .37369 Mdot
.656 .37371 Mdot
.656 .37434 Mdot
.656 .37519 Mdot
.656 .37571 Mdot
.656 .37707 Mdot
.656 .37876 Mdot
.656 .37915 Mdot
.656 .37953 Mdot
.656 .38091 Mdot
.656 .38144 Mdot
.656 .38192 Mdot
.656 .3823 Mdot
.656 .38278 Mdot
.656 .38279 Mdot
.656 .38387 Mdot
.656 .38391 Mdot
.656 .38394 Mdot
.656 .38507 Mdot
.656 .38768 Mdot
.656 .38792 Mdot
.656 .38808 Mdot
.656 .38945 Mdot
.656 .38967 Mdot
.656 .38982 Mdot
.656 .39478 Mdot
.656 .3956 Mdot
.656 .39566 Mdot
.656 .39624 Mdot
.656 .39637 Mdot
.656 .39902 Mdot
.656 .3993 Mdot
.658 .01507 Mdot
.658 .01517 Mdot
.658 .01518 Mdot
.658 .01532 Mdot
.658 .01533 Mdot
.658 .01551 Mdot
.658 .01552 Mdot
.658 .01576 Mdot
.658 .01578 Mdot
.658 .01598 Mdot
.658 .01609 Mdot
.658 .01611 Mdot
.658 .01638 Mdot
.658 .01641 Mdot
.658 .01652 Mdot
.658 .01655 Mdot
.658 .01665 Mdot
.658 .01679 Mdot
.658 .01691 Mdot
.658 .01695 Mdot
.658 .01709 Mdot
.658 .01713 Mdot
.658 .01727 Mdot
.658 .01745 Mdot
.658 .01761 Mdot
.658 .01766 Mdot
.658 .01766 Mdot
.658 .01784 Mdot
.658 .0179 Mdot
.658 .01807 Mdot
.658 .01831 Mdot
.658 .01852 Mdot
.658 .01859 Mdot
.658 .0186 Mdot
.658 .01883 Mdot
.658 .01891 Mdot
.658 .01899 Mdot
.658 .01913 Mdot
.658 .0193 Mdot
.658 .01945 Mdot
.658 .01972 Mdot
.658 .01981 Mdot
.658 .01982 Mdot
.658 .02023 Mdot
.658 .02034 Mdot
.658 .02053 Mdot
.658 .02055 Mdot
.658 .02065 Mdot
.658 .02072 Mdot
.658 .02075 Mdot
.658 .02095 Mdot
.658 .02131 Mdot
.658 .02142 Mdot
.658 .02144 Mdot
.658 .02197 Mdot
.658 .02212 Mdot
.658 .02231 Mdot
.658 .02237 Mdot
.658 .02239 Mdot
.658 .02252 Mdot
.658 .02261 Mdot
.658 .02265 Mdot
.658 .02291 Mdot
.658 .02292 Mdot
.658 .02339 Mdot
.658 .02354 Mdot
.658 .02356 Mdot
.658 .02395 Mdot
.658 .02427 Mdot
.658 .02446 Mdot
.658 .02471 Mdot
.658 .02478 Mdot
.658 .02481 Mdot
.658 .02482 Mdot
.658 .02489 Mdot
.658 .02499 Mdot
.658 .02511 Mdot
.658 .02516 Mdot
.658 .02551 Mdot
.658 .02551 Mdot
.658 .0258 Mdot
.658 .02613 Mdot
.658 .02633 Mdot
.658 .02636 Mdot
.658 .02687 Mdot
.658 .02728 Mdot
.658 .02753 Mdot
.658 .02787 Mdot
.658 .02797 Mdot
.658 .02799 Mdot
.658 .02801 Mdot
.658 .0281 Mdot
.658 .02824 Mdot
.658 .02839 Mdot
.658 .02846 Mdot
.658 .02892 Mdot
.658 .02892 Mdot
.658 .02931 Mdot
.658 .02973 Mdot
.658 .03 Mdot
.658 .03004 Mdot
.658 .03071 Mdot
.658 .03085 Mdot
.658 .03126 Mdot
.658 .03158 Mdot
.658 .0316 Mdot
.658 .03203 Mdot
.658 .03215 Mdot
.658 .03219 Mdot
.658 .03221 Mdot
.658 .03233 Mdot
.658 .03251 Mdot
.658 .03272 Mdot
.658 .03281 Mdot
.658 .0334 Mdot
.658 .03341 Mdot
.658 .03392 Mdot
.658 .03448 Mdot
.658 .03483 Mdot
.658 .03488 Mdot
.658 .03554 Mdot
.658 .03576 Mdot
.658 .03595 Mdot
.658 .03648 Mdot
.658 .03692 Mdot
.658 .03693 Mdot
.658 .03751 Mdot
.658 .03766 Mdot
.658 .03771 Mdot
.658 .03774 Mdot
.658 .0379 Mdot
.658 .03803 Mdot
.658 .03813 Mdot
.658 .0384 Mdot
.658 .03853 Mdot
.658 .03903 Mdot
.658 .03931 Mdot
.658 .03932 Mdot
.658 .03999 Mdot
.658 .04073 Mdot
.658 .04119 Mdot
.658 .04125 Mdot
.658 .04212 Mdot
.658 .0422 Mdot
.658 .04241 Mdot
.658 .04266 Mdot
.658 .04336 Mdot
.658 .04336 Mdot
.658 .04393 Mdot
.658 .04395 Mdot
.658 .04471 Mdot
.658 .04491 Mdot
.658 .04498 Mdot
.658 .04501 Mdot
.658 .04522 Mdot
.658 .0454 Mdot
.658 .04553 Mdot
.658 .04589 Mdot
.658 .04589 Mdot
.658 .04605 Mdot
.658 .04667 Mdot
.658 .04671 Mdot
.658 .04708 Mdot
.658 .0471 Mdot
.658 .04797 Mdot
.658 .04808 Mdot
.658 .04809 Mdot
.658 .04828 Mdot
.658 .04895 Mdot
.658 .04955 Mdot
.658 .04964 Mdot
.658 .05078 Mdot
.658 .0508 Mdot
.658 .05088 Mdot
.658 .05117 Mdot
.658 .0515 Mdot
.658 .0524 Mdot
.658 .05241 Mdot
.658 .05242 Mdot
.658 .05252 Mdot
.658 .0528 Mdot
.658 .0528 Mdot
.658 .05316 Mdot
.658 .05319 Mdot
.658 .05371 Mdot
.658 .05377 Mdot
.658 .05396 Mdot
.658 .05419 Mdot
.658 .05446 Mdot
.658 .05455 Mdot
.658 .05458 Mdot
.658 .05473 Mdot
.658 .05486 Mdot
.658 .0551 Mdot
.658 .05527 Mdot
.658 .05574 Mdot
.658 .05574 Mdot
.658 .05595 Mdot
.658 .05615 Mdot
.658 .05677 Mdot
.658 .05682 Mdot
.658 .05713 Mdot
.658 .05731 Mdot
.658 .05733 Mdot
.658 .05742 Mdot
.658 .05848 Mdot
.658 .05863 Mdot
.658 .05864 Mdot
.658 .05888 Mdot
.658 .05976 Mdot
.658 .06028 Mdot
.658 .06056 Mdot
.658 .06067 Mdot
.658 .06102 Mdot
.658 .06217 Mdot
.658 .0622 Mdot
.658 .06231 Mdot
.658 .06233 Mdot
.658 .06269 Mdot
.658 .06312 Mdot
.658 .06326 Mdot
.658 .0643 Mdot
.658 .06432 Mdot
.658 .06433 Mdot
.658 .06437 Mdot
.658 .06446 Mdot
.658 .06484 Mdot
.658 .06484 Mdot
.658 .06488 Mdot
.658 .06492 Mdot
.658 .06524 Mdot
.658 .06531 Mdot
.658 .06535 Mdot
.658 .06603 Mdot
.658 .0661 Mdot
.658 .06636 Mdot
.658 .06666 Mdot
.658 .06702 Mdot
.658 .06713 Mdot
.658 .06718 Mdot
.658 .06737 Mdot
.658 .06755 Mdot
.658 .06786 Mdot
.658 .06809 Mdot
.658 .0687 Mdot
.658 .06871 Mdot
.658 .06875 Mdot
.658 .06899 Mdot
.658 .06924 Mdot
.658 .06973 Mdot
.658 .07006 Mdot
.658 .07013 Mdot
.658 .07054 Mdot
.658 .07057 Mdot
.658 .07077 Mdot
.658 .0708 Mdot
.658 .07092 Mdot
.658 .07157 Mdot
.658 .07169 Mdot
.658 .07182 Mdot
.658 .07189 Mdot
.658 .07192 Mdot
.658 .07226 Mdot
.658 .07231 Mdot
.658 .07251 Mdot
.658 .07252 Mdot
.658 .07275 Mdot
.658 .07284 Mdot
.658 .07299 Mdot
.658 .07311 Mdot
.658 .07313 Mdot
.658 .074 Mdot
.658 .07468 Mdot
.658 .07505 Mdot
.658 .0752 Mdot
.658 .07566 Mdot
.658 .07652 Mdot
.658 .07652 Mdot
.658 .07692 Mdot
.658 .07715 Mdot
.658 .07717 Mdot
.658 .07721 Mdot
.658 .07721 Mdot
.658 .07735 Mdot
.658 .07738 Mdot
.658 .07784 Mdot
.658 .07841 Mdot
.658 .0786 Mdot
.658 .07898 Mdot
.658 .07903 Mdot
.658 .07954 Mdot
.658 .07996 Mdot
.658 .07997 Mdot
.658 .07999 Mdot
.658 .08001 Mdot
.658 .08006 Mdot
.658 .08013 Mdot
.658 .08018 Mdot
.658 .08068 Mdot
.658 .08068 Mdot
.658 .08074 Mdot
.658 .08077 Mdot
.658 .08078 Mdot
.658 .08105 Mdot
.658 .08112 Mdot
.658 .08121 Mdot
.658 .0813 Mdot
.658 .08135 Mdot
.658 .08224 Mdot
.658 .08234 Mdot
.658 .08268 Mdot
.658 .08307 Mdot
.658 .08354 Mdot
.658 .08369 Mdot
.658 .08376 Mdot
.658 .08401 Mdot
.658 .08424 Mdot
.658 .08466 Mdot
.658 .08495 Mdot
.658 .08541 Mdot
.658 .08577 Mdot
.658 .08577 Mdot
.658 .08583 Mdot
.658 .08614 Mdot
.658 .08647 Mdot
.658 .08712 Mdot
.658 .08722 Mdot
.658 .08754 Mdot
.658 .08764 Mdot
.658 .08786 Mdot
.658 .0879 Mdot
.658 .08818 Mdot
.658 .08822 Mdot
.658 .08848 Mdot
.658 .08852 Mdot
.658 .08868 Mdot
.658 .08954 Mdot
.658 .08969 Mdot
.658 .08987 Mdot
.658 .08995 Mdot
.658 .09 Mdot
.658 .09019 Mdot
.658 .09045 Mdot
.658 .09051 Mdot
.658 .09077 Mdot
.658 .09078 Mdot
.658 .09109 Mdot
.658 .0912 Mdot
.658 .0914 Mdot
.658 .09157 Mdot
.658 .09158 Mdot
.658 .09273 Mdot
.658 .09288 Mdot
.658 .09363 Mdot
.658 .09412 Mdot
.658 .09431 Mdot
.658 .09492 Mdot
.658 .09605 Mdot
.658 .09605 Mdot
.658 .09609 Mdot
.658 .09657 Mdot
.658 .09688 Mdot
.658 .0969 Mdot
.658 .09696 Mdot
.658 .09696 Mdot
.658 .09713 Mdot
.658 .09714 Mdot
.658 .09718 Mdot
.658 .0976 Mdot
.658 .09779 Mdot
.658 .0984 Mdot
.658 .09854 Mdot
.658 .09879 Mdot
.658 .09928 Mdot
.658 .09929 Mdot
.658 .09935 Mdot
.658 .10003 Mdot
.658 .10057 Mdot
.658 .10059 Mdot
.658 .10062 Mdot
.658 .10064 Mdot
.658 .1007 Mdot
.658 .1008 Mdot
.658 .10087 Mdot
.658 .10087 Mdot
.658 .10152 Mdot
.658 .10152 Mdot
.658 .1016 Mdot
.658 .10165 Mdot
.658 .10166 Mdot
.658 .10201 Mdot
.658 .10211 Mdot
.658 .10222 Mdot
.658 .10234 Mdot
.658 .10241 Mdot
.658 .10358 Mdot
.658 .10371 Mdot
.658 .10371 Mdot
.658 .10416 Mdot
.658 .10467 Mdot
.658 .10529 Mdot
.658 .10549 Mdot
.658 .10558 Mdot
.658 .10574 Mdot
.658 .10591 Mdot
.658 .10621 Mdot
.658 .10676 Mdot
.658 .10715 Mdot
.658 .10776 Mdot
.658 .10822 Mdot
.658 .10823 Mdot
.658 .1083 Mdot
.658 .10863 Mdot
.658 .10871 Mdot
.658 .10889 Mdot
.658 .10915 Mdot
.658 .11 Mdot
.658 .11013 Mdot
.658 .11056 Mdot
.658 .11069 Mdot
.658 .11097 Mdot
.658 .11103 Mdot
.658 .11129 Mdot
.658 .11133 Mdot
.658 .11139 Mdot
.658 .11145 Mdot
.658 .11174 Mdot
.658 .11179 Mdot
.658 .11184 Mdot
.658 .11205 Mdot
.658 .11318 Mdot
.658 .11339 Mdot
.658 .11341 Mdot
.658 .11362 Mdot
.658 .11373 Mdot
.658 .11379 Mdot
.658 .11382 Mdot
.658 .11404 Mdot
.658 .11438 Mdot
.658 .11446 Mdot
.658 .11478 Mdot
.658 .1148 Mdot
.658 .11482 Mdot
.658 .11522 Mdot
.658 .11537 Mdot
.658 .11564 Mdot
.658 .11585 Mdot
.658 .11587 Mdot
.658 .11611 Mdot
.658 .11739 Mdot
.658 .11757 Mdot
.658 .11857 Mdot
.658 .11921 Mdot
.658 .11946 Mdot
.658 .12026 Mdot
.658 .12055 Mdot
.658 .1212 Mdot
.658 .12139 Mdot
.658 .12175 Mdot
.658 .12175 Mdot
.658 .1218 Mdot
.658 .12244 Mdot
.658 .12284 Mdot
.658 .12287 Mdot
.658 .12295 Mdot
.658 .12295 Mdot
.658 .12318 Mdot
.658 .12319 Mdot
.658 .12324 Mdot
.658 .12343 Mdot
.658 .12379 Mdot
.658 .12404 Mdot
.658 .12412 Mdot
.658 .12484 Mdot
.658 .12503 Mdot
.658 .12536 Mdot
.658 .1256 Mdot
.658 .12588 Mdot
.658 .12601 Mdot
.658 .12602 Mdot
.658 .1261 Mdot
.658 .12699 Mdot
.658 .12724 Mdot
.658 .12745 Mdot
.658 .1277 Mdot
.658 .12773 Mdot
.658 .12777 Mdot
.658 .12778 Mdot
.658 .12779 Mdot
.658 .12788 Mdot
.658 .128 Mdot
.658 .12806 Mdot
.658 .12809 Mdot
.658 .1281 Mdot
.658 .12896 Mdot
.658 .12896 Mdot
.658 .12906 Mdot
.658 .12912 Mdot
.658 .12913 Mdot
.658 .12958 Mdot
.658 .12959 Mdot
.658 .12972 Mdot
.658 .12983 Mdot
.658 .12987 Mdot
.658 .13003 Mdot
.658 .1301 Mdot
.658 .13012 Mdot
.658 .13121 Mdot
.658 .13167 Mdot
.658 .13183 Mdot
.658 .13184 Mdot
.658 .13242 Mdot
.658 .1331 Mdot
.658 .13391 Mdot
.658 .13418 Mdot
.658 .1343 Mdot
.658 .1345 Mdot
.658 .13472 Mdot
.658 .13512 Mdot
.658 .13584 Mdot
.658 .13636 Mdot
.658 .13709 Mdot
.658 .13716 Mdot
.658 .13776 Mdot
.658 .13777 Mdot
.658 .13788 Mdot
.658 .1383 Mdot
.658 .13841 Mdot
.658 .13865 Mdot
.658 .13899 Mdot
.658 .14011 Mdot
.658 .14027 Mdot
.658 .14084 Mdot
.658 .14101 Mdot
.658 .14139 Mdot
.658 .14146 Mdot
.658 .1418 Mdot
.658 .14186 Mdot
.658 .14194 Mdot
.658 .14201 Mdot
.658 .1424 Mdot
.658 .14246 Mdot
.658 .14253 Mdot
.658 .14281 Mdot
.658 .1443 Mdot
.658 .14457 Mdot
.658 .1446 Mdot
.658 .14487 Mdot
.658 .14502 Mdot
.658 .1451 Mdot
.658 .14514 Mdot
.658 .14543 Mdot
.658 .14587 Mdot
.658 .14598 Mdot
.658 .14639 Mdot
.658 .14643 Mdot
.658 .14645 Mdot
.658 .14698 Mdot
.658 .14718 Mdot
.658 .14753 Mdot
.658 .14781 Mdot
.658 .14784 Mdot
.658 .14815 Mdot
.658 .14983 Mdot
.658 .15008 Mdot
.658 .15139 Mdot
.658 .15222 Mdot
.658 .15256 Mdot
.658 .15361 Mdot
.658 .154 Mdot
.658 .15484 Mdot
.658 .1551 Mdot
.658 .15558 Mdot
.658 .15558 Mdot
.658 .15564 Mdot
.658 .15648 Mdot
.658 .15701 Mdot
.658 .15705 Mdot
.658 .15715 Mdot
.658 .15715 Mdot
.658 .15745 Mdot
.658 .15747 Mdot
.658 .15753 Mdot
.658 .15779 Mdot
.658 .15826 Mdot
.658 .15859 Mdot
.658 .15869 Mdot
.658 .15964 Mdot
.658 .15989 Mdot
.658 .16033 Mdot
.658 .16064 Mdot
.658 .161 Mdot
.658 .16118 Mdot
.658 .16119 Mdot
.658 .1613 Mdot
.658 .16247 Mdot
.658 .16279 Mdot
.658 .16307 Mdot
.658 .16341 Mdot
.658 .16345 Mdot
.658 .16349 Mdot
.658 .16351 Mdot
.658 .16352 Mdot
.658 .16364 Mdot
.658 .1638 Mdot
.658 .16388 Mdot
.658 .16392 Mdot
.658 .16392 Mdot
.658 .16506 Mdot
.658 .16506 Mdot
.658 .16519 Mdot
.658 .16527 Mdot
.658 .16529 Mdot
.658 .16588 Mdot
.658 .16589 Mdot
.658 .16606 Mdot
.658 .1662 Mdot
.658 .16626 Mdot
.658 .16647 Mdot
.658 .16657 Mdot
.658 .16659 Mdot
.658 .16802 Mdot
.658 .16862 Mdot
.658 .16884 Mdot
.658 .16885 Mdot
.658 .16961 Mdot
.658 .17051 Mdot
.658 .17158 Mdot
.658 .17193 Mdot
.658 .17208 Mdot
.658 .17235 Mdot
.658 .17265 Mdot
.658 .17317 Mdot
.658 .17412 Mdot
.658 .1748 Mdot
.658 .17576 Mdot
.658 .17585 Mdot
.658 .17665 Mdot
.658 .17666 Mdot
.658 .1768 Mdot
.658 .17736 Mdot
.658 .17749 Mdot
.658 .17781 Mdot
.658 .17825 Mdot
.658 .17974 Mdot
.658 .17995 Mdot
.658 .1807 Mdot
.658 .18093 Mdot
.658 .18142 Mdot
.658 .18151 Mdot
.658 .18197 Mdot
.658 .18204 Mdot
.658 .18215 Mdot
.658 .18224 Mdot
.658 .18275 Mdot
.658 .18283 Mdot
.658 .18292 Mdot
.658 .18329 Mdot
.658 .18525 Mdot
.658 .1856 Mdot
.658 .18565 Mdot
.658 .186 Mdot
.658 .18619 Mdot
.658 .1863 Mdot
.658 .18636 Mdot
.658 .18674 Mdot
.658 .18732 Mdot
.658 .18746 Mdot
.658 .188 Mdot
.658 .18805 Mdot
.658 .18808 Mdot
.658 .18878 Mdot
.658 .18904 Mdot
.658 .1895 Mdot
.658 .18987 Mdot
.658 .18991 Mdot
.658 .19031 Mdot
.658 .19253 Mdot
.658 .19285 Mdot
.658 .19458 Mdot
.658 .19568 Mdot
.658 .19611 Mdot
.658 .1975 Mdot
.658 .19801 Mdot
.658 .19913 Mdot
.658 .19947 Mdot
.658 .20009 Mdot
.658 .20009 Mdot
.658 .20017 Mdot
.658 .20128 Mdot
.658 .20198 Mdot
.658 .20203 Mdot
.658 .20216 Mdot
.658 .20216 Mdot
.658 .20255 Mdot
.658 .20258 Mdot
.658 .20266 Mdot
.658 .203 Mdot
.658 .20363 Mdot
.658 .20406 Mdot
.658 .20418 Mdot
.658 .20544 Mdot
.658 .20576 Mdot
.658 .20634 Mdot
.658 .20675 Mdot
.658 .20723 Mdot
.658 .20746 Mdot
.658 .20747 Mdot
.658 .20761 Mdot
.658 .20916 Mdot
.658 .20959 Mdot
.658 .20995 Mdot
.658 .21039 Mdot
.658 .21044 Mdot
.658 .2105 Mdot
.658 .21053 Mdot
.658 .21055 Mdot
.658 .2107 Mdot
.658 .21091 Mdot
.658 .21101 Mdot
.658 .21107 Mdot
.658 .21107 Mdot
.658 .21256 Mdot
.658 .21256 Mdot
.658 .21274 Mdot
.658 .21284 Mdot
.658 .21287 Mdot
.658 .21364 Mdot
.658 .21366 Mdot
.658 .21389 Mdot
.658 .21407 Mdot
.658 .21415 Mdot
.658 .21443 Mdot
.658 .21455 Mdot
.658 .21458 Mdot
.658 .21647 Mdot
.658 .21726 Mdot
.658 .21754 Mdot
.658 .21756 Mdot
.658 .21856 Mdot
.658 .21974 Mdot
.658 .22115 Mdot
.658 .22161 Mdot
.658 .22181 Mdot
.658 .22216 Mdot
.658 .22255 Mdot
.658 .22325 Mdot
.658 .22449 Mdot
.658 .22538 Mdot
.658 .22665 Mdot
.658 .22677 Mdot
.658 .22782 Mdot
.658 .22784 Mdot
.658 .22802 Mdot
.658 .22875 Mdot
.658 .22893 Mdot
.658 .22935 Mdot
.658 .22993 Mdot
.658 .23188 Mdot
.658 .23217 Mdot
.658 .23315 Mdot
.658 .23345 Mdot
.658 .2341 Mdot
.658 .23422 Mdot
.658 .23482 Mdot
.658 .23491 Mdot
.658 .23506 Mdot
.658 .23518 Mdot
.658 .23584 Mdot
.658 .23595 Mdot
.658 .23607 Mdot
.658 .23656 Mdot
.658 .23914 Mdot
.658 .2396 Mdot
.658 .23966 Mdot
.658 .24013 Mdot
.658 .24038 Mdot
.658 .24052 Mdot
.658 .2406 Mdot
.658 .2411 Mdot
.658 .24186 Mdot
.658 .24204 Mdot
.658 .24276 Mdot
.658 .24282 Mdot
.658 .24286 Mdot
.658 .24378 Mdot
.658 .24413 Mdot
.658 .24473 Mdot
.658 .24522 Mdot
.658 .24527 Mdot
.658 .2458 Mdot
.658 .24871 Mdot
.658 .24915 Mdot
.658 .25142 Mdot
.658 .25286 Mdot
.658 .25344 Mdot
.658 .25527 Mdot
.658 .25593 Mdot
.658 .2574 Mdot
.658 .25785 Mdot
.658 .25866 Mdot
.658 .25867 Mdot
.658 .25878 Mdot
.658 .26023 Mdot
.658 .26115 Mdot
.658 .26122 Mdot
.658 .26139 Mdot
.658 .26139 Mdot
.658 .26191 Mdot
.658 .26194 Mdot
.658 .26206 Mdot
.658 .2625 Mdot
.658 .26332 Mdot
.658 .26389 Mdot
.658 .26406 Mdot
.658 .26571 Mdot
.658 .26614 Mdot
.658 .26689 Mdot
.658 .26743 Mdot
.658 .26807 Mdot
.658 .26837 Mdot
.658 .26838 Mdot
.658 .26857 Mdot
.658 .2706 Mdot
.658 .27117 Mdot
.658 .27165 Mdot
.658 .27223 Mdot
.658 .27229 Mdot
.658 .27237 Mdot
.658 .27241 Mdot
.658 .27243 Mdot
.658 .27263 Mdot
.658 .27291 Mdot
.658 .27305 Mdot
.658 .27312 Mdot
.658 .27312 Mdot
.658 .27508 Mdot
.658 .27508 Mdot
.658 .27531 Mdot
.658 .27545 Mdot
.658 .27548 Mdot
.658 .27651 Mdot
.658 .27653 Mdot
.658 .27683 Mdot
.658 .27707 Mdot
.658 .27717 Mdot
.658 .27754 Mdot
.658 .2777 Mdot
.658 .27774 Mdot
.658 .28022 Mdot
.658 .28126 Mdot
.658 .28163 Mdot
.658 .28165 Mdot
.658 .28298 Mdot
.658 .28453 Mdot
.658 .28638 Mdot
.658 .28699 Mdot
.658 .28726 Mdot
.658 .28772 Mdot
.658 .28823 Mdot
.658 .28914 Mdot
.658 .29078 Mdot
.658 .29195 Mdot
.658 .29362 Mdot
.658 .29377 Mdot
.658 .29516 Mdot
.658 .29518 Mdot
.658 .29542 Mdot
.658 .29639 Mdot
.658 .29662 Mdot
.658 .29717 Mdot
.658 .29794 Mdot
.658 .30051 Mdot
.658 .30088 Mdot
.658 .30217 Mdot
.658 .30257 Mdot
.658 .30342 Mdot
.658 .30358 Mdot
.658 .30437 Mdot
.658 .30449 Mdot
.658 .30468 Mdot
.658 .30484 Mdot
.658 .30572 Mdot
.658 .30586 Mdot
.658 .30602 Mdot
.658 .30666 Mdot
.658 .31006 Mdot
.658 .31067 Mdot
.658 .31074 Mdot
.658 .31136 Mdot
.658 .31169 Mdot
.658 .31187 Mdot
.658 .31198 Mdot
.658 .31264 Mdot
.658 .31364 Mdot
.658 .31388 Mdot
.658 .31483 Mdot
.658 .3149 Mdot
.658 .31496 Mdot
.658 .31617 Mdot
.658 .31663 Mdot
.658 .31741 Mdot
.658 .31806 Mdot
.658 .31812 Mdot
.658 .31882 Mdot
.658 .32266 Mdot
.658 .32322 Mdot
.658 .32622 Mdot
.658 .32812 Mdot
.658 .32887 Mdot
.658 .33128 Mdot
.658 .33216 Mdot
.658 .33409 Mdot
.658 .33468 Mdot
.658 .33575 Mdot
.658 .33576 Mdot
.658 .3359 Mdot
.658 .33782 Mdot
.658 .33903 Mdot
.658 .33912 Mdot
.658 .33934 Mdot
.658 .33934 Mdot
.658 .34003 Mdot
.658 .34007 Mdot
.658 .34022 Mdot
.658 .3408 Mdot
.658 .34188 Mdot
.658 .34263 Mdot
.658 .34285 Mdot
.658 .34502 Mdot
.658 .34559 Mdot
.658 .34658 Mdot
.658 .34729 Mdot
.658 .34813 Mdot
.658 .34852 Mdot
.658 .34854 Mdot
.658 .34879 Mdot
.658 .35146 Mdot
.658 .3522 Mdot
.658 .35284 Mdot
.658 .3536 Mdot
.658 .35369 Mdot
.658 .35379 Mdot
.658 .35384 Mdot
.658 .35387 Mdot
.658 .35413 Mdot
.658 .3545 Mdot
.658 .35468 Mdot
.658 .35477 Mdot
.658 .35478 Mdot
.658 .35736 Mdot
.658 .35736 Mdot
.658 .35766 Mdot
.658 .35784 Mdot
.658 .35788 Mdot
.658 .35923 Mdot
.658 .35927 Mdot
.658 .35966 Mdot
.658 .35997 Mdot
.658 .3601 Mdot
.658 .36059 Mdot
.658 .3608 Mdot
.658 .36086 Mdot
.658 .36412 Mdot
.658 .36549 Mdot
.658 .36598 Mdot
.658 .36601 Mdot
.658 .36775 Mdot
.658 .36979 Mdot
.658 .37223 Mdot
.658 .37302 Mdot
.658 .37338 Mdot
.658 .37399 Mdot
.658 .37466 Mdot
.658 .37586 Mdot
.658 .37802 Mdot
.658 .37956 Mdot
.658 .38176 Mdot
.658 .38196 Mdot
.658 .38378 Mdot
.658 .38381 Mdot
.658 .38412 Mdot
.658 .38539 Mdot
.658 .38571 Mdot
.658 .38643 Mdot
.658 .38744 Mdot
.658 .39082 Mdot
.658 .39131 Mdot
.658 .39301 Mdot
.658 .39353 Mdot
.658 .39465 Mdot
.658 .39487 Mdot
.658 .3959 Mdot
.658 .39606 Mdot
.658 .39631 Mdot
.658 .39653 Mdot
.658 .39768 Mdot
.658 .39787 Mdot
.658 .39808 Mdot
.658 .39892 Mdot
.658 .40339 Mdot
.66 .01556 Mdot
.66 .01582 Mdot
.66 .01618 Mdot
.66 .01665 Mdot
.66 .01727 Mdot
.66 .01808 Mdot
.66 .01809 Mdot
.66 .01864 Mdot
.66 .01916 Mdot
.66 .01917 Mdot
.66 .01975 Mdot
.66 .01989 Mdot
.66 .02058 Mdot
.66 .0206 Mdot
.66 .02136 Mdot
.66 .02155 Mdot
.66 .02246 Mdot
.66 .02248 Mdot
.66 .02349 Mdot
.66 .02374 Mdot
.66 .02494 Mdot
.66 .02497 Mdot
.66 .0263 Mdot
.66 .02662 Mdot
.66 .0269 Mdot
.66 .02712 Mdot
.66 .02816 Mdot
.66 .02821 Mdot
.66 .02825 Mdot
.66 .02878 Mdot
.66 .02932 Mdot
.66 .02964 Mdot
.66 .03 Mdot
.66 .03043 Mdot
.66 .0308 Mdot
.66 .03089 Mdot
.66 .03109 Mdot
.66 .0324 Mdot
.66 .03246 Mdot
.66 .03253 Mdot
.66 .03258 Mdot
.66 .03317 Mdot
.66 .03329 Mdot
.66 .03371 Mdot
.66 .034 Mdot
.66 .03408 Mdot
.66 .03442 Mdot
.66 .03489 Mdot
.66 .03494 Mdot
.66 .03546 Mdot
.66 .03595 Mdot
.66 .03607 Mdot
.66 .03627 Mdot
.66 .03628 Mdot
.66 .03633 Mdot
.66 .03713 Mdot
.66 .03805 Mdot
.66 .03814 Mdot
.66 .03823 Mdot
.66 .03829 Mdot
.66 .03907 Mdot
.66 .03923 Mdot
.66 .03979 Mdot
.66 .04003 Mdot
.66 .04017 Mdot
.66 .04028 Mdot
.66 .04072 Mdot
.66 .04081 Mdot
.66 .04086 Mdot
.66 .04135 Mdot
.66 .04141 Mdot
.66 .04142 Mdot
.66 .04171 Mdot
.66 .04191 Mdot
.66 .0421 Mdot
.66 .04211 Mdot
.66 .04274 Mdot
.66 .0429 Mdot
.66 .04296 Mdot
.66 .04307 Mdot
.66 .04316 Mdot
.66 .04318 Mdot
.66 .04324 Mdot
.66 .04351 Mdot
.66 .04429 Mdot
.66 .04431 Mdot
.66 .04552 Mdot
.66 .04563 Mdot
.66 .04575 Mdot
.66 .04584 Mdot
.66 .04686 Mdot
.66 .04707 Mdot
.66 .04781 Mdot
.66 .04812 Mdot
.66 .04831 Mdot
.66 .04846 Mdot
.66 .04864 Mdot
.66 .04894 Mdot
.66 .04905 Mdot
.66 .04916 Mdot
.66 .04923 Mdot
.66 .04987 Mdot
.66 .04995 Mdot
.66 .04997 Mdot
.66 .05004 Mdot
.66 .05035 Mdot
.66 .0505 Mdot
.66 .05061 Mdot
.66 .05081 Mdot
.66 .05087 Mdot
.66 .05087 Mdot
.66 .05138 Mdot
.66 .05171 Mdot
.66 .05192 Mdot
.66 .05199 Mdot
.66 .05199 Mdot
.66 .05214 Mdot
.66 .05217 Mdot
.66 .05227 Mdot
.66 .05229 Mdot
.66 .05237 Mdot
.66 .05272 Mdot
.66 .05315 Mdot
.66 .0533 Mdot
.66 .05343 Mdot
.66 .05376 Mdot
.66 .05378 Mdot
.66 .05419 Mdot
.66 .0551 Mdot
.66 .05538 Mdot
.66 .05552 Mdot
.66 .05568 Mdot
.66 .0558 Mdot
.66 .05715 Mdot
.66 .05743 Mdot
.66 .05761 Mdot
.66 .05801 Mdot
.66 .05841 Mdot
.66 .05882 Mdot
.66 .05906 Mdot
.66 .05925 Mdot
.66 .05949 Mdot
.66 .05981 Mdot
.66 .05989 Mdot
.66 .06001 Mdot
.66 .06003 Mdot
.66 .06018 Mdot
.66 .06027 Mdot
.66 .0611 Mdot
.66 .06112 Mdot
.66 .06123 Mdot
.66 .06125 Mdot
.66 .06134 Mdot
.66 .06176 Mdot
.66 .06195 Mdot
.66 .06209 Mdot
.66 .06236 Mdot
.66 .06244 Mdot
.66 .06244 Mdot
.66 .06311 Mdot
.66 .06331 Mdot
.66 .06334 Mdot
.66 .06354 Mdot
.66 .06354 Mdot
.66 .06383 Mdot
.66 .06392 Mdot
.66 .06392 Mdot
.66 .06412 Mdot
.66 .06416 Mdot
.66 .06425 Mdot
.66 .06428 Mdot
.66 .06432 Mdot
.66 .06433 Mdot
.66 .06442 Mdot
.66 .06488 Mdot
.66 .06546 Mdot
.66 .0656 Mdot
.66 .06564 Mdot
.66 .06582 Mdot
.66 .06612 Mdot
.66 .06625 Mdot
.66 .06628 Mdot
.66 .06628 Mdot
.66 .06672 Mdot
.66 .06682 Mdot
.66 .06686 Mdot
.66 .06802 Mdot
.66 .06839 Mdot
.66 .06858 Mdot
.66 .06879 Mdot
.66 .06894 Mdot
.66 .07051 Mdot
.66 .07054 Mdot
.66 .07073 Mdot
.66 .07109 Mdot
.66 .07133 Mdot
.66 .07236 Mdot
.66 .07239 Mdot
.66 .07254 Mdot
.66 .07263 Mdot
.66 .07293 Mdot
.66 .07325 Mdot
.66 .07351 Mdot
.66 .0737 Mdot
.66 .0737 Mdot
.66 .07382 Mdot
.66 .07424 Mdot
.66 .07435 Mdot
.66 .07444 Mdot
.66 .07448 Mdot
.66 .07451 Mdot
.66 .07453 Mdot
.66 .07473 Mdot
.66 .07485 Mdot
.66 .07547 Mdot
.66 .07595 Mdot
.66 .07598 Mdot
.66 .07612 Mdot
.66 .07614 Mdot
.66 .07626 Mdot
.66 .07681 Mdot
.66 .07707 Mdot
.66 .0771 Mdot
.66 .07725 Mdot
.66 .07758 Mdot
.66 .0776 Mdot
.66 .07771 Mdot
.66 .07772 Mdot
.66 .0779 Mdot
.66 .07797 Mdot
.66 .07808 Mdot
.66 .0786 Mdot
.66 .07861 Mdot
.66 .07887 Mdot
.66 .0789 Mdot
.66 .07916 Mdot
.66 .07917 Mdot
.66 .07931 Mdot
.66 .07955 Mdot
.66 .07966 Mdot
.66 .07967 Mdot
.66 .07976 Mdot
.66 .07993 Mdot
.66 .07998 Mdot
.66 .08011 Mdot
.66 .08012 Mdot
.66 .08014 Mdot
.66 .08019 Mdot
.66 .0802 Mdot
.66 .08033 Mdot
.66 .08094 Mdot
.66 .08101 Mdot
.66 .08109 Mdot
.66 .08128 Mdot
.66 .08158 Mdot
.66 .08169 Mdot
.66 .0817 Mdot
.66 .08189 Mdot
.66 .08194 Mdot
.66 .08217 Mdot
.66 .08257 Mdot
.66 .08259 Mdot
.66 .08274 Mdot
.66 .08277 Mdot
.66 .08277 Mdot
.66 .08336 Mdot
.66 .0835 Mdot
.66 .08355 Mdot
.66 .08508 Mdot
.66 .08557 Mdot
.66 .08582 Mdot
.66 .08609 Mdot
.66 .0863 Mdot
.66 .08681 Mdot
.66 .08732 Mdot
.66 .08763 Mdot
.66 .08791 Mdot
.66 .08836 Mdot
.66 .0884 Mdot
.66 .08866 Mdot
.66 .08914 Mdot
.66 .08924 Mdot
.66 .08945 Mdot
.66 .0908 Mdot
.66 .09084 Mdot
.66 .09104 Mdot
.66 .09116 Mdot
.66 .09132 Mdot
.66 .09156 Mdot
.66 .09184 Mdot
.66 .09199 Mdot
.66 .09209 Mdot
.66 .09216 Mdot
.66 .09232 Mdot
.66 .09257 Mdot
.66 .09257 Mdot
.66 .09274 Mdot
.66 .09328 Mdot
.66 .09343 Mdot
.66 .09344 Mdot
.66 .09355 Mdot
.66 .0936 Mdot
.66 .09364 Mdot
.66 .09368 Mdot
.66 .09384 Mdot
.66 .09394 Mdot
.66 .09409 Mdot
.66 .09491 Mdot
.66 .09526 Mdot
.66 .09543 Mdot
.66 .09554 Mdot
.66 .09558 Mdot
.66 .09576 Mdot
.66 .09579 Mdot
.66 .09582 Mdot
.66 .09596 Mdot
.66 .09668 Mdot
.66 .09702 Mdot
.66 .09706 Mdot
.66 .09727 Mdot
.66 .09769 Mdot
.66 .09773 Mdot
.66 .09786 Mdot
.66 .09788 Mdot
.66 .09812 Mdot
.66 .09822 Mdot
.66 .09824 Mdot
.66 .09833 Mdot
.66 .09836 Mdot
.66 .09904 Mdot
.66 .09905 Mdot
.66 .09939 Mdot
.66 .09943 Mdot
.66 .09945 Mdot
.66 .09965 Mdot
.66 .09965 Mdot
.66 .09979 Mdot
.66 .0998 Mdot
.66 .09998 Mdot
.66 .10029 Mdot
.66 .10044 Mdot
.66 .10046 Mdot
.66 .10048 Mdot
.66 .10058 Mdot
.66 .10071 Mdot
.66 .10079 Mdot
.66 .10086 Mdot
.66 .10103 Mdot
.66 .10105 Mdot
.66 .10108 Mdot
.66 .10114 Mdot
.66 .10116 Mdot
.66 .10133 Mdot
.66 .10213 Mdot
.66 .10222 Mdot
.66 .10228 Mdot
.66 .10233 Mdot
.66 .10259 Mdot
.66 .10298 Mdot
.66 .10312 Mdot
.66 .10314 Mdot
.66 .10338 Mdot
.66 .10345 Mdot
.66 .10372 Mdot
.66 .10376 Mdot
.66 .10429 Mdot
.66 .1043 Mdot
.66 .10451 Mdot
.66 .10455 Mdot
.66 .10455 Mdot
.66 .10471 Mdot
.66 .10505 Mdot
.66 .10532 Mdot
.66 .10551 Mdot
.66 .10557 Mdot
.66 .1076 Mdot
.66 .10825 Mdot
.66 .10852 Mdot
.66 .10858 Mdot
.66 .10893 Mdot
.66 .1092 Mdot
.66 .10987 Mdot
.66 .11055 Mdot
.66 .11097 Mdot
.66 .11133 Mdot
.66 .11193 Mdot
.66 .11198 Mdot
.66 .11232 Mdot
.66 .11295 Mdot
.66 .11309 Mdot
.66 .11336 Mdot
.66 .11515 Mdot
.66 .1152 Mdot
.66 .11546 Mdot
.66 .11562 Mdot
.66 .11575 Mdot
.66 .11583 Mdot
.66 .11614 Mdot
.66 .11652 Mdot
.66 .11671 Mdot
.66 .11685 Mdot
.66 .11694 Mdot
.66 .11715 Mdot
.66 .11749 Mdot
.66 .11749 Mdot
.66 .1177 Mdot
.66 .11842 Mdot
.66 .11862 Mdot
.66 .11863 Mdot
.66 .11877 Mdot
.66 .11885 Mdot
.66 .11889 Mdot
.66 .11894 Mdot
.66 .11916 Mdot
.66 .11918 Mdot
.66 .11929 Mdot
.66 .11949 Mdot
.66 .12057 Mdot
.66 .12065 Mdot
.66 .12092 Mdot
.66 .12104 Mdot
.66 .12111 Mdot
.66 .12126 Mdot
.66 .12141 Mdot
.66 .12145 Mdot
.66 .1217 Mdot
.66 .12174 Mdot
.66 .12177 Mdot
.66 .12196 Mdot
.66 .12219 Mdot
.66 .12281 Mdot
.66 .12291 Mdot
.66 .12336 Mdot
.66 .12341 Mdot
.66 .12368 Mdot
.66 .12424 Mdot
.66 .12424 Mdot
.66 .12429 Mdot
.66 .12447 Mdot
.66 .12449 Mdot
.66 .12481 Mdot
.66 .12494 Mdot
.66 .12497 Mdot
.66 .12508 Mdot
.66 .12512 Mdot
.66 .12603 Mdot
.66 .12604 Mdot
.66 .12649 Mdot
.66 .12654 Mdot
.66 .12656 Mdot
.66 .12683 Mdot
.66 .12683 Mdot
.66 .12701 Mdot
.66 .12702 Mdot
.66 .12727 Mdot
.66 .12767 Mdot
.66 .12779 Mdot
.66 .12787 Mdot
.66 .12789 Mdot
.66 .12792 Mdot
.66 .12805 Mdot
.66 .12823 Mdot
.66 .12834 Mdot
.66 .12843 Mdot
.66 .12865 Mdot
.66 .12867 Mdot
.66 .12872 Mdot
.66 .12879 Mdot
.66 .12882 Mdot
.66 .12904 Mdot
.66 .1301 Mdot
.66 .13022 Mdot
.66 .1303 Mdot
.66 .13037 Mdot
.66 .1307 Mdot
.66 .13122 Mdot
.66 .13135 Mdot
.66 .13142 Mdot
.66 .13143 Mdot
.66 .13175 Mdot
.66 .13185 Mdot
.66 .13221 Mdot
.66 .13225 Mdot
.66 .13295 Mdot
.66 .13297 Mdot
.66 .13325 Mdot
.66 .1333 Mdot
.66 .1333 Mdot
.66 .13351 Mdot
.66 .13357 Mdot
.66 .13396 Mdot
.66 .13432 Mdot
.66 .13456 Mdot
.66 .13465 Mdot
.66 .13552 Mdot
.66 .13732 Mdot
.66 .13818 Mdot
.66 .13854 Mdot
.66 .13861 Mdot
.66 .13866 Mdot
.66 .13893 Mdot
.66 .13908 Mdot
.66 .13944 Mdot
.66 .14033 Mdot
.66 .14121 Mdot
.66 .14177 Mdot
.66 .14225 Mdot
.66 .14304 Mdot
.66 .1431 Mdot
.66 .14355 Mdot
.66 .14439 Mdot
.66 .14457 Mdot
.66 .14493 Mdot
.66 .14729 Mdot
.66 .14736 Mdot
.66 .1477 Mdot
.66 .14791 Mdot
.66 .14809 Mdot
.66 .14819 Mdot
.66 .1486 Mdot
.66 .1491 Mdot
.66 .14935 Mdot
.66 .14953 Mdot
.66 .14965 Mdot
.66 .14994 Mdot
.66 .15037 Mdot
.66 .15038 Mdot
.66 .15066 Mdot
.66 .15161 Mdot
.66 .15187 Mdot
.66 .15189 Mdot
.66 .15207 Mdot
.66 .15217 Mdot
.66 .15223 Mdot
.66 .1523 Mdot
.66 .15258 Mdot
.66 .15261 Mdot
.66 .15276 Mdot
.66 .15302 Mdot
.66 .15445 Mdot
.66 .15455 Mdot
.66 .15491 Mdot
.66 .15506 Mdot
.66 .15516 Mdot
.66 .15535 Mdot
.66 .15555 Mdot
.66 .15561 Mdot
.66 .15594 Mdot
.66 .15598 Mdot
.66 .15603 Mdot
.66 .15628 Mdot
.66 .15658 Mdot
.66 .1574 Mdot
.66 .15753 Mdot
.66 .15813 Mdot
.66 .15819 Mdot
.66 .15855 Mdot
.66 .15928 Mdot
.66 .15929 Mdot
.66 .15936 Mdot
.66 .15959 Mdot
.66 .15962 Mdot
.66 .16004 Mdot
.66 .16021 Mdot
.66 .16026 Mdot
.66 .1604 Mdot
.66 .16045 Mdot
.66 .16165 Mdot
.66 .16166 Mdot
.66 .16226 Mdot
.66 .16232 Mdot
.66 .16235 Mdot
.66 .1627 Mdot
.66 .1627 Mdot
.66 .16294 Mdot
.66 .16296 Mdot
.66 .16329 Mdot
.66 .16382 Mdot
.66 .16398 Mdot
.66 .16409 Mdot
.66 .16411 Mdot
.66 .16415 Mdot
.66 .16432 Mdot
.66 .16455 Mdot
.66 .1647 Mdot
.66 .16482 Mdot
.66 .16511 Mdot
.66 .16514 Mdot
.66 .1652 Mdot
.66 .1653 Mdot
.66 .16534 Mdot
.66 .16563 Mdot
.66 .16702 Mdot
.66 .16719 Mdot
.66 .16729 Mdot
.66 .16738 Mdot
.66 .16782 Mdot
.66 .16851 Mdot
.66 .16868 Mdot
.66 .16876 Mdot
.66 .16878 Mdot
.66 .1692 Mdot
.66 .16934 Mdot
.66 .16981 Mdot
.66 .16986 Mdot
.66 .16999 Mdot
.66 .17079 Mdot
.66 .17081 Mdot
.66 .17118 Mdot
.66 .17125 Mdot
.66 .17125 Mdot
.66 .17152 Mdot
.66 .1716 Mdot
.66 .17212 Mdot
.66 .17259 Mdot
.66 .17292 Mdot
.66 .17303 Mdot
.66 .17417 Mdot
.66 .17655 Mdot
.66 .17768 Mdot
.66 .17817 Mdot
.66 .17826 Mdot
.66 .17832 Mdot
.66 .17867 Mdot
.66 .17888 Mdot
.66 .17935 Mdot
.66 .18052 Mdot
.66 .18169 Mdot
.66 .18242 Mdot
.66 .18306 Mdot
.66 .1841 Mdot
.66 .18419 Mdot
.66 .18478 Mdot
.66 .18588 Mdot
.66 .18612 Mdot
.66 .1866 Mdot
.66 .18971 Mdot
.66 .18981 Mdot
.66 .19026 Mdot
.66 .19053 Mdot
.66 .19076 Mdot
.66 .1909 Mdot
.66 .19145 Mdot
.66 .1921 Mdot
.66 .19243 Mdot
.66 .19267 Mdot
.66 .19283 Mdot
.66 .19321 Mdot
.66 .19378 Mdot
.66 .19379 Mdot
.66 .19416 Mdot
.66 .19542 Mdot
.66 .19576 Mdot
.66 .19578 Mdot
.66 .19602 Mdot
.66 .19615 Mdot
.66 .19624 Mdot
.66 .19632 Mdot
.66 .19669 Mdot
.66 .19674 Mdot
.66 .19693 Mdot
.66 .19727 Mdot
.66 .19916 Mdot
.66 .19929 Mdot
.66 .19977 Mdot
.66 .19997 Mdot
.66 .20011 Mdot
.66 .20035 Mdot
.66 .20062 Mdot
.66 .2007 Mdot
.66 .20113 Mdot
.66 .20119 Mdot
.66 .20125 Mdot
.66 .20158 Mdot
.66 .20197 Mdot
.66 .20306 Mdot
.66 .20324 Mdot
.66 .20402 Mdot
.66 .20411 Mdot
.66 .20458 Mdot
.66 .20554 Mdot
.66 .20556 Mdot
.66 .20564 Mdot
.66 .20595 Mdot
.66 .20598 Mdot
.66 .20654 Mdot
.66 .20676 Mdot
.66 .20683 Mdot
.66 .20702 Mdot
.66 .20709 Mdot
.66 .20867 Mdot
.66 .20868 Mdot
.66 .20947 Mdot
.66 .20955 Mdot
.66 .20959 Mdot
.66 .21006 Mdot
.66 .21006 Mdot
.66 .21038 Mdot
.66 .2104 Mdot
.66 .21083 Mdot
.66 .21154 Mdot
.66 .21174 Mdot
.66 .21188 Mdot
.66 .21192 Mdot
.66 .21196 Mdot
.66 .21219 Mdot
.66 .2125 Mdot
.66 .21269 Mdot
.66 .21285 Mdot
.66 .21324 Mdot
.66 .21327 Mdot
.66 .21336 Mdot
.66 .21349 Mdot
.66 .21354 Mdot
.66 .21392 Mdot
.66 .21576 Mdot
.66 .21598 Mdot
.66 .21612 Mdot
.66 .21624 Mdot
.66 .21681 Mdot
.66 .21772 Mdot
.66 .21795 Mdot
.66 .21805 Mdot
.66 .21808 Mdot
.66 .21864 Mdot
.66 .21881 Mdot
.66 .21943 Mdot
.66 .21951 Mdot
.66 .21967 Mdot
.66 .22073 Mdot
.66 .22077 Mdot
.66 .22124 Mdot
.66 .22134 Mdot
.66 .22134 Mdot
.66 .2217 Mdot
.66 .2218 Mdot
.66 .22249 Mdot
.66 .22311 Mdot
.66 .22354 Mdot
.66 .22369 Mdot
.66 .2252 Mdot
.66 .22834 Mdot
.66 .22983 Mdot
.66 .23047 Mdot
.66 .23059 Mdot
.66 .23067 Mdot
.66 .23114 Mdot
.66 .23141 Mdot
.66 .23203 Mdot
.66 .23358 Mdot
.66 .23513 Mdot
.66 .23609 Mdot
.66 .23694 Mdot
.66 .2383 Mdot
.66 .23842 Mdot
.66 .2392 Mdot
.66 .24065 Mdot
.66 .24097 Mdot
.66 .24161 Mdot
.66 .24571 Mdot
.66 .24583 Mdot
.66 .24643 Mdot
.66 .24679 Mdot
.66 .2471 Mdot
.66 .24728 Mdot
.66 .248 Mdot
.66 .24886 Mdot
.66 .24931 Mdot
.66 .24962 Mdot
.66 .24983 Mdot
.66 .25032 Mdot
.66 .25108 Mdot
.66 .25109 Mdot
.66 .25158 Mdot
.66 .25324 Mdot
.66 .25369 Mdot
.66 .25372 Mdot
.66 .25404 Mdot
.66 .25421 Mdot
.66 .25432 Mdot
.66 .25444 Mdot
.66 .25492 Mdot
.66 .25499 Mdot
.66 .25524 Mdot
.66 .25569 Mdot
.66 .25818 Mdot
.66 .25836 Mdot
.66 .25899 Mdot
.66 .25925 Mdot
.66 .25943 Mdot
.66 .25976 Mdot
.66 .26011 Mdot
.66 .26021 Mdot
.66 .26078 Mdot
.66 .26086 Mdot
.66 .26093 Mdot
.66 .26137 Mdot
.66 .26189 Mdot
.66 .26333 Mdot
.66 .26356 Mdot
.66 .26459 Mdot
.66 .26471 Mdot
.66 .26534 Mdot
.66 .26661 Mdot
.66 .26662 Mdot
.66 .26674 Mdot
.66 .26715 Mdot
.66 .26719 Mdot
.66 .26792 Mdot
.66 .26822 Mdot
.66 .26831 Mdot
.66 .26856 Mdot
.66 .26864 Mdot
.66 .27074 Mdot
.66 .27075 Mdot
.66 .2718 Mdot
.66 .2719 Mdot
.66 .27195 Mdot
.66 .27257 Mdot
.66 .27257 Mdot
.66 .27299 Mdot
.66 .27301 Mdot
.66 .27358 Mdot
.66 .27452 Mdot
.66 .27479 Mdot
.66 .27498 Mdot
.66 .27502 Mdot
.66 .27508 Mdot
.66 .27538 Mdot
.66 .27579 Mdot
.66 .27605 Mdot
.66 .27625 Mdot
.66 .27676 Mdot
.66 .27681 Mdot
.66 .27692 Mdot
.66 .27709 Mdot
.66 .27716 Mdot
.66 .27767 Mdot
.66 .28009 Mdot
.66 .28038 Mdot
.66 .28056 Mdot
.66 .28072 Mdot
.66 .28149 Mdot
.66 .28268 Mdot
.66 .28298 Mdot
.66 .28312 Mdot
.66 .28316 Mdot
.66 .2839 Mdot
.66 .28413 Mdot
.66 .28494 Mdot
.66 .28504 Mdot
.66 .28526 Mdot
.66 .28666 Mdot
.66 .2867 Mdot
.66 .28733 Mdot
.66 .28746 Mdot
.66 .28746 Mdot
.66 .28794 Mdot
.66 .28807 Mdot
.66 .28897 Mdot
.66 .2898 Mdot
.66 .29037 Mdot
.66 .29056 Mdot
.66 .29255 Mdot
.66 .2967 Mdot
.66 .29867 Mdot
.66 .29951 Mdot
.66 .29967 Mdot
.66 .29978 Mdot
.66 .3004 Mdot
.66 .30075 Mdot
.66 .30157 Mdot
.66 .30361 Mdot
.66 .30566 Mdot
.66 .30693 Mdot
.66 .30805 Mdot
.66 .30985 Mdot
.66 .31 Mdot
.66 .31103 Mdot
.66 .31295 Mdot
.66 .31337 Mdot
.66 .31421 Mdot
.66 .31963 Mdot
.66 .31979 Mdot
.66 .32058 Mdot
.66 .32105 Mdot
.66 .32146 Mdot
.66 .3217 Mdot
.66 .32265 Mdot
.66 .32379 Mdot
.66 .32437 Mdot
.66 .32479 Mdot
.66 .32507 Mdot
.66 .32572 Mdot
.66 .32672 Mdot
.66 .32673 Mdot
.66 .32738 Mdot
.66 .32957 Mdot
.66 .33017 Mdot
.66 .3302 Mdot
.66 .33063 Mdot
.66 .33085 Mdot
.66 .331 Mdot
.66 .33115 Mdot
.66 .33179 Mdot
.66 .33188 Mdot
.66 .33221 Mdot
.66 .3328 Mdot
.66 .33609 Mdot
.66 .33632 Mdot
.66 .33716 Mdot
.66 .33751 Mdot
.66 .33774 Mdot
.66 .33817 Mdot
.66 .33863 Mdot
.66 .33877 Mdot
.66 .33952 Mdot
.66 .33963 Mdot
.66 .33972 Mdot
.66 .3403 Mdot
.66 .34099 Mdot
.66 .34289 Mdot
.66 .3432 Mdot
.66 .34456 Mdot
.66 .34471 Mdot
.66 .34554 Mdot
.66 .34721 Mdot
.66 .34724 Mdot
.66 .34738 Mdot
.66 .34792 Mdot
.66 .34798 Mdot
.66 .34895 Mdot
.66 .34934 Mdot
.66 .34946 Mdot
.66 .34979 Mdot
.66 .3499 Mdot
.66 .35266 Mdot
.66 .35269 Mdot
.66 .35406 Mdot
.66 .3542 Mdot
.66 .35427 Mdot
.66 .35508 Mdot
.66 .35508 Mdot
.66 .35564 Mdot
.66 .35567 Mdot
.66 .35642 Mdot
.66 .35766 Mdot
.66 .35802 Mdot
.66 .35826 Mdot
.66 .35832 Mdot
.66 .3584 Mdot
.66 .3588 Mdot
.66 .35933 Mdot
.66 .35967 Mdot
.66 .35994 Mdot
.66 .36062 Mdot
.66 .36068 Mdot
.66 .36083 Mdot
.66 .36105 Mdot
.66 .36114 Mdot
.66 .36181 Mdot
.66 .36501 Mdot
.66 .3654 Mdot
.66 .36564 Mdot
.66 .36585 Mdot
.66 .36685 Mdot
.66 .36843 Mdot
.66 .36882 Mdot
.66 .36901 Mdot
.66 .36907 Mdot
.66 .37004 Mdot
.66 .37034 Mdot
.66 .37142 Mdot
.66 .37154 Mdot
.66 .37184 Mdot
.66 .37368 Mdot
.66 .37374 Mdot
.66 .37457 Mdot
.66 .37474 Mdot
.66 .37474 Mdot
.66 .37537 Mdot
.66 .37554 Mdot
.66 .37673 Mdot
.66 .37783 Mdot
.66 .37857 Mdot
.66 .37883 Mdot
.66 .38146 Mdot
.66 .38694 Mdot
.66 .38954 Mdot
.66 .39065 Mdot
.66 .39086 Mdot
.66 .391 Mdot
.66 .39181 Mdot
.66 .39229 Mdot
.66 .39337 Mdot
.66 .39606 Mdot
.66 .39876 Mdot
.66 .40044 Mdot
.66 .40191 Mdot
.66 .40429 Mdot
.66 .4045 Mdot
.662 .01508 Mdot
.662 .0152 Mdot
.662 .01535 Mdot
.662 .01556 Mdot
.662 .01583 Mdot
.662 .01614 Mdot
.662 .01619 Mdot
.662 .01631 Mdot
.662 .0166 Mdot
.662 .01667 Mdot
.662 .0167 Mdot
.662 .01683 Mdot
.662 .01721 Mdot
.662 .01731 Mdot
.662 .01735 Mdot
.662 .01739 Mdot
.662 .01751 Mdot
.662 .01784 Mdot
.662 .01802 Mdot
.662 .01815 Mdot
.662 .0182 Mdot
.662 .01826 Mdot
.662 .01842 Mdot
.662 .01885 Mdot
.662 .01906 Mdot
.662 .01909 Mdot
.662 .01926 Mdot
.662 .01933 Mdot
.662 .0194 Mdot
.662 .01962 Mdot
.662 .02019 Mdot
.662 .02047 Mdot
.662 .02051 Mdot
.662 .02073 Mdot
.662 .02083 Mdot
.662 .02092 Mdot
.662 .02121 Mdot
.662 .02197 Mdot
.662 .02233 Mdot
.662 .02239 Mdot
.662 .02268 Mdot
.662 .02281 Mdot
.662 .02293 Mdot
.662 .02332 Mdot
.662 .02382 Mdot
.662 .02432 Mdot
.662 .02463 Mdot
.662 .0248 Mdot
.662 .02487 Mdot
.662 .0249 Mdot
.662 .02526 Mdot
.662 .02543 Mdot
.662 .0256 Mdot
.662 .0261 Mdot
.662 .02678 Mdot
.662 .02743 Mdot
.662 .02767 Mdot
.662 .02784 Mdot
.662 .02806 Mdot
.662 .02817 Mdot
.662 .02819 Mdot
.662 .02827 Mdot
.662 .02867 Mdot
.662 .0289 Mdot
.662 .02912 Mdot
.662 .02967 Mdot
.662 .02979 Mdot
.662 .03068 Mdot
.662 .03133 Mdot
.662 .03155 Mdot
.662 .03187 Mdot
.662 .03193 Mdot
.662 .03207 Mdot
.662 .03209 Mdot
.662 .03239 Mdot
.662 .03252 Mdot
.662 .03256 Mdot
.662 .03267 Mdot
.662 .0332 Mdot
.662 .0335 Mdot
.662 .03379 Mdot
.662 .03452 Mdot
.662 .03468 Mdot
.662 .03486 Mdot
.662 .03518 Mdot
.662 .03586 Mdot
.662 .0362 Mdot
.662 .03672 Mdot
.662 .037 Mdot
.662 .03716 Mdot
.662 .03743 Mdot
.662 .03751 Mdot
.662 .03769 Mdot
.662 .03772 Mdot
.662 .03772 Mdot
.662 .03811 Mdot
.662 .03828 Mdot
.662 .03829 Mdot
.662 .03834 Mdot
.662 .03849 Mdot
.662 .03898 Mdot
.662 .03918 Mdot
.662 .03958 Mdot
.662 .03972 Mdot
.662 .03997 Mdot
.662 .04093 Mdot
.662 .04115 Mdot
.662 .0413 Mdot
.662 .04138 Mdot
.662 .04181 Mdot
.662 .04271 Mdot
.662 .04316 Mdot
.662 .04384 Mdot
.662 .04403 Mdot
.662 .04422 Mdot
.662 .04444 Mdot
.662 .04479 Mdot
.662 .0449 Mdot
.662 .04513 Mdot
.662 .04518 Mdot
.662 .04518 Mdot
.662 .04569 Mdot
.662 .04592 Mdot
.662 .04593 Mdot
.662 .046 Mdot
.662 .04619 Mdot
.662 .04684 Mdot
.662 .04711 Mdot
.662 .04764 Mdot
.662 .04782 Mdot
.662 .04815 Mdot
.662 .04837 Mdot
.662 .04943 Mdot
.662 .04971 Mdot
.662 .04992 Mdot
.662 .05003 Mdot
.662 .05043 Mdot
.662 .05059 Mdot
.662 .05102 Mdot
.662 .05124 Mdot
.662 .05178 Mdot
.662 .05237 Mdot
.662 .05328 Mdot
.662 .05353 Mdot
.662 .05378 Mdot
.662 .05381 Mdot
.662 .05407 Mdot
.662 .05454 Mdot
.662 .05468 Mdot
.662 .05498 Mdot
.662 .05505 Mdot
.662 .05505 Mdot
.662 .05548 Mdot
.662 .05573 Mdot
.662 .05603 Mdot
.662 .05605 Mdot
.662 .05611 Mdot
.662 .05613 Mdot
.662 .05638 Mdot
.662 .05714 Mdot
.662 .05722 Mdot
.662 .05725 Mdot
.662 .05761 Mdot
.662 .05793 Mdot
.662 .05831 Mdot
.662 .05855 Mdot
.662 .05899 Mdot
.662 .05928 Mdot
.662 .06002 Mdot
.662 .06004 Mdot
.662 .06031 Mdot
.662 .06067 Mdot
.662 .06075 Mdot
.662 .06105 Mdot
.662 .06132 Mdot
.662 .06147 Mdot
.662 .06201 Mdot
.662 .06218 Mdot
.662 .06221 Mdot
.662 .06278 Mdot
.662 .06307 Mdot
.662 .06312 Mdot
.662 .06336 Mdot
.662 .06379 Mdot
.662 .06457 Mdot
.662 .0647 Mdot
.662 .06578 Mdot
.662 .06611 Mdot
.662 .06643 Mdot
.662 .06648 Mdot
.662 .06681 Mdot
.662 .06744 Mdot
.662 .06762 Mdot
.662 .06803 Mdot
.662 .06811 Mdot
.662 .06811 Mdot
.662 .06825 Mdot
.662 .06869 Mdot
.662 .06902 Mdot
.662 .06942 Mdot
.662 .06944 Mdot
.662 .06952 Mdot
.662 .06952 Mdot
.662 .06955 Mdot
.662 .06981 Mdot
.662 .06988 Mdot
.662 .07088 Mdot
.662 .071 Mdot
.662 .07103 Mdot
.662 .07142 Mdot
.662 .07151 Mdot
.662 .0717 Mdot
.662 .07194 Mdot
.662 .07243 Mdot
.662 .07275 Mdot
.662 .07333 Mdot
.662 .07372 Mdot
.662 .0747 Mdot
.662 .07473 Mdot
.662 .07509 Mdot
.662 .07557 Mdot
.662 .07567 Mdot
.662 .07606 Mdot
.662 .07626 Mdot
.662 .07643 Mdot
.662 .07661 Mdot
.662 .07711 Mdot
.662 .07733 Mdot
.662 .07756 Mdot
.662 .0776 Mdot
.662 .07835 Mdot
.662 .07874 Mdot
.662 .07881 Mdot
.662 .07885 Mdot
.662 .07912 Mdot
.662 .07968 Mdot
.662 .07984 Mdot
.662 .08033 Mdot
.662 .08067 Mdot
.662 .08072 Mdot
.662 .0809 Mdot
.662 .08195 Mdot
.662 .08201 Mdot
.662 .08232 Mdot
.662 .08259 Mdot
.662 .08259 Mdot
.662 .08276 Mdot
.662 .08319 Mdot
.662 .08325 Mdot
.662 .08369 Mdot
.662 .08452 Mdot
.662 .08476 Mdot
.662 .08531 Mdot
.662 .08541 Mdot
.662 .08542 Mdot
.662 .08558 Mdot
.662 .0856 Mdot
.662 .08618 Mdot
.662 .08659 Mdot
.662 .08661 Mdot
.662 .08676 Mdot
.662 .08714 Mdot
.662 .08717 Mdot
.662 .08728 Mdot
.662 .08728 Mdot
.662 .08728 Mdot
.662 .08732 Mdot
.662 .08736 Mdot
.662 .08765 Mdot
.662 .08769 Mdot
.662 .08776 Mdot
.662 .08908 Mdot
.662 .08923 Mdot
.662 .08928 Mdot
.662 .0898 Mdot
.662 .08991 Mdot
.662 .09017 Mdot
.662 .09047 Mdot
.662 .09059 Mdot
.662 .09113 Mdot
.662 .09119 Mdot
.662 .09156 Mdot
.662 .09233 Mdot
.662 .09283 Mdot
.662 .09364 Mdot
.662 .09402 Mdot
.662 .09413 Mdot
.662 .09417 Mdot
.662 .09465 Mdot
.662 .09527 Mdot
.662 .09528 Mdot
.662 .09541 Mdot
.662 .09585 Mdot
.662 .09594 Mdot
.662 .0962 Mdot
.662 .09642 Mdot
.662 .09667 Mdot
.662 .09733 Mdot
.662 .09756 Mdot
.662 .09762 Mdot
.662 .09792 Mdot
.662 .09797 Mdot
.662 .09897 Mdot
.662 .09948 Mdot
.662 .09957 Mdot
.662 .09963 Mdot
.662 .09999 Mdot
.662 .09999 Mdot
.662 .10055 Mdot
.662 .10073 Mdot
.662 .10094 Mdot
.662 .10147 Mdot
.662 .10159 Mdot
.662 .10204 Mdot
.662 .10211 Mdot
.662 .10234 Mdot
.662 .10245 Mdot
.662 .10277 Mdot
.662 .10322 Mdot
.662 .10368 Mdot
.662 .10374 Mdot
.662 .10382 Mdot
.662 .1039 Mdot
.662 .10395 Mdot
.662 .10419 Mdot
.662 .10422 Mdot
.662 .10458 Mdot
.662 .10459 Mdot
.662 .10481 Mdot
.662 .10519 Mdot
.662 .10537 Mdot
.662 .10539 Mdot
.662 .10545 Mdot
.662 .10604 Mdot
.662 .10714 Mdot
.662 .10732 Mdot
.662 .10735 Mdot
.662 .10746 Mdot
.662 .10818 Mdot
.662 .10832 Mdot
.662 .10832 Mdot
.662 .10854 Mdot
.662 .10856 Mdot
.662 .10857 Mdot
.662 .10933 Mdot
.662 .10988 Mdot
.662 .10991 Mdot
.662 .1101 Mdot
.662 .11061 Mdot
.662 .11062 Mdot
.662 .11064 Mdot
.662 .11079 Mdot
.662 .11079 Mdot
.662 .11079 Mdot
.662 .11085 Mdot
.662 .11089 Mdot
.662 .11129 Mdot
.662 .11133 Mdot
.662 .11143 Mdot
.662 .11159 Mdot
.662 .1117 Mdot
.662 .112 Mdot
.662 .11318 Mdot
.662 .11337 Mdot
.662 .11344 Mdot
.662 .11412 Mdot
.662 .11427 Mdot
.662 .11461 Mdot
.662 .11502 Mdot
.662 .11517 Mdot
.662 .1152 Mdot
.662 .11589 Mdot
.662 .11597 Mdot
.662 .11622 Mdot
.662 .11645 Mdot
.662 .11659 Mdot
.662 .11673 Mdot
.662 .1169 Mdot
.662 .11708 Mdot
.662 .11747 Mdot
.662 .11814 Mdot
.662 .11921 Mdot
.662 .11972 Mdot
.662 .11986 Mdot
.662 .11991 Mdot
.662 .12055 Mdot
.662 .12096 Mdot
.662 .12111 Mdot
.662 .12136 Mdot
.662 .12138 Mdot
.662 .12156 Mdot
.662 .12207 Mdot
.662 .12208 Mdot
.662 .12214 Mdot
.662 .12225 Mdot
.662 .1226 Mdot
.662 .12283 Mdot
.662 .12289 Mdot
.662 .12322 Mdot
.662 .1241 Mdot
.662 .12441 Mdot
.662 .12448 Mdot
.662 .12487 Mdot
.662 .12494 Mdot
.662 .12606 Mdot
.662 .12627 Mdot
.662 .1267 Mdot
.662 .12694 Mdot
.662 .12706 Mdot
.662 .12715 Mdot
.662 .12746 Mdot
.662 .12748 Mdot
.662 .12762 Mdot
.662 .12762 Mdot
.662 .12835 Mdot
.662 .1286 Mdot
.662 .12864 Mdot
.662 .12877 Mdot
.662 .12879 Mdot
.662 .12887 Mdot
.662 .12958 Mdot
.662 .12973 Mdot
.662 .13033 Mdot
.662 .13043 Mdot
.662 .13073 Mdot
.662 .13088 Mdot
.662 .1313 Mdot
.662 .1319 Mdot
.662 .13203 Mdot
.662 .13226 Mdot
.662 .1325 Mdot
.662 .13258 Mdot
.662 .13269 Mdot
.662 .1328 Mdot
.662 .13286 Mdot
.662 .13287 Mdot
.662 .13293 Mdot
.662 .13317 Mdot
.662 .13322 Mdot
.662 .1337 Mdot
.662 .1337 Mdot
.662 .134 Mdot
.662 .13451 Mdot
.662 .13475 Mdot
.662 .13478 Mdot
.662 .13485 Mdot
.662 .13563 Mdot
.662 .13588 Mdot
.662 .13598 Mdot
.662 .13601 Mdot
.662 .13605 Mdot
.662 .1361 Mdot
.662 .13705 Mdot
.662 .13709 Mdot
.662 .13732 Mdot
.662 .13732 Mdot
.662 .13736 Mdot
.662 .13751 Mdot
.662 .1383 Mdot
.662 .13846 Mdot
.662 .13865 Mdot
.662 .13865 Mdot
.662 .13894 Mdot
.662 .13897 Mdot
.662 .13897 Mdot
.662 .13977 Mdot
.662 .13983 Mdot
.662 .13998 Mdot
.662 .13999 Mdot
.662 .14072 Mdot
.662 .14074 Mdot
.662 .14075 Mdot
.662 .14076 Mdot
.662 .14077 Mdot
.662 .141 Mdot
.662 .14107 Mdot
.662 .14131 Mdot
.662 .14167 Mdot
.662 .14169 Mdot
.662 .14172 Mdot
.662 .14191 Mdot
.662 .14192 Mdot
.662 .14192 Mdot
.662 .14199 Mdot
.662 .14205 Mdot
.662 .14258 Mdot
.662 .14263 Mdot
.662 .14276 Mdot
.662 .14298 Mdot
.662 .14313 Mdot
.662 .14353 Mdot
.662 .14508 Mdot
.662 .14534 Mdot
.662 .14543 Mdot
.662 .14633 Mdot
.662 .14652 Mdot
.662 .14698 Mdot
.662 .14752 Mdot
.662 .14772 Mdot
.662 .14776 Mdot
.662 .14867 Mdot
.662 .14877 Mdot
.662 .1491 Mdot
.662 .14942 Mdot
.662 .1496 Mdot
.662 .14978 Mdot
.662 .15001 Mdot
.662 .15025 Mdot
.662 .15076 Mdot
.662 .15165 Mdot
.662 .15307 Mdot
.662 .15374 Mdot
.662 .15393 Mdot
.662 .154 Mdot
.662 .15483 Mdot
.662 .15538 Mdot
.662 .15558 Mdot
.662 .15592 Mdot
.662 .15595 Mdot
.662 .15618 Mdot
.662 .15685 Mdot
.662 .15686 Mdot
.662 .15695 Mdot
.662 .15709 Mdot
.662 .15756 Mdot
.662 .15786 Mdot
.662 .15794 Mdot
.662 .15838 Mdot
.662 .15953 Mdot
.662 .15995 Mdot
.662 .16004 Mdot
.662 .16057 Mdot
.662 .16066 Mdot
.662 .16214 Mdot
.662 .16242 Mdot
.662 .16298 Mdot
.662 .1633 Mdot
.662 .16346 Mdot
.662 .16358 Mdot
.662 .16399 Mdot
.662 .16401 Mdot
.662 .1642 Mdot
.662 .1642 Mdot
.662 .16517 Mdot
.662 .1655 Mdot
.662 .16556 Mdot
.662 .16573 Mdot
.662 .16575 Mdot
.662 .16586 Mdot
.662 .1668 Mdot
.662 .167 Mdot
.662 .1678 Mdot
.662 .16792 Mdot
.662 .16833 Mdot
.662 .16852 Mdot
.662 .16907 Mdot
.662 .16986 Mdot
.662 .17004 Mdot
.662 .17035 Mdot
.662 .17066 Mdot
.662 .17077 Mdot
.662 .17091 Mdot
.662 .17106 Mdot
.662 .17114 Mdot
.662 .17115 Mdot
.662 .17123 Mdot
.662 .17156 Mdot
.662 .17162 Mdot
.662 .17225 Mdot
.662 .17226 Mdot
.662 .17265 Mdot
.662 .17332 Mdot
.662 .17364 Mdot
.662 .17367 Mdot
.662 .17377 Mdot
.662 .17481 Mdot
.662 .17514 Mdot
.662 .17527 Mdot
.662 .17531 Mdot
.662 .17537 Mdot
.662 .17542 Mdot
.662 .17669 Mdot
.662 .17674 Mdot
.662 .17705 Mdot
.662 .17705 Mdot
.662 .1771 Mdot
.662 .1773 Mdot
.662 .17835 Mdot
.662 .17855 Mdot
.662 .1788 Mdot
.662 .17881 Mdot
.662 .17919 Mdot
.662 .17923 Mdot
.662 .17923 Mdot
.662 .18029 Mdot
.662 .18036 Mdot
.662 .18056 Mdot
.662 .18058 Mdot
.662 .18154 Mdot
.662 .18157 Mdot
.662 .18158 Mdot
.662 .1816 Mdot
.662 .18161 Mdot
.662 .18192 Mdot
.662 .18201 Mdot
.662 .18233 Mdot
.662 .18281 Mdot
.662 .18283 Mdot
.662 .18288 Mdot
.662 .18312 Mdot
.662 .18313 Mdot
.662 .18313 Mdot
.662 .18323 Mdot
.662 .18331 Mdot
.662 .184 Mdot
.662 .18408 Mdot
.662 .18425 Mdot
.662 .18454 Mdot
.662 .18474 Mdot
.662 .18526 Mdot
.662 .18731 Mdot
.662 .18766 Mdot
.662 .18778 Mdot
.662 .18897 Mdot
.662 .18923 Mdot
.662 .18983 Mdot
.662 .19055 Mdot
.662 .19081 Mdot
.662 .19086 Mdot
.662 .19207 Mdot
.662 .19221 Mdot
.662 .19264 Mdot
.662 .19306 Mdot
.662 .1933 Mdot
.662 .19354 Mdot
.662 .19384 Mdot
.662 .19416 Mdot
.662 .19484 Mdot
.662 .19602 Mdot
.662 .19789 Mdot
.662 .19878 Mdot
.662 .19903 Mdot
.662 .19912 Mdot
.662 .20023 Mdot
.662 .20095 Mdot
.662 .20122 Mdot
.662 .20167 Mdot
.662 .2017 Mdot
.662 .20201 Mdot
.662 .20291 Mdot
.662 .20292 Mdot
.662 .20304 Mdot
.662 .20322 Mdot
.662 .20384 Mdot
.662 .20425 Mdot
.662 .20435 Mdot
.662 .20493 Mdot
.662 .20646 Mdot
.662 .207 Mdot
.662 .20712 Mdot
.662 .20782 Mdot
.662 .20794 Mdot
.662 .20991 Mdot
.662 .21027 Mdot
.662 .21102 Mdot
.662 .21145 Mdot
.662 .21166 Mdot
.662 .21181 Mdot
.662 .21236 Mdot
.662 .21239 Mdot
.662 .21263 Mdot
.662 .21264 Mdot
.662 .21392 Mdot
.662 .21436 Mdot
.662 .21443 Mdot
.662 .21465 Mdot
.662 .21469 Mdot
.662 .21483 Mdot
.662 .21608 Mdot
.662 .21634 Mdot
.662 .21739 Mdot
.662 .21756 Mdot
.662 .21809 Mdot
.662 .21835 Mdot
.662 .21909 Mdot
.662 .22013 Mdot
.662 .22037 Mdot
.662 .22077 Mdot
.662 .22119 Mdot
.662 .22133 Mdot
.662 .22152 Mdot
.662 .22172 Mdot
.662 .22182 Mdot
.662 .22184 Mdot
.662 .22194 Mdot
.662 .22237 Mdot
.662 .22246 Mdot
.662 .22329 Mdot
.662 .2233 Mdot
.662 .22382 Mdot
.662 .22471 Mdot
.662 .22513 Mdot
.662 .22518 Mdot
.662 .22531 Mdot
.662 .22668 Mdot
.662 .22712 Mdot
.662 .22728 Mdot
.662 .22734 Mdot
.662 .22742 Mdot
.662 .22749 Mdot
.662 .22916 Mdot
.662 .22923 Mdot
.662 .22964 Mdot
.662 .22965 Mdot
.662 .22971 Mdot
.662 .22997 Mdot
.662 .23136 Mdot
.662 .23164 Mdot
.662 .23197 Mdot
.662 .23197 Mdot
.662 .23248 Mdot
.662 .23253 Mdot
.662 .23254 Mdot
.662 .23394 Mdot
.662 .23403 Mdot
.662 .2343 Mdot
.662 .23432 Mdot
.662 .2356 Mdot
.662 .23564 Mdot
.662 .23565 Mdot
.662 .23567 Mdot
.662 .23569 Mdot
.662 .2361 Mdot
.662 .23622 Mdot
.662 .23664 Mdot
.662 .23727 Mdot
.662 .23729 Mdot
.662 .23736 Mdot
.662 .23769 Mdot
.662 .2377 Mdot
.662 .2377 Mdot
.662 .23783 Mdot
.662 .23793 Mdot
.662 .23825 Mdot
.662 .23885 Mdot
.662 .23895 Mdot
.662 .23917 Mdot
.662 .23956 Mdot
.662 .23982 Mdot
.662 .24052 Mdot
.662 .24324 Mdot
.662 .24369 Mdot
.662 .24385 Mdot
.662 .24543 Mdot
.662 .24577 Mdot
.662 .24657 Mdot
.662 .24752 Mdot
.662 .24786 Mdot
.662 .24794 Mdot
.662 .24953 Mdot
.662 .24971 Mdot
.662 .25029 Mdot
.662 .25084 Mdot
.662 .25116 Mdot
.662 .25148 Mdot
.662 .25188 Mdot
.662 .2523 Mdot
.662 .25321 Mdot
.662 .25476 Mdot
.662 .25724 Mdot
.662 .25842 Mdot
.662 .25875 Mdot
.662 .25887 Mdot
.662 .26034 Mdot
.662 .2613 Mdot
.662 .26165 Mdot
.662 .26224 Mdot
.662 .26229 Mdot
.662 .26269 Mdot
.662 .26388 Mdot
.662 .2639 Mdot
.662 .26405 Mdot
.662 .2643 Mdot
.662 .26511 Mdot
.662 .26565 Mdot
.662 .26579 Mdot
.662 .26656 Mdot
.662 .26858 Mdot
.662 .2693 Mdot
.662 .26947 Mdot
.662 .27039 Mdot
.662 .27055 Mdot
.662 .27315 Mdot
.662 .27363 Mdot
.662 .27463 Mdot
.662 .27519 Mdot
.662 .27547 Mdot
.662 .27566 Mdot
.662 .27639 Mdot
.662 .27643 Mdot
.662 .27676 Mdot
.662 .27676 Mdot
.662 .27846 Mdot
.662 .27904 Mdot
.662 .27914 Mdot
.662 .27943 Mdot
.662 .27948 Mdot
.662 .27967 Mdot
.662 .28132 Mdot
.662 .28166 Mdot
.662 .28306 Mdot
.662 .28328 Mdot
.662 .28399 Mdot
.662 .28433 Mdot
.662 .2853 Mdot
.662 .28669 Mdot
.662 .287 Mdot
.662 .28753 Mdot
.662 .28809 Mdot
.662 .28827 Mdot
.662 .28853 Mdot
.662 .28879 Mdot
.662 .28892 Mdot
.662 .28894 Mdot
.662 .28908 Mdot
.662 .28965 Mdot
.662 .28977 Mdot
.662 .29087 Mdot
.662 .29088 Mdot
.662 .29158 Mdot
.662 .29275 Mdot
.662 .2933 Mdot
.662 .29337 Mdot
.662 .29354 Mdot
.662 .29536 Mdot
.662 .29594 Mdot
.662 .29616 Mdot
.662 .29623 Mdot
.662 .29633 Mdot
.662 .29644 Mdot
.662 .29865 Mdot
.662 .29873 Mdot
.662 .29928 Mdot
.662 .29928 Mdot
.662 .29972 Mdot
.662 .30156 Mdot
.662 .30192 Mdot
.662 .30236 Mdot
.662 .30237 Mdot
.662 .30303 Mdot
.662 .3031 Mdot
.662 .30311 Mdot
.662 .30496 Mdot
.662 .30509 Mdot
.662 .30544 Mdot
.662 .30547 Mdot
.662 .30716 Mdot
.662 .30721 Mdot
.662 .30723 Mdot
.662 .30726 Mdot
.662 .30728 Mdot
.662 .30783 Mdot
.662 .30798 Mdot
.662 .30854 Mdot
.662 .30938 Mdot
.662 .30941 Mdot
.662 .3095 Mdot
.662 .30993 Mdot
.662 .30994 Mdot
.662 .30995 Mdot
.662 .31012 Mdot
.662 .31026 Mdot
.662 .31067 Mdot
.662 .31147 Mdot
.662 .3116 Mdot
.662 .3119 Mdot
.662 .31242 Mdot
.662 .31276 Mdot
.662 .31368 Mdot
.662 .31728 Mdot
.662 .31788 Mdot
.662 .31809 Mdot
.662 .32018 Mdot
.662 .32064 Mdot
.662 .32169 Mdot
.662 .32295 Mdot
.662 .3234 Mdot
.662 .3235 Mdot
.662 .32561 Mdot
.662 .32585 Mdot
.662 .32662 Mdot
.662 .32735 Mdot
.662 .32777 Mdot
.662 .3282 Mdot
.662 .32872 Mdot
.662 .32928 Mdot
.662 .33048 Mdot
.662 .33254 Mdot
.662 .33582 Mdot
.662 .33737 Mdot
.662 .33782 Mdot
.662 .33798 Mdot
.662 .33992 Mdot
.662 .34119 Mdot
.662 .34166 Mdot
.662 .34244 Mdot
.662 .3425 Mdot
.662 .34304 Mdot
.662 .34461 Mdot
.662 .34463 Mdot
.662 .34484 Mdot
.662 .34517 Mdot
.662 .34624 Mdot
.662 .34696 Mdot
.662 .34714 Mdot
.662 .34815 Mdot
.662 .35083 Mdot
.662 .35179 Mdot
.662 .352 Mdot
.662 .35323 Mdot
.662 .35344 Mdot
.662 .35688 Mdot
.662 .35752 Mdot
.662 .35884 Mdot
.662 .35958 Mdot
.662 .35995 Mdot
.662 .36021 Mdot
.662 .36118 Mdot
.662 .36123 Mdot
.662 .36166 Mdot
.662 .36166 Mdot
.662 .36392 Mdot
.662 .36469 Mdot
.662 .36481 Mdot
.662 .3652 Mdot
.662 .36526 Mdot
.662 .36551 Mdot
.662 .3677 Mdot
.662 .36816 Mdot
.662 .37001 Mdot
.662 .37029 Mdot
.662 .37123 Mdot
.662 .37168 Mdot
.662 .37297 Mdot
.662 .3748 Mdot
.662 .37522 Mdot
.662 .37592 Mdot
.662 .37666 Mdot
.662 .3769 Mdot
.662 .37724 Mdot
.662 .37759 Mdot
.662 .37776 Mdot
.662 .37779 Mdot
.662 .37797 Mdot
.662 .37873 Mdot
.662 .37889 Mdot
.662 .38034 Mdot
.662 .38036 Mdot
.662 .38128 Mdot
.662 .38283 Mdot
.662 .38357 Mdot
.662 .38365 Mdot
.662 .38388 Mdot
.662 .38629 Mdot
.662 .38706 Mdot
.662 .38734 Mdot
.662 .38745 Mdot
.662 .38758 Mdot
.662 .38771 Mdot
.662 .39064 Mdot
.662 .39076 Mdot
.662 .39148 Mdot
.662 .39149 Mdot
.662 .39206 Mdot
.662 .3945 Mdot
.662 .39498 Mdot
.662 .39555 Mdot
.662 .39556 Mdot
.662 .39644 Mdot
.662 .39654 Mdot
.662 .39656 Mdot
.662 .399 Mdot
.662 .39918 Mdot
.662 .39964 Mdot
.662 .39968 Mdot
.662 .40191 Mdot
.662 .40198 Mdot
.662 .40201 Mdot
.662 .40204 Mdot
.662 .40207 Mdot
.662 .40279 Mdot
.662 .403 Mdot
.662 .40374 Mdot
.662 .40485 Mdot
.662 .40489 Mdot
.662 .405 Mdot
.662 .40558 Mdot
.662 .4056 Mdot
.662 .4056 Mdot
.662 .40583 Mdot
.662 .40601 Mdot
.664 .01506 Mdot
.664 .01517 Mdot
.664 .01532 Mdot
.664 .01533 Mdot
.664 .01553 Mdot
.664 .01553 Mdot
.664 .01553 Mdot
.664 .01579 Mdot
.664 .01579 Mdot
.664 .0158 Mdot
.664 .01614 Mdot
.664 .01615 Mdot
.664 .01616 Mdot
.664 .01661 Mdot
.664 .01662 Mdot
.664 .01663 Mdot
.664 .01705 Mdot
.664 .01723 Mdot
.664 .01724 Mdot
.664 .01726 Mdot
.664 .01764 Mdot
.664 .01781 Mdot
.664 .01805 Mdot
.664 .01806 Mdot
.664 .01807 Mdot
.664 .01809 Mdot
.664 .01829 Mdot
.664 .01859 Mdot
.664 .01883 Mdot
.664 .01915 Mdot
.664 .01916 Mdot
.664 .01917 Mdot
.664 .0192 Mdot
.664 .01946 Mdot
.664 .01987 Mdot
.664 .01989 Mdot
.664 .02018 Mdot
.664 .02044 Mdot
.664 .0206 Mdot
.664 .02061 Mdot
.664 .02064 Mdot
.664 .02067 Mdot
.664 .02102 Mdot
.664 .02141 Mdot
.664 .02156 Mdot
.664 .02159 Mdot
.664 .02197 Mdot
.664 .02232 Mdot
.664 .02254 Mdot
.664 .02255 Mdot
.664 .02258 Mdot
.664 .02263 Mdot
.664 .02308 Mdot
.664 .02361 Mdot
.664 .02361 Mdot
.664 .0238 Mdot
.664 .02385 Mdot
.664 .02406 Mdot
.664 .02435 Mdot
.664 .02481 Mdot
.664 .0251 Mdot
.664 .02512 Mdot
.664 .02516 Mdot
.664 .02522 Mdot
.664 .02523 Mdot
.664 .02547 Mdot
.664 .02561 Mdot
.664 .02583 Mdot
.664 .02652 Mdot
.664 .02653 Mdot
.664 .02678 Mdot
.664 .02684 Mdot
.664 .02712 Mdot
.664 .02746 Mdot
.664 .02751 Mdot
.664 .02808 Mdot
.664 .02812 Mdot
.664 .02851 Mdot
.664 .02853 Mdot
.664 .02859 Mdot
.664 .02867 Mdot
.664 .02868 Mdot
.664 .029 Mdot
.664 .02913 Mdot
.664 .02919 Mdot
.664 .02948 Mdot
.664 .03039 Mdot
.664 .0304 Mdot
.664 .03074 Mdot
.664 .03082 Mdot
.664 .03119 Mdot
.664 .03164 Mdot
.664 .03171 Mdot
.664 .03187 Mdot
.664 .03246 Mdot
.664 .03252 Mdot
.664 .03253 Mdot
.664 .03303 Mdot
.664 .03306 Mdot
.664 .03314 Mdot
.664 .03325 Mdot
.664 .03326 Mdot
.664 .03369 Mdot
.664 .03386 Mdot
.664 .03394 Mdot
.664 .03432 Mdot
.664 .03554 Mdot
.664 .03555 Mdot
.664 .036 Mdot
.664 .03608 Mdot
.664 .0361 Mdot
.664 .03627 Mdot
.664 .03643 Mdot
.664 .03659 Mdot
.664 .03702 Mdot
.664 .03714 Mdot
.664 .03719 Mdot
.664 .03728 Mdot
.664 .0375 Mdot
.664 .03777 Mdot
.664 .03828 Mdot
.664 .03836 Mdot
.664 .03837 Mdot
.664 .039 Mdot
.664 .03904 Mdot
.664 .03908 Mdot
.664 .03918 Mdot
.664 .03933 Mdot
.664 .03934 Mdot
.664 .03938 Mdot
.664 .03991 Mdot
.664 .04015 Mdot
.664 .04024 Mdot
.664 .04075 Mdot
.664 .04194 Mdot
.664 .04212 Mdot
.664 .04224 Mdot
.664 .04236 Mdot
.664 .04238 Mdot
.664 .04287 Mdot
.664 .04298 Mdot
.664 .04308 Mdot
.664 .04311 Mdot
.664 .04334 Mdot
.664 .04355 Mdot
.664 .04362 Mdot
.664 .04376 Mdot
.664 .04433 Mdot
.664 .04449 Mdot
.664 .04456 Mdot
.664 .04468 Mdot
.664 .04497 Mdot
.664 .04533 Mdot
.664 .04601 Mdot
.664 .0461 Mdot
.664 .04612 Mdot
.664 .04613 Mdot
.664 .04696 Mdot
.664 .04697 Mdot
.664 .04702 Mdot
.664 .04708 Mdot
.664 .04717 Mdot
.664 .0472 Mdot
.664 .0474 Mdot
.664 .04742 Mdot
.664 .04747 Mdot
.664 .04817 Mdot
.664 .04849 Mdot
.664 .04861 Mdot
.664 .04928 Mdot
.664 .05087 Mdot
.664 .05111 Mdot
.664 .05126 Mdot
.664 .05143 Mdot
.664 .05145 Mdot
.664 .05183 Mdot
.664 .0521 Mdot
.664 .05225 Mdot
.664 .05239 Mdot
.664 .05243 Mdot
.664 .05273 Mdot
.664 .053 Mdot
.664 .0531 Mdot
.664 .05329 Mdot
.664 .05362 Mdot
.664 .05405 Mdot
.664 .05412 Mdot
.664 .05426 Mdot
.664 .05435 Mdot
.664 .05451 Mdot
.664 .05489 Mdot
.664 .05519 Mdot
.664 .05537 Mdot
.664 .05561 Mdot
.664 .0559 Mdot
.664 .05627 Mdot
.664 .05639 Mdot
.664 .05642 Mdot
.664 .05643 Mdot
.664 .0568 Mdot
.664 .05752 Mdot
.664 .05754 Mdot
.664 .05755 Mdot
.664 .05761 Mdot
.664 .05769 Mdot
.664 .05782 Mdot
.664 .05786 Mdot
.664 .05812 Mdot
.664 .05815 Mdot
.664 .05822 Mdot
.664 .05914 Mdot
.664 .05956 Mdot
.664 .05973 Mdot
.664 .06062 Mdot
.664 .06208 Mdot
.664 .06272 Mdot
.664 .06277 Mdot
.664 .06304 Mdot
.664 .06325 Mdot
.664 .06348 Mdot
.664 .0635 Mdot
.664 .06365 Mdot
.664 .06401 Mdot
.664 .06437 Mdot
.664 .06446 Mdot
.664 .06456 Mdot
.664 .06474 Mdot
.664 .0648 Mdot
.664 .06499 Mdot
.664 .0652 Mdot
.664 .06556 Mdot
.664 .0657 Mdot
.664 .06595 Mdot
.664 .06615 Mdot
.664 .06632 Mdot
.664 .06638 Mdot
.664 .06695 Mdot
.664 .06705 Mdot
.664 .06723 Mdot
.664 .06735 Mdot
.664 .06757 Mdot
.664 .06807 Mdot
.664 .06847 Mdot
.664 .06867 Mdot
.664 .06871 Mdot
.664 .06902 Mdot
.664 .06941 Mdot
.664 .0699 Mdot
.664 .07006 Mdot
.664 .0701 Mdot
.664 .07012 Mdot
.664 .07046 Mdot
.664 .0706 Mdot
.664 .07155 Mdot
.664 .07158 Mdot
.664 .0716 Mdot
.664 .07168 Mdot
.664 .07179 Mdot
.664 .07196 Mdot
.664 .07201 Mdot
.664 .07236 Mdot
.664 .0724 Mdot
.664 .07249 Mdot
.664 .07372 Mdot
.664 .07427 Mdot
.664 .0745 Mdot
.664 .07534 Mdot
.664 .07568 Mdot
.664 .07761 Mdot
.664 .07847 Mdot
.664 .07854 Mdot
.664 .07889 Mdot
.664 .07917 Mdot
.664 .07947 Mdot
.664 .0795 Mdot
.664 .07971 Mdot
.664 .07984 Mdot
.664 .08017 Mdot
.664 .0802 Mdot
.664 .08065 Mdot
.664 .08078 Mdot
.664 .0809 Mdot
.664 .08115 Mdot
.664 .08122 Mdot
.664 .08148 Mdot
.664 .08176 Mdot
.664 .08189 Mdot
.664 .08224 Mdot
.664 .08242 Mdot
.664 .08275 Mdot
.664 .08296 Mdot
.664 .08298 Mdot
.664 .08302 Mdot
.664 .08325 Mdot
.664 .08333 Mdot
.664 .08369 Mdot
.664 .08408 Mdot
.664 .08422 Mdot
.664 .08446 Mdot
.664 .08457 Mdot
.664 .08461 Mdot
.664 .0849 Mdot
.664 .08557 Mdot
.664 .0861 Mdot
.664 .08636 Mdot
.664 .08641 Mdot
.664 .08645 Mdot
.664 .08683 Mdot
.664 .08695 Mdot
.664 .08725 Mdot
.664 .08735 Mdot
.664 .088 Mdot
.664 .08822 Mdot
.664 .08826 Mdot
.664 .08829 Mdot
.664 .08874 Mdot
.664 .08893 Mdot
.664 .08955 Mdot
.664 .0902 Mdot
.664 .09023 Mdot
.664 .09026 Mdot
.664 .09037 Mdot
.664 .0905 Mdot
.664 .09073 Mdot
.664 .0908 Mdot
.664 .09126 Mdot
.664 .0913 Mdot
.664 .09132 Mdot
.664 .09143 Mdot
.664 .09157 Mdot
.664 .09202 Mdot
.664 .09307 Mdot
.664 .09376 Mdot
.664 .09381 Mdot
.664 .09397 Mdot
.664 .0941 Mdot
.664 .09522 Mdot
.664 .09547 Mdot
.664 .09568 Mdot
.664 .09646 Mdot
.664 .09824 Mdot
.664 .09855 Mdot
.664 .09888 Mdot
.664 .09904 Mdot
.664 .09938 Mdot
.664 .09947 Mdot
.664 .09994 Mdot
.664 .10031 Mdot
.664 .1004 Mdot
.664 .10071 Mdot
.664 .10075 Mdot
.664 .10102 Mdot
.664 .10121 Mdot
.664 .10165 Mdot
.664 .10167 Mdot
.664 .10192 Mdot
.664 .10228 Mdot
.664 .10236 Mdot
.664 .10245 Mdot
.664 .10262 Mdot
.664 .10277 Mdot
.664 .10295 Mdot
.664 .10304 Mdot
.664 .10306 Mdot
.664 .10328 Mdot
.664 .10338 Mdot
.664 .10375 Mdot
.664 .10393 Mdot
.664 .1042 Mdot
.664 .10439 Mdot
.664 .10462 Mdot
.664 .10506 Mdot
.664 .10507 Mdot
.664 .10535 Mdot
.664 .10537 Mdot
.664 .10542 Mdot
.664 .10572 Mdot
.664 .10583 Mdot
.664 .10602 Mdot
.664 .10631 Mdot
.664 .10651 Mdot
.664 .10665 Mdot
.664 .10665 Mdot
.664 .10684 Mdot
.664 .10701 Mdot
.664 .10733 Mdot
.664 .10748 Mdot
.664 .10753 Mdot
.664 .10785 Mdot
.664 .10792 Mdot
.664 .10838 Mdot
.664 .10881 Mdot
.664 .10951 Mdot
.664 .10987 Mdot
.664 .10993 Mdot
.664 .10998 Mdot
.664 .11035 Mdot
.664 .11044 Mdot
.664 .11049 Mdot
.664 .11065 Mdot
.664 .11104 Mdot
.664 .11117 Mdot
.664 .1114 Mdot
.664 .11194 Mdot
.664 .11204 Mdot
.664 .11233 Mdot
.664 .11239 Mdot
.664 .11242 Mdot
.664 .11287 Mdot
.664 .11302 Mdot
.664 .11327 Mdot
.664 .11394 Mdot
.664 .1141 Mdot
.664 .11495 Mdot
.664 .115 Mdot
.664 .11504 Mdot
.664 .11518 Mdot
.664 .11521 Mdot
.664 .11536 Mdot
.664 .11566 Mdot
.664 .11575 Mdot
.664 .11637 Mdot
.664 .11642 Mdot
.664 .11645 Mdot
.664 .1166 Mdot
.664 .11678 Mdot
.664 .11738 Mdot
.664 .11759 Mdot
.664 .11764 Mdot
.664 .11877 Mdot
.664 .1192 Mdot
.664 .11932 Mdot
.664 .11958 Mdot
.664 .11968 Mdot
.664 .11975 Mdot
.664 .11997 Mdot
.664 .12014 Mdot
.664 .12125 Mdot
.664 .12142 Mdot
.664 .12163 Mdot
.664 .12183 Mdot
.664 .12195 Mdot
.664 .12223 Mdot
.664 .12228 Mdot
.664 .12284 Mdot
.664 .12328 Mdot
.664 .12446 Mdot
.664 .12555 Mdot
.664 .12564 Mdot
.664 .12605 Mdot
.664 .12631 Mdot
.664 .12631 Mdot
.664 .12648 Mdot
.664 .12669 Mdot
.664 .12715 Mdot
.664 .12727 Mdot
.664 .12734 Mdot
.664 .1279 Mdot
.664 .12832 Mdot
.664 .12839 Mdot
.664 .1285 Mdot
.664 .12892 Mdot
.664 .12897 Mdot
.664 .12933 Mdot
.664 .12957 Mdot
.664 .13008 Mdot
.664 .13016 Mdot
.664 .1302 Mdot
.664 .13053 Mdot
.664 .1309 Mdot
.664 .131 Mdot
.664 .1311 Mdot
.664 .13117 Mdot
.664 .13123 Mdot
.664 .13145 Mdot
.664 .13165 Mdot
.664 .13189 Mdot
.664 .13201 Mdot
.664 .13204 Mdot
.664 .13204 Mdot
.664 .13233 Mdot
.664 .13246 Mdot
.664 .13294 Mdot
.664 .13296 Mdot
.664 .13319 Mdot
.664 .13332 Mdot
.664 .13355 Mdot
.664 .1338 Mdot
.664 .13411 Mdot
.664 .13469 Mdot
.664 .1347 Mdot
.664 .13508 Mdot
.664 .13511 Mdot
.664 .13517 Mdot
.664 .13558 Mdot
.664 .13562 Mdot
.664 .13571 Mdot
.664 .13582 Mdot
.664 .13596 Mdot
.664 .13635 Mdot
.664 .13662 Mdot
.664 .1368 Mdot
.664 .1368 Mdot
.664 .13705 Mdot
.664 .13729 Mdot
.664 .13771 Mdot
.664 .13791 Mdot
.664 .13798 Mdot
.664 .13819 Mdot
.664 .1384 Mdot
.664 .1385 Mdot
.664 .1391 Mdot
.664 .13968 Mdot
.664 .14061 Mdot
.664 .14108 Mdot
.664 .14116 Mdot
.664 .14123 Mdot
.664 .14171 Mdot
.664 .14183 Mdot
.664 .1419 Mdot
.664 .14204 Mdot
.664 .14211 Mdot
.664 .14263 Mdot
.664 .14281 Mdot
.664 .14312 Mdot
.664 .14382 Mdot
.664 .14397 Mdot
.664 .14435 Mdot
.664 .14442 Mdot
.664 .14447 Mdot
.664 .14506 Mdot
.664 .14526 Mdot
.664 .1456 Mdot
.664 .14648 Mdot
.664 .14669 Mdot
.664 .14783 Mdot
.664 .1479 Mdot
.664 .14795 Mdot
.664 .14814 Mdot
.664 .14817 Mdot
.664 .14838 Mdot
.664 .14877 Mdot
.664 .1489 Mdot
.664 .14972 Mdot
.664 .14978 Mdot
.664 .14981 Mdot
.664 .15002 Mdot
.664 .15026 Mdot
.664 .15106 Mdot
.664 .15133 Mdot
.664 .1514 Mdot
.664 .1529 Mdot
.664 .15347 Mdot
.664 .15364 Mdot
.664 .15398 Mdot
.664 .15411 Mdot
.664 .15421 Mdot
.664 .15449 Mdot
.664 .15473 Mdot
.664 .15619 Mdot
.664 .15642 Mdot
.664 .1567 Mdot
.664 .15696 Mdot
.664 .15713 Mdot
.664 .1575 Mdot
.664 .15756 Mdot
.664 .15831 Mdot
.664 .15889 Mdot
.664 .16046 Mdot
.664 .1619 Mdot
.664 .16202 Mdot
.664 .16256 Mdot
.664 .16291 Mdot
.664 .16291 Mdot
.664 .16314 Mdot
.664 .16342 Mdot
.664 .16403 Mdot
.664 .16419 Mdot
.664 .16428 Mdot
.664 .16503 Mdot
.664 .16559 Mdot
.664 .16568 Mdot
.664 .16582 Mdot
.664 .16638 Mdot
.664 .16645 Mdot
.664 .16693 Mdot
.664 .16725 Mdot
.664 .16792 Mdot
.664 .16802 Mdot
.664 .16808 Mdot
.664 .16851 Mdot
.664 .169 Mdot
.664 .16914 Mdot
.664 .16928 Mdot
.664 .16937 Mdot
.664 .16944 Mdot
.664 .16973 Mdot
.664 .17001 Mdot
.664 .17032 Mdot
.664 .17048 Mdot
.664 .17052 Mdot
.664 .17052 Mdot
.664 .17091 Mdot
.664 .17108 Mdot
.664 .17171 Mdot
.664 .17174 Mdot
.664 .17205 Mdot
.664 .17222 Mdot
.664 .17252 Mdot
.664 .17287 Mdot
.664 .17328 Mdot
.664 .17404 Mdot
.664 .17406 Mdot
.664 .17456 Mdot
.664 .1746 Mdot
.664 .17468 Mdot
.664 .17522 Mdot
.664 .17527 Mdot
.664 .1754 Mdot
.664 .17555 Mdot
.664 .17573 Mdot
.664 .17625 Mdot
.664 .1766 Mdot
.664 .17684 Mdot
.664 .17684 Mdot
.664 .17718 Mdot
.664 .17749 Mdot
.664 .17806 Mdot
.664 .17832 Mdot
.664 .17841 Mdot
.664 .17869 Mdot
.664 .17897 Mdot
.664 .1791 Mdot
.664 .1799 Mdot
.664 .18066 Mdot
.664 .1819 Mdot
.664 .18252 Mdot
.664 .18264 Mdot
.664 .18272 Mdot
.664 .18337 Mdot
.664 .18353 Mdot
.664 .18362 Mdot
.664 .1838 Mdot
.664 .1839 Mdot
.664 .18458 Mdot
.664 .18482 Mdot
.664 .18523 Mdot
.664 .18617 Mdot
.664 .18636 Mdot
.664 .18686 Mdot
.664 .18697 Mdot
.664 .18703 Mdot
.664 .18781 Mdot
.664 .18808 Mdot
.664 .18853 Mdot
.664 .1897 Mdot
.664 .18998 Mdot
.664 .1915 Mdot
.664 .19158 Mdot
.664 .19164 Mdot
.664 .1919 Mdot
.664 .19195 Mdot
.664 .19222 Mdot
.664 .19275 Mdot
.664 .19291 Mdot
.664 .194 Mdot
.664 .19407 Mdot
.664 .19413 Mdot
.664 .1944 Mdot
.664 .19472 Mdot
.664 .19577 Mdot
.664 .19614 Mdot
.664 .19623 Mdot
.664 .19822 Mdot
.664 .19899 Mdot
.664 .1992 Mdot
.664 .19966 Mdot
.664 .19983 Mdot
.664 .19996 Mdot
.664 .20034 Mdot
.664 .20065 Mdot
.664 .2026 Mdot
.664 .20289 Mdot
.664 .20327 Mdot
.664 .20362 Mdot
.664 .20384 Mdot
.664 .20433 Mdot
.664 .20441 Mdot
.664 .20541 Mdot
.664 .20617 Mdot
.664 .20826 Mdot
.664 .21018 Mdot
.664 .21033 Mdot
.664 .21106 Mdot
.664 .21152 Mdot
.664 .21152 Mdot
.664 .21182 Mdot
.664 .2122 Mdot
.664 .213 Mdot
.664 .21322 Mdot
.664 .21334 Mdot
.664 .21433 Mdot
.664 .21507 Mdot
.664 .21519 Mdot
.664 .21538 Mdot
.664 .21612 Mdot
.664 .21622 Mdot
.664 .21685 Mdot
.664 .21728 Mdot
.664 .21817 Mdot
.664 .21831 Mdot
.664 .21838 Mdot
.664 .21896 Mdot
.664 .21961 Mdot
.664 .21979 Mdot
.664 .21997 Mdot
.664 .2201 Mdot
.664 .22019 Mdot
.664 .22058 Mdot
.664 .22095 Mdot
.664 .22136 Mdot
.664 .22157 Mdot
.664 .22163 Mdot
.664 .22163 Mdot
.664 .22214 Mdot
.664 .22237 Mdot
.664 .22321 Mdot
.664 .22325 Mdot
.664 .22366 Mdot
.664 .22389 Mdot
.664 .22428 Mdot
.664 .22474 Mdot
.664 .22528 Mdot
.664 .2263 Mdot
.664 .22632 Mdot
.664 .22699 Mdot
.664 .22704 Mdot
.664 .22715 Mdot
.664 .22786 Mdot
.664 .22793 Mdot
.664 .22811 Mdot
.664 .2283 Mdot
.664 .22854 Mdot
.664 .22923 Mdot
.664 .2297 Mdot
.664 .23002 Mdot
.664 .23002 Mdot
.664 .23046 Mdot
.664 .23088 Mdot
.664 .23163 Mdot
.664 .23198 Mdot
.664 .2321 Mdot
.664 .23247 Mdot
.664 .23285 Mdot
.664 .23302 Mdot
.664 .23409 Mdot
.664 .23509 Mdot
.664 .23674 Mdot
.664 .23756 Mdot
.664 .23772 Mdot
.664 .23783 Mdot
.664 .23869 Mdot
.664 .2389 Mdot
.664 .23902 Mdot
.664 .23926 Mdot
.664 .23939 Mdot
.664 .2403 Mdot
.664 .24061 Mdot
.664 .24116 Mdot
.664 .24241 Mdot
.664 .24266 Mdot
.664 .24333 Mdot
.664 .24347 Mdot
.664 .24355 Mdot
.664 .24459 Mdot
.664 .24494 Mdot
.664 .24554 Mdot
.664 .24709 Mdot
.664 .24747 Mdot
.664 .24948 Mdot
.664 .24959 Mdot
.664 .24968 Mdot
.664 .25001 Mdot
.664 .25008 Mdot
.664 .25044 Mdot
.664 .25114 Mdot
.664 .25135 Mdot
.664 .2528 Mdot
.664 .2529 Mdot
.664 .25297 Mdot
.664 .25333 Mdot
.664 .25376 Mdot
.664 .25516 Mdot
.664 .25565 Mdot
.664 .25577 Mdot
.664 .25841 Mdot
.664 .25943 Mdot
.664 .25971 Mdot
.664 .26032 Mdot
.664 .26055 Mdot
.664 .26072 Mdot
.664 .26123 Mdot
.664 .26164 Mdot
.664 .26422 Mdot
.664 .26462 Mdot
.664 .26512 Mdot
.664 .26557 Mdot
.664 .26587 Mdot
.664 .26653 Mdot
.664 .26663 Mdot
.664 .26796 Mdot
.664 .26897 Mdot
.664 .27174 Mdot
.664 .2743 Mdot
.664 .2745 Mdot
.664 .27546 Mdot
.664 .27607 Mdot
.664 .27608 Mdot
.664 .27648 Mdot
.664 .27698 Mdot
.664 .27804 Mdot
.664 .27833 Mdot
.664 .27849 Mdot
.664 .2798 Mdot
.664 .28079 Mdot
.664 .28095 Mdot
.664 .2812 Mdot
.664 .28219 Mdot
.664 .28231 Mdot
.664 .28316 Mdot
.664 .28372 Mdot
.664 .2849 Mdot
.664 .28509 Mdot
.664 .28518 Mdot
.664 .28595 Mdot
.664 .28682 Mdot
.664 .28706 Mdot
.664 .2873 Mdot
.664 .28746 Mdot
.664 .28759 Mdot
.664 .2881 Mdot
.664 .28859 Mdot
.664 .28914 Mdot
.664 .28942 Mdot
.664 .28949 Mdot
.664 .28949 Mdot
.664 .29018 Mdot
.664 .29048 Mdot
.664 .29159 Mdot
.664 .29164 Mdot
.664 .29219 Mdot
.664 .29249 Mdot
.664 .29302 Mdot
.664 .29363 Mdot
.664 .29435 Mdot
.664 .2957 Mdot
.664 .29573 Mdot
.664 .29661 Mdot
.664 .29668 Mdot
.664 .29683 Mdot
.664 .29777 Mdot
.664 .29787 Mdot
.664 .2981 Mdot
.664 .29836 Mdot
.664 .29868 Mdot
.664 .29959 Mdot
.664 .30021 Mdot
.664 .30064 Mdot
.664 .30064 Mdot
.664 .30123 Mdot
.664 .30179 Mdot
.664 .30278 Mdot
.664 .30324 Mdot
.664 .3034 Mdot
.664 .30389 Mdot
.664 .3044 Mdot
.664 .30462 Mdot
.664 .30604 Mdot
.664 .30738 Mdot
.664 .30956 Mdot
.664 .31066 Mdot
.664 .31086 Mdot
.664 .31101 Mdot
.664 .31215 Mdot
.664 .3126 Mdot
.664 .31291 Mdot
.664 .31309 Mdot
.664 .31429 Mdot
.664 .31471 Mdot
.664 .31544 Mdot
.664 .31709 Mdot
.664 .31743 Mdot
.664 .31832 Mdot
.664 .3185 Mdot
.664 .3186 Mdot
.664 .31999 Mdot
.664 .32046 Mdot
.664 .32125 Mdot
.664 .32331 Mdot
.664 .32381 Mdot
.664 .32648 Mdot
.664 .32663 Mdot
.664 .32674 Mdot
.664 .32719 Mdot
.664 .32728 Mdot
.664 .32776 Mdot
.664 .32869 Mdot
.664 .32897 Mdot
.664 .33089 Mdot
.664 .33103 Mdot
.664 .33112 Mdot
.664 .3316 Mdot
.664 .33216 Mdot
.664 .33403 Mdot
.664 .33468 Mdot
.664 .33484 Mdot
.664 .33835 Mdot
.664 .33969 Mdot
.664 .34007 Mdot
.664 .34088 Mdot
.664 .34119 Mdot
.664 .34141 Mdot
.664 .34208 Mdot
.664 .34263 Mdot
.664 .34606 Mdot
.664 .34659 Mdot
.664 .34725 Mdot
.664 .34786 Mdot
.664 .34825 Mdot
.664 .34913 Mdot
.664 .34926 Mdot
.664 .35102 Mdot
.664 .35237 Mdot
.664 .35605 Mdot
.664 .35944 Mdot
.664 .3597 Mdot
.664 .36098 Mdot
.664 .36179 Mdot
.664 .3618 Mdot
.664 .36233 Mdot
.664 .363 Mdot
.664 .36441 Mdot
.664 .36479 Mdot
.664 .36501 Mdot
.664 .36675 Mdot
.664 .36806 Mdot
.664 .36827 Mdot
.664 .36861 Mdot
.664 .36992 Mdot
.664 .37008 Mdot
.664 .3712 Mdot
.664 .37195 Mdot
.664 .37352 Mdot
.664 .37377 Mdot
.664 .37389 Mdot
.664 .37491 Mdot
.664 .37606 Mdot
.664 .37639 Mdot
.664 .3767 Mdot
.664 .37692 Mdot
.664 .37709 Mdot
.664 .37778 Mdot
.664 .37842 Mdot
.664 .37915 Mdot
.664 .37952 Mdot
.664 .37962 Mdot
.664 .37962 Mdot
.664 .38053 Mdot
.664 .38093 Mdot
.664 .38241 Mdot
.664 .38248 Mdot
.664 .3832 Mdot
.664 .3836 Mdot
.664 .38431 Mdot
.664 .38511 Mdot
.664 .38607 Mdot
.664 .38786 Mdot
.664 .3879 Mdot
.664 .38908 Mdot
.664 .38917 Mdot
.664 .38936 Mdot
.664 .39062 Mdot
.664 .39074 Mdot
.664 .39105 Mdot
.664 .39139 Mdot
.664 .39182 Mdot
.664 .39304 Mdot
.664 .39386 Mdot
.664 .39443 Mdot
.664 .39443 Mdot
.664 .39521 Mdot
.664 .39594 Mdot
.664 .39727 Mdot
.664 .39788 Mdot
.664 .39809 Mdot
.664 .39874 Mdot
.664 .39942 Mdot
.664 .39971 Mdot
.664 .40159 Mdot
.664 .40337 Mdot
.664 .40627 Mdot
.666 .01474 Mdot
.666 .01475 Mdot
.666 .01477 Mdot
.666 .01478 Mdot
.666 .01481 Mdot
.666 .01484 Mdot
.666 .01488 Mdot
.666 .01493 Mdot
.666 .01501 Mdot
.666 .0151 Mdot
.666 .01523 Mdot
.666 .0154 Mdot
.666 .01563 Mdot
.666 .01593 Mdot
.666 .01633 Mdot
.666 .01665 Mdot
.666 .01666 Mdot
.666 .01687 Mdot
.666 .01691 Mdot
.666 .01729 Mdot
.666 .01731 Mdot
.666 .01759 Mdot
.666 .01764 Mdot
.666 .01814 Mdot
.666 .01817 Mdot
.666 .01854 Mdot
.666 .01859 Mdot
.666 .01861 Mdot
.666 .01923 Mdot
.666 .01928 Mdot
.666 .01932 Mdot
.666 .01981 Mdot
.666 .01987 Mdot
.666 .0199 Mdot
.666 .0207 Mdot
.666 .02073 Mdot
.666 .0208 Mdot
.666 .02085 Mdot
.666 .02151 Mdot
.666 .02158 Mdot
.666 .02162 Mdot
.666 .02178 Mdot
.666 .02213 Mdot
.666 .02246 Mdot
.666 .02268 Mdot
.666 .02273 Mdot
.666 .02282 Mdot
.666 .02289 Mdot
.666 .02308 Mdot
.666 .02376 Mdot
.666 .02377 Mdot
.666 .02386 Mdot
.666 .02392 Mdot
.666 .02413 Mdot
.666 .02449 Mdot
.666 .0246 Mdot
.666 .02485 Mdot
.666 .02503 Mdot
.666 .02533 Mdot
.666 .02539 Mdot
.666 .0255 Mdot
.666 .02551 Mdot
.666 .0256 Mdot
.666 .02584 Mdot
.666 .02586 Mdot
.666 .02624 Mdot
.666 .0263 Mdot
.666 .02676 Mdot
.666 .02678 Mdot
.666 .02686 Mdot
.666 .0269 Mdot
.666 .02697 Mdot
.666 .02711 Mdot
.666 .02725 Mdot
.666 .02773 Mdot
.666 .02788 Mdot
.666 .02821 Mdot
.666 .02845 Mdot
.666 .02885 Mdot
.666 .02894 Mdot
.666 .02908 Mdot
.666 .02909 Mdot
.666 .02922 Mdot
.666 .02954 Mdot
.666 .02956 Mdot
.666 .02966 Mdot
.666 .03006 Mdot
.666 .03007 Mdot
.666 .03015 Mdot
.666 .03077 Mdot
.666 .03078 Mdot
.666 .03089 Mdot
.666 .03095 Mdot
.666 .03104 Mdot
.666 .03123 Mdot
.666 .03141 Mdot
.666 .03147 Mdot
.666 .03186 Mdot
.666 .03205 Mdot
.666 .03217 Mdot
.666 .03225 Mdot
.666 .03265 Mdot
.666 .0327 Mdot
.666 .03301 Mdot
.666 .03301 Mdot
.666 .03355 Mdot
.666 .03366 Mdot
.666 .03385 Mdot
.666 .03386 Mdot
.666 .03403 Mdot
.666 .03446 Mdot
.666 .03448 Mdot
.666 .03463 Mdot
.666 .03515 Mdot
.666 .03515 Mdot
.666 .03517 Mdot
.666 .03528 Mdot
.666 .03609 Mdot
.666 .03612 Mdot
.666 .03626 Mdot
.666 .03633 Mdot
.666 .03647 Mdot
.666 .03671 Mdot
.666 .03696 Mdot
.666 .03703 Mdot
.666 .03756 Mdot
.666 .03781 Mdot
.666 .03797 Mdot
.666 .03807 Mdot
.666 .03861 Mdot
.666 .03867 Mdot
.666 .03908 Mdot
.666 .03908 Mdot
.666 .03975 Mdot
.666 .0398 Mdot
.666 .03995 Mdot
.666 .04021 Mdot
.666 .04022 Mdot
.666 .04045 Mdot
.666 .04098 Mdot
.666 .04101 Mdot
.666 .04105 Mdot
.666 .04124 Mdot
.666 .04193 Mdot
.666 .04194 Mdot
.666 .04194 Mdot
.666 .04196 Mdot
.666 .04211 Mdot
.666 .04319 Mdot
.666 .04322 Mdot
.666 .04342 Mdot
.666 .04351 Mdot
.666 .04369 Mdot
.666 .04401 Mdot
.666 .04434 Mdot
.666 .04444 Mdot
.666 .04514 Mdot
.666 .04524 Mdot
.666 .04547 Mdot
.666 .04569 Mdot
.666 .04582 Mdot
.666 .04654 Mdot
.666 .04662 Mdot
.666 .04687 Mdot
.666 .04717 Mdot
.666 .04717 Mdot
.666 .04807 Mdot
.666 .04813 Mdot
.666 .04832 Mdot
.666 .04867 Mdot
.666 .04868 Mdot
.666 .04899 Mdot
.666 .04926 Mdot
.666 .04929 Mdot
.666 .0497 Mdot
.666 .04974 Mdot
.666 .04979 Mdot
.666 .05004 Mdot
.666 .05097 Mdot
.666 .05098 Mdot
.666 .05098 Mdot
.666 .05101 Mdot
.666 .0512 Mdot
.666 .05265 Mdot
.666 .05269 Mdot
.666 .05295 Mdot
.666 .05307 Mdot
.666 .05331 Mdot
.666 .05374 Mdot
.666 .05409 Mdot
.666 .05418 Mdot
.666 .05431 Mdot
.666 .05524 Mdot
.666 .05538 Mdot
.666 .05569 Mdot
.666 .05597 Mdot
.666 .05615 Mdot
.666 .05622 Mdot
.666 .05711 Mdot
.666 .05721 Mdot
.666 .05754 Mdot
.666 .05795 Mdot
.666 .05795 Mdot
.666 .05914 Mdot
.666 .05922 Mdot
.666 .05948 Mdot
.666 .05994 Mdot
.666 .05996 Mdot
.666 .06037 Mdot
.666 .06073 Mdot
.666 .06077 Mdot
.666 .0608 Mdot
.666 .06105 Mdot
.666 .06131 Mdot
.666 .06137 Mdot
.666 .06143 Mdot
.666 .06177 Mdot
.666 .0619 Mdot
.666 .063 Mdot
.666 .06301 Mdot
.666 .06302 Mdot
.666 .06305 Mdot
.666 .06331 Mdot
.666 .06447 Mdot
.666 .06471 Mdot
.666 .06524 Mdot
.666 .0653 Mdot
.666 .06564 Mdot
.666 .06581 Mdot
.666 .06599 Mdot
.666 .06612 Mdot
.666 .0667 Mdot
.666 .06716 Mdot
.666 .06728 Mdot
.666 .06746 Mdot
.666 .06865 Mdot
.666 .0687 Mdot
.666 .06887 Mdot
.666 .06902 Mdot
.666 .06921 Mdot
.666 .06929 Mdot
.666 .06967 Mdot
.666 .06991 Mdot
.666 .07 Mdot
.666 .0704 Mdot
.666 .07102 Mdot
.666 .07119 Mdot
.666 .07132 Mdot
.666 .07176 Mdot
.666 .0723 Mdot
.666 .0723 Mdot
.666 .07324 Mdot
.666 .07389 Mdot
.666 .074 Mdot
.666 .07435 Mdot
.666 .07496 Mdot
.666 .07498 Mdot
.666 .07514 Mdot
.666 .07552 Mdot
.666 .076 Mdot
.666 .07605 Mdot
.666 .0761 Mdot
.666 .07644 Mdot
.666 .07678 Mdot
.666 .07679 Mdot
.666 .07686 Mdot
.666 .07694 Mdot
.666 .07718 Mdot
.666 .07731 Mdot
.666 .0774 Mdot
.666 .0774 Mdot
.666 .07755 Mdot
.666 .07757 Mdot
.666 .07903 Mdot
.666 .07905 Mdot
.666 .07905 Mdot
.666 .0791 Mdot
.666 .07944 Mdot
.666 .08003 Mdot
.666 .08043 Mdot
.666 .08099 Mdot
.666 .08131 Mdot
.666 .08201 Mdot
.666 .08209 Mdot
.666 .08254 Mdot
.666 .08257 Mdot
.666 .08263 Mdot
.666 .08277 Mdot
.666 .08302 Mdot
.666 .08307 Mdot
.666 .08318 Mdot
.666 .08318 Mdot
.666 .08377 Mdot
.666 .08395 Mdot
.666 .08457 Mdot
.666 .08473 Mdot
.666 .08497 Mdot
.666 .08524 Mdot
.666 .08558 Mdot
.666 .08593 Mdot
.666 .0865 Mdot
.666 .08656 Mdot
.666 .08662 Mdot
.666 .08686 Mdot
.666 .08698 Mdot
.666 .08705 Mdot
.666 .08716 Mdot
.666 .08723 Mdot
.666 .08731 Mdot
.666 .08741 Mdot
.666 .08791 Mdot
.666 .08798 Mdot
.666 .08823 Mdot
.666 .0883 Mdot
.666 .08836 Mdot
.666 .08845 Mdot
.666 .08851 Mdot
.666 .08889 Mdot
.666 .08972 Mdot
.666 .08994 Mdot
.666 .09011 Mdot
.666 .0907 Mdot
.666 .09142 Mdot
.666 .09142 Mdot
.666 .09228 Mdot
.666 .09267 Mdot
.666 .09349 Mdot
.666 .09353 Mdot
.666 .09368 Mdot
.666 .09414 Mdot
.666 .09419 Mdot
.666 .09442 Mdot
.666 .09496 Mdot
.666 .09499 Mdot
.666 .0952 Mdot
.666 .09571 Mdot
.666 .09635 Mdot
.666 .09642 Mdot
.666 .09646 Mdot
.666 .09648 Mdot
.666 .09693 Mdot
.666 .09738 Mdot
.666 .09739 Mdot
.666 .09747 Mdot
.666 .09749 Mdot
.666 .0976 Mdot
.666 .09792 Mdot
.666 .09809 Mdot
.666 .09821 Mdot
.666 .09822 Mdot
.666 .09841 Mdot
.666 .09843 Mdot
.666 .09934 Mdot
.666 .09946 Mdot
.666 .0995 Mdot
.666 .09987 Mdot
.666 .10005 Mdot
.666 .10039 Mdot
.666 .10041 Mdot
.666 .10041 Mdot
.666 .10048 Mdot
.666 .10082 Mdot
.666 .10094 Mdot
.666 .10159 Mdot
.666 .10171 Mdot
.666 .10179 Mdot
.666 .10224 Mdot
.666 .10241 Mdot
.666 .103 Mdot
.666 .10342 Mdot
.666 .10436 Mdot
.666 .10446 Mdot
.666 .10506 Mdot
.666 .10509 Mdot
.666 .10514 Mdot
.666 .10518 Mdot
.666 .1052 Mdot
.666 .10536 Mdot
.666 .1057 Mdot
.666 .10576 Mdot
.666 .10591 Mdot
.666 .10592 Mdot
.666 .10605 Mdot
.666 .1067 Mdot
.666 .10673 Mdot
.666 .10694 Mdot
.666 .10717 Mdot
.666 .10776 Mdot
.666 .10798 Mdot
.666 .10829 Mdot
.666 .10834 Mdot
.666 .10865 Mdot
.666 .10911 Mdot
.666 .10957 Mdot
.666 .10972 Mdot
.666 .11033 Mdot
.666 .11042 Mdot
.666 .11049 Mdot
.666 .11064 Mdot
.666 .11081 Mdot
.666 .11098 Mdot
.666 .11106 Mdot
.666 .11122 Mdot
.666 .1113 Mdot
.666 .11141 Mdot
.666 .11154 Mdot
.666 .11221 Mdot
.666 .11231 Mdot
.666 .11264 Mdot
.666 .11274 Mdot
.666 .11281 Mdot
.666 .11292 Mdot
.666 .11301 Mdot
.666 .11352 Mdot
.666 .11462 Mdot
.666 .11491 Mdot
.666 .11514 Mdot
.666 .11593 Mdot
.666 .11631 Mdot
.666 .11688 Mdot
.666 .11689 Mdot
.666 .11804 Mdot
.666 .11854 Mdot
.666 .11964 Mdot
.666 .1197 Mdot
.666 .1199 Mdot
.666 .12051 Mdot
.666 .12057 Mdot
.666 .12088 Mdot
.666 .12151 Mdot
.666 .1216 Mdot
.666 .12164 Mdot
.666 .12193 Mdot
.666 .12207 Mdot
.666 .1226 Mdot
.666 .12306 Mdot
.666 .12345 Mdot
.666 .12354 Mdot
.666 .12357 Mdot
.666 .1236 Mdot
.666 .12363 Mdot
.666 .12422 Mdot
.666 .12432 Mdot
.666 .12483 Mdot
.666 .12484 Mdot
.666 .12495 Mdot
.666 .12497 Mdot
.666 .12512 Mdot
.666 .12547 Mdot
.666 .12555 Mdot
.666 .12563 Mdot
.666 .12577 Mdot
.666 .12588 Mdot
.666 .12592 Mdot
.666 .12594 Mdot
.666 .12612 Mdot
.666 .1262 Mdot
.666 .12623 Mdot
.666 .12625 Mdot
.666 .12715 Mdot
.666 .12743 Mdot
.666 .1276 Mdot
.666 .12765 Mdot
.666 .12814 Mdot
.666 .12838 Mdot
.666 .12883 Mdot
.666 .12886 Mdot
.666 .12887 Mdot
.666 .12895 Mdot
.666 .129 Mdot
.666 .12918 Mdot
.666 .12936 Mdot
.666 .12941 Mdot
.666 .12956 Mdot
.666 .13021 Mdot
.666 .13023 Mdot
.666 .13043 Mdot
.666 .13059 Mdot
.666 .13069 Mdot
.666 .13097 Mdot
.666 .1313 Mdot
.666 .13152 Mdot
.666 .1323 Mdot
.666 .13288 Mdot
.666 .13412 Mdot
.666 .13425 Mdot
.666 .13448 Mdot
.666 .13461 Mdot
.666 .13479 Mdot
.666 .13506 Mdot
.666 .1351 Mdot
.666 .13516 Mdot
.666 .13521 Mdot
.666 .13524 Mdot
.666 .13546 Mdot
.666 .1359 Mdot
.666 .13595 Mdot
.666 .13599 Mdot
.666 .13619 Mdot
.666 .13619 Mdot
.666 .13637 Mdot
.666 .13721 Mdot
.666 .13724 Mdot
.666 .13728 Mdot
.666 .13756 Mdot
.666 .13786 Mdot
.666 .13865 Mdot
.666 .13894 Mdot
.666 .13936 Mdot
.666 .13942 Mdot
.666 .13984 Mdot
.666 .14045 Mdot
.666 .14053 Mdot
.666 .14106 Mdot
.666 .14127 Mdot
.666 .14173 Mdot
.666 .14208 Mdot
.666 .14219 Mdot
.666 .14229 Mdot
.666 .14249 Mdot
.666 .14271 Mdot
.666 .14293 Mdot
.666 .14305 Mdot
.666 .14326 Mdot
.666 .14337 Mdot
.666 .14349 Mdot
.666 .14351 Mdot
.666 .14369 Mdot
.666 .14377 Mdot
.666 .14458 Mdot
.666 .14471 Mdot
.666 .14515 Mdot
.666 .14528 Mdot
.666 .14538 Mdot
.666 .14553 Mdot
.666 .14564 Mdot
.666 .14632 Mdot
.666 .14778 Mdot
.666 .14817 Mdot
.666 .14848 Mdot
.666 .14953 Mdot
.666 .15004 Mdot
.666 .1508 Mdot
.666 .15081 Mdot
.666 .15234 Mdot
.666 .15302 Mdot
.666 .15447 Mdot
.666 .15455 Mdot
.666 .15482 Mdot
.666 .15564 Mdot
.666 .15571 Mdot
.666 .15612 Mdot
.666 .15697 Mdot
.666 .15708 Mdot
.666 .15714 Mdot
.666 .15752 Mdot
.666 .15772 Mdot
.666 .15842 Mdot
.666 .15903 Mdot
.666 .15955 Mdot
.666 .15967 Mdot
.666 .15971 Mdot
.666 .15975 Mdot
.666 .15979 Mdot
.666 .16058 Mdot
.666 .16071 Mdot
.666 .16139 Mdot
.666 .16141 Mdot
.666 .16154 Mdot
.666 .16158 Mdot
.666 .16177 Mdot
.666 .16223 Mdot
.666 .16234 Mdot
.666 .16245 Mdot
.666 .16263 Mdot
.666 .16279 Mdot
.666 .16285 Mdot
.666 .16287 Mdot
.666 .16311 Mdot
.666 .16321 Mdot
.666 .16325 Mdot
.666 .16327 Mdot
.666 .16447 Mdot
.666 .16485 Mdot
.666 .16508 Mdot
.666 .16515 Mdot
.666 .1658 Mdot
.666 .16612 Mdot
.666 .16671 Mdot
.666 .16675 Mdot
.666 .16677 Mdot
.666 .16688 Mdot
.666 .16694 Mdot
.666 .16719 Mdot
.666 .16743 Mdot
.666 .16749 Mdot
.666 .16769 Mdot
.666 .16856 Mdot
.666 .16858 Mdot
.666 .16885 Mdot
.666 .16906 Mdot
.666 .1692 Mdot
.666 .16957 Mdot
.666 .17001 Mdot
.666 .1703 Mdot
.666 .17211 Mdot
.666 .17376 Mdot
.666 .17394 Mdot
.666 .17425 Mdot
.666 .17441 Mdot
.666 .17465 Mdot
.666 .17501 Mdot
.666 .17507 Mdot
.666 .17515 Mdot
.666 .17522 Mdot
.666 .17526 Mdot
.666 .17555 Mdot
.666 .17614 Mdot
.666 .17619 Mdot
.666 .17625 Mdot
.666 .17652 Mdot
.666 .17653 Mdot
.666 .17676 Mdot
.666 .17788 Mdot
.666 .17792 Mdot
.666 .17797 Mdot
.666 .17834 Mdot
.666 .17874 Mdot
.666 .1798 Mdot
.666 .18018 Mdot
.666 .18074 Mdot
.666 .18083 Mdot
.666 .18138 Mdot
.666 .18219 Mdot
.666 .18219 Mdot
.666 .1823 Mdot
.666 .18301 Mdot
.666 .18328 Mdot
.666 .1839 Mdot
.666 .18436 Mdot
.666 .18451 Mdot
.666 .18464 Mdot
.666 .18491 Mdot
.666 .1852 Mdot
.666 .1855 Mdot
.666 .18566 Mdot
.666 .18593 Mdot
.666 .18608 Mdot
.666 .18624 Mdot
.666 .18627 Mdot
.666 .18651 Mdot
.666 .18661 Mdot
.666 .18769 Mdot
.666 .18787 Mdot
.666 .18846 Mdot
.666 .18863 Mdot
.666 .18876 Mdot
.666 .18896 Mdot
.666 .18911 Mdot
.666 .19001 Mdot
.666 .19196 Mdot
.666 .19248 Mdot
.666 .19289 Mdot
.666 .19429 Mdot
.666 .19497 Mdot
.666 .19599 Mdot
.666 .196 Mdot
.666 .19803 Mdot
.666 .19893 Mdot
.666 .20087 Mdot
.666 .20098 Mdot
.666 .20134 Mdot
.666 .20242 Mdot
.666 .20253 Mdot
.666 .20307 Mdot
.666 .20419 Mdot
.666 .20435 Mdot
.666 .20443 Mdot
.666 .20493 Mdot
.666 .20519 Mdot
.666 .20613 Mdot
.666 .20694 Mdot
.666 .20763 Mdot
.666 .2078 Mdot
.666 .20785 Mdot
.666 .2079 Mdot
.666 .20796 Mdot
.666 .209 Mdot
.666 .20917 Mdot
.666 .21008 Mdot
.666 .21011 Mdot
.666 .21029 Mdot
.666 .21034 Mdot
.666 .21059 Mdot
.666 .21121 Mdot
.666 .21136 Mdot
.666 .2115 Mdot
.666 .21174 Mdot
.666 .21195 Mdot
.666 .21203 Mdot
.666 .21205 Mdot
.666 .21237 Mdot
.666 .21251 Mdot
.666 .21257 Mdot
.666 .21259 Mdot
.666 .21419 Mdot
.666 .2147 Mdot
.666 .215 Mdot
.666 .21509 Mdot
.666 .21596 Mdot
.666 .21639 Mdot
.666 .21718 Mdot
.666 .21723 Mdot
.666 .21725 Mdot
.666 .2174 Mdot
.666 .21748 Mdot
.666 .21781 Mdot
.666 .21813 Mdot
.666 .21821 Mdot
.666 .21848 Mdot
.666 .21963 Mdot
.666 .21966 Mdot
.666 .22002 Mdot
.666 .22031 Mdot
.666 .22049 Mdot
.666 .22099 Mdot
.666 .22157 Mdot
.666 .22196 Mdot
.666 .22436 Mdot
.666 .22656 Mdot
.666 .2268 Mdot
.666 .22721 Mdot
.666 .22743 Mdot
.666 .22775 Mdot
.666 .22823 Mdot
.666 .2283 Mdot
.666 .22841 Mdot
.666 .22851 Mdot
.666 .22856 Mdot
.666 .22894 Mdot
.666 .22973 Mdot
.666 .2298 Mdot
.666 .22988 Mdot
.666 .23024 Mdot
.666 .23025 Mdot
.666 .23056 Mdot
.666 .23205 Mdot
.666 .2321 Mdot
.666 .23218 Mdot
.666 .23267 Mdot
.666 .2332 Mdot
.666 .23461 Mdot
.666 .23511 Mdot
.666 .23586 Mdot
.666 .23598 Mdot
.666 .23671 Mdot
.666 .23779 Mdot
.666 .2378 Mdot
.666 .23794 Mdot
.666 .23888 Mdot
.666 .23924 Mdot
.666 .24007 Mdot
.666 .24068 Mdot
.666 .24088 Mdot
.666 .24106 Mdot
.666 .24141 Mdot
.666 .2418 Mdot
.666 .24221 Mdot
.666 .24241 Mdot
.666 .24278 Mdot
.666 .24297 Mdot
.666 .24319 Mdot
.666 .24323 Mdot
.666 .24354 Mdot
.666 .24369 Mdot
.666 .24512 Mdot
.666 .24535 Mdot
.666 .24614 Mdot
.666 .24636 Mdot
.666 .24654 Mdot
.666 .24681 Mdot
.666 .24701 Mdot
.666 .24821 Mdot
.666 .25081 Mdot
.666 .2515 Mdot
.666 .25204 Mdot
.666 .2539 Mdot
.666 .25482 Mdot
.666 .25617 Mdot
.666 .25618 Mdot
.666 .25889 Mdot
.666 .26009 Mdot
.666 .26267 Mdot
.666 .26281 Mdot
.666 .26329 Mdot
.666 .26474 Mdot
.666 .26488 Mdot
.666 .2656 Mdot
.666 .2671 Mdot
.666 .26731 Mdot
.666 .26742 Mdot
.666 .26809 Mdot
.666 .26843 Mdot
.666 .26968 Mdot
.666 .27076 Mdot
.666 .27168 Mdot
.666 .27191 Mdot
.666 .27198 Mdot
.666 .27203 Mdot
.666 .27211 Mdot
.666 .27351 Mdot
.666 .27374 Mdot
.666 .27494 Mdot
.666 .27498 Mdot
.666 .27522 Mdot
.666 .27529 Mdot
.666 .27562 Mdot
.666 .27645 Mdot
.666 .27664 Mdot
.666 .27683 Mdot
.666 .27716 Mdot
.666 .27743 Mdot
.666 .27753 Mdot
.666 .27757 Mdot
.666 .27799 Mdot
.666 .27817 Mdot
.666 .27825 Mdot
.666 .27829 Mdot
.666 .28042 Mdot
.666 .28109 Mdot
.666 .28149 Mdot
.666 .28162 Mdot
.666 .28277 Mdot
.666 .28334 Mdot
.666 .28439 Mdot
.666 .28446 Mdot
.666 .28449 Mdot
.666 .28469 Mdot
.666 .2848 Mdot
.666 .28523 Mdot
.666 .28566 Mdot
.666 .28577 Mdot
.666 .28612 Mdot
.666 .28766 Mdot
.666 .2877 Mdot
.666 .28818 Mdot
.666 .28856 Mdot
.666 .28881 Mdot
.666 .28947 Mdot
.666 .29025 Mdot
.666 .29076 Mdot
.666 .29396 Mdot
.666 .29689 Mdot
.666 .29721 Mdot
.666 .29776 Mdot
.666 .29805 Mdot
.666 .29847 Mdot
.666 .29912 Mdot
.666 .29921 Mdot
.666 .29935 Mdot
.666 .29949 Mdot
.666 .29956 Mdot
.666 .30007 Mdot
.666 .30111 Mdot
.666 .30121 Mdot
.666 .30132 Mdot
.666 .30179 Mdot
.666 .3018 Mdot
.666 .30222 Mdot
.666 .3042 Mdot
.666 .30427 Mdot
.666 .30437 Mdot
.666 .30503 Mdot
.666 .30574 Mdot
.666 .30761 Mdot
.666 .30829 Mdot
.666 .30928 Mdot
.666 .30944 Mdot
.666 .31042 Mdot
.666 .31185 Mdot
.666 .31186 Mdot
.666 .31204 Mdot
.666 .3133 Mdot
.666 .31379 Mdot
.666 .31489 Mdot
.666 .3157 Mdot
.666 .31597 Mdot
.666 .31621 Mdot
.666 .31668 Mdot
.666 .3172 Mdot
.666 .31773 Mdot
.666 .318 Mdot
.666 .31849 Mdot
.666 .31875 Mdot
.666 .31904 Mdot
.666 .3191 Mdot
.666 .31951 Mdot
.666 .3197 Mdot
.666 .32162 Mdot
.666 .32192 Mdot
.666 .32297 Mdot
.666 .32327 Mdot
.666 .3235 Mdot
.666 .32386 Mdot
.666 .32413 Mdot
.666 .32574 Mdot
.666 .32919 Mdot
.666 .33011 Mdot
.666 .33083 Mdot
.666 .33331 Mdot
.666 .33453 Mdot
.666 .33633 Mdot
.666 .33635 Mdot
.666 .33995 Mdot
.666 .34156 Mdot
.666 .345 Mdot
.666 .34518 Mdot
.666 .34582 Mdot
.666 .34775 Mdot
.666 .34793 Mdot
.666 .34889 Mdot
.666 .35089 Mdot
.666 .35116 Mdot
.666 .35131 Mdot
.666 .3522 Mdot
.666 .35267 Mdot
.666 .35433 Mdot
.666 .35576 Mdot
.666 .357 Mdot
.666 .35729 Mdot
.666 .35739 Mdot
.666 .35746 Mdot
.666 .35757 Mdot
.666 .35943 Mdot
.666 .35973 Mdot
.666 .36134 Mdot
.666 .36138 Mdot
.666 .36171 Mdot
.666 .3618 Mdot
.666 .36224 Mdot
.666 .36334 Mdot
.666 .3636 Mdot
.666 .36386 Mdot
.666 .36429 Mdot
.666 .36465 Mdot
.666 .36479 Mdot
.666 .36483 Mdot
.666 .3654 Mdot
.666 .36564 Mdot
.666 .36575 Mdot
.666 .3658 Mdot
.666 .36863 Mdot
.666 .36953 Mdot
.666 .37006 Mdot
.666 .37023 Mdot
.666 .37176 Mdot
.666 .37253 Mdot
.666 .37393 Mdot
.666 .37402 Mdot
.666 .37405 Mdot
.666 .37433 Mdot
.666 .37446 Mdot
.666 .37504 Mdot
.666 .37562 Mdot
.666 .37577 Mdot
.666 .37623 Mdot
.666 .37828 Mdot
.666 .37833 Mdot
.666 .37897 Mdot
.666 .37948 Mdot
.666 .3798 Mdot
.666 .38069 Mdot
.666 .38172 Mdot
.666 .38241 Mdot
.666 .38667 Mdot
.666 .39057 Mdot
.666 .391 Mdot
.666 .39173 Mdot
.666 .39212 Mdot
.666 .39268 Mdot
.666 .39354 Mdot
.666 .39366 Mdot
.666 .39385 Mdot
.666 .39403 Mdot
.666 .39413 Mdot
.666 .3948 Mdot
.666 .39619 Mdot
.666 .39633 Mdot
.666 .39647 Mdot
.666 .3971 Mdot
.666 .39712 Mdot
.666 .39768 Mdot
.666 .40031 Mdot
.666 .40041 Mdot
.666 .40054 Mdot
.666 .40141 Mdot
.666 .40236 Mdot
.666 .40485 Mdot
.666 .40575 Mdot
.666 .40707 Mdot
.666 .40728 Mdot
.668 .01605 Mdot
.668 .01649 Mdot
.668 .01686 Mdot
.668 .01709 Mdot
.668 .01758 Mdot
.668 .01789 Mdot
.668 .01854 Mdot
.668 .01895 Mdot
.668 .01939 Mdot
.668 .01982 Mdot
.668 .02038 Mdot
.668 .02097 Mdot
.668 .02154 Mdot
.668 .02228 Mdot
.668 .02307 Mdot
.668 .02356 Mdot
.668 .02361 Mdot
.668 .02383 Mdot
.668 .02482 Mdot
.668 .02585 Mdot
.668 .02587 Mdot
.668 .02654 Mdot
.668 .02659 Mdot
.668 .02689 Mdot
.668 .02721 Mdot
.668 .0276 Mdot
.668 .02801 Mdot
.668 .02822 Mdot
.668 .02959 Mdot
.668 .02962 Mdot
.668 .03022 Mdot
.668 .03051 Mdot
.668 .03058 Mdot
.668 .03098 Mdot
.668 .0314 Mdot
.668 .03194 Mdot
.668 .03212 Mdot
.668 .03221 Mdot
.668 .03248 Mdot
.668 .03249 Mdot
.668 .03276 Mdot
.668 .03295 Mdot
.668 .03389 Mdot
.668 .03455 Mdot
.668 .03458 Mdot
.668 .03462 Mdot
.668 .03463 Mdot
.668 .03544 Mdot
.668 .03581 Mdot
.668 .03592 Mdot
.668 .03645 Mdot
.668 .03648 Mdot
.668 .03701 Mdot
.668 .03714 Mdot
.668 .03723 Mdot
.668 .03748 Mdot
.668 .03762 Mdot
.668 .03772 Mdot
.668 .03796 Mdot
.668 .03809 Mdot
.668 .03845 Mdot
.668 .03847 Mdot
.668 .03882 Mdot
.668 .03882 Mdot
.668 .03907 Mdot
.668 .03923 Mdot
.668 .03933 Mdot
.668 .03997 Mdot
.668 .04005 Mdot
.668 .04033 Mdot
.668 .04058 Mdot
.668 .04084 Mdot
.668 .04122 Mdot
.668 .04126 Mdot
.668 .04131 Mdot
.668 .04132 Mdot
.668 .04202 Mdot
.668 .04221 Mdot
.668 .0424 Mdot
.668 .04279 Mdot
.668 .0429 Mdot
.668 .04304 Mdot
.668 .04312 Mdot
.668 .04358 Mdot
.668 .04376 Mdot
.668 .04379 Mdot
.668 .04419 Mdot
.668 .0445 Mdot
.668 .04467 Mdot
.668 .0448 Mdot
.668 .04513 Mdot
.668 .04532 Mdot
.668 .04545 Mdot
.668 .04577 Mdot
.668 .04594 Mdot
.668 .04642 Mdot
.668 .04645 Mdot
.668 .04692 Mdot
.668 .04692 Mdot
.668 .04726 Mdot
.668 .04746 Mdot
.668 .04758 Mdot
.668 .0476 Mdot
.668 .04845 Mdot
.668 .04856 Mdot
.668 .04893 Mdot
.668 .04927 Mdot
.668 .0496 Mdot
.668 .04962 Mdot
.668 .04995 Mdot
.668 .05012 Mdot
.668 .05018 Mdot
.668 .05024 Mdot
.668 .05026 Mdot
.668 .05068 Mdot
.668 .05108 Mdot
.668 .05119 Mdot
.668 .05144 Mdot
.668 .0517 Mdot
.668 .05223 Mdot
.668 .05237 Mdot
.668 .05256 Mdot
.668 .05267 Mdot
.668 .05297 Mdot
.668 .05328 Mdot
.668 .05351 Mdot
.668 .05356 Mdot
.668 .0541 Mdot
.668 .05451 Mdot
.668 .05473 Mdot
.668 .05491 Mdot
.668 .05495 Mdot
.668 .05535 Mdot
.668 .0556 Mdot
.668 .05578 Mdot
.668 .05613 Mdot
.668 .05621 Mdot
.668 .05633 Mdot
.668 .0564 Mdot
.668 .05643 Mdot
.668 .05707 Mdot
.668 .05711 Mdot
.668 .05774 Mdot
.668 .05774 Mdot
.668 .05812 Mdot
.668 .05819 Mdot
.668 .05846 Mdot
.668 .05847 Mdot
.668 .05862 Mdot
.668 .05864 Mdot
.668 .05978 Mdot
.668 .05993 Mdot
.668 .06022 Mdot
.668 .06043 Mdot
.668 .06088 Mdot
.668 .06099 Mdot
.668 .06105 Mdot
.668 .06132 Mdot
.668 .06135 Mdot
.668 .06179 Mdot
.668 .06202 Mdot
.668 .06209 Mdot
.668 .06218 Mdot
.668 .0622 Mdot
.668 .06268 Mdot
.668 .06277 Mdot
.668 .06319 Mdot
.668 .0633 Mdot
.668 .06345 Mdot
.668 .06367 Mdot
.668 .06374 Mdot
.668 .06378 Mdot
.668 .06412 Mdot
.668 .06483 Mdot
.668 .06503 Mdot
.668 .06515 Mdot
.668 .06527 Mdot
.668 .06533 Mdot
.668 .06542 Mdot
.668 .06555 Mdot
.668 .06583 Mdot
.668 .06624 Mdot
.668 .06655 Mdot
.668 .06661 Mdot
.668 .06733 Mdot
.668 .06788 Mdot
.668 .06818 Mdot
.668 .06841 Mdot
.668 .06846 Mdot
.668 .069 Mdot
.668 .06924 Mdot
.668 .06932 Mdot
.668 .06933 Mdot
.668 .06958 Mdot
.668 .07005 Mdot
.668 .07012 Mdot
.668 .07015 Mdot
.668 .07031 Mdot
.668 .07041 Mdot
.668 .07045 Mdot
.668 .0713 Mdot
.668 .07135 Mdot
.668 .07219 Mdot
.668 .0722 Mdot
.668 .0727 Mdot
.668 .0728 Mdot
.668 .07281 Mdot
.668 .07316 Mdot
.668 .07317 Mdot
.668 .07338 Mdot
.668 .0734 Mdot
.668 .07493 Mdot
.668 .07512 Mdot
.668 .07551 Mdot
.668 .07579 Mdot
.668 .07639 Mdot
.668 .07654 Mdot
.668 .07662 Mdot
.668 .07698 Mdot
.668 .07702 Mdot
.668 .07712 Mdot
.668 .07761 Mdot
.668 .07791 Mdot
.668 .07792 Mdot
.668 .07801 Mdot
.668 .07813 Mdot
.668 .07815 Mdot
.668 .07861 Mdot
.668 .07879 Mdot
.668 .07891 Mdot
.668 .07948 Mdot
.668 .07962 Mdot
.668 .07982 Mdot
.668 .08011 Mdot
.668 .08021 Mdot
.668 .08027 Mdot
.668 .08073 Mdot
.668 .08167 Mdot
.668 .08193 Mdot
.668 .08209 Mdot
.668 .08226 Mdot
.668 .08234 Mdot
.668 .08245 Mdot
.668 .08263 Mdot
.668 .083 Mdot
.668 .08355 Mdot
.668 .08368 Mdot
.668 .08376 Mdot
.668 .08396 Mdot
.668 .08405 Mdot
.668 .08456 Mdot
.668 .08501 Mdot
.668 .08575 Mdot
.668 .08614 Mdot
.668 .08645 Mdot
.668 .08652 Mdot
.668 .08724 Mdot
.668 .08756 Mdot
.668 .08767 Mdot
.668 .08768 Mdot
.668 .08801 Mdot
.668 .08821 Mdot
.668 .08842 Mdot
.668 .08864 Mdot
.668 .08873 Mdot
.668 .08878 Mdot
.668 .08899 Mdot
.668 .08912 Mdot
.668 .08918 Mdot
.668 .08937 Mdot
.668 .08996 Mdot
.668 .09032 Mdot
.668 .09038 Mdot
.668 .09051 Mdot
.668 .0915 Mdot
.668 .09152 Mdot
.668 .09188 Mdot
.668 .09219 Mdot
.668 .09232 Mdot
.668 .09233 Mdot
.668 .09262 Mdot
.668 .09271 Mdot
.668 .09279 Mdot
.668 .09281 Mdot
.668 .09305 Mdot
.668 .09308 Mdot
.668 .09312 Mdot
.668 .09377 Mdot
.668 .09379 Mdot
.668 .09516 Mdot
.668 .09542 Mdot
.668 .09593 Mdot
.668 .09631 Mdot
.668 .09711 Mdot
.668 .09731 Mdot
.668 .09742 Mdot
.668 .09751 Mdot
.668 .0979 Mdot
.668 .09796 Mdot
.668 .09809 Mdot
.668 .09874 Mdot
.668 .09914 Mdot
.668 .09915 Mdot
.668 .09928 Mdot
.668 .09944 Mdot
.668 .09947 Mdot
.668 .09977 Mdot
.668 .09983 Mdot
.668 .10008 Mdot
.668 .10032 Mdot
.668 .10048 Mdot
.668 .10056 Mdot
.668 .10124 Mdot
.668 .10143 Mdot
.668 .10145 Mdot
.668 .10164 Mdot
.668 .1017 Mdot
.668 .10209 Mdot
.668 .10222 Mdot
.668 .1023 Mdot
.668 .10291 Mdot
.668 .10336 Mdot
.668 .10339 Mdot
.668 .10369 Mdot
.668 .10372 Mdot
.668 .10417 Mdot
.668 .10452 Mdot
.668 .10473 Mdot
.668 .10488 Mdot
.668 .10495 Mdot
.668 .10506 Mdot
.668 .10511 Mdot
.668 .10522 Mdot
.668 .10544 Mdot
.668 .10595 Mdot
.668 .10648 Mdot
.668 .10668 Mdot
.668 .10685 Mdot
.668 .10696 Mdot
.668 .10723 Mdot
.668 .10735 Mdot
.668 .10738 Mdot
.668 .10784 Mdot
.668 .10803 Mdot
.668 .10862 Mdot
.668 .10961 Mdot
.668 .11014 Mdot
.668 .11055 Mdot
.668 .11065 Mdot
.668 .11161 Mdot
.668 .1117 Mdot
.668 .11181 Mdot
.668 .11203 Mdot
.668 .11219 Mdot
.668 .1122 Mdot
.668 .11264 Mdot
.668 .11279 Mdot
.668 .11287 Mdot
.668 .11291 Mdot
.668 .11319 Mdot
.668 .11348 Mdot
.668 .1136 Mdot
.668 .11366 Mdot
.668 .11394 Mdot
.668 .11398 Mdot
.668 .11412 Mdot
.668 .1142 Mdot
.668 .11431 Mdot
.668 .11445 Mdot
.668 .11525 Mdot
.668 .11572 Mdot
.668 .1158 Mdot
.668 .11598 Mdot
.668 .11651 Mdot
.668 .11698 Mdot
.668 .11726 Mdot
.668 .1173 Mdot
.668 .11732 Mdot
.668 .11772 Mdot
.668 .1178 Mdot
.668 .11822 Mdot
.668 .1184 Mdot
.668 .11841 Mdot
.668 .11879 Mdot
.668 .11891 Mdot
.668 .11903 Mdot
.668 .11904 Mdot
.668 .11937 Mdot
.668 .11942 Mdot
.668 .11947 Mdot
.668 .12034 Mdot
.668 .12036 Mdot
.668 .12054 Mdot
.668 .12118 Mdot
.668 .12219 Mdot
.668 .12237 Mdot
.668 .12254 Mdot
.668 .12322 Mdot
.668 .12373 Mdot
.668 .12375 Mdot
.668 .12394 Mdot
.668 .12479 Mdot
.668 .12484 Mdot
.668 .12507 Mdot
.668 .12521 Mdot
.668 .12533 Mdot
.668 .12565 Mdot
.668 .12583 Mdot
.668 .12585 Mdot
.668 .12593 Mdot
.668 .1261 Mdot
.668 .1261 Mdot
.668 .12698 Mdot
.668 .12751 Mdot
.668 .12752 Mdot
.668 .12769 Mdot
.668 .1279 Mdot
.668 .12795 Mdot
.668 .12835 Mdot
.668 .12836 Mdot
.668 .12843 Mdot
.668 .12844 Mdot
.668 .12871 Mdot
.668 .12876 Mdot
.668 .12909 Mdot
.668 .1293 Mdot
.668 .1294 Mdot
.668 .13031 Mdot
.668 .13034 Mdot
.668 .13057 Mdot
.668 .13059 Mdot
.668 .13085 Mdot
.668 .13092 Mdot
.668 .13144 Mdot
.668 .13155 Mdot
.668 .13162 Mdot
.668 .13173 Mdot
.668 .13239 Mdot
.668 .13254 Mdot
.668 .13282 Mdot
.668 .13314 Mdot
.668 .13319 Mdot
.668 .1334 Mdot
.668 .13359 Mdot
.668 .13363 Mdot
.668 .1337 Mdot
.668 .13423 Mdot
.668 .13424 Mdot
.668 .13431 Mdot
.668 .13469 Mdot
.668 .13498 Mdot
.668 .13517 Mdot
.668 .13527 Mdot
.668 .13541 Mdot
.668 .13548 Mdot
.668 .13561 Mdot
.668 .13562 Mdot
.668 .13593 Mdot
.668 .1366 Mdot
.668 .13731 Mdot
.668 .13758 Mdot
.668 .1378 Mdot
.668 .13795 Mdot
.668 .13832 Mdot
.668 .13847 Mdot
.668 .13847 Mdot
.668 .13852 Mdot
.668 .13913 Mdot
.668 .13938 Mdot
.668 .14018 Mdot
.668 .14149 Mdot
.668 .1415 Mdot
.668 .1422 Mdot
.668 .14263 Mdot
.668 .14276 Mdot
.668 .14288 Mdot
.668 .14358 Mdot
.668 .14417 Mdot
.668 .1442 Mdot
.668 .14429 Mdot
.668 .14443 Mdot
.668 .14473 Mdot
.668 .14494 Mdot
.668 .14496 Mdot
.668 .14554 Mdot
.668 .14575 Mdot
.668 .14578 Mdot
.668 .14586 Mdot
.668 .1459 Mdot
.668 .14628 Mdot
.668 .1464 Mdot
.668 .14644 Mdot
.668 .14664 Mdot
.668 .14666 Mdot
.668 .14683 Mdot
.668 .14691 Mdot
.668 .14728 Mdot
.668 .14734 Mdot
.668 .14752 Mdot
.668 .14763 Mdot
.668 .14777 Mdot
.668 .14796 Mdot
.668 .14903 Mdot
.668 .14966 Mdot
.668 .14977 Mdot
.668 .15 Mdot
.668 .15012 Mdot
.668 .15072 Mdot
.668 .15134 Mdot
.668 .15171 Mdot
.668 .15177 Mdot
.668 .1518 Mdot
.668 .15233 Mdot
.668 .15244 Mdot
.668 .15299 Mdot
.668 .15324 Mdot
.668 .15325 Mdot
.668 .15376 Mdot
.668 .15393 Mdot
.668 .15407 Mdot
.668 .1541 Mdot
.668 .15454 Mdot
.668 .1546 Mdot
.668 .15467 Mdot
.668 .15582 Mdot
.668 .15585 Mdot
.668 .1561 Mdot
.668 .15695 Mdot
.668 .1583 Mdot
.668 .15855 Mdot
.668 .15877 Mdot
.668 .15968 Mdot
.668 .16036 Mdot
.668 .16038 Mdot
.668 .16063 Mdot
.668 .16178 Mdot
.668 .16185 Mdot
.668 .16214 Mdot
.668 .16233 Mdot
.668 .1625 Mdot
.668 .16293 Mdot
.668 .16316 Mdot
.668 .16319 Mdot
.668 .1633 Mdot
.668 .16353 Mdot
.668 .16353 Mdot
.668 .1647 Mdot
.668 .16541 Mdot
.668 .16543 Mdot
.668 .16566 Mdot
.668 .16593 Mdot
.668 .166 Mdot
.668 .16653 Mdot
.668 .16654 Mdot
.668 .16664 Mdot
.668 .16665 Mdot
.668 .16701 Mdot
.668 .16708 Mdot
.668 .16751 Mdot
.668 .1678 Mdot
.668 .16794 Mdot
.668 .16915 Mdot
.668 .16919 Mdot
.668 .1695 Mdot
.668 .16952 Mdot
.668 .16987 Mdot
.668 .16997 Mdot
.668 .17066 Mdot
.668 .17081 Mdot
.668 .1709 Mdot
.668 .17104 Mdot
.668 .17193 Mdot
.668 .17213 Mdot
.668 .1725 Mdot
.668 .17293 Mdot
.668 .17299 Mdot
.668 .17328 Mdot
.668 .17353 Mdot
.668 .17359 Mdot
.668 .17367 Mdot
.668 .17438 Mdot
.668 .17441 Mdot
.668 .17449 Mdot
.668 .175 Mdot
.668 .17538 Mdot
.668 .17565 Mdot
.668 .17578 Mdot
.668 .17596 Mdot
.668 .17606 Mdot
.668 .17623 Mdot
.668 .17625 Mdot
.668 .17666 Mdot
.668 .17755 Mdot
.668 .1785 Mdot
.668 .17886 Mdot
.668 .17916 Mdot
.668 .17935 Mdot
.668 .17985 Mdot
.668 .18005 Mdot
.668 .18006 Mdot
.668 .18012 Mdot
.668 .18093 Mdot
.668 .18127 Mdot
.668 .18233 Mdot
.668 .18408 Mdot
.668 .1841 Mdot
.668 .18504 Mdot
.668 .18561 Mdot
.668 .18578 Mdot
.668 .18595 Mdot
.668 .18688 Mdot
.668 .18767 Mdot
.668 .18771 Mdot
.668 .18783 Mdot
.668 .18802 Mdot
.668 .18841 Mdot
.668 .18869 Mdot
.668 .18872 Mdot
.668 .1895 Mdot
.668 .18977 Mdot
.668 .18981 Mdot
.668 .18992 Mdot
.668 .18998 Mdot
.668 .19048 Mdot
.668 .19065 Mdot
.668 .19069 Mdot
.668 .19096 Mdot
.668 .191 Mdot
.668 .19122 Mdot
.668 .19133 Mdot
.668 .19182 Mdot
.668 .1919 Mdot
.668 .19215 Mdot
.668 .19228 Mdot
.668 .19248 Mdot
.668 .19273 Mdot
.668 .19415 Mdot
.668 .195 Mdot
.668 .19515 Mdot
.668 .19545 Mdot
.668 .19562 Mdot
.668 .19642 Mdot
.668 .19724 Mdot
.668 .19774 Mdot
.668 .19782 Mdot
.668 .19785 Mdot
.668 .19857 Mdot
.668 .19872 Mdot
.668 .19945 Mdot
.668 .19978 Mdot
.668 .1998 Mdot
.668 .20049 Mdot
.668 .2007 Mdot
.668 .2009 Mdot
.668 .20093 Mdot
.668 .20152 Mdot
.668 .2016 Mdot
.668 .20169 Mdot
.668 .20324 Mdot
.668 .20327 Mdot
.668 .20361 Mdot
.668 .20474 Mdot
.668 .20654 Mdot
.668 .20688 Mdot
.668 .20717 Mdot
.668 .20839 Mdot
.668 .20929 Mdot
.668 .20933 Mdot
.668 .20966 Mdot
.668 .21119 Mdot
.668 .21128 Mdot
.668 .21168 Mdot
.668 .21193 Mdot
.668 .21216 Mdot
.668 .21273 Mdot
.668 .21304 Mdot
.668 .21308 Mdot
.668 .21322 Mdot
.668 .21353 Mdot
.668 .21353 Mdot
.668 .21509 Mdot
.668 .21604 Mdot
.668 .21607 Mdot
.668 .21637 Mdot
.668 .21674 Mdot
.668 .21683 Mdot
.668 .21755 Mdot
.668 .21756 Mdot
.668 .21769 Mdot
.668 .2177 Mdot
.668 .21818 Mdot
.668 .21828 Mdot
.668 .21885 Mdot
.668 .21923 Mdot
.668 .21942 Mdot
.668 .22104 Mdot
.668 .22109 Mdot
.668 .2215 Mdot
.668 .22154 Mdot
.668 .222 Mdot
.668 .22214 Mdot
.668 .22306 Mdot
.668 .22326 Mdot
.668 .22337 Mdot
.668 .22357 Mdot
.668 .22475 Mdot
.668 .22502 Mdot
.668 .22552 Mdot
.668 .2261 Mdot
.668 .22617 Mdot
.668 .22656 Mdot
.668 .2269 Mdot
.668 .22697 Mdot
.668 .22708 Mdot
.668 .22803 Mdot
.668 .22806 Mdot
.668 .22818 Mdot
.668 .22886 Mdot
.668 .22937 Mdot
.668 .22972 Mdot
.668 .2299 Mdot
.668 .23014 Mdot
.668 .23027 Mdot
.668 .2305 Mdot
.668 .23052 Mdot
.668 .23107 Mdot
.668 .23227 Mdot
.668 .23353 Mdot
.668 .23401 Mdot
.668 .23441 Mdot
.668 .23467 Mdot
.668 .23533 Mdot
.668 .2356 Mdot
.668 .23561 Mdot
.668 .23569 Mdot
.668 .23678 Mdot
.668 .23723 Mdot
.668 .23865 Mdot
.668 .24099 Mdot
.668 .24101 Mdot
.668 .24227 Mdot
.668 .24303 Mdot
.668 .24325 Mdot
.668 .24348 Mdot
.668 .24472 Mdot
.668 .24578 Mdot
.668 .24584 Mdot
.668 .24599 Mdot
.668 .24625 Mdot
.668 .24677 Mdot
.668 .24715 Mdot
.668 .24719 Mdot
.668 .24823 Mdot
.668 .24859 Mdot
.668 .24865 Mdot
.668 .24879 Mdot
.668 .24887 Mdot
.668 .24954 Mdot
.668 .24977 Mdot
.668 .24982 Mdot
.668 .25018 Mdot
.668 .25023 Mdot
.668 .25052 Mdot
.668 .25067 Mdot
.668 .25133 Mdot
.668 .25144 Mdot
.668 .25176 Mdot
.668 .25195 Mdot
.668 .25221 Mdot
.668 .25255 Mdot
.668 .25445 Mdot
.668 .25558 Mdot
.668 .25578 Mdot
.668 .25618 Mdot
.668 .25641 Mdot
.668 .25747 Mdot
.668 .25857 Mdot
.668 .25924 Mdot
.668 .25935 Mdot
.668 .25939 Mdot
.668 .26035 Mdot
.668 .26054 Mdot
.668 .26153 Mdot
.668 .26196 Mdot
.668 .26199 Mdot
.668 .2629 Mdot
.668 .26319 Mdot
.668 .26346 Mdot
.668 .2635 Mdot
.668 .26429 Mdot
.668 .26439 Mdot
.668 .26451 Mdot
.668 .26658 Mdot
.668 .26663 Mdot
.668 .26707 Mdot
.668 .26858 Mdot
.668 .271 Mdot
.668 .27144 Mdot
.668 .27183 Mdot
.668 .27467 Mdot
.668 .27471 Mdot
.668 .27516 Mdot
.668 .27721 Mdot
.668 .27733 Mdot
.668 .27786 Mdot
.668 .27819 Mdot
.668 .2785 Mdot
.668 .27926 Mdot
.668 .27968 Mdot
.668 .27973 Mdot
.668 .27992 Mdot
.668 .28033 Mdot
.668 .28033 Mdot
.668 .28242 Mdot
.668 .28369 Mdot
.668 .28372 Mdot
.668 .28413 Mdot
.668 .28462 Mdot
.668 .28473 Mdot
.668 .2857 Mdot
.668 .28571 Mdot
.668 .28588 Mdot
.668 .2859 Mdot
.668 .28655 Mdot
.668 .28668 Mdot
.668 .28744 Mdot
.668 .28795 Mdot
.668 .28821 Mdot
.668 .29037 Mdot
.668 .29043 Mdot
.668 .29098 Mdot
.668 .29103 Mdot
.668 .29165 Mdot
.668 .29183 Mdot
.668 .29307 Mdot
.668 .29333 Mdot
.668 .29348 Mdot
.668 .29374 Mdot
.668 .29532 Mdot
.668 .29568 Mdot
.668 .29635 Mdot
.668 .29712 Mdot
.668 .29722 Mdot
.668 .29773 Mdot
.668 .29819 Mdot
.668 .29829 Mdot
.668 .29844 Mdot
.668 .2997 Mdot
.668 .29975 Mdot
.668 .2999 Mdot
.668 .30081 Mdot
.668 .30149 Mdot
.668 .30196 Mdot
.668 .3022 Mdot
.668 .30253 Mdot
.668 .30269 Mdot
.668 .303 Mdot
.668 .30304 Mdot
.668 .30376 Mdot
.668 .30537 Mdot
.668 .30706 Mdot
.668 .3077 Mdot
.668 .30823 Mdot
.668 .30858 Mdot
.668 .30946 Mdot
.668 .30981 Mdot
.668 .30983 Mdot
.668 .30994 Mdot
.668 .31139 Mdot
.668 .312 Mdot
.668 .3139 Mdot
.668 .31702 Mdot
.668 .31705 Mdot
.668 .31873 Mdot
.668 .31975 Mdot
.668 .32004 Mdot
.668 .32035 Mdot
.668 .322 Mdot
.668 .32342 Mdot
.668 .32349 Mdot
.668 .3237 Mdot
.668 .32404 Mdot
.668 .32475 Mdot
.668 .32524 Mdot
.668 .3253 Mdot
.668 .32669 Mdot
.668 .32718 Mdot
.668 .32725 Mdot
.668 .32744 Mdot
.668 .32754 Mdot
.668 .32844 Mdot
.668 .32874 Mdot
.668 .32882 Mdot
.668 .3293 Mdot
.668 .32936 Mdot
.668 .32975 Mdot
.668 .32995 Mdot
.668 .33083 Mdot
.668 .33097 Mdot
.668 .33141 Mdot
.668 .33166 Mdot
.668 .332 Mdot
.668 .33246 Mdot
.668 .335 Mdot
.668 .33651 Mdot
.668 .33677 Mdot
.668 .33732 Mdot
.668 .33762 Mdot
.668 .33903 Mdot
.668 .34051 Mdot
.668 .3414 Mdot
.668 .34154 Mdot
.668 .3416 Mdot
.668 .34288 Mdot
.668 .34314 Mdot
.668 .34446 Mdot
.668 .34503 Mdot
.668 .34508 Mdot
.668 .3463 Mdot
.668 .34668 Mdot
.668 .34704 Mdot
.668 .34709 Mdot
.668 .34814 Mdot
.668 .34828 Mdot
.668 .34844 Mdot
.668 .35121 Mdot
.668 .35127 Mdot
.668 .35186 Mdot
.668 .35388 Mdot
.668 .35711 Mdot
.668 .3577 Mdot
.668 .35822 Mdot
.668 .36201 Mdot
.668 .36207 Mdot
.668 .36268 Mdot
.668 .36541 Mdot
.668 .36557 Mdot
.668 .36627 Mdot
.668 .36672 Mdot
.668 .36713 Mdot
.668 .36815 Mdot
.668 .36871 Mdot
.668 .36877 Mdot
.668 .36903 Mdot
.668 .36957 Mdot
.668 .36958 Mdot
.668 .37237 Mdot
.668 .37406 Mdot
.668 .37411 Mdot
.668 .37465 Mdot
.668 .37531 Mdot
.668 .37546 Mdot
.668 .37675 Mdot
.668 .37677 Mdot
.668 .377 Mdot
.668 .37702 Mdot
.668 .37788 Mdot
.668 .37806 Mdot
.668 .37908 Mdot
.668 .37976 Mdot
.668 .3801 Mdot
.668 .38299 Mdot
.668 .38307 Mdot
.668 .38381 Mdot
.668 .38387 Mdot
.668 .3847 Mdot
.668 .38494 Mdot
.668 .38659 Mdot
.668 .38694 Mdot
.668 .38715 Mdot
.668 .3875 Mdot
.668 .38961 Mdot
.668 .39008 Mdot
.668 .39098 Mdot
.668 .39201 Mdot
.668 .39215 Mdot
.668 .39283 Mdot
.668 .39343 Mdot
.668 .39357 Mdot
.668 .39377 Mdot
.668 .39546 Mdot
.668 .39552 Mdot
.668 .39572 Mdot
.668 .39694 Mdot
.668 .39785 Mdot
.668 .39848 Mdot
.668 .3988 Mdot
.668 .39923 Mdot
.668 .39945 Mdot
.668 .39986 Mdot
.668 .39991 Mdot
.668 .40089 Mdot
.668 .40302 Mdot
.668 .40529 Mdot
.668 .40614 Mdot
.668 .40685 Mdot
.668 .40732 Mdot
.668 .4085 Mdot
.668 .40897 Mdot
.668 .40899 Mdot
.668 .40914 Mdot
.67 .01493 Mdot
.67 .015 Mdot
.67 .0151 Mdot
.67 .01515 Mdot
.67 .01523 Mdot
.67 .01529 Mdot
.67 .01541 Mdot
.67 .01549 Mdot
.67 .01551 Mdot
.67 .01564 Mdot
.67 .01575 Mdot
.67 .01578 Mdot
.67 .01596 Mdot
.67 .01611 Mdot
.67 .01614 Mdot
.67 .01638 Mdot
.67 .01658 Mdot
.67 .01663 Mdot
.67 .01694 Mdot
.67 .01714 Mdot
.67 .01722 Mdot
.67 .01728 Mdot
.67 .01739 Mdot
.67 .0177 Mdot
.67 .01797 Mdot
.67 .01807 Mdot
.67 .01815 Mdot
.67 .0183 Mdot
.67 .01872 Mdot
.67 .01907 Mdot
.67 .01921 Mdot
.67 .01932 Mdot
.67 .01952 Mdot
.67 .01978 Mdot
.67 .02008 Mdot
.67 .02024 Mdot
.67 .02055 Mdot
.67 .02073 Mdot
.67 .02089 Mdot
.67 .02115 Mdot
.67 .0215 Mdot
.67 .0219 Mdot
.67 .02207 Mdot
.67 .02212 Mdot
.67 .02254 Mdot
.67 .02278 Mdot
.67 .02299 Mdot
.67 .02334 Mdot
.67 .02335 Mdot
.67 .02351 Mdot
.67 .02381 Mdot
.67 .02429 Mdot
.67 .02434 Mdot
.67 .02457 Mdot
.67 .02463 Mdot
.67 .02482 Mdot
.67 .0252 Mdot
.67 .02537 Mdot
.67 .02552 Mdot
.67 .0258 Mdot
.67 .02628 Mdot
.67 .02629 Mdot
.67 .0265 Mdot
.67 .0267 Mdot
.67 .02679 Mdot
.67 .0269 Mdot
.67 .02755 Mdot
.67 .02762 Mdot
.67 .02792 Mdot
.67 .028 Mdot
.67 .02825 Mdot
.67 .02876 Mdot
.67 .02899 Mdot
.67 .0292 Mdot
.67 .02956 Mdot
.67 .02984 Mdot
.67 .03021 Mdot
.67 .03023 Mdot
.67 .03051 Mdot
.67 .03078 Mdot
.67 .0309 Mdot
.67 .03094 Mdot
.67 .03104 Mdot
.67 .03192 Mdot
.67 .03201 Mdot
.67 .03241 Mdot
.67 .03252 Mdot
.67 .03285 Mdot
.67 .03348 Mdot
.67 .03354 Mdot
.67 .03384 Mdot
.67 .03412 Mdot
.67 .03461 Mdot
.67 .03498 Mdot
.67 .03547 Mdot
.67 .0355 Mdot
.67 .03588 Mdot
.67 .03624 Mdot
.67 .0364 Mdot
.67 .03645 Mdot
.67 .03651 Mdot
.67 .03659 Mdot
.67 .03776 Mdot
.67 .03788 Mdot
.67 .03829 Mdot
.67 .03843 Mdot
.67 .03858 Mdot
.67 .03902 Mdot
.67 .03961 Mdot
.67 .03975 Mdot
.67 .03986 Mdot
.67 .03994 Mdot
.67 .04035 Mdot
.67 .04072 Mdot
.67 .04095 Mdot
.67 .04138 Mdot
.67 .04142 Mdot
.67 .04188 Mdot
.67 .04217 Mdot
.67 .04253 Mdot
.67 .04257 Mdot
.67 .04307 Mdot
.67 .04356 Mdot
.67 .04378 Mdot
.67 .04385 Mdot
.67 .04392 Mdot
.67 .04403 Mdot
.67 .04551 Mdot
.67 .0456 Mdot
.67 .04576 Mdot
.67 .04582 Mdot
.67 .04614 Mdot
.67 .04631 Mdot
.67 .04649 Mdot
.67 .04661 Mdot
.67 .04669 Mdot
.67 .04729 Mdot
.67 .04743 Mdot
.67 .04754 Mdot
.67 .04807 Mdot
.67 .04826 Mdot
.67 .04841 Mdot
.67 .04851 Mdot
.67 .04874 Mdot
.67 .04906 Mdot
.67 .04916 Mdot
.67 .04956 Mdot
.67 .04986 Mdot
.67 .05026 Mdot
.67 .05044 Mdot
.67 .0505 Mdot
.67 .05071 Mdot
.67 .05098 Mdot
.67 .05111 Mdot
.67 .0515 Mdot
.67 .0518 Mdot
.67 .05199 Mdot
.67 .05204 Mdot
.67 .05271 Mdot
.67 .05336 Mdot
.67 .05366 Mdot
.67 .05375 Mdot
.67 .05385 Mdot
.67 .05399 Mdot
.67 .05598 Mdot
.67 .0561 Mdot
.67 .05629 Mdot
.67 .05632 Mdot
.67 .0564 Mdot
.67 .05683 Mdot
.67 .05698 Mdot
.67 .05705 Mdot
.67 .0573 Mdot
.67 .05745 Mdot
.67 .05756 Mdot
.67 .05789 Mdot
.67 .0583 Mdot
.67 .05836 Mdot
.67 .05856 Mdot
.67 .05857 Mdot
.67 .0587 Mdot
.67 .05942 Mdot
.67 .05966 Mdot
.67 .05986 Mdot
.67 .05987 Mdot
.67 .06 Mdot
.67 .06028 Mdot
.67 .06031 Mdot
.67 .06074 Mdot
.67 .06086 Mdot
.67 .06116 Mdot
.67 .06141 Mdot
.67 .06182 Mdot
.67 .06235 Mdot
.67 .06259 Mdot
.67 .06267 Mdot
.67 .06277 Mdot
.67 .06294 Mdot
.67 .06331 Mdot
.67 .06348 Mdot
.67 .06368 Mdot
.67 .06392 Mdot
.67 .06401 Mdot
.67 .06416 Mdot
.67 .06456 Mdot
.67 .06466 Mdot
.67 .06473 Mdot
.67 .06491 Mdot
.67 .06563 Mdot
.67 .0665 Mdot
.67 .0669 Mdot
.67 .06702 Mdot
.67 .06709 Mdot
.67 .06716 Mdot
.67 .06733 Mdot
.67 .06735 Mdot
.67 .06821 Mdot
.67 .0686 Mdot
.67 .07001 Mdot
.67 .07017 Mdot
.67 .07043 Mdot
.67 .07046 Mdot
.67 .07057 Mdot
.67 .07115 Mdot
.67 .07135 Mdot
.67 .07144 Mdot
.67 .07161 Mdot
.67 .07178 Mdot
.67 .07198 Mdot
.67 .07213 Mdot
.67 .07221 Mdot
.67 .07257 Mdot
.67 .07268 Mdot
.67 .07312 Mdot
.67 .0732 Mdot
.67 .07347 Mdot
.67 .07348 Mdot
.67 .07365 Mdot
.67 .07375 Mdot
.67 .07427 Mdot
.67 .07439 Mdot
.67 .07462 Mdot
.67 .07495 Mdot
.67 .07521 Mdot
.67 .07522 Mdot
.67 .0754 Mdot
.67 .0757 Mdot
.67 .07578 Mdot
.67 .07581 Mdot
.67 .07639 Mdot
.67 .07648 Mdot
.67 .07656 Mdot
.67 .07681 Mdot
.67 .07696 Mdot
.67 .07728 Mdot
.67 .07783 Mdot
.67 .07855 Mdot
.67 .07887 Mdot
.67 .07897 Mdot
.67 .07911 Mdot
.67 .07934 Mdot
.67 .07983 Mdot
.67 .08006 Mdot
.67 .08033 Mdot
.67 .08034 Mdot
.67 .08052 Mdot
.67 .08065 Mdot
.67 .08077 Mdot
.67 .08097 Mdot
.67 .08143 Mdot
.67 .08151 Mdot
.67 .08165 Mdot
.67 .08174 Mdot
.67 .08198 Mdot
.67 .08257 Mdot
.67 .08294 Mdot
.67 .08319 Mdot
.67 .08411 Mdot
.67 .08465 Mdot
.67 .08481 Mdot
.67 .0849 Mdot
.67 .08499 Mdot
.67 .08522 Mdot
.67 .08524 Mdot
.67 .08577 Mdot
.67 .0864 Mdot
.67 .08692 Mdot
.67 .08777 Mdot
.67 .0879 Mdot
.67 .08881 Mdot
.67 .08903 Mdot
.67 .0891 Mdot
.67 .08929 Mdot
.67 .08937 Mdot
.67 .08942 Mdot
.67 .08956 Mdot
.67 .09034 Mdot
.67 .09061 Mdot
.67 .09073 Mdot
.67 .09095 Mdot
.67 .09118 Mdot
.67 .09145 Mdot
.67 .09161 Mdot
.67 .09165 Mdot
.67 .09169 Mdot
.67 .09176 Mdot
.67 .0922 Mdot
.67 .09224 Mdot
.67 .09239 Mdot
.67 .09246 Mdot
.67 .09298 Mdot
.67 .09309 Mdot
.67 .09344 Mdot
.67 .09346 Mdot
.67 .09369 Mdot
.67 .09382 Mdot
.67 .09449 Mdot
.67 .09452 Mdot
.67 .09468 Mdot
.67 .09487 Mdot
.67 .09498 Mdot
.67 .09543 Mdot
.67 .09577 Mdot
.67 .09579 Mdot
.67 .09604 Mdot
.67 .09644 Mdot
.67 .09654 Mdot
.67 .09658 Mdot
.67 .09693 Mdot
.67 .097 Mdot
.67 .09736 Mdot
.67 .09748 Mdot
.67 .09758 Mdot
.67 .09765 Mdot
.67 .09792 Mdot
.67 .09812 Mdot
.67 .09824 Mdot
.67 .09856 Mdot
.67 .09865 Mdot
.67 .09929 Mdot
.67 .10023 Mdot
.67 .10025 Mdot
.67 .10068 Mdot
.67 .10082 Mdot
.67 .101 Mdot
.67 .10131 Mdot
.67 .10135 Mdot
.67 .10197 Mdot
.67 .10207 Mdot
.67 .10228 Mdot
.67 .10264 Mdot
.67 .10265 Mdot
.67 .10289 Mdot
.67 .10306 Mdot
.67 .10324 Mdot
.67 .10349 Mdot
.67 .10389 Mdot
.67 .10411 Mdot
.67 .10422 Mdot
.67 .1044 Mdot
.67 .10442 Mdot
.67 .10452 Mdot
.67 .10465 Mdot
.67 .10485 Mdot
.67 .10564 Mdot
.67 .10579 Mdot
.67 .10609 Mdot
.67 .10614 Mdot
.67 .10647 Mdot
.67 .1077 Mdot
.67 .10812 Mdot
.67 .10842 Mdot
.67 .10864 Mdot
.67 .10876 Mdot
.67 .10889 Mdot
.67 .1092 Mdot
.67 .10922 Mdot
.67 .10992 Mdot
.67 .11077 Mdot
.67 .11147 Mdot
.67 .11222 Mdot
.67 .1126 Mdot
.67 .11278 Mdot
.67 .11355 Mdot
.67 .1137 Mdot
.67 .114 Mdot
.67 .1143 Mdot
.67 .11439 Mdot
.67 .11465 Mdot
.67 .11475 Mdot
.67 .11482 Mdot
.67 .11501 Mdot
.67 .11605 Mdot
.67 .11621 Mdot
.67 .11642 Mdot
.67 .11651 Mdot
.67 .11657 Mdot
.67 .11687 Mdot
.67 .11697 Mdot
.67 .11717 Mdot
.67 .11755 Mdot
.67 .11776 Mdot
.67 .11781 Mdot
.67 .11787 Mdot
.67 .11796 Mdot
.67 .11804 Mdot
.67 .11855 Mdot
.67 .1186 Mdot
.67 .1188 Mdot
.67 .11889 Mdot
.67 .11959 Mdot
.67 .11973 Mdot
.67 .11984 Mdot
.67 .12009 Mdot
.67 .12021 Mdot
.67 .12023 Mdot
.67 .12054 Mdot
.67 .12072 Mdot
.67 .1208 Mdot
.67 .12161 Mdot
.67 .12165 Mdot
.67 .12186 Mdot
.67 .12213 Mdot
.67 .12227 Mdot
.67 .12287 Mdot
.67 .12333 Mdot
.67 .12336 Mdot
.67 .12364 Mdot
.67 .12368 Mdot
.67 .12422 Mdot
.67 .12424 Mdot
.67 .12436 Mdot
.67 .12442 Mdot
.67 .12489 Mdot
.67 .12498 Mdot
.67 .12545 Mdot
.67 .12547 Mdot
.67 .12562 Mdot
.67 .12576 Mdot
.67 .12585 Mdot
.67 .12621 Mdot
.67 .12648 Mdot
.67 .12664 Mdot
.67 .12706 Mdot
.67 .12719 Mdot
.67 .12724 Mdot
.67 .1275 Mdot
.67 .12757 Mdot
.67 .12804 Mdot
.67 .12899 Mdot
.67 .1293 Mdot
.67 .12933 Mdot
.67 .12991 Mdot
.67 .12998 Mdot
.67 .13009 Mdot
.67 .13034 Mdot
.67 .13075 Mdot
.67 .13081 Mdot
.67 .13098 Mdot
.67 .13163 Mdot
.67 .13177 Mdot
.67 .13206 Mdot
.67 .13247 Mdot
.67 .13253 Mdot
.67 .13254 Mdot
.67 .13287 Mdot
.67 .1331 Mdot
.67 .13333 Mdot
.67 .13368 Mdot
.67 .13421 Mdot
.67 .1345 Mdot
.67 .13465 Mdot
.67 .13475 Mdot
.67 .1349 Mdot
.67 .13492 Mdot
.67 .13506 Mdot
.67 .13523 Mdot
.67 .1355 Mdot
.67 .13603 Mdot
.67 .13656 Mdot
.67 .13665 Mdot
.67 .13675 Mdot
.67 .1371 Mdot
.67 .13716 Mdot
.67 .13722 Mdot
.67 .13767 Mdot
.67 .13774 Mdot
.67 .13785 Mdot
.67 .13843 Mdot
.67 .13917 Mdot
.67 .13932 Mdot
.67 .13988 Mdot
.67 .14028 Mdot
.67 .14033 Mdot
.67 .14057 Mdot
.67 .14074 Mdot
.67 .14091 Mdot
.67 .14132 Mdot
.67 .14135 Mdot
.67 .14229 Mdot
.67 .14263 Mdot
.67 .14342 Mdot
.67 .14436 Mdot
.67 .14492 Mdot
.67 .14532 Mdot
.67 .14537 Mdot
.67 .14574 Mdot
.67 .14589 Mdot
.67 .14612 Mdot
.67 .14715 Mdot
.67 .14725 Mdot
.67 .14735 Mdot
.67 .14749 Mdot
.67 .14775 Mdot
.67 .14778 Mdot
.67 .14816 Mdot
.67 .14828 Mdot
.67 .14863 Mdot
.67 .14877 Mdot
.67 .14885 Mdot
.67 .14911 Mdot
.67 .1505 Mdot
.67 .15071 Mdot
.67 .15099 Mdot
.67 .15112 Mdot
.67 .1512 Mdot
.67 .1516 Mdot
.67 .15174 Mdot
.67 .15201 Mdot
.67 .15251 Mdot
.67 .15279 Mdot
.67 .15286 Mdot
.67 .15294 Mdot
.67 .15306 Mdot
.67 .15317 Mdot
.67 .15385 Mdot
.67 .15392 Mdot
.67 .15419 Mdot
.67 .15432 Mdot
.67 .15525 Mdot
.67 .15544 Mdot
.67 .15558 Mdot
.67 .15591 Mdot
.67 .15607 Mdot
.67 .15611 Mdot
.67 .15652 Mdot
.67 .15676 Mdot
.67 .15686 Mdot
.67 .15796 Mdot
.67 .15801 Mdot
.67 .15829 Mdot
.67 .15865 Mdot
.67 .15884 Mdot
.67 .15964 Mdot
.67 .16026 Mdot
.67 .1603 Mdot
.67 .16067 Mdot
.67 .16073 Mdot
.67 .16145 Mdot
.67 .16148 Mdot
.67 .16164 Mdot
.67 .16172 Mdot
.67 .16235 Mdot
.67 .16246 Mdot
.67 .1631 Mdot
.67 .16312 Mdot
.67 .16333 Mdot
.67 .16351 Mdot
.67 .16364 Mdot
.67 .16412 Mdot
.67 .16447 Mdot
.67 .1647 Mdot
.67 .16526 Mdot
.67 .16543 Mdot
.67 .1655 Mdot
.67 .16585 Mdot
.67 .16594 Mdot
.67 .16657 Mdot
.67 .16784 Mdot
.67 .16826 Mdot
.67 .1683 Mdot
.67 .16908 Mdot
.67 .16918 Mdot
.67 .16932 Mdot
.67 .16965 Mdot
.67 .17021 Mdot
.67 .17028 Mdot
.67 .1705 Mdot
.67 .17139 Mdot
.67 .17157 Mdot
.67 .17195 Mdot
.67 .1725 Mdot
.67 .17258 Mdot
.67 .17261 Mdot
.67 .17305 Mdot
.67 .17335 Mdot
.67 .17366 Mdot
.67 .17412 Mdot
.67 .17483 Mdot
.67 .17523 Mdot
.67 .17542 Mdot
.67 .17556 Mdot
.67 .17576 Mdot
.67 .17579 Mdot
.67 .17597 Mdot
.67 .1762 Mdot
.67 .17656 Mdot
.67 .17728 Mdot
.67 .17799 Mdot
.67 .17811 Mdot
.67 .17824 Mdot
.67 .17871 Mdot
.67 .17879 Mdot
.67 .17887 Mdot
.67 .17947 Mdot
.67 .17956 Mdot
.67 .17972 Mdot
.67 .1805 Mdot
.67 .18149 Mdot
.67 .18168 Mdot
.67 .18244 Mdot
.67 .18298 Mdot
.67 .18304 Mdot
.67 .18337 Mdot
.67 .18358 Mdot
.67 .18381 Mdot
.67 .18437 Mdot
.67 .18441 Mdot
.67 .18567 Mdot
.67 .18613 Mdot
.67 .18718 Mdot
.67 .18844 Mdot
.67 .18918 Mdot
.67 .18973 Mdot
.67 .18979 Mdot
.67 .19029 Mdot
.67 .19048 Mdot
.67 .1908 Mdot
.67 .19218 Mdot
.67 .19231 Mdot
.67 .19245 Mdot
.67 .19264 Mdot
.67 .19298 Mdot
.67 .19303 Mdot
.67 .19353 Mdot
.67 .1937 Mdot
.67 .19416 Mdot
.67 .19434 Mdot
.67 .19446 Mdot
.67 .1948 Mdot
.67 .19666 Mdot
.67 .19695 Mdot
.67 .19733 Mdot
.67 .1975 Mdot
.67 .19761 Mdot
.67 .19815 Mdot
.67 .19832 Mdot
.67 .19869 Mdot
.67 .19936 Mdot
.67 .19973 Mdot
.67 .19983 Mdot
.67 .19993 Mdot
.67 .2001 Mdot
.67 .20025 Mdot
.67 .20115 Mdot
.67 .20125 Mdot
.67 .20162 Mdot
.67 .20178 Mdot
.67 .20303 Mdot
.67 .20328 Mdot
.67 .20348 Mdot
.67 .20392 Mdot
.67 .20414 Mdot
.67 .20419 Mdot
.67 .20473 Mdot
.67 .20505 Mdot
.67 .20519 Mdot
.67 .20666 Mdot
.67 .20673 Mdot
.67 .20711 Mdot
.67 .20759 Mdot
.67 .20784 Mdot
.67 .20891 Mdot
.67 .20975 Mdot
.67 .2098 Mdot
.67 .2103 Mdot
.67 .21038 Mdot
.67 .21134 Mdot
.67 .21138 Mdot
.67 .21159 Mdot
.67 .2117 Mdot
.67 .21254 Mdot
.67 .2127 Mdot
.67 .21356 Mdot
.67 .21358 Mdot
.67 .21385 Mdot
.67 .2141 Mdot
.67 .21427 Mdot
.67 .21492 Mdot
.67 .21539 Mdot
.67 .21569 Mdot
.67 .21645 Mdot
.67 .21667 Mdot
.67 .21676 Mdot
.67 .21723 Mdot
.67 .21736 Mdot
.67 .21821 Mdot
.67 .21991 Mdot
.67 .22046 Mdot
.67 .22052 Mdot
.67 .22157 Mdot
.67 .22169 Mdot
.67 .22188 Mdot
.67 .22233 Mdot
.67 .22308 Mdot
.67 .22318 Mdot
.67 .22347 Mdot
.67 .22466 Mdot
.67 .2249 Mdot
.67 .22541 Mdot
.67 .22615 Mdot
.67 .22626 Mdot
.67 .22629 Mdot
.67 .22688 Mdot
.67 .22729 Mdot
.67 .2277 Mdot
.67 .22832 Mdot
.67 .22927 Mdot
.67 .2298 Mdot
.67 .23006 Mdot
.67 .23025 Mdot
.67 .23051 Mdot
.67 .23056 Mdot
.67 .2308 Mdot
.67 .23111 Mdot
.67 .23159 Mdot
.67 .23255 Mdot
.67 .2335 Mdot
.67 .23367 Mdot
.67 .23384 Mdot
.67 .23447 Mdot
.67 .23457 Mdot
.67 .23469 Mdot
.67 .23549 Mdot
.67 .23561 Mdot
.67 .23582 Mdot
.67 .23686 Mdot
.67 .23819 Mdot
.67 .23845 Mdot
.67 .23947 Mdot
.67 .24018 Mdot
.67 .24027 Mdot
.67 .24071 Mdot
.67 .241 Mdot
.67 .24131 Mdot
.67 .24205 Mdot
.67 .2421 Mdot
.67 .2438 Mdot
.67 .24441 Mdot
.67 .24582 Mdot
.67 .24751 Mdot
.67 .2485 Mdot
.67 .24924 Mdot
.67 .24931 Mdot
.67 .24998 Mdot
.67 .25024 Mdot
.67 .25066 Mdot
.67 .25252 Mdot
.67 .2527 Mdot
.67 .25288 Mdot
.67 .25313 Mdot
.67 .25359 Mdot
.67 .25365 Mdot
.67 .25432 Mdot
.67 .25455 Mdot
.67 .25517 Mdot
.67 .25542 Mdot
.67 .25557 Mdot
.67 .25603 Mdot
.67 .25853 Mdot
.67 .25891 Mdot
.67 .25942 Mdot
.67 .25965 Mdot
.67 .2598 Mdot
.67 .26051 Mdot
.67 .26075 Mdot
.67 .26124 Mdot
.67 .26213 Mdot
.67 .26264 Mdot
.67 .26277 Mdot
.67 .26291 Mdot
.67 .26313 Mdot
.67 .26333 Mdot
.67 .26454 Mdot
.67 .26468 Mdot
.67 .26516 Mdot
.67 .26538 Mdot
.67 .26706 Mdot
.67 .26739 Mdot
.67 .26766 Mdot
.67 .26825 Mdot
.67 .26854 Mdot
.67 .26861 Mdot
.67 .26934 Mdot
.67 .26977 Mdot
.67 .26995 Mdot
.67 .27192 Mdot
.67 .27202 Mdot
.67 .27253 Mdot
.67 .27316 Mdot
.67 .27351 Mdot
.67 .27494 Mdot
.67 .27606 Mdot
.67 .27613 Mdot
.67 .2768 Mdot
.67 .27691 Mdot
.67 .2782 Mdot
.67 .27824 Mdot
.67 .27853 Mdot
.67 .27867 Mdot
.67 .2798 Mdot
.67 .28001 Mdot
.67 .28116 Mdot
.67 .2812 Mdot
.67 .28156 Mdot
.67 .28189 Mdot
.67 .28212 Mdot
.67 .28299 Mdot
.67 .28362 Mdot
.67 .28402 Mdot
.67 .28503 Mdot
.67 .28533 Mdot
.67 .28546 Mdot
.67 .28609 Mdot
.67 .28626 Mdot
.67 .28739 Mdot
.67 .28967 Mdot
.67 .29042 Mdot
.67 .2905 Mdot
.67 .29189 Mdot
.67 .29206 Mdot
.67 .29232 Mdot
.67 .29292 Mdot
.67 .29392 Mdot
.67 .29406 Mdot
.67 .29445 Mdot
.67 .29603 Mdot
.67 .29637 Mdot
.67 .29705 Mdot
.67 .29804 Mdot
.67 .29819 Mdot
.67 .29822 Mdot
.67 .29901 Mdot
.67 .29957 Mdot
.67 .30012 Mdot
.67 .30095 Mdot
.67 .30222 Mdot
.67 .30294 Mdot
.67 .30328 Mdot
.67 .30353 Mdot
.67 .30389 Mdot
.67 .30395 Mdot
.67 .30427 Mdot
.67 .30469 Mdot
.67 .30533 Mdot
.67 .30661 Mdot
.67 .30788 Mdot
.67 .30811 Mdot
.67 .30834 Mdot
.67 .30918 Mdot
.67 .30932 Mdot
.67 .30948 Mdot
.67 .31056 Mdot
.67 .31072 Mdot
.67 .31099 Mdot
.67 .31239 Mdot
.67 .31417 Mdot
.67 .31452 Mdot
.67 .31589 Mdot
.67 .31684 Mdot
.67 .31696 Mdot
.67 .31755 Mdot
.67 .31794 Mdot
.67 .31835 Mdot
.67 .31934 Mdot
.67 .31941 Mdot
.67 .32168 Mdot
.67 .3225 Mdot
.67 .3244 Mdot
.67 .32666 Mdot
.67 .32799 Mdot
.67 .32897 Mdot
.67 .32908 Mdot
.67 .32997 Mdot
.67 .33033 Mdot
.67 .33089 Mdot
.67 .33338 Mdot
.67 .33361 Mdot
.67 .33385 Mdot
.67 .3342 Mdot
.67 .33481 Mdot
.67 .33489 Mdot
.67 .33579 Mdot
.67 .3361 Mdot
.67 .33693 Mdot
.67 .33725 Mdot
.67 .33746 Mdot
.67 .33807 Mdot
.67 .34142 Mdot
.67 .34194 Mdot
.67 .34262 Mdot
.67 .34292 Mdot
.67 .34312 Mdot
.67 .34408 Mdot
.67 .3444 Mdot
.67 .34506 Mdot
.67 .34626 Mdot
.67 .34694 Mdot
.67 .34711 Mdot
.67 .34729 Mdot
.67 .34759 Mdot
.67 .34786 Mdot
.67 .34948 Mdot
.67 .34966 Mdot
.67 .35032 Mdot
.67 .35061 Mdot
.67 .35285 Mdot
.67 .35331 Mdot
.67 .35366 Mdot
.67 .35445 Mdot
.67 .35484 Mdot
.67 .35493 Mdot
.67 .35591 Mdot
.67 .35649 Mdot
.67 .35674 Mdot
.67 .35937 Mdot
.67 .3595 Mdot
.67 .36018 Mdot
.67 .36104 Mdot
.67 .3615 Mdot
.67 .36342 Mdot
.67 .36491 Mdot
.67 .36501 Mdot
.67 .36591 Mdot
.67 .36605 Mdot
.67 .36778 Mdot
.67 .36784 Mdot
.67 .36822 Mdot
.67 .36842 Mdot
.67 .36993 Mdot
.67 .37022 Mdot
.67 .37175 Mdot
.67 .3718 Mdot
.67 .37229 Mdot
.67 .37273 Mdot
.67 .37303 Mdot
.67 .37421 Mdot
.67 .37505 Mdot
.67 .37559 Mdot
.67 .37694 Mdot
.67 .37734 Mdot
.67 .37751 Mdot
.67 .37836 Mdot
.67 .37859 Mdot
.67 .3801 Mdot
.67 .38316 Mdot
.67 .38415 Mdot
.67 .38426 Mdot
.67 .38614 Mdot
.67 .38636 Mdot
.67 .38671 Mdot
.67 .38751 Mdot
.67 .38885 Mdot
.67 .38903 Mdot
.67 .38956 Mdot
.67 .39168 Mdot
.67 .39213 Mdot
.67 .39305 Mdot
.67 .39437 Mdot
.67 .39457 Mdot
.67 .39462 Mdot
.67 .39568 Mdot
.67 .39642 Mdot
.67 .39716 Mdot
.67 .39827 Mdot
.67 .39997 Mdot
.67 .40093 Mdot
.67 .40139 Mdot
.67 .40173 Mdot
.67 .4022 Mdot
.67 .40229 Mdot
.67 .40272 Mdot
.67 .40328 Mdot
.67 .40414 Mdot
.67 .40586 Mdot
.67 .40756 Mdot
.67 .40787 Mdot
.67 .40817 Mdot
.67 .4093 Mdot
.67 .40949 Mdot
.67 .4097 Mdot
.672 .01478 Mdot
.672 .0148 Mdot
.672 .01483 Mdot
.672 .01487 Mdot
.672 .01492 Mdot
.672 .015 Mdot
.672 .01509 Mdot
.672 .01522 Mdot
.672 .0154 Mdot
.672 .01563 Mdot
.672 .01595 Mdot
.672 .01597 Mdot
.672 .01633 Mdot
.672 .01637 Mdot
.672 .0164 Mdot
.672 .01682 Mdot
.672 .01688 Mdot
.672 .01694 Mdot
.672 .01698 Mdot
.672 .01754 Mdot
.672 .01763 Mdot
.672 .01771 Mdot
.672 .01776 Mdot
.672 .01852 Mdot
.672 .01863 Mdot
.672 .01874 Mdot
.672 .01881 Mdot
.672 .01974 Mdot
.672 .01982 Mdot
.672 .01997 Mdot
.672 .02012 Mdot
.672 .02022 Mdot
.672 .02037 Mdot
.672 .02081 Mdot
.672 .02107 Mdot
.672 .02147 Mdot
.672 .02158 Mdot
.672 .02178 Mdot
.672 .02198 Mdot
.672 .02211 Mdot
.672 .02231 Mdot
.672 .02232 Mdot
.672 .02287 Mdot
.672 .02291 Mdot
.672 .02313 Mdot
.672 .02326 Mdot
.672 .02379 Mdot
.672 .02394 Mdot
.672 .02421 Mdot
.672 .02448 Mdot
.672 .02466 Mdot
.672 .02473 Mdot
.672 .0249 Mdot
.672 .02492 Mdot
.672 .02494 Mdot
.672 .02568 Mdot
.672 .02573 Mdot
.672 .02602 Mdot
.672 .0262 Mdot
.672 .02632 Mdot
.672 .02691 Mdot
.672 .02712 Mdot
.672 .02722 Mdot
.672 .02748 Mdot
.672 .02784 Mdot
.672 .02798 Mdot
.672 .02808 Mdot
.672 .02817 Mdot
.672 .0284 Mdot
.672 .02843 Mdot
.672 .02846 Mdot
.672 .02876 Mdot
.672 .02945 Mdot
.672 .02952 Mdot
.672 .02984 Mdot
.672 .02991 Mdot
.672 .03015 Mdot
.672 .03031 Mdot
.672 .0306 Mdot
.672 .03079 Mdot
.672 .03102 Mdot
.672 .03111 Mdot
.672 .03123 Mdot
.672 .03138 Mdot
.672 .03153 Mdot
.672 .03187 Mdot
.672 .03218 Mdot
.672 .03236 Mdot
.672 .03255 Mdot
.672 .03268 Mdot
.672 .0328 Mdot
.672 .03291 Mdot
.672 .03298 Mdot
.672 .03302 Mdot
.672 .03311 Mdot
.672 .03315 Mdot
.672 .03319 Mdot
.672 .03359 Mdot
.672 .03452 Mdot
.672 .03461 Mdot
.672 .03502 Mdot
.672 .03504 Mdot
.672 .03513 Mdot
.672 .03546 Mdot
.672 .03567 Mdot
.672 .03607 Mdot
.672 .03633 Mdot
.672 .03663 Mdot
.672 .03675 Mdot
.672 .03691 Mdot
.672 .03702 Mdot
.672 .03711 Mdot
.672 .03731 Mdot
.672 .03766 Mdot
.672 .03777 Mdot
.672 .03818 Mdot
.672 .03842 Mdot
.672 .03868 Mdot
.672 .03883 Mdot
.672 .03885 Mdot
.672 .03903 Mdot
.672 .03903 Mdot
.672 .03917 Mdot
.672 .03926 Mdot
.672 .03931 Mdot
.672 .03944 Mdot
.672 .03949 Mdot
.672 .03954 Mdot
.672 .04009 Mdot
.672 .04098 Mdot
.672 .04133 Mdot
.672 .04146 Mdot
.672 .042 Mdot
.672 .04204 Mdot
.672 .04216 Mdot
.672 .0426 Mdot
.672 .04264 Mdot
.672 .04288 Mdot
.672 .04342 Mdot
.672 .04376 Mdot
.672 .04409 Mdot
.672 .04417 Mdot
.672 .04419 Mdot
.672 .04432 Mdot
.672 .04454 Mdot
.672 .0447 Mdot
.672 .04482 Mdot
.672 .04494 Mdot
.672 .04508 Mdot
.672 .04555 Mdot
.672 .0457 Mdot
.672 .04625 Mdot
.672 .04633 Mdot
.672 .04658 Mdot
.672 .04693 Mdot
.672 .04713 Mdot
.672 .04716 Mdot
.672 .04728 Mdot
.672 .04738 Mdot
.672 .04739 Mdot
.672 .04739 Mdot
.672 .04759 Mdot
.672 .04771 Mdot
.672 .04777 Mdot
.672 .04794 Mdot
.672 .04802 Mdot
.672 .04807 Mdot
.672 .04808 Mdot
.672 .04881 Mdot
.672 .04986 Mdot
.672 .05001 Mdot
.672 .05049 Mdot
.672 .05065 Mdot
.672 .05111 Mdot
.672 .05111 Mdot
.672 .05139 Mdot
.672 .05144 Mdot
.672 .0516 Mdot
.672 .0518 Mdot
.672 .05205 Mdot
.672 .05216 Mdot
.672 .05219 Mdot
.672 .05224 Mdot
.672 .05257 Mdot
.672 .05298 Mdot
.672 .05329 Mdot
.672 .05375 Mdot
.672 .0542 Mdot
.672 .05431 Mdot
.672 .05433 Mdot
.672 .05451 Mdot
.672 .0548 Mdot
.672 .05501 Mdot
.672 .05518 Mdot
.672 .05534 Mdot
.672 .05553 Mdot
.672 .05616 Mdot
.672 .05636 Mdot
.672 .05647 Mdot
.672 .05667 Mdot
.672 .0571 Mdot
.672 .05721 Mdot
.672 .05736 Mdot
.672 .05754 Mdot
.672 .05801 Mdot
.672 .05828 Mdot
.672 .05832 Mdot
.672 .05848 Mdot
.672 .05858 Mdot
.672 .05862 Mdot
.672 .05863 Mdot
.672 .05864 Mdot
.672 .0589 Mdot
.672 .05906 Mdot
.672 .05915 Mdot
.672 .05937 Mdot
.672 .05947 Mdot
.672 .05955 Mdot
.672 .05956 Mdot
.672 .06054 Mdot
.672 .06069 Mdot
.672 .06073 Mdot
.672 .06135 Mdot
.672 .06185 Mdot
.672 .06195 Mdot
.672 .06215 Mdot
.672 .06279 Mdot
.672 .06302 Mdot
.672 .06305 Mdot
.672 .06363 Mdot
.672 .06363 Mdot
.672 .06394 Mdot
.672 .06401 Mdot
.672 .06407 Mdot
.672 .06429 Mdot
.672 .06456 Mdot
.672 .06489 Mdot
.672 .06504 Mdot
.672 .06509 Mdot
.672 .06515 Mdot
.672 .0656 Mdot
.672 .06584 Mdot
.672 .06615 Mdot
.672 .06656 Mdot
.672 .06718 Mdot
.672 .06778 Mdot
.672 .06793 Mdot
.672 .06795 Mdot
.672 .0682 Mdot
.672 .06859 Mdot
.672 .0686 Mdot
.672 .06887 Mdot
.672 .06909 Mdot
.672 .06932 Mdot
.672 .06957 Mdot
.672 .06971 Mdot
.672 .07042 Mdot
.672 .07069 Mdot
.672 .07083 Mdot
.672 .0711 Mdot
.672 .07134 Mdot
.672 .07169 Mdot
.672 .07183 Mdot
.672 .07203 Mdot
.672 .07227 Mdot
.672 .07291 Mdot
.672 .07325 Mdot
.672 .07327 Mdot
.672 .07332 Mdot
.672 .07353 Mdot
.672 .07366 Mdot
.672 .07372 Mdot
.672 .07374 Mdot
.672 .07374 Mdot
.672 .07409 Mdot
.672 .07431 Mdot
.672 .07443 Mdot
.672 .07474 Mdot
.672 .07487 Mdot
.672 .07497 Mdot
.672 .07499 Mdot
.672 .07539 Mdot
.672 .0754 Mdot
.672 .07631 Mdot
.672 .0765 Mdot
.672 .07656 Mdot
.672 .07737 Mdot
.672 .0774 Mdot
.672 .07807 Mdot
.672 .0782 Mdot
.672 .07826 Mdot
.672 .07847 Mdot
.672 .07933 Mdot
.672 .07963 Mdot
.672 .07967 Mdot
.672 .07992 Mdot
.672 .08045 Mdot
.672 .08045 Mdot
.672 .08087 Mdot
.672 .08097 Mdot
.672 .08097 Mdot
.672 .08104 Mdot
.672 .08112 Mdot
.672 .08134 Mdot
.672 .08152 Mdot
.672 .08171 Mdot
.672 .08204 Mdot
.672 .08215 Mdot
.672 .08235 Mdot
.672 .08241 Mdot
.672 .0825 Mdot
.672 .0831 Mdot
.672 .08322 Mdot
.672 .08343 Mdot
.672 .08357 Mdot
.672 .08384 Mdot
.672 .08426 Mdot
.672 .08439 Mdot
.672 .08471 Mdot
.672 .08487 Mdot
.672 .08491 Mdot
.672 .08494 Mdot
.672 .08523 Mdot
.672 .08603 Mdot
.672 .08623 Mdot
.672 .08627 Mdot
.672 .0866 Mdot
.672 .08713 Mdot
.672 .08714 Mdot
.672 .08751 Mdot
.672 .08768 Mdot
.672 .0878 Mdot
.672 .0881 Mdot
.672 .08832 Mdot
.672 .08843 Mdot
.672 .08863 Mdot
.672 .08923 Mdot
.672 .08926 Mdot
.672 .08938 Mdot
.672 .08958 Mdot
.672 .08995 Mdot
.672 .09014 Mdot
.672 .09034 Mdot
.672 .09049 Mdot
.672 .09082 Mdot
.672 .09128 Mdot
.672 .09147 Mdot
.672 .09175 Mdot
.672 .09207 Mdot
.672 .09277 Mdot
.672 .09292 Mdot
.672 .09338 Mdot
.672 .09341 Mdot
.672 .09348 Mdot
.672 .09376 Mdot
.672 .09382 Mdot
.672 .09394 Mdot
.672 .09402 Mdot
.672 .09404 Mdot
.672 .09405 Mdot
.672 .09452 Mdot
.672 .09463 Mdot
.672 .09479 Mdot
.672 .09481 Mdot
.672 .09497 Mdot
.672 .09538 Mdot
.672 .09556 Mdot
.672 .0957 Mdot
.672 .09573 Mdot
.672 .09627 Mdot
.672 .09628 Mdot
.672 .0975 Mdot
.672 .09775 Mdot
.672 .09783 Mdot
.672 .09797 Mdot
.672 .09806 Mdot
.672 .09892 Mdot
.672 .09896 Mdot
.672 .09986 Mdot
.672 .10004 Mdot
.672 .10012 Mdot
.672 .1004 Mdot
.672 .10156 Mdot
.672 .10196 Mdot
.672 .10202 Mdot
.672 .10235 Mdot
.672 .10306 Mdot
.672 .10307 Mdot
.672 .10363 Mdot
.672 .10376 Mdot
.672 .10376 Mdot
.672 .10386 Mdot
.672 .10397 Mdot
.672 .10426 Mdot
.672 .1045 Mdot
.672 .10475 Mdot
.672 .1052 Mdot
.672 .10523 Mdot
.672 .10535 Mdot
.672 .10562 Mdot
.672 .1057 Mdot
.672 .10582 Mdot
.672 .10662 Mdot
.672 .10673 Mdot
.672 .10679 Mdot
.672 .10707 Mdot
.672 .1072 Mdot
.672 .10725 Mdot
.672 .10762 Mdot
.672 .10798 Mdot
.672 .10819 Mdot
.672 .10836 Mdot
.672 .10854 Mdot
.672 .10878 Mdot
.672 .109 Mdot
.672 .10905 Mdot
.672 .1091 Mdot
.672 .10949 Mdot
.672 .11057 Mdot
.672 .11084 Mdot
.672 .11088 Mdot
.672 .11132 Mdot
.672 .11203 Mdot
.672 .11206 Mdot
.672 .11223 Mdot
.672 .11255 Mdot
.672 .11278 Mdot
.672 .11294 Mdot
.672 .11335 Mdot
.672 .11363 Mdot
.672 .11363 Mdot
.672 .11379 Mdot
.672 .11385 Mdot
.672 .11406 Mdot
.672 .11486 Mdot
.672 .1149 Mdot
.672 .11506 Mdot
.672 .11534 Mdot
.672 .11583 Mdot
.672 .11609 Mdot
.672 .11636 Mdot
.672 .11656 Mdot
.672 .11699 Mdot
.672 .11762 Mdot
.672 .11788 Mdot
.672 .11825 Mdot
.672 .11868 Mdot
.672 .11917 Mdot
.672 .11918 Mdot
.672 .11962 Mdot
.672 .11983 Mdot
.672 .1202 Mdot
.672 .12044 Mdot
.672 .12048 Mdot
.672 .12057 Mdot
.672 .12069 Mdot
.672 .12096 Mdot
.672 .12104 Mdot
.672 .1212 Mdot
.672 .1213 Mdot
.672 .12133 Mdot
.672 .12134 Mdot
.672 .12135 Mdot
.672 .12197 Mdot
.672 .12212 Mdot
.672 .12233 Mdot
.672 .12233 Mdot
.672 .12236 Mdot
.672 .12258 Mdot
.672 .12314 Mdot
.672 .12338 Mdot
.672 .12356 Mdot
.672 .1236 Mdot
.672 .12432 Mdot
.672 .12434 Mdot
.672 .12598 Mdot
.672 .12632 Mdot
.672 .12642 Mdot
.672 .1266 Mdot
.672 .12673 Mdot
.672 .12757 Mdot
.672 .12789 Mdot
.672 .12794 Mdot
.672 .12916 Mdot
.672 .12916 Mdot
.672 .12939 Mdot
.672 .1295 Mdot
.672 .12965 Mdot
.672 .12987 Mdot
.672 .13107 Mdot
.672 .13143 Mdot
.672 .13155 Mdot
.672 .13187 Mdot
.672 .13198 Mdot
.672 .13205 Mdot
.672 .1325 Mdot
.672 .13346 Mdot
.672 .13346 Mdot
.672 .13382 Mdot
.672 .13422 Mdot
.672 .13439 Mdot
.672 .13439 Mdot
.672 .13453 Mdot
.672 .13467 Mdot
.672 .13506 Mdot
.672 .13538 Mdot
.672 .13573 Mdot
.672 .13632 Mdot
.672 .13637 Mdot
.672 .13653 Mdot
.672 .13689 Mdot
.672 .137 Mdot
.672 .13715 Mdot
.672 .13805 Mdot
.672 .13824 Mdot
.672 .13838 Mdot
.672 .13846 Mdot
.672 .13884 Mdot
.672 .13901 Mdot
.672 .13909 Mdot
.672 .13958 Mdot
.672 .13963 Mdot
.672 .14007 Mdot
.672 .14034 Mdot
.672 .14058 Mdot
.672 .14081 Mdot
.672 .14114 Mdot
.672 .14138 Mdot
.672 .14144 Mdot
.672 .14151 Mdot
.672 .14157 Mdot
.672 .14209 Mdot
.672 .14211 Mdot
.672 .14212 Mdot
.672 .14273 Mdot
.672 .14335 Mdot
.672 .14354 Mdot
.672 .1439 Mdot
.672 .14396 Mdot
.672 .14456 Mdot
.672 .14507 Mdot
.672 .14551 Mdot
.672 .14554 Mdot
.672 .14577 Mdot
.672 .1462 Mdot
.672 .14649 Mdot
.672 .14652 Mdot
.672 .14673 Mdot
.672 .14728 Mdot
.672 .14766 Mdot
.672 .14766 Mdot
.672 .14788 Mdot
.672 .14795 Mdot
.672 .14799 Mdot
.672 .14824 Mdot
.672 .14931 Mdot
.672 .14937 Mdot
.672 .14958 Mdot
.672 .14995 Mdot
.672 .1506 Mdot
.672 .15061 Mdot
.672 .1508 Mdot
.672 .15096 Mdot
.672 .15132 Mdot
.672 .1516 Mdot
.672 .15218 Mdot
.672 .15302 Mdot
.672 .15337 Mdot
.672 .15386 Mdot
.672 .15445 Mdot
.672 .15511 Mdot
.672 .15511 Mdot
.672 .15571 Mdot
.672 .15598 Mdot
.672 .15649 Mdot
.672 .15681 Mdot
.672 .15686 Mdot
.672 .15698 Mdot
.672 .15714 Mdot
.672 .1575 Mdot
.672 .15761 Mdot
.672 .15782 Mdot
.672 .15796 Mdot
.672 .15801 Mdot
.672 .15802 Mdot
.672 .15803 Mdot
.672 .15887 Mdot
.672 .15907 Mdot
.672 .15935 Mdot
.672 .15936 Mdot
.672 .15939 Mdot
.672 .15969 Mdot
.672 .16043 Mdot
.672 .16075 Mdot
.672 .161 Mdot
.672 .16105 Mdot
.672 .16202 Mdot
.672 .16205 Mdot
.672 .16425 Mdot
.672 .16471 Mdot
.672 .16485 Mdot
.672 .16509 Mdot
.672 .16526 Mdot
.672 .1664 Mdot
.672 .16683 Mdot
.672 .16689 Mdot
.672 .16852 Mdot
.672 .16852 Mdot
.672 .16884 Mdot
.672 .16899 Mdot
.672 .16919 Mdot
.672 .16949 Mdot
.672 .1711 Mdot
.672 .17158 Mdot
.672 .17174 Mdot
.672 .17217 Mdot
.672 .17232 Mdot
.672 .17241 Mdot
.672 .17301 Mdot
.672 .1743 Mdot
.672 .17431 Mdot
.672 .17479 Mdot
.672 .17533 Mdot
.672 .17555 Mdot
.672 .17556 Mdot
.672 .17574 Mdot
.672 .17593 Mdot
.672 .17646 Mdot
.672 .17689 Mdot
.672 .17735 Mdot
.672 .17815 Mdot
.672 .17822 Mdot
.672 .17843 Mdot
.672 .17892 Mdot
.672 .17907 Mdot
.672 .17927 Mdot
.672 .18048 Mdot
.672 .18073 Mdot
.672 .18092 Mdot
.672 .18103 Mdot
.672 .18154 Mdot
.672 .18177 Mdot
.672 .18187 Mdot
.672 .18253 Mdot
.672 .1826 Mdot
.672 .18319 Mdot
.672 .18356 Mdot
.672 .18387 Mdot
.672 .18419 Mdot
.672 .18464 Mdot
.672 .18495 Mdot
.672 .18503 Mdot
.672 .18512 Mdot
.672 .18521 Mdot
.672 .1859 Mdot
.672 .18593 Mdot
.672 .18594 Mdot
.672 .18677 Mdot
.672 .1876 Mdot
.672 .18786 Mdot
.672 .18834 Mdot
.672 .18842 Mdot
.672 .18922 Mdot
.672 .18991 Mdot
.672 .19051 Mdot
.672 .19055 Mdot
.672 .19086 Mdot
.672 .19143 Mdot
.672 .19182 Mdot
.672 .19186 Mdot
.672 .19215 Mdot
.672 .19288 Mdot
.672 .1934 Mdot
.672 .1934 Mdot
.672 .19368 Mdot
.672 .19378 Mdot
.672 .19383 Mdot
.672 .19417 Mdot
.672 .19561 Mdot
.672 .19569 Mdot
.672 .19597 Mdot
.672 .19647 Mdot
.672 .19734 Mdot
.672 .19736 Mdot
.672 .19762 Mdot
.672 .19782 Mdot
.672 .19831 Mdot
.672 .19868 Mdot
.672 .19947 Mdot
.672 .2006 Mdot
.672 .20106 Mdot
.672 .20173 Mdot
.672 .20252 Mdot
.672 .2034 Mdot
.672 .2034 Mdot
.672 .20421 Mdot
.672 .20458 Mdot
.672 .20526 Mdot
.672 .2057 Mdot
.672 .20576 Mdot
.672 .20592 Mdot
.672 .20614 Mdot
.672 .20662 Mdot
.672 .20677 Mdot
.672 .20705 Mdot
.672 .20724 Mdot
.672 .2073 Mdot
.672 .20732 Mdot
.672 .20733 Mdot
.672 .20846 Mdot
.672 .20872 Mdot
.672 .2091 Mdot
.672 .20911 Mdot
.672 .20916 Mdot
.672 .20956 Mdot
.672 .21056 Mdot
.672 .21099 Mdot
.672 .21132 Mdot
.672 .21139 Mdot
.672 .2127 Mdot
.672 .21274 Mdot
.672 .21569 Mdot
.672 .21631 Mdot
.672 .2165 Mdot
.672 .21682 Mdot
.672 .21705 Mdot
.672 .21857 Mdot
.672 .21915 Mdot
.672 .21924 Mdot
.672 .22143 Mdot
.672 .22143 Mdot
.672 .22186 Mdot
.672 .22206 Mdot
.672 .22233 Mdot
.672 .22273 Mdot
.672 .22489 Mdot
.672 .22555 Mdot
.672 .22575 Mdot
.672 .22633 Mdot
.672 .22653 Mdot
.672 .22666 Mdot
.672 .22747 Mdot
.672 .2292 Mdot
.672 .22921 Mdot
.672 .22986 Mdot
.672 .23058 Mdot
.672 .23088 Mdot
.672 .23088 Mdot
.672 .23114 Mdot
.672 .23139 Mdot
.672 .2321 Mdot
.672 .23268 Mdot
.672 .2333 Mdot
.672 .23438 Mdot
.672 .23446 Mdot
.672 .23475 Mdot
.672 .23541 Mdot
.672 .23561 Mdot
.672 .23588 Mdot
.672 .2375 Mdot
.672 .23784 Mdot
.672 .23809 Mdot
.672 .23824 Mdot
.672 .23893 Mdot
.672 .23923 Mdot
.672 .23937 Mdot
.672 .24026 Mdot
.672 .24035 Mdot
.672 .24114 Mdot
.672 .24164 Mdot
.672 .24206 Mdot
.672 .24249 Mdot
.672 .24309 Mdot
.672 .24351 Mdot
.672 .24362 Mdot
.672 .24374 Mdot
.672 .24386 Mdot
.672 .24479 Mdot
.672 .24483 Mdot
.672 .24485 Mdot
.672 .24596 Mdot
.672 .24707 Mdot
.672 .24742 Mdot
.672 .24807 Mdot
.672 .24818 Mdot
.672 .24925 Mdot
.672 .25017 Mdot
.672 .25098 Mdot
.672 .25103 Mdot
.672 .25145 Mdot
.672 .25222 Mdot
.672 .25274 Mdot
.672 .2528 Mdot
.672 .25318 Mdot
.672 .25417 Mdot
.672 .25486 Mdot
.672 .25486 Mdot
.672 .25525 Mdot
.672 .25538 Mdot
.672 .25545 Mdot
.672 .2559 Mdot
.672 .25783 Mdot
.672 .25794 Mdot
.672 .25833 Mdot
.672 .259 Mdot
.672 .26017 Mdot
.672 .26019 Mdot
.672 .26054 Mdot
.672 .26081 Mdot
.672 .26147 Mdot
.672 .26197 Mdot
.672 .26302 Mdot
.672 .26455 Mdot
.672 .26516 Mdot
.672 .26606 Mdot
.672 .26712 Mdot
.672 .26831 Mdot
.672 .26831 Mdot
.672 .2694 Mdot
.672 .2699 Mdot
.672 .27081 Mdot
.672 .27139 Mdot
.672 .27148 Mdot
.672 .2717 Mdot
.672 .27199 Mdot
.672 .27264 Mdot
.672 .27283 Mdot
.672 .27322 Mdot
.672 .27346 Mdot
.672 .27355 Mdot
.672 .27358 Mdot
.672 .27359 Mdot
.672 .27511 Mdot
.672 .27546 Mdot
.672 .27597 Mdot
.672 .27598 Mdot
.672 .27605 Mdot
.672 .27658 Mdot
.672 .27793 Mdot
.672 .27851 Mdot
.672 .27896 Mdot
.672 .27905 Mdot
.672 .2808 Mdot
.672 .28086 Mdot
.672 .28483 Mdot
.672 .28565 Mdot
.672 .28591 Mdot
.672 .28635 Mdot
.672 .28666 Mdot
.672 .2887 Mdot
.672 .28948 Mdot
.672 .2896 Mdot
.672 .29254 Mdot
.672 .29255 Mdot
.672 .29312 Mdot
.672 .29338 Mdot
.672 .29375 Mdot
.672 .29429 Mdot
.672 .29719 Mdot
.672 .29807 Mdot
.672 .29835 Mdot
.672 .29913 Mdot
.672 .29939 Mdot
.672 .29957 Mdot
.672 .30065 Mdot
.672 .30298 Mdot
.672 .30299 Mdot
.672 .30387 Mdot
.672 .30484 Mdot
.672 .30524 Mdot
.672 .30525 Mdot
.672 .30559 Mdot
.672 .30593 Mdot
.672 .30688 Mdot
.672 .30767 Mdot
.672 .3085 Mdot
.672 .30994 Mdot
.672 .31006 Mdot
.672 .31044 Mdot
.672 .31133 Mdot
.672 .3116 Mdot
.672 .31196 Mdot
.672 .31413 Mdot
.672 .3146 Mdot
.672 .31493 Mdot
.672 .31513 Mdot
.672 .31606 Mdot
.672 .31647 Mdot
.672 .31665 Mdot
.672 .31785 Mdot
.672 .31797 Mdot
.672 .31903 Mdot
.672 .3197 Mdot
.672 .32027 Mdot
.672 .32085 Mdot
.672 .32165 Mdot
.672 .32222 Mdot
.672 .32236 Mdot
.672 .32253 Mdot
.672 .32268 Mdot
.672 .32394 Mdot
.672 .32399 Mdot
.672 .32401 Mdot
.672 .3255 Mdot
.672 .32699 Mdot
.672 .32747 Mdot
.672 .32834 Mdot
.672 .32849 Mdot
.672 .32994 Mdot
.672 .33117 Mdot
.672 .33225 Mdot
.672 .33233 Mdot
.672 .33289 Mdot
.672 .33392 Mdot
.672 .33462 Mdot
.672 .3347 Mdot
.672 .33522 Mdot
.672 .33655 Mdot
.672 .33747 Mdot
.672 .33747 Mdot
.672 .33799 Mdot
.672 .33817 Mdot
.672 .33826 Mdot
.672 .33887 Mdot
.672 .34146 Mdot
.672 .34161 Mdot
.672 .34213 Mdot
.672 .34303 Mdot
.672 .3446 Mdot
.672 .34463 Mdot
.672 .3451 Mdot
.672 .34547 Mdot
.672 .34636 Mdot
.672 .34702 Mdot
.672 .34844 Mdot
.672 .35049 Mdot
.672 .35132 Mdot
.672 .35253 Mdot
.672 .35395 Mdot
.672 .35554 Mdot
.672 .35555 Mdot
.672 .35702 Mdot
.672 .35768 Mdot
.672 .35891 Mdot
.672 .35969 Mdot
.672 .35981 Mdot
.672 .3601 Mdot
.672 .36049 Mdot
.672 .36137 Mdot
.672 .36163 Mdot
.672 .36214 Mdot
.672 .36247 Mdot
.672 .36259 Mdot
.672 .36262 Mdot
.672 .36265 Mdot
.672 .36469 Mdot
.672 .36516 Mdot
.672 .36584 Mdot
.672 .36586 Mdot
.672 .36595 Mdot
.672 .36667 Mdot
.672 .36847 Mdot
.672 .36926 Mdot
.672 .36986 Mdot
.672 .36997 Mdot
.672 .37234 Mdot
.672 .37241 Mdot
.672 .37774 Mdot
.672 .37886 Mdot
.672 .37921 Mdot
.672 .37979 Mdot
.672 .38021 Mdot
.672 .38295 Mdot
.672 .384 Mdot
.672 .38416 Mdot
.672 .38812 Mdot
.672 .38812 Mdot
.672 .38889 Mdot
.672 .38924 Mdot
.672 .38974 Mdot
.672 .39046 Mdot
.672 .39437 Mdot
.672 .39555 Mdot
.672 .39591 Mdot
.672 .39697 Mdot
.672 .39732 Mdot
.672 .39756 Mdot
.672 .39902 Mdot
.672 .40215 Mdot
.672 .40216 Mdot
.672 .40334 Mdot
.672 .40464 Mdot
.672 .40518 Mdot
.672 .40519 Mdot
.672 .40565 Mdot
.672 .4061 Mdot
.672 .40738 Mdot
.672 .40844 Mdot
.672 .40956 Mdot
.672 .4115 Mdot
.672 .41165 Mdot
.674 .01591 Mdot
.674 .01632 Mdot
.674 .01688 Mdot
.674 .01723 Mdot
.674 .01735 Mdot
.674 .01763 Mdot
.674 .01811 Mdot
.674 .01827 Mdot
.674 .01865 Mdot
.674 .01897 Mdot
.674 .01907 Mdot
.674 .01929 Mdot
.674 .01934 Mdot
.674 .0195 Mdot
.674 .01959 Mdot
.674 .01975 Mdot
.674 .02001 Mdot
.674 .02026 Mdot
.674 .02045 Mdot
.674 .02058 Mdot
.674 .02088 Mdot
.674 .02094 Mdot
.674 .02117 Mdot
.674 .02129 Mdot
.674 .02151 Mdot
.674 .02186 Mdot
.674 .02219 Mdot
.674 .02245 Mdot
.674 .02262 Mdot
.674 .02263 Mdot
.674 .02303 Mdot
.674 .02311 Mdot
.674 .02342 Mdot
.674 .02355 Mdot
.674 .02357 Mdot
.674 .02364 Mdot
.674 .02387 Mdot
.674 .02435 Mdot
.674 .0248 Mdot
.674 .02514 Mdot
.674 .02537 Mdot
.674 .02539 Mdot
.674 .02592 Mdot
.674 .02603 Mdot
.674 .02604 Mdot
.674 .02633 Mdot
.674 .02644 Mdot
.674 .02662 Mdot
.674 .02666 Mdot
.674 .02675 Mdot
.674 .02706 Mdot
.674 .02707 Mdot
.674 .0277 Mdot
.674 .0278 Mdot
.674 .0283 Mdot
.674 .02849 Mdot
.674 .02876 Mdot
.674 .02899 Mdot
.674 .02906 Mdot
.674 .02908 Mdot
.674 .0291 Mdot
.674 .02982 Mdot
.674 .02997 Mdot
.674 .02997 Mdot
.674 .03037 Mdot
.674 .03053 Mdot
.674 .03076 Mdot
.674 .03081 Mdot
.674 .03089 Mdot
.674 .03093 Mdot
.674 .0312 Mdot
.674 .03134 Mdot
.674 .03135 Mdot
.674 .03136 Mdot
.674 .03221 Mdot
.674 .03236 Mdot
.674 .03303 Mdot
.674 .03328 Mdot
.674 .03365 Mdot
.674 .03396 Mdot
.674 .03405 Mdot
.674 .03408 Mdot
.674 .03411 Mdot
.674 .03415 Mdot
.674 .03448 Mdot
.674 .03508 Mdot
.674 .03528 Mdot
.674 .03528 Mdot
.674 .03582 Mdot
.674 .03603 Mdot
.674 .03634 Mdot
.674 .03641 Mdot
.674 .03652 Mdot
.674 .03658 Mdot
.674 .03693 Mdot
.674 .03712 Mdot
.674 .03714 Mdot
.674 .03716 Mdot
.674 .0383 Mdot
.674 .03835 Mdot
.674 .0385 Mdot
.674 .03941 Mdot
.674 .03949 Mdot
.674 .03974 Mdot
.674 .04025 Mdot
.674 .04049 Mdot
.674 .04066 Mdot
.674 .04078 Mdot
.674 .04083 Mdot
.674 .04086 Mdot
.674 .04091 Mdot
.674 .04135 Mdot
.674 .04217 Mdot
.674 .04221 Mdot
.674 .04237 Mdot
.674 .04244 Mdot
.674 .04244 Mdot
.674 .04261 Mdot
.674 .04316 Mdot
.674 .04344 Mdot
.674 .04387 Mdot
.674 .04397 Mdot
.674 .04411 Mdot
.674 .04418 Mdot
.674 .04426 Mdot
.674 .04462 Mdot
.674 .04466 Mdot
.674 .04492 Mdot
.674 .04495 Mdot
.674 .04497 Mdot
.674 .04576 Mdot
.674 .04601 Mdot
.674 .04651 Mdot
.674 .04658 Mdot
.674 .04678 Mdot
.674 .048 Mdot
.674 .048 Mdot
.674 .04811 Mdot
.674 .04812 Mdot
.674 .04831 Mdot
.674 .04844 Mdot
.674 .04845 Mdot
.674 .04908 Mdot
.674 .04913 Mdot
.674 .04921 Mdot
.674 .04946 Mdot
.674 .04969 Mdot
.674 .04985 Mdot
.674 .04991 Mdot
.674 .04996 Mdot
.674 .05002 Mdot
.674 .05032 Mdot
.674 .05062 Mdot
.674 .0508 Mdot
.674 .05111 Mdot
.674 .05117 Mdot
.674 .05166 Mdot
.674 .05172 Mdot
.674 .05178 Mdot
.674 .052 Mdot
.674 .05208 Mdot
.674 .05209 Mdot
.674 .05231 Mdot
.674 .05306 Mdot
.674 .05344 Mdot
.674 .05352 Mdot
.674 .05402 Mdot
.674 .05412 Mdot
.674 .05414 Mdot
.674 .05434 Mdot
.674 .05444 Mdot
.674 .05454 Mdot
.674 .05503 Mdot
.674 .05508 Mdot
.674 .05543 Mdot
.674 .05547 Mdot
.674 .05549 Mdot
.674 .05563 Mdot
.674 .05596 Mdot
.674 .05623 Mdot
.674 .05643 Mdot
.674 .05656 Mdot
.674 .0569 Mdot
.674 .05758 Mdot
.674 .05767 Mdot
.674 .05793 Mdot
.674 .05874 Mdot
.674 .05958 Mdot
.674 .05958 Mdot
.674 .05973 Mdot
.674 .05974 Mdot
.674 .06 Mdot
.674 .06006 Mdot
.674 .06017 Mdot
.674 .0602 Mdot
.674 .06044 Mdot
.674 .06059 Mdot
.674 .06072 Mdot
.674 .06095 Mdot
.674 .06103 Mdot
.674 .06111 Mdot
.674 .06121 Mdot
.674 .06155 Mdot
.674 .06186 Mdot
.674 .06208 Mdot
.674 .06216 Mdot
.674 .06222 Mdot
.674 .06225 Mdot
.674 .06231 Mdot
.674 .06271 Mdot
.674 .06312 Mdot
.674 .06336 Mdot
.674 .06377 Mdot
.674 .06386 Mdot
.674 .06452 Mdot
.674 .0646 Mdot
.674 .06468 Mdot
.674 .06498 Mdot
.674 .06509 Mdot
.674 .0651 Mdot
.674 .0654 Mdot
.674 .06576 Mdot
.674 .066 Mdot
.674 .06605 Mdot
.674 .0664 Mdot
.674 .06692 Mdot
.674 .06703 Mdot
.674 .06769 Mdot
.674 .06783 Mdot
.674 .06787 Mdot
.674 .06813 Mdot
.674 .06815 Mdot
.674 .06826 Mdot
.674 .0684 Mdot
.674 .0685 Mdot
.674 .06879 Mdot
.674 .06906 Mdot
.674 .0691 Mdot
.674 .06913 Mdot
.674 .06915 Mdot
.674 .0696 Mdot
.674 .06965 Mdot
.674 .06969 Mdot
.674 .06987 Mdot
.674 .07031 Mdot
.674 .07068 Mdot
.674 .07072 Mdot
.674 .07092 Mdot
.674 .07095 Mdot
.674 .07112 Mdot
.674 .07157 Mdot
.674 .07231 Mdot
.674 .07249 Mdot
.674 .07262 Mdot
.674 .07297 Mdot
.674 .07406 Mdot
.674 .07471 Mdot
.674 .07519 Mdot
.674 .0752 Mdot
.674 .07539 Mdot
.674 .07541 Mdot
.674 .07576 Mdot
.674 .07584 Mdot
.674 .07599 Mdot
.674 .07601 Mdot
.674 .07602 Mdot
.674 .07635 Mdot
.674 .07655 Mdot
.674 .07674 Mdot
.674 .07703 Mdot
.674 .07715 Mdot
.674 .07725 Mdot
.674 .0774 Mdot
.674 .07784 Mdot
.674 .07826 Mdot
.674 .07854 Mdot
.674 .07856 Mdot
.674 .07867 Mdot
.674 .07875 Mdot
.674 .07879 Mdot
.674 .07887 Mdot
.674 .07941 Mdot
.674 .07997 Mdot
.674 .08029 Mdot
.674 .08084 Mdot
.674 .08096 Mdot
.674 .08186 Mdot
.674 .08196 Mdot
.674 .08199 Mdot
.674 .08207 Mdot
.674 .08247 Mdot
.674 .08262 Mdot
.674 .08263 Mdot
.674 .08303 Mdot
.674 .08344 Mdot
.674 .08353 Mdot
.674 .08384 Mdot
.674 .08392 Mdot
.674 .08439 Mdot
.674 .08444 Mdot
.674 .08509 Mdot
.674 .08523 Mdot
.674 .08544 Mdot
.674 .08573 Mdot
.674 .08613 Mdot
.674 .08632 Mdot
.674 .08636 Mdot
.674 .08671 Mdot
.674 .08675 Mdot
.674 .0869 Mdot
.674 .08708 Mdot
.674 .08716 Mdot
.674 .08721 Mdot
.674 .0873 Mdot
.674 .08761 Mdot
.674 .08797 Mdot
.674 .08802 Mdot
.674 .08807 Mdot
.674 .0881 Mdot
.674 .0887 Mdot
.674 .08877 Mdot
.674 .08882 Mdot
.674 .08907 Mdot
.674 .08965 Mdot
.674 .08969 Mdot
.674 .09016 Mdot
.674 .09021 Mdot
.674 .09048 Mdot
.674 .09051 Mdot
.674 .09075 Mdot
.674 .09136 Mdot
.674 .09236 Mdot
.674 .0926 Mdot
.674 .09277 Mdot
.674 .09322 Mdot
.674 .09325 Mdot
.674 .09471 Mdot
.674 .09559 Mdot
.674 .09559 Mdot
.674 .09612 Mdot
.674 .09623 Mdot
.674 .09625 Mdot
.674 .09651 Mdot
.674 .09653 Mdot
.674 .097 Mdot
.674 .09711 Mdot
.674 .09732 Mdot
.674 .09733 Mdot
.674 .09736 Mdot
.674 .0978 Mdot
.674 .09807 Mdot
.674 .09832 Mdot
.674 .09846 Mdot
.674 .09872 Mdot
.674 .09888 Mdot
.674 .09901 Mdot
.674 .09921 Mdot
.674 .09981 Mdot
.674 .10038 Mdot
.674 .10075 Mdot
.674 .10078 Mdot
.674 .10093 Mdot
.674 .10104 Mdot
.674 .10109 Mdot
.674 .1012 Mdot
.674 .10139 Mdot
.674 .1014 Mdot
.674 .10193 Mdot
.674 .10267 Mdot
.674 .10311 Mdot
.674 .10386 Mdot
.674 .10401 Mdot
.674 .10453 Mdot
.674 .10522 Mdot
.674 .10524 Mdot
.674 .1053 Mdot
.674 .10536 Mdot
.674 .1054 Mdot
.674 .10551 Mdot
.674 .10604 Mdot
.674 .10625 Mdot
.674 .10627 Mdot
.674 .10681 Mdot
.674 .10687 Mdot
.674 .10704 Mdot
.674 .10736 Mdot
.674 .10747 Mdot
.674 .1079 Mdot
.674 .108 Mdot
.674 .10863 Mdot
.674 .1087 Mdot
.674 .10958 Mdot
.674 .10977 Mdot
.674 .10983 Mdot
.674 .11006 Mdot
.674 .11044 Mdot
.674 .11048 Mdot
.674 .11098 Mdot
.674 .11124 Mdot
.674 .1113 Mdot
.674 .11174 Mdot
.674 .11177 Mdot
.674 .11181 Mdot
.674 .11184 Mdot
.674 .11198 Mdot
.674 .11201 Mdot
.674 .11226 Mdot
.674 .11237 Mdot
.674 .11244 Mdot
.674 .11257 Mdot
.674 .11298 Mdot
.674 .11346 Mdot
.674 .11353 Mdot
.674 .11359 Mdot
.674 .11364 Mdot
.674 .11445 Mdot
.674 .11454 Mdot
.674 .11457 Mdot
.674 .1146 Mdot
.674 .11465 Mdot
.674 .11494 Mdot
.674 .11573 Mdot
.674 .11579 Mdot
.674 .11627 Mdot
.674 .11641 Mdot
.674 .11648 Mdot
.674 .11685 Mdot
.674 .11689 Mdot
.674 .11721 Mdot
.674 .11774 Mdot
.674 .11804 Mdot
.674 .11861 Mdot
.674 .11938 Mdot
.674 .11971 Mdot
.674 .11993 Mdot
.674 .12016 Mdot
.674 .12022 Mdot
.674 .12054 Mdot
.674 .12057 Mdot
.674 .12111 Mdot
.674 .1219 Mdot
.674 .12255 Mdot
.674 .12308 Mdot
.674 .12374 Mdot
.674 .12374 Mdot
.674 .12444 Mdot
.674 .1246 Mdot
.674 .12462 Mdot
.674 .12497 Mdot
.674 .12501 Mdot
.674 .12563 Mdot
.674 .12578 Mdot
.674 .12606 Mdot
.674 .12609 Mdot
.674 .12612 Mdot
.674 .1267 Mdot
.674 .12672 Mdot
.674 .12708 Mdot
.674 .12741 Mdot
.674 .12761 Mdot
.674 .12795 Mdot
.674 .12797 Mdot
.674 .12817 Mdot
.674 .12835 Mdot
.674 .12861 Mdot
.674 .12942 Mdot
.674 .12971 Mdot
.674 .1301 Mdot
.674 .13019 Mdot
.674 .1307 Mdot
.674 .13073 Mdot
.674 .13093 Mdot
.674 .13108 Mdot
.674 .13115 Mdot
.674 .1313 Mdot
.674 .13156 Mdot
.674 .13156 Mdot
.674 .13228 Mdot
.674 .13236 Mdot
.674 .13251 Mdot
.674 .13328 Mdot
.674 .1334 Mdot
.674 .13387 Mdot
.674 .13407 Mdot
.674 .13438 Mdot
.674 .13488 Mdot
.674 .13505 Mdot
.674 .13509 Mdot
.674 .13579 Mdot
.674 .13619 Mdot
.674 .13623 Mdot
.674 .13672 Mdot
.674 .13675 Mdot
.674 .13683 Mdot
.674 .1369 Mdot
.674 .13695 Mdot
.674 .13711 Mdot
.674 .13783 Mdot
.674 .1381 Mdot
.674 .13813 Mdot
.674 .13886 Mdot
.674 .13894 Mdot
.674 .13917 Mdot
.674 .13939 Mdot
.674 .1396 Mdot
.674 .13975 Mdot
.674 .13977 Mdot
.674 .14033 Mdot
.674 .14042 Mdot
.674 .14046 Mdot
.674 .14131 Mdot
.674 .14141 Mdot
.674 .14259 Mdot
.674 .14285 Mdot
.674 .14293 Mdot
.674 .14323 Mdot
.674 .14376 Mdot
.674 .14381 Mdot
.674 .14388 Mdot
.674 .14438 Mdot
.674 .14449 Mdot
.674 .14483 Mdot
.674 .1449 Mdot
.674 .14551 Mdot
.674 .14554 Mdot
.674 .1456 Mdot
.674 .14564 Mdot
.674 .14583 Mdot
.674 .14588 Mdot
.674 .14621 Mdot
.674 .14636 Mdot
.674 .14645 Mdot
.674 .14647 Mdot
.674 .14662 Mdot
.674 .14718 Mdot
.674 .14736 Mdot
.674 .14782 Mdot
.674 .14792 Mdot
.674 .148 Mdot
.674 .14806 Mdot
.674 .14876 Mdot
.674 .14916 Mdot
.674 .14928 Mdot
.674 .14932 Mdot
.674 .14936 Mdot
.674 .14943 Mdot
.674 .14982 Mdot
.674 .15089 Mdot
.674 .15096 Mdot
.674 .15098 Mdot
.674 .15161 Mdot
.674 .15172 Mdot
.674 .15181 Mdot
.674 .1519 Mdot
.674 .15192 Mdot
.674 .15239 Mdot
.674 .15245 Mdot
.674 .15287 Mdot
.674 .1536 Mdot
.674 .15399 Mdot
.674 .15476 Mdot
.674 .1558 Mdot
.674 .15624 Mdot
.674 .15654 Mdot
.674 .15685 Mdot
.674 .15694 Mdot
.674 .15737 Mdot
.674 .15741 Mdot
.674 .15814 Mdot
.674 .1592 Mdot
.674 .16008 Mdot
.674 .16079 Mdot
.674 .16168 Mdot
.674 .16168 Mdot
.674 .16263 Mdot
.674 .16285 Mdot
.674 .16286 Mdot
.674 .16334 Mdot
.674 .16339 Mdot
.674 .16424 Mdot
.674 .16443 Mdot
.674 .16481 Mdot
.674 .16484 Mdot
.674 .16489 Mdot
.674 .16567 Mdot
.674 .16569 Mdot
.674 .16618 Mdot
.674 .16663 Mdot
.674 .16689 Mdot
.674 .16736 Mdot
.674 .16738 Mdot
.674 .16765 Mdot
.674 .16789 Mdot
.674 .16825 Mdot
.674 .16934 Mdot
.674 .16973 Mdot
.674 .17026 Mdot
.674 .17037 Mdot
.674 .17106 Mdot
.674 .1711 Mdot
.674 .17137 Mdot
.674 .17157 Mdot
.674 .17167 Mdot
.674 .17187 Mdot
.674 .17222 Mdot
.674 .17223 Mdot
.674 .17319 Mdot
.674 .1733 Mdot
.674 .1735 Mdot
.674 .17455 Mdot
.674 .1747 Mdot
.674 .17533 Mdot
.674 .1756 Mdot
.674 .17603 Mdot
.674 .1767 Mdot
.674 .17692 Mdot
.674 .17698 Mdot
.674 .17792 Mdot
.674 .17846 Mdot
.674 .17851 Mdot
.674 .17917 Mdot
.674 .17921 Mdot
.674 .17932 Mdot
.674 .17943 Mdot
.674 .17949 Mdot
.674 .1797 Mdot
.674 .18067 Mdot
.674 .18104 Mdot
.674 .18108 Mdot
.674 .18206 Mdot
.674 .18218 Mdot
.674 .18248 Mdot
.674 .18278 Mdot
.674 .18306 Mdot
.674 .18327 Mdot
.674 .18329 Mdot
.674 .18404 Mdot
.674 .18416 Mdot
.674 .18422 Mdot
.674 .18537 Mdot
.674 .1855 Mdot
.674 .18709 Mdot
.674 .18755 Mdot
.674 .18796 Mdot
.674 .18866 Mdot
.674 .18873 Mdot
.674 .18882 Mdot
.674 .1895 Mdot
.674 .18965 Mdot
.674 .19011 Mdot
.674 .19021 Mdot
.674 .19102 Mdot
.674 .19107 Mdot
.674 .19115 Mdot
.674 .1912 Mdot
.674 .19146 Mdot
.674 .19152 Mdot
.674 .19197 Mdot
.674 .19217 Mdot
.674 .19229 Mdot
.674 .19232 Mdot
.674 .19252 Mdot
.674 .19328 Mdot
.674 .19352 Mdot
.674 .19414 Mdot
.674 .19427 Mdot
.674 .19439 Mdot
.674 .19447 Mdot
.674 .19541 Mdot
.674 .19595 Mdot
.674 .1961 Mdot
.674 .19616 Mdot
.674 .19622 Mdot
.674 .19631 Mdot
.674 .19684 Mdot
.674 .19828 Mdot
.674 .19837 Mdot
.674 .19839 Mdot
.674 .19925 Mdot
.674 .19939 Mdot
.674 .19951 Mdot
.674 .19964 Mdot
.674 .19966 Mdot
.674 .2003 Mdot
.674 .20038 Mdot
.674 .20095 Mdot
.674 .20193 Mdot
.674 .20246 Mdot
.674 .20349 Mdot
.674 .2049 Mdot
.674 .20549 Mdot
.674 .2059 Mdot
.674 .20631 Mdot
.674 .20643 Mdot
.674 .20701 Mdot
.674 .20707 Mdot
.674 .20805 Mdot
.674 .20949 Mdot
.674 .21067 Mdot
.674 .21163 Mdot
.674 .21282 Mdot
.674 .21283 Mdot
.674 .2141 Mdot
.674 .21439 Mdot
.674 .21442 Mdot
.674 .21506 Mdot
.674 .21513 Mdot
.674 .21627 Mdot
.674 .21653 Mdot
.674 .21705 Mdot
.674 .21709 Mdot
.674 .21715 Mdot
.674 .2182 Mdot
.674 .21824 Mdot
.674 .2189 Mdot
.674 .2195 Mdot
.674 .21985 Mdot
.674 .22048 Mdot
.674 .22051 Mdot
.674 .22087 Mdot
.674 .2212 Mdot
.674 .22168 Mdot
.674 .22315 Mdot
.674 .22367 Mdot
.674 .22438 Mdot
.674 .22454 Mdot
.674 .22547 Mdot
.674 .22553 Mdot
.674 .22589 Mdot
.674 .22616 Mdot
.674 .22629 Mdot
.674 .22656 Mdot
.674 .22703 Mdot
.674 .22704 Mdot
.674 .22834 Mdot
.674 .22849 Mdot
.674 .22876 Mdot
.674 .23017 Mdot
.674 .23037 Mdot
.674 .23123 Mdot
.674 .23159 Mdot
.674 .23216 Mdot
.674 .23307 Mdot
.674 .23337 Mdot
.674 .23345 Mdot
.674 .23472 Mdot
.674 .23545 Mdot
.674 .23551 Mdot
.674 .2364 Mdot
.674 .23646 Mdot
.674 .23661 Mdot
.674 .23675 Mdot
.674 .23684 Mdot
.674 .23712 Mdot
.674 .23842 Mdot
.674 .23892 Mdot
.674 .23897 Mdot
.674 .24029 Mdot
.674 .24045 Mdot
.674 .24086 Mdot
.674 .24127 Mdot
.674 .24164 Mdot
.674 .24192 Mdot
.674 .24196 Mdot
.674 .24296 Mdot
.674 .24313 Mdot
.674 .24321 Mdot
.674 .24476 Mdot
.674 .24494 Mdot
.674 .24707 Mdot
.674 .2477 Mdot
.674 .24825 Mdot
.674 .2492 Mdot
.674 .24928 Mdot
.674 .24941 Mdot
.674 .25032 Mdot
.674 .25052 Mdot
.674 .25115 Mdot
.674 .25128 Mdot
.674 .25238 Mdot
.674 .25244 Mdot
.674 .25255 Mdot
.674 .25262 Mdot
.674 .25297 Mdot
.674 .25305 Mdot
.674 .25366 Mdot
.674 .25392 Mdot
.674 .25409 Mdot
.674 .25413 Mdot
.674 .2544 Mdot
.674 .25542 Mdot
.674 .25575 Mdot
.674 .25658 Mdot
.674 .25676 Mdot
.674 .25691 Mdot
.674 .25702 Mdot
.674 .25829 Mdot
.674 .25902 Mdot
.674 .25923 Mdot
.674 .25931 Mdot
.674 .25938 Mdot
.674 .2595 Mdot
.674 .26022 Mdot
.674 .26216 Mdot
.674 .26228 Mdot
.674 .26232 Mdot
.674 .26347 Mdot
.674 .26366 Mdot
.674 .26382 Mdot
.674 .26399 Mdot
.674 .26402 Mdot
.674 .26488 Mdot
.674 .26499 Mdot
.674 .26576 Mdot
.674 .26708 Mdot
.674 .26779 Mdot
.674 .26919 Mdot
.674 .27108 Mdot
.674 .27189 Mdot
.674 .27243 Mdot
.674 .27299 Mdot
.674 .27314 Mdot
.674 .27393 Mdot
.674 .27401 Mdot
.674 .27533 Mdot
.674 .27727 Mdot
.674 .27886 Mdot
.674 .28015 Mdot
.674 .28176 Mdot
.674 .28177 Mdot
.674 .28349 Mdot
.674 .28388 Mdot
.674 .28392 Mdot
.674 .28478 Mdot
.674 .28487 Mdot
.674 .28641 Mdot
.674 .28676 Mdot
.674 .28746 Mdot
.674 .28751 Mdot
.674 .28759 Mdot
.674 .28902 Mdot
.674 .28906 Mdot
.674 .28995 Mdot
.674 .29076 Mdot
.674 .29124 Mdot
.674 .29209 Mdot
.674 .29213 Mdot
.674 .29262 Mdot
.674 .29305 Mdot
.674 .2937 Mdot
.674 .29569 Mdot
.674 .29639 Mdot
.674 .29735 Mdot
.674 .29756 Mdot
.674 .29881 Mdot
.674 .29889 Mdot
.674 .29938 Mdot
.674 .29975 Mdot
.674 .29992 Mdot
.674 .30028 Mdot
.674 .30091 Mdot
.674 .30093 Mdot
.674 .30268 Mdot
.674 .30289 Mdot
.674 .30324 Mdot
.674 .30514 Mdot
.674 .30542 Mdot
.674 .30657 Mdot
.674 .30706 Mdot
.674 .30783 Mdot
.674 .30905 Mdot
.674 .30946 Mdot
.674 .30957 Mdot
.674 .31128 Mdot
.674 .31226 Mdot
.674 .31235 Mdot
.674 .31355 Mdot
.674 .31362 Mdot
.674 .31382 Mdot
.674 .31401 Mdot
.674 .31413 Mdot
.674 .31451 Mdot
.674 .31627 Mdot
.674 .31695 Mdot
.674 .31702 Mdot
.674 .31879 Mdot
.674 .31901 Mdot
.674 .31956 Mdot
.674 .32011 Mdot
.674 .32061 Mdot
.674 .32099 Mdot
.674 .32104 Mdot
.674 .3224 Mdot
.674 .32262 Mdot
.674 .32273 Mdot
.674 .32481 Mdot
.674 .32506 Mdot
.674 .32793 Mdot
.674 .32878 Mdot
.674 .32951 Mdot
.674 .3308 Mdot
.674 .33092 Mdot
.674 .33109 Mdot
.674 .33231 Mdot
.674 .33258 Mdot
.674 .33342 Mdot
.674 .33361 Mdot
.674 .33509 Mdot
.674 .33517 Mdot
.674 .33532 Mdot
.674 .33541 Mdot
.674 .33589 Mdot
.674 .33599 Mdot
.674 .33681 Mdot
.674 .33717 Mdot
.674 .33739 Mdot
.674 .33744 Mdot
.674 .33781 Mdot
.674 .33918 Mdot
.674 .33963 Mdot
.674 .34075 Mdot
.674 .34099 Mdot
.674 .3412 Mdot
.674 .34134 Mdot
.674 .34306 Mdot
.674 .34403 Mdot
.674 .34432 Mdot
.674 .34443 Mdot
.674 .34453 Mdot
.674 .34469 Mdot
.674 .34566 Mdot
.674 .34826 Mdot
.674 .34844 Mdot
.674 .34848 Mdot
.674 .35004 Mdot
.674 .35029 Mdot
.674 .35051 Mdot
.674 .35074 Mdot
.674 .35078 Mdot
.674 .35194 Mdot
.674 .35209 Mdot
.674 .35313 Mdot
.674 .35491 Mdot
.674 .35586 Mdot
.674 .35775 Mdot
.674 .3603 Mdot
.674 .36138 Mdot
.674 .36212 Mdot
.674 .36286 Mdot
.674 .36308 Mdot
.674 .36414 Mdot
.674 .36425 Mdot
.674 .36602 Mdot
.674 .36864 Mdot
.674 .37078 Mdot
.674 .37252 Mdot
.674 .3747 Mdot
.674 .3747 Mdot
.674 .37703 Mdot
.674 .37755 Mdot
.674 .3776 Mdot
.674 .37876 Mdot
.674 .37889 Mdot
.674 .38096 Mdot
.674 .38144 Mdot
.674 .38237 Mdot
.674 .38245 Mdot
.674 .38255 Mdot
.674 .38447 Mdot
.674 .38453 Mdot
.674 .38573 Mdot
.674 .38683 Mdot
.674 .38747 Mdot
.674 .38862 Mdot
.674 .38866 Mdot
.674 .38932 Mdot
.674 .38991 Mdot
.674 .39079 Mdot
.674 .39347 Mdot
.674 .39441 Mdot
.674 .3957 Mdot
.674 .39599 Mdot
.674 .39767 Mdot
.674 .39778 Mdot
.674 .39844 Mdot
.674 .39894 Mdot
.674 .39917 Mdot
.674 .39966 Mdot
.674 .40051 Mdot
.674 .40054 Mdot
.674 .40289 Mdot
.674 .40317 Mdot
.674 .40365 Mdot
.674 .40621 Mdot
.674 .40658 Mdot
.674 .40814 Mdot
.674 .4088 Mdot
.674 .40984 Mdot
.674 .41148 Mdot
.674 .41203 Mdot
.674 .41218 Mdot
.676 .01475 Mdot
.676 .01476 Mdot
.676 .01478 Mdot
.676 .0148 Mdot
.676 .01483 Mdot
.676 .01487 Mdot
.676 .01488 Mdot
.676 .01492 Mdot
.676 .01494 Mdot
.676 .015 Mdot
.676 .01501 Mdot
.676 .01509 Mdot
.676 .01512 Mdot
.676 .01523 Mdot
.676 .01526 Mdot
.676 .01541 Mdot
.676 .01545 Mdot
.676 .01565 Mdot
.676 .01571 Mdot
.676 .01598 Mdot
.676 .01606 Mdot
.676 .01643 Mdot
.676 .01653 Mdot
.676 .01703 Mdot
.676 .01717 Mdot
.676 .0173 Mdot
.676 .01783 Mdot
.676 .01785 Mdot
.676 .01792 Mdot
.676 .01803 Mdot
.676 .01821 Mdot
.676 .01869 Mdot
.676 .01892 Mdot
.676 .01895 Mdot
.676 .01898 Mdot
.676 .01905 Mdot
.676 .0192 Mdot
.676 .01944 Mdot
.676 .01978 Mdot
.676 .02009 Mdot
.676 .0204 Mdot
.676 .02044 Mdot
.676 .02048 Mdot
.676 .02058 Mdot
.676 .02078 Mdot
.676 .02111 Mdot
.676 .02156 Mdot
.676 .02198 Mdot
.676 .0224 Mdot
.676 .02246 Mdot
.676 .02251 Mdot
.676 .02264 Mdot
.676 .02292 Mdot
.676 .02331 Mdot
.676 .02336 Mdot
.676 .02397 Mdot
.676 .02404 Mdot
.676 .02453 Mdot
.676 .02511 Mdot
.676 .02518 Mdot
.676 .02526 Mdot
.676 .02543 Mdot
.676 .02581 Mdot
.676 .02628 Mdot
.676 .02632 Mdot
.676 .02633 Mdot
.676 .0264 Mdot
.676 .027 Mdot
.676 .02723 Mdot
.676 .02732 Mdot
.676 .02797 Mdot
.676 .02799 Mdot
.676 .02839 Mdot
.676 .02867 Mdot
.676 .02877 Mdot
.676 .02886 Mdot
.676 .02897 Mdot
.676 .02921 Mdot
.676 .02971 Mdot
.676 .03035 Mdot
.676 .03041 Mdot
.676 .03042 Mdot
.676 .03051 Mdot
.676 .03082 Mdot
.676 .03133 Mdot
.676 .03163 Mdot
.676 .03176 Mdot
.676 .03228 Mdot
.676 .03264 Mdot
.676 .03266 Mdot
.676 .03321 Mdot
.676 .03331 Mdot
.676 .03338 Mdot
.676 .03357 Mdot
.676 .03358 Mdot
.676 .03372 Mdot
.676 .03385 Mdot
.676 .03398 Mdot
.676 .03431 Mdot
.676 .03499 Mdot
.676 .03569 Mdot
.676 .03585 Mdot
.676 .03593 Mdot
.676 .03595 Mdot
.676 .03607 Mdot
.676 .03649 Mdot
.676 .03705 Mdot
.676 .03718 Mdot
.676 .03759 Mdot
.676 .03776 Mdot
.676 .03789 Mdot
.676 .03802 Mdot
.676 .03847 Mdot
.676 .03895 Mdot
.676 .03898 Mdot
.676 .03972 Mdot
.676 .03985 Mdot
.676 .03995 Mdot
.676 .04021 Mdot
.676 .04022 Mdot
.676 .0404 Mdot
.676 .04058 Mdot
.676 .04077 Mdot
.676 .0412 Mdot
.676 .04211 Mdot
.676 .04212 Mdot
.676 .04223 Mdot
.676 .04274 Mdot
.676 .04302 Mdot
.676 .04308 Mdot
.676 .04308 Mdot
.676 .0432 Mdot
.676 .04329 Mdot
.676 .0434 Mdot
.676 .04343 Mdot
.676 .04359 Mdot
.676 .04415 Mdot
.676 .04489 Mdot
.676 .04491 Mdot
.676 .04509 Mdot
.676 .04551 Mdot
.676 .04564 Mdot
.676 .04587 Mdot
.676 .0459 Mdot
.676 .04605 Mdot
.676 .04622 Mdot
.676 .04629 Mdot
.676 .04683 Mdot
.676 .04747 Mdot
.676 .04748 Mdot
.676 .04752 Mdot
.676 .04783 Mdot
.676 .04795 Mdot
.676 .04829 Mdot
.676 .04852 Mdot
.676 .0487 Mdot
.676 .04873 Mdot
.676 .04884 Mdot
.676 .04918 Mdot
.676 .04919 Mdot
.676 .04945 Mdot
.676 .04968 Mdot
.676 .04994 Mdot
.676 .05053 Mdot
.676 .0508 Mdot
.676 .05088 Mdot
.676 .05175 Mdot
.676 .05177 Mdot
.676 .05192 Mdot
.676 .05221 Mdot
.676 .0526 Mdot
.676 .05298 Mdot
.676 .05306 Mdot
.676 .05306 Mdot
.676 .05323 Mdot
.676 .05335 Mdot
.676 .05346 Mdot
.676 .0535 Mdot
.676 .05353 Mdot
.676 .05376 Mdot
.676 .05451 Mdot
.676 .05454 Mdot
.676 .05546 Mdot
.676 .05551 Mdot
.676 .05554 Mdot
.676 .05578 Mdot
.676 .05585 Mdot
.676 .05635 Mdot
.676 .05652 Mdot
.676 .05684 Mdot
.676 .05687 Mdot
.676 .05708 Mdot
.676 .05731 Mdot
.676 .0574 Mdot
.676 .05813 Mdot
.676 .059 Mdot
.676 .05902 Mdot
.676 .05907 Mdot
.676 .05927 Mdot
.676 .05949 Mdot
.676 .0595 Mdot
.676 .05965 Mdot
.676 .06011 Mdot
.676 .06042 Mdot
.676 .06066 Mdot
.676 .06071 Mdot
.676 .06085 Mdot
.676 .06131 Mdot
.676 .06133 Mdot
.676 .06167 Mdot
.676 .0618 Mdot
.676 .06199 Mdot
.676 .06233 Mdot
.676 .06313 Mdot
.676 .06351 Mdot
.676 .06361 Mdot
.676 .06374 Mdot
.676 .06478 Mdot
.676 .06482 Mdot
.676 .06539 Mdot
.676 .06541 Mdot
.676 .06593 Mdot
.676 .06645 Mdot
.676 .06656 Mdot
.676 .06656 Mdot
.676 .06678 Mdot
.676 .06695 Mdot
.676 .06709 Mdot
.676 .06715 Mdot
.676 .06719 Mdot
.676 .06725 Mdot
.676 .0675 Mdot
.676 .06751 Mdot
.676 .06767 Mdot
.676 .06795 Mdot
.676 .06852 Mdot
.676 .06855 Mdot
.676 .06927 Mdot
.676 .0698 Mdot
.676 .06981 Mdot
.676 .06987 Mdot
.676 .06991 Mdot
.676 .06992 Mdot
.676 .07023 Mdot
.676 .07033 Mdot
.676 .07036 Mdot
.676 .07053 Mdot
.676 .07073 Mdot
.676 .0708 Mdot
.676 .07101 Mdot
.676 .07124 Mdot
.676 .07167 Mdot
.676 .07171 Mdot
.676 .07199 Mdot
.676 .0723 Mdot
.676 .07243 Mdot
.676 .07335 Mdot
.676 .07342 Mdot
.676 .07408 Mdot
.676 .07417 Mdot
.676 .07444 Mdot
.676 .07458 Mdot
.676 .07461 Mdot
.676 .07468 Mdot
.676 .07495 Mdot
.676 .07525 Mdot
.676 .07526 Mdot
.676 .07527 Mdot
.676 .07547 Mdot
.676 .07584 Mdot
.676 .07609 Mdot
.676 .07651 Mdot
.676 .07683 Mdot
.676 .0769 Mdot
.676 .07709 Mdot
.676 .07736 Mdot
.676 .07748 Mdot
.676 .07762 Mdot
.676 .07771 Mdot
.676 .07773 Mdot
.676 .07804 Mdot
.676 .0782 Mdot
.676 .07838 Mdot
.676 .07863 Mdot
.676 .07909 Mdot
.676 .07977 Mdot
.676 .08018 Mdot
.676 .08068 Mdot
.676 .08082 Mdot
.676 .081 Mdot
.676 .0817 Mdot
.676 .08241 Mdot
.676 .08245 Mdot
.676 .08305 Mdot
.676 .08323 Mdot
.676 .08326 Mdot
.676 .08396 Mdot
.676 .08398 Mdot
.676 .08465 Mdot
.676 .0848 Mdot
.676 .08481 Mdot
.676 .08511 Mdot
.676 .08521 Mdot
.676 .08534 Mdot
.676 .08553 Mdot
.676 .08559 Mdot
.676 .08561 Mdot
.676 .08567 Mdot
.676 .08574 Mdot
.676 .08608 Mdot
.676 .08609 Mdot
.676 .08631 Mdot
.676 .08669 Mdot
.676 .08746 Mdot
.676 .0875 Mdot
.676 .08788 Mdot
.676 .08847 Mdot
.676 .0891 Mdot
.676 .08919 Mdot
.676 .08921 Mdot
.676 .08928 Mdot
.676 .08934 Mdot
.676 .08935 Mdot
.676 .08977 Mdot
.676 .08991 Mdot
.676 .08995 Mdot
.676 .09018 Mdot
.676 .09043 Mdot
.676 .09045 Mdot
.676 .09054 Mdot
.676 .09082 Mdot
.676 .09114 Mdot
.676 .09151 Mdot
.676 .09171 Mdot
.676 .09177 Mdot
.676 .09215 Mdot
.676 .09257 Mdot
.676 .09274 Mdot
.676 .09399 Mdot
.676 .09408 Mdot
.676 .09497 Mdot
.676 .0951 Mdot
.676 .09547 Mdot
.676 .09566 Mdot
.676 .09569 Mdot
.676 .09579 Mdot
.676 .09615 Mdot
.676 .09656 Mdot
.676 .09657 Mdot
.676 .09658 Mdot
.676 .09685 Mdot
.676 .09736 Mdot
.676 .09769 Mdot
.676 .09826 Mdot
.676 .09831 Mdot
.676 .0987 Mdot
.676 .09878 Mdot
.676 .09904 Mdot
.676 .09912 Mdot
.676 .09942 Mdot
.676 .09957 Mdot
.676 .09968 Mdot
.676 .09977 Mdot
.676 .09989 Mdot
.676 .09992 Mdot
.676 .10033 Mdot
.676 .10055 Mdot
.676 .10079 Mdot
.676 .10113 Mdot
.676 .10176 Mdot
.676 .10267 Mdot
.676 .10322 Mdot
.676 .1039 Mdot
.676 .10409 Mdot
.676 .10433 Mdot
.676 .10511 Mdot
.676 .10527 Mdot
.676 .10593 Mdot
.676 .10624 Mdot
.676 .1063 Mdot
.676 .1071 Mdot
.676 .10734 Mdot
.676 .10738 Mdot
.676 .10815 Mdot
.676 .10834 Mdot
.676 .10837 Mdot
.676 .10927 Mdot
.676 .1093 Mdot
.676 .10947 Mdot
.676 .10949 Mdot
.676 .10952 Mdot
.676 .10989 Mdot
.676 .11003 Mdot
.676 .11011 Mdot
.676 .1102 Mdot
.676 .11046 Mdot
.676 .11054 Mdot
.676 .11057 Mdot
.676 .11064 Mdot
.676 .11074 Mdot
.676 .1112 Mdot
.676 .11122 Mdot
.676 .11151 Mdot
.676 .11202 Mdot
.676 .11232 Mdot
.676 .11307 Mdot
.676 .11312 Mdot
.676 .11363 Mdot
.676 .11406 Mdot
.676 .11443 Mdot
.676 .11484 Mdot
.676 .1149 Mdot
.676 .11493 Mdot
.676 .11529 Mdot
.676 .11541 Mdot
.676 .11543 Mdot
.676 .11553 Mdot
.676 .11557 Mdot
.676 .11561 Mdot
.676 .11562 Mdot
.676 .11619 Mdot
.676 .11637 Mdot
.676 .11643 Mdot
.676 .11661 Mdot
.676 .11674 Mdot
.676 .11708 Mdot
.676 .1171 Mdot
.676 .11723 Mdot
.676 .11761 Mdot
.676 .11804 Mdot
.676 .11834 Mdot
.676 .11854 Mdot
.676 .11882 Mdot
.676 .1189 Mdot
.676 .11941 Mdot
.676 .11968 Mdot
.676 .11997 Mdot
.676 .12021 Mdot
.676 .12172 Mdot
.676 .12189 Mdot
.676 .12202 Mdot
.676 .12322 Mdot
.676 .1234 Mdot
.676 .12389 Mdot
.676 .12415 Mdot
.676 .1242 Mdot
.676 .12433 Mdot
.676 .12482 Mdot
.676 .1252 Mdot
.676 .12537 Mdot
.676 .12539 Mdot
.676 .12539 Mdot
.676 .12553 Mdot
.676 .12577 Mdot
.676 .12615 Mdot
.676 .12644 Mdot
.676 .1269 Mdot
.676 .12767 Mdot
.676 .12774 Mdot
.676 .12788 Mdot
.676 .12826 Mdot
.676 .12838 Mdot
.676 .1284 Mdot
.676 .12849 Mdot
.676 .12873 Mdot
.676 .12883 Mdot
.676 .12894 Mdot
.676 .12923 Mdot
.676 .12944 Mdot
.676 .12959 Mdot
.676 .12971 Mdot
.676 .12987 Mdot
.676 .12991 Mdot
.676 .12998 Mdot
.676 .13046 Mdot
.676 .13046 Mdot
.676 .13076 Mdot
.676 .13093 Mdot
.676 .13109 Mdot
.676 .13155 Mdot
.676 .13226 Mdot
.676 .13239 Mdot
.676 .13322 Mdot
.676 .13363 Mdot
.676 .13386 Mdot
.676 .13437 Mdot
.676 .13441 Mdot
.676 .13513 Mdot
.676 .13529 Mdot
.676 .13532 Mdot
.676 .13555 Mdot
.676 .13564 Mdot
.676 .13588 Mdot
.676 .13693 Mdot
.676 .13715 Mdot
.676 .13782 Mdot
.676 .13783 Mdot
.676 .13804 Mdot
.676 .13845 Mdot
.676 .13854 Mdot
.676 .13918 Mdot
.676 .13962 Mdot
.676 .13992 Mdot
.676 .13995 Mdot
.676 .14 Mdot
.676 .14064 Mdot
.676 .14104 Mdot
.676 .1413 Mdot
.676 .14133 Mdot
.676 .14256 Mdot
.676 .1426 Mdot
.676 .14275 Mdot
.676 .14283 Mdot
.676 .14285 Mdot
.676 .14288 Mdot
.676 .14339 Mdot
.676 .14358 Mdot
.676 .14369 Mdot
.676 .14381 Mdot
.676 .14416 Mdot
.676 .14427 Mdot
.676 .14431 Mdot
.676 .14441 Mdot
.676 .14454 Mdot
.676 .14516 Mdot
.676 .14518 Mdot
.676 .14558 Mdot
.676 .14595 Mdot
.676 .14628 Mdot
.676 .14655 Mdot
.676 .14667 Mdot
.676 .14769 Mdot
.676 .14776 Mdot
.676 .14845 Mdot
.676 .14903 Mdot
.676 .14953 Mdot
.676 .15008 Mdot
.676 .15016 Mdot
.676 .15021 Mdot
.676 .15029 Mdot
.676 .15069 Mdot
.676 .15085 Mdot
.676 .15088 Mdot
.676 .15101 Mdot
.676 .15106 Mdot
.676 .15112 Mdot
.676 .15114 Mdot
.676 .15191 Mdot
.676 .15213 Mdot
.676 .15216 Mdot
.676 .15224 Mdot
.676 .15248 Mdot
.676 .15265 Mdot
.676 .15311 Mdot
.676 .15314 Mdot
.676 .15319 Mdot
.676 .15331 Mdot
.676 .15383 Mdot
.676 .15441 Mdot
.676 .15481 Mdot
.676 .15509 Mdot
.676 .15546 Mdot
.676 .15557 Mdot
.676 .15626 Mdot
.676 .15662 Mdot
.676 .15702 Mdot
.676 .15734 Mdot
.676 .15938 Mdot
.676 .15962 Mdot
.676 .15979 Mdot
.676 .16141 Mdot
.676 .16166 Mdot
.676 .16233 Mdot
.676 .16267 Mdot
.676 .16273 Mdot
.676 .16291 Mdot
.676 .16357 Mdot
.676 .16409 Mdot
.676 .16433 Mdot
.676 .16434 Mdot
.676 .16435 Mdot
.676 .16454 Mdot
.676 .16486 Mdot
.676 .16537 Mdot
.676 .16577 Mdot
.676 .16638 Mdot
.676 .16743 Mdot
.676 .16753 Mdot
.676 .16771 Mdot
.676 .16823 Mdot
.676 .16838 Mdot
.676 .16841 Mdot
.676 .16854 Mdot
.676 .16886 Mdot
.676 .169 Mdot
.676 .16914 Mdot
.676 .16954 Mdot
.676 .16983 Mdot
.676 .17002 Mdot
.676 .17018 Mdot
.676 .1704 Mdot
.676 .17046 Mdot
.676 .17055 Mdot
.676 .1712 Mdot
.676 .17121 Mdot
.676 .17161 Mdot
.676 .17183 Mdot
.676 .17205 Mdot
.676 .17268 Mdot
.676 .17364 Mdot
.676 .17382 Mdot
.676 .17494 Mdot
.676 .17549 Mdot
.676 .1758 Mdot
.676 .17649 Mdot
.676 .17654 Mdot
.676 .17752 Mdot
.676 .17773 Mdot
.676 .17777 Mdot
.676 .17808 Mdot
.676 .1782 Mdot
.676 .17852 Mdot
.676 .17995 Mdot
.676 .18025 Mdot
.676 .18115 Mdot
.676 .18117 Mdot
.676 .18145 Mdot
.676 .18201 Mdot
.676 .18212 Mdot
.676 .18299 Mdot
.676 .18358 Mdot
.676 .184 Mdot
.676 .18403 Mdot
.676 .1841 Mdot
.676 .18496 Mdot
.676 .18551 Mdot
.676 .18585 Mdot
.676 .1859 Mdot
.676 .18756 Mdot
.676 .18761 Mdot
.676 .18781 Mdot
.676 .18793 Mdot
.676 .18795 Mdot
.676 .188 Mdot
.676 .18868 Mdot
.676 .18894 Mdot
.676 .18909 Mdot
.676 .18925 Mdot
.676 .18973 Mdot
.676 .18988 Mdot
.676 .18992 Mdot
.676 .19006 Mdot
.676 .19024 Mdot
.676 .19108 Mdot
.676 .19111 Mdot
.676 .19165 Mdot
.676 .19215 Mdot
.676 .19259 Mdot
.676 .19296 Mdot
.676 .19312 Mdot
.676 .1945 Mdot
.676 .1946 Mdot
.676 .19553 Mdot
.676 .19631 Mdot
.676 .19698 Mdot
.676 .19773 Mdot
.676 .19784 Mdot
.676 .1979 Mdot
.676 .19802 Mdot
.676 .19855 Mdot
.676 .19877 Mdot
.676 .19881 Mdot
.676 .19899 Mdot
.676 .19906 Mdot
.676 .19914 Mdot
.676 .19917 Mdot
.676 .2002 Mdot
.676 .20049 Mdot
.676 .20053 Mdot
.676 .20064 Mdot
.676 .20098 Mdot
.676 .20121 Mdot
.676 .20182 Mdot
.676 .20187 Mdot
.676 .20193 Mdot
.676 .2021 Mdot
.676 .2028 Mdot
.676 .20358 Mdot
.676 .20412 Mdot
.676 .2045 Mdot
.676 .205 Mdot
.676 .20515 Mdot
.676 .20608 Mdot
.676 .20657 Mdot
.676 .20711 Mdot
.676 .20755 Mdot
.676 .2103 Mdot
.676 .21063 Mdot
.676 .21085 Mdot
.676 .21305 Mdot
.676 .21338 Mdot
.676 .21428 Mdot
.676 .21475 Mdot
.676 .21483 Mdot
.676 .21508 Mdot
.676 .21597 Mdot
.676 .21667 Mdot
.676 .21699 Mdot
.676 .21701 Mdot
.676 .21703 Mdot
.676 .21728 Mdot
.676 .21771 Mdot
.676 .2184 Mdot
.676 .21895 Mdot
.676 .21977 Mdot
.676 .22118 Mdot
.676 .22132 Mdot
.676 .22157 Mdot
.676 .22226 Mdot
.676 .22248 Mdot
.676 .22251 Mdot
.676 .22269 Mdot
.676 .22311 Mdot
.676 .22331 Mdot
.676 .2235 Mdot
.676 .22404 Mdot
.676 .22443 Mdot
.676 .22469 Mdot
.676 .22491 Mdot
.676 .2252 Mdot
.676 .22528 Mdot
.676 .2254 Mdot
.676 .22629 Mdot
.676 .22629 Mdot
.676 .22684 Mdot
.676 .22714 Mdot
.676 .22743 Mdot
.676 .22828 Mdot
.676 .22958 Mdot
.676 .22982 Mdot
.676 .23133 Mdot
.676 .23208 Mdot
.676 .23251 Mdot
.676 .23343 Mdot
.676 .2335 Mdot
.676 .23483 Mdot
.676 .23512 Mdot
.676 .23517 Mdot
.676 .23559 Mdot
.676 .23575 Mdot
.676 .23618 Mdot
.676 .23811 Mdot
.676 .23852 Mdot
.676 .23974 Mdot
.676 .23976 Mdot
.676 .24014 Mdot
.676 .2409 Mdot
.676 .24105 Mdot
.676 .24222 Mdot
.676 .24303 Mdot
.676 .24358 Mdot
.676 .24363 Mdot
.676 .24373 Mdot
.676 .24489 Mdot
.676 .24563 Mdot
.676 .24609 Mdot
.676 .24616 Mdot
.676 .2484 Mdot
.676 .24847 Mdot
.676 .24874 Mdot
.676 .2489 Mdot
.676 .24893 Mdot
.676 .249 Mdot
.676 .24992 Mdot
.676 .25026 Mdot
.676 .25047 Mdot
.676 .25069 Mdot
.676 .25133 Mdot
.676 .25153 Mdot
.676 .2516 Mdot
.676 .25178 Mdot
.676 .25202 Mdot
.676 .25316 Mdot
.676 .2532 Mdot
.676 .25393 Mdot
.676 .25461 Mdot
.676 .2552 Mdot
.676 .2557 Mdot
.676 .25592 Mdot
.676 .25779 Mdot
.676 .25791 Mdot
.676 .25917 Mdot
.676 .26024 Mdot
.676 .26114 Mdot
.676 .26215 Mdot
.676 .2623 Mdot
.676 .26238 Mdot
.676 .26254 Mdot
.676 .26326 Mdot
.676 .26356 Mdot
.676 .26362 Mdot
.676 .26386 Mdot
.676 .26395 Mdot
.676 .26406 Mdot
.676 .2641 Mdot
.676 .26549 Mdot
.676 .26589 Mdot
.676 .26594 Mdot
.676 .26609 Mdot
.676 .26654 Mdot
.676 .26685 Mdot
.676 .26769 Mdot
.676 .26775 Mdot
.676 .26783 Mdot
.676 .26806 Mdot
.676 .269 Mdot
.676 .27006 Mdot
.676 .2708 Mdot
.676 .27131 Mdot
.676 .27198 Mdot
.676 .27219 Mdot
.676 .27344 Mdot
.676 .27411 Mdot
.676 .27483 Mdot
.676 .27543 Mdot
.676 .27915 Mdot
.676 .27959 Mdot
.676 .2799 Mdot
.676 .28287 Mdot
.676 .28332 Mdot
.676 .28453 Mdot
.676 .28516 Mdot
.676 .28528 Mdot
.676 .2856 Mdot
.676 .28681 Mdot
.676 .28776 Mdot
.676 .28819 Mdot
.676 .28822 Mdot
.676 .28824 Mdot
.676 .28859 Mdot
.676 .28916 Mdot
.676 .2901 Mdot
.676 .29084 Mdot
.676 .29195 Mdot
.676 .29386 Mdot
.676 .29404 Mdot
.676 .29438 Mdot
.676 .29532 Mdot
.676 .29561 Mdot
.676 .29566 Mdot
.676 .2959 Mdot
.676 .29647 Mdot
.676 .29674 Mdot
.676 .29699 Mdot
.676 .29772 Mdot
.676 .29825 Mdot
.676 .2986 Mdot
.676 .2989 Mdot
.676 .29929 Mdot
.676 .29939 Mdot
.676 .29957 Mdot
.676 .30076 Mdot
.676 .30077 Mdot
.676 .30151 Mdot
.676 .30191 Mdot
.676 .3023 Mdot
.676 .30346 Mdot
.676 .30521 Mdot
.676 .30554 Mdot
.676 .30759 Mdot
.676 .30859 Mdot
.676 .30917 Mdot
.676 .31042 Mdot
.676 .31052 Mdot
.676 .31231 Mdot
.676 .3127 Mdot
.676 .31277 Mdot
.676 .31333 Mdot
.676 .31355 Mdot
.676 .31414 Mdot
.676 .31675 Mdot
.676 .31729 Mdot
.676 .31895 Mdot
.676 .31898 Mdot
.676 .31949 Mdot
.676 .32051 Mdot
.676 .32071 Mdot
.676 .32231 Mdot
.676 .32339 Mdot
.676 .32415 Mdot
.676 .3242 Mdot
.676 .32434 Mdot
.676 .32591 Mdot
.676 .32692 Mdot
.676 .32754 Mdot
.676 .32763 Mdot
.676 .33066 Mdot
.676 .33075 Mdot
.676 .33112 Mdot
.676 .33133 Mdot
.676 .33137 Mdot
.676 .33146 Mdot
.676 .33271 Mdot
.676 .33317 Mdot
.676 .33346 Mdot
.676 .33375 Mdot
.676 .33462 Mdot
.676 .33489 Mdot
.676 .33498 Mdot
.676 .33523 Mdot
.676 .33556 Mdot
.676 .33709 Mdot
.676 .33714 Mdot
.676 .33813 Mdot
.676 .33905 Mdot
.676 .33985 Mdot
.676 .34053 Mdot
.676 .34082 Mdot
.676 .34335 Mdot
.676 .34352 Mdot
.676 .34522 Mdot
.676 .34666 Mdot
.676 .34788 Mdot
.676 .34925 Mdot
.676 .34944 Mdot
.676 .34956 Mdot
.676 .34977 Mdot
.676 .35074 Mdot
.676 .35115 Mdot
.676 .35123 Mdot
.676 .35155 Mdot
.676 .35168 Mdot
.676 .35183 Mdot
.676 .35188 Mdot
.676 .35377 Mdot
.676 .3543 Mdot
.676 .35438 Mdot
.676 .35457 Mdot
.676 .35518 Mdot
.676 .35561 Mdot
.676 .35673 Mdot
.676 .35682 Mdot
.676 .35693 Mdot
.676 .35723 Mdot
.676 .35851 Mdot
.676 .35994 Mdot
.676 .36094 Mdot
.676 .36163 Mdot
.676 .36254 Mdot
.676 .36282 Mdot
.676 .36451 Mdot
.676 .36542 Mdot
.676 .3664 Mdot
.676 .3672 Mdot
.676 .37223 Mdot
.676 .37283 Mdot
.676 .37324 Mdot
.676 .37726 Mdot
.676 .37786 Mdot
.676 .37951 Mdot
.676 .38036 Mdot
.676 .38051 Mdot
.676 .38096 Mdot
.676 .38259 Mdot
.676 .38388 Mdot
.676 .38445 Mdot
.676 .38449 Mdot
.676 .38452 Mdot
.676 .38499 Mdot
.676 .38576 Mdot
.676 .38704 Mdot
.676 .38803 Mdot
.676 .38954 Mdot
.676 .39212 Mdot
.676 .39236 Mdot
.676 .39282 Mdot
.676 .3941 Mdot
.676 .39448 Mdot
.676 .39455 Mdot
.676 .39488 Mdot
.676 .39565 Mdot
.676 .39601 Mdot
.676 .39635 Mdot
.676 .39734 Mdot
.676 .39805 Mdot
.676 .39852 Mdot
.676 .39893 Mdot
.676 .39946 Mdot
.676 .3996 Mdot
.676 .39983 Mdot
.676 .40145 Mdot
.676 .40146 Mdot
.676 .40246 Mdot
.676 .40301 Mdot
.676 .40353 Mdot
.676 .40509 Mdot
.676 .40747 Mdot
.676 .40791 Mdot
.676 .41068 Mdot
.676 .41203 Mdot
.676 .41282 Mdot
.678 .01536 Mdot
.678 .01547 Mdot
.678 .01559 Mdot
.678 .01574 Mdot
.678 .01585 Mdot
.678 .0159 Mdot
.678 .01611 Mdot
.678 .01626 Mdot
.678 .01633 Mdot
.678 .01649 Mdot
.678 .0166 Mdot
.678 .01681 Mdot
.678 .0169 Mdot
.678 .01713 Mdot
.678 .01727 Mdot
.678 .01746 Mdot
.678 .01755 Mdot
.678 .01768 Mdot
.678 .01799 Mdot
.678 .01818 Mdot
.678 .01825 Mdot
.678 .01843 Mdot
.678 .01856 Mdot
.678 .01874 Mdot
.678 .0189 Mdot
.678 .01915 Mdot
.678 .01942 Mdot
.678 .01951 Mdot
.678 .0197 Mdot
.678 .01976 Mdot
.678 .01993 Mdot
.678 .02017 Mdot
.678 .0204 Mdot
.678 .02042 Mdot
.678 .0206 Mdot
.678 .02073 Mdot
.678 .02109 Mdot
.678 .02122 Mdot
.678 .02147 Mdot
.678 .02155 Mdot
.678 .02159 Mdot
.678 .02179 Mdot
.678 .02211 Mdot
.678 .02242 Mdot
.678 .02245 Mdot
.678 .02269 Mdot
.678 .02286 Mdot
.678 .02287 Mdot
.678 .02336 Mdot
.678 .02353 Mdot
.678 .02388 Mdot
.678 .02397 Mdot
.678 .02399 Mdot
.678 .02403 Mdot
.678 .02431 Mdot
.678 .02474 Mdot
.678 .02511 Mdot
.678 .02516 Mdot
.678 .0252 Mdot
.678 .02553 Mdot
.678 .02561 Mdot
.678 .02576 Mdot
.678 .02578 Mdot
.678 .02644 Mdot
.678 .02644 Mdot
.678 .02667 Mdot
.678 .02714 Mdot
.678 .02727 Mdot
.678 .02729 Mdot
.678 .02735 Mdot
.678 .02764 Mdot
.678 .02769 Mdot
.678 .02772 Mdot
.678 .02822 Mdot
.678 .02831 Mdot
.678 .02872 Mdot
.678 .02881 Mdot
.678 .02888 Mdot
.678 .02893 Mdot
.678 .02938 Mdot
.678 .02949 Mdot
.678 .02969 Mdot
.678 .02972 Mdot
.678 .03061 Mdot
.678 .03062 Mdot
.678 .03093 Mdot
.678 .03156 Mdot
.678 .03174 Mdot
.678 .03176 Mdot
.678 .03183 Mdot
.678 .03185 Mdot
.678 .0319 Mdot
.678 .03224 Mdot
.678 .0323 Mdot
.678 .03235 Mdot
.678 .03303 Mdot
.678 .03315 Mdot
.678 .03371 Mdot
.678 .03382 Mdot
.678 .03392 Mdot
.678 .03399 Mdot
.678 .03461 Mdot
.678 .03475 Mdot
.678 .03483 Mdot
.678 .03502 Mdot
.678 .03504 Mdot
.678 .03506 Mdot
.678 .03529 Mdot
.678 .03627 Mdot
.678 .03628 Mdot
.678 .03649 Mdot
.678 .0367 Mdot
.678 .03756 Mdot
.678 .0378 Mdot
.678 .03783 Mdot
.678 .03793 Mdot
.678 .03795 Mdot
.678 .03801 Mdot
.678 .03847 Mdot
.678 .03848 Mdot
.678 .03857 Mdot
.678 .03863 Mdot
.678 .03912 Mdot
.678 .03955 Mdot
.678 .03972 Mdot
.678 .04047 Mdot
.678 .04062 Mdot
.678 .04063 Mdot
.678 .04076 Mdot
.678 .04085 Mdot
.678 .0409 Mdot
.678 .04118 Mdot
.678 .04134 Mdot
.678 .04169 Mdot
.678 .04188 Mdot
.678 .04191 Mdot
.678 .04199 Mdot
.678 .04225 Mdot
.678 .04227 Mdot
.678 .0423 Mdot
.678 .04258 Mdot
.678 .04262 Mdot
.678 .04395 Mdot
.678 .04396 Mdot
.678 .04416 Mdot
.678 .04425 Mdot
.678 .04452 Mdot
.678 .04466 Mdot
.678 .04564 Mdot
.678 .04569 Mdot
.678 .04601 Mdot
.678 .04606 Mdot
.678 .04619 Mdot
.678 .04622 Mdot
.678 .0463 Mdot
.678 .04632 Mdot
.678 .04693 Mdot
.678 .04694 Mdot
.678 .04706 Mdot
.678 .04714 Mdot
.678 .0478 Mdot
.678 .04839 Mdot
.678 .04862 Mdot
.678 .04957 Mdot
.678 .04963 Mdot
.678 .04985 Mdot
.678 .04986 Mdot
.678 .04995 Mdot
.678 .05003 Mdot
.678 .05016 Mdot
.678 .05023 Mdot
.678 .0506 Mdot
.678 .05082 Mdot
.678 .05129 Mdot
.678 .05155 Mdot
.678 .05159 Mdot
.678 .0517 Mdot
.678 .05206 Mdot
.678 .05208 Mdot
.678 .05212 Mdot
.678 .05223 Mdot
.678 .0525 Mdot
.678 .05256 Mdot
.678 .0538 Mdot
.678 .05387 Mdot
.678 .05436 Mdot
.678 .05437 Mdot
.678 .05464 Mdot
.678 .05471 Mdot
.678 .05476 Mdot
.678 .05508 Mdot
.678 .05514 Mdot
.678 .05532 Mdot
.678 .05596 Mdot
.678 .05665 Mdot
.678 .05672 Mdot
.678 .05716 Mdot
.678 .05721 Mdot
.678 .05739 Mdot
.678 .05743 Mdot
.678 .05755 Mdot
.678 .05757 Mdot
.678 .0584 Mdot
.678 .05842 Mdot
.678 .05857 Mdot
.678 .05868 Mdot
.678 .05906 Mdot
.678 .05921 Mdot
.678 .05958 Mdot
.678 .06038 Mdot
.678 .0605 Mdot
.678 .06069 Mdot
.678 .06131 Mdot
.678 .06196 Mdot
.678 .06198 Mdot
.678 .06206 Mdot
.678 .06235 Mdot
.678 .06237 Mdot
.678 .06241 Mdot
.678 .06249 Mdot
.678 .0626 Mdot
.678 .06277 Mdot
.678 .06287 Mdot
.678 .06338 Mdot
.678 .06367 Mdot
.678 .06431 Mdot
.678 .06466 Mdot
.678 .06472 Mdot
.678 .06486 Mdot
.678 .06535 Mdot
.678 .06538 Mdot
.678 .06544 Mdot
.678 .06558 Mdot
.678 .06577 Mdot
.678 .06595 Mdot
.678 .06603 Mdot
.678 .06692 Mdot
.678 .06702 Mdot
.678 .06707 Mdot
.678 .06771 Mdot
.678 .06781 Mdot
.678 .06847 Mdot
.678 .06848 Mdot
.678 .06885 Mdot
.678 .06895 Mdot
.678 .06901 Mdot
.678 .06945 Mdot
.678 .06953 Mdot
.678 .06977 Mdot
.678 .07013 Mdot
.678 .07014 Mdot
.678 .07038 Mdot
.678 .07064 Mdot
.678 .07093 Mdot
.678 .0715 Mdot
.678 .07158 Mdot
.678 .07167 Mdot
.678 .07226 Mdot
.678 .07234 Mdot
.678 .07259 Mdot
.678 .07264 Mdot
.678 .0728 Mdot
.678 .07283 Mdot
.678 .07366 Mdot
.678 .07387 Mdot
.678 .07396 Mdot
.678 .07397 Mdot
.678 .07418 Mdot
.678 .07434 Mdot
.678 .07485 Mdot
.678 .07505 Mdot
.678 .07515 Mdot
.678 .07556 Mdot
.678 .07582 Mdot
.678 .07663 Mdot
.678 .0768 Mdot
.678 .07706 Mdot
.678 .0779 Mdot
.678 .07791 Mdot
.678 .07878 Mdot
.678 .07881 Mdot
.678 .07892 Mdot
.678 .07931 Mdot
.678 .07933 Mdot
.678 .07939 Mdot
.678 .0795 Mdot
.678 .07965 Mdot
.678 .07978 Mdot
.678 .07988 Mdot
.678 .08001 Mdot
.678 .0807 Mdot
.678 .08088 Mdot
.678 .08096 Mdot
.678 .0811 Mdot
.678 .08196 Mdot
.678 .08245 Mdot
.678 .08252 Mdot
.678 .08271 Mdot
.678 .08303 Mdot
.678 .08338 Mdot
.678 .08342 Mdot
.678 .08349 Mdot
.678 .08369 Mdot
.678 .08395 Mdot
.678 .08403 Mdot
.678 .08418 Mdot
.678 .08429 Mdot
.678 .08482 Mdot
.678 .08488 Mdot
.678 .08524 Mdot
.678 .08551 Mdot
.678 .08564 Mdot
.678 .0857 Mdot
.678 .08657 Mdot
.678 .08671 Mdot
.678 .08761 Mdot
.678 .08762 Mdot
.678 .08763 Mdot
.678 .08812 Mdot
.678 .08812 Mdot
.678 .08825 Mdot
.678 .08834 Mdot
.678 .08893 Mdot
.678 .08904 Mdot
.678 .08937 Mdot
.678 .08985 Mdot
.678 .08987 Mdot
.678 .0902 Mdot
.678 .09056 Mdot
.678 .09094 Mdot
.678 .09167 Mdot
.678 .09171 Mdot
.678 .09182 Mdot
.678 .09194 Mdot
.678 .09216 Mdot
.678 .09244 Mdot
.678 .09275 Mdot
.678 .09286 Mdot
.678 .0931 Mdot
.678 .09319 Mdot
.678 .09326 Mdot
.678 .09348 Mdot
.678 .09352 Mdot
.678 .09377 Mdot
.678 .09388 Mdot
.678 .09465 Mdot
.678 .09494 Mdot
.678 .09505 Mdot
.678 .09507 Mdot
.678 .09523 Mdot
.678 .09535 Mdot
.678 .09556 Mdot
.678 .09625 Mdot
.678 .09653 Mdot
.678 .09666 Mdot
.678 .09694 Mdot
.678 .09722 Mdot
.678 .09758 Mdot
.678 .09867 Mdot
.678 .0989 Mdot
.678 .0989 Mdot
.678 .09925 Mdot
.678 .09955 Mdot
.678 .09958 Mdot
.678 .1004 Mdot
.678 .1004 Mdot
.678 .10109 Mdot
.678 .10158 Mdot
.678 .10162 Mdot
.678 .10162 Mdot
.678 .10178 Mdot
.678 .10205 Mdot
.678 .10231 Mdot
.678 .10234 Mdot
.678 .10242 Mdot
.678 .10256 Mdot
.678 .10277 Mdot
.678 .10294 Mdot
.678 .10308 Mdot
.678 .10326 Mdot
.678 .10341 Mdot
.678 .10367 Mdot
.678 .10419 Mdot
.678 .10444 Mdot
.678 .10455 Mdot
.678 .10473 Mdot
.678 .10522 Mdot
.678 .1059 Mdot
.678 .10592 Mdot
.678 .10656 Mdot
.678 .10666 Mdot
.678 .10692 Mdot
.678 .10735 Mdot
.678 .10749 Mdot
.678 .10782 Mdot
.678 .10788 Mdot
.678 .10798 Mdot
.678 .10825 Mdot
.678 .10859 Mdot
.678 .1087 Mdot
.678 .10892 Mdot
.678 .10906 Mdot
.678 .10977 Mdot
.678 .10985 Mdot
.678 .11035 Mdot
.678 .11069 Mdot
.678 .11071 Mdot
.678 .11089 Mdot
.678 .11097 Mdot
.678 .11117 Mdot
.678 .11216 Mdot
.678 .11233 Mdot
.678 .11248 Mdot
.678 .11316 Mdot
.678 .11331 Mdot
.678 .11356 Mdot
.678 .11358 Mdot
.678 .11359 Mdot
.678 .11426 Mdot
.678 .11426 Mdot
.678 .11431 Mdot
.678 .11443 Mdot
.678 .11456 Mdot
.678 .11507 Mdot
.678 .11535 Mdot
.678 .1155 Mdot
.678 .11595 Mdot
.678 .11636 Mdot
.678 .1166 Mdot
.678 .11662 Mdot
.678 .11707 Mdot
.678 .11755 Mdot
.678 .11807 Mdot
.678 .11896 Mdot
.678 .11906 Mdot
.678 .11912 Mdot
.678 .11927 Mdot
.678 .11944 Mdot
.678 .11973 Mdot
.678 .1201 Mdot
.678 .12053 Mdot
.678 .12067 Mdot
.678 .12068 Mdot
.678 .12101 Mdot
.678 .12113 Mdot
.678 .12122 Mdot
.678 .12152 Mdot
.678 .12157 Mdot
.678 .12191 Mdot
.678 .12206 Mdot
.678 .12241 Mdot
.678 .12311 Mdot
.678 .12321 Mdot
.678 .12349 Mdot
.678 .12364 Mdot
.678 .12368 Mdot
.678 .12389 Mdot
.678 .12406 Mdot
.678 .12434 Mdot
.678 .12491 Mdot
.678 .12528 Mdot
.678 .12566 Mdot
.678 .12584 Mdot
.678 .12621 Mdot
.678 .12659 Mdot
.678 .12666 Mdot
.678 .12697 Mdot
.678 .12708 Mdot
.678 .12842 Mdot
.678 .12856 Mdot
.678 .12887 Mdot
.678 .12887 Mdot
.678 .12891 Mdot
.678 .12935 Mdot
.678 .12974 Mdot
.678 .12979 Mdot
.678 .1309 Mdot
.678 .13091 Mdot
.678 .13184 Mdot
.678 .13251 Mdot
.678 .13256 Mdot
.678 .13256 Mdot
.678 .13277 Mdot
.678 .13314 Mdot
.678 .1335 Mdot
.678 .13353 Mdot
.678 .13364 Mdot
.678 .13383 Mdot
.678 .13412 Mdot
.678 .13435 Mdot
.678 .13454 Mdot
.678 .13478 Mdot
.678 .13499 Mdot
.678 .13504 Mdot
.678 .13534 Mdot
.678 .13571 Mdot
.678 .13604 Mdot
.678 .13638 Mdot
.678 .13653 Mdot
.678 .13677 Mdot
.678 .13713 Mdot
.678 .13714 Mdot
.678 .1373 Mdot
.678 .13745 Mdot
.678 .13837 Mdot
.678 .13839 Mdot
.678 .13925 Mdot
.678 .13931 Mdot
.678 .13939 Mdot
.678 .13975 Mdot
.678 .14033 Mdot
.678 .14052 Mdot
.678 .14097 Mdot
.678 .14105 Mdot
.678 .14113 Mdot
.678 .14118 Mdot
.678 .14135 Mdot
.678 .14155 Mdot
.678 .14201 Mdot
.678 .14216 Mdot
.678 .14245 Mdot
.678 .14265 Mdot
.678 .14361 Mdot
.678 .14372 Mdot
.678 .1444 Mdot
.678 .14486 Mdot
.678 .14488 Mdot
.678 .14513 Mdot
.678 .14524 Mdot
.678 .1455 Mdot
.678 .14642 Mdot
.678 .14647 Mdot
.678 .14685 Mdot
.678 .14709 Mdot
.678 .14728 Mdot
.678 .14741 Mdot
.678 .14821 Mdot
.678 .1484 Mdot
.678 .14875 Mdot
.678 .14878 Mdot
.678 .14879 Mdot
.678 .14969 Mdot
.678 .1497 Mdot
.678 .14977 Mdot
.678 .14993 Mdot
.678 .1501 Mdot
.678 .15074 Mdot
.678 .1508 Mdot
.678 .15118 Mdot
.678 .15138 Mdot
.678 .15199 Mdot
.678 .15255 Mdot
.678 .15287 Mdot
.678 .1529 Mdot
.678 .15351 Mdot
.678 .1538 Mdot
.678 .15404 Mdot
.678 .15406 Mdot
.678 .15416 Mdot
.678 .15487 Mdot
.678 .15502 Mdot
.678 .15606 Mdot
.678 .15621 Mdot
.678 .15629 Mdot
.678 .15649 Mdot
.678 .15669 Mdot
.678 .15672 Mdot
.678 .15712 Mdot
.678 .15762 Mdot
.678 .1582 Mdot
.678 .15839 Mdot
.678 .1584 Mdot
.678 .15885 Mdot
.678 .15901 Mdot
.678 .15913 Mdot
.678 .15954 Mdot
.678 .15961 Mdot
.678 .16007 Mdot
.678 .16028 Mdot
.678 .16075 Mdot
.678 .16169 Mdot
.678 .16183 Mdot
.678 .16222 Mdot
.678 .16242 Mdot
.678 .16246 Mdot
.678 .16276 Mdot
.678 .16299 Mdot
.678 .16337 Mdot
.678 .16414 Mdot
.678 .16464 Mdot
.678 .16516 Mdot
.678 .16539 Mdot
.678 .1659 Mdot
.678 .16641 Mdot
.678 .16651 Mdot
.678 .16693 Mdot
.678 .16708 Mdot
.678 .16889 Mdot
.678 .16909 Mdot
.678 .16951 Mdot
.678 .16951 Mdot
.678 .16956 Mdot
.678 .17016 Mdot
.678 .17069 Mdot
.678 .17076 Mdot
.678 .17226 Mdot
.678 .17227 Mdot
.678 .17354 Mdot
.678 .17444 Mdot
.678 .17451 Mdot
.678 .17452 Mdot
.678 .1748 Mdot
.678 .1753 Mdot
.678 .17578 Mdot
.678 .17583 Mdot
.678 .17598 Mdot
.678 .17624 Mdot
.678 .17662 Mdot
.678 .17694 Mdot
.678 .1772 Mdot
.678 .17752 Mdot
.678 .17781 Mdot
.678 .17788 Mdot
.678 .17828 Mdot
.678 .17879 Mdot
.678 .17923 Mdot
.678 .17969 Mdot
.678 .17989 Mdot
.678 .18022 Mdot
.678 .18071 Mdot
.678 .18072 Mdot
.678 .18094 Mdot
.678 .18114 Mdot
.678 .18239 Mdot
.678 .18241 Mdot
.678 .18359 Mdot
.678 .18367 Mdot
.678 .18378 Mdot
.678 .18426 Mdot
.678 .18505 Mdot
.678 .18531 Mdot
.678 .18592 Mdot
.678 .18603 Mdot
.678 .18614 Mdot
.678 .1862 Mdot
.678 .18643 Mdot
.678 .1867 Mdot
.678 .18733 Mdot
.678 .18753 Mdot
.678 .18792 Mdot
.678 .1882 Mdot
.678 .1895 Mdot
.678 .18965 Mdot
.678 .19057 Mdot
.678 .1912 Mdot
.678 .19122 Mdot
.678 .19156 Mdot
.678 .19171 Mdot
.678 .19206 Mdot
.678 .19331 Mdot
.678 .19337 Mdot
.678 .19389 Mdot
.678 .19421 Mdot
.678 .19447 Mdot
.678 .19465 Mdot
.678 .19573 Mdot
.678 .196 Mdot
.678 .19646 Mdot
.678 .1965 Mdot
.678 .19652 Mdot
.678 .19775 Mdot
.678 .19775 Mdot
.678 .19785 Mdot
.678 .19807 Mdot
.678 .1983 Mdot
.678 .19916 Mdot
.678 .19925 Mdot
.678 .19976 Mdot
.678 .20003 Mdot
.678 .20087 Mdot
.678 .20162 Mdot
.678 .20206 Mdot
.678 .20209 Mdot
.678 .20292 Mdot
.678 .20332 Mdot
.678 .20364 Mdot
.678 .20366 Mdot
.678 .20381 Mdot
.678 .20477 Mdot
.678 .20496 Mdot
.678 .20639 Mdot
.678 .20658 Mdot
.678 .20669 Mdot
.678 .20696 Mdot
.678 .20723 Mdot
.678 .20727 Mdot
.678 .20781 Mdot
.678 .2085 Mdot
.678 .20929 Mdot
.678 .20954 Mdot
.678 .20956 Mdot
.678 .21016 Mdot
.678 .21038 Mdot
.678 .21055 Mdot
.678 .2111 Mdot
.678 .2112 Mdot
.678 .21182 Mdot
.678 .2121 Mdot
.678 .21273 Mdot
.678 .21402 Mdot
.678 .21421 Mdot
.678 .21473 Mdot
.678 .21501 Mdot
.678 .21506 Mdot
.678 .21547 Mdot
.678 .21577 Mdot
.678 .21629 Mdot
.678 .21733 Mdot
.678 .21802 Mdot
.678 .21871 Mdot
.678 .21904 Mdot
.678 .21972 Mdot
.678 .22042 Mdot
.678 .22054 Mdot
.678 .22112 Mdot
.678 .22132 Mdot
.678 .22378 Mdot
.678 .22405 Mdot
.678 .22462 Mdot
.678 .22462 Mdot
.678 .22469 Mdot
.678 .2255 Mdot
.678 .22622 Mdot
.678 .22631 Mdot
.678 .22834 Mdot
.678 .22836 Mdot
.678 .23008 Mdot
.678 .23131 Mdot
.678 .2314 Mdot
.678 .23141 Mdot
.678 .23179 Mdot
.678 .23246 Mdot
.678 .23312 Mdot
.678 .23318 Mdot
.678 .23339 Mdot
.678 .23374 Mdot
.678 .23426 Mdot
.678 .23469 Mdot
.678 .23505 Mdot
.678 .23548 Mdot
.678 .23587 Mdot
.678 .23597 Mdot
.678 .23651 Mdot
.678 .2372 Mdot
.678 .2378 Mdot
.678 .23842 Mdot
.678 .23869 Mdot
.678 .23915 Mdot
.678 .2398 Mdot
.678 .23982 Mdot
.678 .24011 Mdot
.678 .24039 Mdot
.678 .24208 Mdot
.678 .24211 Mdot
.678 .24371 Mdot
.678 .24382 Mdot
.678 .24396 Mdot
.678 .24461 Mdot
.678 .24569 Mdot
.678 .24604 Mdot
.678 .24686 Mdot
.678 .24701 Mdot
.678 .24716 Mdot
.678 .24725 Mdot
.678 .24756 Mdot
.678 .24792 Mdot
.678 .24878 Mdot
.678 .24905 Mdot
.678 .24959 Mdot
.678 .24996 Mdot
.678 .25173 Mdot
.678 .25193 Mdot
.678 .25317 Mdot
.678 .25402 Mdot
.678 .25406 Mdot
.678 .25452 Mdot
.678 .25472 Mdot
.678 .2552 Mdot
.678 .25689 Mdot
.678 .25697 Mdot
.678 .25767 Mdot
.678 .25811 Mdot
.678 .25846 Mdot
.678 .25871 Mdot
.678 .26018 Mdot
.678 .26054 Mdot
.678 .26116 Mdot
.678 .26122 Mdot
.678 .26124 Mdot
.678 .2629 Mdot
.678 .26291 Mdot
.678 .26304 Mdot
.678 .26334 Mdot
.678 .26365 Mdot
.678 .26483 Mdot
.678 .26494 Mdot
.678 .26564 Mdot
.678 .266 Mdot
.678 .26714 Mdot
.678 .26815 Mdot
.678 .26875 Mdot
.678 .2688 Mdot
.678 .26992 Mdot
.678 .27046 Mdot
.678 .27089 Mdot
.678 .27093 Mdot
.678 .27113 Mdot
.678 .27242 Mdot
.678 .27269 Mdot
.678 .27462 Mdot
.678 .27489 Mdot
.678 .27504 Mdot
.678 .2754 Mdot
.678 .27576 Mdot
.678 .27582 Mdot
.678 .27656 Mdot
.678 .27748 Mdot
.678 .27855 Mdot
.678 .2789 Mdot
.678 .27892 Mdot
.678 .27974 Mdot
.678 .28003 Mdot
.678 .28026 Mdot
.678 .28101 Mdot
.678 .28115 Mdot
.678 .28199 Mdot
.678 .28237 Mdot
.678 .28323 Mdot
.678 .28497 Mdot
.678 .28522 Mdot
.678 .28594 Mdot
.678 .28631 Mdot
.678 .28639 Mdot
.678 .28694 Mdot
.678 .28735 Mdot
.678 .28805 Mdot
.678 .28946 Mdot
.678 .29039 Mdot
.678 .29134 Mdot
.678 .29177 Mdot
.678 .2927 Mdot
.678 .29365 Mdot
.678 .29382 Mdot
.678 .29461 Mdot
.678 .29487 Mdot
.678 .29821 Mdot
.678 .29857 Mdot
.678 .29934 Mdot
.678 .29935 Mdot
.678 .29944 Mdot
.678 .30053 Mdot
.678 .30152 Mdot
.678 .30164 Mdot
.678 .3044 Mdot
.678 .30442 Mdot
.678 .30494 Mdot
.678 .30675 Mdot
.678 .30841 Mdot
.678 .30854 Mdot
.678 .30855 Mdot
.678 .30907 Mdot
.678 .30998 Mdot
.678 .31087 Mdot
.678 .31095 Mdot
.678 .31124 Mdot
.678 .31171 Mdot
.678 .31242 Mdot
.678 .313 Mdot
.678 .31349 Mdot
.678 .31407 Mdot
.678 .3146 Mdot
.678 .31473 Mdot
.678 .31546 Mdot
.678 .3164 Mdot
.678 .31722 Mdot
.678 .31806 Mdot
.678 .31843 Mdot
.678 .31904 Mdot
.678 .31993 Mdot
.678 .31996 Mdot
.678 .32036 Mdot
.678 .32072 Mdot
.678 .32302 Mdot
.678 .32307 Mdot
.678 .32523 Mdot
.678 .32538 Mdot
.678 .32557 Mdot
.678 .32646 Mdot
.678 .32792 Mdot
.678 .32839 Mdot
.678 .32951 Mdot
.678 .32971 Mdot
.678 .32991 Mdot
.678 .33003 Mdot
.678 .33045 Mdot
.678 .33094 Mdot
.678 .33211 Mdot
.678 .33248 Mdot
.678 .3332 Mdot
.678 .3337 Mdot
.678 .3361 Mdot
.678 .33638 Mdot
.678 .33806 Mdot
.678 .33922 Mdot
.678 .33927 Mdot
.678 .33989 Mdot
.678 .34016 Mdot
.678 .34081 Mdot
.678 .3431 Mdot
.678 .34321 Mdot
.678 .34416 Mdot
.678 .34476 Mdot
.678 .34524 Mdot
.678 .34557 Mdot
.678 .34805 Mdot
.678 .3489 Mdot
.678 .34897 Mdot
.678 .349 Mdot
.678 .35126 Mdot
.678 .35127 Mdot
.678 .35145 Mdot
.678 .35185 Mdot
.678 .35227 Mdot
.678 .35387 Mdot
.678 .35402 Mdot
.678 .35496 Mdot
.678 .35546 Mdot
.678 .357 Mdot
.678 .35838 Mdot
.678 .35919 Mdot
.678 .35925 Mdot
.678 .36078 Mdot
.678 .36151 Mdot
.678 .36209 Mdot
.678 .36214 Mdot
.678 .36241 Mdot
.678 .36417 Mdot
.678 .36453 Mdot
.678 .36715 Mdot
.678 .36751 Mdot
.678 .36771 Mdot
.678 .36821 Mdot
.678 .3687 Mdot
.678 .36878 Mdot
.678 .36977 Mdot
.678 .37103 Mdot
.678 .37248 Mdot
.678 .37296 Mdot
.678 .37298 Mdot
.678 .37409 Mdot
.678 .37449 Mdot
.678 .3748 Mdot
.678 .37581 Mdot
.678 .376 Mdot
.678 .37714 Mdot
.678 .37765 Mdot
.678 .37882 Mdot
.678 .38118 Mdot
.678 .38153 Mdot
.678 .38249 Mdot
.678 .383 Mdot
.678 .3831 Mdot
.678 .38385 Mdot
.678 .38441 Mdot
.678 .38536 Mdot
.678 .38727 Mdot
.678 .38854 Mdot
.678 .38981 Mdot
.678 .39041 Mdot
.678 .39166 Mdot
.678 .39295 Mdot
.678 .39318 Mdot
.678 .39425 Mdot
.678 .39461 Mdot
.678 .39913 Mdot
.678 .39963 Mdot
.678 .40067 Mdot
.678 .40068 Mdot
.678 .4008 Mdot
.678 .40228 Mdot
.678 .40362 Mdot
.678 .40378 Mdot
.678 .40752 Mdot
.678 .40756 Mdot
.678 .40826 Mdot
.678 .41071 Mdot
.678 .41297 Mdot
.678 .41314 Mdot
.678 .41316 Mdot
.678 .41386 Mdot
.678 .41509 Mdot
.68 .01573 Mdot
.68 .01586 Mdot
.68 .0161 Mdot
.68 .01627 Mdot
.68 .0166 Mdot
.68 .01683 Mdot
.68 .01727 Mdot
.68 .01759 Mdot
.68 .01807 Mdot
.68 .01819 Mdot
.68 .01862 Mdot
.68 .0189 Mdot
.68 .01927 Mdot
.68 .01943 Mdot
.68 .01945 Mdot
.68 .01947 Mdot
.68 .02003 Mdot
.68 .02041 Mdot
.68 .02091 Mdot
.68 .02112 Mdot
.68 .02115 Mdot
.68 .02119 Mdot
.68 .02145 Mdot
.68 .02195 Mdot
.68 .02246 Mdot
.68 .02249 Mdot
.68 .02315 Mdot
.68 .02343 Mdot
.68 .02346 Mdot
.68 .02352 Mdot
.68 .02387 Mdot
.68 .02425 Mdot
.68 .02455 Mdot
.68 .02463 Mdot
.68 .02525 Mdot
.68 .02529 Mdot
.68 .02618 Mdot
.68 .02656 Mdot
.68 .02661 Mdot
.68 .02669 Mdot
.68 .02717 Mdot
.68 .02768 Mdot
.68 .02809 Mdot
.68 .0282 Mdot
.68 .02904 Mdot
.68 .0291 Mdot
.68 .0291 Mdot
.68 .03018 Mdot
.68 .03031 Mdot
.68 .03036 Mdot
.68 .03083 Mdot
.68 .0309 Mdot
.68 .03097 Mdot
.68 .031 Mdot
.68 .03108 Mdot
.68 .03166 Mdot
.68 .03195 Mdot
.68 .03235 Mdot
.68 .03262 Mdot
.68 .0329 Mdot
.68 .03305 Mdot
.68 .03306 Mdot
.68 .03396 Mdot
.68 .03414 Mdot
.68 .0342 Mdot
.68 .03427 Mdot
.68 .03428 Mdot
.68 .03431 Mdot
.68 .03575 Mdot
.68 .03592 Mdot
.68 .03596 Mdot
.68 .03599 Mdot
.68 .03611 Mdot
.68 .03614 Mdot
.68 .03663 Mdot
.68 .0367 Mdot
.68 .03672 Mdot
.68 .03683 Mdot
.68 .03686 Mdot
.68 .03698 Mdot
.68 .03708 Mdot
.68 .03764 Mdot
.68 .03775 Mdot
.68 .03815 Mdot
.68 .0387 Mdot
.68 .03906 Mdot
.68 .03945 Mdot
.68 .03966 Mdot
.68 .03967 Mdot
.68 .04005 Mdot
.68 .04088 Mdot
.68 .04113 Mdot
.68 .04121 Mdot
.68 .04131 Mdot
.68 .04132 Mdot
.68 .04136 Mdot
.68 .04211 Mdot
.68 .04332 Mdot
.68 .04356 Mdot
.68 .04361 Mdot
.68 .04364 Mdot
.68 .04364 Mdot
.68 .04365 Mdot
.68 .04369 Mdot
.68 .04381 Mdot
.68 .04386 Mdot
.68 .04452 Mdot
.68 .04462 Mdot
.68 .04465 Mdot
.68 .04479 Mdot
.68 .04483 Mdot
.68 .04499 Mdot
.68 .04513 Mdot
.68 .04589 Mdot
.68 .04605 Mdot
.68 .04659 Mdot
.68 .04681 Mdot
.68 .04733 Mdot
.68 .04783 Mdot
.68 .04836 Mdot
.68 .04863 Mdot
.68 .04865 Mdot
.68 .04868 Mdot
.68 .04917 Mdot
.68 .04943 Mdot
.68 .04974 Mdot
.68 .0503 Mdot
.68 .05041 Mdot
.68 .05055 Mdot
.68 .05064 Mdot
.68 .05075 Mdot
.68 .05089 Mdot
.68 .0509 Mdot
.68 .05095 Mdot
.68 .05155 Mdot
.68 .05198 Mdot
.68 .05347 Mdot
.68 .05361 Mdot
.68 .05394 Mdot
.68 .05402 Mdot
.68 .05405 Mdot
.68 .05406 Mdot
.68 .05407 Mdot
.68 .05412 Mdot
.68 .05429 Mdot
.68 .05435 Mdot
.68 .05455 Mdot
.68 .05525 Mdot
.68 .05538 Mdot
.68 .05542 Mdot
.68 .05543 Mdot
.68 .05561 Mdot
.68 .05567 Mdot
.68 .05589 Mdot
.68 .05609 Mdot
.68 .05613 Mdot
.68 .05712 Mdot
.68 .05733 Mdot
.68 .05779 Mdot
.68 .05807 Mdot
.68 .05837 Mdot
.68 .05907 Mdot
.68 .05975 Mdot
.68 .06047 Mdot
.68 .06048 Mdot
.68 .06084 Mdot
.68 .06087 Mdot
.68 .0609 Mdot
.68 .06158 Mdot
.68 .06193 Mdot
.68 .06199 Mdot
.68 .06235 Mdot
.68 .06312 Mdot
.68 .06326 Mdot
.68 .06345 Mdot
.68 .06358 Mdot
.68 .06372 Mdot
.68 .06391 Mdot
.68 .06393 Mdot
.68 .064 Mdot
.68 .06481 Mdot
.68 .06481 Mdot
.68 .06481 Mdot
.68 .06539 Mdot
.68 .06618 Mdot
.68 .06742 Mdot
.68 .06762 Mdot
.68 .06784 Mdot
.68 .06806 Mdot
.68 .06817 Mdot
.68 .06821 Mdot
.68 .06822 Mdot
.68 .06823 Mdot
.68 .0683 Mdot
.68 .06854 Mdot
.68 .06861 Mdot
.68 .06883 Mdot
.68 .06889 Mdot
.68 .06916 Mdot
.68 .06967 Mdot
.68 .06975 Mdot
.68 .06984 Mdot
.68 .07002 Mdot
.68 .07008 Mdot
.68 .07009 Mdot
.68 .07034 Mdot
.68 .07042 Mdot
.68 .07071 Mdot
.68 .07098 Mdot
.68 .07104 Mdot
.68 .07166 Mdot
.68 .07206 Mdot
.68 .07236 Mdot
.68 .07238 Mdot
.68 .07256 Mdot
.68 .07267 Mdot
.68 .07296 Mdot
.68 .07303 Mdot
.68 .07314 Mdot
.68 .0733 Mdot
.68 .07367 Mdot
.68 .07373 Mdot
.68 .07384 Mdot
.68 .07408 Mdot
.68 .07504 Mdot
.68 .07576 Mdot
.68 .07596 Mdot
.68 .07636 Mdot
.68 .07642 Mdot
.68 .07694 Mdot
.68 .07695 Mdot
.68 .07745 Mdot
.68 .07749 Mdot
.68 .07753 Mdot
.68 .07825 Mdot
.68 .07845 Mdot
.68 .0788 Mdot
.68 .07893 Mdot
.68 .07901 Mdot
.68 .0795 Mdot
.68 .07977 Mdot
.68 .08054 Mdot
.68 .08071 Mdot
.68 .08074 Mdot
.68 .08084 Mdot
.68 .08099 Mdot
.68 .0811 Mdot
.68 .08117 Mdot
.68 .08136 Mdot
.68 .08163 Mdot
.68 .08165 Mdot
.68 .08174 Mdot
.68 .0826 Mdot
.68 .08284 Mdot
.68 .08284 Mdot
.68 .08285 Mdot
.68 .08334 Mdot
.68 .08363 Mdot
.68 .0838 Mdot
.68 .08456 Mdot
.68 .0847 Mdot
.68 .08481 Mdot
.68 .0855 Mdot
.68 .08618 Mdot
.68 .08618 Mdot
.68 .0864 Mdot
.68 .08666 Mdot
.68 .08695 Mdot
.68 .08696 Mdot
.68 .08727 Mdot
.68 .08738 Mdot
.68 .08741 Mdot
.68 .08747 Mdot
.68 .08748 Mdot
.68 .0875 Mdot
.68 .08759 Mdot
.68 .08791 Mdot
.68 .08802 Mdot
.68 .08831 Mdot
.68 .08839 Mdot
.68 .08855 Mdot
.68 .08876 Mdot
.68 .089 Mdot
.68 .08911 Mdot
.68 .08931 Mdot
.68 .08945 Mdot
.68 .08956 Mdot
.68 .08968 Mdot
.68 .08994 Mdot
.68 .09001 Mdot
.68 .09002 Mdot
.68 .09036 Mdot
.68 .09047 Mdot
.68 .09087 Mdot
.68 .09123 Mdot
.68 .09125 Mdot
.68 .09132 Mdot
.68 .09191 Mdot
.68 .09216 Mdot
.68 .09271 Mdot
.68 .09311 Mdot
.68 .09314 Mdot
.68 .09339 Mdot
.68 .09353 Mdot
.68 .09393 Mdot
.68 .09402 Mdot
.68 .09417 Mdot
.68 .09439 Mdot
.68 .09446 Mdot
.68 .0949 Mdot
.68 .09498 Mdot
.68 .09512 Mdot
.68 .09546 Mdot
.68 .09611 Mdot
.68 .09676 Mdot
.68 .09677 Mdot
.68 .09689 Mdot
.68 .0973 Mdot
.68 .09773 Mdot
.68 .09801 Mdot
.68 .09855 Mdot
.68 .09863 Mdot
.68 .09934 Mdot
.68 .09936 Mdot
.68 .09949 Mdot
.68 .09989 Mdot
.68 .10004 Mdot
.68 .10008 Mdot
.68 .10015 Mdot
.68 .10106 Mdot
.68 .10113 Mdot
.68 .10139 Mdot
.68 .10187 Mdot
.68 .10205 Mdot
.68 .10216 Mdot
.68 .10217 Mdot
.68 .10259 Mdot
.68 .10282 Mdot
.68 .10319 Mdot
.68 .10424 Mdot
.68 .10447 Mdot
.68 .10451 Mdot
.68 .10464 Mdot
.68 .10466 Mdot
.68 .10485 Mdot
.68 .10499 Mdot
.68 .10509 Mdot
.68 .10536 Mdot
.68 .10571 Mdot
.68 .10574 Mdot
.68 .10587 Mdot
.68 .10595 Mdot
.68 .10607 Mdot
.68 .10703 Mdot
.68 .10736 Mdot
.68 .10736 Mdot
.68 .10737 Mdot
.68 .10745 Mdot
.68 .10804 Mdot
.68 .10845 Mdot
.68 .10861 Mdot
.68 .10867 Mdot
.68 .10882 Mdot
.68 .10885 Mdot
.68 .10971 Mdot
.68 .1099 Mdot
.68 .11005 Mdot
.68 .1104 Mdot
.68 .11098 Mdot
.68 .11131 Mdot
.68 .11191 Mdot
.68 .11191 Mdot
.68 .11221 Mdot
.68 .11256 Mdot
.68 .11296 Mdot
.68 .11297 Mdot
.68 .11338 Mdot
.68 .11353 Mdot
.68 .11358 Mdot
.68 .11367 Mdot
.68 .11368 Mdot
.68 .1137 Mdot
.68 .11383 Mdot
.68 .11385 Mdot
.68 .11427 Mdot
.68 .11439 Mdot
.68 .11441 Mdot
.68 .1148 Mdot
.68 .11492 Mdot
.68 .11513 Mdot
.68 .11536 Mdot
.68 .11541 Mdot
.68 .11574 Mdot
.68 .1159 Mdot
.68 .11616 Mdot
.68 .11636 Mdot
.68 .11651 Mdot
.68 .11667 Mdot
.68 .11676 Mdot
.68 .11702 Mdot
.68 .11711 Mdot
.68 .11714 Mdot
.68 .11718 Mdot
.68 .1176 Mdot
.68 .11774 Mdot
.68 .11829 Mdot
.68 .11864 Mdot
.68 .11878 Mdot
.68 .11881 Mdot
.68 .1189 Mdot
.68 .1197 Mdot
.68 .11994 Mdot
.68 .12003 Mdot
.68 .12048 Mdot
.68 .12078 Mdot
.68 .12133 Mdot
.68 .12137 Mdot
.68 .12138 Mdot
.68 .12171 Mdot
.68 .12191 Mdot
.68 .12245 Mdot
.68 .12257 Mdot
.68 .12278 Mdot
.68 .12308 Mdot
.68 .12317 Mdot
.68 .12348 Mdot
.68 .12376 Mdot
.68 .12388 Mdot
.68 .12407 Mdot
.68 .12452 Mdot
.68 .12542 Mdot
.68 .1263 Mdot
.68 .1263 Mdot
.68 .12647 Mdot
.68 .12703 Mdot
.68 .12762 Mdot
.68 .12763 Mdot
.68 .128 Mdot
.68 .12872 Mdot
.68 .12885 Mdot
.68 .12981 Mdot
.68 .12983 Mdot
.68 .13001 Mdot
.68 .13056 Mdot
.68 .13075 Mdot
.68 .13081 Mdot
.68 .1309 Mdot
.68 .13174 Mdot
.68 .13176 Mdot
.68 .13214 Mdot
.68 .13224 Mdot
.68 .13256 Mdot
.68 .13259 Mdot
.68 .13324 Mdot
.68 .13348 Mdot
.68 .13364 Mdot
.68 .13365 Mdot
.68 .13423 Mdot
.68 .13453 Mdot
.68 .13505 Mdot
.68 .13516 Mdot
.68 .13646 Mdot
.68 .13678 Mdot
.68 .13683 Mdot
.68 .13701 Mdot
.68 .13705 Mdot
.68 .1373 Mdot
.68 .13749 Mdot
.68 .13762 Mdot
.68 .13789 Mdot
.68 .13794 Mdot
.68 .13799 Mdot
.68 .13847 Mdot
.68 .13852 Mdot
.68 .13869 Mdot
.68 .1388 Mdot
.68 .13896 Mdot
.68 .13967 Mdot
.68 .14027 Mdot
.68 .14072 Mdot
.68 .14072 Mdot
.68 .14073 Mdot
.68 .14084 Mdot
.68 .14164 Mdot
.68 .14219 Mdot
.68 .14241 Mdot
.68 .1425 Mdot
.68 .1427 Mdot
.68 .14273 Mdot
.68 .14303 Mdot
.68 .14359 Mdot
.68 .14391 Mdot
.68 .14416 Mdot
.68 .14437 Mdot
.68 .14485 Mdot
.68 .14564 Mdot
.68 .14608 Mdot
.68 .1469 Mdot
.68 .1469 Mdot
.68 .1473 Mdot
.68 .14779 Mdot
.68 .14808 Mdot
.68 .14818 Mdot
.68 .14832 Mdot
.68 .14835 Mdot
.68 .14891 Mdot
.68 .14902 Mdot
.68 .14911 Mdot
.68 .14917 Mdot
.68 .14929 Mdot
.68 .14931 Mdot
.68 .14934 Mdot
.68 .14951 Mdot
.68 .14954 Mdot
.68 .1501 Mdot
.68 .15028 Mdot
.68 .1503 Mdot
.68 .15083 Mdot
.68 .15099 Mdot
.68 .15128 Mdot
.68 .15155 Mdot
.68 .15159 Mdot
.68 .15166 Mdot
.68 .1521 Mdot
.68 .15232 Mdot
.68 .15246 Mdot
.68 .15268 Mdot
.68 .15275 Mdot
.68 .15295 Mdot
.68 .15315 Mdot
.68 .15315 Mdot
.68 .15338 Mdot
.68 .1535 Mdot
.68 .15384 Mdot
.68 .15397 Mdot
.68 .15401 Mdot
.68 .15406 Mdot
.68 .15463 Mdot
.68 .15483 Mdot
.68 .15557 Mdot
.68 .15605 Mdot
.68 .15624 Mdot
.68 .15628 Mdot
.68 .1564 Mdot
.68 .15704 Mdot
.68 .15716 Mdot
.68 .1575 Mdot
.68 .15782 Mdot
.68 .15795 Mdot
.68 .15855 Mdot
.68 .15893 Mdot
.68 .15897 Mdot
.68 .15937 Mdot
.68 .15971 Mdot
.68 .15977 Mdot
.68 .15978 Mdot
.68 .16023 Mdot
.68 .1605 Mdot
.68 .16124 Mdot
.68 .1614 Mdot
.68 .16168 Mdot
.68 .16209 Mdot
.68 .16221 Mdot
.68 .16264 Mdot
.68 .16302 Mdot
.68 .16318 Mdot
.68 .16344 Mdot
.68 .16405 Mdot
.68 .16527 Mdot
.68 .16647 Mdot
.68 .16647 Mdot
.68 .16671 Mdot
.68 .16747 Mdot
.68 .16826 Mdot
.68 .16828 Mdot
.68 .16879 Mdot
.68 .16977 Mdot
.68 .16993 Mdot
.68 .17124 Mdot
.68 .17127 Mdot
.68 .17152 Mdot
.68 .17226 Mdot
.68 .17252 Mdot
.68 .17261 Mdot
.68 .17273 Mdot
.68 .17386 Mdot
.68 .1739 Mdot
.68 .17442 Mdot
.68 .17454 Mdot
.68 .17498 Mdot
.68 .17503 Mdot
.68 .17591 Mdot
.68 .17624 Mdot
.68 .17645 Mdot
.68 .17647 Mdot
.68 .17725 Mdot
.68 .17767 Mdot
.68 .17837 Mdot
.68 .17852 Mdot
.68 .18029 Mdot
.68 .18072 Mdot
.68 .18079 Mdot
.68 .18104 Mdot
.68 .18108 Mdot
.68 .18143 Mdot
.68 .18169 Mdot
.68 .18187 Mdot
.68 .18223 Mdot
.68 .1823 Mdot
.68 .18237 Mdot
.68 .18302 Mdot
.68 .18308 Mdot
.68 .18332 Mdot
.68 .18347 Mdot
.68 .18369 Mdot
.68 .18465 Mdot
.68 .18547 Mdot
.68 .18608 Mdot
.68 .18608 Mdot
.68 .1861 Mdot
.68 .18624 Mdot
.68 .18734 Mdot
.68 .18808 Mdot
.68 .18838 Mdot
.68 .1885 Mdot
.68 .18877 Mdot
.68 .18882 Mdot
.68 .18922 Mdot
.68 .18998 Mdot
.68 .19041 Mdot
.68 .19076 Mdot
.68 .19104 Mdot
.68 .1917 Mdot
.68 .19277 Mdot
.68 .19337 Mdot
.68 .19449 Mdot
.68 .19449 Mdot
.68 .19504 Mdot
.68 .1957 Mdot
.68 .19609 Mdot
.68 .19622 Mdot
.68 .19642 Mdot
.68 .19646 Mdot
.68 .19721 Mdot
.68 .19737 Mdot
.68 .19749 Mdot
.68 .19757 Mdot
.68 .19773 Mdot
.68 .19776 Mdot
.68 .1978 Mdot
.68 .19804 Mdot
.68 .19808 Mdot
.68 .19884 Mdot
.68 .19908 Mdot
.68 .19911 Mdot
.68 .19984 Mdot
.68 .20005 Mdot
.68 .20044 Mdot
.68 .20081 Mdot
.68 .20086 Mdot
.68 .20097 Mdot
.68 .20156 Mdot
.68 .20186 Mdot
.68 .20204 Mdot
.68 .20234 Mdot
.68 .20244 Mdot
.68 .20272 Mdot
.68 .20299 Mdot
.68 .20299 Mdot
.68 .20329 Mdot
.68 .20346 Mdot
.68 .20393 Mdot
.68 .20411 Mdot
.68 .20415 Mdot
.68 .20423 Mdot
.68 .205 Mdot
.68 .20527 Mdot
.68 .20628 Mdot
.68 .20694 Mdot
.68 .2072 Mdot
.68 .20725 Mdot
.68 .20741 Mdot
.68 .20828 Mdot
.68 .20844 Mdot
.68 .2089 Mdot
.68 .20934 Mdot
.68 .20951 Mdot
.68 .21034 Mdot
.68 .21085 Mdot
.68 .2109 Mdot
.68 .21144 Mdot
.68 .2119 Mdot
.68 .21199 Mdot
.68 .212 Mdot
.68 .21262 Mdot
.68 .21298 Mdot
.68 .21399 Mdot
.68 .2142 Mdot
.68 .21459 Mdot
.68 .21515 Mdot
.68 .21531 Mdot
.68 .21589 Mdot
.68 .21641 Mdot
.68 .21662 Mdot
.68 .21698 Mdot
.68 .21782 Mdot
.68 .21947 Mdot
.68 .2211 Mdot
.68 .22111 Mdot
.68 .22142 Mdot
.68 .22246 Mdot
.68 .22354 Mdot
.68 .22356 Mdot
.68 .22425 Mdot
.68 .22559 Mdot
.68 .22581 Mdot
.68 .22759 Mdot
.68 .22763 Mdot
.68 .22797 Mdot
.68 .22898 Mdot
.68 .22933 Mdot
.68 .22945 Mdot
.68 .22961 Mdot
.68 .23116 Mdot
.68 .2312 Mdot
.68 .23191 Mdot
.68 .23208 Mdot
.68 .23268 Mdot
.68 .23275 Mdot
.68 .23394 Mdot
.68 .23439 Mdot
.68 .23467 Mdot
.68 .2347 Mdot
.68 .23577 Mdot
.68 .23633 Mdot
.68 .23728 Mdot
.68 .23749 Mdot
.68 .2399 Mdot
.68 .24049 Mdot
.68 .24058 Mdot
.68 .24092 Mdot
.68 .24098 Mdot
.68 .24145 Mdot
.68 .24181 Mdot
.68 .24205 Mdot
.68 .24253 Mdot
.68 .24263 Mdot
.68 .24272 Mdot
.68 .24362 Mdot
.68 .2437 Mdot
.68 .24402 Mdot
.68 .24422 Mdot
.68 .24452 Mdot
.68 .24583 Mdot
.68 .24694 Mdot
.68 .24777 Mdot
.68 .24777 Mdot
.68 .24779 Mdot
.68 .24948 Mdot
.68 .25049 Mdot
.68 .2509 Mdot
.68 .25106 Mdot
.68 .25143 Mdot
.68 .2515 Mdot
.68 .25204 Mdot
.68 .25308 Mdot
.68 .25366 Mdot
.68 .25414 Mdot
.68 .25452 Mdot
.68 .25542 Mdot
.68 .25687 Mdot
.68 .25769 Mdot
.68 .25921 Mdot
.68 .25921 Mdot
.68 .25995 Mdot
.68 .26085 Mdot
.68 .26138 Mdot
.68 .26156 Mdot
.68 .26184 Mdot
.68 .26188 Mdot
.68 .26291 Mdot
.68 .26313 Mdot
.68 .26329 Mdot
.68 .2634 Mdot
.68 .26362 Mdot
.68 .26365 Mdot
.68 .26372 Mdot
.68 .26404 Mdot
.68 .26409 Mdot
.68 .26513 Mdot
.68 .26545 Mdot
.68 .26549 Mdot
.68 .26648 Mdot
.68 .26677 Mdot
.68 .2673 Mdot
.68 .26781 Mdot
.68 .26788 Mdot
.68 .26802 Mdot
.68 .26883 Mdot
.68 .26923 Mdot
.68 .26948 Mdot
.68 .26989 Mdot
.68 .27003 Mdot
.68 .2704 Mdot
.68 .27077 Mdot
.68 .27077 Mdot
.68 .27118 Mdot
.68 .27141 Mdot
.68 .27205 Mdot
.68 .27229 Mdot
.68 .27235 Mdot
.68 .27246 Mdot
.68 .27351 Mdot
.68 .27387 Mdot
.68 .27524 Mdot
.68 .27614 Mdot
.68 .27649 Mdot
.68 .27656 Mdot
.68 .27678 Mdot
.68 .27796 Mdot
.68 .27818 Mdot
.68 .27881 Mdot
.68 .27941 Mdot
.68 .27964 Mdot
.68 .28076 Mdot
.68 .28146 Mdot
.68 .28152 Mdot
.68 .28227 Mdot
.68 .28289 Mdot
.68 .28301 Mdot
.68 .28302 Mdot
.68 .28386 Mdot
.68 .28435 Mdot
.68 .28573 Mdot
.68 .28602 Mdot
.68 .28654 Mdot
.68 .2873 Mdot
.68 .28752 Mdot
.68 .28832 Mdot
.68 .28902 Mdot
.68 .28931 Mdot
.68 .28979 Mdot
.68 .29093 Mdot
.68 .29318 Mdot
.68 .2954 Mdot
.68 .29541 Mdot
.68 .29584 Mdot
.68 .29725 Mdot
.68 .29872 Mdot
.68 .29875 Mdot
.68 .29968 Mdot
.68 .3015 Mdot
.68 .3018 Mdot
.68 .30423 Mdot
.68 .30428 Mdot
.68 .30474 Mdot
.68 .30611 Mdot
.68 .3066 Mdot
.68 .30676 Mdot
.68 .30697 Mdot
.68 .30908 Mdot
.68 .30914 Mdot
.68 .3101 Mdot
.68 .31034 Mdot
.68 .31114 Mdot
.68 .31124 Mdot
.68 .31286 Mdot
.68 .31348 Mdot
.68 .31386 Mdot
.68 .3139 Mdot
.68 .31535 Mdot
.68 .31612 Mdot
.68 .31741 Mdot
.68 .31769 Mdot
.68 .32097 Mdot
.68 .32177 Mdot
.68 .3219 Mdot
.68 .32235 Mdot
.68 .32243 Mdot
.68 .32307 Mdot
.68 .32356 Mdot
.68 .32389 Mdot
.68 .32454 Mdot
.68 .32468 Mdot
.68 .3248 Mdot
.68 .32602 Mdot
.68 .32613 Mdot
.68 .32656 Mdot
.68 .32684 Mdot
.68 .32725 Mdot
.68 .32903 Mdot
.68 .33054 Mdot
.68 .33166 Mdot
.68 .33167 Mdot
.68 .3317 Mdot
.68 .334 Mdot
.68 .33537 Mdot
.68 .33592 Mdot
.68 .33615 Mdot
.68 .33664 Mdot
.68 .33674 Mdot
.68 .33748 Mdot
.68 .33889 Mdot
.68 .33969 Mdot
.68 .34033 Mdot
.68 .34085 Mdot
.68 .34207 Mdot
.68 .34405 Mdot
.68 .34516 Mdot
.68 .34723 Mdot
.68 .34723 Mdot
.68 .34824 Mdot
.68 .34946 Mdot
.68 .35019 Mdot
.68 .35043 Mdot
.68 .3508 Mdot
.68 .35086 Mdot
.68 .35226 Mdot
.68 .35256 Mdot
.68 .35278 Mdot
.68 .35293 Mdot
.68 .35323 Mdot
.68 .35327 Mdot
.68 .35336 Mdot
.68 .35379 Mdot
.68 .35387 Mdot
.68 .35528 Mdot
.68 .35572 Mdot
.68 .35577 Mdot
.68 .35712 Mdot
.68 .35752 Mdot
.68 .35823 Mdot
.68 .35892 Mdot
.68 .35901 Mdot
.68 .35921 Mdot
.68 .36031 Mdot
.68 .36086 Mdot
.68 .3612 Mdot
.68 .36175 Mdot
.68 .36194 Mdot
.68 .36244 Mdot
.68 .36295 Mdot
.68 .36295 Mdot
.68 .36351 Mdot
.68 .36382 Mdot
.68 .36469 Mdot
.68 .36501 Mdot
.68 .3651 Mdot
.68 .36524 Mdot
.68 .36667 Mdot
.68 .36716 Mdot
.68 .36903 Mdot
.68 .37025 Mdot
.68 .37073 Mdot
.68 .37082 Mdot
.68 .37112 Mdot
.68 .37273 Mdot
.68 .37303 Mdot
.68 .37388 Mdot
.68 .3747 Mdot
.68 .37501 Mdot
.68 .37653 Mdot
.68 .37748 Mdot
.68 .37757 Mdot
.68 .37858 Mdot
.68 .37943 Mdot
.68 .37959 Mdot
.68 .37961 Mdot
.68 .38076 Mdot
.68 .38142 Mdot
.68 .38329 Mdot
.68 .38369 Mdot
.68 .3844 Mdot
.68 .38543 Mdot
.68 .38574 Mdot
.68 .38681 Mdot
.68 .38777 Mdot
.68 .38816 Mdot
.68 .38882 Mdot
.68 .39037 Mdot
.68 .39342 Mdot
.68 .39644 Mdot
.68 .39646 Mdot
.68 .39705 Mdot
.68 .39896 Mdot
.68 .40096 Mdot
.68 .401 Mdot
.68 .40227 Mdot
.68 .40474 Mdot
.68 .40516 Mdot
.68 .40846 Mdot
.68 .40853 Mdot
.68 .40915 Mdot
.68 .41101 Mdot
.68 .41168 Mdot
.68 .41189 Mdot
.68 .41219 Mdot
.68 .41505 Mdot
.68 .41513 Mdot
.68 .41644 Mdot
.68 .41676 Mdot
.682 .01513 Mdot
.682 .01529 Mdot
.682 .01549 Mdot
.682 .01578 Mdot
.682 .01616 Mdot
.682 .01669 Mdot
.682 .01741 Mdot
.682 .01779 Mdot
.682 .01831 Mdot
.682 .01839 Mdot
.682 .01891 Mdot
.682 .0193 Mdot
.682 .01945 Mdot
.682 .01958 Mdot
.682 .01962 Mdot
.682 .01973 Mdot
.682 .01984 Mdot
.682 .02044 Mdot
.682 .02096 Mdot
.682 .02117 Mdot
.682 .02136 Mdot
.682 .0214 Mdot
.682 .02156 Mdot
.682 .02171 Mdot
.682 .02244 Mdot
.682 .02252 Mdot
.682 .02307 Mdot
.682 .02324 Mdot
.682 .02337 Mdot
.682 .02352 Mdot
.682 .02377 Mdot
.682 .02383 Mdot
.682 .02384 Mdot
.682 .02405 Mdot
.682 .02425 Mdot
.682 .02525 Mdot
.682 .02536 Mdot
.682 .02542 Mdot
.682 .02551 Mdot
.682 .02561 Mdot
.682 .02612 Mdot
.682 .02634 Mdot
.682 .02652 Mdot
.682 .02673 Mdot
.682 .02693 Mdot
.682 .02704 Mdot
.682 .02707 Mdot
.682 .0271 Mdot
.682 .02714 Mdot
.682 .02715 Mdot
.682 .02715 Mdot
.682 .02745 Mdot
.682 .02773 Mdot
.682 .02908 Mdot
.682 .02924 Mdot
.682 .02931 Mdot
.682 .02944 Mdot
.682 .02958 Mdot
.682 .03027 Mdot
.682 .03057 Mdot
.682 .03082 Mdot
.682 .0311 Mdot
.682 .03137 Mdot
.682 .03153 Mdot
.682 .03157 Mdot
.682 .03161 Mdot
.682 .03166 Mdot
.682 .03168 Mdot
.682 .03168 Mdot
.682 .03188 Mdot
.682 .03208 Mdot
.682 .03246 Mdot
.682 .0332 Mdot
.682 .03336 Mdot
.682 .03431 Mdot
.682 .03452 Mdot
.682 .03462 Mdot
.682 .0348 Mdot
.682 .03499 Mdot
.682 .03593 Mdot
.682 .03634 Mdot
.682 .03668 Mdot
.682 .03707 Mdot
.682 .03744 Mdot
.682 .03765 Mdot
.682 .0377 Mdot
.682 .03775 Mdot
.682 .03783 Mdot
.682 .03786 Mdot
.682 .03786 Mdot
.682 .03813 Mdot
.682 .03839 Mdot
.682 .03841 Mdot
.682 .03865 Mdot
.682 .03892 Mdot
.682 .0399 Mdot
.682 .03992 Mdot
.682 .04006 Mdot
.682 .04015 Mdot
.682 .04015 Mdot
.682 .04053 Mdot
.682 .04145 Mdot
.682 .04173 Mdot
.682 .04187 Mdot
.682 .04196 Mdot
.682 .04202 Mdot
.682 .04211 Mdot
.682 .04237 Mdot
.682 .04347 Mdot
.682 .04365 Mdot
.682 .04421 Mdot
.682 .04468 Mdot
.682 .04521 Mdot
.682 .04534 Mdot
.682 .04571 Mdot
.682 .046 Mdot
.682 .04607 Mdot
.682 .04614 Mdot
.682 .04624 Mdot
.682 .04628 Mdot
.682 .04628 Mdot
.682 .04666 Mdot
.682 .04671 Mdot
.682 .04697 Mdot
.682 .04701 Mdot
.682 .04703 Mdot
.682 .04731 Mdot
.682 .04736 Mdot
.682 .04773 Mdot
.682 .0483 Mdot
.682 .04907 Mdot
.682 .0491 Mdot
.682 .04914 Mdot
.682 .04929 Mdot
.682 .0494 Mdot
.682 .04941 Mdot
.682 .04993 Mdot
.682 .05118 Mdot
.682 .05157 Mdot
.682 .05175 Mdot
.682 .05188 Mdot
.682 .05196 Mdot
.682 .05208 Mdot
.682 .05243 Mdot
.682 .05294 Mdot
.682 .05302 Mdot
.682 .05394 Mdot
.682 .05418 Mdot
.682 .05495 Mdot
.682 .05518 Mdot
.682 .05559 Mdot
.682 .0556 Mdot
.682 .05572 Mdot
.682 .05595 Mdot
.682 .0563 Mdot
.682 .05648 Mdot
.682 .05658 Mdot
.682 .05673 Mdot
.682 .05699 Mdot
.682 .05738 Mdot
.682 .05749 Mdot
.682 .05758 Mdot
.682 .05762 Mdot
.682 .05772 Mdot
.682 .05777 Mdot
.682 .05777 Mdot
.682 .05819 Mdot
.682 .05829 Mdot
.682 .05836 Mdot
.682 .05871 Mdot
.682 .05876 Mdot
.682 .05879 Mdot
.682 .05889 Mdot
.682 .05915 Mdot
.682 .05918 Mdot
.682 .05924 Mdot
.682 .05933 Mdot
.682 .05937 Mdot
.682 .05975 Mdot
.682 .05993 Mdot
.682 .06032 Mdot
.682 .06052 Mdot
.682 .06158 Mdot
.682 .06161 Mdot
.682 .06167 Mdot
.682 .06187 Mdot
.682 .06202 Mdot
.682 .06203 Mdot
.682 .06204 Mdot
.682 .06275 Mdot
.682 .06332 Mdot
.682 .06445 Mdot
.682 .06498 Mdot
.682 .06523 Mdot
.682 .06541 Mdot
.682 .06551 Mdot
.682 .06566 Mdot
.682 .06569 Mdot
.682 .06582 Mdot
.682 .06616 Mdot
.682 .06685 Mdot
.682 .06696 Mdot
.682 .06743 Mdot
.682 .06821 Mdot
.682 .06855 Mdot
.682 .06936 Mdot
.682 .0696 Mdot
.682 .0699 Mdot
.682 .07008 Mdot
.682 .07021 Mdot
.682 .07036 Mdot
.682 .07046 Mdot
.682 .07047 Mdot
.682 .07048 Mdot
.682 .07065 Mdot
.682 .07096 Mdot
.682 .07097 Mdot
.682 .07144 Mdot
.682 .07169 Mdot
.682 .07182 Mdot
.682 .07202 Mdot
.682 .07238 Mdot
.682 .07292 Mdot
.682 .07305 Mdot
.682 .07318 Mdot
.682 .07324 Mdot
.682 .07338 Mdot
.682 .07345 Mdot
.682 .07345 Mdot
.682 .07401 Mdot
.682 .07415 Mdot
.682 .07425 Mdot
.682 .0745 Mdot
.682 .07473 Mdot
.682 .07479 Mdot
.682 .07484 Mdot
.682 .07496 Mdot
.682 .07502 Mdot
.682 .07532 Mdot
.682 .07536 Mdot
.682 .07545 Mdot
.682 .07557 Mdot
.682 .07563 Mdot
.682 .07573 Mdot
.682 .07615 Mdot
.682 .07639 Mdot
.682 .07692 Mdot
.682 .07699 Mdot
.682 .0772 Mdot
.682 .07864 Mdot
.682 .07868 Mdot
.682 .07876 Mdot
.682 .07903 Mdot
.682 .07924 Mdot
.682 .07925 Mdot
.682 .07926 Mdot
.682 .08024 Mdot
.682 .08102 Mdot
.682 .08135 Mdot
.682 .08256 Mdot
.682 .08328 Mdot
.682 .08329 Mdot
.682 .08362 Mdot
.682 .08384 Mdot
.682 .08386 Mdot
.682 .084 Mdot
.682 .0842 Mdot
.682 .08424 Mdot
.682 .08427 Mdot
.682 .08442 Mdot
.682 .08489 Mdot
.682 .08583 Mdot
.682 .08596 Mdot
.682 .08598 Mdot
.682 .08662 Mdot
.682 .08769 Mdot
.682 .08814 Mdot
.682 .08925 Mdot
.682 .08957 Mdot
.682 .08962 Mdot
.682 .08999 Mdot
.682 .09023 Mdot
.682 .09042 Mdot
.682 .09062 Mdot
.682 .09076 Mdot
.682 .09076 Mdot
.682 .09076 Mdot
.682 .09077 Mdot
.682 .09101 Mdot
.682 .09139 Mdot
.682 .09143 Mdot
.682 .09144 Mdot
.682 .09209 Mdot
.682 .09243 Mdot
.682 .09259 Mdot
.682 .09261 Mdot
.682 .09288 Mdot
.682 .09337 Mdot
.682 .09381 Mdot
.682 .0941 Mdot
.682 .09429 Mdot
.682 .09447 Mdot
.682 .09454 Mdot
.682 .09473 Mdot
.682 .09483 Mdot
.682 .09483 Mdot
.682 .09559 Mdot
.682 .09578 Mdot
.682 .09592 Mdot
.682 .0962 Mdot
.682 .09626 Mdot
.682 .09657 Mdot
.682 .09666 Mdot
.682 .09672 Mdot
.682 .0969 Mdot
.682 .09698 Mdot
.682 .09738 Mdot
.682 .09743 Mdot
.682 .09755 Mdot
.682 .09772 Mdot
.682 .09773 Mdot
.682 .0978 Mdot
.682 .09793 Mdot
.682 .09851 Mdot
.682 .09879 Mdot
.682 .09884 Mdot
.682 .09893 Mdot
.682 .09957 Mdot
.682 .09966 Mdot
.682 .09994 Mdot
.682 .10023 Mdot
.682 .10111 Mdot
.682 .10114 Mdot
.682 .10117 Mdot
.682 .10122 Mdot
.682 .10191 Mdot
.682 .10197 Mdot
.682 .10207 Mdot
.682 .10244 Mdot
.682 .10272 Mdot
.682 .10275 Mdot
.682 .10276 Mdot
.682 .10277 Mdot
.682 .10409 Mdot
.682 .10515 Mdot
.682 .10521 Mdot
.682 .10547 Mdot
.682 .10552 Mdot
.682 .1056 Mdot
.682 .10691 Mdot
.682 .10725 Mdot
.682 .10823 Mdot
.682 .10825 Mdot
.682 .10871 Mdot
.682 .10887 Mdot
.682 .109 Mdot
.682 .10903 Mdot
.682 .10922 Mdot
.682 .10949 Mdot
.682 .10955 Mdot
.682 .10959 Mdot
.682 .10971 Mdot
.682 .1098 Mdot
.682 .11043 Mdot
.682 .11171 Mdot
.682 .11186 Mdot
.682 .11189 Mdot
.682 .11192 Mdot
.682 .11205 Mdot
.682 .1128 Mdot
.682 .11291 Mdot
.682 .11306 Mdot
.682 .11333 Mdot
.682 .11425 Mdot
.682 .11478 Mdot
.682 .11487 Mdot
.682 .11523 Mdot
.682 .11638 Mdot
.682 .11682 Mdot
.682 .11689 Mdot
.682 .1174 Mdot
.682 .11772 Mdot
.682 .11794 Mdot
.682 .11797 Mdot
.682 .11825 Mdot
.682 .11843 Mdot
.682 .11844 Mdot
.682 .11845 Mdot
.682 .11846 Mdot
.682 .11879 Mdot
.682 .1193 Mdot
.682 .11936 Mdot
.682 .11937 Mdot
.682 .12026 Mdot
.682 .12071 Mdot
.682 .12075 Mdot
.682 .12093 Mdot
.682 .12097 Mdot
.682 .12102 Mdot
.682 .12133 Mdot
.682 .122 Mdot
.682 .1226 Mdot
.682 .12265 Mdot
.682 .123 Mdot
.682 .12326 Mdot
.682 .1235 Mdot
.682 .12359 Mdot
.682 .12385 Mdot
.682 .12387 Mdot
.682 .12399 Mdot
.682 .12399 Mdot
.682 .125 Mdot
.682 .12503 Mdot
.682 .12529 Mdot
.682 .12547 Mdot
.682 .12547 Mdot
.682 .12586 Mdot
.682 .12595 Mdot
.682 .12637 Mdot
.682 .12648 Mdot
.682 .12657 Mdot
.682 .12669 Mdot
.682 .12679 Mdot
.682 .12681 Mdot
.682 .12692 Mdot
.682 .12732 Mdot
.682 .12732 Mdot
.682 .12747 Mdot
.682 .12754 Mdot
.682 .12771 Mdot
.682 .12793 Mdot
.682 .12794 Mdot
.682 .12804 Mdot
.682 .12823 Mdot
.682 .12901 Mdot
.682 .1294 Mdot
.682 .12947 Mdot
.682 .12958 Mdot
.682 .13046 Mdot
.682 .13058 Mdot
.682 .13096 Mdot
.682 .13135 Mdot
.682 .13212 Mdot
.682 .13227 Mdot
.682 .13255 Mdot
.682 .1326 Mdot
.682 .13264 Mdot
.682 .13271 Mdot
.682 .13346 Mdot
.682 .13364 Mdot
.682 .13373 Mdot
.682 .13386 Mdot
.682 .13432 Mdot
.682 .13435 Mdot
.682 .13438 Mdot
.682 .13476 Mdot
.682 .13479 Mdot
.682 .13481 Mdot
.682 .13482 Mdot
.682 .13619 Mdot
.682 .13657 Mdot
.682 .13662 Mdot
.682 .13807 Mdot
.682 .13814 Mdot
.682 .13851 Mdot
.682 .13855 Mdot
.682 .13858 Mdot
.682 .13869 Mdot
.682 .13912 Mdot
.682 .13954 Mdot
.682 .14008 Mdot
.682 .14047 Mdot
.682 .14055 Mdot
.682 .14065 Mdot
.682 .14093 Mdot
.682 .14117 Mdot
.682 .14227 Mdot
.682 .1423 Mdot
.682 .14292 Mdot
.682 .14304 Mdot
.682 .14308 Mdot
.682 .14314 Mdot
.682 .14333 Mdot
.682 .14337 Mdot
.682 .14362 Mdot
.682 .14379 Mdot
.682 .14399 Mdot
.682 .14407 Mdot
.682 .14412 Mdot
.682 .14413 Mdot
.682 .14429 Mdot
.682 .14441 Mdot
.682 .1449 Mdot
.682 .14527 Mdot
.682 .14595 Mdot
.682 .14599 Mdot
.682 .14646 Mdot
.682 .14702 Mdot
.682 .14722 Mdot
.682 .14726 Mdot
.682 .14731 Mdot
.682 .14734 Mdot
.682 .14748 Mdot
.682 .1485 Mdot
.682 .14865 Mdot
.682 .14886 Mdot
.682 .14922 Mdot
.682 .15048 Mdot
.682 .15104 Mdot
.682 .1512 Mdot
.682 .15133 Mdot
.682 .15181 Mdot
.682 .15287 Mdot
.682 .1532 Mdot
.682 .15338 Mdot
.682 .15373 Mdot
.682 .15408 Mdot
.682 .15477 Mdot
.682 .15521 Mdot
.682 .15552 Mdot
.682 .15556 Mdot
.682 .15593 Mdot
.682 .15619 Mdot
.682 .1562 Mdot
.682 .15621 Mdot
.682 .15622 Mdot
.682 .15667 Mdot
.682 .15737 Mdot
.682 .15745 Mdot
.682 .15746 Mdot
.682 .15787 Mdot
.682 .15843 Mdot
.682 .15867 Mdot
.682 .1593 Mdot
.682 .15935 Mdot
.682 .1596 Mdot
.682 .15964 Mdot
.682 .15972 Mdot
.682 .16014 Mdot
.682 .16027 Mdot
.682 .16105 Mdot
.682 .16186 Mdot
.682 .16194 Mdot
.682 .16241 Mdot
.682 .16277 Mdot
.682 .16309 Mdot
.682 .16323 Mdot
.682 .16358 Mdot
.682 .16361 Mdot
.682 .16376 Mdot
.682 .16376 Mdot
.682 .16515 Mdot
.682 .16519 Mdot
.682 .16553 Mdot
.682 .16578 Mdot
.682 .16579 Mdot
.682 .16632 Mdot
.682 .16643 Mdot
.682 .16701 Mdot
.682 .16717 Mdot
.682 .16729 Mdot
.682 .16745 Mdot
.682 .16758 Mdot
.682 .16761 Mdot
.682 .16776 Mdot
.682 .1683 Mdot
.682 .16831 Mdot
.682 .16852 Mdot
.682 .16861 Mdot
.682 .16884 Mdot
.682 .16914 Mdot
.682 .16916 Mdot
.682 .16929 Mdot
.682 .16954 Mdot
.682 .17061 Mdot
.682 .17114 Mdot
.682 .17124 Mdot
.682 .17139 Mdot
.682 .17259 Mdot
.682 .17275 Mdot
.682 .17328 Mdot
.682 .17381 Mdot
.682 .17485 Mdot
.682 .17506 Mdot
.682 .17545 Mdot
.682 .17551 Mdot
.682 .17556 Mdot
.682 .17566 Mdot
.682 .17668 Mdot
.682 .17693 Mdot
.682 .17705 Mdot
.682 .17723 Mdot
.682 .17786 Mdot
.682 .1779 Mdot
.682 .17793 Mdot
.682 .17845 Mdot
.682 .1785 Mdot
.682 .17852 Mdot
.682 .17854 Mdot
.682 .18041 Mdot
.682 .18092 Mdot
.682 .18099 Mdot
.682 .18297 Mdot
.682 .18307 Mdot
.682 .18357 Mdot
.682 .18363 Mdot
.682 .18366 Mdot
.682 .18382 Mdot
.682 .1844 Mdot
.682 .18497 Mdot
.682 .18571 Mdot
.682 .18625 Mdot
.682 .18635 Mdot
.682 .18649 Mdot
.682 .18687 Mdot
.682 .18721 Mdot
.682 .1887 Mdot
.682 .18874 Mdot
.682 .18959 Mdot
.682 .18975 Mdot
.682 .1898 Mdot
.682 .18989 Mdot
.682 .19014 Mdot
.682 .1902 Mdot
.682 .19055 Mdot
.682 .19077 Mdot
.682 .19105 Mdot
.682 .19115 Mdot
.682 .19122 Mdot
.682 .19124 Mdot
.682 .19146 Mdot
.682 .19161 Mdot
.682 .19228 Mdot
.682 .1928 Mdot
.682 .19371 Mdot
.682 .19378 Mdot
.682 .19442 Mdot
.682 .19517 Mdot
.682 .19546 Mdot
.682 .19551 Mdot
.682 .19557 Mdot
.682 .19561 Mdot
.682 .19581 Mdot
.682 .1972 Mdot
.682 .19741 Mdot
.682 .19768 Mdot
.682 .19818 Mdot
.682 .1999 Mdot
.682 .20066 Mdot
.682 .20088 Mdot
.682 .20105 Mdot
.682 .20171 Mdot
.682 .20316 Mdot
.682 .20361 Mdot
.682 .20386 Mdot
.682 .20433 Mdot
.682 .20481 Mdot
.682 .20575 Mdot
.682 .20635 Mdot
.682 .20677 Mdot
.682 .20682 Mdot
.682 .20734 Mdot
.682 .20768 Mdot
.682 .2077 Mdot
.682 .20771 Mdot
.682 .20773 Mdot
.682 .20834 Mdot
.682 .2093 Mdot
.682 .2094 Mdot
.682 .20942 Mdot
.682 .20997 Mdot
.682 .21074 Mdot
.682 .21108 Mdot
.682 .21192 Mdot
.682 .212 Mdot
.682 .21234 Mdot
.682 .21239 Mdot
.682 .2125 Mdot
.682 .21307 Mdot
.682 .21325 Mdot
.682 .21432 Mdot
.682 .21543 Mdot
.682 .21553 Mdot
.682 .21617 Mdot
.682 .21666 Mdot
.682 .2171 Mdot
.682 .21728 Mdot
.682 .21776 Mdot
.682 .2178 Mdot
.682 .21801 Mdot
.682 .21801 Mdot
.682 .2199 Mdot
.682 .21996 Mdot
.682 .22043 Mdot
.682 .22077 Mdot
.682 .22078 Mdot
.682 .22151 Mdot
.682 .22166 Mdot
.682 .22244 Mdot
.682 .22266 Mdot
.682 .22283 Mdot
.682 .22304 Mdot
.682 .22323 Mdot
.682 .22326 Mdot
.682 .22347 Mdot
.682 .22421 Mdot
.682 .22422 Mdot
.682 .2245 Mdot
.682 .22463 Mdot
.682 .22494 Mdot
.682 .22535 Mdot
.682 .22537 Mdot
.682 .22556 Mdot
.682 .2259 Mdot
.682 .22736 Mdot
.682 .22808 Mdot
.682 .22821 Mdot
.682 .22842 Mdot
.682 .23005 Mdot
.682 .23027 Mdot
.682 .231 Mdot
.682 .23172 Mdot
.682 .23314 Mdot
.682 .23342 Mdot
.682 .23395 Mdot
.682 .23403 Mdot
.682 .23411 Mdot
.682 .23425 Mdot
.682 .23564 Mdot
.682 .23598 Mdot
.682 .23614 Mdot
.682 .23639 Mdot
.682 .23724 Mdot
.682 .23729 Mdot
.682 .23735 Mdot
.682 .23805 Mdot
.682 .23812 Mdot
.682 .23815 Mdot
.682 .23817 Mdot
.682 .24072 Mdot
.682 .24142 Mdot
.682 .24151 Mdot
.682 .24421 Mdot
.682 .24435 Mdot
.682 .24503 Mdot
.682 .24511 Mdot
.682 .24516 Mdot
.682 .24537 Mdot
.682 .24617 Mdot
.682 .24695 Mdot
.682 .24795 Mdot
.682 .24869 Mdot
.682 .24883 Mdot
.682 .24901 Mdot
.682 .24954 Mdot
.682 .24999 Mdot
.682 .25203 Mdot
.682 .25208 Mdot
.682 .25324 Mdot
.682 .25346 Mdot
.682 .25353 Mdot
.682 .25365 Mdot
.682 .25399 Mdot
.682 .25407 Mdot
.682 .25455 Mdot
.682 .25486 Mdot
.682 .25523 Mdot
.682 .25537 Mdot
.682 .25547 Mdot
.682 .25549 Mdot
.682 .25579 Mdot
.682 .256 Mdot
.682 .25692 Mdot
.682 .25762 Mdot
.682 .25887 Mdot
.682 .25896 Mdot
.682 .25983 Mdot
.682 .26086 Mdot
.682 .26125 Mdot
.682 .26132 Mdot
.682 .2614 Mdot
.682 .26146 Mdot
.682 .26172 Mdot
.682 .26362 Mdot
.682 .26391 Mdot
.682 .26428 Mdot
.682 .26496 Mdot
.682 .26731 Mdot
.682 .26835 Mdot
.682 .26865 Mdot
.682 .26888 Mdot
.682 .26978 Mdot
.682 .27175 Mdot
.682 .27237 Mdot
.682 .2727 Mdot
.682 .27335 Mdot
.682 .274 Mdot
.682 .27529 Mdot
.682 .2761 Mdot
.682 .27668 Mdot
.682 .27675 Mdot
.682 .27745 Mdot
.682 .27792 Mdot
.682 .27794 Mdot
.682 .27796 Mdot
.682 .27799 Mdot
.682 .27882 Mdot
.682 .28013 Mdot
.682 .28027 Mdot
.682 .2803 Mdot
.682 .28105 Mdot
.682 .2821 Mdot
.682 .28255 Mdot
.682 .28371 Mdot
.682 .28381 Mdot
.682 .28427 Mdot
.682 .28435 Mdot
.682 .28449 Mdot
.682 .28527 Mdot
.682 .28551 Mdot
.682 .28697 Mdot
.682 .28848 Mdot
.682 .28863 Mdot
.682 .28951 Mdot
.682 .29016 Mdot
.682 .29077 Mdot
.682 .29102 Mdot
.682 .29167 Mdot
.682 .29173 Mdot
.682 .29201 Mdot
.682 .29202 Mdot
.682 .29459 Mdot
.682 .29467 Mdot
.682 .29531 Mdot
.682 .29578 Mdot
.682 .29579 Mdot
.682 .29678 Mdot
.682 .29699 Mdot
.682 .29805 Mdot
.682 .29836 Mdot
.682 .29858 Mdot
.682 .29887 Mdot
.682 .29912 Mdot
.682 .29918 Mdot
.682 .29946 Mdot
.682 .30046 Mdot
.682 .30048 Mdot
.682 .30087 Mdot
.682 .30104 Mdot
.682 .30146 Mdot
.682 .30203 Mdot
.682 .30205 Mdot
.682 .3023 Mdot
.682 .30277 Mdot
.682 .30476 Mdot
.682 .30575 Mdot
.682 .30592 Mdot
.682 .30621 Mdot
.682 .30843 Mdot
.682 .30874 Mdot
.682 .30972 Mdot
.682 .3107 Mdot
.682 .31265 Mdot
.682 .31303 Mdot
.682 .31375 Mdot
.682 .31387 Mdot
.682 .31397 Mdot
.682 .31416 Mdot
.682 .31606 Mdot
.682 .31652 Mdot
.682 .31674 Mdot
.682 .31708 Mdot
.682 .31824 Mdot
.682 .31831 Mdot
.682 .31838 Mdot
.682 .31935 Mdot
.682 .31943 Mdot
.682 .31948 Mdot
.682 .3195 Mdot
.682 .32298 Mdot
.682 .32395 Mdot
.682 .32407 Mdot
.682 .32775 Mdot
.682 .32794 Mdot
.682 .32886 Mdot
.682 .32898 Mdot
.682 .32904 Mdot
.682 .32932 Mdot
.682 .33041 Mdot
.682 .33148 Mdot
.682 .33285 Mdot
.682 .33386 Mdot
.682 .33404 Mdot
.682 .33429 Mdot
.682 .33502 Mdot
.682 .33563 Mdot
.682 .33842 Mdot
.682 .33848 Mdot
.682 .34006 Mdot
.682 .34037 Mdot
.682 .34046 Mdot
.682 .34063 Mdot
.682 .34109 Mdot
.682 .3412 Mdot
.682 .34185 Mdot
.682 .34227 Mdot
.682 .34278 Mdot
.682 .34297 Mdot
.682 .34311 Mdot
.682 .34314 Mdot
.682 .34355 Mdot
.682 .34383 Mdot
.682 .34508 Mdot
.682 .34603 Mdot
.682 .34774 Mdot
.682 .34786 Mdot
.682 .34905 Mdot
.682 .35046 Mdot
.682 .35098 Mdot
.682 .35109 Mdot
.682 .35119 Mdot
.682 .35127 Mdot
.682 .35164 Mdot
.682 .35423 Mdot
.682 .35461 Mdot
.682 .35513 Mdot
.682 .35605 Mdot
.682 .35925 Mdot
.682 .36067 Mdot
.682 .36108 Mdot
.682 .36139 Mdot
.682 .36263 Mdot
.682 .36531 Mdot
.682 .36615 Mdot
.682 .36661 Mdot
.682 .36749 Mdot
.682 .36838 Mdot
.682 .37014 Mdot
.682 .37125 Mdot
.682 .37204 Mdot
.682 .37213 Mdot
.682 .37309 Mdot
.682 .37373 Mdot
.682 .37376 Mdot
.682 .37378 Mdot
.682 .37382 Mdot
.682 .37495 Mdot
.682 .37674 Mdot
.682 .37693 Mdot
.682 .37697 Mdot
.682 .37799 Mdot
.682 .37942 Mdot
.682 .38004 Mdot
.682 .38162 Mdot
.682 .38176 Mdot
.682 .38239 Mdot
.682 .3825 Mdot
.682 .38269 Mdot
.682 .38376 Mdot
.682 .38408 Mdot
.682 .38608 Mdot
.682 .38814 Mdot
.682 .38833 Mdot
.682 .38953 Mdot
.682 .39042 Mdot
.682 .39125 Mdot
.682 .39159 Mdot
.682 .39249 Mdot
.682 .39256 Mdot
.682 .39295 Mdot
.682 .39295 Mdot
.682 .39647 Mdot
.682 .39658 Mdot
.682 .39745 Mdot
.682 .39808 Mdot
.682 .3981 Mdot
.682 .39945 Mdot
.682 .39973 Mdot
.682 .40119 Mdot
.682 .4016 Mdot
.682 .40191 Mdot
.682 .4023 Mdot
.682 .40265 Mdot
.682 .40272 Mdot
.682 .40311 Mdot
.682 .40448 Mdot
.682 .4045 Mdot
.682 .40502 Mdot
.682 .40527 Mdot
.682 .40584 Mdot
.682 .40661 Mdot
.682 .40664 Mdot
.682 .40698 Mdot
.682 .40763 Mdot
.682 .41034 Mdot
.682 .41168 Mdot
.682 .41192 Mdot
.682 .41231 Mdot
.682 .41535 Mdot
.682 .41576 Mdot
.682 .41711 Mdot
.684 .01504 Mdot
.684 .01516 Mdot
.684 .01532 Mdot
.684 .0155 Mdot
.684 .01554 Mdot
.684 .01578 Mdot
.684 .01584 Mdot
.684 .01618 Mdot
.684 .01626 Mdot
.684 .01653 Mdot
.684 .01671 Mdot
.684 .01683 Mdot
.684 .01719 Mdot
.684 .01745 Mdot
.684 .0176 Mdot
.684 .0181 Mdot
.684 .01846 Mdot
.684 .01867 Mdot
.684 .01915 Mdot
.684 .01935 Mdot
.684 .01983 Mdot
.684 .02005 Mdot
.684 .02012 Mdot
.684 .02079 Mdot
.684 .02099 Mdot
.684 .02106 Mdot
.684 .0213 Mdot
.684 .02163 Mdot
.684 .02172 Mdot
.684 .02202 Mdot
.684 .02211 Mdot
.684 .02302 Mdot
.684 .0233 Mdot
.684 .02339 Mdot
.684 .0237 Mdot
.684 .02373 Mdot
.684 .02398 Mdot
.684 .02418 Mdot
.684 .02429 Mdot
.684 .02471 Mdot
.684 .02483 Mdot
.684 .02484 Mdot
.684 .02506 Mdot
.684 .0256 Mdot
.684 .02601 Mdot
.684 .02608 Mdot
.684 .02646 Mdot
.684 .02658 Mdot
.684 .027 Mdot
.684 .02704 Mdot
.684 .02734 Mdot
.684 .02739 Mdot
.684 .02766 Mdot
.684 .02782 Mdot
.684 .02838 Mdot
.684 .02856 Mdot
.684 .02856 Mdot
.684 .02887 Mdot
.684 .02961 Mdot
.684 .03008 Mdot
.684 .03017 Mdot
.684 .03023 Mdot
.684 .03026 Mdot
.684 .03078 Mdot
.684 .03095 Mdot
.684 .03153 Mdot
.684 .03158 Mdot
.684 .03199 Mdot
.684 .03205 Mdot
.684 .03242 Mdot
.684 .03264 Mdot
.684 .03289 Mdot
.684 .03341 Mdot
.684 .03365 Mdot
.684 .03366 Mdot
.684 .03389 Mdot
.684 .03408 Mdot
.684 .03509 Mdot
.684 .03573 Mdot
.684 .03585 Mdot
.684 .03593 Mdot
.684 .03598 Mdot
.684 .03669 Mdot
.684 .03693 Mdot
.684 .03749 Mdot
.684 .03771 Mdot
.684 .03779 Mdot
.684 .03834 Mdot
.684 .03834 Mdot
.684 .03839 Mdot
.684 .03843 Mdot
.684 .03923 Mdot
.684 .03944 Mdot
.684 .03957 Mdot
.684 .0399 Mdot
.684 .0403 Mdot
.684 .04062 Mdot
.684 .04063 Mdot
.684 .04094 Mdot
.684 .0412 Mdot
.684 .04121 Mdot
.684 .04213 Mdot
.684 .04237 Mdot
.684 .04258 Mdot
.684 .04346 Mdot
.684 .04363 Mdot
.684 .04374 Mdot
.684 .04381 Mdot
.684 .04478 Mdot
.684 .04489 Mdot
.684 .045 Mdot
.684 .0451 Mdot
.684 .04572 Mdot
.684 .04588 Mdot
.684 .04611 Mdot
.684 .04618 Mdot
.684 .04628 Mdot
.684 .04658 Mdot
.684 .04703 Mdot
.684 .04704 Mdot
.684 .0471 Mdot
.684 .04716 Mdot
.684 .04826 Mdot
.684 .04843 Mdot
.684 .04854 Mdot
.684 .04872 Mdot
.684 .04917 Mdot
.684 .04971 Mdot
.684 .05015 Mdot
.684 .05016 Mdot
.684 .05029 Mdot
.684 .05059 Mdot
.684 .05095 Mdot
.684 .05096 Mdot
.684 .05134 Mdot
.684 .05223 Mdot
.684 .05252 Mdot
.684 .05255 Mdot
.684 .05284 Mdot
.684 .05404 Mdot
.684 .05427 Mdot
.684 .05433 Mdot
.684 .05443 Mdot
.684 .05452 Mdot
.684 .05469 Mdot
.684 .05476 Mdot
.684 .05584 Mdot
.684 .05599 Mdot
.684 .05614 Mdot
.684 .05629 Mdot
.684 .05713 Mdot
.684 .05734 Mdot
.684 .05766 Mdot
.684 .05775 Mdot
.684 .05789 Mdot
.684 .05831 Mdot
.684 .05892 Mdot
.684 .05893 Mdot
.684 .05902 Mdot
.684 .0591 Mdot
.684 .05943 Mdot
.684 .06032 Mdot
.684 .0606 Mdot
.684 .06083 Mdot
.684 .06098 Mdot
.684 .06109 Mdot
.684 .06124 Mdot
.684 .06156 Mdot
.684 .06186 Mdot
.684 .06259 Mdot
.684 .06289 Mdot
.684 .06319 Mdot
.684 .06321 Mdot
.684 .06338 Mdot
.684 .0638 Mdot
.684 .06429 Mdot
.684 .0643 Mdot
.684 .06482 Mdot
.684 .06505 Mdot
.684 .06544 Mdot
.684 .06603 Mdot
.684 .06611 Mdot
.684 .06644 Mdot
.684 .06648 Mdot
.684 .06687 Mdot
.684 .06851 Mdot
.684 .06883 Mdot
.684 .0689 Mdot
.684 .06904 Mdot
.684 .06911 Mdot
.684 .06916 Mdot
.684 .0694 Mdot
.684 .0695 Mdot
.684 .06986 Mdot
.684 .07031 Mdot
.684 .07098 Mdot
.684 .07103 Mdot
.684 .07118 Mdot
.684 .07139 Mdot
.684 .07158 Mdot
.684 .07273 Mdot
.684 .07303 Mdot
.684 .07346 Mdot
.684 .07359 Mdot
.684 .07378 Mdot
.684 .07397 Mdot
.684 .07433 Mdot
.684 .07435 Mdot
.684 .07519 Mdot
.684 .0752 Mdot
.684 .07532 Mdot
.684 .07544 Mdot
.684 .07588 Mdot
.684 .07633 Mdot
.684 .07711 Mdot
.684 .07749 Mdot
.684 .0778 Mdot
.684 .07784 Mdot
.684 .07801 Mdot
.684 .07815 Mdot
.684 .07836 Mdot
.684 .0788 Mdot
.684 .0792 Mdot
.684 .0802 Mdot
.684 .08061 Mdot
.684 .08103 Mdot
.684 .08105 Mdot
.684 .08122 Mdot
.684 .08129 Mdot
.684 .08186 Mdot
.684 .0822 Mdot
.684 .08253 Mdot
.684 .08254 Mdot
.684 .08325 Mdot
.684 .08358 Mdot
.684 .08411 Mdot
.684 .08484 Mdot
.684 .08491 Mdot
.684 .08502 Mdot
.684 .08547 Mdot
.684 .08553 Mdot
.684 .08606 Mdot
.684 .08777 Mdot
.684 .08831 Mdot
.684 .08874 Mdot
.684 .08884 Mdot
.684 .08903 Mdot
.684 .08906 Mdot
.684 .08909 Mdot
.684 .08913 Mdot
.684 .08913 Mdot
.684 .08917 Mdot
.684 .0892 Mdot
.684 .08952 Mdot
.684 .08966 Mdot
.684 .09016 Mdot
.684 .09076 Mdot
.684 .09143 Mdot
.684 .09146 Mdot
.684 .09168 Mdot
.684 .09175 Mdot
.684 .09196 Mdot
.684 .09198 Mdot
.684 .09224 Mdot
.684 .09251 Mdot
.684 .09251 Mdot
.684 .09259 Mdot
.684 .09296 Mdot
.684 .09409 Mdot
.684 .09413 Mdot
.684 .09449 Mdot
.684 .09508 Mdot
.684 .09526 Mdot
.684 .0954 Mdot
.684 .09552 Mdot
.684 .09578 Mdot
.684 .09607 Mdot
.684 .09626 Mdot
.684 .09629 Mdot
.684 .09674 Mdot
.684 .0973 Mdot
.684 .09744 Mdot
.684 .09746 Mdot
.684 .09751 Mdot
.684 .09763 Mdot
.684 .09771 Mdot
.684 .09779 Mdot
.684 .09794 Mdot
.684 .09795 Mdot
.684 .09796 Mdot
.684 .09822 Mdot
.684 .09839 Mdot
.684 .09841 Mdot
.684 .0985 Mdot
.684 .09859 Mdot
.684 .099 Mdot
.684 .09921 Mdot
.684 .10007 Mdot
.684 .10026 Mdot
.684 .10045 Mdot
.684 .10052 Mdot
.684 .10059 Mdot
.684 .10102 Mdot
.684 .10108 Mdot
.684 .1013 Mdot
.684 .10141 Mdot
.684 .1015 Mdot
.684 .10178 Mdot
.684 .10238 Mdot
.684 .10293 Mdot
.684 .10314 Mdot
.684 .1039 Mdot
.684 .10408 Mdot
.684 .1043 Mdot
.684 .1044 Mdot
.684 .10467 Mdot
.684 .10486 Mdot
.684 .10544 Mdot
.684 .10546 Mdot
.684 .10569 Mdot
.684 .10579 Mdot
.684 .10657 Mdot
.684 .10679 Mdot
.684 .10703 Mdot
.684 .10748 Mdot
.684 .1075 Mdot
.684 .10847 Mdot
.684 .10866 Mdot
.684 .10892 Mdot
.684 .1092 Mdot
.684 .10965 Mdot
.684 .1105 Mdot
.684 .11065 Mdot
.684 .11074 Mdot
.684 .1109 Mdot
.684 .11151 Mdot
.684 .11158 Mdot
.684 .11232 Mdot
.684 .11302 Mdot
.684 .11323 Mdot
.684 .11378 Mdot
.684 .11439 Mdot
.684 .11466 Mdot
.684 .11467 Mdot
.684 .11467 Mdot
.684 .11515 Mdot
.684 .11516 Mdot
.684 .11527 Mdot
.684 .1154 Mdot
.684 .11598 Mdot
.684 .11612 Mdot
.684 .11638 Mdot
.684 .11642 Mdot
.684 .11646 Mdot
.684 .11651 Mdot
.684 .11651 Mdot
.684 .11652 Mdot
.684 .11657 Mdot
.684 .11661 Mdot
.684 .11663 Mdot
.684 .11678 Mdot
.684 .11705 Mdot
.684 .11724 Mdot
.684 .1176 Mdot
.684 .11792 Mdot
.684 .11836 Mdot
.684 .11875 Mdot
.684 .11886 Mdot
.684 .11966 Mdot
.684 .1197 Mdot
.684 .12 Mdot
.684 .12011 Mdot
.684 .12011 Mdot
.684 .12013 Mdot
.684 .12039 Mdot
.684 .12041 Mdot
.684 .12062 Mdot
.684 .12077 Mdot
.684 .12114 Mdot
.684 .12114 Mdot
.684 .12125 Mdot
.684 .12175 Mdot
.684 .12303 Mdot
.684 .12329 Mdot
.684 .12336 Mdot
.684 .12385 Mdot
.684 .12466 Mdot
.684 .1249 Mdot
.684 .1251 Mdot
.684 .12526 Mdot
.684 .12561 Mdot
.684 .12601 Mdot
.684 .12627 Mdot
.684 .12631 Mdot
.684 .12692 Mdot
.684 .12769 Mdot
.684 .12788 Mdot
.684 .12791 Mdot
.684 .12798 Mdot
.684 .12814 Mdot
.684 .12825 Mdot
.684 .12835 Mdot
.684 .12836 Mdot
.684 .12856 Mdot
.684 .12857 Mdot
.684 .12859 Mdot
.684 .12896 Mdot
.684 .12915 Mdot
.684 .12919 Mdot
.684 .12921 Mdot
.684 .12933 Mdot
.684 .12946 Mdot
.684 .13002 Mdot
.684 .1303 Mdot
.684 .13043 Mdot
.684 .13073 Mdot
.684 .13148 Mdot
.684 .13174 Mdot
.684 .132 Mdot
.684 .13209 Mdot
.684 .13219 Mdot
.684 .13278 Mdot
.684 .13286 Mdot
.684 .1331 Mdot
.684 .13316 Mdot
.684 .13332 Mdot
.684 .13344 Mdot
.684 .13382 Mdot
.684 .13464 Mdot
.684 .1354 Mdot
.684 .13568 Mdot
.684 .13671 Mdot
.684 .13696 Mdot
.684 .13697 Mdot
.684 .13727 Mdot
.684 .1374 Mdot
.684 .13778 Mdot
.684 .13804 Mdot
.684 .13811 Mdot
.684 .13883 Mdot
.684 .13886 Mdot
.684 .13906 Mdot
.684 .13917 Mdot
.684 .13931 Mdot
.684 .13984 Mdot
.684 .14037 Mdot
.684 .14067 Mdot
.684 .14101 Mdot
.684 .14152 Mdot
.684 .14162 Mdot
.684 .14165 Mdot
.684 .14298 Mdot
.684 .14323 Mdot
.684 .14345 Mdot
.684 .14359 Mdot
.684 .14397 Mdot
.684 .14458 Mdot
.684 .1447 Mdot
.684 .14489 Mdot
.684 .14574 Mdot
.684 .14596 Mdot
.684 .14608 Mdot
.684 .14629 Mdot
.684 .14713 Mdot
.684 .14723 Mdot
.684 .1478 Mdot
.684 .14824 Mdot
.684 .1492 Mdot
.684 .14948 Mdot
.684 .15023 Mdot
.684 .15107 Mdot
.684 .15144 Mdot
.684 .15145 Mdot
.684 .15146 Mdot
.684 .15147 Mdot
.684 .15212 Mdot
.684 .15212 Mdot
.684 .15227 Mdot
.684 .15242 Mdot
.684 .15245 Mdot
.684 .15255 Mdot
.684 .15289 Mdot
.684 .15325 Mdot
.684 .15344 Mdot
.684 .15363 Mdot
.684 .15379 Mdot
.684 .15385 Mdot
.684 .15391 Mdot
.684 .15397 Mdot
.684 .15398 Mdot
.684 .15398 Mdot
.684 .15406 Mdot
.684 .15411 Mdot
.684 .15413 Mdot
.684 .15416 Mdot
.684 .15434 Mdot
.684 .15464 Mdot
.684 .15469 Mdot
.684 .15471 Mdot
.684 .15497 Mdot
.684 .15546 Mdot
.684 .15567 Mdot
.684 .15573 Mdot
.684 .15582 Mdot
.684 .1559 Mdot
.684 .1565 Mdot
.684 .15704 Mdot
.684 .15719 Mdot
.684 .15756 Mdot
.684 .15828 Mdot
.684 .15834 Mdot
.684 .1585 Mdot
.684 .15867 Mdot
.684 .15875 Mdot
.684 .15875 Mdot
.684 .15889 Mdot
.684 .15889 Mdot
.684 .15892 Mdot
.684 .15928 Mdot
.684 .15931 Mdot
.684 .15935 Mdot
.684 .15959 Mdot
.684 .1598 Mdot
.684 .15995 Mdot
.684 .1603 Mdot
.684 .16031 Mdot
.684 .16045 Mdot
.684 .16114 Mdot
.684 .16266 Mdot
.684 .16289 Mdot
.684 .16325 Mdot
.684 .16334 Mdot
.684 .16401 Mdot
.684 .16511 Mdot
.684 .16544 Mdot
.684 .16572 Mdot
.684 .16594 Mdot
.684 .16642 Mdot
.684 .16697 Mdot
.684 .16732 Mdot
.684 .16738 Mdot
.684 .16821 Mdot
.684 .16926 Mdot
.684 .16953 Mdot
.684 .16957 Mdot
.684 .16966 Mdot
.684 .16988 Mdot
.684 .17003 Mdot
.684 .17016 Mdot
.684 .17018 Mdot
.684 .17046 Mdot
.684 .17047 Mdot
.684 .1705 Mdot
.684 .171 Mdot
.684 .17126 Mdot
.684 .17131 Mdot
.684 .17134 Mdot
.684 .17151 Mdot
.684 .17168 Mdot
.684 .17245 Mdot
.684 .17284 Mdot
.684 .17302 Mdot
.684 .17342 Mdot
.684 .17445 Mdot
.684 .1748 Mdot
.684 .17516 Mdot
.684 .17529 Mdot
.684 .17541 Mdot
.684 .17622 Mdot
.684 .17633 Mdot
.684 .17667 Mdot
.684 .17675 Mdot
.684 .17697 Mdot
.684 .17712 Mdot
.684 .17764 Mdot
.684 .17877 Mdot
.684 .17981 Mdot
.684 .1802 Mdot
.684 .18161 Mdot
.684 .18194 Mdot
.684 .18196 Mdot
.684 .18237 Mdot
.684 .18255 Mdot
.684 .18306 Mdot
.684 .18342 Mdot
.684 .18352 Mdot
.684 .1845 Mdot
.684 .18454 Mdot
.684 .18482 Mdot
.684 .18497 Mdot
.684 .18516 Mdot
.684 .18588 Mdot
.684 .18661 Mdot
.684 .18702 Mdot
.684 .18748 Mdot
.684 .18819 Mdot
.684 .18833 Mdot
.684 .18836 Mdot
.684 .19018 Mdot
.684 .19053 Mdot
.684 .19083 Mdot
.684 .19101 Mdot
.684 .19153 Mdot
.684 .19238 Mdot
.684 .19253 Mdot
.684 .19279 Mdot
.684 .19396 Mdot
.684 .19425 Mdot
.684 .19443 Mdot
.684 .19471 Mdot
.684 .19586 Mdot
.684 .196 Mdot
.684 .19678 Mdot
.684 .19737 Mdot
.684 .19869 Mdot
.684 .19907 Mdot
.684 .20011 Mdot
.684 .20125 Mdot
.684 .20175 Mdot
.684 .20177 Mdot
.684 .20178 Mdot
.684 .2018 Mdot
.684 .20268 Mdot
.684 .20269 Mdot
.684 .20289 Mdot
.684 .2031 Mdot
.684 .20313 Mdot
.684 .20327 Mdot
.684 .20373 Mdot
.684 .20423 Mdot
.684 .20449 Mdot
.684 .20475 Mdot
.684 .20497 Mdot
.684 .20505 Mdot
.684 .20513 Mdot
.684 .20522 Mdot
.684 .20522 Mdot
.684 .20523 Mdot
.684 .20533 Mdot
.684 .2054 Mdot
.684 .20544 Mdot
.684 .20547 Mdot
.684 .20572 Mdot
.684 .20613 Mdot
.684 .2062 Mdot
.684 .20623 Mdot
.684 .20658 Mdot
.684 .20725 Mdot
.684 .20755 Mdot
.684 .20762 Mdot
.684 .20774 Mdot
.684 .20785 Mdot
.684 .20868 Mdot
.684 .20941 Mdot
.684 .20962 Mdot
.684 .21013 Mdot
.684 .21111 Mdot
.684 .21119 Mdot
.684 .21141 Mdot
.684 .21165 Mdot
.684 .21175 Mdot
.684 .21176 Mdot
.684 .21195 Mdot
.684 .21195 Mdot
.684 .21199 Mdot
.684 .21248 Mdot
.684 .21252 Mdot
.684 .21258 Mdot
.684 .2129 Mdot
.684 .2132 Mdot
.684 .21339 Mdot
.684 .21388 Mdot
.684 .21389 Mdot
.684 .21408 Mdot
.684 .21502 Mdot
.684 .2171 Mdot
.684 .21741 Mdot
.684 .21791 Mdot
.684 .21803 Mdot
.684 .21896 Mdot
.684 .22046 Mdot
.684 .22091 Mdot
.684 .22128 Mdot
.684 .22159 Mdot
.684 .22224 Mdot
.684 .223 Mdot
.684 .22348 Mdot
.684 .22356 Mdot
.684 .2247 Mdot
.684 .22613 Mdot
.684 .2265 Mdot
.684 .22655 Mdot
.684 .22668 Mdot
.684 .22697 Mdot
.684 .22718 Mdot
.684 .22737 Mdot
.684 .22739 Mdot
.684 .22777 Mdot
.684 .22779 Mdot
.684 .22783 Mdot
.684 .22851 Mdot
.684 .22888 Mdot
.684 .22894 Mdot
.684 .22898 Mdot
.684 .22921 Mdot
.684 .22944 Mdot
.684 .2305 Mdot
.684 .23103 Mdot
.684 .23127 Mdot
.684 .23182 Mdot
.684 .23323 Mdot
.684 .23371 Mdot
.684 .23421 Mdot
.684 .23438 Mdot
.684 .23455 Mdot
.684 .23566 Mdot
.684 .23581 Mdot
.684 .23626 Mdot
.684 .23639 Mdot
.684 .23667 Mdot
.684 .23689 Mdot
.684 .2376 Mdot
.684 .23914 Mdot
.684 .24057 Mdot
.684 .2411 Mdot
.684 .24303 Mdot
.684 .24348 Mdot
.684 .24351 Mdot
.684 .24407 Mdot
.684 .24432 Mdot
.684 .24501 Mdot
.684 .24551 Mdot
.684 .24564 Mdot
.684 .24698 Mdot
.684 .24704 Mdot
.684 .24742 Mdot
.684 .24763 Mdot
.684 .24788 Mdot
.684 .24887 Mdot
.684 .24987 Mdot
.684 .25043 Mdot
.684 .25106 Mdot
.684 .25202 Mdot
.684 .25222 Mdot
.684 .25225 Mdot
.684 .25475 Mdot
.684 .25523 Mdot
.684 .25564 Mdot
.684 .25589 Mdot
.684 .2566 Mdot
.684 .25775 Mdot
.684 .25796 Mdot
.684 .25832 Mdot
.684 .25992 Mdot
.684 .26032 Mdot
.684 .26056 Mdot
.684 .26095 Mdot
.684 .26252 Mdot
.684 .26271 Mdot
.684 .26378 Mdot
.684 .26459 Mdot
.684 .26639 Mdot
.684 .26692 Mdot
.684 .26833 Mdot
.684 .2699 Mdot
.684 .27058 Mdot
.684 .2706 Mdot
.684 .27062 Mdot
.684 .27064 Mdot
.684 .27185 Mdot
.684 .27187 Mdot
.684 .27214 Mdot
.684 .27243 Mdot
.684 .27247 Mdot
.684 .27266 Mdot
.684 .27329 Mdot
.684 .27397 Mdot
.684 .27433 Mdot
.684 .27468 Mdot
.684 .27498 Mdot
.684 .2751 Mdot
.684 .2752 Mdot
.684 .27533 Mdot
.684 .27533 Mdot
.684 .27534 Mdot
.684 .27548 Mdot
.684 .27558 Mdot
.684 .27563 Mdot
.684 .27567 Mdot
.684 .27601 Mdot
.684 .27657 Mdot
.684 .27667 Mdot
.684 .2767 Mdot
.684 .27718 Mdot
.684 .27811 Mdot
.684 .27851 Mdot
.684 .27861 Mdot
.684 .27878 Mdot
.684 .27892 Mdot
.684 .28005 Mdot
.684 .28106 Mdot
.684 .28134 Mdot
.684 .28204 Mdot
.684 .28339 Mdot
.684 .2835 Mdot
.684 .28379 Mdot
.684 .28412 Mdot
.684 .28427 Mdot
.684 .28427 Mdot
.684 .28453 Mdot
.684 .28453 Mdot
.684 .28459 Mdot
.684 .28525 Mdot
.684 .28531 Mdot
.684 .28539 Mdot
.684 .28583 Mdot
.684 .28624 Mdot
.684 .28651 Mdot
.684 .28717 Mdot
.684 .28718 Mdot
.684 .28744 Mdot
.684 .28873 Mdot
.684 .29158 Mdot
.684 .29201 Mdot
.684 .29269 Mdot
.684 .29285 Mdot
.684 .29412 Mdot
.684 .29618 Mdot
.684 .29679 Mdot
.684 .2973 Mdot
.684 .29771 Mdot
.684 .29862 Mdot
.684 .29965 Mdot
.684 .30031 Mdot
.684 .30041 Mdot
.684 .30197 Mdot
.684 .30393 Mdot
.684 .30444 Mdot
.684 .30451 Mdot
.684 .30469 Mdot
.684 .30509 Mdot
.684 .30537 Mdot
.684 .30562 Mdot
.684 .30565 Mdot
.684 .30618 Mdot
.684 .30621 Mdot
.684 .30626 Mdot
.684 .30719 Mdot
.684 .30769 Mdot
.684 .30778 Mdot
.684 .30782 Mdot
.684 .30814 Mdot
.684 .30846 Mdot
.684 .30991 Mdot
.684 .31063 Mdot
.684 .31097 Mdot
.684 .31172 Mdot
.684 .31364 Mdot
.684 .3143 Mdot
.684 .31498 Mdot
.684 .31521 Mdot
.684 .31545 Mdot
.684 .31696 Mdot
.684 .31717 Mdot
.684 .31779 Mdot
.684 .31796 Mdot
.684 .31835 Mdot
.684 .31865 Mdot
.684 .31962 Mdot
.684 .32173 Mdot
.684 .32368 Mdot
.684 .32441 Mdot
.684 .32705 Mdot
.684 .32766 Mdot
.684 .3277 Mdot
.684 .32847 Mdot
.684 .32881 Mdot
.684 .32976 Mdot
.684 .33044 Mdot
.684 .33061 Mdot
.684 .33245 Mdot
.684 .33253 Mdot
.684 .33306 Mdot
.684 .33334 Mdot
.684 .33369 Mdot
.684 .33504 Mdot
.684 .3364 Mdot
.684 .33717 Mdot
.684 .33803 Mdot
.684 .33935 Mdot
.684 .33962 Mdot
.684 .33967 Mdot
.684 .34308 Mdot
.684 .34374 Mdot
.684 .34429 Mdot
.684 .34464 Mdot
.684 .34561 Mdot
.684 .34719 Mdot
.684 .34748 Mdot
.684 .34797 Mdot
.684 .35016 Mdot
.684 .35071 Mdot
.684 .35103 Mdot
.684 .35156 Mdot
.684 .35371 Mdot
.684 .35397 Mdot
.684 .35544 Mdot
.684 .35654 Mdot
.684 .35901 Mdot
.684 .35973 Mdot
.684 .36166 Mdot
.684 .3638 Mdot
.684 .36474 Mdot
.684 .36477 Mdot
.684 .36479 Mdot
.684 .36482 Mdot
.684 .36647 Mdot
.684 .3665 Mdot
.684 .36688 Mdot
.684 .36727 Mdot
.684 .36732 Mdot
.684 .36759 Mdot
.684 .36845 Mdot
.684 .36938 Mdot
.684 .36987 Mdot
.684 .37035 Mdot
.684 .37076 Mdot
.684 .37092 Mdot
.684 .37106 Mdot
.684 .37123 Mdot
.684 .37124 Mdot
.684 .37125 Mdot
.684 .37144 Mdot
.684 .37157 Mdot
.684 .37164 Mdot
.684 .37171 Mdot
.684 .37216 Mdot
.684 .37293 Mdot
.684 .37307 Mdot
.684 .37312 Mdot
.684 .37377 Mdot
.684 .37504 Mdot
.684 .37559 Mdot
.684 .37572 Mdot
.684 .37595 Mdot
.684 .37615 Mdot
.684 .3777 Mdot
.684 .37907 Mdot
.684 .37946 Mdot
.684 .38041 Mdot
.684 .38226 Mdot
.684 .38241 Mdot
.684 .38281 Mdot
.684 .38326 Mdot
.684 .38346 Mdot
.684 .38347 Mdot
.684 .38382 Mdot
.684 .38382 Mdot
.684 .3839 Mdot
.684 .38481 Mdot
.684 .38489 Mdot
.684 .385 Mdot
.684 .3856 Mdot
.684 .38616 Mdot
.684 .38653 Mdot
.684 .38744 Mdot
.684 .38745 Mdot
.684 .38781 Mdot
.684 .38957 Mdot
.684 .39346 Mdot
.684 .39405 Mdot
.684 .39499 Mdot
.684 .3952 Mdot
.684 .39694 Mdot
.684 .39975 Mdot
.684 .4006 Mdot
.684 .40129 Mdot
.684 .40186 Mdot
.684 .40309 Mdot
.684 .4045 Mdot
.684 .40541 Mdot
.684 .40555 Mdot
.684 .40768 Mdot
.684 .41036 Mdot
.684 .41106 Mdot
.684 .41115 Mdot
.684 .4114 Mdot
.684 .41194 Mdot
.684 .41233 Mdot
.684 .41268 Mdot
.684 .41272 Mdot
.684 .41344 Mdot
.684 .41348 Mdot
.684 .41354 Mdot
.684 .41481 Mdot
.684 .4155 Mdot
.684 .41563 Mdot
.684 .41569 Mdot
.684 .41613 Mdot
.684 .41656 Mdot
.684 .41854 Mdot
.686 .01657 Mdot
.686 .01705 Mdot
.686 .01726 Mdot
.686 .0178 Mdot
.686 .01792 Mdot
.686 .01821 Mdot
.686 .01824 Mdot
.686 .01894 Mdot
.686 .01912 Mdot
.686 .01951 Mdot
.686 .01954 Mdot
.686 .01955 Mdot
.686 .02037 Mdot
.686 .02052 Mdot
.686 .02075 Mdot
.686 .02099 Mdot
.686 .0213 Mdot
.686 .02133 Mdot
.686 .02134 Mdot
.686 .02179 Mdot
.686 .02211 Mdot
.686 .02247 Mdot
.686 .02267 Mdot
.686 .023 Mdot
.686 .02332 Mdot
.686 .02374 Mdot
.686 .0238 Mdot
.686 .02381 Mdot
.686 .02443 Mdot
.686 .02486 Mdot
.686 .02536 Mdot
.686 .02564 Mdot
.686 .02608 Mdot
.686 .02652 Mdot
.686 .0271 Mdot
.686 .02717 Mdot
.686 .02719 Mdot
.686 .02801 Mdot
.686 .02804 Mdot
.686 .02864 Mdot
.686 .0289 Mdot
.686 .0292 Mdot
.686 .02931 Mdot
.686 .0297 Mdot
.686 .03031 Mdot
.686 .03068 Mdot
.686 .03091 Mdot
.686 .03141 Mdot
.686 .03171 Mdot
.686 .03181 Mdot
.686 .03183 Mdot
.686 .03196 Mdot
.686 .03281 Mdot
.686 .03296 Mdot
.686 .033 Mdot
.686 .03375 Mdot
.686 .03382 Mdot
.686 .03417 Mdot
.686 .03458 Mdot
.686 .03474 Mdot
.686 .03487 Mdot
.686 .03512 Mdot
.686 .03527 Mdot
.686 .03611 Mdot
.686 .03619 Mdot
.686 .03658 Mdot
.686 .03662 Mdot
.686 .03667 Mdot
.686 .03694 Mdot
.686 .0376 Mdot
.686 .03762 Mdot
.686 .03766 Mdot
.686 .03792 Mdot
.686 .03804 Mdot
.686 .03817 Mdot
.686 .0382 Mdot
.686 .03837 Mdot
.686 .03919 Mdot
.686 .03953 Mdot
.686 .03975 Mdot
.686 .0398 Mdot
.686 .04022 Mdot
.686 .04083 Mdot
.686 .04092 Mdot
.686 .04114 Mdot
.686 .04141 Mdot
.686 .04197 Mdot
.686 .0422 Mdot
.686 .04237 Mdot
.686 .04271 Mdot
.686 .04292 Mdot
.686 .04338 Mdot
.686 .04407 Mdot
.686 .04418 Mdot
.686 .04472 Mdot
.686 .04477 Mdot
.686 .04483 Mdot
.686 .04521 Mdot
.686 .04612 Mdot
.686 .04613 Mdot
.686 .04619 Mdot
.686 .0463 Mdot
.686 .04649 Mdot
.686 .04656 Mdot
.686 .04671 Mdot
.686 .04689 Mdot
.686 .04694 Mdot
.686 .04717 Mdot
.686 .04721 Mdot
.686 .04727 Mdot
.686 .0483 Mdot
.686 .04836 Mdot
.686 .04877 Mdot
.686 .04898 Mdot
.686 .04906 Mdot
.686 .04913 Mdot
.686 .04961 Mdot
.686 .0497 Mdot
.686 .05012 Mdot
.686 .05054 Mdot
.686 .05055 Mdot
.686 .05067 Mdot
.686 .05093 Mdot
.686 .05098 Mdot
.686 .05134 Mdot
.686 .05211 Mdot
.686 .05242 Mdot
.686 .05266 Mdot
.686 .05313 Mdot
.686 .05341 Mdot
.686 .05358 Mdot
.686 .05405 Mdot
.686 .05438 Mdot
.686 .055 Mdot
.686 .05514 Mdot
.686 .05527 Mdot
.686 .05588 Mdot
.686 .05595 Mdot
.686 .05604 Mdot
.686 .05655 Mdot
.686 .0566 Mdot
.686 .05753 Mdot
.686 .05768 Mdot
.686 .0578 Mdot
.686 .05782 Mdot
.686 .0579 Mdot
.686 .05805 Mdot
.686 .05805 Mdot
.686 .05817 Mdot
.686 .05832 Mdot
.686 .0584 Mdot
.686 .05861 Mdot
.686 .05884 Mdot
.686 .05886 Mdot
.686 .05892 Mdot
.686 .05897 Mdot
.686 .05925 Mdot
.686 .0593 Mdot
.686 .05938 Mdot
.686 .05943 Mdot
.686 .05982 Mdot
.686 .0605 Mdot
.686 .06059 Mdot
.686 .06079 Mdot
.686 .06087 Mdot
.686 .06143 Mdot
.686 .06172 Mdot
.686 .06183 Mdot
.686 .06193 Mdot
.686 .0626 Mdot
.686 .06272 Mdot
.686 .063 Mdot
.686 .06329 Mdot
.686 .06348 Mdot
.686 .06374 Mdot
.686 .06387 Mdot
.686 .06388 Mdot
.686 .06405 Mdot
.686 .06432 Mdot
.686 .0644 Mdot
.686 .06447 Mdot
.686 .06496 Mdot
.686 .06603 Mdot
.686 .06638 Mdot
.686 .06644 Mdot
.686 .06677 Mdot
.686 .06742 Mdot
.686 .06781 Mdot
.686 .06804 Mdot
.686 .06868 Mdot
.686 .06888 Mdot
.686 .06914 Mdot
.686 .06998 Mdot
.686 .07017 Mdot
.686 .07035 Mdot
.686 .07045 Mdot
.686 .07119 Mdot
.686 .07129 Mdot
.686 .07141 Mdot
.686 .07211 Mdot
.686 .07218 Mdot
.686 .07346 Mdot
.686 .07367 Mdot
.686 .07383 Mdot
.686 .07386 Mdot
.686 .07396 Mdot
.686 .07417 Mdot
.686 .07418 Mdot
.686 .07433 Mdot
.686 .07454 Mdot
.686 .07465 Mdot
.686 .07494 Mdot
.686 .07525 Mdot
.686 .07529 Mdot
.686 .07537 Mdot
.686 .07543 Mdot
.686 .07581 Mdot
.686 .07589 Mdot
.686 .076 Mdot
.686 .07606 Mdot
.686 .07638 Mdot
.686 .0766 Mdot
.686 .07753 Mdot
.686 .07766 Mdot
.686 .07793 Mdot
.686 .07804 Mdot
.686 .07812 Mdot
.686 .0786 Mdot
.686 .07881 Mdot
.686 .07883 Mdot
.686 .07921 Mdot
.686 .07936 Mdot
.686 .0795 Mdot
.686 .08041 Mdot
.686 .08058 Mdot
.686 .08067 Mdot
.686 .08097 Mdot
.686 .08136 Mdot
.686 .08162 Mdot
.686 .08182 Mdot
.686 .08198 Mdot
.686 .08205 Mdot
.686 .08215 Mdot
.686 .08217 Mdot
.686 .08224 Mdot
.686 .0824 Mdot
.686 .08241 Mdot
.686 .08278 Mdot
.686 .08289 Mdot
.686 .08297 Mdot
.686 .08366 Mdot
.686 .08504 Mdot
.686 .08511 Mdot
.686 .08542 Mdot
.686 .0856 Mdot
.686 .08569 Mdot
.686 .08614 Mdot
.686 .08679 Mdot
.686 .08702 Mdot
.686 .08756 Mdot
.686 .08788 Mdot
.686 .08849 Mdot
.686 .08875 Mdot
.686 .08903 Mdot
.686 .08937 Mdot
.686 .08938 Mdot
.686 .08977 Mdot
.686 .09054 Mdot
.686 .0908 Mdot
.686 .09105 Mdot
.686 .09118 Mdot
.686 .09134 Mdot
.686 .0922 Mdot
.686 .09234 Mdot
.686 .0925 Mdot
.686 .09268 Mdot
.686 .09347 Mdot
.686 .09355 Mdot
.686 .09489 Mdot
.686 .09531 Mdot
.686 .09555 Mdot
.686 .09559 Mdot
.686 .09582 Mdot
.686 .09586 Mdot
.686 .096 Mdot
.686 .09629 Mdot
.686 .0963 Mdot
.686 .09651 Mdot
.686 .09679 Mdot
.686 .09684 Mdot
.686 .09695 Mdot
.686 .09702 Mdot
.686 .09735 Mdot
.686 .09777 Mdot
.686 .09782 Mdot
.686 .09793 Mdot
.686 .09802 Mdot
.686 .09854 Mdot
.686 .09864 Mdot
.686 .0988 Mdot
.686 .09889 Mdot
.686 .09932 Mdot
.686 .09945 Mdot
.686 .09962 Mdot
.686 .09968 Mdot
.686 .1009 Mdot
.686 .10108 Mdot
.686 .10114 Mdot
.686 .10145 Mdot
.686 .10159 Mdot
.686 .10171 Mdot
.686 .10236 Mdot
.686 .10258 Mdot
.686 .10266 Mdot
.686 .10268 Mdot
.686 .10287 Mdot
.686 .10294 Mdot
.686 .1032 Mdot
.686 .10341 Mdot
.686 .1036 Mdot
.686 .10406 Mdot
.686 .10466 Mdot
.686 .1047 Mdot
.686 .10485 Mdot
.686 .10508 Mdot
.686 .10521 Mdot
.686 .10553 Mdot
.686 .10561 Mdot
.686 .10616 Mdot
.686 .1065 Mdot
.686 .10678 Mdot
.686 .10697 Mdot
.686 .107 Mdot
.686 .10708 Mdot
.686 .1071 Mdot
.686 .10724 Mdot
.686 .10726 Mdot
.686 .10736 Mdot
.686 .10758 Mdot
.686 .1076 Mdot
.686 .10809 Mdot
.686 .10825 Mdot
.686 .10837 Mdot
.686 .1093 Mdot
.686 .10963 Mdot
.686 .1112 Mdot
.686 .1113 Mdot
.686 .11135 Mdot
.686 .11173 Mdot
.686 .11196 Mdot
.686 .11205 Mdot
.686 .11209 Mdot
.686 .11263 Mdot
.686 .11271 Mdot
.686 .1136 Mdot
.686 .11392 Mdot
.686 .11465 Mdot
.686 .11479 Mdot
.686 .11506 Mdot
.686 .11509 Mdot
.686 .11594 Mdot
.686 .11629 Mdot
.686 .11631 Mdot
.686 .11654 Mdot
.686 .11667 Mdot
.686 .11684 Mdot
.686 .11714 Mdot
.686 .11716 Mdot
.686 .11768 Mdot
.686 .11818 Mdot
.686 .11875 Mdot
.686 .11906 Mdot
.686 .11911 Mdot
.686 .11944 Mdot
.686 .11962 Mdot
.686 .11985 Mdot
.686 .12016 Mdot
.686 .12023 Mdot
.686 .12103 Mdot
.686 .12122 Mdot
.686 .12143 Mdot
.686 .12165 Mdot
.686 .12169 Mdot
.686 .12199 Mdot
.686 .12276 Mdot
.686 .12288 Mdot
.686 .12454 Mdot
.686 .12471 Mdot
.686 .12529 Mdot
.686 .12562 Mdot
.686 .12568 Mdot
.686 .1259 Mdot
.686 .12599 Mdot
.686 .12605 Mdot
.686 .12624 Mdot
.686 .12663 Mdot
.686 .12664 Mdot
.686 .12681 Mdot
.686 .12693 Mdot
.686 .12732 Mdot
.686 .1274 Mdot
.686 .12754 Mdot
.686 .12764 Mdot
.686 .12784 Mdot
.686 .12809 Mdot
.686 .12867 Mdot
.686 .12873 Mdot
.686 .12889 Mdot
.686 .12893 Mdot
.686 .12901 Mdot
.686 .1291 Mdot
.686 .12973 Mdot
.686 .12986 Mdot
.686 .13007 Mdot
.686 .1302 Mdot
.686 .13056 Mdot
.686 .1308 Mdot
.686 .13097 Mdot
.686 .1312 Mdot
.686 .13129 Mdot
.686 .13296 Mdot
.686 .13321 Mdot
.686 .13329 Mdot
.686 .13371 Mdot
.686 .13391 Mdot
.686 .13407 Mdot
.686 .13431 Mdot
.686 .13458 Mdot
.686 .13489 Mdot
.686 .13496 Mdot
.686 .13526 Mdot
.686 .13538 Mdot
.686 .1354 Mdot
.686 .13566 Mdot
.686 .13568 Mdot
.686 .13575 Mdot
.686 .13611 Mdot
.686 .1364 Mdot
.686 .13666 Mdot
.686 .13729 Mdot
.686 .13812 Mdot
.686 .13817 Mdot
.686 .13837 Mdot
.686 .13839 Mdot
.686 .1387 Mdot
.686 .13887 Mdot
.686 .13905 Mdot
.686 .13931 Mdot
.686 .13942 Mdot
.686 .14017 Mdot
.686 .1404 Mdot
.686 .14065 Mdot
.686 .14102 Mdot
.686 .14129 Mdot
.686 .14133 Mdot
.686 .14143 Mdot
.686 .14147 Mdot
.686 .14166 Mdot
.686 .14169 Mdot
.686 .14182 Mdot
.686 .14193 Mdot
.686 .14212 Mdot
.686 .14215 Mdot
.686 .14283 Mdot
.686 .14296 Mdot
.686 .14304 Mdot
.686 .1432 Mdot
.686 .14378 Mdot
.686 .14449 Mdot
.686 .14493 Mdot
.686 .14661 Mdot
.686 .1471 Mdot
.686 .14723 Mdot
.686 .1473 Mdot
.686 .14782 Mdot
.686 .14814 Mdot
.686 .14821 Mdot
.686 .14826 Mdot
.686 .14831 Mdot
.686 .14905 Mdot
.686 .14916 Mdot
.686 .14954 Mdot
.686 .15002 Mdot
.686 .15027 Mdot
.686 .15038 Mdot
.686 .15083 Mdot
.686 .15121 Mdot
.686 .15183 Mdot
.686 .15202 Mdot
.686 .15238 Mdot
.686 .15243 Mdot
.686 .15312 Mdot
.686 .15318 Mdot
.686 .15359 Mdot
.686 .154 Mdot
.686 .15408 Mdot
.686 .1541 Mdot
.686 .15442 Mdot
.686 .15459 Mdot
.686 .1546 Mdot
.686 .15483 Mdot
.686 .15524 Mdot
.686 .15527 Mdot
.686 .15599 Mdot
.686 .15648 Mdot
.686 .15667 Mdot
.686 .15684 Mdot
.686 .15745 Mdot
.686 .15752 Mdot
.686 .15787 Mdot
.686 .15794 Mdot
.686 .15803 Mdot
.686 .1584 Mdot
.686 .15865 Mdot
.686 .15896 Mdot
.686 .15898 Mdot
.686 .15938 Mdot
.686 .15948 Mdot
.686 .1602 Mdot
.686 .16058 Mdot
.686 .16084 Mdot
.686 .16113 Mdot
.686 .16144 Mdot
.686 .16148 Mdot
.686 .1619 Mdot
.686 .16295 Mdot
.686 .16303 Mdot
.686 .16312 Mdot
.686 .16334 Mdot
.686 .16411 Mdot
.686 .16429 Mdot
.686 .16467 Mdot
.686 .16511 Mdot
.686 .1654 Mdot
.686 .16563 Mdot
.686 .16643 Mdot
.686 .16688 Mdot
.686 .16696 Mdot
.686 .16725 Mdot
.686 .16739 Mdot
.686 .16746 Mdot
.686 .16772 Mdot
.686 .16826 Mdot
.686 .16828 Mdot
.686 .16851 Mdot
.686 .16868 Mdot
.686 .16921 Mdot
.686 .16931 Mdot
.686 .16951 Mdot
.686 .16965 Mdot
.686 .16992 Mdot
.686 .17026 Mdot
.686 .17106 Mdot
.686 .17115 Mdot
.686 .17136 Mdot
.686 .17142 Mdot
.686 .17152 Mdot
.686 .17165 Mdot
.686 .17251 Mdot
.686 .1727 Mdot
.686 .17299 Mdot
.686 .17316 Mdot
.686 .17366 Mdot
.686 .17398 Mdot
.686 .17422 Mdot
.686 .17453 Mdot
.686 .17466 Mdot
.686 .17694 Mdot
.686 .17728 Mdot
.686 .1774 Mdot
.686 .17798 Mdot
.686 .17826 Mdot
.686 .17847 Mdot
.686 .1788 Mdot
.686 .17916 Mdot
.686 .1796 Mdot
.686 .17969 Mdot
.686 .18011 Mdot
.686 .18026 Mdot
.686 .18029 Mdot
.686 .18066 Mdot
.686 .18068 Mdot
.686 .18078 Mdot
.686 .18127 Mdot
.686 .18167 Mdot
.686 .18203 Mdot
.686 .18289 Mdot
.686 .18402 Mdot
.686 .1841 Mdot
.686 .18438 Mdot
.686 .1844 Mdot
.686 .18482 Mdot
.686 .18506 Mdot
.686 .18531 Mdot
.686 .18566 Mdot
.686 .18582 Mdot
.686 .18684 Mdot
.686 .18715 Mdot
.686 .18749 Mdot
.686 .18801 Mdot
.686 .18837 Mdot
.686 .18843 Mdot
.686 .18857 Mdot
.686 .18862 Mdot
.686 .18888 Mdot
.686 .18893 Mdot
.686 .18911 Mdot
.686 .18926 Mdot
.686 .18952 Mdot
.686 .18956 Mdot
.686 .19049 Mdot
.686 .19067 Mdot
.686 .19078 Mdot
.686 .191 Mdot
.686 .1918 Mdot
.686 .19277 Mdot
.686 .19337 Mdot
.686 .19567 Mdot
.686 .19634 Mdot
.686 .19653 Mdot
.686 .19662 Mdot
.686 .19733 Mdot
.686 .19777 Mdot
.686 .19787 Mdot
.686 .19794 Mdot
.686 .19801 Mdot
.686 .19902 Mdot
.686 .19917 Mdot
.686 .1997 Mdot
.686 .20036 Mdot
.686 .2007 Mdot
.686 .20085 Mdot
.686 .20146 Mdot
.686 .20198 Mdot
.686 .20284 Mdot
.686 .20309 Mdot
.686 .20359 Mdot
.686 .20366 Mdot
.686 .2046 Mdot
.686 .20469 Mdot
.686 .20526 Mdot
.686 .20581 Mdot
.686 .20593 Mdot
.686 .20595 Mdot
.686 .20639 Mdot
.686 .20662 Mdot
.686 .20663 Mdot
.686 .20696 Mdot
.686 .20751 Mdot
.686 .20756 Mdot
.686 .20854 Mdot
.686 .20921 Mdot
.686 .20948 Mdot
.686 .2097 Mdot
.686 .21054 Mdot
.686 .21064 Mdot
.686 .21113 Mdot
.686 .21122 Mdot
.686 .21134 Mdot
.686 .21186 Mdot
.686 .2122 Mdot
.686 .21262 Mdot
.686 .21265 Mdot
.686 .2132 Mdot
.686 .21333 Mdot
.686 .21432 Mdot
.686 .21484 Mdot
.686 .2152 Mdot
.686 .21559 Mdot
.686 .21602 Mdot
.686 .21608 Mdot
.686 .21665 Mdot
.686 .2181 Mdot
.686 .2182 Mdot
.686 .21833 Mdot
.686 .21863 Mdot
.686 .21968 Mdot
.686 .21994 Mdot
.686 .22046 Mdot
.686 .22105 Mdot
.686 .22145 Mdot
.686 .22177 Mdot
.686 .22286 Mdot
.686 .22348 Mdot
.686 .2236 Mdot
.686 .224 Mdot
.686 .22419 Mdot
.686 .22428 Mdot
.686 .22464 Mdot
.686 .22538 Mdot
.686 .22541 Mdot
.686 .22572 Mdot
.686 .22595 Mdot
.686 .22668 Mdot
.686 .22682 Mdot
.686 .22709 Mdot
.686 .22728 Mdot
.686 .22765 Mdot
.686 .22812 Mdot
.686 .22922 Mdot
.686 .22934 Mdot
.686 .22964 Mdot
.686 .22971 Mdot
.686 .22986 Mdot
.686 .23002 Mdot
.686 .23121 Mdot
.686 .23147 Mdot
.686 .23186 Mdot
.686 .2321 Mdot
.686 .23279 Mdot
.686 .23323 Mdot
.686 .23356 Mdot
.686 .23399 Mdot
.686 .23416 Mdot
.686 .23729 Mdot
.686 .23776 Mdot
.686 .23792 Mdot
.686 .23871 Mdot
.686 .23909 Mdot
.686 .23939 Mdot
.686 .23984 Mdot
.686 .24034 Mdot
.686 .24093 Mdot
.686 .24107 Mdot
.686 .24163 Mdot
.686 .24184 Mdot
.686 .24189 Mdot
.686 .24239 Mdot
.686 .24241 Mdot
.686 .24255 Mdot
.686 .24323 Mdot
.686 .24377 Mdot
.686 .24427 Mdot
.686 .24546 Mdot
.686 .24701 Mdot
.686 .24711 Mdot
.686 .24749 Mdot
.686 .24752 Mdot
.686 .2481 Mdot
.686 .24843 Mdot
.686 .24877 Mdot
.686 .24904 Mdot
.686 .24926 Mdot
.686 .24947 Mdot
.686 .25087 Mdot
.686 .2513 Mdot
.686 .25177 Mdot
.686 .25248 Mdot
.686 .25297 Mdot
.686 .25305 Mdot
.686 .25325 Mdot
.686 .25331 Mdot
.686 .25367 Mdot
.686 .25374 Mdot
.686 .25398 Mdot
.686 .25419 Mdot
.686 .25455 Mdot
.686 .2546 Mdot
.686 .25588 Mdot
.686 .25613 Mdot
.686 .25627 Mdot
.686 .25658 Mdot
.686 .25767 Mdot
.686 .259 Mdot
.686 .25983 Mdot
.686 .26299 Mdot
.686 .26391 Mdot
.686 .26416 Mdot
.686 .26428 Mdot
.686 .26527 Mdot
.686 .26587 Mdot
.686 .266 Mdot
.686 .2661 Mdot
.686 .26619 Mdot
.686 .26759 Mdot
.686 .26779 Mdot
.686 .26851 Mdot
.686 .26942 Mdot
.686 .26988 Mdot
.686 .2701 Mdot
.686 .27093 Mdot
.686 .27165 Mdot
.686 .27282 Mdot
.686 .27317 Mdot
.686 .27386 Mdot
.686 .27395 Mdot
.686 .27524 Mdot
.686 .27536 Mdot
.686 .27614 Mdot
.686 .2769 Mdot
.686 .27706 Mdot
.686 .27709 Mdot
.686 .27769 Mdot
.686 .27801 Mdot
.686 .27803 Mdot
.686 .27847 Mdot
.686 .27923 Mdot
.686 .27929 Mdot
.686 .28065 Mdot
.686 .28156 Mdot
.686 .28193 Mdot
.686 .28224 Mdot
.686 .28339 Mdot
.686 .28353 Mdot
.686 .2842 Mdot
.686 .28432 Mdot
.686 .28448 Mdot
.686 .28519 Mdot
.686 .28566 Mdot
.686 .28624 Mdot
.686 .28628 Mdot
.686 .28704 Mdot
.686 .28722 Mdot
.686 .28857 Mdot
.686 .28929 Mdot
.686 .28978 Mdot
.686 .29032 Mdot
.686 .2909 Mdot
.686 .29099 Mdot
.686 .29177 Mdot
.686 .29376 Mdot
.686 .2939 Mdot
.686 .29407 Mdot
.686 .29449 Mdot
.686 .29593 Mdot
.686 .29628 Mdot
.686 .29699 Mdot
.686 .29781 Mdot
.686 .29836 Mdot
.686 .29879 Mdot
.686 .30029 Mdot
.686 .30114 Mdot
.686 .3013 Mdot
.686 .30185 Mdot
.686 .30211 Mdot
.686 .30224 Mdot
.686 .30274 Mdot
.686 .30375 Mdot
.686 .30379 Mdot
.686 .30422 Mdot
.686 .30453 Mdot
.686 .30553 Mdot
.686 .30573 Mdot
.686 .30609 Mdot
.686 .30636 Mdot
.686 .30687 Mdot
.686 .30751 Mdot
.686 .30902 Mdot
.686 .30918 Mdot
.686 .30959 Mdot
.686 .30969 Mdot
.686 .30989 Mdot
.686 .31012 Mdot
.686 .31175 Mdot
.686 .3121 Mdot
.686 .31264 Mdot
.686 .31296 Mdot
.686 .31391 Mdot
.686 .31452 Mdot
.686 .31497 Mdot
.686 .31556 Mdot
.686 .31579 Mdot
.686 .32009 Mdot
.686 .32073 Mdot
.686 .32095 Mdot
.686 .32203 Mdot
.686 .32256 Mdot
.686 .32296 Mdot
.686 .32358 Mdot
.686 .32427 Mdot
.686 .32509 Mdot
.686 .32527 Mdot
.686 .32605 Mdot
.686 .32634 Mdot
.686 .3264 Mdot
.686 .32708 Mdot
.686 .32712 Mdot
.686 .32731 Mdot
.686 .32824 Mdot
.686 .32898 Mdot
.686 .32966 Mdot
.686 .33129 Mdot
.686 .33342 Mdot
.686 .33356 Mdot
.686 .33408 Mdot
.686 .33413 Mdot
.686 .33492 Mdot
.686 .33537 Mdot
.686 .33583 Mdot
.686 .3362 Mdot
.686 .33651 Mdot
.686 .33679 Mdot
.686 .33872 Mdot
.686 .33931 Mdot
.686 .33995 Mdot
.686 .34092 Mdot
.686 .3416 Mdot
.686 .34171 Mdot
.686 .34198 Mdot
.686 .34207 Mdot
.686 .34256 Mdot
.686 .34265 Mdot
.686 .34299 Mdot
.686 .34327 Mdot
.686 .34377 Mdot
.686 .34384 Mdot
.686 .34559 Mdot
.686 .34594 Mdot
.686 .34613 Mdot
.686 .34655 Mdot
.686 .34805 Mdot
.686 .34987 Mdot
.686 .35102 Mdot
.686 .35534 Mdot
.686 .35661 Mdot
.686 .35696 Mdot
.686 .35712 Mdot
.686 .35847 Mdot
.686 .3593 Mdot
.686 .35947 Mdot
.686 .35961 Mdot
.686 .35974 Mdot
.686 .36165 Mdot
.686 .36193 Mdot
.686 .36293 Mdot
.686 .36417 Mdot
.686 .36481 Mdot
.686 .3651 Mdot
.686 .36625 Mdot
.686 .36723 Mdot
.686 .36883 Mdot
.686 .36931 Mdot
.686 .37026 Mdot
.686 .37039 Mdot
.686 .37216 Mdot
.686 .37233 Mdot
.686 .37339 Mdot
.686 .37444 Mdot
.686 .37465 Mdot
.686 .3747 Mdot
.686 .37552 Mdot
.686 .37595 Mdot
.686 .37598 Mdot
.686 .37659 Mdot
.686 .37764 Mdot
.686 .37771 Mdot
.686 .37957 Mdot
.686 .38083 Mdot
.686 .38134 Mdot
.686 .38176 Mdot
.686 .38334 Mdot
.686 .38353 Mdot
.686 .38444 Mdot
.686 .38461 Mdot
.686 .38483 Mdot
.686 .38581 Mdot
.686 .38645 Mdot
.686 .38725 Mdot
.686 .3873 Mdot
.686 .38834 Mdot
.686 .38859 Mdot
.686 .39044 Mdot
.686 .39143 Mdot
.686 .3921 Mdot
.686 .39285 Mdot
.686 .39364 Mdot
.686 .39376 Mdot
.686 .39483 Mdot
.686 .39756 Mdot
.686 .39776 Mdot
.686 .39799 Mdot
.686 .39856 Mdot
.686 .40054 Mdot
.686 .40102 Mdot
.686 .402 Mdot
.686 .40312 Mdot
.686 .40387 Mdot
.686 .40447 Mdot
.686 .40653 Mdot
.686 .40769 Mdot
.686 .40791 Mdot
.686 .40867 Mdot
.686 .40902 Mdot
.686 .4092 Mdot
.686 .40988 Mdot
.686 .41127 Mdot
.686 .41132 Mdot
.686 .41192 Mdot
.686 .41234 Mdot
.686 .41372 Mdot
.686 .41398 Mdot
.686 .41448 Mdot
.686 .41485 Mdot
.686 .41555 Mdot
.686 .41643 Mdot
.686 .4185 Mdot
.686 .41872 Mdot
.686 .41928 Mdot
.686 .41942 Mdot
.686 .4197 Mdot
.686 .42001 Mdot
.688 .01509 Mdot
.688 .01523 Mdot
.688 .01543 Mdot
.688 .01549 Mdot
.688 .01569 Mdot
.688 .01579 Mdot
.688 .01606 Mdot
.688 .01657 Mdot
.688 .01727 Mdot
.688 .01823 Mdot
.688 .01884 Mdot
.688 .01938 Mdot
.688 .01955 Mdot
.688 .02039 Mdot
.688 .02114 Mdot
.688 .02136 Mdot
.688 .02148 Mdot
.688 .02191 Mdot
.688 .02194 Mdot
.688 .0224 Mdot
.688 .02253 Mdot
.688 .02307 Mdot
.688 .02336 Mdot
.688 .02355 Mdot
.688 .02386 Mdot
.688 .02402 Mdot
.688 .02462 Mdot
.688 .02466 Mdot
.688 .02529 Mdot
.688 .02546 Mdot
.688 .02616 Mdot
.688 .0262 Mdot
.688 .02622 Mdot
.688 .02662 Mdot
.688 .02686 Mdot
.688 .02688 Mdot
.688 .02689 Mdot
.688 .02721 Mdot
.688 .0273 Mdot
.688 .02752 Mdot
.688 .02834 Mdot
.688 .02839 Mdot
.688 .02927 Mdot
.688 .02938 Mdot
.688 .02951 Mdot
.688 .02969 Mdot
.688 .03004 Mdot
.688 .03033 Mdot
.688 .03046 Mdot
.688 .03052 Mdot
.688 .03054 Mdot
.688 .03109 Mdot
.688 .03142 Mdot
.688 .03145 Mdot
.688 .03147 Mdot
.688 .03191 Mdot
.688 .03204 Mdot
.688 .03234 Mdot
.688 .03279 Mdot
.688 .03347 Mdot
.688 .03354 Mdot
.688 .03475 Mdot
.688 .03489 Mdot
.688 .03507 Mdot
.688 .03532 Mdot
.688 .0358 Mdot
.688 .0362 Mdot
.688 .03638 Mdot
.688 .03647 Mdot
.688 .03649 Mdot
.688 .03665 Mdot
.688 .03671 Mdot
.688 .03681 Mdot
.688 .03725 Mdot
.688 .0376 Mdot
.688 .0377 Mdot
.688 .03774 Mdot
.688 .03777 Mdot
.688 .03811 Mdot
.688 .03821 Mdot
.688 .03837 Mdot
.688 .03855 Mdot
.688 .03896 Mdot
.688 .03897 Mdot
.688 .03958 Mdot
.688 .04 Mdot
.688 .04052 Mdot
.688 .04061 Mdot
.688 .04121 Mdot
.688 .04164 Mdot
.688 .04228 Mdot
.688 .04248 Mdot
.688 .04272 Mdot
.688 .04307 Mdot
.688 .04373 Mdot
.688 .04373 Mdot
.688 .04391 Mdot
.688 .04427 Mdot
.688 .04452 Mdot
.688 .04465 Mdot
.688 .04468 Mdot
.688 .0449 Mdot
.688 .04493 Mdot
.688 .04498 Mdot
.688 .04511 Mdot
.688 .04572 Mdot
.688 .0462 Mdot
.688 .04634 Mdot
.688 .0464 Mdot
.688 .04643 Mdot
.688 .04669 Mdot
.688 .0469 Mdot
.688 .04705 Mdot
.688 .04726 Mdot
.688 .04751 Mdot
.688 .04757 Mdot
.688 .04778 Mdot
.688 .04808 Mdot
.688 .04809 Mdot
.688 .04834 Mdot
.688 .04844 Mdot
.688 .04872 Mdot
.688 .04893 Mdot
.688 .04951 Mdot
.688 .04982 Mdot
.688 .05022 Mdot
.688 .05033 Mdot
.688 .05035 Mdot
.688 .05117 Mdot
.688 .05176 Mdot
.688 .05264 Mdot
.688 .05291 Mdot
.688 .05325 Mdot
.688 .05373 Mdot
.688 .05393 Mdot
.688 .05464 Mdot
.688 .05464 Mdot
.688 .05489 Mdot
.688 .055 Mdot
.688 .05539 Mdot
.688 .05573 Mdot
.688 .0559 Mdot
.688 .05594 Mdot
.688 .05594 Mdot
.688 .05624 Mdot
.688 .05625 Mdot
.688 .05629 Mdot
.688 .05636 Mdot
.688 .05655 Mdot
.688 .05738 Mdot
.688 .05799 Mdot
.688 .05804 Mdot
.688 .05824 Mdot
.688 .05832 Mdot
.688 .05836 Mdot
.688 .05872 Mdot
.688 .059 Mdot
.688 .05905 Mdot
.688 .0592 Mdot
.688 .0595 Mdot
.688 .05985 Mdot
.688 .05992 Mdot
.688 .06021 Mdot
.688 .06063 Mdot
.688 .06063 Mdot
.688 .06098 Mdot
.688 .06111 Mdot
.688 .0614 Mdot
.688 .06151 Mdot
.688 .0618 Mdot
.688 .06248 Mdot
.688 .06259 Mdot
.688 .06291 Mdot
.688 .06302 Mdot
.688 .06357 Mdot
.688 .06373 Mdot
.688 .06375 Mdot
.688 .06415 Mdot
.688 .06466 Mdot
.688 .06488 Mdot
.688 .06559 Mdot
.688 .06569 Mdot
.688 .06581 Mdot
.688 .0669 Mdot
.688 .06728 Mdot
.688 .06774 Mdot
.688 .06788 Mdot
.688 .068 Mdot
.688 .06812 Mdot
.688 .06826 Mdot
.688 .0684 Mdot
.688 .06868 Mdot
.688 .06955 Mdot
.688 .06965 Mdot
.688 .06965 Mdot
.688 .07 Mdot
.688 .07015 Mdot
.688 .07016 Mdot
.688 .07068 Mdot
.688 .07115 Mdot
.688 .07138 Mdot
.688 .07143 Mdot
.688 .07145 Mdot
.688 .07167 Mdot
.688 .07186 Mdot
.688 .07187 Mdot
.688 .07192 Mdot
.688 .07202 Mdot
.688 .07227 Mdot
.688 .07342 Mdot
.688 .07409 Mdot
.688 .07426 Mdot
.688 .07432 Mdot
.688 .07434 Mdot
.688 .07436 Mdot
.688 .0746 Mdot
.688 .07463 Mdot
.688 .07471 Mdot
.688 .07477 Mdot
.688 .07526 Mdot
.688 .07565 Mdot
.688 .07572 Mdot
.688 .07572 Mdot
.688 .07593 Mdot
.688 .07634 Mdot
.688 .07635 Mdot
.688 .07645 Mdot
.688 .07682 Mdot
.688 .07686 Mdot
.688 .07691 Mdot
.688 .07732 Mdot
.688 .07789 Mdot
.688 .0779 Mdot
.688 .07803 Mdot
.688 .07838 Mdot
.688 .07856 Mdot
.688 .07896 Mdot
.688 .07911 Mdot
.688 .0795 Mdot
.688 .07983 Mdot
.688 .08043 Mdot
.688 .08059 Mdot
.688 .08103 Mdot
.688 .08119 Mdot
.688 .08194 Mdot
.688 .08215 Mdot
.688 .08219 Mdot
.688 .08274 Mdot
.688 .08305 Mdot
.688 .08344 Mdot
.688 .08374 Mdot
.688 .08399 Mdot
.688 .08472 Mdot
.688 .08486 Mdot
.688 .08502 Mdot
.688 .08508 Mdot
.688 .08511 Mdot
.688 .08543 Mdot
.688 .08566 Mdot
.688 .08652 Mdot
.688 .08695 Mdot
.688 .08704 Mdot
.688 .08747 Mdot
.688 .08751 Mdot
.688 .08768 Mdot
.688 .08782 Mdot
.688 .08787 Mdot
.688 .08804 Mdot
.688 .0882 Mdot
.688 .0884 Mdot
.688 .08858 Mdot
.688 .08897 Mdot
.688 .08898 Mdot
.688 .08937 Mdot
.688 .09016 Mdot
.688 .0903 Mdot
.688 .0903 Mdot
.688 .09079 Mdot
.688 .09099 Mdot
.688 .09101 Mdot
.688 .09172 Mdot
.688 .09237 Mdot
.688 .09269 Mdot
.688 .09276 Mdot
.688 .09278 Mdot
.688 .09308 Mdot
.688 .09334 Mdot
.688 .09336 Mdot
.688 .09343 Mdot
.688 .09357 Mdot
.688 .09391 Mdot
.688 .09526 Mdot
.688 .09549 Mdot
.688 .09642 Mdot
.688 .09665 Mdot
.688 .09673 Mdot
.688 .09675 Mdot
.688 .09679 Mdot
.688 .09712 Mdot
.688 .09716 Mdot
.688 .09727 Mdot
.688 .09735 Mdot
.688 .09803 Mdot
.688 .09814 Mdot
.688 .09857 Mdot
.688 .09865 Mdot
.688 .09866 Mdot
.688 .09875 Mdot
.688 .09895 Mdot
.688 .09951 Mdot
.688 .09952 Mdot
.688 .09966 Mdot
.688 .10017 Mdot
.688 .10023 Mdot
.688 .1003 Mdot
.688 .10036 Mdot
.688 .10086 Mdot
.688 .10164 Mdot
.688 .10165 Mdot
.688 .10167 Mdot
.688 .10183 Mdot
.688 .10194 Mdot
.688 .10196 Mdot
.688 .10232 Mdot
.688 .10257 Mdot
.688 .10308 Mdot
.688 .10311 Mdot
.688 .10332 Mdot
.688 .10386 Mdot
.688 .10403 Mdot
.688 .10431 Mdot
.688 .10442 Mdot
.688 .10515 Mdot
.688 .10536 Mdot
.688 .10555 Mdot
.688 .10597 Mdot
.688 .10618 Mdot
.688 .10666 Mdot
.688 .10722 Mdot
.688 .10751 Mdot
.688 .10755 Mdot
.688 .10797 Mdot
.688 .10805 Mdot
.688 .10831 Mdot
.688 .10844 Mdot
.688 .10874 Mdot
.688 .10923 Mdot
.688 .10928 Mdot
.688 .10929 Mdot
.688 .10956 Mdot
.688 .10969 Mdot
.688 .11003 Mdot
.688 .11105 Mdot
.688 .11124 Mdot
.688 .11146 Mdot
.688 .11153 Mdot
.688 .11158 Mdot
.688 .11184 Mdot
.688 .11194 Mdot
.688 .11195 Mdot
.688 .11201 Mdot
.688 .11225 Mdot
.688 .11233 Mdot
.688 .11352 Mdot
.688 .11411 Mdot
.688 .11423 Mdot
.688 .11456 Mdot
.688 .11482 Mdot
.688 .11488 Mdot
.688 .11488 Mdot
.688 .11511 Mdot
.688 .1153 Mdot
.688 .11538 Mdot
.688 .11561 Mdot
.688 .11583 Mdot
.688 .1161 Mdot
.688 .11636 Mdot
.688 .11688 Mdot
.688 .11691 Mdot
.688 .11744 Mdot
.688 .11853 Mdot
.688 .11872 Mdot
.688 .11872 Mdot
.688 .11939 Mdot
.688 .11967 Mdot
.688 .1197 Mdot
.688 .11997 Mdot
.688 .12068 Mdot
.688 .12089 Mdot
.688 .12091 Mdot
.688 .12157 Mdot
.688 .12201 Mdot
.688 .1221 Mdot
.688 .12213 Mdot
.688 .12255 Mdot
.688 .1229 Mdot
.688 .12293 Mdot
.688 .12303 Mdot
.688 .12322 Mdot
.688 .12369 Mdot
.688 .12418 Mdot
.688 .12555 Mdot
.688 .12557 Mdot
.688 .1257 Mdot
.688 .12587 Mdot
.688 .12705 Mdot
.688 .12714 Mdot
.688 .12746 Mdot
.688 .12757 Mdot
.688 .1276 Mdot
.688 .12765 Mdot
.688 .1281 Mdot
.688 .12816 Mdot
.688 .12831 Mdot
.688 .12843 Mdot
.688 .12936 Mdot
.688 .12951 Mdot
.688 .13009 Mdot
.688 .13022 Mdot
.688 .13022 Mdot
.688 .13035 Mdot
.688 .13054 Mdot
.688 .13062 Mdot
.688 .1314 Mdot
.688 .13141 Mdot
.688 .13159 Mdot
.688 .1316 Mdot
.688 .13169 Mdot
.688 .1323 Mdot
.688 .13239 Mdot
.688 .13248 Mdot
.688 .13256 Mdot
.688 .13325 Mdot
.688 .13433 Mdot
.688 .13434 Mdot
.688 .13437 Mdot
.688 .13459 Mdot
.688 .13473 Mdot
.688 .13476 Mdot
.688 .13497 Mdot
.688 .13526 Mdot
.688 .1356 Mdot
.688 .13572 Mdot
.688 .1363 Mdot
.688 .13635 Mdot
.688 .13664 Mdot
.688 .13713 Mdot
.688 .13737 Mdot
.688 .13743 Mdot
.688 .13759 Mdot
.688 .13761 Mdot
.688 .13769 Mdot
.688 .138 Mdot
.688 .13814 Mdot
.688 .13915 Mdot
.688 .13945 Mdot
.688 .13971 Mdot
.688 .13979 Mdot
.688 .14028 Mdot
.688 .14058 Mdot
.688 .14123 Mdot
.688 .14153 Mdot
.688 .14165 Mdot
.688 .142 Mdot
.688 .14214 Mdot
.688 .1424 Mdot
.688 .14246 Mdot
.688 .14304 Mdot
.688 .14307 Mdot
.688 .14311 Mdot
.688 .14315 Mdot
.688 .1435 Mdot
.688 .14367 Mdot
.688 .1441 Mdot
.688 .14477 Mdot
.688 .14483 Mdot
.688 .14485 Mdot
.688 .14492 Mdot
.688 .14522 Mdot
.688 .1454 Mdot
.688 .14543 Mdot
.688 .14554 Mdot
.688 .14587 Mdot
.688 .14637 Mdot
.688 .14727 Mdot
.688 .14753 Mdot
.688 .14783 Mdot
.688 .14784 Mdot
.688 .14793 Mdot
.688 .148 Mdot
.688 .14836 Mdot
.688 .1485 Mdot
.688 .14851 Mdot
.688 .1486 Mdot
.688 .14892 Mdot
.688 .14903 Mdot
.688 .15068 Mdot
.688 .15148 Mdot
.688 .15165 Mdot
.688 .1521 Mdot
.688 .15247 Mdot
.688 .15254 Mdot
.688 .15254 Mdot
.688 .15286 Mdot
.688 .15312 Mdot
.688 .15323 Mdot
.688 .15355 Mdot
.688 .15386 Mdot
.688 .15422 Mdot
.688 .15435 Mdot
.688 .15457 Mdot
.688 .15459 Mdot
.688 .15467 Mdot
.688 .1553 Mdot
.688 .15533 Mdot
.688 .15533 Mdot
.688 .15542 Mdot
.688 .15606 Mdot
.688 .15615 Mdot
.688 .15757 Mdot
.688 .15783 Mdot
.688 .15783 Mdot
.688 .15874 Mdot
.688 .15913 Mdot
.688 .15917 Mdot
.688 .15954 Mdot
.688 .16052 Mdot
.688 .16081 Mdot
.688 .16084 Mdot
.688 .16175 Mdot
.688 .16196 Mdot
.688 .16236 Mdot
.688 .16244 Mdot
.688 .16248 Mdot
.688 .16251 Mdot
.688 .1631 Mdot
.688 .16358 Mdot
.688 .16362 Mdot
.688 .16375 Mdot
.688 .16401 Mdot
.688 .16402 Mdot
.688 .16453 Mdot
.688 .16467 Mdot
.688 .1647 Mdot
.688 .16493 Mdot
.688 .16534 Mdot
.688 .16716 Mdot
.688 .16722 Mdot
.688 .16725 Mdot
.688 .16743 Mdot
.688 .16746 Mdot
.688 .16766 Mdot
.688 .16928 Mdot
.688 .16942 Mdot
.688 .16986 Mdot
.688 .17 Mdot
.688 .17005 Mdot
.688 .17011 Mdot
.688 .17073 Mdot
.688 .17081 Mdot
.688 .17103 Mdot
.688 .17118 Mdot
.688 .17246 Mdot
.688 .17267 Mdot
.688 .17348 Mdot
.688 .17364 Mdot
.688 .17365 Mdot
.688 .17383 Mdot
.688 .17409 Mdot
.688 .1742 Mdot
.688 .17527 Mdot
.688 .17529 Mdot
.688 .17554 Mdot
.688 .17555 Mdot
.688 .17568 Mdot
.688 .17651 Mdot
.688 .17663 Mdot
.688 .17676 Mdot
.688 .17687 Mdot
.688 .17782 Mdot
.688 .1793 Mdot
.688 .17932 Mdot
.688 .17936 Mdot
.688 .17967 Mdot
.688 .17986 Mdot
.688 .1799 Mdot
.688 .18019 Mdot
.688 .18059 Mdot
.688 .18105 Mdot
.688 .18122 Mdot
.688 .18202 Mdot
.688 .18209 Mdot
.688 .18248 Mdot
.688 .18316 Mdot
.688 .18349 Mdot
.688 .18357 Mdot
.688 .18379 Mdot
.688 .18382 Mdot
.688 .18394 Mdot
.688 .18436 Mdot
.688 .18455 Mdot
.688 .18593 Mdot
.688 .18634 Mdot
.688 .1867 Mdot
.688 .18682 Mdot
.688 .18749 Mdot
.688 .1879 Mdot
.688 .1888 Mdot
.688 .18921 Mdot
.688 .18938 Mdot
.688 .18986 Mdot
.688 .19005 Mdot
.688 .19041 Mdot
.688 .19049 Mdot
.688 .19129 Mdot
.688 .19134 Mdot
.688 .19138 Mdot
.688 .19143 Mdot
.688 .19193 Mdot
.688 .19216 Mdot
.688 .19274 Mdot
.688 .19367 Mdot
.688 .19376 Mdot
.688 .19378 Mdot
.688 .19388 Mdot
.688 .1943 Mdot
.688 .19454 Mdot
.688 .19458 Mdot
.688 .19474 Mdot
.688 .19518 Mdot
.688 .19587 Mdot
.688 .19711 Mdot
.688 .19747 Mdot
.688 .19789 Mdot
.688 .1979 Mdot
.688 .19802 Mdot
.688 .19811 Mdot
.688 .19861 Mdot
.688 .19881 Mdot
.688 .19882 Mdot
.688 .19894 Mdot
.688 .19939 Mdot
.688 .19954 Mdot
.688 .2018 Mdot
.688 .2029 Mdot
.688 .20314 Mdot
.688 .20375 Mdot
.688 .20426 Mdot
.688 .20436 Mdot
.688 .20437 Mdot
.688 .2048 Mdot
.688 .20516 Mdot
.688 .20531 Mdot
.688 .20575 Mdot
.688 .20617 Mdot
.688 .20668 Mdot
.688 .20685 Mdot
.688 .20716 Mdot
.688 .20718 Mdot
.688 .20729 Mdot
.688 .20816 Mdot
.688 .2082 Mdot
.688 .2082 Mdot
.688 .20832 Mdot
.688 .2092 Mdot
.688 .20933 Mdot
.688 .21128 Mdot
.688 .21164 Mdot
.688 .21164 Mdot
.688 .2129 Mdot
.688 .21343 Mdot
.688 .21348 Mdot
.688 .214 Mdot
.688 .21534 Mdot
.688 .21575 Mdot
.688 .21578 Mdot
.688 .21704 Mdot
.688 .21733 Mdot
.688 .21787 Mdot
.688 .21798 Mdot
.688 .21804 Mdot
.688 .21809 Mdot
.688 .21889 Mdot
.688 .21956 Mdot
.688 .2196 Mdot
.688 .21979 Mdot
.688 .22015 Mdot
.688 .22016 Mdot
.688 .22086 Mdot
.688 .22105 Mdot
.688 .2211 Mdot
.688 .22142 Mdot
.688 .22198 Mdot
.688 .22448 Mdot
.688 .22457 Mdot
.688 .2246 Mdot
.688 .22485 Mdot
.688 .22489 Mdot
.688 .22517 Mdot
.688 .2274 Mdot
.688 .22758 Mdot
.688 .22819 Mdot
.688 .22838 Mdot
.688 .22845 Mdot
.688 .22854 Mdot
.688 .22939 Mdot
.688 .22951 Mdot
.688 .2298 Mdot
.688 .23001 Mdot
.688 .23178 Mdot
.688 .23207 Mdot
.688 .23317 Mdot
.688 .2334 Mdot
.688 .23342 Mdot
.688 .23366 Mdot
.688 .23401 Mdot
.688 .23417 Mdot
.688 .23564 Mdot
.688 .23567 Mdot
.688 .23601 Mdot
.688 .23603 Mdot
.688 .2362 Mdot
.688 .23734 Mdot
.688 .23751 Mdot
.688 .23769 Mdot
.688 .23784 Mdot
.688 .23914 Mdot
.688 .24119 Mdot
.688 .24122 Mdot
.688 .24127 Mdot
.688 .24169 Mdot
.688 .24195 Mdot
.688 .24201 Mdot
.688 .24241 Mdot
.688 .24295 Mdot
.688 .24359 Mdot
.688 .24382 Mdot
.688 .24492 Mdot
.688 .24502 Mdot
.688 .24556 Mdot
.688 .24649 Mdot
.688 .24695 Mdot
.688 .24706 Mdot
.688 .24736 Mdot
.688 .24741 Mdot
.688 .24756 Mdot
.688 .24814 Mdot
.688 .24841 Mdot
.688 .25031 Mdot
.688 .25088 Mdot
.688 .25137 Mdot
.688 .25153 Mdot
.688 .25246 Mdot
.688 .25302 Mdot
.688 .25426 Mdot
.688 .25483 Mdot
.688 .25505 Mdot
.688 .25571 Mdot
.688 .25598 Mdot
.688 .25647 Mdot
.688 .25659 Mdot
.688 .25768 Mdot
.688 .25774 Mdot
.688 .25781 Mdot
.688 .25788 Mdot
.688 .25856 Mdot
.688 .25888 Mdot
.688 .25968 Mdot
.688 .26096 Mdot
.688 .26108 Mdot
.688 .2611 Mdot
.688 .26124 Mdot
.688 .26182 Mdot
.688 .26215 Mdot
.688 .2622 Mdot
.688 .26242 Mdot
.688 .26304 Mdot
.688 .26399 Mdot
.688 .26569 Mdot
.688 .26619 Mdot
.688 .26676 Mdot
.688 .26678 Mdot
.688 .26695 Mdot
.688 .26707 Mdot
.688 .26775 Mdot
.688 .26802 Mdot
.688 .26805 Mdot
.688 .26821 Mdot
.688 .26882 Mdot
.688 .26903 Mdot
.688 .27214 Mdot
.688 .27366 Mdot
.688 .27399 Mdot
.688 .27483 Mdot
.688 .27553 Mdot
.688 .27567 Mdot
.688 .27568 Mdot
.688 .27627 Mdot
.688 .27677 Mdot
.688 .27698 Mdot
.688 .27758 Mdot
.688 .27816 Mdot
.688 .27885 Mdot
.688 .2791 Mdot
.688 .27952 Mdot
.688 .27954 Mdot
.688 .27969 Mdot
.688 .2809 Mdot
.688 .28095 Mdot
.688 .28096 Mdot
.688 .28111 Mdot
.688 .28233 Mdot
.688 .2825 Mdot
.688 .28519 Mdot
.688 .28568 Mdot
.688 .28569 Mdot
.688 .28742 Mdot
.688 .28815 Mdot
.688 .28822 Mdot
.688 .28893 Mdot
.688 .29077 Mdot
.688 .29134 Mdot
.688 .29138 Mdot
.688 .29311 Mdot
.688 .29351 Mdot
.688 .29425 Mdot
.688 .29441 Mdot
.688 .2945 Mdot
.688 .29455 Mdot
.688 .29566 Mdot
.688 .29658 Mdot
.688 .29664 Mdot
.688 .2969 Mdot
.688 .29739 Mdot
.688 .29741 Mdot
.688 .29837 Mdot
.688 .29864 Mdot
.688 .2987 Mdot
.688 .29913 Mdot
.688 .29991 Mdot
.688 .30335 Mdot
.688 .30347 Mdot
.688 .30352 Mdot
.688 .30387 Mdot
.688 .30391 Mdot
.688 .3043 Mdot
.688 .30737 Mdot
.688 .30762 Mdot
.688 .30846 Mdot
.688 .30872 Mdot
.688 .30882 Mdot
.688 .30894 Mdot
.688 .31011 Mdot
.688 .31027 Mdot
.688 .31067 Mdot
.688 .31096 Mdot
.688 .31339 Mdot
.688 .31379 Mdot
.688 .31531 Mdot
.688 .31563 Mdot
.688 .31565 Mdot
.688 .31598 Mdot
.688 .31647 Mdot
.688 .31668 Mdot
.688 .31871 Mdot
.688 .31875 Mdot
.688 .31922 Mdot
.688 .31924 Mdot
.688 .31948 Mdot
.688 .32105 Mdot
.688 .32128 Mdot
.688 .32153 Mdot
.688 .32174 Mdot
.688 .32353 Mdot
.688 .32634 Mdot
.688 .32638 Mdot
.688 .32645 Mdot
.688 .32703 Mdot
.688 .32739 Mdot
.688 .32747 Mdot
.688 .32802 Mdot
.688 .32877 Mdot
.688 .32965 Mdot
.688 .32996 Mdot
.688 .33148 Mdot
.688 .33162 Mdot
.688 .33235 Mdot
.688 .33364 Mdot
.688 .33427 Mdot
.688 .33443 Mdot
.688 .33483 Mdot
.688 .3349 Mdot
.688 .33511 Mdot
.688 .33591 Mdot
.688 .33628 Mdot
.688 .3389 Mdot
.688 .33967 Mdot
.688 .34035 Mdot
.688 .34058 Mdot
.688 .34185 Mdot
.688 .34262 Mdot
.688 .34433 Mdot
.688 .34511 Mdot
.688 .34542 Mdot
.688 .34632 Mdot
.688 .3467 Mdot
.688 .34737 Mdot
.688 .34753 Mdot
.688 .34903 Mdot
.688 .34912 Mdot
.688 .34921 Mdot
.688 .34931 Mdot
.688 .35024 Mdot
.688 .35069 Mdot
.688 .35179 Mdot
.688 .35355 Mdot
.688 .35371 Mdot
.688 .35374 Mdot
.688 .35394 Mdot
.688 .35473 Mdot
.688 .35519 Mdot
.688 .35526 Mdot
.688 .35556 Mdot
.688 .35641 Mdot
.688 .35772 Mdot
.688 .36006 Mdot
.688 .36074 Mdot
.688 .36153 Mdot
.688 .36155 Mdot
.688 .36179 Mdot
.688 .36195 Mdot
.688 .36289 Mdot
.688 .36327 Mdot
.688 .3633 Mdot
.688 .36352 Mdot
.688 .36437 Mdot
.688 .36465 Mdot
.688 .36893 Mdot
.688 .37103 Mdot
.688 .37147 Mdot
.688 .37264 Mdot
.688 .37359 Mdot
.688 .37378 Mdot
.688 .3738 Mdot
.688 .37461 Mdot
.688 .37531 Mdot
.688 .37559 Mdot
.688 .37641 Mdot
.688 .37722 Mdot
.688 .37817 Mdot
.688 .37851 Mdot
.688 .37909 Mdot
.688 .37912 Mdot
.688 .37933 Mdot
.688 .38098 Mdot
.688 .38106 Mdot
.688 .38106 Mdot
.688 .38128 Mdot
.688 .38296 Mdot
.688 .38319 Mdot
.688 .38689 Mdot
.688 .38756 Mdot
.688 .38757 Mdot
.688 .38995 Mdot
.688 .39096 Mdot
.688 .39106 Mdot
.688 .39203 Mdot
.688 .39457 Mdot
.688 .39534 Mdot
.688 .39541 Mdot
.688 .39779 Mdot
.688 .39833 Mdot
.688 .39936 Mdot
.688 .39958 Mdot
.688 .39969 Mdot
.688 .39977 Mdot
.688 .40129 Mdot
.688 .40256 Mdot
.688 .40265 Mdot
.688 .403 Mdot
.688 .40368 Mdot
.688 .4037 Mdot
.688 .40502 Mdot
.688 .40539 Mdot
.688 .40548 Mdot
.688 .40608 Mdot
.688 .40715 Mdot
.688 .41188 Mdot
.688 .41205 Mdot
.688 .4121 Mdot
.688 .41259 Mdot
.688 .41265 Mdot
.688 .41318 Mdot
.688 .41741 Mdot
.688 .41775 Mdot
.688 .4189 Mdot
.688 .41927 Mdot
.688 .4194 Mdot
.688 .41957 Mdot
.688 .42118 Mdot
.688 .4214 Mdot
.69 .01598 Mdot
.69 .01646 Mdot
.69 .01687 Mdot
.69 .01712 Mdot
.69 .01719 Mdot
.69 .01769 Mdot
.69 .01804 Mdot
.69 .01813 Mdot
.69 .01882 Mdot
.69 .0193 Mdot
.69 .01942 Mdot
.69 .01956 Mdot
.69 .01957 Mdot
.69 .01958 Mdot
.69 .02038 Mdot
.69 .02105 Mdot
.69 .02121 Mdot
.69 .02141 Mdot
.69 .02142 Mdot
.69 .02143 Mdot
.69 .02231 Mdot
.69 .02254 Mdot
.69 .02259 Mdot
.69 .02337 Mdot
.69 .02337 Mdot
.69 .02345 Mdot
.69 .02359 Mdot
.69 .02368 Mdot
.69 .02395 Mdot
.69 .02397 Mdot
.69 .02399 Mdot
.69 .0252 Mdot
.69 .02551 Mdot
.69 .02559 Mdot
.69 .02583 Mdot
.69 .02658 Mdot
.69 .02666 Mdot
.69 .02666 Mdot
.69 .02678 Mdot
.69 .02697 Mdot
.69 .02708 Mdot
.69 .02746 Mdot
.69 .02749 Mdot
.69 .02751 Mdot
.69 .02918 Mdot
.69 .02961 Mdot
.69 .02972 Mdot
.69 .03005 Mdot
.69 .03018 Mdot
.69 .03109 Mdot
.69 .0312 Mdot
.69 .0312 Mdot
.69 .03136 Mdot
.69 .03162 Mdot
.69 .03178 Mdot
.69 .03186 Mdot
.69 .03189 Mdot
.69 .0323 Mdot
.69 .03234 Mdot
.69 .03237 Mdot
.69 .03301 Mdot
.69 .03365 Mdot
.69 .03373 Mdot
.69 .03425 Mdot
.69 .03468 Mdot
.69 .03528 Mdot
.69 .03542 Mdot
.69 .03588 Mdot
.69 .03605 Mdot
.69 .0361 Mdot
.69 .03612 Mdot
.69 .03625 Mdot
.69 .03633 Mdot
.69 .03649 Mdot
.69 .03683 Mdot
.69 .03726 Mdot
.69 .03731 Mdot
.69 .03746 Mdot
.69 .03746 Mdot
.69 .03768 Mdot
.69 .03805 Mdot
.69 .03827 Mdot
.69 .03837 Mdot
.69 .03838 Mdot
.69 .03841 Mdot
.69 .03898 Mdot
.69 .03904 Mdot
.69 .03908 Mdot
.69 .03996 Mdot
.69 .04084 Mdot
.69 .04096 Mdot
.69 .04167 Mdot
.69 .04227 Mdot
.69 .04239 Mdot
.69 .04292 Mdot
.69 .04309 Mdot
.69 .04329 Mdot
.69 .04392 Mdot
.69 .04416 Mdot
.69 .04422 Mdot
.69 .04425 Mdot
.69 .04443 Mdot
.69 .04455 Mdot
.69 .04476 Mdot
.69 .04524 Mdot
.69 .04583 Mdot
.69 .0459 Mdot
.69 .04611 Mdot
.69 .04611 Mdot
.69 .04631 Mdot
.69 .04641 Mdot
.69 .04664 Mdot
.69 .04691 Mdot
.69 .04713 Mdot
.69 .04722 Mdot
.69 .04736 Mdot
.69 .04736 Mdot
.69 .04737 Mdot
.69 .04739 Mdot
.69 .04742 Mdot
.69 .04754 Mdot
.69 .04784 Mdot
.69 .04788 Mdot
.69 .04814 Mdot
.69 .0482 Mdot
.69 .04828 Mdot
.69 .04834 Mdot
.69 .0489 Mdot
.69 .04955 Mdot
.69 .04972 Mdot
.69 .05077 Mdot
.69 .05093 Mdot
.69 .05191 Mdot
.69 .05274 Mdot
.69 .0529 Mdot
.69 .05364 Mdot
.69 .05387 Mdot
.69 .05415 Mdot
.69 .05502 Mdot
.69 .05535 Mdot
.69 .05544 Mdot
.69 .05548 Mdot
.69 .05572 Mdot
.69 .05572 Mdot
.69 .05589 Mdot
.69 .05618 Mdot
.69 .05636 Mdot
.69 .05684 Mdot
.69 .05749 Mdot
.69 .05766 Mdot
.69 .05775 Mdot
.69 .05804 Mdot
.69 .05804 Mdot
.69 .05832 Mdot
.69 .05835 Mdot
.69 .05843 Mdot
.69 .05846 Mdot
.69 .05877 Mdot
.69 .05915 Mdot
.69 .05944 Mdot
.69 .05957 Mdot
.69 .05977 Mdot
.69 .05977 Mdot
.69 .05978 Mdot
.69 .05981 Mdot
.69 .05985 Mdot
.69 .06001 Mdot
.69 .06043 Mdot
.69 .06048 Mdot
.69 .06084 Mdot
.69 .06093 Mdot
.69 .061 Mdot
.69 .06103 Mdot
.69 .06111 Mdot
.69 .06189 Mdot
.69 .06278 Mdot
.69 .06302 Mdot
.69 .06376 Mdot
.69 .06447 Mdot
.69 .06469 Mdot
.69 .06483 Mdot
.69 .06526 Mdot
.69 .06532 Mdot
.69 .06605 Mdot
.69 .06705 Mdot
.69 .06718 Mdot
.69 .06737 Mdot
.69 .06742 Mdot
.69 .06843 Mdot
.69 .06849 Mdot
.69 .06875 Mdot
.69 .06914 Mdot
.69 .06947 Mdot
.69 .07034 Mdot
.69 .07079 Mdot
.69 .07091 Mdot
.69 .07097 Mdot
.69 .0713 Mdot
.69 .07131 Mdot
.69 .07134 Mdot
.69 .07153 Mdot
.69 .07194 Mdot
.69 .07218 Mdot
.69 .07285 Mdot
.69 .07305 Mdot
.69 .07335 Mdot
.69 .07375 Mdot
.69 .07398 Mdot
.69 .07411 Mdot
.69 .07415 Mdot
.69 .0745 Mdot
.69 .0745 Mdot
.69 .07489 Mdot
.69 .07493 Mdot
.69 .07505 Mdot
.69 .07508 Mdot
.69 .0754 Mdot
.69 .07551 Mdot
.69 .07603 Mdot
.69 .07628 Mdot
.69 .07628 Mdot
.69 .07644 Mdot
.69 .07662 Mdot
.69 .07689 Mdot
.69 .07689 Mdot
.69 .07691 Mdot
.69 .07695 Mdot
.69 .077 Mdot
.69 .07722 Mdot
.69 .0778 Mdot
.69 .07788 Mdot
.69 .07837 Mdot
.69 .07849 Mdot
.69 .07852 Mdot
.69 .07852 Mdot
.69 .07859 Mdot
.69 .0786 Mdot
.69 .07863 Mdot
.69 .07874 Mdot
.69 .07982 Mdot
.69 .08089 Mdot
.69 .08105 Mdot
.69 .08137 Mdot
.69 .0824 Mdot
.69 .08271 Mdot
.69 .08303 Mdot
.69 .08304 Mdot
.69 .08338 Mdot
.69 .08368 Mdot
.69 .08383 Mdot
.69 .08388 Mdot
.69 .08401 Mdot
.69 .0843 Mdot
.69 .08438 Mdot
.69 .08447 Mdot
.69 .08455 Mdot
.69 .08511 Mdot
.69 .08529 Mdot
.69 .08556 Mdot
.69 .08694 Mdot
.69 .08712 Mdot
.69 .08729 Mdot
.69 .08738 Mdot
.69 .08744 Mdot
.69 .08783 Mdot
.69 .08847 Mdot
.69 .08884 Mdot
.69 .08892 Mdot
.69 .08903 Mdot
.69 .08928 Mdot
.69 .08972 Mdot
.69 .08982 Mdot
.69 .09028 Mdot
.69 .09084 Mdot
.69 .09095 Mdot
.69 .09148 Mdot
.69 .09179 Mdot
.69 .0921 Mdot
.69 .09227 Mdot
.69 .09234 Mdot
.69 .0928 Mdot
.69 .09281 Mdot
.69 .09284 Mdot
.69 .09286 Mdot
.69 .09312 Mdot
.69 .09369 Mdot
.69 .09402 Mdot
.69 .09414 Mdot
.69 .09494 Mdot
.69 .09522 Mdot
.69 .09564 Mdot
.69 .09597 Mdot
.69 .09618 Mdot
.69 .0965 Mdot
.69 .09667 Mdot
.69 .09674 Mdot
.69 .09721 Mdot
.69 .09722 Mdot
.69 .09776 Mdot
.69 .09782 Mdot
.69 .09797 Mdot
.69 .09802 Mdot
.69 .09846 Mdot
.69 .09861 Mdot
.69 .09933 Mdot
.69 .09967 Mdot
.69 .09967 Mdot
.69 .0999 Mdot
.69 .10003 Mdot
.69 .10015 Mdot
.69 .10052 Mdot
.69 .10052 Mdot
.69 .10055 Mdot
.69 .10059 Mdot
.69 .10066 Mdot
.69 .10097 Mdot
.69 .10177 Mdot
.69 .10188 Mdot
.69 .10256 Mdot
.69 .10272 Mdot
.69 .10277 Mdot
.69 .10277 Mdot
.69 .10286 Mdot
.69 .10287 Mdot
.69 .10292 Mdot
.69 .10307 Mdot
.69 .10444 Mdot
.69 .10456 Mdot
.69 .10498 Mdot
.69 .10549 Mdot
.69 .10604 Mdot
.69 .10626 Mdot
.69 .1067 Mdot
.69 .10676 Mdot
.69 .1079 Mdot
.69 .10812 Mdot
.69 .10837 Mdot
.69 .10854 Mdot
.69 .10854 Mdot
.69 .10899 Mdot
.69 .10899 Mdot
.69 .10901 Mdot
.69 .10947 Mdot
.69 .10989 Mdot
.69 .11009 Mdot
.69 .11016 Mdot
.69 .11034 Mdot
.69 .11074 Mdot
.69 .11085 Mdot
.69 .11098 Mdot
.69 .11109 Mdot
.69 .11123 Mdot
.69 .11147 Mdot
.69 .11164 Mdot
.69 .11185 Mdot
.69 .11211 Mdot
.69 .11248 Mdot
.69 .11329 Mdot
.69 .11417 Mdot
.69 .11438 Mdot
.69 .11463 Mdot
.69 .11486 Mdot
.69 .11496 Mdot
.69 .11499 Mdot
.69 .11508 Mdot
.69 .11561 Mdot
.69 .11611 Mdot
.69 .11627 Mdot
.69 .1165 Mdot
.69 .11701 Mdot
.69 .11712 Mdot
.69 .11727 Mdot
.69 .11762 Mdot
.69 .11823 Mdot
.69 .11836 Mdot
.69 .11864 Mdot
.69 .11899 Mdot
.69 .1192 Mdot
.69 .11977 Mdot
.69 .11991 Mdot
.69 .11997 Mdot
.69 .12065 Mdot
.69 .12108 Mdot
.69 .12151 Mdot
.69 .12169 Mdot
.69 .12174 Mdot
.69 .12184 Mdot
.69 .12247 Mdot
.69 .12249 Mdot
.69 .12253 Mdot
.69 .12256 Mdot
.69 .12292 Mdot
.69 .1237 Mdot
.69 .12405 Mdot
.69 .12415 Mdot
.69 .12432 Mdot
.69 .12475 Mdot
.69 .12541 Mdot
.69 .12542 Mdot
.69 .12581 Mdot
.69 .12639 Mdot
.69 .12681 Mdot
.69 .12684 Mdot
.69 .12714 Mdot
.69 .12757 Mdot
.69 .12782 Mdot
.69 .12791 Mdot
.69 .12856 Mdot
.69 .12856 Mdot
.69 .12857 Mdot
.69 .12932 Mdot
.69 .1294 Mdot
.69 .12961 Mdot
.69 .12961 Mdot
.69 .12967 Mdot
.69 .13029 Mdot
.69 .1305 Mdot
.69 .13149 Mdot
.69 .13195 Mdot
.69 .13196 Mdot
.69 .13227 Mdot
.69 .13244 Mdot
.69 .13247 Mdot
.69 .13261 Mdot
.69 .13312 Mdot
.69 .13313 Mdot
.69 .13316 Mdot
.69 .13318 Mdot
.69 .13323 Mdot
.69 .13332 Mdot
.69 .13344 Mdot
.69 .13375 Mdot
.69 .13485 Mdot
.69 .135 Mdot
.69 .13594 Mdot
.69 .13603 Mdot
.69 .13604 Mdot
.69 .13616 Mdot
.69 .13623 Mdot
.69 .13623 Mdot
.69 .13627 Mdot
.69 .13636 Mdot
.69 .13637 Mdot
.69 .13644 Mdot
.69 .13665 Mdot
.69 .13687 Mdot
.69 .13853 Mdot
.69 .13871 Mdot
.69 .13902 Mdot
.69 .13926 Mdot
.69 .13928 Mdot
.69 .13999 Mdot
.69 .14075 Mdot
.69 .14104 Mdot
.69 .14116 Mdot
.69 .14118 Mdot
.69 .14165 Mdot
.69 .14174 Mdot
.69 .14205 Mdot
.69 .14232 Mdot
.69 .14284 Mdot
.69 .14331 Mdot
.69 .14339 Mdot
.69 .14361 Mdot
.69 .14396 Mdot
.69 .1442 Mdot
.69 .1442 Mdot
.69 .14482 Mdot
.69 .14482 Mdot
.69 .14484 Mdot
.69 .14547 Mdot
.69 .14597 Mdot
.69 .14606 Mdot
.69 .14606 Mdot
.69 .14628 Mdot
.69 .14633 Mdot
.69 .14641 Mdot
.69 .14643 Mdot
.69 .14668 Mdot
.69 .14723 Mdot
.69 .14738 Mdot
.69 .14756 Mdot
.69 .14772 Mdot
.69 .14791 Mdot
.69 .14821 Mdot
.69 .14824 Mdot
.69 .14848 Mdot
.69 .14877 Mdot
.69 .14912 Mdot
.69 .14963 Mdot
.69 .15075 Mdot
.69 .15196 Mdot
.69 .15211 Mdot
.69 .15225 Mdot
.69 .1526 Mdot
.69 .15292 Mdot
.69 .15305 Mdot
.69 .1531 Mdot
.69 .15322 Mdot
.69 .15384 Mdot
.69 .1539 Mdot
.69 .15395 Mdot
.69 .1544 Mdot
.69 .15465 Mdot
.69 .15486 Mdot
.69 .15518 Mdot
.69 .15523 Mdot
.69 .15588 Mdot
.69 .15603 Mdot
.69 .15624 Mdot
.69 .15672 Mdot
.69 .15737 Mdot
.69 .15756 Mdot
.69 .15774 Mdot
.69 .15813 Mdot
.69 .15861 Mdot
.69 .1589 Mdot
.69 .15969 Mdot
.69 .15989 Mdot
.69 .15996 Mdot
.69 .16067 Mdot
.69 .16068 Mdot
.69 .16074 Mdot
.69 .16091 Mdot
.69 .1615 Mdot
.69 .16156 Mdot
.69 .16209 Mdot
.69 .16209 Mdot
.69 .16233 Mdot
.69 .16241 Mdot
.69 .16255 Mdot
.69 .1627 Mdot
.69 .16342 Mdot
.69 .16344 Mdot
.69 .1635 Mdot
.69 .16354 Mdot
.69 .16403 Mdot
.69 .16511 Mdot
.69 .16558 Mdot
.69 .1656 Mdot
.69 .16574 Mdot
.69 .16597 Mdot
.69 .16656 Mdot
.69 .16747 Mdot
.69 .16747 Mdot
.69 .16749 Mdot
.69 .16771 Mdot
.69 .16786 Mdot
.69 .16803 Mdot
.69 .16882 Mdot
.69 .16934 Mdot
.69 .16941 Mdot
.69 .16945 Mdot
.69 .16986 Mdot
.69 .17046 Mdot
.69 .1708 Mdot
.69 .17092 Mdot
.69 .17182 Mdot
.69 .17183 Mdot
.69 .17183 Mdot
.69 .17287 Mdot
.69 .17298 Mdot
.69 .17327 Mdot
.69 .17327 Mdot
.69 .17336 Mdot
.69 .17421 Mdot
.69 .17449 Mdot
.69 .17586 Mdot
.69 .1765 Mdot
.69 .17651 Mdot
.69 .17694 Mdot
.69 .17718 Mdot
.69 .17721 Mdot
.69 .17741 Mdot
.69 .17811 Mdot
.69 .17812 Mdot
.69 .17817 Mdot
.69 .1782 Mdot
.69 .17826 Mdot
.69 .17839 Mdot
.69 .17856 Mdot
.69 .17898 Mdot
.69 .18051 Mdot
.69 .18071 Mdot
.69 .182 Mdot
.69 .18212 Mdot
.69 .18231 Mdot
.69 .1824 Mdot
.69 .18241 Mdot
.69 .18247 Mdot
.69 .18258 Mdot
.69 .1826 Mdot
.69 .1827 Mdot
.69 .18299 Mdot
.69 .1833 Mdot
.69 .18558 Mdot
.69 .18582 Mdot
.69 .18625 Mdot
.69 .18658 Mdot
.69 .18661 Mdot
.69 .18759 Mdot
.69 .18864 Mdot
.69 .18905 Mdot
.69 .18921 Mdot
.69 .18923 Mdot
.69 .18989 Mdot
.69 .19001 Mdot
.69 .19044 Mdot
.69 .19081 Mdot
.69 .19152 Mdot
.69 .19217 Mdot
.69 .19229 Mdot
.69 .19259 Mdot
.69 .19307 Mdot
.69 .1934 Mdot
.69 .1934 Mdot
.69 .19426 Mdot
.69 .19426 Mdot
.69 .19428 Mdot
.69 .19516 Mdot
.69 .19585 Mdot
.69 .19597 Mdot
.69 .19598 Mdot
.69 .19627 Mdot
.69 .19635 Mdot
.69 .19645 Mdot
.69 .19648 Mdot
.69 .19683 Mdot
.69 .19759 Mdot
.69 .1978 Mdot
.69 .19804 Mdot
.69 .19826 Mdot
.69 .19852 Mdot
.69 .19894 Mdot
.69 .19898 Mdot
.69 .19931 Mdot
.69 .19971 Mdot
.69 .2002 Mdot
.69 .20089 Mdot
.69 .20244 Mdot
.69 .20412 Mdot
.69 .20432 Mdot
.69 .20452 Mdot
.69 .205 Mdot
.69 .20543 Mdot
.69 .20561 Mdot
.69 .20568 Mdot
.69 .20585 Mdot
.69 .2067 Mdot
.69 .20679 Mdot
.69 .20686 Mdot
.69 .20749 Mdot
.69 .20782 Mdot
.69 .20812 Mdot
.69 .20856 Mdot
.69 .20862 Mdot
.69 .20952 Mdot
.69 .20973 Mdot
.69 .21003 Mdot
.69 .21068 Mdot
.69 .21158 Mdot
.69 .21184 Mdot
.69 .2121 Mdot
.69 .21263 Mdot
.69 .2133 Mdot
.69 .2137 Mdot
.69 .21478 Mdot
.69 .21506 Mdot
.69 .21515 Mdot
.69 .21614 Mdot
.69 .21614 Mdot
.69 .21623 Mdot
.69 .21646 Mdot
.69 .21728 Mdot
.69 .21737 Mdot
.69 .21809 Mdot
.69 .2181 Mdot
.69 .21843 Mdot
.69 .21853 Mdot
.69 .21873 Mdot
.69 .21894 Mdot
.69 .21992 Mdot
.69 .21996 Mdot
.69 .22004 Mdot
.69 .22009 Mdot
.69 .22077 Mdot
.69 .22226 Mdot
.69 .22291 Mdot
.69 .22294 Mdot
.69 .22313 Mdot
.69 .22344 Mdot
.69 .22426 Mdot
.69 .22552 Mdot
.69 .22552 Mdot
.69 .22554 Mdot
.69 .22585 Mdot
.69 .22606 Mdot
.69 .22629 Mdot
.69 .22738 Mdot
.69 .2281 Mdot
.69 .22819 Mdot
.69 .22825 Mdot
.69 .22881 Mdot
.69 .22964 Mdot
.69 .23011 Mdot
.69 .23027 Mdot
.69 .23152 Mdot
.69 .23153 Mdot
.69 .23153 Mdot
.69 .23297 Mdot
.69 .23311 Mdot
.69 .23352 Mdot
.69 .23352 Mdot
.69 .23364 Mdot
.69 .23481 Mdot
.69 .23521 Mdot
.69 .2371 Mdot
.69 .23798 Mdot
.69 .23799 Mdot
.69 .23858 Mdot
.69 .23892 Mdot
.69 .23896 Mdot
.69 .23923 Mdot
.69 .24021 Mdot
.69 .24022 Mdot
.69 .24028 Mdot
.69 .24033 Mdot
.69 .24041 Mdot
.69 .24059 Mdot
.69 .24082 Mdot
.69 .2414 Mdot
.69 .24351 Mdot
.69 .24379 Mdot
.69 .24557 Mdot
.69 .24574 Mdot
.69 .246 Mdot
.69 .24612 Mdot
.69 .24614 Mdot
.69 .24621 Mdot
.69 .24637 Mdot
.69 .24639 Mdot
.69 .24653 Mdot
.69 .24693 Mdot
.69 .24736 Mdot
.69 .25051 Mdot
.69 .25084 Mdot
.69 .25144 Mdot
.69 .25189 Mdot
.69 .25193 Mdot
.69 .25328 Mdot
.69 .25473 Mdot
.69 .25529 Mdot
.69 .25552 Mdot
.69 .25555 Mdot
.69 .25646 Mdot
.69 .25663 Mdot
.69 .25721 Mdot
.69 .25773 Mdot
.69 .25871 Mdot
.69 .25961 Mdot
.69 .25977 Mdot
.69 .26019 Mdot
.69 .26084 Mdot
.69 .2613 Mdot
.69 .2613 Mdot
.69 .26248 Mdot
.69 .26248 Mdot
.69 .26252 Mdot
.69 .26373 Mdot
.69 .26468 Mdot
.69 .26485 Mdot
.69 .26486 Mdot
.69 .26527 Mdot
.69 .26536 Mdot
.69 .26552 Mdot
.69 .26556 Mdot
.69 .26604 Mdot
.69 .26708 Mdot
.69 .26737 Mdot
.69 .26771 Mdot
.69 .268 Mdot
.69 .26836 Mdot
.69 .26895 Mdot
.69 .26901 Mdot
.69 .26945 Mdot
.69 .27 Mdot
.69 .27068 Mdot
.69 .27164 Mdot
.69 .27377 Mdot
.69 .27609 Mdot
.69 .27637 Mdot
.69 .27664 Mdot
.69 .27731 Mdot
.69 .27791 Mdot
.69 .27815 Mdot
.69 .27825 Mdot
.69 .27848 Mdot
.69 .27966 Mdot
.69 .27979 Mdot
.69 .27987 Mdot
.69 .28074 Mdot
.69 .2812 Mdot
.69 .28161 Mdot
.69 .28222 Mdot
.69 .2823 Mdot
.69 .28355 Mdot
.69 .28384 Mdot
.69 .28424 Mdot
.69 .28515 Mdot
.69 .28639 Mdot
.69 .28675 Mdot
.69 .2871 Mdot
.69 .28784 Mdot
.69 .28876 Mdot
.69 .28931 Mdot
.69 .29081 Mdot
.69 .29119 Mdot
.69 .29132 Mdot
.69 .29268 Mdot
.69 .29268 Mdot
.69 .29281 Mdot
.69 .29312 Mdot
.69 .29425 Mdot
.69 .29437 Mdot
.69 .29537 Mdot
.69 .29538 Mdot
.69 .29584 Mdot
.69 .29598 Mdot
.69 .29625 Mdot
.69 .29655 Mdot
.69 .2979 Mdot
.69 .29795 Mdot
.69 .29806 Mdot
.69 .29813 Mdot
.69 .29908 Mdot
.69 .30112 Mdot
.69 .30203 Mdot
.69 .30206 Mdot
.69 .30233 Mdot
.69 .30276 Mdot
.69 .30389 Mdot
.69 .30562 Mdot
.69 .30562 Mdot
.69 .30565 Mdot
.69 .30609 Mdot
.69 .30637 Mdot
.69 .30669 Mdot
.69 .3082 Mdot
.69 .30919 Mdot
.69 .30932 Mdot
.69 .30939 Mdot
.69 .31017 Mdot
.69 .31131 Mdot
.69 .31196 Mdot
.69 .31219 Mdot
.69 .31391 Mdot
.69 .31392 Mdot
.69 .31392 Mdot
.69 .3159 Mdot
.69 .31611 Mdot
.69 .31667 Mdot
.69 .31667 Mdot
.69 .31683 Mdot
.69 .31845 Mdot
.69 .319 Mdot
.69 .3216 Mdot
.69 .32282 Mdot
.69 .32284 Mdot
.69 .32365 Mdot
.69 .32411 Mdot
.69 .32418 Mdot
.69 .32455 Mdot
.69 .32589 Mdot
.69 .32591 Mdot
.69 .326 Mdot
.69 .32606 Mdot
.69 .32617 Mdot
.69 .32642 Mdot
.69 .32674 Mdot
.69 .32755 Mdot
.69 .33045 Mdot
.69 .33083 Mdot
.69 .33329 Mdot
.69 .33353 Mdot
.69 .33388 Mdot
.69 .33406 Mdot
.69 .33408 Mdot
.69 .33418 Mdot
.69 .3344 Mdot
.69 .33443 Mdot
.69 .33462 Mdot
.69 .33517 Mdot
.69 .33576 Mdot
.69 .34011 Mdot
.69 .34057 Mdot
.69 .34139 Mdot
.69 .34202 Mdot
.69 .34208 Mdot
.69 .34394 Mdot
.69 .34594 Mdot
.69 .34671 Mdot
.69 .34703 Mdot
.69 .34707 Mdot
.69 .34832 Mdot
.69 .34855 Mdot
.69 .34936 Mdot
.69 .35007 Mdot
.69 .35143 Mdot
.69 .35267 Mdot
.69 .35289 Mdot
.69 .35347 Mdot
.69 .35437 Mdot
.69 .35501 Mdot
.69 .35501 Mdot
.69 .35663 Mdot
.69 .35663 Mdot
.69 .35669 Mdot
.69 .35835 Mdot
.69 .35967 Mdot
.69 .3599 Mdot
.69 .35991 Mdot
.69 .36048 Mdot
.69 .36061 Mdot
.69 .36082 Mdot
.69 .36088 Mdot
.69 .36154 Mdot
.69 .36298 Mdot
.69 .36338 Mdot
.69 .36385 Mdot
.69 .36425 Mdot
.69 .36475 Mdot
.69 .36556 Mdot
.69 .36564 Mdot
.69 .36625 Mdot
.69 .36701 Mdot
.69 .36795 Mdot
.69 .36927 Mdot
.69 .37222 Mdot
.69 .37541 Mdot
.69 .3758 Mdot
.69 .37618 Mdot
.69 .3771 Mdot
.69 .37792 Mdot
.69 .37826 Mdot
.69 .37839 Mdot
.69 .37871 Mdot
.69 .38033 Mdot
.69 .38051 Mdot
.69 .38063 Mdot
.69 .38183 Mdot
.69 .38246 Mdot
.69 .38303 Mdot
.69 .38387 Mdot
.69 .38399 Mdot
.69 .3857 Mdot
.69 .38611 Mdot
.69 .38666 Mdot
.69 .38791 Mdot
.69 .38963 Mdot
.69 .39013 Mdot
.69 .39061 Mdot
.69 .39163 Mdot
.69 .39289 Mdot
.69 .39365 Mdot
.69 .39572 Mdot
.69 .39624 Mdot
.69 .39643 Mdot
.69 .3983 Mdot
.69 .39831 Mdot
.69 .39848 Mdot
.69 .39892 Mdot
.69 .40047 Mdot
.69 .40064 Mdot
.69 .40202 Mdot
.69 .40204 Mdot
.69 .40267 Mdot
.69 .40286 Mdot
.69 .40324 Mdot
.69 .40364 Mdot
.69 .40551 Mdot
.69 .40558 Mdot
.69 .40573 Mdot
.69 .40583 Mdot
.69 .40713 Mdot
.69 .40996 Mdot
.69 .41121 Mdot
.69 .41126 Mdot
.69 .41162 Mdot
.69 .41222 Mdot
.69 .41377 Mdot
.69 .41616 Mdot
.69 .41616 Mdot
.69 .41621 Mdot
.69 .41681 Mdot
.69 .41719 Mdot
.69 .41763 Mdot
.69 .41972 Mdot
.69 .42109 Mdot
.69 .42127 Mdot
.69 .42137 Mdot
.69 .42245 Mdot
.692 .01498 Mdot
.692 .015 Mdot
.692 .01508 Mdot
.692 .0151 Mdot
.692 .0151 Mdot
.692 .01522 Mdot
.692 .01525 Mdot
.692 .01525 Mdot
.692 .01542 Mdot
.692 .01546 Mdot
.692 .01546 Mdot
.692 .01569 Mdot
.692 .01575 Mdot
.692 .01575 Mdot
.692 .01606 Mdot
.692 .01614 Mdot
.692 .01614 Mdot
.692 .01657 Mdot
.692 .01669 Mdot
.692 .01669 Mdot
.692 .01693 Mdot
.692 .01729 Mdot
.692 .01745 Mdot
.692 .01745 Mdot
.692 .01779 Mdot
.692 .01828 Mdot
.692 .01832 Mdot
.692 .0185 Mdot
.692 .01851 Mdot
.692 .01897 Mdot
.692 .01957 Mdot
.692 .01961 Mdot
.692 .01965 Mdot
.692 .0197 Mdot
.692 .01996 Mdot
.692 .01996 Mdot
.692 .02056 Mdot
.692 .0206 Mdot
.692 .02112 Mdot
.692 .02142 Mdot
.692 .02142 Mdot
.692 .02144 Mdot
.692 .02149 Mdot
.692 .02154 Mdot
.692 .02161 Mdot
.692 .02197 Mdot
.692 .02198 Mdot
.692 .0221 Mdot
.692 .02281 Mdot
.692 .02286 Mdot
.692 .02358 Mdot
.692 .02399 Mdot
.692 .02399 Mdot
.692 .02402 Mdot
.692 .0241 Mdot
.692 .02416 Mdot
.692 .02426 Mdot
.692 .02451 Mdot
.692 .02476 Mdot
.692 .02476 Mdot
.692 .02494 Mdot
.692 .02542 Mdot
.692 .02591 Mdot
.692 .02598 Mdot
.692 .02611 Mdot
.692 .02698 Mdot
.692 .02755 Mdot
.692 .02755 Mdot
.692 .0276 Mdot
.692 .0277 Mdot
.692 .02771 Mdot
.692 .02779 Mdot
.692 .02793 Mdot
.692 .02827 Mdot
.692 .02862 Mdot
.692 .02862 Mdot
.692 .02886 Mdot
.692 .02953 Mdot
.692 .03021 Mdot
.692 .03031 Mdot
.692 .03049 Mdot
.692 .03056 Mdot
.692 .03169 Mdot
.692 .03178 Mdot
.692 .03248 Mdot
.692 .03248 Mdot
.692 .03254 Mdot
.692 .03268 Mdot
.692 .03271 Mdot
.692 .03279 Mdot
.692 .0328 Mdot
.692 .03282 Mdot
.692 .033 Mdot
.692 .03348 Mdot
.692 .03379 Mdot
.692 .03395 Mdot
.692 .03396 Mdot
.692 .03418 Mdot
.692 .03429 Mdot
.692 .03521 Mdot
.692 .03616 Mdot
.692 .0363 Mdot
.692 .03654 Mdot
.692 .03664 Mdot
.692 .03821 Mdot
.692 .03824 Mdot
.692 .03834 Mdot
.692 .03844 Mdot
.692 .0393 Mdot
.692 .0393 Mdot
.692 .03939 Mdot
.692 .03958 Mdot
.692 .03962 Mdot
.692 .03968 Mdot
.692 .03972 Mdot
.692 .03975 Mdot
.692 .03977 Mdot
.692 .04002 Mdot
.692 .04068 Mdot
.692 .04112 Mdot
.692 .04134 Mdot
.692 .04135 Mdot
.692 .04166 Mdot
.692 .04181 Mdot
.692 .04258 Mdot
.692 .04308 Mdot
.692 .04316 Mdot
.692 .04317 Mdot
.692 .04322 Mdot
.692 .04372 Mdot
.692 .0444 Mdot
.692 .04459 Mdot
.692 .04493 Mdot
.692 .04507 Mdot
.692 .04561 Mdot
.692 .04646 Mdot
.692 .04656 Mdot
.692 .04723 Mdot
.692 .04727 Mdot
.692 .04741 Mdot
.692 .04748 Mdot
.692 .04755 Mdot
.692 .04767 Mdot
.692 .04828 Mdot
.692 .04874 Mdot
.692 .04874 Mdot
.692 .04887 Mdot
.692 .04907 Mdot
.692 .04908 Mdot
.692 .04913 Mdot
.692 .04918 Mdot
.692 .04927 Mdot
.692 .04933 Mdot
.692 .04936 Mdot
.692 .04939 Mdot
.692 .04974 Mdot
.692 .05004 Mdot
.692 .05066 Mdot
.692 .05126 Mdot
.692 .05157 Mdot
.692 .05158 Mdot
.692 .052 Mdot
.692 .05222 Mdot
.692 .05275 Mdot
.692 .05327 Mdot
.692 .05379 Mdot
.692 .05398 Mdot
.692 .05408 Mdot
.692 .0541 Mdot
.692 .05417 Mdot
.692 .05486 Mdot
.692 .0556 Mdot
.692 .0558 Mdot
.692 .05606 Mdot
.692 .05653 Mdot
.692 .05672 Mdot
.692 .05682 Mdot
.692 .05729 Mdot
.692 .05748 Mdot
.692 .0578 Mdot
.692 .05865 Mdot
.692 .05879 Mdot
.692 .05971 Mdot
.692 .05977 Mdot
.692 .05997 Mdot
.692 .06006 Mdot
.692 .06016 Mdot
.692 .06032 Mdot
.692 .06117 Mdot
.692 .0618 Mdot
.692 .0618 Mdot
.692 .06198 Mdot
.692 .06207 Mdot
.692 .06227 Mdot
.692 .06227 Mdot
.692 .06235 Mdot
.692 .06241 Mdot
.692 .06253 Mdot
.692 .06262 Mdot
.692 .06267 Mdot
.692 .0627 Mdot
.692 .06318 Mdot
.692 .06347 Mdot
.692 .0635 Mdot
.692 .0636 Mdot
.692 .06446 Mdot
.692 .06455 Mdot
.692 .06521 Mdot
.692 .06529 Mdot
.692 .06572 Mdot
.692 .06574 Mdot
.692 .06613 Mdot
.692 .06632 Mdot
.692 .06659 Mdot
.692 .06662 Mdot
.692 .06677 Mdot
.692 .06716 Mdot
.692 .06735 Mdot
.692 .06792 Mdot
.692 .06801 Mdot
.692 .06803 Mdot
.692 .06808 Mdot
.692 .06876 Mdot
.692 .06879 Mdot
.692 .06905 Mdot
.692 .0692 Mdot
.692 .06922 Mdot
.692 .06932 Mdot
.692 .0694 Mdot
.692 .07027 Mdot
.692 .07061 Mdot
.692 .07105 Mdot
.692 .0713 Mdot
.692 .07143 Mdot
.692 .07157 Mdot
.692 .07192 Mdot
.692 .07194 Mdot
.692 .07225 Mdot
.692 .07258 Mdot
.692 .07285 Mdot
.692 .07298 Mdot
.692 .07364 Mdot
.692 .0739 Mdot
.692 .07434 Mdot
.692 .07552 Mdot
.692 .07571 Mdot
.692 .07629 Mdot
.692 .07691 Mdot
.692 .07699 Mdot
.692 .07707 Mdot
.692 .07734 Mdot
.692 .07748 Mdot
.692 .07761 Mdot
.692 .07783 Mdot
.692 .079 Mdot
.692 .07968 Mdot
.692 .07988 Mdot
.692 .07989 Mdot
.692 .08004 Mdot
.692 .08013 Mdot
.692 .08026 Mdot
.692 .08041 Mdot
.692 .08053 Mdot
.692 .08053 Mdot
.692 .08064 Mdot
.692 .08073 Mdot
.692 .0809 Mdot
.692 .08096 Mdot
.692 .08101 Mdot
.692 .08108 Mdot
.692 .08113 Mdot
.692 .08179 Mdot
.692 .08219 Mdot
.692 .08224 Mdot
.692 .08237 Mdot
.692 .08356 Mdot
.692 .08368 Mdot
.692 .0846 Mdot
.692 .08471 Mdot
.692 .0853 Mdot
.692 .08534 Mdot
.692 .08551 Mdot
.692 .08587 Mdot
.692 .08614 Mdot
.692 .08651 Mdot
.692 .08654 Mdot
.692 .08668 Mdot
.692 .08676 Mdot
.692 .0873 Mdot
.692 .08756 Mdot
.692 .08776 Mdot
.692 .08835 Mdot
.692 .08848 Mdot
.692 .0885 Mdot
.692 .08857 Mdot
.692 .08932 Mdot
.692 .08952 Mdot
.692 .08956 Mdot
.692 .08974 Mdot
.692 .08992 Mdot
.692 .09012 Mdot
.692 .09015 Mdot
.692 .09019 Mdot
.692 .09029 Mdot
.692 .0904 Mdot
.692 .09083 Mdot
.692 .09161 Mdot
.692 .09207 Mdot
.692 .09268 Mdot
.692 .09303 Mdot
.692 .0932 Mdot
.692 .0934 Mdot
.692 .09389 Mdot
.692 .09391 Mdot
.692 .09434 Mdot
.692 .09481 Mdot
.692 .09517 Mdot
.692 .09536 Mdot
.692 .09574 Mdot
.692 .09626 Mdot
.692 .09657 Mdot
.692 .09662 Mdot
.692 .09662 Mdot
.692 .09723 Mdot
.692 .09741 Mdot
.692 .09843 Mdot
.692 .09867 Mdot
.692 .09886 Mdot
.692 .09914 Mdot
.692 .09994 Mdot
.692 .10079 Mdot
.692 .10091 Mdot
.692 .10102 Mdot
.692 .10139 Mdot
.692 .10156 Mdot
.692 .10158 Mdot
.692 .10176 Mdot
.692 .10179 Mdot
.692 .10207 Mdot
.692 .103 Mdot
.692 .10369 Mdot
.692 .10379 Mdot
.692 .10463 Mdot
.692 .10491 Mdot
.692 .10491 Mdot
.692 .10512 Mdot
.692 .10525 Mdot
.692 .10543 Mdot
.692 .10556 Mdot
.692 .10563 Mdot
.692 .1058 Mdot
.692 .1058 Mdot
.692 .10595 Mdot
.692 .10607 Mdot
.692 .10631 Mdot
.692 .1064 Mdot
.692 .10647 Mdot
.692 .10657 Mdot
.692 .10663 Mdot
.692 .10743 Mdot
.692 .10755 Mdot
.692 .1081 Mdot
.692 .10817 Mdot
.692 .10835 Mdot
.692 .11 Mdot
.692 .11008 Mdot
.692 .11017 Mdot
.692 .11029 Mdot
.692 .11126 Mdot
.692 .11142 Mdot
.692 .11144 Mdot
.692 .11159 Mdot
.692 .11179 Mdot
.692 .11241 Mdot
.692 .11245 Mdot
.692 .11269 Mdot
.692 .11319 Mdot
.692 .11356 Mdot
.692 .11409 Mdot
.692 .11413 Mdot
.692 .11432 Mdot
.692 .11435 Mdot
.692 .11442 Mdot
.692 .11517 Mdot
.692 .11554 Mdot
.692 .11561 Mdot
.692 .1158 Mdot
.692 .11662 Mdot
.692 .1168 Mdot
.692 .11683 Mdot
.692 .11694 Mdot
.692 .11746 Mdot
.692 .11784 Mdot
.692 .11797 Mdot
.692 .11824 Mdot
.692 .11829 Mdot
.692 .11854 Mdot
.692 .1188 Mdot
.692 .1188 Mdot
.692 .11907 Mdot
.692 .11911 Mdot
.692 .11917 Mdot
.692 .11931 Mdot
.692 .11946 Mdot
.692 .12005 Mdot
.692 .1208 Mdot
.692 .12113 Mdot
.692 .12178 Mdot
.692 .12262 Mdot
.692 .12296 Mdot
.692 .1231 Mdot
.692 .12334 Mdot
.692 .12342 Mdot
.692 .12362 Mdot
.692 .12387 Mdot
.692 .12403 Mdot
.692 .12429 Mdot
.692 .12433 Mdot
.692 .12456 Mdot
.692 .12492 Mdot
.692 .12556 Mdot
.692 .12607 Mdot
.692 .12632 Mdot
.692 .12686 Mdot
.692 .12723 Mdot
.692 .12758 Mdot
.692 .12784 Mdot
.692 .128 Mdot
.692 .12808 Mdot
.692 .12808 Mdot
.692 .12826 Mdot
.692 .12892 Mdot
.692 .12917 Mdot
.692 .12936 Mdot
.692 .12979 Mdot
.692 .13057 Mdot
.692 .1309 Mdot
.692 .13118 Mdot
.692 .13118 Mdot
.692 .13145 Mdot
.692 .13156 Mdot
.692 .13266 Mdot
.692 .13272 Mdot
.692 .13306 Mdot
.692 .13384 Mdot
.692 .134 Mdot
.692 .13401 Mdot
.692 .13402 Mdot
.692 .13416 Mdot
.692 .13467 Mdot
.692 .1349 Mdot
.692 .13493 Mdot
.692 .13518 Mdot
.692 .13523 Mdot
.692 .1354 Mdot
.692 .13562 Mdot
.692 .13562 Mdot
.692 .13588 Mdot
.692 .13662 Mdot
.692 .1369 Mdot
.692 .13739 Mdot
.692 .13773 Mdot
.692 .13785 Mdot
.692 .13799 Mdot
.692 .13916 Mdot
.692 .13954 Mdot
.692 .13955 Mdot
.692 .13983 Mdot
.692 .14001 Mdot
.692 .14026 Mdot
.692 .14039 Mdot
.692 .14044 Mdot
.692 .14055 Mdot
.692 .14075 Mdot
.692 .14078 Mdot
.692 .14078 Mdot
.692 .14098 Mdot
.692 .14116 Mdot
.692 .14149 Mdot
.692 .1416 Mdot
.692 .14171 Mdot
.692 .14184 Mdot
.692 .14193 Mdot
.692 .14303 Mdot
.692 .1432 Mdot
.692 .14396 Mdot
.692 .14405 Mdot
.692 .14416 Mdot
.692 .14431 Mdot
.692 .14555 Mdot
.692 .14587 Mdot
.692 .14616 Mdot
.692 .14659 Mdot
.692 .1467 Mdot
.692 .14682 Mdot
.692 .147 Mdot
.692 .14834 Mdot
.692 .14856 Mdot
.692 .14858 Mdot
.692 .14879 Mdot
.692 .14907 Mdot
.692 .14913 Mdot
.692 .14992 Mdot
.692 .14999 Mdot
.692 .15031 Mdot
.692 .15053 Mdot
.692 .15101 Mdot
.692 .15152 Mdot
.692 .15224 Mdot
.692 .1523 Mdot
.692 .15257 Mdot
.692 .15261 Mdot
.692 .15271 Mdot
.692 .15341 Mdot
.692 .15375 Mdot
.692 .15426 Mdot
.692 .15436 Mdot
.692 .15462 Mdot
.692 .15516 Mdot
.692 .15575 Mdot
.692 .15588 Mdot
.692 .156 Mdot
.692 .15605 Mdot
.692 .15619 Mdot
.692 .15692 Mdot
.692 .15709 Mdot
.692 .1572 Mdot
.692 .15744 Mdot
.692 .1575 Mdot
.692 .15762 Mdot
.692 .158 Mdot
.692 .15807 Mdot
.692 .15841 Mdot
.692 .15851 Mdot
.692 .15876 Mdot
.692 .15877 Mdot
.692 .15914 Mdot
.692 .1592 Mdot
.692 .15927 Mdot
.692 .15948 Mdot
.692 .15969 Mdot
.692 .15978 Mdot
.692 .1605 Mdot
.692 .1606 Mdot
.692 .16153 Mdot
.692 .16191 Mdot
.692 .162 Mdot
.692 .16208 Mdot
.692 .16289 Mdot
.692 .16327 Mdot
.692 .16405 Mdot
.692 .16453 Mdot
.692 .16473 Mdot
.692 .16505 Mdot
.692 .16509 Mdot
.692 .16517 Mdot
.692 .16544 Mdot
.692 .16579 Mdot
.692 .16601 Mdot
.692 .16637 Mdot
.692 .16642 Mdot
.692 .16674 Mdot
.692 .16724 Mdot
.692 .16813 Mdot
.692 .16835 Mdot
.692 .16883 Mdot
.692 .16918 Mdot
.692 .16919 Mdot
.692 .16992 Mdot
.692 .17044 Mdot
.692 .17091 Mdot
.692 .17093 Mdot
.692 .17129 Mdot
.692 .1715 Mdot
.692 .17161 Mdot
.692 .17161 Mdot
.692 .17187 Mdot
.692 .17278 Mdot
.692 .17312 Mdot
.692 .17338 Mdot
.692 .17398 Mdot
.692 .17506 Mdot
.692 .17552 Mdot
.692 .1759 Mdot
.692 .17591 Mdot
.692 .17628 Mdot
.692 .17642 Mdot
.692 .17795 Mdot
.692 .17803 Mdot
.692 .1785 Mdot
.692 .17959 Mdot
.692 .17981 Mdot
.692 .17981 Mdot
.692 .17983 Mdot
.692 .18002 Mdot
.692 .18074 Mdot
.692 .18105 Mdot
.692 .18109 Mdot
.692 .18144 Mdot
.692 .18151 Mdot
.692 .18174 Mdot
.692 .18204 Mdot
.692 .18204 Mdot
.692 .1824 Mdot
.692 .18343 Mdot
.692 .18382 Mdot
.692 .1845 Mdot
.692 .18496 Mdot
.692 .18514 Mdot
.692 .18533 Mdot
.692 .18695 Mdot
.692 .18747 Mdot
.692 .18749 Mdot
.692 .18788 Mdot
.692 .18813 Mdot
.692 .18847 Mdot
.692 .18865 Mdot
.692 .18872 Mdot
.692 .18886 Mdot
.692 .18915 Mdot
.692 .18919 Mdot
.692 .18919 Mdot
.692 .18947 Mdot
.692 .18971 Mdot
.692 .19016 Mdot
.692 .19033 Mdot
.692 .19047 Mdot
.692 .19066 Mdot
.692 .19078 Mdot
.692 .19231 Mdot
.692 .19254 Mdot
.692 .19359 Mdot
.692 .19372 Mdot
.692 .19386 Mdot
.692 .19407 Mdot
.692 .19578 Mdot
.692 .19623 Mdot
.692 .19663 Mdot
.692 .19722 Mdot
.692 .19738 Mdot
.692 .19755 Mdot
.692 .19779 Mdot
.692 .19965 Mdot
.692 .19996 Mdot
.692 .19998 Mdot
.692 .20028 Mdot
.692 .20066 Mdot
.692 .20075 Mdot
.692 .20184 Mdot
.692 .20193 Mdot
.692 .20238 Mdot
.692 .20268 Mdot
.692 .20335 Mdot
.692 .20406 Mdot
.692 .20505 Mdot
.692 .20513 Mdot
.692 .2055 Mdot
.692 .20556 Mdot
.692 .2057 Mdot
.692 .20666 Mdot
.692 .20714 Mdot
.692 .20784 Mdot
.692 .20798 Mdot
.692 .20834 Mdot
.692 .2091 Mdot
.692 .20991 Mdot
.692 .21009 Mdot
.692 .21026 Mdot
.692 .21032 Mdot
.692 .21052 Mdot
.692 .21152 Mdot
.692 .21176 Mdot
.692 .21191 Mdot
.692 .21233 Mdot
.692 .21249 Mdot
.692 .21302 Mdot
.692 .21312 Mdot
.692 .21359 Mdot
.692 .21372 Mdot
.692 .21408 Mdot
.692 .21409 Mdot
.692 .2146 Mdot
.692 .21469 Mdot
.692 .21479 Mdot
.692 .21506 Mdot
.692 .21536 Mdot
.692 .21548 Mdot
.692 .21649 Mdot
.692 .21662 Mdot
.692 .21791 Mdot
.692 .21843 Mdot
.692 .21855 Mdot
.692 .21866 Mdot
.692 .21979 Mdot
.692 .22031 Mdot
.692 .2214 Mdot
.692 .22206 Mdot
.692 .22233 Mdot
.692 .22279 Mdot
.692 .22283 Mdot
.692 .22294 Mdot
.692 .22332 Mdot
.692 .2238 Mdot
.692 .22411 Mdot
.692 .22461 Mdot
.692 .22467 Mdot
.692 .22512 Mdot
.692 .2258 Mdot
.692 .22704 Mdot
.692 .22735 Mdot
.692 .22801 Mdot
.692 .2285 Mdot
.692 .2285 Mdot
.692 .22952 Mdot
.692 .23024 Mdot
.692 .23089 Mdot
.692 .23091 Mdot
.692 .23141 Mdot
.692 .2317 Mdot
.692 .23186 Mdot
.692 .23186 Mdot
.692 .23221 Mdot
.692 .23347 Mdot
.692 .23394 Mdot
.692 .23431 Mdot
.692 .23514 Mdot
.692 .23663 Mdot
.692 .23727 Mdot
.692 .23779 Mdot
.692 .23781 Mdot
.692 .23832 Mdot
.692 .23852 Mdot
.692 .24064 Mdot
.692 .24074 Mdot
.692 .24139 Mdot
.692 .2429 Mdot
.692 .24321 Mdot
.692 .24321 Mdot
.692 .24324 Mdot
.692 .2435 Mdot
.692 .24449 Mdot
.692 .24493 Mdot
.692 .24498 Mdot
.692 .24546 Mdot
.692 .24556 Mdot
.692 .24588 Mdot
.692 .2463 Mdot
.692 .2463 Mdot
.692 .2468 Mdot
.692 .24821 Mdot
.692 .24876 Mdot
.692 .2497 Mdot
.692 .25034 Mdot
.692 .25058 Mdot
.692 .25085 Mdot
.692 .25308 Mdot
.692 .25381 Mdot
.692 .25383 Mdot
.692 .25437 Mdot
.692 .25472 Mdot
.692 .2552 Mdot
.692 .25544 Mdot
.692 .25553 Mdot
.692 .25574 Mdot
.692 .25613 Mdot
.692 .25618 Mdot
.692 .25619 Mdot
.692 .25657 Mdot
.692 .25691 Mdot
.692 .25754 Mdot
.692 .25777 Mdot
.692 .25796 Mdot
.692 .25822 Mdot
.692 .25839 Mdot
.692 .2605 Mdot
.692 .26083 Mdot
.692 .26228 Mdot
.692 .26246 Mdot
.692 .26265 Mdot
.692 .26294 Mdot
.692 .26532 Mdot
.692 .26593 Mdot
.692 .26649 Mdot
.692 .26731 Mdot
.692 .26752 Mdot
.692 .26776 Mdot
.692 .26809 Mdot
.692 .27066 Mdot
.692 .27109 Mdot
.692 .27112 Mdot
.692 .27153 Mdot
.692 .27206 Mdot
.692 .27219 Mdot
.692 .27369 Mdot
.692 .27382 Mdot
.692 .27445 Mdot
.692 .27486 Mdot
.692 .27578 Mdot
.692 .27676 Mdot
.692 .27814 Mdot
.692 .27826 Mdot
.692 .27876 Mdot
.692 .27885 Mdot
.692 .27904 Mdot
.692 .28037 Mdot
.692 .28103 Mdot
.692 .282 Mdot
.692 .28219 Mdot
.692 .2827 Mdot
.692 .28374 Mdot
.692 .28487 Mdot
.692 .28511 Mdot
.692 .28535 Mdot
.692 .28543 Mdot
.692 .2857 Mdot
.692 .2871 Mdot
.692 .28742 Mdot
.692 .28764 Mdot
.692 .28821 Mdot
.692 .28844 Mdot
.692 .28916 Mdot
.692 .2893 Mdot
.692 .28996 Mdot
.692 .29014 Mdot
.692 .29063 Mdot
.692 .29064 Mdot
.692 .29136 Mdot
.692 .29148 Mdot
.692 .29161 Mdot
.692 .292 Mdot
.692 .2924 Mdot
.692 .29258 Mdot
.692 .29397 Mdot
.692 .29416 Mdot
.692 .29593 Mdot
.692 .29666 Mdot
.692 .29683 Mdot
.692 .29698 Mdot
.692 .29853 Mdot
.692 .29926 Mdot
.692 .30076 Mdot
.692 .30168 Mdot
.692 .30206 Mdot
.692 .30268 Mdot
.692 .30274 Mdot
.692 .3029 Mdot
.692 .30343 Mdot
.692 .30409 Mdot
.692 .30452 Mdot
.692 .3052 Mdot
.692 .30529 Mdot
.692 .30591 Mdot
.692 .30686 Mdot
.692 .30857 Mdot
.692 .309 Mdot
.692 .30991 Mdot
.692 .31059 Mdot
.692 .3106 Mdot
.692 .312 Mdot
.692 .313 Mdot
.692 .31391 Mdot
.692 .31393 Mdot
.692 .31462 Mdot
.692 .31502 Mdot
.692 .31524 Mdot
.692 .31524 Mdot
.692 .31573 Mdot
.692 .31747 Mdot
.692 .31813 Mdot
.692 .31863 Mdot
.692 .31979 Mdot
.692 .32184 Mdot
.692 .32273 Mdot
.692 .32345 Mdot
.692 .32348 Mdot
.692 .32418 Mdot
.692 .32446 Mdot
.692 .32739 Mdot
.692 .32754 Mdot
.692 .32843 Mdot
.692 .33053 Mdot
.692 .33095 Mdot
.692 .33096 Mdot
.692 .33099 Mdot
.692 .33135 Mdot
.692 .33272 Mdot
.692 .33333 Mdot
.692 .33341 Mdot
.692 .33407 Mdot
.692 .33421 Mdot
.692 .33465 Mdot
.692 .33522 Mdot
.692 .33522 Mdot
.692 .33592 Mdot
.692 .33788 Mdot
.692 .33863 Mdot
.692 .33994 Mdot
.692 .34082 Mdot
.692 .34116 Mdot
.692 .34152 Mdot
.692 .34462 Mdot
.692 .34562 Mdot
.692 .34565 Mdot
.692 .3464 Mdot
.692 .34688 Mdot
.692 .34754 Mdot
.692 .34788 Mdot
.692 .34801 Mdot
.692 .34829 Mdot
.692 .34884 Mdot
.692 .3489 Mdot
.692 .34892 Mdot
.692 .34945 Mdot
.692 .34991 Mdot
.692 .35078 Mdot
.692 .3511 Mdot
.692 .35137 Mdot
.692 .35173 Mdot
.692 .35197 Mdot
.692 .35489 Mdot
.692 .35533 Mdot
.692 .35734 Mdot
.692 .35759 Mdot
.692 .35786 Mdot
.692 .35826 Mdot
.692 .36155 Mdot
.692 .3624 Mdot
.692 .36317 Mdot
.692 .3643 Mdot
.692 .3646 Mdot
.692 .36493 Mdot
.692 .36539 Mdot
.692 .36894 Mdot
.692 .36954 Mdot
.692 .36958 Mdot
.692 .37015 Mdot
.692 .37088 Mdot
.692 .37105 Mdot
.692 .37314 Mdot
.692 .37331 Mdot
.692 .37419 Mdot
.692 .37476 Mdot
.692 .37603 Mdot
.692 .37739 Mdot
.692 .3793 Mdot
.692 .37946 Mdot
.692 .38016 Mdot
.692 .38027 Mdot
.692 .38054 Mdot
.692 .38239 Mdot
.692 .3833 Mdot
.692 .38464 Mdot
.692 .38491 Mdot
.692 .3856 Mdot
.692 .38704 Mdot
.692 .38861 Mdot
.692 .38894 Mdot
.692 .38927 Mdot
.692 .38938 Mdot
.692 .38976 Mdot
.692 .39169 Mdot
.692 .39214 Mdot
.692 .39244 Mdot
.692 .39323 Mdot
.692 .39355 Mdot
.692 .39455 Mdot
.692 .39474 Mdot
.692 .39566 Mdot
.692 .3959 Mdot
.692 .39659 Mdot
.692 .3966 Mdot
.692 .3976 Mdot
.692 .39775 Mdot
.692 .39794 Mdot
.692 .39848 Mdot
.692 .39904 Mdot
.692 .39928 Mdot
.692 .4012 Mdot
.692 .40146 Mdot
.692 .40392 Mdot
.692 .40493 Mdot
.692 .40516 Mdot
.692 .40537 Mdot
.692 .40752 Mdot
.692 .40853 Mdot
.692 .41061 Mdot
.692 .41188 Mdot
.692 .41239 Mdot
.692 .41326 Mdot
.692 .41335 Mdot
.692 .41356 Mdot
.692 .41429 Mdot
.692 .41521 Mdot
.692 .41581 Mdot
.692 .41675 Mdot
.692 .41687 Mdot
.692 .41773 Mdot
.692 .41905 Mdot
.692 .42141 Mdot
.692 .42201 Mdot
.692 .42327 Mdot
.694 .01695 Mdot
.694 .01722 Mdot
.694 .01782 Mdot
.694 .01789 Mdot
.694 .01819 Mdot
.694 .01903 Mdot
.694 .01912 Mdot
.694 .01931 Mdot
.694 .01952 Mdot
.694 .01954 Mdot
.694 .0199 Mdot
.694 .01996 Mdot
.694 .02032 Mdot
.694 .0207 Mdot
.694 .02083 Mdot
.694 .0211 Mdot
.694 .02139 Mdot
.694 .02141 Mdot
.694 .02191 Mdot
.694 .02199 Mdot
.694 .02212 Mdot
.694 .0225 Mdot
.694 .02302 Mdot
.694 .02321 Mdot
.694 .02358 Mdot
.694 .02397 Mdot
.694 .024 Mdot
.694 .0247 Mdot
.694 .02481 Mdot
.694 .025 Mdot
.694 .02552 Mdot
.694 .026 Mdot
.694 .02624 Mdot
.694 .02636 Mdot
.694 .0265 Mdot
.694 .02679 Mdot
.694 .02701 Mdot
.694 .02757 Mdot
.694 .02761 Mdot
.694 .0277 Mdot
.694 .02827 Mdot
.694 .02858 Mdot
.694 .02873 Mdot
.694 .02888 Mdot
.694 .02898 Mdot
.694 .02971 Mdot
.694 .03037 Mdot
.694 .03071 Mdot
.694 .03088 Mdot
.694 .03107 Mdot
.694 .03143 Mdot
.694 .03147 Mdot
.694 .03179 Mdot
.694 .03203 Mdot
.694 .03255 Mdot
.694 .03261 Mdot
.694 .03274 Mdot
.694 .03298 Mdot
.694 .0334 Mdot
.694 .03352 Mdot
.694 .03365 Mdot
.694 .03396 Mdot
.694 .0341 Mdot
.694 .03417 Mdot
.694 .03437 Mdot
.694 .03452 Mdot
.694 .03553 Mdot
.694 .03635 Mdot
.694 .03645 Mdot
.694 .03677 Mdot
.694 .03692 Mdot
.694 .03716 Mdot
.694 .03717 Mdot
.694 .03742 Mdot
.694 .03791 Mdot
.694 .03797 Mdot
.694 .03841 Mdot
.694 .03843 Mdot
.694 .03867 Mdot
.694 .03874 Mdot
.694 .03906 Mdot
.694 .03947 Mdot
.694 .03955 Mdot
.694 .03973 Mdot
.694 .03998 Mdot
.694 .04006 Mdot
.694 .04065 Mdot
.694 .04082 Mdot
.694 .041 Mdot
.694 .04142 Mdot
.694 .04148 Mdot
.694 .04152 Mdot
.694 .04162 Mdot
.694 .04171 Mdot
.694 .042 Mdot
.694 .04221 Mdot
.694 .04228 Mdot
.694 .04249 Mdot
.694 .04345 Mdot
.694 .0436 Mdot
.694 .04392 Mdot
.694 .0443 Mdot
.694 .04474 Mdot
.694 .04488 Mdot
.694 .04533 Mdot
.694 .04549 Mdot
.694 .04553 Mdot
.694 .04586 Mdot
.694 .04588 Mdot
.694 .04623 Mdot
.694 .04692 Mdot
.694 .047 Mdot
.694 .04732 Mdot
.694 .0476 Mdot
.694 .04763 Mdot
.694 .04789 Mdot
.694 .04796 Mdot
.694 .04807 Mdot
.694 .04851 Mdot
.694 .04902 Mdot
.694 .04908 Mdot
.694 .04915 Mdot
.694 .04919 Mdot
.694 .04942 Mdot
.694 .04943 Mdot
.694 .04978 Mdot
.694 .0499 Mdot
.694 .05071 Mdot
.694 .05095 Mdot
.694 .0512 Mdot
.694 .05179 Mdot
.694 .05187 Mdot
.694 .05192 Mdot
.694 .05197 Mdot
.694 .05206 Mdot
.694 .05219 Mdot
.694 .05258 Mdot
.694 .05287 Mdot
.694 .05297 Mdot
.694 .05326 Mdot
.694 .05348 Mdot
.694 .05461 Mdot
.694 .05474 Mdot
.694 .05481 Mdot
.694 .05525 Mdot
.694 .05577 Mdot
.694 .05639 Mdot
.694 .05659 Mdot
.694 .0572 Mdot
.694 .05737 Mdot
.694 .05743 Mdot
.694 .05749 Mdot
.694 .05775 Mdot
.694 .05795 Mdot
.694 .05797 Mdot
.694 .05846 Mdot
.694 .05886 Mdot
.694 .05941 Mdot
.694 .05952 Mdot
.694 .05997 Mdot
.694 .06036 Mdot
.694 .0604 Mdot
.694 .06076 Mdot
.694 .06086 Mdot
.694 .06101 Mdot
.694 .06133 Mdot
.694 .06145 Mdot
.694 .06157 Mdot
.694 .06162 Mdot
.694 .06226 Mdot
.694 .06233 Mdot
.694 .06241 Mdot
.694 .06251 Mdot
.694 .06257 Mdot
.694 .06288 Mdot
.694 .0629 Mdot
.694 .06302 Mdot
.694 .06339 Mdot
.694 .06355 Mdot
.694 .06377 Mdot
.694 .06457 Mdot
.694 .06467 Mdot
.694 .06501 Mdot
.694 .06535 Mdot
.694 .06582 Mdot
.694 .06617 Mdot
.694 .06628 Mdot
.694 .06635 Mdot
.694 .06643 Mdot
.694 .06655 Mdot
.694 .06673 Mdot
.694 .06694 Mdot
.694 .06728 Mdot
.694 .06752 Mdot
.694 .06768 Mdot
.694 .06782 Mdot
.694 .06789 Mdot
.694 .06799 Mdot
.694 .06815 Mdot
.694 .06822 Mdot
.694 .06852 Mdot
.694 .06931 Mdot
.694 .06987 Mdot
.694 .07008 Mdot
.694 .07026 Mdot
.694 .07037 Mdot
.694 .0707 Mdot
.694 .07098 Mdot
.694 .0717 Mdot
.694 .07255 Mdot
.694 .07284 Mdot
.694 .07369 Mdot
.694 .07393 Mdot
.694 .07401 Mdot
.694 .07409 Mdot
.694 .07445 Mdot
.694 .07472 Mdot
.694 .07476 Mdot
.694 .07543 Mdot
.694 .07597 Mdot
.694 .07599 Mdot
.694 .07619 Mdot
.694 .07641 Mdot
.694 .07675 Mdot
.694 .07691 Mdot
.694 .07693 Mdot
.694 .07753 Mdot
.694 .07771 Mdot
.694 .07808 Mdot
.694 .07813 Mdot
.694 .07863 Mdot
.694 .07866 Mdot
.694 .07876 Mdot
.694 .07897 Mdot
.694 .07908 Mdot
.694 .07926 Mdot
.694 .07941 Mdot
.694 .07958 Mdot
.694 .07974 Mdot
.694 .07982 Mdot
.694 .08071 Mdot
.694 .08074 Mdot
.694 .08081 Mdot
.694 .08092 Mdot
.694 .08105 Mdot
.694 .08114 Mdot
.694 .08134 Mdot
.694 .08157 Mdot
.694 .0816 Mdot
.694 .08177 Mdot
.694 .08227 Mdot
.694 .08233 Mdot
.694 .0825 Mdot
.694 .08258 Mdot
.694 .08281 Mdot
.694 .08378 Mdot
.694 .0839 Mdot
.694 .08391 Mdot
.694 .08405 Mdot
.694 .08452 Mdot
.694 .085 Mdot
.694 .08565 Mdot
.694 .08613 Mdot
.694 .08629 Mdot
.694 .08639 Mdot
.694 .08649 Mdot
.694 .08666 Mdot
.694 .08691 Mdot
.694 .0872 Mdot
.694 .08738 Mdot
.694 .08767 Mdot
.694 .08779 Mdot
.694 .08801 Mdot
.694 .08823 Mdot
.694 .08842 Mdot
.694 .08853 Mdot
.694 .08866 Mdot
.694 .08888 Mdot
.694 .08898 Mdot
.694 .089 Mdot
.694 .08939 Mdot
.694 .08958 Mdot
.694 .09049 Mdot
.694 .09119 Mdot
.694 .09128 Mdot
.694 .09157 Mdot
.694 .09182 Mdot
.694 .09196 Mdot
.694 .09201 Mdot
.694 .09242 Mdot
.694 .09281 Mdot
.694 .09381 Mdot
.694 .095 Mdot
.694 .09539 Mdot
.694 .0954 Mdot
.694 .09657 Mdot
.694 .09672 Mdot
.694 .0969 Mdot
.694 .09701 Mdot
.694 .09713 Mdot
.694 .09762 Mdot
.694 .09801 Mdot
.694 .09806 Mdot
.694 .09814 Mdot
.694 .09866 Mdot
.694 .09898 Mdot
.694 .09903 Mdot
.694 .09911 Mdot
.694 .09958 Mdot
.694 .09973 Mdot
.694 .09977 Mdot
.694 .10005 Mdot
.694 .10012 Mdot
.694 .10035 Mdot
.694 .10082 Mdot
.694 .10104 Mdot
.694 .10106 Mdot
.694 .1019 Mdot
.694 .10215 Mdot
.694 .10266 Mdot
.694 .10273 Mdot
.694 .10295 Mdot
.694 .10343 Mdot
.694 .10345 Mdot
.694 .10347 Mdot
.694 .10361 Mdot
.694 .1039 Mdot
.694 .10406 Mdot
.694 .1043 Mdot
.694 .10452 Mdot
.694 .10463 Mdot
.694 .10475 Mdot
.694 .10498 Mdot
.694 .10509 Mdot
.694 .10627 Mdot
.694 .10631 Mdot
.694 .10636 Mdot
.694 .10646 Mdot
.694 .10661 Mdot
.694 .10679 Mdot
.694 .10687 Mdot
.694 .10691 Mdot
.694 .1072 Mdot
.694 .1075 Mdot
.694 .10755 Mdot
.694 .10779 Mdot
.694 .10849 Mdot
.694 .10856 Mdot
.694 .1088 Mdot
.694 .10891 Mdot
.694 .10922 Mdot
.694 .11004 Mdot
.694 .1103 Mdot
.694 .11057 Mdot
.694 .11067 Mdot
.694 .11075 Mdot
.694 .11076 Mdot
.694 .11096 Mdot
.694 .11151 Mdot
.694 .1116 Mdot
.694 .11227 Mdot
.694 .11293 Mdot
.694 .11317 Mdot
.694 .11384 Mdot
.694 .11406 Mdot
.694 .1142 Mdot
.694 .11434 Mdot
.694 .11458 Mdot
.694 .11492 Mdot
.694 .11498 Mdot
.694 .11532 Mdot
.694 .11558 Mdot
.694 .11597 Mdot
.694 .11609 Mdot
.694 .11614 Mdot
.694 .11645 Mdot
.694 .11675 Mdot
.694 .1168 Mdot
.694 .11702 Mdot
.694 .11716 Mdot
.694 .11735 Mdot
.694 .11755 Mdot
.694 .11766 Mdot
.694 .11779 Mdot
.694 .11783 Mdot
.694 .11837 Mdot
.694 .11862 Mdot
.694 .11877 Mdot
.694 .11989 Mdot
.694 .12028 Mdot
.694 .12055 Mdot
.694 .12063 Mdot
.694 .12083 Mdot
.694 .12086 Mdot
.694 .12098 Mdot
.694 .12138 Mdot
.694 .12173 Mdot
.694 .12193 Mdot
.694 .122 Mdot
.694 .12257 Mdot
.694 .1226 Mdot
.694 .12311 Mdot
.694 .12391 Mdot
.694 .12451 Mdot
.694 .12596 Mdot
.694 .12615 Mdot
.694 .12658 Mdot
.694 .12669 Mdot
.694 .1267 Mdot
.694 .1268 Mdot
.694 .12729 Mdot
.694 .12833 Mdot
.694 .12843 Mdot
.694 .12854 Mdot
.694 .12879 Mdot
.694 .12894 Mdot
.694 .12911 Mdot
.694 .12979 Mdot
.694 .12995 Mdot
.694 .13021 Mdot
.694 .13032 Mdot
.694 .13039 Mdot
.694 .13051 Mdot
.694 .13112 Mdot
.694 .13123 Mdot
.694 .13134 Mdot
.694 .13168 Mdot
.694 .13174 Mdot
.694 .13185 Mdot
.694 .1321 Mdot
.694 .1325 Mdot
.694 .13251 Mdot
.694 .13272 Mdot
.694 .13277 Mdot
.694 .13303 Mdot
.694 .13316 Mdot
.694 .13326 Mdot
.694 .13358 Mdot
.694 .13407 Mdot
.694 .13423 Mdot
.694 .13453 Mdot
.694 .13457 Mdot
.694 .13464 Mdot
.694 .13533 Mdot
.694 .13573 Mdot
.694 .13607 Mdot
.694 .13678 Mdot
.694 .13688 Mdot
.694 .13718 Mdot
.694 .13785 Mdot
.694 .13788 Mdot
.694 .13791 Mdot
.694 .1381 Mdot
.694 .13831 Mdot
.694 .13851 Mdot
.694 .13872 Mdot
.694 .13906 Mdot
.694 .13936 Mdot
.694 .13952 Mdot
.694 .13962 Mdot
.694 .13969 Mdot
.694 .14 Mdot
.694 .14015 Mdot
.694 .14037 Mdot
.694 .14179 Mdot
.694 .14185 Mdot
.694 .14191 Mdot
.694 .14205 Mdot
.694 .14226 Mdot
.694 .14252 Mdot
.694 .14263 Mdot
.694 .14268 Mdot
.694 .14308 Mdot
.694 .14324 Mdot
.694 .14351 Mdot
.694 .14357 Mdot
.694 .1439 Mdot
.694 .14393 Mdot
.694 .14487 Mdot
.694 .14498 Mdot
.694 .14531 Mdot
.694 .14546 Mdot
.694 .14589 Mdot
.694 .14612 Mdot
.694 .14703 Mdot
.694 .14738 Mdot
.694 .14777 Mdot
.694 .14791 Mdot
.694 .14801 Mdot
.694 .14803 Mdot
.694 .14816 Mdot
.694 .1483 Mdot
.694 .14906 Mdot
.694 .1492 Mdot
.694 .14952 Mdot
.694 .14996 Mdot
.694 .15012 Mdot
.694 .15097 Mdot
.694 .15104 Mdot
.694 .15114 Mdot
.694 .15137 Mdot
.694 .15175 Mdot
.694 .1523 Mdot
.694 .1526 Mdot
.694 .15279 Mdot
.694 .153 Mdot
.694 .15333 Mdot
.694 .15373 Mdot
.694 .1538 Mdot
.694 .15383 Mdot
.694 .15388 Mdot
.694 .15436 Mdot
.694 .15471 Mdot
.694 .15526 Mdot
.694 .15543 Mdot
.694 .15549 Mdot
.694 .15562 Mdot
.694 .15593 Mdot
.694 .15634 Mdot
.694 .15641 Mdot
.694 .15665 Mdot
.694 .15671 Mdot
.694 .15692 Mdot
.694 .15702 Mdot
.694 .15717 Mdot
.694 .15745 Mdot
.694 .1576 Mdot
.694 .15779 Mdot
.694 .15784 Mdot
.694 .15859 Mdot
.694 .15894 Mdot
.694 .15915 Mdot
.694 .15992 Mdot
.694 .1601 Mdot
.694 .16069 Mdot
.694 .16124 Mdot
.694 .16161 Mdot
.694 .16173 Mdot
.694 .162 Mdot
.694 .16205 Mdot
.694 .16221 Mdot
.694 .16274 Mdot
.694 .16277 Mdot
.694 .16325 Mdot
.694 .16353 Mdot
.694 .16363 Mdot
.694 .16441 Mdot
.694 .16446 Mdot
.694 .16517 Mdot
.694 .16628 Mdot
.694 .16687 Mdot
.694 .1671 Mdot
.694 .16903 Mdot
.694 .16913 Mdot
.694 .16938 Mdot
.694 .16991 Mdot
.694 .16999 Mdot
.694 .17013 Mdot
.694 .17015 Mdot
.694 .17029 Mdot
.694 .17096 Mdot
.694 .17241 Mdot
.694 .17255 Mdot
.694 .17271 Mdot
.694 .17305 Mdot
.694 .17326 Mdot
.694 .17349 Mdot
.694 .17444 Mdot
.694 .17467 Mdot
.694 .17502 Mdot
.694 .17518 Mdot
.694 .17527 Mdot
.694 .17544 Mdot
.694 .17628 Mdot
.694 .17644 Mdot
.694 .17659 Mdot
.694 .17706 Mdot
.694 .17715 Mdot
.694 .1773 Mdot
.694 .17764 Mdot
.694 .1782 Mdot
.694 .17822 Mdot
.694 .1785 Mdot
.694 .17858 Mdot
.694 .17894 Mdot
.694 .17911 Mdot
.694 .17925 Mdot
.694 .1797 Mdot
.694 .18039 Mdot
.694 .1806 Mdot
.694 .18102 Mdot
.694 .18107 Mdot
.694 .18117 Mdot
.694 .18213 Mdot
.694 .18269 Mdot
.694 .18316 Mdot
.694 .18415 Mdot
.694 .18429 Mdot
.694 .1847 Mdot
.694 .18562 Mdot
.694 .18567 Mdot
.694 .18571 Mdot
.694 .18597 Mdot
.694 .18626 Mdot
.694 .18654 Mdot
.694 .18684 Mdot
.694 .1873 Mdot
.694 .18772 Mdot
.694 .18794 Mdot
.694 .18808 Mdot
.694 .18818 Mdot
.694 .18861 Mdot
.694 .18882 Mdot
.694 .18913 Mdot
.694 .1911 Mdot
.694 .19118 Mdot
.694 .19127 Mdot
.694 .19146 Mdot
.694 .19175 Mdot
.694 .19211 Mdot
.694 .19226 Mdot
.694 .19233 Mdot
.694 .19288 Mdot
.694 .19311 Mdot
.694 .19348 Mdot
.694 .19357 Mdot
.694 .19402 Mdot
.694 .19407 Mdot
.694 .19537 Mdot
.694 .19552 Mdot
.694 .19597 Mdot
.694 .19619 Mdot
.694 .19679 Mdot
.694 .1971 Mdot
.694 .19836 Mdot
.694 .19886 Mdot
.694 .19939 Mdot
.694 .19959 Mdot
.694 .19972 Mdot
.694 .19975 Mdot
.694 .19993 Mdot
.694 .20013 Mdot
.694 .20119 Mdot
.694 .20138 Mdot
.694 .20182 Mdot
.694 .20243 Mdot
.694 .20266 Mdot
.694 .20384 Mdot
.694 .20394 Mdot
.694 .20408 Mdot
.694 .20439 Mdot
.694 .20492 Mdot
.694 .20569 Mdot
.694 .20611 Mdot
.694 .20637 Mdot
.694 .20665 Mdot
.694 .20711 Mdot
.694 .20767 Mdot
.694 .20777 Mdot
.694 .2078 Mdot
.694 .20788 Mdot
.694 .20854 Mdot
.694 .20903 Mdot
.694 .2098 Mdot
.694 .21003 Mdot
.694 .21011 Mdot
.694 .21029 Mdot
.694 .21072 Mdot
.694 .21129 Mdot
.694 .21138 Mdot
.694 .21172 Mdot
.694 .21181 Mdot
.694 .21209 Mdot
.694 .21224 Mdot
.694 .21244 Mdot
.694 .21283 Mdot
.694 .21304 Mdot
.694 .2133 Mdot
.694 .21337 Mdot
.694 .21441 Mdot
.694 .2149 Mdot
.694 .21518 Mdot
.694 .21626 Mdot
.694 .21651 Mdot
.694 .21733 Mdot
.694 .21809 Mdot
.694 .2186 Mdot
.694 .21877 Mdot
.694 .21915 Mdot
.694 .21921 Mdot
.694 .21944 Mdot
.694 .22018 Mdot
.694 .22022 Mdot
.694 .22089 Mdot
.694 .22127 Mdot
.694 .22141 Mdot
.694 .22249 Mdot
.694 .22256 Mdot
.694 .22355 Mdot
.694 .22509 Mdot
.694 .2259 Mdot
.694 .22623 Mdot
.694 .2289 Mdot
.694 .22904 Mdot
.694 .22939 Mdot
.694 .23013 Mdot
.694 .23024 Mdot
.694 .23043 Mdot
.694 .23046 Mdot
.694 .23065 Mdot
.694 .23159 Mdot
.694 .2336 Mdot
.694 .23379 Mdot
.694 .23401 Mdot
.694 .23448 Mdot
.694 .23478 Mdot
.694 .23509 Mdot
.694 .23642 Mdot
.694 .23673 Mdot
.694 .23722 Mdot
.694 .23744 Mdot
.694 .23757 Mdot
.694 .2378 Mdot
.694 .23897 Mdot
.694 .23919 Mdot
.694 .2394 Mdot
.694 .24005 Mdot
.694 .24017 Mdot
.694 .24038 Mdot
.694 .24086 Mdot
.694 .24164 Mdot
.694 .24165 Mdot
.694 .24205 Mdot
.694 .24216 Mdot
.694 .24266 Mdot
.694 .2429 Mdot
.694 .2431 Mdot
.694 .24372 Mdot
.694 .24467 Mdot
.694 .24496 Mdot
.694 .24555 Mdot
.694 .24562 Mdot
.694 .24575 Mdot
.694 .24708 Mdot
.694 .24786 Mdot
.694 .24851 Mdot
.694 .24988 Mdot
.694 .25008 Mdot
.694 .25066 Mdot
.694 .25194 Mdot
.694 .252 Mdot
.694 .25206 Mdot
.694 .25242 Mdot
.694 .25282 Mdot
.694 .25321 Mdot
.694 .25362 Mdot
.694 .25427 Mdot
.694 .25485 Mdot
.694 .25515 Mdot
.694 .25534 Mdot
.694 .25548 Mdot
.694 .25608 Mdot
.694 .25637 Mdot
.694 .2568 Mdot
.694 .25953 Mdot
.694 .25965 Mdot
.694 .25977 Mdot
.694 .26003 Mdot
.694 .26044 Mdot
.694 .26093 Mdot
.694 .26115 Mdot
.694 .26124 Mdot
.694 .26201 Mdot
.694 .26233 Mdot
.694 .26284 Mdot
.694 .26297 Mdot
.694 .26359 Mdot
.694 .26365 Mdot
.694 .26546 Mdot
.694 .26567 Mdot
.694 .2663 Mdot
.694 .2666 Mdot
.694 .26744 Mdot
.694 .26786 Mdot
.694 .26962 Mdot
.694 .27031 Mdot
.694 .27105 Mdot
.694 .27131 Mdot
.694 .27151 Mdot
.694 .27155 Mdot
.694 .27179 Mdot
.694 .27207 Mdot
.694 .27354 Mdot
.694 .2738 Mdot
.694 .27441 Mdot
.694 .27526 Mdot
.694 .27558 Mdot
.694 .27722 Mdot
.694 .27736 Mdot
.694 .27755 Mdot
.694 .27798 Mdot
.694 .27872 Mdot
.694 .27978 Mdot
.694 .28036 Mdot
.694 .28073 Mdot
.694 .28112 Mdot
.694 .28175 Mdot
.694 .28254 Mdot
.694 .28267 Mdot
.694 .28272 Mdot
.694 .28282 Mdot
.694 .28374 Mdot
.694 .28442 Mdot
.694 .28549 Mdot
.694 .28581 Mdot
.694 .28592 Mdot
.694 .28617 Mdot
.694 .28677 Mdot
.694 .28756 Mdot
.694 .28769 Mdot
.694 .28816 Mdot
.694 .28828 Mdot
.694 .28867 Mdot
.694 .28888 Mdot
.694 .28916 Mdot
.694 .2897 Mdot
.694 .28999 Mdot
.694 .29035 Mdot
.694 .29044 Mdot
.694 .29189 Mdot
.694 .29257 Mdot
.694 .29297 Mdot
.694 .29446 Mdot
.694 .29481 Mdot
.694 .29595 Mdot
.694 .29701 Mdot
.694 .29771 Mdot
.694 .29794 Mdot
.694 .29847 Mdot
.694 .29856 Mdot
.694 .29887 Mdot
.694 .2999 Mdot
.694 .29995 Mdot
.694 .30088 Mdot
.694 .30142 Mdot
.694 .30161 Mdot
.694 .30311 Mdot
.694 .30321 Mdot
.694 .30458 Mdot
.694 .30672 Mdot
.694 .30784 Mdot
.694 .3083 Mdot
.694 .31201 Mdot
.694 .3122 Mdot
.694 .31268 Mdot
.694 .31371 Mdot
.694 .31386 Mdot
.694 .31413 Mdot
.694 .31417 Mdot
.694 .31444 Mdot
.694 .31573 Mdot
.694 .31852 Mdot
.694 .31879 Mdot
.694 .31909 Mdot
.694 .31975 Mdot
.694 .32016 Mdot
.694 .3206 Mdot
.694 .32244 Mdot
.694 .32287 Mdot
.694 .32355 Mdot
.694 .32386 Mdot
.694 .32404 Mdot
.694 .32436 Mdot
.694 .32598 Mdot
.694 .32629 Mdot
.694 .32657 Mdot
.694 .32748 Mdot
.694 .32765 Mdot
.694 .32794 Mdot
.694 .3286 Mdot
.694 .32968 Mdot
.694 .32971 Mdot
.694 .33025 Mdot
.694 .3304 Mdot
.694 .3311 Mdot
.694 .33144 Mdot
.694 .33171 Mdot
.694 .33257 Mdot
.694 .33389 Mdot
.694 .3343 Mdot
.694 .33511 Mdot
.694 .3352 Mdot
.694 .3354 Mdot
.694 .33724 Mdot
.694 .33832 Mdot
.694 .33923 Mdot
.694 .34113 Mdot
.694 .3414 Mdot
.694 .3422 Mdot
.694 .34398 Mdot
.694 .34407 Mdot
.694 .34415 Mdot
.694 .34465 Mdot
.694 .3452 Mdot
.694 .34574 Mdot
.694 .34631 Mdot
.694 .34721 Mdot
.694 .34802 Mdot
.694 .34844 Mdot
.694 .34871 Mdot
.694 .34889 Mdot
.694 .34973 Mdot
.694 .35014 Mdot
.694 .35073 Mdot
.694 .35452 Mdot
.694 .35469 Mdot
.694 .35485 Mdot
.694 .35522 Mdot
.694 .35578 Mdot
.694 .35647 Mdot
.694 .35677 Mdot
.694 .3569 Mdot
.694 .35796 Mdot
.694 .3584 Mdot
.694 .35911 Mdot
.694 .35929 Mdot
.694 .36015 Mdot
.694 .36024 Mdot
.694 .36275 Mdot
.694 .36304 Mdot
.694 .36392 Mdot
.694 .36433 Mdot
.694 .36549 Mdot
.694 .36609 Mdot
.694 .36852 Mdot
.694 .36948 Mdot
.694 .3705 Mdot
.694 .37088 Mdot
.694 .37114 Mdot
.694 .3712 Mdot
.694 .37154 Mdot
.694 .37193 Mdot
.694 .37397 Mdot
.694 .37433 Mdot
.694 .37518 Mdot
.694 .37636 Mdot
.694 .37679 Mdot
.694 .37907 Mdot
.694 .37926 Mdot
.694 .37953 Mdot
.694 .38013 Mdot
.694 .38116 Mdot
.694 .38263 Mdot
.694 .38344 Mdot
.694 .38394 Mdot
.694 .38448 Mdot
.694 .38536 Mdot
.694 .38645 Mdot
.694 .38664 Mdot
.694 .38671 Mdot
.694 .38685 Mdot
.694 .38812 Mdot
.694 .38907 Mdot
.694 .39055 Mdot
.694 .39099 Mdot
.694 .39115 Mdot
.694 .3915 Mdot
.694 .39232 Mdot
.694 .39342 Mdot
.694 .39361 Mdot
.694 .39426 Mdot
.694 .39442 Mdot
.694 .39496 Mdot
.694 .39526 Mdot
.694 .39564 Mdot
.694 .39639 Mdot
.694 .3968 Mdot
.694 .39729 Mdot
.694 .39944 Mdot
.694 .40038 Mdot
.694 .40093 Mdot
.694 .40299 Mdot
.694 .40349 Mdot
.694 .40507 Mdot
.694 .40653 Mdot
.694 .40751 Mdot
.694 .40783 Mdot
.694 .40856 Mdot
.694 .40869 Mdot
.694 .40913 Mdot
.694 .41055 Mdot
.694 .41062 Mdot
.694 .41191 Mdot
.694 .41266 Mdot
.694 .41292 Mdot
.694 .41501 Mdot
.694 .41514 Mdot
.694 .41705 Mdot
.694 .42002 Mdot
.694 .42157 Mdot
.694 .42221 Mdot
.696 .01537 Mdot
.696 .01563 Mdot
.696 .01598 Mdot
.696 .01624 Mdot
.696 .01648 Mdot
.696 .01683 Mdot
.696 .01717 Mdot
.696 .01767 Mdot
.696 .01774 Mdot
.696 .01814 Mdot
.696 .01882 Mdot
.696 .01892 Mdot
.696 .01928 Mdot
.696 .01948 Mdot
.696 .02043 Mdot
.696 .02057 Mdot
.696 .02107 Mdot
.696 .02134 Mdot
.696 .02147 Mdot
.696 .02156 Mdot
.696 .02245 Mdot
.696 .02262 Mdot
.696 .02267 Mdot
.696 .02287 Mdot
.696 .02356 Mdot
.696 .02394 Mdot
.696 .02411 Mdot
.696 .02425 Mdot
.696 .02425 Mdot
.696 .02428 Mdot
.696 .02435 Mdot
.696 .02476 Mdot
.696 .02539 Mdot
.696 .02549 Mdot
.696 .02572 Mdot
.696 .02579 Mdot
.696 .02606 Mdot
.696 .02703 Mdot
.696 .02703 Mdot
.696 .02756 Mdot
.696 .02779 Mdot
.696 .02798 Mdot
.696 .02798 Mdot
.696 .02803 Mdot
.696 .02813 Mdot
.696 .0287 Mdot
.696 .02876 Mdot
.696 .0291 Mdot
.696 .02945 Mdot
.696 .02957 Mdot
.696 .02971 Mdot
.696 .03003 Mdot
.696 .03013 Mdot
.696 .03051 Mdot
.696 .03059 Mdot
.696 .03185 Mdot
.696 .03186 Mdot
.696 .03235 Mdot
.696 .03259 Mdot
.696 .03292 Mdot
.696 .03292 Mdot
.696 .03315 Mdot
.696 .03318 Mdot
.696 .03318 Mdot
.696 .03325 Mdot
.696 .03339 Mdot
.696 .03418 Mdot
.696 .03426 Mdot
.696 .03459 Mdot
.696 .03474 Mdot
.696 .03488 Mdot
.696 .0351 Mdot
.696 .03522 Mdot
.696 .03535 Mdot
.696 .03539 Mdot
.696 .03559 Mdot
.696 .03603 Mdot
.696 .03618 Mdot
.696 .03623 Mdot
.696 .03663 Mdot
.696 .0367 Mdot
.696 .03681 Mdot
.696 .03745 Mdot
.696 .03857 Mdot
.696 .03858 Mdot
.696 .03926 Mdot
.696 .0396 Mdot
.696 .04005 Mdot
.696 .04006 Mdot
.696 .04038 Mdot
.696 .04042 Mdot
.696 .04042 Mdot
.696 .04051 Mdot
.696 .04071 Mdot
.696 .04181 Mdot
.696 .04192 Mdot
.696 .04238 Mdot
.696 .04259 Mdot
.696 .04279 Mdot
.696 .04309 Mdot
.696 .04326 Mdot
.696 .04344 Mdot
.696 .0435 Mdot
.696 .04377 Mdot
.696 .04439 Mdot
.696 .04446 Mdot
.696 .04459 Mdot
.696 .04467 Mdot
.696 .04516 Mdot
.696 .04522 Mdot
.696 .04532 Mdot
.696 .04547 Mdot
.696 .04607 Mdot
.696 .04637 Mdot
.696 .04694 Mdot
.696 .04792 Mdot
.696 .04793 Mdot
.696 .04859 Mdot
.696 .04888 Mdot
.696 .04933 Mdot
.696 .04935 Mdot
.696 .04978 Mdot
.696 .04998 Mdot
.696 .04999 Mdot
.696 .05029 Mdot
.696 .05044 Mdot
.696 .0505 Mdot
.696 .0505 Mdot
.696 .05062 Mdot
.696 .0509 Mdot
.696 .05112 Mdot
.696 .05148 Mdot
.696 .05243 Mdot
.696 .05259 Mdot
.696 .05323 Mdot
.696 .05341 Mdot
.696 .05352 Mdot
.696 .0538 Mdot
.696 .05396 Mdot
.696 .05422 Mdot
.696 .05445 Mdot
.696 .0547 Mdot
.696 .05478 Mdot
.696 .055 Mdot
.696 .05516 Mdot
.696 .05602 Mdot
.696 .05612 Mdot
.696 .0563 Mdot
.696 .05641 Mdot
.696 .0571 Mdot
.696 .05718 Mdot
.696 .05732 Mdot
.696 .05737 Mdot
.696 .05752 Mdot
.696 .05837 Mdot
.696 .05878 Mdot
.696 .05882 Mdot
.696 .05957 Mdot
.696 .06094 Mdot
.696 .06095 Mdot
.696 .06186 Mdot
.696 .06219 Mdot
.696 .06227 Mdot
.696 .0629 Mdot
.696 .06293 Mdot
.696 .06341 Mdot
.696 .06352 Mdot
.696 .06381 Mdot
.696 .06382 Mdot
.696 .06423 Mdot
.696 .06445 Mdot
.696 .06452 Mdot
.696 .06453 Mdot
.696 .0647 Mdot
.696 .06478 Mdot
.696 .06509 Mdot
.696 .06539 Mdot
.696 .0659 Mdot
.696 .06595 Mdot
.696 .06722 Mdot
.696 .06743 Mdot
.696 .06833 Mdot
.696 .06858 Mdot
.696 .06873 Mdot
.696 .06911 Mdot
.696 .06934 Mdot
.696 .0697 Mdot
.696 .06996 Mdot
.696 .07002 Mdot
.696 .07037 Mdot
.696 .07048 Mdot
.696 .07079 Mdot
.696 .07101 Mdot
.696 .07126 Mdot
.696 .07138 Mdot
.696 .07222 Mdot
.696 .07235 Mdot
.696 .0726 Mdot
.696 .0726 Mdot
.696 .07262 Mdot
.696 .07276 Mdot
.696 .07371 Mdot
.696 .07382 Mdot
.696 .07402 Mdot
.696 .07409 Mdot
.696 .0743 Mdot
.696 .07548 Mdot
.696 .0756 Mdot
.696 .07572 Mdot
.696 .07605 Mdot
.696 .07611 Mdot
.696 .07715 Mdot
.696 .07888 Mdot
.696 .07906 Mdot
.696 .07908 Mdot
.696 .08035 Mdot
.696 .08061 Mdot
.696 .0808 Mdot
.696 .08091 Mdot
.696 .08179 Mdot
.696 .08183 Mdot
.696 .08185 Mdot
.696 .08248 Mdot
.696 .08249 Mdot
.696 .08266 Mdot
.696 .08305 Mdot
.696 .08307 Mdot
.696 .08364 Mdot
.696 .08388 Mdot
.696 .08394 Mdot
.696 .08405 Mdot
.696 .08406 Mdot
.696 .08411 Mdot
.696 .08429 Mdot
.696 .08441 Mdot
.696 .08463 Mdot
.696 .08471 Mdot
.696 .08484 Mdot
.696 .08526 Mdot
.696 .08596 Mdot
.696 .08603 Mdot
.696 .08665 Mdot
.696 .0878 Mdot
.696 .0881 Mdot
.696 .08819 Mdot
.696 .08859 Mdot
.696 .08899 Mdot
.696 .08935 Mdot
.696 .08939 Mdot
.696 .08969 Mdot
.696 .0899 Mdot
.696 .09044 Mdot
.696 .0907 Mdot
.696 .09075 Mdot
.696 .0911 Mdot
.696 .09125 Mdot
.696 .09136 Mdot
.696 .09155 Mdot
.696 .09162 Mdot
.696 .0917 Mdot
.696 .09218 Mdot
.696 .09234 Mdot
.696 .09278 Mdot
.696 .09289 Mdot
.696 .09307 Mdot
.696 .09342 Mdot
.696 .09359 Mdot
.696 .09476 Mdot
.696 .09495 Mdot
.696 .09529 Mdot
.696 .0953 Mdot
.696 .09531 Mdot
.696 .09551 Mdot
.696 .09615 Mdot
.696 .09622 Mdot
.696 .09629 Mdot
.696 .09684 Mdot
.696 .09695 Mdot
.696 .097 Mdot
.696 .09727 Mdot
.696 .09733 Mdot
.696 .09737 Mdot
.696 .09742 Mdot
.696 .09759 Mdot
.696 .09766 Mdot
.696 .09929 Mdot
.696 .09947 Mdot
.696 .09963 Mdot
.696 .10009 Mdot
.696 .10018 Mdot
.696 .10027 Mdot
.696 .10043 Mdot
.696 .10163 Mdot
.696 .10191 Mdot
.696 .10278 Mdot
.696 .10404 Mdot
.696 .10429 Mdot
.696 .10431 Mdot
.696 .10454 Mdot
.696 .10512 Mdot
.696 .10575 Mdot
.696 .10608 Mdot
.696 .10631 Mdot
.696 .10643 Mdot
.696 .1067 Mdot
.696 .10675 Mdot
.696 .10686 Mdot
.696 .10753 Mdot
.696 .1076 Mdot
.696 .10801 Mdot
.696 .10808 Mdot
.696 .10813 Mdot
.696 .10817 Mdot
.696 .10843 Mdot
.696 .10905 Mdot
.696 .10906 Mdot
.696 .10927 Mdot
.696 .10929 Mdot
.696 .10984 Mdot
.696 .10987 Mdot
.696 .11015 Mdot
.696 .11032 Mdot
.696 .11066 Mdot
.696 .11099 Mdot
.696 .11108 Mdot
.696 .11123 Mdot
.696 .11124 Mdot
.696 .11132 Mdot
.696 .1114 Mdot
.696 .11156 Mdot
.696 .11173 Mdot
.696 .11176 Mdot
.696 .11204 Mdot
.696 .11215 Mdot
.696 .11233 Mdot
.696 .11234 Mdot
.696 .11291 Mdot
.696 .11328 Mdot
.696 .11335 Mdot
.696 .11388 Mdot
.696 .11399 Mdot
.696 .11419 Mdot
.696 .11485 Mdot
.696 .11596 Mdot
.696 .11632 Mdot
.696 .11644 Mdot
.696 .11686 Mdot
.696 .11699 Mdot
.696 .11705 Mdot
.696 .11755 Mdot
.696 .11811 Mdot
.696 .11825 Mdot
.696 .1186 Mdot
.696 .11863 Mdot
.696 .11867 Mdot
.696 .11908 Mdot
.696 .11937 Mdot
.696 .12012 Mdot
.696 .12049 Mdot
.696 .12056 Mdot
.696 .12104 Mdot
.696 .12126 Mdot
.696 .1214 Mdot
.696 .12142 Mdot
.696 .12166 Mdot
.696 .12177 Mdot
.696 .12188 Mdot
.696 .12197 Mdot
.696 .12255 Mdot
.696 .12277 Mdot
.696 .12299 Mdot
.696 .12338 Mdot
.696 .12354 Mdot
.696 .12379 Mdot
.696 .12428 Mdot
.696 .12451 Mdot
.696 .12614 Mdot
.696 .12616 Mdot
.696 .1264 Mdot
.696 .12644 Mdot
.696 .12688 Mdot
.696 .12689 Mdot
.696 .12691 Mdot
.696 .12718 Mdot
.696 .12808 Mdot
.696 .12817 Mdot
.696 .12826 Mdot
.696 .12904 Mdot
.696 .12919 Mdot
.696 .12925 Mdot
.696 .12963 Mdot
.696 .12971 Mdot
.696 .12977 Mdot
.696 .12983 Mdot
.696 .13007 Mdot
.696 .13018 Mdot
.696 .13226 Mdot
.696 .13245 Mdot
.696 .13269 Mdot
.696 .13292 Mdot
.696 .13336 Mdot
.696 .13356 Mdot
.696 .13368 Mdot
.696 .13381 Mdot
.696 .13404 Mdot
.696 .13413 Mdot
.696 .13465 Mdot
.696 .13479 Mdot
.696 .13507 Mdot
.696 .1357 Mdot
.696 .13609 Mdot
.696 .13698 Mdot
.696 .13731 Mdot
.696 .13767 Mdot
.696 .13799 Mdot
.696 .13905 Mdot
.696 .1394 Mdot
.696 .13943 Mdot
.696 .13976 Mdot
.696 .13976 Mdot
.696 .14056 Mdot
.696 .14059 Mdot
.696 .14143 Mdot
.696 .14189 Mdot
.696 .14222 Mdot
.696 .14239 Mdot
.696 .14276 Mdot
.696 .14282 Mdot
.696 .14296 Mdot
.696 .14298 Mdot
.696 .1435 Mdot
.696 .14391 Mdot
.696 .14402 Mdot
.696 .14412 Mdot
.696 .14423 Mdot
.696 .14458 Mdot
.696 .14468 Mdot
.696 .14475 Mdot
.696 .1448 Mdot
.696 .14516 Mdot
.696 .14603 Mdot
.696 .14605 Mdot
.696 .14607 Mdot
.696 .14624 Mdot
.696 .14634 Mdot
.696 .14637 Mdot
.696 .14641 Mdot
.696 .14713 Mdot
.696 .14717 Mdot
.696 .14756 Mdot
.696 .1478 Mdot
.696 .14826 Mdot
.696 .14842 Mdot
.696 .14858 Mdot
.696 .14874 Mdot
.696 .14885 Mdot
.696 .14906 Mdot
.696 .14908 Mdot
.696 .14919 Mdot
.696 .1493 Mdot
.696 .14952 Mdot
.696 .14976 Mdot
.696 .1498 Mdot
.696 .15009 Mdot
.696 .15019 Mdot
.696 .15034 Mdot
.696 .15059 Mdot
.696 .15061 Mdot
.696 .15083 Mdot
.696 .1513 Mdot
.696 .1514 Mdot
.696 .1516 Mdot
.696 .15191 Mdot
.696 .15202 Mdot
.696 .15276 Mdot
.696 .15291 Mdot
.696 .15318 Mdot
.696 .15402 Mdot
.696 .1541 Mdot
.696 .15565 Mdot
.696 .15594 Mdot
.696 .15615 Mdot
.696 .15628 Mdot
.696 .15632 Mdot
.696 .15639 Mdot
.696 .1569 Mdot
.696 .15709 Mdot
.696 .15717 Mdot
.696 .15764 Mdot
.696 .15786 Mdot
.696 .1585 Mdot
.696 .15864 Mdot
.696 .15881 Mdot
.696 .15883 Mdot
.696 .15932 Mdot
.696 .15937 Mdot
.696 .15942 Mdot
.696 .15995 Mdot
.696 .15999 Mdot
.696 .1604 Mdot
.696 .16059 Mdot
.696 .16072 Mdot
.696 .1608 Mdot
.696 .16144 Mdot
.696 .16195 Mdot
.696 .16204 Mdot
.696 .16207 Mdot
.696 .16241 Mdot
.696 .16263 Mdot
.696 .16272 Mdot
.696 .16302 Mdot
.696 .16319 Mdot
.696 .16323 Mdot
.696 .16325 Mdot
.696 .16359 Mdot
.696 .16368 Mdot
.696 .16374 Mdot
.696 .16389 Mdot
.696 .16401 Mdot
.696 .16482 Mdot
.696 .16513 Mdot
.696 .16543 Mdot
.696 .16597 Mdot
.696 .1662 Mdot
.696 .16655 Mdot
.696 .16672 Mdot
.696 .16723 Mdot
.696 .16755 Mdot
.696 .16788 Mdot
.696 .169 Mdot
.696 .16981 Mdot
.696 .16985 Mdot
.696 .17018 Mdot
.696 .17024 Mdot
.696 .17085 Mdot
.696 .17086 Mdot
.696 .17089 Mdot
.696 .17104 Mdot
.696 .17127 Mdot
.696 .17188 Mdot
.696 .17252 Mdot
.696 .17265 Mdot
.696 .17277 Mdot
.696 .1732 Mdot
.696 .17385 Mdot
.696 .17406 Mdot
.696 .17415 Mdot
.696 .17468 Mdot
.696 .17479 Mdot
.696 .17487 Mdot
.696 .17496 Mdot
.696 .17529 Mdot
.696 .17544 Mdot
.696 .17574 Mdot
.696 .17834 Mdot
.696 .1786 Mdot
.696 .17894 Mdot
.696 .17926 Mdot
.696 .17987 Mdot
.696 .18015 Mdot
.696 .18031 Mdot
.696 .1805 Mdot
.696 .18081 Mdot
.696 .18094 Mdot
.696 .18166 Mdot
.696 .18186 Mdot
.696 .18225 Mdot
.696 .18313 Mdot
.696 .18366 Mdot
.696 .18491 Mdot
.696 .18536 Mdot
.696 .18587 Mdot
.696 .18631 Mdot
.696 .1878 Mdot
.696 .18828 Mdot
.696 .18832 Mdot
.696 .18877 Mdot
.696 .18878 Mdot
.696 .18989 Mdot
.696 .18993 Mdot
.696 .1911 Mdot
.696 .19174 Mdot
.696 .1922 Mdot
.696 .19244 Mdot
.696 .19296 Mdot
.696 .19304 Mdot
.696 .19323 Mdot
.696 .19326 Mdot
.696 .19398 Mdot
.696 .19455 Mdot
.696 .1947 Mdot
.696 .19485 Mdot
.696 .195 Mdot
.696 .19548 Mdot
.696 .19563 Mdot
.696 .19573 Mdot
.696 .1958 Mdot
.696 .1963 Mdot
.696 .19751 Mdot
.696 .19753 Mdot
.696 .19755 Mdot
.696 .1978 Mdot
.696 .19794 Mdot
.696 .19797 Mdot
.696 .19804 Mdot
.696 .19903 Mdot
.696 .19909 Mdot
.696 .19964 Mdot
.696 .19996 Mdot
.696 .20062 Mdot
.696 .20083 Mdot
.696 .20106 Mdot
.696 .20127 Mdot
.696 .20143 Mdot
.696 .20172 Mdot
.696 .20175 Mdot
.696 .2019 Mdot
.696 .20206 Mdot
.696 .20237 Mdot
.696 .20269 Mdot
.696 .20276 Mdot
.696 .20316 Mdot
.696 .20329 Mdot
.696 .20351 Mdot
.696 .20385 Mdot
.696 .20388 Mdot
.696 .20419 Mdot
.696 .20485 Mdot
.696 .20498 Mdot
.696 .20525 Mdot
.696 .2057 Mdot
.696 .20584 Mdot
.696 .20687 Mdot
.696 .20708 Mdot
.696 .20745 Mdot
.696 .20863 Mdot
.696 .20874 Mdot
.696 .21089 Mdot
.696 .2113 Mdot
.696 .21159 Mdot
.696 .21178 Mdot
.696 .21183 Mdot
.696 .21193 Mdot
.696 .21264 Mdot
.696 .2129 Mdot
.696 .21301 Mdot
.696 .21367 Mdot
.696 .21398 Mdot
.696 .21486 Mdot
.696 .21506 Mdot
.696 .21529 Mdot
.696 .21533 Mdot
.696 .21601 Mdot
.696 .21608 Mdot
.696 .21614 Mdot
.696 .21688 Mdot
.696 .21694 Mdot
.696 .2175 Mdot
.696 .21778 Mdot
.696 .21795 Mdot
.696 .21806 Mdot
.696 .21896 Mdot
.696 .21967 Mdot
.696 .2198 Mdot
.696 .21984 Mdot
.696 .2203 Mdot
.696 .22062 Mdot
.696 .22073 Mdot
.696 .22116 Mdot
.696 .2214 Mdot
.696 .22144 Mdot
.696 .22147 Mdot
.696 .22195 Mdot
.696 .22207 Mdot
.696 .22215 Mdot
.696 .22236 Mdot
.696 .22254 Mdot
.696 .22367 Mdot
.696 .2241 Mdot
.696 .22451 Mdot
.696 .22527 Mdot
.696 .22558 Mdot
.696 .22607 Mdot
.696 .2263 Mdot
.696 .22701 Mdot
.696 .22747 Mdot
.696 .22792 Mdot
.696 .22949 Mdot
.696 .23061 Mdot
.696 .23066 Mdot
.696 .23112 Mdot
.696 .23121 Mdot
.696 .23205 Mdot
.696 .23207 Mdot
.696 .2321 Mdot
.696 .23231 Mdot
.696 .23264 Mdot
.696 .23348 Mdot
.696 .23438 Mdot
.696 .23455 Mdot
.696 .23473 Mdot
.696 .23532 Mdot
.696 .23623 Mdot
.696 .23652 Mdot
.696 .23665 Mdot
.696 .23739 Mdot
.696 .23754 Mdot
.696 .23765 Mdot
.696 .23778 Mdot
.696 .23824 Mdot
.696 .23844 Mdot
.696 .23887 Mdot
.696 .24248 Mdot
.696 .24284 Mdot
.696 .24331 Mdot
.696 .24376 Mdot
.696 .24461 Mdot
.696 .24499 Mdot
.696 .24523 Mdot
.696 .24549 Mdot
.696 .24592 Mdot
.696 .2461 Mdot
.696 .2471 Mdot
.696 .24738 Mdot
.696 .24792 Mdot
.696 .24914 Mdot
.696 .24989 Mdot
.696 .25163 Mdot
.696 .25226 Mdot
.696 .25297 Mdot
.696 .25357 Mdot
.696 .25564 Mdot
.696 .25631 Mdot
.696 .25637 Mdot
.696 .257 Mdot
.696 .25701 Mdot
.696 .25855 Mdot
.696 .25861 Mdot
.696 .26025 Mdot
.696 .26113 Mdot
.696 .26178 Mdot
.696 .2621 Mdot
.696 .26283 Mdot
.696 .26295 Mdot
.696 .26321 Mdot
.696 .26325 Mdot
.696 .26425 Mdot
.696 .26505 Mdot
.696 .26526 Mdot
.696 .26546 Mdot
.696 .26567 Mdot
.696 .26635 Mdot
.696 .26655 Mdot
.696 .26668 Mdot
.696 .26678 Mdot
.696 .26748 Mdot
.696 .26916 Mdot
.696 .26919 Mdot
.696 .26923 Mdot
.696 .26957 Mdot
.696 .26976 Mdot
.696 .26981 Mdot
.696 .2699 Mdot
.696 .27129 Mdot
.696 .27137 Mdot
.696 .27213 Mdot
.696 .27258 Mdot
.696 .27349 Mdot
.696 .27379 Mdot
.696 .27411 Mdot
.696 .2744 Mdot
.696 .27463 Mdot
.696 .27503 Mdot
.696 .27507 Mdot
.696 .27528 Mdot
.696 .27549 Mdot
.696 .27593 Mdot
.696 .27638 Mdot
.696 .27647 Mdot
.696 .27703 Mdot
.696 .27721 Mdot
.696 .27751 Mdot
.696 .278 Mdot
.696 .27803 Mdot
.696 .27846 Mdot
.696 .27938 Mdot
.696 .27956 Mdot
.696 .27995 Mdot
.696 .28056 Mdot
.696 .28076 Mdot
.696 .2822 Mdot
.696 .28248 Mdot
.696 .28301 Mdot
.696 .28465 Mdot
.696 .28479 Mdot
.696 .28779 Mdot
.696 .28836 Mdot
.696 .28876 Mdot
.696 .28902 Mdot
.696 .2891 Mdot
.696 .28924 Mdot
.696 .29023 Mdot
.696 .29059 Mdot
.696 .29075 Mdot
.696 .29166 Mdot
.696 .29209 Mdot
.696 .29332 Mdot
.696 .29359 Mdot
.696 .29391 Mdot
.696 .29397 Mdot
.696 .29492 Mdot
.696 .29501 Mdot
.696 .2951 Mdot
.696 .29613 Mdot
.696 .29622 Mdot
.696 .29699 Mdot
.696 .29738 Mdot
.696 .29762 Mdot
.696 .29777 Mdot
.696 .29902 Mdot
.696 .30001 Mdot
.696 .30019 Mdot
.696 .30025 Mdot
.696 .30089 Mdot
.696 .30133 Mdot
.696 .30149 Mdot
.696 .30208 Mdot
.696 .30242 Mdot
.696 .30248 Mdot
.696 .30252 Mdot
.696 .30318 Mdot
.696 .30335 Mdot
.696 .30347 Mdot
.696 .30376 Mdot
.696 .30401 Mdot
.696 .30558 Mdot
.696 .30617 Mdot
.696 .30676 Mdot
.696 .3078 Mdot
.696 .30824 Mdot
.696 .30892 Mdot
.696 .30924 Mdot
.696 .31023 Mdot
.696 .31087 Mdot
.696 .31149 Mdot
.696 .31368 Mdot
.696 .31525 Mdot
.696 .31532 Mdot
.696 .31595 Mdot
.696 .31607 Mdot
.696 .31724 Mdot
.696 .31727 Mdot
.696 .31732 Mdot
.696 .31761 Mdot
.696 .31806 Mdot
.696 .31924 Mdot
.696 .32048 Mdot
.696 .32073 Mdot
.696 .32098 Mdot
.696 .3218 Mdot
.696 .32306 Mdot
.696 .32347 Mdot
.696 .32364 Mdot
.696 .32468 Mdot
.696 .32489 Mdot
.696 .32504 Mdot
.696 .32522 Mdot
.696 .32586 Mdot
.696 .32614 Mdot
.696 .32673 Mdot
.696 .33177 Mdot
.696 .33227 Mdot
.696 .33292 Mdot
.696 .33355 Mdot
.696 .33473 Mdot
.696 .33526 Mdot
.696 .33559 Mdot
.696 .33595 Mdot
.696 .33655 Mdot
.696 .33681 Mdot
.696 .33819 Mdot
.696 .33859 Mdot
.696 .33934 Mdot
.696 .34104 Mdot
.696 .34208 Mdot
.696 .3445 Mdot
.696 .34538 Mdot
.696 .34636 Mdot
.696 .3472 Mdot
.696 .35009 Mdot
.696 .35102 Mdot
.696 .3511 Mdot
.696 .35198 Mdot
.696 .35199 Mdot
.696 .35414 Mdot
.696 .35422 Mdot
.696 .3565 Mdot
.696 .35773 Mdot
.696 .35863 Mdot
.696 .35908 Mdot
.696 .36008 Mdot
.696 .36025 Mdot
.696 .36062 Mdot
.696 .36068 Mdot
.696 .36207 Mdot
.696 .36318 Mdot
.696 .36347 Mdot
.696 .36376 Mdot
.696 .36404 Mdot
.696 .36498 Mdot
.696 .36527 Mdot
.696 .36546 Mdot
.696 .36559 Mdot
.696 .36656 Mdot
.696 .3689 Mdot
.696 .36895 Mdot
.696 .369 Mdot
.696 .36947 Mdot
.696 .36974 Mdot
.696 .36981 Mdot
.696 .36993 Mdot
.696 .37186 Mdot
.696 .37198 Mdot
.696 .37303 Mdot
.696 .37366 Mdot
.696 .37493 Mdot
.696 .37534 Mdot
.696 .37579 Mdot
.696 .3762 Mdot
.696 .37651 Mdot
.696 .37707 Mdot
.696 .37713 Mdot
.696 .37742 Mdot
.696 .37772 Mdot
.696 .37833 Mdot
.696 .37896 Mdot
.696 .37908 Mdot
.696 .37985 Mdot
.696 .38011 Mdot
.696 .38053 Mdot
.696 .3812 Mdot
.696 .38126 Mdot
.696 .38185 Mdot
.696 .38313 Mdot
.696 .38339 Mdot
.696 .38392 Mdot
.696 .38477 Mdot
.696 .38505 Mdot
.696 .38705 Mdot
.696 .38745 Mdot
.696 .38818 Mdot
.696 .39046 Mdot
.696 .39066 Mdot
.696 .39484 Mdot
.696 .39563 Mdot
.696 .39618 Mdot
.696 .39655 Mdot
.696 .39666 Mdot
.696 .39686 Mdot
.696 .39823 Mdot
.696 .39873 Mdot
.696 .39895 Mdot
.696 .40023 Mdot
.696 .40082 Mdot
.696 .40253 Mdot
.696 .40291 Mdot
.696 .40336 Mdot
.696 .40344 Mdot
.696 .40476 Mdot
.696 .40488 Mdot
.696 .40501 Mdot
.696 .40645 Mdot
.696 .40657 Mdot
.696 .40765 Mdot
.696 .40818 Mdot
.696 .40852 Mdot
.696 .40873 Mdot
.696 .41047 Mdot
.696 .41185 Mdot
.696 .4121 Mdot
.696 .41218 Mdot
.696 .41308 Mdot
.696 .41369 Mdot
.696 .41391 Mdot
.696 .41473 Mdot
.696 .41519 Mdot
.696 .41528 Mdot
.696 .41534 Mdot
.696 .41626 Mdot
.696 .4165 Mdot
.696 .41666 Mdot
.696 .41706 Mdot
.696 .41741 Mdot
.696 .41959 Mdot
.696 .42043 Mdot
.696 .42124 Mdot
.696 .4227 Mdot
.696 .4233 Mdot
.696 .42425 Mdot
.696 .4247 Mdot
.696 .42608 Mdot
.698 .01476 Mdot
.698 .01477 Mdot
.698 .01479 Mdot
.698 .01482 Mdot
.698 .01487 Mdot
.698 .01493 Mdot
.698 .01501 Mdot
.698 .01513 Mdot
.698 .01529 Mdot
.698 .01552 Mdot
.698 .01584 Mdot
.698 .01629 Mdot
.698 .01643 Mdot
.698 .01692 Mdot
.698 .01711 Mdot
.698 .01746 Mdot
.698 .01779 Mdot
.698 .01798 Mdot
.698 .01806 Mdot
.698 .01813 Mdot
.698 .01842 Mdot
.698 .01854 Mdot
.698 .01865 Mdot
.698 .01867 Mdot
.698 .01901 Mdot
.698 .01915 Mdot
.698 .01928 Mdot
.698 .01938 Mdot
.698 .01948 Mdot
.698 .01989 Mdot
.698 .02 Mdot
.698 .02006 Mdot
.698 .02021 Mdot
.698 .02023 Mdot
.698 .02066 Mdot
.698 .0207 Mdot
.698 .02091 Mdot
.698 .02108 Mdot
.698 .02123 Mdot
.698 .02137 Mdot
.698 .02193 Mdot
.698 .0221 Mdot
.698 .02211 Mdot
.698 .02217 Mdot
.698 .02239 Mdot
.698 .02242 Mdot
.698 .02301 Mdot
.698 .02308 Mdot
.698 .02322 Mdot
.698 .02336 Mdot
.698 .0236 Mdot
.698 .02381 Mdot
.698 .02401 Mdot
.698 .02401 Mdot
.698 .02479 Mdot
.698 .02502 Mdot
.698 .02504 Mdot
.698 .02508 Mdot
.698 .02513 Mdot
.698 .02542 Mdot
.698 .02547 Mdot
.698 .0263 Mdot
.698 .02639 Mdot
.698 .02659 Mdot
.698 .0266 Mdot
.698 .02678 Mdot
.698 .02712 Mdot
.698 .02741 Mdot
.698 .02769 Mdot
.698 .02769 Mdot
.698 .02773 Mdot
.698 .02878 Mdot
.698 .0291 Mdot
.698 .02913 Mdot
.698 .02918 Mdot
.698 .02925 Mdot
.698 .02966 Mdot
.698 .02973 Mdot
.698 .03025 Mdot
.698 .03087 Mdot
.698 .03089 Mdot
.698 .03093 Mdot
.698 .03101 Mdot
.698 .03129 Mdot
.698 .0313 Mdot
.698 .03156 Mdot
.698 .03168 Mdot
.698 .03203 Mdot
.698 .03242 Mdot
.698 .03244 Mdot
.698 .03245 Mdot
.698 .03282 Mdot
.698 .03283 Mdot
.698 .03289 Mdot
.698 .03409 Mdot
.698 .03436 Mdot
.698 .0348 Mdot
.698 .03484 Mdot
.698 .03491 Mdot
.698 .03501 Mdot
.698 .03558 Mdot
.698 .03568 Mdot
.698 .03641 Mdot
.698 .03647 Mdot
.698 .03694 Mdot
.698 .03696 Mdot
.698 .03726 Mdot
.698 .03728 Mdot
.698 .03729 Mdot
.698 .03735 Mdot
.698 .03746 Mdot
.698 .03785 Mdot
.698 .03787 Mdot
.698 .03823 Mdot
.698 .0384 Mdot
.698 .03876 Mdot
.698 .03889 Mdot
.698 .03942 Mdot
.698 .03945 Mdot
.698 .03947 Mdot
.698 .03965 Mdot
.698 .03966 Mdot
.698 .03999 Mdot
.698 .04 Mdot
.698 .04007 Mdot
.698 .04008 Mdot
.698 .04177 Mdot
.698 .04213 Mdot
.698 .04251 Mdot
.698 .04258 Mdot
.698 .04275 Mdot
.698 .04281 Mdot
.698 .0429 Mdot
.698 .04305 Mdot
.698 .0437 Mdot
.698 .04385 Mdot
.698 .04398 Mdot
.698 .045 Mdot
.698 .04509 Mdot
.698 .04574 Mdot
.698 .04577 Mdot
.698 .04608 Mdot
.698 .04619 Mdot
.698 .04621 Mdot
.698 .04623 Mdot
.698 .04632 Mdot
.698 .04647 Mdot
.698 .04649 Mdot
.698 .04702 Mdot
.698 .04704 Mdot
.698 .04719 Mdot
.698 .04754 Mdot
.698 .04778 Mdot
.698 .04828 Mdot
.698 .04847 Mdot
.698 .04859 Mdot
.698 .04917 Mdot
.698 .04921 Mdot
.698 .04925 Mdot
.698 .04928 Mdot
.698 .04947 Mdot
.698 .04953 Mdot
.698 .04954 Mdot
.698 .04994 Mdot
.698 .05 Mdot
.698 .05002 Mdot
.698 .05011 Mdot
.698 .05013 Mdot
.698 .05127 Mdot
.698 .05145 Mdot
.698 .0518 Mdot
.698 .05248 Mdot
.698 .05286 Mdot
.698 .05299 Mdot
.698 .05351 Mdot
.698 .05362 Mdot
.698 .05385 Mdot
.698 .05394 Mdot
.698 .05407 Mdot
.698 .05426 Mdot
.698 .05442 Mdot
.698 .05518 Mdot
.698 .05538 Mdot
.698 .05556 Mdot
.698 .05592 Mdot
.698 .05623 Mdot
.698 .05654 Mdot
.698 .05677 Mdot
.698 .05699 Mdot
.698 .05708 Mdot
.698 .05712 Mdot
.698 .05781 Mdot
.698 .05803 Mdot
.698 .05807 Mdot
.698 .05851 Mdot
.698 .05865 Mdot
.698 .05868 Mdot
.698 .05871 Mdot
.698 .05884 Mdot
.698 .05904 Mdot
.698 .05907 Mdot
.698 .05981 Mdot
.698 .05984 Mdot
.698 .05996 Mdot
.698 .06005 Mdot
.698 .06005 Mdot
.698 .06027 Mdot
.698 .06054 Mdot
.698 .06062 Mdot
.698 .06087 Mdot
.698 .06157 Mdot
.698 .06183 Mdot
.698 .06201 Mdot
.698 .06282 Mdot
.698 .06287 Mdot
.698 .06293 Mdot
.698 .06297 Mdot
.698 .06323 Mdot
.698 .06331 Mdot
.698 .06333 Mdot
.698 .06388 Mdot
.698 .06398 Mdot
.698 .064 Mdot
.698 .06413 Mdot
.698 .06416 Mdot
.698 .06563 Mdot
.698 .06564 Mdot
.698 .06575 Mdot
.698 .06599 Mdot
.698 .06648 Mdot
.698 .06744 Mdot
.698 .06785 Mdot
.698 .06796 Mdot
.698 .06815 Mdot
.698 .0682 Mdot
.698 .06888 Mdot
.698 .06903 Mdot
.698 .06935 Mdot
.698 .06945 Mdot
.698 .06947 Mdot
.698 .06965 Mdot
.698 .06993 Mdot
.698 .07014 Mdot
.698 .07034 Mdot
.698 .07034 Mdot
.698 .07046 Mdot
.698 .07102 Mdot
.698 .07108 Mdot
.698 .0712 Mdot
.698 .07148 Mdot
.698 .07174 Mdot
.698 .07224 Mdot
.698 .07258 Mdot
.698 .07267 Mdot
.698 .0731 Mdot
.698 .07342 Mdot
.698 .07373 Mdot
.698 .07385 Mdot
.698 .07391 Mdot
.698 .07487 Mdot
.698 .07518 Mdot
.698 .07524 Mdot
.698 .07542 Mdot
.698 .07564 Mdot
.698 .07585 Mdot
.698 .07605 Mdot
.698 .07609 Mdot
.698 .07614 Mdot
.698 .07621 Mdot
.698 .07631 Mdot
.698 .0766 Mdot
.698 .07661 Mdot
.698 .07664 Mdot
.698 .07669 Mdot
.698 .07766 Mdot
.698 .07771 Mdot
.698 .07788 Mdot
.698 .078 Mdot
.698 .078 Mdot
.698 .0783 Mdot
.698 .07869 Mdot
.698 .07879 Mdot
.698 .07886 Mdot
.698 .07915 Mdot
.698 .08012 Mdot
.698 .08049 Mdot
.698 .08074 Mdot
.698 .08187 Mdot
.698 .08194 Mdot
.698 .08202 Mdot
.698 .08208 Mdot
.698 .08244 Mdot
.698 .08256 Mdot
.698 .08258 Mdot
.698 .08335 Mdot
.698 .08349 Mdot
.698 .08351 Mdot
.698 .08369 Mdot
.698 .08374 Mdot
.698 .0858 Mdot
.698 .0858 Mdot
.698 .08596 Mdot
.698 .08606 Mdot
.698 .0863 Mdot
.698 .08698 Mdot
.698 .08831 Mdot
.698 .08876 Mdot
.698 .0889 Mdot
.698 .08905 Mdot
.698 .08931 Mdot
.698 .08938 Mdot
.698 .09033 Mdot
.698 .09053 Mdot
.698 .09061 Mdot
.698 .09061 Mdot
.698 .09099 Mdot
.698 .09112 Mdot
.698 .09115 Mdot
.698 .09141 Mdot
.698 .09157 Mdot
.698 .09179 Mdot
.698 .09209 Mdot
.698 .09236 Mdot
.698 .09237 Mdot
.698 .09254 Mdot
.698 .09331 Mdot
.698 .09341 Mdot
.698 .09357 Mdot
.698 .09396 Mdot
.698 .09432 Mdot
.698 .09502 Mdot
.698 .0955 Mdot
.698 .09562 Mdot
.698 .09577 Mdot
.698 .09622 Mdot
.698 .09667 Mdot
.698 .0971 Mdot
.698 .09727 Mdot
.698 .09735 Mdot
.698 .09869 Mdot
.698 .09896 Mdot
.698 .09912 Mdot
.698 .09921 Mdot
.698 .09946 Mdot
.698 .0995 Mdot
.698 .09976 Mdot
.698 .10006 Mdot
.698 .10034 Mdot
.698 .1004 Mdot
.698 .10046 Mdot
.698 .1005 Mdot
.698 .10056 Mdot
.698 .1007 Mdot
.698 .1011 Mdot
.698 .10112 Mdot
.698 .10116 Mdot
.698 .10123 Mdot
.698 .10259 Mdot
.698 .10266 Mdot
.698 .10289 Mdot
.698 .10306 Mdot
.698 .10306 Mdot
.698 .10308 Mdot
.698 .1032 Mdot
.698 .10348 Mdot
.698 .10402 Mdot
.698 .10406 Mdot
.698 .10417 Mdot
.698 .10424 Mdot
.698 .10426 Mdot
.698 .10467 Mdot
.698 .10603 Mdot
.698 .10653 Mdot
.698 .10688 Mdot
.698 .10688 Mdot
.698 .10846 Mdot
.698 .10856 Mdot
.698 .10867 Mdot
.698 .10875 Mdot
.698 .10926 Mdot
.698 .10942 Mdot
.698 .10946 Mdot
.698 .10995 Mdot
.698 .11053 Mdot
.698 .11072 Mdot
.698 .11076 Mdot
.698 .11096 Mdot
.698 .11101 Mdot
.698 .11107 Mdot
.698 .11116 Mdot
.698 .11222 Mdot
.698 .11249 Mdot
.698 .11279 Mdot
.698 .11326 Mdot
.698 .11395 Mdot
.698 .11395 Mdot
.698 .11417 Mdot
.698 .11431 Mdot
.698 .11465 Mdot
.698 .1156 Mdot
.698 .1156 Mdot
.698 .11746 Mdot
.698 .11808 Mdot
.698 .11827 Mdot
.698 .11849 Mdot
.698 .11885 Mdot
.698 .11892 Mdot
.698 .11895 Mdot
.698 .11947 Mdot
.698 .12027 Mdot
.698 .12031 Mdot
.698 .12056 Mdot
.698 .12066 Mdot
.698 .12067 Mdot
.698 .12119 Mdot
.698 .12138 Mdot
.698 .12142 Mdot
.698 .12178 Mdot
.698 .1219 Mdot
.698 .12201 Mdot
.698 .12231 Mdot
.698 .12273 Mdot
.698 .12311 Mdot
.698 .12312 Mdot
.698 .12336 Mdot
.698 .12385 Mdot
.698 .12444 Mdot
.698 .12444 Mdot
.698 .12457 Mdot
.698 .12479 Mdot
.698 .12496 Mdot
.698 .12535 Mdot
.698 .12585 Mdot
.698 .12683 Mdot
.698 .12749 Mdot
.698 .12765 Mdot
.698 .12787 Mdot
.698 .12806 Mdot
.698 .12807 Mdot
.698 .1285 Mdot
.698 .12913 Mdot
.698 .12926 Mdot
.698 .12973 Mdot
.698 .12997 Mdot
.698 .12997 Mdot
.698 .13008 Mdot
.698 .13103 Mdot
.698 .13177 Mdot
.698 .13195 Mdot
.698 .13232 Mdot
.698 .13247 Mdot
.698 .13255 Mdot
.698 .13267 Mdot
.698 .13303 Mdot
.698 .13307 Mdot
.698 .13316 Mdot
.698 .13344 Mdot
.698 .13385 Mdot
.698 .13425 Mdot
.698 .13433 Mdot
.698 .13441 Mdot
.698 .13447 Mdot
.698 .13455 Mdot
.698 .13475 Mdot
.698 .13531 Mdot
.698 .13534 Mdot
.698 .13539 Mdot
.698 .13549 Mdot
.698 .13681 Mdot
.698 .13681 Mdot
.698 .13739 Mdot
.698 .13748 Mdot
.698 .13781 Mdot
.698 .13805 Mdot
.698 .13805 Mdot
.698 .13808 Mdot
.698 .13822 Mdot
.698 .13824 Mdot
.698 .13864 Mdot
.698 .13938 Mdot
.698 .13944 Mdot
.698 .13959 Mdot
.698 .1397 Mdot
.698 .13972 Mdot
.698 .14029 Mdot
.698 .14218 Mdot
.698 .1429 Mdot
.698 .14338 Mdot
.698 .14338 Mdot
.698 .14364 Mdot
.698 .14558 Mdot
.698 .14572 Mdot
.698 .14588 Mdot
.698 .14599 Mdot
.698 .14667 Mdot
.698 .1467 Mdot
.698 .14692 Mdot
.698 .14697 Mdot
.698 .14767 Mdot
.698 .14848 Mdot
.698 .14874 Mdot
.698 .14879 Mdot
.698 .14907 Mdot
.698 .14914 Mdot
.698 .14922 Mdot
.698 .14935 Mdot
.698 .14996 Mdot
.698 .15084 Mdot
.698 .15098 Mdot
.698 .1512 Mdot
.698 .15162 Mdot
.698 .15214 Mdot
.698 .15229 Mdot
.698 .15243 Mdot
.698 .15324 Mdot
.698 .15325 Mdot
.698 .15356 Mdot
.698 .15375 Mdot
.698 .15403 Mdot
.698 .15422 Mdot
.698 .15441 Mdot
.698 .15459 Mdot
.698 .15555 Mdot
.698 .15555 Mdot
.698 .15592 Mdot
.698 .15735 Mdot
.698 .15814 Mdot
.698 .15901 Mdot
.698 .15928 Mdot
.698 .15958 Mdot
.698 .15966 Mdot
.698 .16008 Mdot
.698 .16018 Mdot
.698 .16023 Mdot
.698 .16058 Mdot
.698 .16095 Mdot
.698 .16156 Mdot
.698 .16181 Mdot
.698 .16207 Mdot
.698 .16213 Mdot
.698 .16247 Mdot
.698 .16262 Mdot
.698 .16263 Mdot
.698 .16311 Mdot
.698 .16335 Mdot
.698 .16361 Mdot
.698 .16367 Mdot
.698 .16368 Mdot
.698 .16371 Mdot
.698 .16417 Mdot
.698 .16435 Mdot
.698 .1645 Mdot
.698 .16492 Mdot
.698 .1655 Mdot
.698 .16553 Mdot
.698 .16604 Mdot
.698 .16605 Mdot
.698 .16639 Mdot
.698 .16645 Mdot
.698 .16707 Mdot
.698 .16745 Mdot
.698 .16764 Mdot
.698 .16769 Mdot
.698 .1678 Mdot
.698 .16789 Mdot
.698 .16789 Mdot
.698 .16807 Mdot
.698 .16838 Mdot
.698 .16862 Mdot
.698 .16916 Mdot
.698 .16956 Mdot
.698 .16985 Mdot
.698 .17025 Mdot
.698 .17081 Mdot
.698 .17122 Mdot
.698 .17215 Mdot
.698 .17237 Mdot
.698 .1724 Mdot
.698 .17267 Mdot
.698 .17294 Mdot
.698 .17296 Mdot
.698 .17356 Mdot
.698 .17444 Mdot
.698 .17461 Mdot
.698 .17462 Mdot
.698 .17473 Mdot
.698 .17528 Mdot
.698 .1756 Mdot
.698 .17561 Mdot
.698 .17576 Mdot
.698 .17665 Mdot
.698 .17668 Mdot
.698 .17709 Mdot
.698 .17797 Mdot
.698 .17812 Mdot
.698 .17837 Mdot
.698 .17889 Mdot
.698 .1791 Mdot
.698 .17921 Mdot
.698 .17938 Mdot
.698 .17988 Mdot
.698 .17994 Mdot
.698 .18007 Mdot
.698 .18046 Mdot
.698 .18103 Mdot
.698 .18159 Mdot
.698 .1817 Mdot
.698 .18181 Mdot
.698 .1819 Mdot
.698 .18201 Mdot
.698 .18228 Mdot
.698 .18307 Mdot
.698 .1831 Mdot
.698 .18318 Mdot
.698 .18331 Mdot
.698 .18516 Mdot
.698 .18516 Mdot
.698 .18597 Mdot
.698 .1861 Mdot
.698 .18656 Mdot
.698 .18688 Mdot
.698 .18688 Mdot
.698 .18693 Mdot
.698 .18713 Mdot
.698 .18716 Mdot
.698 .18771 Mdot
.698 .18875 Mdot
.698 .18883 Mdot
.698 .18904 Mdot
.698 .18919 Mdot
.698 .18922 Mdot
.698 .19002 Mdot
.698 .19266 Mdot
.698 .19365 Mdot
.698 .19434 Mdot
.698 .19434 Mdot
.698 .19469 Mdot
.698 .1974 Mdot
.698 .1976 Mdot
.698 .19782 Mdot
.698 .19797 Mdot
.698 .19892 Mdot
.698 .19896 Mdot
.698 .19928 Mdot
.698 .19935 Mdot
.698 .20032 Mdot
.698 .20145 Mdot
.698 .20182 Mdot
.698 .20189 Mdot
.698 .20228 Mdot
.698 .20238 Mdot
.698 .20249 Mdot
.698 .20266 Mdot
.698 .20352 Mdot
.698 .20474 Mdot
.698 .20494 Mdot
.698 .20525 Mdot
.698 .20584 Mdot
.698 .20655 Mdot
.698 .20677 Mdot
.698 .20696 Mdot
.698 .2081 Mdot
.698 .2081 Mdot
.698 .20854 Mdot
.698 .2088 Mdot
.698 .20919 Mdot
.698 .20946 Mdot
.698 .20972 Mdot
.698 .20998 Mdot
.698 .21132 Mdot
.698 .21132 Mdot
.698 .21184 Mdot
.698 .21383 Mdot
.698 .21494 Mdot
.698 .21615 Mdot
.698 .21653 Mdot
.698 .21695 Mdot
.698 .21706 Mdot
.698 .21765 Mdot
.698 .21778 Mdot
.698 .21785 Mdot
.698 .21834 Mdot
.698 .21887 Mdot
.698 .21972 Mdot
.698 .22005 Mdot
.698 .22042 Mdot
.698 .22051 Mdot
.698 .22098 Mdot
.698 .22119 Mdot
.698 .2212 Mdot
.698 .22187 Mdot
.698 .22221 Mdot
.698 .22258 Mdot
.698 .22265 Mdot
.698 .22267 Mdot
.698 .22271 Mdot
.698 .22336 Mdot
.698 .22361 Mdot
.698 .22381 Mdot
.698 .2244 Mdot
.698 .22521 Mdot
.698 .22526 Mdot
.698 .22596 Mdot
.698 .22597 Mdot
.698 .22645 Mdot
.698 .22654 Mdot
.698 .2274 Mdot
.698 .22793 Mdot
.698 .2282 Mdot
.698 .22827 Mdot
.698 .22842 Mdot
.698 .22854 Mdot
.698 .22855 Mdot
.698 .2288 Mdot
.698 .22923 Mdot
.698 .22957 Mdot
.698 .23032 Mdot
.698 .23089 Mdot
.698 .23129 Mdot
.698 .23184 Mdot
.698 .23262 Mdot
.698 .2332 Mdot
.698 .23449 Mdot
.698 .23481 Mdot
.698 .23484 Mdot
.698 .23523 Mdot
.698 .2356 Mdot
.698 .23562 Mdot
.698 .23646 Mdot
.698 .23769 Mdot
.698 .23793 Mdot
.698 .23794 Mdot
.698 .2381 Mdot
.698 .23886 Mdot
.698 .23932 Mdot
.698 .23932 Mdot
.698 .23953 Mdot
.698 .24078 Mdot
.698 .24082 Mdot
.698 .24139 Mdot
.698 .24262 Mdot
.698 .24283 Mdot
.698 .24318 Mdot
.698 .24391 Mdot
.698 .2442 Mdot
.698 .24435 Mdot
.698 .24459 Mdot
.698 .24528 Mdot
.698 .24537 Mdot
.698 .24555 Mdot
.698 .24609 Mdot
.698 .24689 Mdot
.698 .24767 Mdot
.698 .24782 Mdot
.698 .24798 Mdot
.698 .2481 Mdot
.698 .24826 Mdot
.698 .24863 Mdot
.698 .24974 Mdot
.698 .24978 Mdot
.698 .24989 Mdot
.698 .25007 Mdot
.698 .25265 Mdot
.698 .25265 Mdot
.698 .25379 Mdot
.698 .25397 Mdot
.698 .25461 Mdot
.698 .25506 Mdot
.698 .25506 Mdot
.698 .25513 Mdot
.698 .25541 Mdot
.698 .25545 Mdot
.698 .25622 Mdot
.698 .25767 Mdot
.698 .25778 Mdot
.698 .25808 Mdot
.698 .25828 Mdot
.698 .25832 Mdot
.698 .25943 Mdot
.698 .26313 Mdot
.698 .26451 Mdot
.698 .26546 Mdot
.698 .26547 Mdot
.698 .26596 Mdot
.698 .26811 Mdot
.698 .26975 Mdot
.698 .27003 Mdot
.698 .27033 Mdot
.698 .27054 Mdot
.698 .27187 Mdot
.698 .27193 Mdot
.698 .27237 Mdot
.698 .27246 Mdot
.698 .27382 Mdot
.698 .27539 Mdot
.698 .27591 Mdot
.698 .27601 Mdot
.698 .27656 Mdot
.698 .27669 Mdot
.698 .27684 Mdot
.698 .27709 Mdot
.698 .27829 Mdot
.698 .27999 Mdot
.698 .28027 Mdot
.698 .28071 Mdot
.698 .28152 Mdot
.698 .28252 Mdot
.698 .28282 Mdot
.698 .28309 Mdot
.698 .28468 Mdot
.698 .28469 Mdot
.698 .2853 Mdot
.698 .28566 Mdot
.698 .28621 Mdot
.698 .28658 Mdot
.698 .28695 Mdot
.698 .2873 Mdot
.698 .28917 Mdot
.698 .28917 Mdot
.698 .2899 Mdot
.698 .29267 Mdot
.698 .29423 Mdot
.698 .29592 Mdot
.698 .29644 Mdot
.698 .29704 Mdot
.698 .29719 Mdot
.698 .29801 Mdot
.698 .2982 Mdot
.698 .29829 Mdot
.698 .29898 Mdot
.698 .29971 Mdot
.698 .3009 Mdot
.698 .30137 Mdot
.698 .30187 Mdot
.698 .302 Mdot
.698 .30267 Mdot
.698 .30295 Mdot
.698 .30297 Mdot
.698 .30391 Mdot
.698 .30438 Mdot
.698 .30489 Mdot
.698 .30499 Mdot
.698 .30502 Mdot
.698 .30507 Mdot
.698 .30598 Mdot
.698 .30633 Mdot
.698 .30662 Mdot
.698 .30743 Mdot
.698 .30857 Mdot
.698 .30863 Mdot
.698 .30962 Mdot
.698 .30963 Mdot
.698 .31029 Mdot
.698 .31042 Mdot
.698 .31162 Mdot
.698 .31236 Mdot
.698 .31274 Mdot
.698 .31284 Mdot
.698 .31305 Mdot
.698 .31322 Mdot
.698 .31323 Mdot
.698 .31357 Mdot
.698 .31418 Mdot
.698 .31465 Mdot
.698 .3157 Mdot
.698 .31649 Mdot
.698 .31705 Mdot
.698 .31782 Mdot
.698 .31891 Mdot
.698 .31972 Mdot
.698 .32153 Mdot
.698 .32197 Mdot
.698 .32201 Mdot
.698 .32255 Mdot
.698 .32308 Mdot
.698 .3231 Mdot
.698 .32428 Mdot
.698 .32598 Mdot
.698 .32632 Mdot
.698 .32633 Mdot
.698 .32656 Mdot
.698 .32762 Mdot
.698 .32826 Mdot
.698 .32827 Mdot
.698 .32856 Mdot
.698 .3303 Mdot
.698 .33036 Mdot
.698 .33116 Mdot
.698 .33287 Mdot
.698 .33316 Mdot
.698 .33366 Mdot
.698 .33466 Mdot
.698 .33508 Mdot
.698 .33529 Mdot
.698 .33563 Mdot
.698 .33658 Mdot
.698 .33671 Mdot
.698 .33696 Mdot
.698 .33772 Mdot
.698 .33884 Mdot
.698 .33992 Mdot
.698 .34013 Mdot
.698 .34036 Mdot
.698 .34052 Mdot
.698 .34074 Mdot
.698 .34126 Mdot
.698 .34281 Mdot
.698 .34287 Mdot
.698 .34303 Mdot
.698 .34328 Mdot
.698 .34687 Mdot
.698 .34687 Mdot
.698 .34846 Mdot
.698 .34871 Mdot
.698 .3496 Mdot
.698 .35024 Mdot
.698 .35024 Mdot
.698 .35033 Mdot
.698 .35073 Mdot
.698 .35077 Mdot
.698 .35185 Mdot
.698 .35388 Mdot
.698 .35404 Mdot
.698 .35445 Mdot
.698 .35473 Mdot
.698 .35479 Mdot
.698 .35634 Mdot
.698 .3615 Mdot
.698 .36344 Mdot
.698 .36476 Mdot
.698 .36477 Mdot
.698 .36545 Mdot
.698 .36846 Mdot
.698 .37074 Mdot
.698 .37113 Mdot
.698 .37155 Mdot
.698 .37185 Mdot
.698 .3737 Mdot
.698 .37378 Mdot
.698 .3744 Mdot
.698 .37453 Mdot
.698 .37642 Mdot
.698 .37862 Mdot
.698 .37934 Mdot
.698 .37948 Mdot
.698 .38024 Mdot
.698 .38043 Mdot
.698 .38065 Mdot
.698 .38099 Mdot
.698 .38266 Mdot
.698 .38504 Mdot
.698 .38544 Mdot
.698 .38604 Mdot
.698 .38718 Mdot
.698 .38857 Mdot
.698 .389 Mdot
.698 .38937 Mdot
.698 .39159 Mdot
.698 .3916 Mdot
.698 .39245 Mdot
.698 .39295 Mdot
.698 .39372 Mdot
.698 .39424 Mdot
.698 .39475 Mdot
.698 .39524 Mdot
.698 .39785 Mdot
.698 .39785 Mdot
.698 .39887 Mdot
.698 .40275 Mdot
.698 .40492 Mdot
.698 .40728 Mdot
.698 .40801 Mdot
.698 .40883 Mdot
.698 .40904 Mdot
.698 .41019 Mdot
.698 .41046 Mdot
.698 .41059 Mdot
.698 .41155 Mdot
.698 .41257 Mdot
.698 .41422 Mdot
.698 .41488 Mdot
.698 .41559 Mdot
.698 .41576 Mdot
.698 .4167 Mdot
.698 .41709 Mdot
.698 .41712 Mdot
.698 .41843 Mdot
.698 .41909 Mdot
.698 .4198 Mdot
.698 .41994 Mdot
.698 .41998 Mdot
.698 .42006 Mdot
.698 .42132 Mdot
.698 .42181 Mdot
.698 .42221 Mdot
.698 .42335 Mdot
.698 .42493 Mdot
.698 .42502 Mdot
.698 .4264 Mdot
.698 .42642 Mdot
.698 .42734 Mdot
.7 .01526 Mdot
.7 .01548 Mdot
.7 .01566 Mdot
.7 .01579 Mdot
.7 .01598 Mdot
.7 .01604 Mdot
.7 .01622 Mdot
.7 .01648 Mdot
.7 .01657 Mdot
.7 .01682 Mdot
.7 .01682 Mdot
.7 .01719 Mdot
.7 .01731 Mdot
.7 .01766 Mdot
.7 .01766 Mdot
.7 .01818 Mdot
.7 .01835 Mdot
.7 .01859 Mdot
.7 .01862 Mdot
.7 .01883 Mdot
.7 .01884 Mdot
.7 .01926 Mdot
.7 .01956 Mdot
.7 .0198 Mdot
.7 .01998 Mdot
.7 .02013 Mdot
.7 .02018 Mdot
.7 .02048 Mdot
.7 .02049 Mdot
.7 .02108 Mdot
.7 .0211 Mdot
.7 .02132 Mdot
.7 .0215 Mdot
.7 .02183 Mdot
.7 .02209 Mdot
.7 .02219 Mdot
.7 .0223 Mdot
.7 .02236 Mdot
.7 .02274 Mdot
.7 .02279 Mdot
.7 .0228 Mdot
.7 .02307 Mdot
.7 .02363 Mdot
.7 .02365 Mdot
.7 .02369 Mdot
.7 .02396 Mdot
.7 .02422 Mdot
.7 .02467 Mdot
.7 .02468 Mdot
.7 .02503 Mdot
.7 .02518 Mdot
.7 .02534 Mdot
.7 .02542 Mdot
.7 .02595 Mdot
.7 .02602 Mdot
.7 .02604 Mdot
.7 .02641 Mdot
.7 .0272 Mdot
.7 .02723 Mdot
.7 .02728 Mdot
.7 .02733 Mdot
.7 .02766 Mdot
.7 .02802 Mdot
.7 .02865 Mdot
.7 .02867 Mdot
.7 .02916 Mdot
.7 .02937 Mdot
.7 .02958 Mdot
.7 .0297 Mdot
.7 .02988 Mdot
.7 .03045 Mdot
.7 .03054 Mdot
.7 .03057 Mdot
.7 .03084 Mdot
.7 .03108 Mdot
.7 .03219 Mdot
.7 .03223 Mdot
.7 .0323 Mdot
.7 .03237 Mdot
.7 .03283 Mdot
.7 .03334 Mdot
.7 .03417 Mdot
.7 .03423 Mdot
.7 .03425 Mdot
.7 .03453 Mdot
.7 .03455 Mdot
.7 .03481 Mdot
.7 .03485 Mdot
.7 .03494 Mdot
.7 .03514 Mdot
.7 .03523 Mdot
.7 .03553 Mdot
.7 .03569 Mdot
.7 .03582 Mdot
.7 .03594 Mdot
.7 .03674 Mdot
.7 .03674 Mdot
.7 .03687 Mdot
.7 .03691 Mdot
.7 .03729 Mdot
.7 .03763 Mdot
.7 .03764 Mdot
.7 .03786 Mdot
.7 .03788 Mdot
.7 .03911 Mdot
.7 .03918 Mdot
.7 .03924 Mdot
.7 .03934 Mdot
.7 .03934 Mdot
.7 .03944 Mdot
.7 .04008 Mdot
.7 .04079 Mdot
.7 .04184 Mdot
.7 .04196 Mdot
.7 .04204 Mdot
.7 .04206 Mdot
.7 .04241 Mdot
.7 .04246 Mdot
.7 .04248 Mdot
.7 .04283 Mdot
.7 .04285 Mdot
.7 .04291 Mdot
.7 .04303 Mdot
.7 .04331 Mdot
.7 .04344 Mdot
.7 .04386 Mdot
.7 .04408 Mdot
.7 .04426 Mdot
.7 .04443 Mdot
.7 .04545 Mdot
.7 .04555 Mdot
.7 .04555 Mdot
.7 .04573 Mdot
.7 .04579 Mdot
.7 .04586 Mdot
.7 .04601 Mdot
.7 .04627 Mdot
.7 .04632 Mdot
.7 .0468 Mdot
.7 .04681 Mdot
.7 .04684 Mdot
.7 .04711 Mdot
.7 .04714 Mdot
.7 .04792 Mdot
.7 .04867 Mdot
.7 .04887 Mdot
.7 .04897 Mdot
.7 .04905 Mdot
.7 .04919 Mdot
.7 .04919 Mdot
.7 .04933 Mdot
.7 .05022 Mdot
.7 .05062 Mdot
.7 .05122 Mdot
.7 .05145 Mdot
.7 .05201 Mdot
.7 .05268 Mdot
.7 .05285 Mdot
.7 .05296 Mdot
.7 .053 Mdot
.7 .05308 Mdot
.7 .05349 Mdot
.7 .05356 Mdot
.7 .05359 Mdot
.7 .05407 Mdot
.7 .0541 Mdot
.7 .05418 Mdot
.7 .05435 Mdot
.7 .05442 Mdot
.7 .05475 Mdot
.7 .05493 Mdot
.7 .05551 Mdot
.7 .05583 Mdot
.7 .05587 Mdot
.7 .05589 Mdot
.7 .05607 Mdot
.7 .05632 Mdot
.7 .05775 Mdot
.7 .05789 Mdot
.7 .05789 Mdot
.7 .05813 Mdot
.7 .05822 Mdot
.7 .05832 Mdot
.7 .05845 Mdot
.7 .05852 Mdot
.7 .05889 Mdot
.7 .05896 Mdot
.7 .05916 Mdot
.7 .05936 Mdot
.7 .05949 Mdot
.7 .05963 Mdot
.7 .05965 Mdot
.7 .05968 Mdot
.7 .06007 Mdot
.7 .06011 Mdot
.7 .06036 Mdot
.7 .06121 Mdot
.7 .06178 Mdot
.7 .06225 Mdot
.7 .06253 Mdot
.7 .06253 Mdot
.7 .06255 Mdot
.7 .06267 Mdot
.7 .06279 Mdot
.7 .06298 Mdot
.7 .06298 Mdot
.7 .06317 Mdot
.7 .06408 Mdot
.7 .06443 Mdot
.7 .06498 Mdot
.7 .06582 Mdot
.7 .06614 Mdot
.7 .06643 Mdot
.7 .06674 Mdot
.7 .06692 Mdot
.7 .06715 Mdot
.7 .06787 Mdot
.7 .06811 Mdot
.7 .06821 Mdot
.7 .06826 Mdot
.7 .06831 Mdot
.7 .06843 Mdot
.7 .069 Mdot
.7 .0691 Mdot
.7 .06914 Mdot
.7 .06923 Mdot
.7 .06941 Mdot
.7 .06982 Mdot
.7 .06986 Mdot
.7 .06997 Mdot
.7 .07021 Mdot
.7 .0703 Mdot
.7 .07076 Mdot
.7 .07101 Mdot
.7 .07137 Mdot
.7 .07183 Mdot
.7 .07228 Mdot
.7 .07233 Mdot
.7 .07236 Mdot
.7 .07262 Mdot
.7 .07277 Mdot
.7 .07296 Mdot
.7 .0742 Mdot
.7 .07446 Mdot
.7 .07479 Mdot
.7 .07497 Mdot
.7 .07516 Mdot
.7 .07516 Mdot
.7 .0755 Mdot
.7 .07562 Mdot
.7 .07575 Mdot
.7 .07594 Mdot
.7 .07605 Mdot
.7 .07656 Mdot
.7 .07666 Mdot
.7 .07693 Mdot
.7 .07722 Mdot
.7 .0774 Mdot
.7 .07759 Mdot
.7 .07763 Mdot
.7 .07767 Mdot
.7 .07821 Mdot
.7 .07827 Mdot
.7 .07862 Mdot
.7 .07889 Mdot
.7 .07929 Mdot
.7 .0798 Mdot
.7 .08007 Mdot
.7 .08061 Mdot
.7 .0812 Mdot
.7 .08124 Mdot
.7 .08127 Mdot
.7 .08165 Mdot
.7 .08166 Mdot
.7 .08168 Mdot
.7 .08185 Mdot
.7 .08196 Mdot
.7 .08202 Mdot
.7 .08228 Mdot
.7 .08229 Mdot
.7 .08255 Mdot
.7 .08383 Mdot
.7 .08394 Mdot
.7 .08431 Mdot
.7 .08507 Mdot
.7 .08509 Mdot
.7 .08529 Mdot
.7 .08566 Mdot
.7 .08626 Mdot
.7 .0863 Mdot
.7 .08671 Mdot
.7 .08695 Mdot
.7 .08712 Mdot
.7 .08755 Mdot
.7 .0878 Mdot
.7 .08812 Mdot
.7 .08914 Mdot
.7 .08947 Mdot
.7 .08961 Mdot
.7 .08968 Mdot
.7 .08975 Mdot
.7 .08992 Mdot
.7 .09072 Mdot
.7 .09084 Mdot
.7 .09085 Mdot
.7 .09091 Mdot
.7 .09104 Mdot
.7 .09128 Mdot
.7 .09186 Mdot
.7 .09192 Mdot
.7 .09207 Mdot
.7 .09241 Mdot
.7 .09253 Mdot
.7 .09287 Mdot
.7 .09291 Mdot
.7 .09307 Mdot
.7 .09318 Mdot
.7 .09353 Mdot
.7 .09403 Mdot
.7 .09468 Mdot
.7 .0953 Mdot
.7 .09537 Mdot
.7 .09542 Mdot
.7 .09578 Mdot
.7 .09599 Mdot
.7 .09626 Mdot
.7 .09691 Mdot
.7 .09755 Mdot
.7 .098 Mdot
.7 .09836 Mdot
.7 .09882 Mdot
.7 .09907 Mdot
.7 .09933 Mdot
.7 .09934 Mdot
.7 .09982 Mdot
.7 .09995 Mdot
.7 .09998 Mdot
.7 .10001 Mdot
.7 .10017 Mdot
.7 .10043 Mdot
.7 .10058 Mdot
.7 .10086 Mdot
.7 .1013 Mdot
.7 .10136 Mdot
.7 .10143 Mdot
.7 .10163 Mdot
.7 .10182 Mdot
.7 .10185 Mdot
.7 .10222 Mdot
.7 .10248 Mdot
.7 .10274 Mdot
.7 .10279 Mdot
.7 .10285 Mdot
.7 .10361 Mdot
.7 .10369 Mdot
.7 .10419 Mdot
.7 .10455 Mdot
.7 .10476 Mdot
.7 .10481 Mdot
.7 .10487 Mdot
.7 .10499 Mdot
.7 .10511 Mdot
.7 .10584 Mdot
.7 .10622 Mdot
.7 .10625 Mdot
.7 .10697 Mdot
.7 .10709 Mdot
.7 .10753 Mdot
.7 .10779 Mdot
.7 .10784 Mdot
.7 .10789 Mdot
.7 .10843 Mdot
.7 .10843 Mdot
.7 .10847 Mdot
.7 .1087 Mdot
.7 .10886 Mdot
.7 .10894 Mdot
.7 .10931 Mdot
.7 .10932 Mdot
.7 .10953 Mdot
.7 .10956 Mdot
.7 .10969 Mdot
.7 .1107 Mdot
.7 .11085 Mdot
.7 .11148 Mdot
.7 .11156 Mdot
.7 .11163 Mdot
.7 .11215 Mdot
.7 .11321 Mdot
.7 .11323 Mdot
.7 .11352 Mdot
.7 .11403 Mdot
.7 .11488 Mdot
.7 .11494 Mdot
.7 .1155 Mdot
.7 .11585 Mdot
.7 .11608 Mdot
.7 .11668 Mdot
.7 .117 Mdot
.7 .11704 Mdot
.7 .11719 Mdot
.7 .11748 Mdot
.7 .11777 Mdot
.7 .1189 Mdot
.7 .11937 Mdot
.7 .11957 Mdot
.7 .11967 Mdot
.7 .11977 Mdot
.7 .12 Mdot
.7 .12112 Mdot
.7 .12116 Mdot
.7 .12129 Mdot
.7 .1213 Mdot
.7 .12139 Mdot
.7 .12157 Mdot
.7 .12161 Mdot
.7 .12191 Mdot
.7 .12198 Mdot
.7 .12272 Mdot
.7 .1228 Mdot
.7 .12302 Mdot
.7 .12349 Mdot
.7 .12365 Mdot
.7 .12384 Mdot
.7 .12413 Mdot
.7 .12419 Mdot
.7 .12442 Mdot
.7 .12456 Mdot
.7 .12464 Mdot
.7 .12481 Mdot
.7 .12506 Mdot
.7 .12575 Mdot
.7 .12667 Mdot
.7 .12754 Mdot
.7 .12763 Mdot
.7 .1277 Mdot
.7 .12771 Mdot
.7 .1282 Mdot
.7 .12849 Mdot
.7 .12888 Mdot
.7 .12979 Mdot
.7 .13047 Mdot
.7 .13062 Mdot
.7 .13068 Mdot
.7 .13131 Mdot
.7 .13182 Mdot
.7 .13218 Mdot
.7 .13246 Mdot
.7 .13281 Mdot
.7 .13318 Mdot
.7 .13319 Mdot
.7 .13386 Mdot
.7 .13404 Mdot
.7 .13409 Mdot
.7 .13413 Mdot
.7 .13435 Mdot
.7 .13472 Mdot
.7 .13492 Mdot
.7 .13492 Mdot
.7 .13532 Mdot
.7 .13593 Mdot
.7 .13601 Mdot
.7 .13612 Mdot
.7 .1364 Mdot
.7 .13666 Mdot
.7 .13671 Mdot
.7 .13722 Mdot
.7 .13758 Mdot
.7 .13796 Mdot
.7 .13802 Mdot
.7 .13811 Mdot
.7 .13917 Mdot
.7 .13928 Mdot
.7 .13948 Mdot
.7 .13978 Mdot
.7 .13979 Mdot
.7 .13998 Mdot
.7 .14049 Mdot
.7 .14078 Mdot
.7 .14084 Mdot
.7 .14094 Mdot
.7 .14111 Mdot
.7 .14127 Mdot
.7 .14229 Mdot
.7 .14282 Mdot
.7 .14283 Mdot
.7 .14287 Mdot
.7 .14387 Mdot
.7 .14403 Mdot
.7 .14466 Mdot
.7 .14467 Mdot
.7 .14502 Mdot
.7 .1451 Mdot
.7 .14515 Mdot
.7 .14591 Mdot
.7 .14592 Mdot
.7 .14594 Mdot
.7 .14597 Mdot
.7 .1463 Mdot
.7 .14652 Mdot
.7 .14663 Mdot
.7 .14715 Mdot
.7 .14716 Mdot
.7 .14746 Mdot
.7 .14749 Mdot
.7 .14768 Mdot
.7 .1491 Mdot
.7 .14915 Mdot
.7 .1493 Mdot
.7 .15018 Mdot
.7 .1503 Mdot
.7 .15039 Mdot
.7 .15088 Mdot
.7 .15109 Mdot
.7 .15113 Mdot
.7 .15188 Mdot
.7 .1526 Mdot
.7 .15264 Mdot
.7 .15305 Mdot
.7 .15376 Mdot
.7 .15495 Mdot
.7 .15503 Mdot
.7 .15503 Mdot
.7 .15582 Mdot
.7 .1563 Mdot
.7 .15663 Mdot
.7 .15746 Mdot
.7 .15791 Mdot
.7 .15797 Mdot
.7 .15818 Mdot
.7 .15859 Mdot
.7 .159 Mdot
.7 .16058 Mdot
.7 .16112 Mdot
.7 .16123 Mdot
.7 .16151 Mdot
.7 .16165 Mdot
.7 .16179 Mdot
.7 .16211 Mdot
.7 .16318 Mdot
.7 .16362 Mdot
.7 .16368 Mdot
.7 .16374 Mdot
.7 .16392 Mdot
.7 .16394 Mdot
.7 .16405 Mdot
.7 .16431 Mdot
.7 .16437 Mdot
.7 .16469 Mdot
.7 .16479 Mdot
.7 .16489 Mdot
.7 .16522 Mdot
.7 .16577 Mdot
.7 .16592 Mdot
.7 .16603 Mdot
.7 .16634 Mdot
.7 .16698 Mdot
.7 .16699 Mdot
.7 .16723 Mdot
.7 .16749 Mdot
.7 .1679 Mdot
.7 .16798 Mdot
.7 .1683 Mdot
.7 .1685 Mdot
.7 .16862 Mdot
.7 .16884 Mdot
.7 .1692 Mdot
.7 .17017 Mdot
.7 .1711 Mdot
.7 .17145 Mdot
.7 .17266 Mdot
.7 .1728 Mdot
.7 .1728 Mdot
.7 .1729 Mdot
.7 .17291 Mdot
.7 .17302 Mdot
.7 .17326 Mdot
.7 .1736 Mdot
.7 .17393 Mdot
.7 .17401 Mdot
.7 .17401 Mdot
.7 .17446 Mdot
.7 .17455 Mdot
.7 .17546 Mdot
.7 .17567 Mdot
.7 .17582 Mdot
.7 .17678 Mdot
.7 .17692 Mdot
.7 .17698 Mdot
.7 .17707 Mdot
.7 .17728 Mdot
.7 .17767 Mdot
.7 .17795 Mdot
.7 .17866 Mdot
.7 .17896 Mdot
.7 .17916 Mdot
.7 .17956 Mdot
.7 .18004 Mdot
.7 .18057 Mdot
.7 .18058 Mdot
.7 .18151 Mdot
.7 .18177 Mdot
.7 .18184 Mdot
.7 .18189 Mdot
.7 .18221 Mdot
.7 .18273 Mdot
.7 .183 Mdot
.7 .183 Mdot
.7 .18356 Mdot
.7 .18442 Mdot
.7 .18453 Mdot
.7 .18468 Mdot
.7 .18507 Mdot
.7 .18544 Mdot
.7 .1855 Mdot
.7 .18622 Mdot
.7 .18673 Mdot
.7 .18725 Mdot
.7 .18735 Mdot
.7 .18747 Mdot
.7 .18896 Mdot
.7 .1891 Mdot
.7 .18939 Mdot
.7 .1898 Mdot
.7 .18981 Mdot
.7 .19008 Mdot
.7 .1908 Mdot
.7 .19121 Mdot
.7 .19129 Mdot
.7 .19143 Mdot
.7 .19166 Mdot
.7 .1919 Mdot
.7 .19331 Mdot
.7 .19406 Mdot
.7 .19407 Mdot
.7 .19413 Mdot
.7 .19553 Mdot
.7 .19576 Mdot
.7 .19663 Mdot
.7 .19666 Mdot
.7 .19715 Mdot
.7 .19725 Mdot
.7 .19733 Mdot
.7 .19839 Mdot
.7 .1984 Mdot
.7 .19843 Mdot
.7 .19847 Mdot
.7 .19893 Mdot
.7 .19924 Mdot
.7 .1994 Mdot
.7 .20013 Mdot
.7 .20014 Mdot
.7 .20055 Mdot
.7 .20061 Mdot
.7 .20087 Mdot
.7 .20285 Mdot
.7 .20292 Mdot
.7 .20313 Mdot
.7 .20437 Mdot
.7 .20453 Mdot
.7 .20466 Mdot
.7 .20534 Mdot
.7 .20563 Mdot
.7 .20569 Mdot
.7 .20675 Mdot
.7 .20776 Mdot
.7 .20781 Mdot
.7 .20838 Mdot
.7 .20938 Mdot
.7 .21104 Mdot
.7 .21115 Mdot
.7 .21115 Mdot
.7 .21226 Mdot
.7 .21293 Mdot
.7 .2134 Mdot
.7 .21456 Mdot
.7 .21519 Mdot
.7 .21527 Mdot
.7 .21556 Mdot
.7 .21614 Mdot
.7 .21671 Mdot
.7 .21893 Mdot
.7 .21968 Mdot
.7 .21984 Mdot
.7 .22023 Mdot
.7 .22042 Mdot
.7 .22062 Mdot
.7 .22106 Mdot
.7 .22256 Mdot
.7 .22318 Mdot
.7 .22326 Mdot
.7 .22335 Mdot
.7 .2236 Mdot
.7 .22363 Mdot
.7 .22379 Mdot
.7 .22415 Mdot
.7 .22423 Mdot
.7 .22469 Mdot
.7 .22482 Mdot
.7 .22496 Mdot
.7 .22543 Mdot
.7 .2262 Mdot
.7 .2264 Mdot
.7 .22656 Mdot
.7 .22699 Mdot
.7 .22789 Mdot
.7 .22791 Mdot
.7 .22824 Mdot
.7 .2286 Mdot
.7 .22917 Mdot
.7 .22928 Mdot
.7 .22973 Mdot
.7 .23001 Mdot
.7 .23018 Mdot
.7 .23049 Mdot
.7 .231 Mdot
.7 .23235 Mdot
.7 .23365 Mdot
.7 .23414 Mdot
.7 .23584 Mdot
.7 .23603 Mdot
.7 .23604 Mdot
.7 .23617 Mdot
.7 .23619 Mdot
.7 .23634 Mdot
.7 .23668 Mdot
.7 .23715 Mdot
.7 .23761 Mdot
.7 .23772 Mdot
.7 .23773 Mdot
.7 .23836 Mdot
.7 .23848 Mdot
.7 .23975 Mdot
.7 .24005 Mdot
.7 .24026 Mdot
.7 .2416 Mdot
.7 .24181 Mdot
.7 .24188 Mdot
.7 .24201 Mdot
.7 .2423 Mdot
.7 .24286 Mdot
.7 .24324 Mdot
.7 .24423 Mdot
.7 .24466 Mdot
.7 .24494 Mdot
.7 .24549 Mdot
.7 .24617 Mdot
.7 .24691 Mdot
.7 .24692 Mdot
.7 .24823 Mdot
.7 .24859 Mdot
.7 .24869 Mdot
.7 .24876 Mdot
.7 .24921 Mdot
.7 .24993 Mdot
.7 .25031 Mdot
.7 .25032 Mdot
.7 .2511 Mdot
.7 .2523 Mdot
.7 .25246 Mdot
.7 .25267 Mdot
.7 .25321 Mdot
.7 .25373 Mdot
.7 .25382 Mdot
.7 .25482 Mdot
.7 .25553 Mdot
.7 .25627 Mdot
.7 .2564 Mdot
.7 .25657 Mdot
.7 .25866 Mdot
.7 .25886 Mdot
.7 .25926 Mdot
.7 .25984 Mdot
.7 .25985 Mdot
.7 .26022 Mdot
.7 .26123 Mdot
.7 .26181 Mdot
.7 .26192 Mdot
.7 .26211 Mdot
.7 .26244 Mdot
.7 .26277 Mdot
.7 .26475 Mdot
.7 .26579 Mdot
.7 .26581 Mdot
.7 .26589 Mdot
.7 .26785 Mdot
.7 .26818 Mdot
.7 .2694 Mdot
.7 .26943 Mdot
.7 .26987 Mdot
.7 .27012 Mdot
.7 .27026 Mdot
.7 .27037 Mdot
.7 .27186 Mdot
.7 .27188 Mdot
.7 .27192 Mdot
.7 .27198 Mdot
.7 .27262 Mdot
.7 .27304 Mdot
.7 .27327 Mdot
.7 .27429 Mdot
.7 .2743 Mdot
.7 .27489 Mdot
.7 .27496 Mdot
.7 .27533 Mdot
.7 .2781 Mdot
.7 .2782 Mdot
.7 .2785 Mdot
.7 .28023 Mdot
.7 .28045 Mdot
.7 .28064 Mdot
.7 .28159 Mdot
.7 .282 Mdot
.7 .28208 Mdot
.7 .28357 Mdot
.7 .28498 Mdot
.7 .28505 Mdot
.7 .28585 Mdot
.7 .28724 Mdot
.7 .28957 Mdot
.7 .28972 Mdot
.7 .28973 Mdot
.7 .29128 Mdot
.7 .29222 Mdot
.7 .29287 Mdot
.7 .2945 Mdot
.7 .29539 Mdot
.7 .29549 Mdot
.7 .2959 Mdot
.7 .29671 Mdot
.7 .2975 Mdot
.7 .30061 Mdot
.7 .30166 Mdot
.7 .30189 Mdot
.7 .30244 Mdot
.7 .30271 Mdot
.7 .30299 Mdot
.7 .3036 Mdot
.7 .3057 Mdot
.7 .30657 Mdot
.7 .30668 Mdot
.7 .30681 Mdot
.7 .30715 Mdot
.7 .30719 Mdot
.7 .30742 Mdot
.7 .30793 Mdot
.7 .30803 Mdot
.7 .30867 Mdot
.7 .30886 Mdot
.7 .30906 Mdot
.7 .30971 Mdot
.7 .31079 Mdot
.7 .31107 Mdot
.7 .3113 Mdot
.7 .3119 Mdot
.7 .31316 Mdot
.7 .31318 Mdot
.7 .31365 Mdot
.7 .31416 Mdot
.7 .31496 Mdot
.7 .31511 Mdot
.7 .31574 Mdot
.7 .31613 Mdot
.7 .31636 Mdot
.7 .31681 Mdot
.7 .31751 Mdot
.7 .31941 Mdot
.7 .32123 Mdot
.7 .32191 Mdot
.7 .3243 Mdot
.7 .32455 Mdot
.7 .32456 Mdot
.7 .32475 Mdot
.7 .32478 Mdot
.7 .32498 Mdot
.7 .32547 Mdot
.7 .32613 Mdot
.7 .32677 Mdot
.7 .32693 Mdot
.7 .32694 Mdot
.7 .32782 Mdot
.7 .32799 Mdot
.7 .32977 Mdot
.7 .33018 Mdot
.7 .33048 Mdot
.7 .33235 Mdot
.7 .33264 Mdot
.7 .33275 Mdot
.7 .33293 Mdot
.7 .33334 Mdot
.7 .33412 Mdot
.7 .33465 Mdot
.7 .33604 Mdot
.7 .33663 Mdot
.7 .33703 Mdot
.7 .3378 Mdot
.7 .33875 Mdot
.7 .33979 Mdot
.7 .33981 Mdot
.7 .34164 Mdot
.7 .34214 Mdot
.7 .34228 Mdot
.7 .34238 Mdot
.7 .343 Mdot
.7 .34402 Mdot
.7 .34455 Mdot
.7 .34456 Mdot
.7 .34566 Mdot
.7 .34734 Mdot
.7 .34755 Mdot
.7 .34785 Mdot
.7 .34861 Mdot
.7 .34934 Mdot
.7 .34946 Mdot
.7 .35086 Mdot
.7 .35186 Mdot
.7 .35289 Mdot
.7 .35307 Mdot
.7 .35331 Mdot
.7 .35623 Mdot
.7 .35652 Mdot
.7 .35708 Mdot
.7 .35788 Mdot
.7 .35791 Mdot
.7 .35843 Mdot
.7 .35984 Mdot
.7 .36065 Mdot
.7 .36081 Mdot
.7 .36107 Mdot
.7 .36153 Mdot
.7 .36199 Mdot
.7 .36477 Mdot
.7 .36622 Mdot
.7 .36625 Mdot
.7 .36637 Mdot
.7 .36911 Mdot
.7 .36956 Mdot
.7 .37128 Mdot
.7 .37132 Mdot
.7 .37193 Mdot
.7 .37228 Mdot
.7 .37248 Mdot
.7 .37264 Mdot
.7 .37472 Mdot
.7 .37475 Mdot
.7 .3748 Mdot
.7 .37488 Mdot
.7 .37578 Mdot
.7 .37637 Mdot
.7 .37669 Mdot
.7 .37812 Mdot
.7 .37814 Mdot
.7 .37896 Mdot
.7 .37906 Mdot
.7 .37957 Mdot
.7 .38346 Mdot
.7 .38359 Mdot
.7 .38401 Mdot
.7 .38643 Mdot
.7 .38675 Mdot
.7 .38702 Mdot
.7 .38834 Mdot
.7 .38892 Mdot
.7 .38903 Mdot
.7 .39111 Mdot
.7 .39308 Mdot
.7 .39318 Mdot
.7 .3943 Mdot
.7 .39625 Mdot
.7 .39952 Mdot
.7 .39973 Mdot
.7 .39973 Mdot
.7 .4019 Mdot
.7 .40322 Mdot
.7 .40413 Mdot
.7 .40642 Mdot
.7 .40765 Mdot
.7 .4078 Mdot
.7 .40837 Mdot
.7 .40951 Mdot
.7 .41062 Mdot
.7 .41497 Mdot
.7 .41644 Mdot
.7 .41676 Mdot
.7 .41752 Mdot
.7 .4179 Mdot
.7 .41829 Mdot
.7 .41916 Mdot
.7 .4221 Mdot
.7 .42331 Mdot
.7 .42347 Mdot
.7 .42364 Mdot
.7 .42412 Mdot
.7 .42418 Mdot
.7 .4245 Mdot
.7 .42521 Mdot
.7 .42536 Mdot
.7 .42626 Mdot
.7 .42651 Mdot
.7 .4268 Mdot
.7 .42771 Mdot
.702 .01719 Mdot
.702 .01738 Mdot
.702 .01779 Mdot
.702 .01794 Mdot
.702 .01819 Mdot
.702 .01846 Mdot
.702 .01894 Mdot
.702 .01903 Mdot
.702 .01911 Mdot
.702 .01924 Mdot
.702 .01959 Mdot
.702 .01979 Mdot
.702 .01997 Mdot
.702 .02024 Mdot
.702 .02042 Mdot
.702 .02046 Mdot
.702 .02065 Mdot
.702 .02078 Mdot
.702 .02088 Mdot
.702 .02107 Mdot
.702 .02156 Mdot
.702 .02184 Mdot
.702 .0221 Mdot
.702 .02233 Mdot
.702 .02247 Mdot
.702 .02272 Mdot
.702 .02278 Mdot
.702 .02299 Mdot
.702 .02305 Mdot
.702 .02323 Mdot
.702 .02337 Mdot
.702 .02363 Mdot
.702 .02432 Mdot
.702 .02444 Mdot
.702 .02472 Mdot
.702 .02508 Mdot
.702 .02541 Mdot
.702 .02561 Mdot
.702 .02596 Mdot
.702 .02604 Mdot
.702 .02604 Mdot
.702 .02634 Mdot
.702 .02641 Mdot
.702 .02667 Mdot
.702 .02687 Mdot
.702 .02723 Mdot
.702 .0282 Mdot
.702 .02837 Mdot
.702 .02877 Mdot
.702 .02927 Mdot
.702 .02959 Mdot
.702 .02973 Mdot
.702 .03001 Mdot
.702 .03011 Mdot
.702 .0305 Mdot
.702 .03062 Mdot
.702 .03062 Mdot
.702 .03094 Mdot
.702 .03098 Mdot
.702 .03104 Mdot
.702 .03114 Mdot
.702 .03149 Mdot
.702 .03178 Mdot
.702 .03229 Mdot
.702 .03271 Mdot
.702 .03272 Mdot
.702 .03331 Mdot
.702 .03332 Mdot
.702 .03335 Mdot
.702 .03365 Mdot
.702 .03389 Mdot
.702 .03394 Mdot
.702 .03442 Mdot
.702 .03444 Mdot
.702 .03457 Mdot
.702 .03457 Mdot
.702 .03515 Mdot
.702 .03518 Mdot
.702 .03523 Mdot
.702 .03561 Mdot
.702 .03579 Mdot
.702 .03609 Mdot
.702 .03618 Mdot
.702 .03632 Mdot
.702 .03688 Mdot
.702 .03704 Mdot
.702 .03705 Mdot
.702 .03747 Mdot
.702 .0375 Mdot
.702 .03756 Mdot
.702 .03763 Mdot
.702 .03777 Mdot
.702 .03797 Mdot
.702 .03827 Mdot
.702 .03868 Mdot
.702 .03939 Mdot
.702 .03998 Mdot
.702 .03999 Mdot
.702 .04082 Mdot
.702 .04084 Mdot
.702 .04088 Mdot
.702 .0413 Mdot
.702 .04164 Mdot
.702 .0417 Mdot
.702 .04171 Mdot
.702 .04237 Mdot
.702 .04241 Mdot
.702 .04242 Mdot
.702 .04258 Mdot
.702 .04259 Mdot
.702 .04259 Mdot
.702 .0434 Mdot
.702 .04344 Mdot
.702 .04352 Mdot
.702 .04405 Mdot
.702 .0443 Mdot
.702 .04473 Mdot
.702 .0448 Mdot
.702 .04486 Mdot
.702 .04505 Mdot
.702 .04577 Mdot
.702 .04584 Mdot
.702 .04587 Mdot
.702 .04606 Mdot
.702 .04607 Mdot
.702 .04634 Mdot
.702 .04635 Mdot
.702 .04666 Mdot
.702 .04671 Mdot
.702 .04679 Mdot
.702 .04689 Mdot
.702 .04709 Mdot
.702 .04737 Mdot
.702 .04779 Mdot
.702 .04836 Mdot
.702 .04861 Mdot
.702 .04872 Mdot
.702 .04936 Mdot
.702 .04959 Mdot
.702 .05018 Mdot
.702 .0502 Mdot
.702 .05056 Mdot
.702 .05137 Mdot
.702 .05139 Mdot
.702 .05145 Mdot
.702 .05204 Mdot
.702 .05251 Mdot
.702 .0526 Mdot
.702 .05262 Mdot
.702 .05269 Mdot
.702 .05279 Mdot
.702 .05355 Mdot
.702 .05357 Mdot
.702 .0536 Mdot
.702 .05362 Mdot
.702 .05379 Mdot
.702 .05383 Mdot
.702 .05385 Mdot
.702 .05385 Mdot
.702 .0547 Mdot
.702 .05483 Mdot
.702 .05499 Mdot
.702 .05505 Mdot
.702 .05516 Mdot
.702 .05516 Mdot
.702 .05589 Mdot
.702 .05626 Mdot
.702 .05647 Mdot
.702 .05685 Mdot
.702 .05686 Mdot
.702 .05695 Mdot
.702 .05704 Mdot
.702 .0572 Mdot
.702 .05727 Mdot
.702 .05731 Mdot
.702 .05764 Mdot
.702 .05832 Mdot
.702 .05841 Mdot
.702 .05846 Mdot
.702 .05872 Mdot
.702 .05874 Mdot
.702 .05912 Mdot
.702 .05913 Mdot
.702 .05921 Mdot
.702 .05957 Mdot
.702 .05963 Mdot
.702 .05974 Mdot
.702 .05988 Mdot
.702 .06017 Mdot
.702 .06035 Mdot
.702 .06056 Mdot
.702 .06115 Mdot
.702 .06124 Mdot
.702 .06195 Mdot
.702 .0623 Mdot
.702 .06245 Mdot
.702 .06335 Mdot
.702 .06368 Mdot
.702 .06409 Mdot
.702 .06451 Mdot
.702 .06454 Mdot
.702 .06504 Mdot
.702 .06618 Mdot
.702 .06621 Mdot
.702 .0663 Mdot
.702 .06712 Mdot
.702 .0672 Mdot
.702 .06778 Mdot
.702 .06791 Mdot
.702 .06793 Mdot
.702 .06803 Mdot
.702 .06817 Mdot
.702 .06831 Mdot
.702 .06847 Mdot
.702 .06857 Mdot
.702 .06924 Mdot
.702 .06926 Mdot
.702 .06932 Mdot
.702 .06933 Mdot
.702 .06949 Mdot
.702 .06958 Mdot
.702 .06964 Mdot
.702 .06966 Mdot
.702 .06966 Mdot
.702 .06999 Mdot
.702 .07086 Mdot
.702 .07103 Mdot
.702 .07126 Mdot
.702 .07135 Mdot
.702 .07151 Mdot
.702 .07151 Mdot
.702 .07253 Mdot
.702 .07284 Mdot
.702 .07298 Mdot
.702 .07304 Mdot
.702 .07334 Mdot
.702 .07387 Mdot
.702 .07388 Mdot
.702 .07402 Mdot
.702 .07413 Mdot
.702 .07436 Mdot
.702 .07441 Mdot
.702 .07446 Mdot
.702 .07447 Mdot
.702 .07452 Mdot
.702 .07499 Mdot
.702 .07593 Mdot
.702 .07606 Mdot
.702 .07613 Mdot
.702 .0765 Mdot
.702 .07652 Mdot
.702 .07706 Mdot
.702 .07707 Mdot
.702 .07709 Mdot
.702 .07719 Mdot
.702 .07721 Mdot
.702 .07735 Mdot
.702 .07769 Mdot
.702 .07778 Mdot
.702 .07793 Mdot
.702 .07807 Mdot
.702 .07813 Mdot
.702 .07825 Mdot
.702 .07853 Mdot
.702 .07879 Mdot
.702 .07903 Mdot
.702 .07908 Mdot
.702 .07934 Mdot
.702 .07936 Mdot
.702 .07991 Mdot
.702 .08003 Mdot
.702 .08104 Mdot
.702 .08152 Mdot
.702 .08174 Mdot
.702 .0818 Mdot
.702 .08195 Mdot
.702 .0826 Mdot
.702 .083 Mdot
.702 .08347 Mdot
.702 .0838 Mdot
.702 .08403 Mdot
.702 .08463 Mdot
.702 .08466 Mdot
.702 .08487 Mdot
.702 .08531 Mdot
.702 .08537 Mdot
.702 .08626 Mdot
.702 .08697 Mdot
.702 .08701 Mdot
.702 .08714 Mdot
.702 .08772 Mdot
.702 .08829 Mdot
.702 .08839 Mdot
.702 .08841 Mdot
.702 .08922 Mdot
.702 .0894 Mdot
.702 .08943 Mdot
.702 .08947 Mdot
.702 .08957 Mdot
.702 .08977 Mdot
.702 .08996 Mdot
.702 .09019 Mdot
.702 .09033 Mdot
.702 .09039 Mdot
.702 .09126 Mdot
.702 .0913 Mdot
.702 .09137 Mdot
.702 .0914 Mdot
.702 .09162 Mdot
.702 .09174 Mdot
.702 .09182 Mdot
.702 .09186 Mdot
.702 .09186 Mdot
.702 .09221 Mdot
.702 .09233 Mdot
.702 .09259 Mdot
.702 .09354 Mdot
.702 .09378 Mdot
.702 .09379 Mdot
.702 .09411 Mdot
.702 .09423 Mdot
.702 .09445 Mdot
.702 .09445 Mdot
.702 .09456 Mdot
.702 .09473 Mdot
.702 .09507 Mdot
.702 .09589 Mdot
.702 .09632 Mdot
.702 .09652 Mdot
.702 .09661 Mdot
.702 .09702 Mdot
.702 .09777 Mdot
.702 .09779 Mdot
.702 .09797 Mdot
.702 .09814 Mdot
.702 .09846 Mdot
.702 .09853 Mdot
.702 .0986 Mdot
.702 .09861 Mdot
.702 .09868 Mdot
.702 .09897 Mdot
.702 .09918 Mdot
.702 .09934 Mdot
.702 .09986 Mdot
.702 .10066 Mdot
.702 .10085 Mdot
.702 .10094 Mdot
.702 .10146 Mdot
.702 .10149 Mdot
.702 .10224 Mdot
.702 .10227 Mdot
.702 .10229 Mdot
.702 .10242 Mdot
.702 .10246 Mdot
.702 .10266 Mdot
.702 .10311 Mdot
.702 .10313 Mdot
.702 .10325 Mdot
.702 .10347 Mdot
.702 .10367 Mdot
.702 .10375 Mdot
.702 .10392 Mdot
.702 .10432 Mdot
.702 .10468 Mdot
.702 .10501 Mdot
.702 .10508 Mdot
.702 .10545 Mdot
.702 .10548 Mdot
.702 .10554 Mdot
.702 .10625 Mdot
.702 .10629 Mdot
.702 .10642 Mdot
.702 .1076 Mdot
.702 .10784 Mdot
.702 .10851 Mdot
.702 .10881 Mdot
.702 .10891 Mdot
.702 .10911 Mdot
.702 .11002 Mdot
.702 .11059 Mdot
.702 .11124 Mdot
.702 .11127 Mdot
.702 .11171 Mdot
.702 .11204 Mdot
.702 .11287 Mdot
.702 .11292 Mdot
.702 .11293 Mdot
.702 .11321 Mdot
.702 .11344 Mdot
.702 .11384 Mdot
.702 .11392 Mdot
.702 .11456 Mdot
.702 .11516 Mdot
.702 .11585 Mdot
.702 .11616 Mdot
.702 .11621 Mdot
.702 .11639 Mdot
.702 .11721 Mdot
.702 .11801 Mdot
.702 .11816 Mdot
.702 .11818 Mdot
.702 .11932 Mdot
.702 .11954 Mdot
.702 .11958 Mdot
.702 .11961 Mdot
.702 .11966 Mdot
.702 .11981 Mdot
.702 .12009 Mdot
.702 .12036 Mdot
.702 .12068 Mdot
.702 .12088 Mdot
.702 .12096 Mdot
.702 .12219 Mdot
.702 .12224 Mdot
.702 .12234 Mdot
.702 .12238 Mdot
.702 .12264 Mdot
.702 .12268 Mdot
.702 .12286 Mdot
.702 .12297 Mdot
.702 .12302 Mdot
.702 .12303 Mdot
.702 .12351 Mdot
.702 .12368 Mdot
.702 .12406 Mdot
.702 .12538 Mdot
.702 .12573 Mdot
.702 .12574 Mdot
.702 .12618 Mdot
.702 .12618 Mdot
.702 .12634 Mdot
.702 .12635 Mdot
.702 .12666 Mdot
.702 .12666 Mdot
.702 .12682 Mdot
.702 .12705 Mdot
.702 .12754 Mdot
.702 .12868 Mdot
.702 .12872 Mdot
.702 .12929 Mdot
.702 .12957 Mdot
.702 .12969 Mdot
.702 .13027 Mdot
.702 .1303 Mdot
.702 .13053 Mdot
.702 .13133 Mdot
.702 .13135 Mdot
.702 .13161 Mdot
.702 .13184 Mdot
.702 .13229 Mdot
.702 .1324 Mdot
.702 .13249 Mdot
.702 .1325 Mdot
.702 .1326 Mdot
.702 .133 Mdot
.702 .1333 Mdot
.702 .13352 Mdot
.702 .13426 Mdot
.702 .13506 Mdot
.702 .13535 Mdot
.702 .13539 Mdot
.702 .13541 Mdot
.702 .13565 Mdot
.702 .13578 Mdot
.702 .13651 Mdot
.702 .13655 Mdot
.702 .13692 Mdot
.702 .13693 Mdot
.702 .1376 Mdot
.702 .13764 Mdot
.702 .13767 Mdot
.702 .13786 Mdot
.702 .1379 Mdot
.702 .1381 Mdot
.702 .13818 Mdot
.702 .13819 Mdot
.702 .13882 Mdot
.702 .13886 Mdot
.702 .13902 Mdot
.702 .13933 Mdot
.702 .13961 Mdot
.702 .13972 Mdot
.702 .13996 Mdot
.702 .14034 Mdot
.702 .14051 Mdot
.702 .14079 Mdot
.702 .14103 Mdot
.702 .14149 Mdot
.702 .14159 Mdot
.702 .1419 Mdot
.702 .1421 Mdot
.702 .14214 Mdot
.702 .14223 Mdot
.702 .14323 Mdot
.702 .14329 Mdot
.702 .14346 Mdot
.702 .1443 Mdot
.702 .14512 Mdot
.702 .14546 Mdot
.702 .1464 Mdot
.702 .14683 Mdot
.702 .14696 Mdot
.702 .14725 Mdot
.702 .14758 Mdot
.702 .14853 Mdot
.702 .14933 Mdot
.702 .15024 Mdot
.702 .15028 Mdot
.702 .15089 Mdot
.702 .1513 Mdot
.702 .15136 Mdot
.702 .15252 Mdot
.702 .1526 Mdot
.702 .15261 Mdot
.702 .153 Mdot
.702 .153 Mdot
.702 .15331 Mdot
.702 .15333 Mdot
.702 .15388 Mdot
.702 .154 Mdot
.702 .15428 Mdot
.702 .1549 Mdot
.702 .15575 Mdot
.702 .1567 Mdot
.702 .15714 Mdot
.702 .15722 Mdot
.702 .15747 Mdot
.702 .15862 Mdot
.702 .15875 Mdot
.702 .15925 Mdot
.702 .15974 Mdot
.702 .15995 Mdot
.702 .15998 Mdot
.702 .16121 Mdot
.702 .16159 Mdot
.702 .16189 Mdot
.702 .16194 Mdot
.702 .16199 Mdot
.702 .16206 Mdot
.702 .16227 Mdot
.702 .16266 Mdot
.702 .16304 Mdot
.702 .1631 Mdot
.702 .16349 Mdot
.702 .16377 Mdot
.702 .16389 Mdot
.702 .16392 Mdot
.702 .16404 Mdot
.702 .16561 Mdot
.702 .16568 Mdot
.702 .16583 Mdot
.702 .16588 Mdot
.702 .16624 Mdot
.702 .1663 Mdot
.702 .16655 Mdot
.702 .16671 Mdot
.702 .16678 Mdot
.702 .16679 Mdot
.702 .16747 Mdot
.702 .16771 Mdot
.702 .16823 Mdot
.702 .16881 Mdot
.702 .17009 Mdot
.702 .17028 Mdot
.702 .17058 Mdot
.702 .17059 Mdot
.702 .17122 Mdot
.702 .17122 Mdot
.702 .17143 Mdot
.702 .17144 Mdot
.702 .17145 Mdot
.702 .17166 Mdot
.702 .17183 Mdot
.702 .17189 Mdot
.702 .17189 Mdot
.702 .17211 Mdot
.702 .17213 Mdot
.702 .17244 Mdot
.702 .17294 Mdot
.702 .17312 Mdot
.702 .17447 Mdot
.702 .17473 Mdot
.702 .17478 Mdot
.702 .17558 Mdot
.702 .17594 Mdot
.702 .17597 Mdot
.702 .17614 Mdot
.702 .17614 Mdot
.702 .17696 Mdot
.702 .177 Mdot
.702 .17732 Mdot
.702 .17767 Mdot
.702 .17844 Mdot
.702 .17847 Mdot
.702 .17875 Mdot
.702 .17883 Mdot
.702 .17916 Mdot
.702 .17921 Mdot
.702 .17933 Mdot
.702 .17979 Mdot
.702 .1798 Mdot
.702 .17994 Mdot
.702 .18006 Mdot
.702 .18009 Mdot
.702 .18023 Mdot
.702 .18079 Mdot
.702 .18121 Mdot
.702 .18152 Mdot
.702 .18255 Mdot
.702 .18368 Mdot
.702 .18408 Mdot
.702 .18414 Mdot
.702 .18417 Mdot
.702 .1845 Mdot
.702 .18469 Mdot
.702 .18572 Mdot
.702 .18577 Mdot
.702 .18629 Mdot
.702 .18631 Mdot
.702 .18725 Mdot
.702 .1873 Mdot
.702 .18735 Mdot
.702 .18761 Mdot
.702 .18767 Mdot
.702 .18795 Mdot
.702 .18806 Mdot
.702 .18807 Mdot
.702 .18896 Mdot
.702 .18901 Mdot
.702 .18924 Mdot
.702 .18968 Mdot
.702 .19006 Mdot
.702 .19022 Mdot
.702 .19057 Mdot
.702 .19109 Mdot
.702 .19134 Mdot
.702 .19172 Mdot
.702 .19206 Mdot
.702 .19271 Mdot
.702 .19285 Mdot
.702 .19329 Mdot
.702 .19356 Mdot
.702 .19363 Mdot
.702 .19375 Mdot
.702 .19516 Mdot
.702 .19523 Mdot
.702 .19548 Mdot
.702 .19665 Mdot
.702 .1978 Mdot
.702 .19827 Mdot
.702 .1996 Mdot
.702 .2002 Mdot
.702 .20039 Mdot
.702 .20079 Mdot
.702 .20126 Mdot
.702 .20259 Mdot
.702 .20371 Mdot
.702 .20499 Mdot
.702 .20505 Mdot
.702 .20591 Mdot
.702 .20648 Mdot
.702 .20656 Mdot
.702 .2082 Mdot
.702 .2083 Mdot
.702 .20833 Mdot
.702 .20887 Mdot
.702 .20887 Mdot
.702 .2093 Mdot
.702 .20933 Mdot
.702 .21011 Mdot
.702 .21027 Mdot
.702 .21067 Mdot
.702 .21154 Mdot
.702 .21272 Mdot
.702 .21407 Mdot
.702 .21468 Mdot
.702 .21479 Mdot
.702 .21514 Mdot
.702 .21676 Mdot
.702 .21694 Mdot
.702 .21765 Mdot
.702 .21833 Mdot
.702 .21862 Mdot
.702 .21867 Mdot
.702 .22039 Mdot
.702 .22092 Mdot
.702 .22134 Mdot
.702 .22142 Mdot
.702 .22148 Mdot
.702 .22159 Mdot
.702 .22188 Mdot
.702 .22244 Mdot
.702 .22297 Mdot
.702 .22304 Mdot
.702 .22359 Mdot
.702 .22399 Mdot
.702 .22415 Mdot
.702 .22419 Mdot
.702 .22436 Mdot
.702 .22657 Mdot
.702 .22667 Mdot
.702 .22687 Mdot
.702 .22695 Mdot
.702 .22746 Mdot
.702 .22754 Mdot
.702 .22789 Mdot
.702 .22812 Mdot
.702 .22821 Mdot
.702 .22823 Mdot
.702 .22918 Mdot
.702 .22951 Mdot
.702 .23025 Mdot
.702 .23106 Mdot
.702 .23286 Mdot
.702 .23312 Mdot
.702 .23355 Mdot
.702 .23357 Mdot
.702 .23444 Mdot
.702 .23445 Mdot
.702 .23475 Mdot
.702 .23475 Mdot
.702 .23477 Mdot
.702 .23507 Mdot
.702 .23531 Mdot
.702 .23539 Mdot
.702 .23539 Mdot
.702 .23569 Mdot
.702 .23572 Mdot
.702 .23616 Mdot
.702 .23686 Mdot
.702 .23711 Mdot
.702 .239 Mdot
.702 .23937 Mdot
.702 .23945 Mdot
.702 .24058 Mdot
.702 .24107 Mdot
.702 .24112 Mdot
.702 .24136 Mdot
.702 .24136 Mdot
.702 .24251 Mdot
.702 .24256 Mdot
.702 .24301 Mdot
.702 .2435 Mdot
.702 .24458 Mdot
.702 .24463 Mdot
.702 .24502 Mdot
.702 .24514 Mdot
.702 .2456 Mdot
.702 .24566 Mdot
.702 .24583 Mdot
.702 .24648 Mdot
.702 .2465 Mdot
.702 .24669 Mdot
.702 .24687 Mdot
.702 .2469 Mdot
.702 .24709 Mdot
.702 .24789 Mdot
.702 .24847 Mdot
.702 .24891 Mdot
.702 .25036 Mdot
.702 .25194 Mdot
.702 .2525 Mdot
.702 .25258 Mdot
.702 .25264 Mdot
.702 .2531 Mdot
.702 .25336 Mdot
.702 .2548 Mdot
.702 .25487 Mdot
.702 .2556 Mdot
.702 .25563 Mdot
.702 .25696 Mdot
.702 .25702 Mdot
.702 .25709 Mdot
.702 .25746 Mdot
.702 .25755 Mdot
.702 .25794 Mdot
.702 .2581 Mdot
.702 .25811 Mdot
.702 .25935 Mdot
.702 .25942 Mdot
.702 .25975 Mdot
.702 .26036 Mdot
.702 .2609 Mdot
.702 .26113 Mdot
.702 .26161 Mdot
.702 .26235 Mdot
.702 .26269 Mdot
.702 .26323 Mdot
.702 .2637 Mdot
.702 .26463 Mdot
.702 .26482 Mdot
.702 .26543 Mdot
.702 .26582 Mdot
.702 .26591 Mdot
.702 .26608 Mdot
.702 .26805 Mdot
.702 .26816 Mdot
.702 .26851 Mdot
.702 .27016 Mdot
.702 .27177 Mdot
.702 .27243 Mdot
.702 .2743 Mdot
.702 .27514 Mdot
.702 .2754 Mdot
.702 .27597 Mdot
.702 .27662 Mdot
.702 .27849 Mdot
.702 .28006 Mdot
.702 .28186 Mdot
.702 .28194 Mdot
.702 .28315 Mdot
.702 .28395 Mdot
.702 .28407 Mdot
.702 .28637 Mdot
.702 .28651 Mdot
.702 .28654 Mdot
.702 .28731 Mdot
.702 .28731 Mdot
.702 .28791 Mdot
.702 .28795 Mdot
.702 .28904 Mdot
.702 .28927 Mdot
.702 .28984 Mdot
.702 .29105 Mdot
.702 .29272 Mdot
.702 .2946 Mdot
.702 .29547 Mdot
.702 .29562 Mdot
.702 .29612 Mdot
.702 .29838 Mdot
.702 .29864 Mdot
.702 .29963 Mdot
.702 .30059 Mdot
.702 .301 Mdot
.702 .30107 Mdot
.702 .30348 Mdot
.702 .30423 Mdot
.702 .30482 Mdot
.702 .30493 Mdot
.702 .30502 Mdot
.702 .30517 Mdot
.702 .30558 Mdot
.702 .30636 Mdot
.702 .3071 Mdot
.702 .30721 Mdot
.702 .30798 Mdot
.702 .30853 Mdot
.702 .30876 Mdot
.702 .30882 Mdot
.702 .30906 Mdot
.702 .31216 Mdot
.702 .3123 Mdot
.702 .31259 Mdot
.702 .31269 Mdot
.702 .31341 Mdot
.702 .31352 Mdot
.702 .31401 Mdot
.702 .31433 Mdot
.702 .31446 Mdot
.702 .31449 Mdot
.702 .31582 Mdot
.702 .31629 Mdot
.702 .31732 Mdot
.702 .31846 Mdot
.702 .32099 Mdot
.702 .32136 Mdot
.702 .32196 Mdot
.702 .32198 Mdot
.702 .32321 Mdot
.702 .32322 Mdot
.702 .32364 Mdot
.702 .32365 Mdot
.702 .32367 Mdot
.702 .32409 Mdot
.702 .32443 Mdot
.702 .32454 Mdot
.702 .32454 Mdot
.702 .32497 Mdot
.702 .32501 Mdot
.702 .32562 Mdot
.702 .3266 Mdot
.702 .32696 Mdot
.702 .32962 Mdot
.702 .33013 Mdot
.702 .33024 Mdot
.702 .33182 Mdot
.702 .33252 Mdot
.702 .33259 Mdot
.702 .33292 Mdot
.702 .33293 Mdot
.702 .33453 Mdot
.702 .33461 Mdot
.702 .33524 Mdot
.702 .33593 Mdot
.702 .33744 Mdot
.702 .33752 Mdot
.702 .33807 Mdot
.702 .33823 Mdot
.702 .33888 Mdot
.702 .33897 Mdot
.702 .33921 Mdot
.702 .34011 Mdot
.702 .34014 Mdot
.702 .34041 Mdot
.702 .34065 Mdot
.702 .3407 Mdot
.702 .34097 Mdot
.702 .34209 Mdot
.702 .3429 Mdot
.702 .34353 Mdot
.702 .34556 Mdot
.702 .34778 Mdot
.702 .34857 Mdot
.702 .34868 Mdot
.702 .34876 Mdot
.702 .34941 Mdot
.702 .34977 Mdot
.702 .3518 Mdot
.702 .3519 Mdot
.702 .35292 Mdot
.702 .35296 Mdot
.702 .35482 Mdot
.702 .35491 Mdot
.702 .35501 Mdot
.702 .35552 Mdot
.702 .35565 Mdot
.702 .3562 Mdot
.702 .35642 Mdot
.702 .35644 Mdot
.702 .35818 Mdot
.702 .35828 Mdot
.702 .35875 Mdot
.702 .3596 Mdot
.702 .36036 Mdot
.702 .36068 Mdot
.702 .36135 Mdot
.702 .36239 Mdot
.702 .36287 Mdot
.702 .36364 Mdot
.702 .3643 Mdot
.702 .36559 Mdot
.702 .36586 Mdot
.702 .36672 Mdot
.702 .36727 Mdot
.702 .36739 Mdot
.702 .36763 Mdot
.702 .3704 Mdot
.702 .37055 Mdot
.702 .37104 Mdot
.702 .37335 Mdot
.702 .37562 Mdot
.702 .37655 Mdot
.702 .37917 Mdot
.702 .38035 Mdot
.702 .38071 Mdot
.702 .38151 Mdot
.702 .38243 Mdot
.702 .38506 Mdot
.702 .38727 Mdot
.702 .38979 Mdot
.702 .3899 Mdot
.702 .3916 Mdot
.702 .39272 Mdot
.702 .39288 Mdot
.702 .39611 Mdot
.702 .39631 Mdot
.702 .39636 Mdot
.702 .39743 Mdot
.702 .39744 Mdot
.702 .39828 Mdot
.702 .39834 Mdot
.702 .39987 Mdot
.702 .40019 Mdot
.702 .40099 Mdot
.702 .40269 Mdot
.702 .40503 Mdot
.702 .40768 Mdot
.702 .40889 Mdot
.702 .40911 Mdot
.702 .4098 Mdot
.702 .41298 Mdot
.702 .41334 Mdot
.702 .41474 Mdot
.702 .41608 Mdot
.702 .41666 Mdot
.702 .41675 Mdot
.702 .42015 Mdot
.702 .42119 Mdot
.702 .42202 Mdot
.702 .42218 Mdot
.702 .4223 Mdot
.702 .42251 Mdot
.702 .42309 Mdot
.702 .42418 Mdot
.702 .42523 Mdot
.702 .42537 Mdot
.702 .42646 Mdot
.702 .42723 Mdot
.702 .42756 Mdot
.702 .42764 Mdot
.702 .42798 Mdot
.704 .0163 Mdot
.704 .01694 Mdot
.704 .01729 Mdot
.704 .01785 Mdot
.704 .01826 Mdot
.704 .01834 Mdot
.704 .01913 Mdot
.704 .01971 Mdot
.704 .01982 Mdot
.704 .01982 Mdot
.704 .02093 Mdot
.704 .02093 Mdot
.704 .02174 Mdot
.704 .0219 Mdot
.704 .0219 Mdot
.704 .02221 Mdot
.704 .02241 Mdot
.704 .02346 Mdot
.704 .02346 Mdot
.704 .02461 Mdot
.704 .0247 Mdot
.704 .02483 Mdot
.704 .02483 Mdot
.704 .02494 Mdot
.704 .02504 Mdot
.704 .02526 Mdot
.704 .02555 Mdot
.704 .02642 Mdot
.704 .02658 Mdot
.704 .02659 Mdot
.704 .02703 Mdot
.704 .02703 Mdot
.704 .02717 Mdot
.704 .02747 Mdot
.704 .02814 Mdot
.704 .02865 Mdot
.704 .02869 Mdot
.704 .0287 Mdot
.704 .02877 Mdot
.704 .02895 Mdot
.704 .02895 Mdot
.704 .02911 Mdot
.704 .02926 Mdot
.704 .02957 Mdot
.704 .02997 Mdot
.704 .0312 Mdot
.704 .03142 Mdot
.704 .03143 Mdot
.704 .03205 Mdot
.704 .03206 Mdot
.704 .03225 Mdot
.704 .03267 Mdot
.704 .03362 Mdot
.704 .03393 Mdot
.704 .03433 Mdot
.704 .0344 Mdot
.704 .0344 Mdot
.704 .0344 Mdot
.704 .03443 Mdot
.704 .0345 Mdot
.704 .03476 Mdot
.704 .03476 Mdot
.704 .03495 Mdot
.704 .03498 Mdot
.704 .03519 Mdot
.704 .03534 Mdot
.704 .03562 Mdot
.704 .0361 Mdot
.704 .0362 Mdot
.704 .03719 Mdot
.704 .03773 Mdot
.704 .03781 Mdot
.704 .03793 Mdot
.704 .03824 Mdot
.704 .03825 Mdot
.704 .03851 Mdot
.704 .03882 Mdot
.704 .03906 Mdot
.704 .03913 Mdot
.704 .03914 Mdot
.704 .03916 Mdot
.704 .03941 Mdot
.704 .03984 Mdot
.704 .04 Mdot
.704 .04058 Mdot
.704 .04134 Mdot
.704 .04163 Mdot
.704 .04166 Mdot
.704 .04177 Mdot
.704 .04234 Mdot
.704 .04243 Mdot
.704 .04244 Mdot
.704 .04244 Mdot
.704 .04247 Mdot
.704 .04257 Mdot
.704 .04294 Mdot
.704 .04294 Mdot
.704 .04321 Mdot
.704 .04323 Mdot
.704 .04324 Mdot
.704 .04354 Mdot
.704 .04369 Mdot
.704 .04376 Mdot
.704 .04415 Mdot
.704 .04482 Mdot
.704 .04496 Mdot
.704 .04532 Mdot
.704 .046 Mdot
.704 .04636 Mdot
.704 .04696 Mdot
.704 .0471 Mdot
.704 .04712 Mdot
.704 .04724 Mdot
.704 .0474 Mdot
.704 .04784 Mdot
.704 .04786 Mdot
.704 .04822 Mdot
.704 .04865 Mdot
.704 .04887 Mdot
.704 .049 Mdot
.704 .04909 Mdot
.704 .0491 Mdot
.704 .04913 Mdot
.704 .04949 Mdot
.704 .04974 Mdot
.704 .05009 Mdot
.704 .05031 Mdot
.704 .05048 Mdot
.704 .05113 Mdot
.704 .0515 Mdot
.704 .05162 Mdot
.704 .0522 Mdot
.704 .05239 Mdot
.704 .0525 Mdot
.704 .0526 Mdot
.704 .05266 Mdot
.704 .05281 Mdot
.704 .05313 Mdot
.704 .05361 Mdot
.704 .05373 Mdot
.704 .05375 Mdot
.704 .05375 Mdot
.704 .0538 Mdot
.704 .05394 Mdot
.704 .05446 Mdot
.704 .05446 Mdot
.704 .05483 Mdot
.704 .05486 Mdot
.704 .05488 Mdot
.704 .05531 Mdot
.704 .05552 Mdot
.704 .0556 Mdot
.704 .05617 Mdot
.704 .05711 Mdot
.704 .0573 Mdot
.704 .05781 Mdot
.704 .05876 Mdot
.704 .05885 Mdot
.704 .05927 Mdot
.704 .06011 Mdot
.704 .06031 Mdot
.704 .06034 Mdot
.704 .06051 Mdot
.704 .06055 Mdot
.704 .06074 Mdot
.704 .06135 Mdot
.704 .06138 Mdot
.704 .06164 Mdot
.704 .0619 Mdot
.704 .06249 Mdot
.704 .06256 Mdot
.704 .0628 Mdot
.704 .06298 Mdot
.704 .06303 Mdot
.704 .06311 Mdot
.704 .06313 Mdot
.704 .06317 Mdot
.704 .06341 Mdot
.704 .06346 Mdot
.704 .06363 Mdot
.704 .06367 Mdot
.704 .06371 Mdot
.704 .06403 Mdot
.704 .06437 Mdot
.704 .06452 Mdot
.704 .06484 Mdot
.704 .06508 Mdot
.704 .06515 Mdot
.704 .06558 Mdot
.704 .06559 Mdot
.704 .06599 Mdot
.704 .06618 Mdot
.704 .06651 Mdot
.704 .06668 Mdot
.704 .06749 Mdot
.704 .06776 Mdot
.704 .06792 Mdot
.704 .06806 Mdot
.704 .06814 Mdot
.704 .06835 Mdot
.704 .0688 Mdot
.704 .06947 Mdot
.704 .06965 Mdot
.704 .06967 Mdot
.704 .06967 Mdot
.704 .06975 Mdot
.704 .06994 Mdot
.704 .06994 Mdot
.704 .07068 Mdot
.704 .07068 Mdot
.704 .07075 Mdot
.704 .07103 Mdot
.704 .07111 Mdot
.704 .0712 Mdot
.704 .07124 Mdot
.704 .07127 Mdot
.704 .07161 Mdot
.704 .07187 Mdot
.704 .07216 Mdot
.704 .07229 Mdot
.704 .0723 Mdot
.704 .07298 Mdot
.704 .07308 Mdot
.704 .07381 Mdot
.704 .0744 Mdot
.704 .0744 Mdot
.704 .07443 Mdot
.704 .07468 Mdot
.704 .07539 Mdot
.704 .07673 Mdot
.704 .07686 Mdot
.704 .07699 Mdot
.704 .07745 Mdot
.704 .07837 Mdot
.704 .07863 Mdot
.704 .07891 Mdot
.704 .07896 Mdot
.704 .07919 Mdot
.704 .07925 Mdot
.704 .07951 Mdot
.704 .07991 Mdot
.704 .08037 Mdot
.704 .08042 Mdot
.704 .08079 Mdot
.704 .08115 Mdot
.704 .08157 Mdot
.704 .08199 Mdot
.704 .08208 Mdot
.704 .08242 Mdot
.704 .08259 Mdot
.704 .08267 Mdot
.704 .08274 Mdot
.704 .08286 Mdot
.704 .08289 Mdot
.704 .08295 Mdot
.704 .08328 Mdot
.704 .08334 Mdot
.704 .08358 Mdot
.704 .0836 Mdot
.704 .08365 Mdot
.704 .08369 Mdot
.704 .08415 Mdot
.704 .08462 Mdot
.704 .08485 Mdot
.704 .08529 Mdot
.704 .08562 Mdot
.704 .08573 Mdot
.704 .08622 Mdot
.704 .08633 Mdot
.704 .08635 Mdot
.704 .08691 Mdot
.704 .08718 Mdot
.704 .08722 Mdot
.704 .08764 Mdot
.704 .08788 Mdot
.704 .08827 Mdot
.704 .08835 Mdot
.704 .08903 Mdot
.704 .0894 Mdot
.704 .08963 Mdot
.704 .08983 Mdot
.704 .08994 Mdot
.704 .09023 Mdot
.704 .09059 Mdot
.704 .09087 Mdot
.704 .09182 Mdot
.704 .09206 Mdot
.704 .09209 Mdot
.704 .09209 Mdot
.704 .0922 Mdot
.704 .09247 Mdot
.704 .09248 Mdot
.704 .09351 Mdot
.704 .09351 Mdot
.704 .09361 Mdot
.704 .09401 Mdot
.704 .09412 Mdot
.704 .09425 Mdot
.704 .0943 Mdot
.704 .09435 Mdot
.704 .09437 Mdot
.704 .09482 Mdot
.704 .09519 Mdot
.704 .0956 Mdot
.704 .09578 Mdot
.704 .0958 Mdot
.704 .09641 Mdot
.704 .09676 Mdot
.704 .09689 Mdot
.704 .09792 Mdot
.704 .09859 Mdot
.704 .09875 Mdot
.704 .09876 Mdot
.704 .09879 Mdot
.704 .09892 Mdot
.704 .09914 Mdot
.704 .10007 Mdot
.704 .10014 Mdot
.704 .10063 Mdot
.704 .10073 Mdot
.704 .1012 Mdot
.704 .10203 Mdot
.704 .10221 Mdot
.704 .1024 Mdot
.704 .10287 Mdot
.704 .10305 Mdot
.704 .10326 Mdot
.704 .10366 Mdot
.704 .10434 Mdot
.704 .10471 Mdot
.704 .10511 Mdot
.704 .10517 Mdot
.704 .10547 Mdot
.704 .10549 Mdot
.704 .10558 Mdot
.704 .10595 Mdot
.704 .10635 Mdot
.704 .10651 Mdot
.704 .10716 Mdot
.704 .10723 Mdot
.704 .10774 Mdot
.704 .10825 Mdot
.704 .10885 Mdot
.704 .10944 Mdot
.704 .10956 Mdot
.704 .10971 Mdot
.704 .10998 Mdot
.704 .11004 Mdot
.704 .11028 Mdot
.704 .11033 Mdot
.704 .1104 Mdot
.704 .1105 Mdot
.704 .11066 Mdot
.704 .1107 Mdot
.704 .11078 Mdot
.704 .11125 Mdot
.704 .11134 Mdot
.704 .11168 Mdot
.704 .11171 Mdot
.704 .11177 Mdot
.704 .11184 Mdot
.704 .11247 Mdot
.704 .11315 Mdot
.704 .11318 Mdot
.704 .11346 Mdot
.704 .11408 Mdot
.704 .11455 Mdot
.704 .11471 Mdot
.704 .1154 Mdot
.704 .11555 Mdot
.704 .11558 Mdot
.704 .11599 Mdot
.704 .11636 Mdot
.704 .11675 Mdot
.704 .1168 Mdot
.704 .1174 Mdot
.704 .11773 Mdot
.704 .11829 Mdot
.704 .11839 Mdot
.704 .11929 Mdot
.704 .11935 Mdot
.704 .11987 Mdot
.704 .1202 Mdot
.704 .12048 Mdot
.704 .12063 Mdot
.704 .12105 Mdot
.704 .12155 Mdot
.704 .12194 Mdot
.704 .12255 Mdot
.704 .12318 Mdot
.704 .12324 Mdot
.704 .12327 Mdot
.704 .12362 Mdot
.704 .12366 Mdot
.704 .12367 Mdot
.704 .12381 Mdot
.704 .12406 Mdot
.704 .1242 Mdot
.704 .1242 Mdot
.704 .12553 Mdot
.704 .12565 Mdot
.704 .12566 Mdot
.704 .12579 Mdot
.704 .12589 Mdot
.704 .12636 Mdot
.704 .12652 Mdot
.704 .1267 Mdot
.704 .12678 Mdot
.704 .12684 Mdot
.704 .12686 Mdot
.704 .12723 Mdot
.704 .12749 Mdot
.704 .1275 Mdot
.704 .1279 Mdot
.704 .12802 Mdot
.704 .12843 Mdot
.704 .1286 Mdot
.704 .12885 Mdot
.704 .12888 Mdot
.704 .12933 Mdot
.704 .12956 Mdot
.704 .12974 Mdot
.704 .13 Mdot
.704 .13023 Mdot
.704 .13042 Mdot
.704 .13187 Mdot
.704 .13258 Mdot
.704 .13282 Mdot
.704 .13303 Mdot
.704 .13305 Mdot
.704 .13309 Mdot
.704 .13311 Mdot
.704 .13328 Mdot
.704 .13348 Mdot
.704 .13359 Mdot
.704 .1349 Mdot
.704 .13497 Mdot
.704 .13499 Mdot
.704 .13512 Mdot
.704 .13547 Mdot
.704 .13568 Mdot
.704 .13583 Mdot
.704 .13584 Mdot
.704 .13649 Mdot
.704 .13684 Mdot
.704 .13723 Mdot
.704 .13766 Mdot
.704 .13791 Mdot
.704 .13817 Mdot
.704 .13884 Mdot
.704 .13909 Mdot
.704 .13936 Mdot
.704 .13938 Mdot
.704 .13995 Mdot
.704 .14091 Mdot
.704 .14143 Mdot
.704 .14199 Mdot
.704 .14207 Mdot
.704 .14236 Mdot
.704 .1425 Mdot
.704 .14253 Mdot
.704 .14265 Mdot
.704 .14307 Mdot
.704 .14317 Mdot
.704 .14328 Mdot
.704 .14374 Mdot
.704 .14396 Mdot
.704 .14481 Mdot
.704 .14488 Mdot
.704 .14497 Mdot
.704 .1457 Mdot
.704 .14641 Mdot
.704 .14725 Mdot
.704 .14808 Mdot
.704 .14824 Mdot
.704 .14826 Mdot
.704 .14847 Mdot
.704 .14884 Mdot
.704 .14893 Mdot
.704 .14927 Mdot
.704 .14934 Mdot
.704 .14944 Mdot
.704 .14958 Mdot
.704 .14981 Mdot
.704 .14986 Mdot
.704 .14998 Mdot
.704 .15064 Mdot
.704 .15077 Mdot
.704 .15086 Mdot
.704 .15124 Mdot
.704 .15128 Mdot
.704 .15137 Mdot
.704 .15146 Mdot
.704 .15172 Mdot
.704 .15182 Mdot
.704 .15236 Mdot
.704 .15312 Mdot
.704 .1533 Mdot
.704 .15336 Mdot
.704 .15375 Mdot
.704 .15462 Mdot
.704 .15515 Mdot
.704 .15529 Mdot
.704 .1555 Mdot
.704 .15553 Mdot
.704 .15586 Mdot
.704 .15638 Mdot
.704 .15647 Mdot
.704 .15656 Mdot
.704 .15669 Mdot
.704 .15674 Mdot
.704 .15731 Mdot
.704 .15784 Mdot
.704 .15837 Mdot
.704 .15845 Mdot
.704 .15883 Mdot
.704 .1593 Mdot
.704 .15976 Mdot
.704 .16054 Mdot
.704 .16069 Mdot
.704 .16088 Mdot
.704 .16196 Mdot
.704 .16204 Mdot
.704 .16277 Mdot
.704 .163 Mdot
.704 .16323 Mdot
.704 .16329 Mdot
.704 .16363 Mdot
.704 .16384 Mdot
.704 .16443 Mdot
.704 .16479 Mdot
.704 .16513 Mdot
.704 .16569 Mdot
.704 .16655 Mdot
.704 .16662 Mdot
.704 .16744 Mdot
.704 .16752 Mdot
.704 .16756 Mdot
.704 .16806 Mdot
.704 .16811 Mdot
.704 .16812 Mdot
.704 .16833 Mdot
.704 .16843 Mdot
.704 .16867 Mdot
.704 .16887 Mdot
.704 .16887 Mdot
.704 .17075 Mdot
.704 .17092 Mdot
.704 .17093 Mdot
.704 .17111 Mdot
.704 .17125 Mdot
.704 .17152 Mdot
.704 .17192 Mdot
.704 .17211 Mdot
.704 .17214 Mdot
.704 .17239 Mdot
.704 .1725 Mdot
.704 .17259 Mdot
.704 .17262 Mdot
.704 .17286 Mdot
.704 .17313 Mdot
.704 .1735 Mdot
.704 .17352 Mdot
.704 .17408 Mdot
.704 .17424 Mdot
.704 .17483 Mdot
.704 .17507 Mdot
.704 .17541 Mdot
.704 .17546 Mdot
.704 .1761 Mdot
.704 .17641 Mdot
.704 .17668 Mdot
.704 .17704 Mdot
.704 .17708 Mdot
.704 .17736 Mdot
.704 .1774 Mdot
.704 .17763 Mdot
.704 .17968 Mdot
.704 .18028 Mdot
.704 .18067 Mdot
.704 .181 Mdot
.704 .18117 Mdot
.704 .18131 Mdot
.704 .18133 Mdot
.704 .18139 Mdot
.704 .18141 Mdot
.704 .18165 Mdot
.704 .18193 Mdot
.704 .18209 Mdot
.704 .18209 Mdot
.704 .1823 Mdot
.704 .18365 Mdot
.704 .18394 Mdot
.704 .18404 Mdot
.704 .18407 Mdot
.704 .18425 Mdot
.704 .1845 Mdot
.704 .18474 Mdot
.704 .18504 Mdot
.704 .18524 Mdot
.704 .18526 Mdot
.704 .18617 Mdot
.704 .18667 Mdot
.704 .18722 Mdot
.704 .18781 Mdot
.704 .18818 Mdot
.704 .18854 Mdot
.704 .18948 Mdot
.704 .18984 Mdot
.704 .19022 Mdot
.704 .19024 Mdot
.704 .19105 Mdot
.704 .1924 Mdot
.704 .19313 Mdot
.704 .19391 Mdot
.704 .19403 Mdot
.704 .19444 Mdot
.704 .19464 Mdot
.704 .19468 Mdot
.704 .19485 Mdot
.704 .19545 Mdot
.704 .19558 Mdot
.704 .19573 Mdot
.704 .19638 Mdot
.704 .19669 Mdot
.704 .1979 Mdot
.704 .19799 Mdot
.704 .19812 Mdot
.704 .19914 Mdot
.704 .20015 Mdot
.704 .20133 Mdot
.704 .2025 Mdot
.704 .20272 Mdot
.704 .20274 Mdot
.704 .20304 Mdot
.704 .20356 Mdot
.704 .20369 Mdot
.704 .20417 Mdot
.704 .20427 Mdot
.704 .20441 Mdot
.704 .2046 Mdot
.704 .20493 Mdot
.704 .20501 Mdot
.704 .20517 Mdot
.704 .20609 Mdot
.704 .20628 Mdot
.704 .20641 Mdot
.704 .20695 Mdot
.704 .207 Mdot
.704 .20712 Mdot
.704 .20726 Mdot
.704 .20762 Mdot
.704 .20776 Mdot
.704 .20852 Mdot
.704 .20959 Mdot
.704 .20985 Mdot
.704 .20992 Mdot
.704 .21047 Mdot
.704 .2117 Mdot
.704 .21244 Mdot
.704 .21264 Mdot
.704 .21295 Mdot
.704 .21298 Mdot
.704 .21345 Mdot
.704 .21417 Mdot
.704 .21431 Mdot
.704 .21443 Mdot
.704 .21461 Mdot
.704 .21468 Mdot
.704 .21549 Mdot
.704 .21623 Mdot
.704 .21699 Mdot
.704 .21709 Mdot
.704 .21763 Mdot
.704 .21828 Mdot
.704 .21893 Mdot
.704 .22004 Mdot
.704 .22025 Mdot
.704 .22052 Mdot
.704 .22203 Mdot
.704 .22215 Mdot
.704 .22318 Mdot
.704 .2235 Mdot
.704 .22383 Mdot
.704 .2239 Mdot
.704 .22438 Mdot
.704 .22469 Mdot
.704 .22551 Mdot
.704 .22601 Mdot
.704 .2265 Mdot
.704 .22729 Mdot
.704 .22849 Mdot
.704 .2286 Mdot
.704 .22975 Mdot
.704 .22987 Mdot
.704 .22993 Mdot
.704 .23062 Mdot
.704 .2307 Mdot
.704 .23071 Mdot
.704 .231 Mdot
.704 .23115 Mdot
.704 .23149 Mdot
.704 .23177 Mdot
.704 .23177 Mdot
.704 .23441 Mdot
.704 .23465 Mdot
.704 .23466 Mdot
.704 .23492 Mdot
.704 .23512 Mdot
.704 .2355 Mdot
.704 .23605 Mdot
.704 .23632 Mdot
.704 .23637 Mdot
.704 .23672 Mdot
.704 .23687 Mdot
.704 .237 Mdot
.704 .23705 Mdot
.704 .23739 Mdot
.704 .23776 Mdot
.704 .23829 Mdot
.704 .23831 Mdot
.704 .2391 Mdot
.704 .23933 Mdot
.704 .24015 Mdot
.704 .24049 Mdot
.704 .24098 Mdot
.704 .24105 Mdot
.704 .24194 Mdot
.704 .24238 Mdot
.704 .24276 Mdot
.704 .24327 Mdot
.704 .24333 Mdot
.704 .24372 Mdot
.704 .24378 Mdot
.704 .24409 Mdot
.704 .24698 Mdot
.704 .24784 Mdot
.704 .24839 Mdot
.704 .24885 Mdot
.704 .24909 Mdot
.704 .24928 Mdot
.704 .2493 Mdot
.704 .24939 Mdot
.704 .24943 Mdot
.704 .24976 Mdot
.704 .25016 Mdot
.704 .25037 Mdot
.704 .25038 Mdot
.704 .25068 Mdot
.704 .25257 Mdot
.704 .25298 Mdot
.704 .25312 Mdot
.704 .25316 Mdot
.704 .25341 Mdot
.704 .25377 Mdot
.704 .25411 Mdot
.704 .25453 Mdot
.704 .25482 Mdot
.704 .25484 Mdot
.704 .25613 Mdot
.704 .25683 Mdot
.704 .2576 Mdot
.704 .25844 Mdot
.704 .25895 Mdot
.704 .25946 Mdot
.704 .26079 Mdot
.704 .26129 Mdot
.704 .26182 Mdot
.704 .26186 Mdot
.704 .26299 Mdot
.704 .26489 Mdot
.704 .26593 Mdot
.704 .26703 Mdot
.704 .26719 Mdot
.704 .26777 Mdot
.704 .26805 Mdot
.704 .26811 Mdot
.704 .26834 Mdot
.704 .26918 Mdot
.704 .26938 Mdot
.704 .26958 Mdot
.704 .2705 Mdot
.704 .27094 Mdot
.704 .27263 Mdot
.704 .27277 Mdot
.704 .27295 Mdot
.704 .27438 Mdot
.704 .2758 Mdot
.704 .27747 Mdot
.704 .27911 Mdot
.704 .27943 Mdot
.704 .27946 Mdot
.704 .27987 Mdot
.704 .28062 Mdot
.704 .2808 Mdot
.704 .28147 Mdot
.704 .2816 Mdot
.704 .28181 Mdot
.704 .28208 Mdot
.704 .28253 Mdot
.704 .28264 Mdot
.704 .28287 Mdot
.704 .28417 Mdot
.704 .28444 Mdot
.704 .28462 Mdot
.704 .28538 Mdot
.704 .28545 Mdot
.704 .28563 Mdot
.704 .28581 Mdot
.704 .28632 Mdot
.704 .28652 Mdot
.704 .28759 Mdot
.704 .2891 Mdot
.704 .28946 Mdot
.704 .28956 Mdot
.704 .29034 Mdot
.704 .29207 Mdot
.704 .29339 Mdot
.704 .29382 Mdot
.704 .29387 Mdot
.704 .29453 Mdot
.704 .29555 Mdot
.704 .29575 Mdot
.704 .29591 Mdot
.704 .29617 Mdot
.704 .29626 Mdot
.704 .29741 Mdot
.704 .29845 Mdot
.704 .29951 Mdot
.704 .29966 Mdot
.704 .30041 Mdot
.704 .30134 Mdot
.704 .30225 Mdot
.704 .30381 Mdot
.704 .30411 Mdot
.704 .30449 Mdot
.704 .30662 Mdot
.704 .30678 Mdot
.704 .30823 Mdot
.704 .30868 Mdot
.704 .30914 Mdot
.704 .30925 Mdot
.704 .30993 Mdot
.704 .31036 Mdot
.704 .31152 Mdot
.704 .31222 Mdot
.704 .31291 Mdot
.704 .31402 Mdot
.704 .31572 Mdot
.704 .31586 Mdot
.704 .31748 Mdot
.704 .31766 Mdot
.704 .31773 Mdot
.704 .31871 Mdot
.704 .31882 Mdot
.704 .31883 Mdot
.704 .31924 Mdot
.704 .31945 Mdot
.704 .31993 Mdot
.704 .32032 Mdot
.704 .32033 Mdot
.704 .32404 Mdot
.704 .32438 Mdot
.704 .3244 Mdot
.704 .32477 Mdot
.704 .32504 Mdot
.704 .32558 Mdot
.704 .32636 Mdot
.704 .32674 Mdot
.704 .3268 Mdot
.704 .3273 Mdot
.704 .32751 Mdot
.704 .32769 Mdot
.704 .32776 Mdot
.704 .32824 Mdot
.704 .32877 Mdot
.704 .32951 Mdot
.704 .32954 Mdot
.704 .33065 Mdot
.704 .33098 Mdot
.704 .33213 Mdot
.704 .33261 Mdot
.704 .3333 Mdot
.704 .3334 Mdot
.704 .33465 Mdot
.704 .33527 Mdot
.704 .3358 Mdot
.704 .33652 Mdot
.704 .33661 Mdot
.704 .33715 Mdot
.704 .33723 Mdot
.704 .33768 Mdot
.704 .34174 Mdot
.704 .34295 Mdot
.704 .34372 Mdot
.704 .34438 Mdot
.704 .34471 Mdot
.704 .34498 Mdot
.704 .34501 Mdot
.704 .34513 Mdot
.704 .34519 Mdot
.704 .34566 Mdot
.704 .34622 Mdot
.704 .34652 Mdot
.704 .34653 Mdot
.704 .34695 Mdot
.704 .34962 Mdot
.704 .35019 Mdot
.704 .35039 Mdot
.704 .35045 Mdot
.704 .3508 Mdot
.704 .3513 Mdot
.704 .35178 Mdot
.704 .35237 Mdot
.704 .35278 Mdot
.704 .3528 Mdot
.704 .35463 Mdot
.704 .35561 Mdot
.704 .3567 Mdot
.704 .35788 Mdot
.704 .3586 Mdot
.704 .35932 Mdot
.704 .36118 Mdot
.704 .36189 Mdot
.704 .36264 Mdot
.704 .36269 Mdot
.704 .36428 Mdot
.704 .36697 Mdot
.704 .36842 Mdot
.704 .36997 Mdot
.704 .3702 Mdot
.704 .37102 Mdot
.704 .37141 Mdot
.704 .37149 Mdot
.704 .37182 Mdot
.704 .37301 Mdot
.704 .37328 Mdot
.704 .37357 Mdot
.704 .37486 Mdot
.704 .37548 Mdot
.704 .37786 Mdot
.704 .37805 Mdot
.704 .3783 Mdot
.704 .38033 Mdot
.704 .38233 Mdot
.704 .38467 Mdot
.704 .38698 Mdot
.704 .38743 Mdot
.704 .38748 Mdot
.704 .38806 Mdot
.704 .3891 Mdot
.704 .38936 Mdot
.704 .3903 Mdot
.704 .39049 Mdot
.704 .39078 Mdot
.704 .39116 Mdot
.704 .3918 Mdot
.704 .39196 Mdot
.704 .39228 Mdot
.704 .39411 Mdot
.704 .39448 Mdot
.704 .39474 Mdot
.704 .39581 Mdot
.704 .39591 Mdot
.704 .39616 Mdot
.704 .39642 Mdot
.704 .39713 Mdot
.704 .39741 Mdot
.704 .39892 Mdot
.704 .40106 Mdot
.704 .40156 Mdot
.704 .4017 Mdot
.704 .4028 Mdot
.704 .40523 Mdot
.704 .40709 Mdot
.704 .4077 Mdot
.704 .40777 Mdot
.704 .4087 Mdot
.704 .41013 Mdot
.704 .41041 Mdot
.704 .41064 Mdot
.704 .41101 Mdot
.704 .41114 Mdot
.704 .41275 Mdot
.704 .41421 Mdot
.704 .41571 Mdot
.704 .41591 Mdot
.704 .41698 Mdot
.704 .41828 Mdot
.704 .41957 Mdot
.704 .42177 Mdot
.704 .42218 Mdot
.704 .42272 Mdot
.704 .42572 Mdot
.704 .42594 Mdot
.704 .42799 Mdot
.704 .42862 Mdot
.704 .42927 Mdot
.704 .42942 Mdot
.704 .43038 Mdot
.704 .43098 Mdot
.706 .01771 Mdot
.706 .01774 Mdot
.706 .01823 Mdot
.706 .01894 Mdot
.706 .01899 Mdot
.706 .01968 Mdot
.706 .0204 Mdot
.706 .02068 Mdot
.706 .02075 Mdot
.706 .02173 Mdot
.706 .02185 Mdot
.706 .02189 Mdot
.706 .02253 Mdot
.706 .02274 Mdot
.706 .02314 Mdot
.706 .02315 Mdot
.706 .02323 Mdot
.706 .02462 Mdot
.706 .0248 Mdot
.706 .02484 Mdot
.706 .02574 Mdot
.706 .02604 Mdot
.706 .02607 Mdot
.706 .02611 Mdot
.706 .02661 Mdot
.706 .02663 Mdot
.706 .02674 Mdot
.706 .0287 Mdot
.706 .02895 Mdot
.706 .02901 Mdot
.706 .03029 Mdot
.706 .03071 Mdot
.706 .03075 Mdot
.706 .0308 Mdot
.706 .03151 Mdot
.706 .03153 Mdot
.706 .03169 Mdot
.706 .03182 Mdot
.706 .03197 Mdot
.706 .03446 Mdot
.706 .03459 Mdot
.706 .03481 Mdot
.706 .0349 Mdot
.706 .03562 Mdot
.706 .0367 Mdot
.706 .03682 Mdot
.706 .0373 Mdot
.706 .03735 Mdot
.706 .03743 Mdot
.706 .03781 Mdot
.706 .03843 Mdot
.706 .03845 Mdot
.706 .03846 Mdot
.706 .03869 Mdot
.706 .03887 Mdot
.706 .03908 Mdot
.706 .04041 Mdot
.706 .04058 Mdot
.706 .04095 Mdot
.706 .04167 Mdot
.706 .0426 Mdot
.706 .04277 Mdot
.706 .0428 Mdot
.706 .04309 Mdot
.706 .04311 Mdot
.706 .04322 Mdot
.706 .04348 Mdot
.706 .04354 Mdot
.706 .04423 Mdot
.706 .04559 Mdot
.706 .04576 Mdot
.706 .04584 Mdot
.706 .04593 Mdot
.706 .04637 Mdot
.706 .0466 Mdot
.706 .04668 Mdot
.706 .04679 Mdot
.706 .04718 Mdot
.706 .04733 Mdot
.706 .04763 Mdot
.706 .04819 Mdot
.706 .04823 Mdot
.706 .04824 Mdot
.706 .04824 Mdot
.706 .0485 Mdot
.706 .04857 Mdot
.706 .04869 Mdot
.706 .04881 Mdot
.706 .04911 Mdot
.706 .04999 Mdot
.706 .05099 Mdot
.706 .05124 Mdot
.706 .05164 Mdot
.706 .05176 Mdot
.706 .05177 Mdot
.706 .05267 Mdot
.706 .05278 Mdot
.706 .05409 Mdot
.706 .05434 Mdot
.706 .05437 Mdot
.706 .05478 Mdot
.706 .05481 Mdot
.706 .05497 Mdot
.706 .05534 Mdot
.706 .05542 Mdot
.706 .05596 Mdot
.706 .05637 Mdot
.706 .05639 Mdot
.706 .05669 Mdot
.706 .05681 Mdot
.706 .05761 Mdot
.706 .05831 Mdot
.706 .05855 Mdot
.706 .05867 Mdot
.706 .05872 Mdot
.706 .05873 Mdot
.706 .0588 Mdot
.706 .05941 Mdot
.706 .05953 Mdot
.706 .05974 Mdot
.706 .05985 Mdot
.706 .06001 Mdot
.706 .06055 Mdot
.706 .06076 Mdot
.706 .0612 Mdot
.706 .06127 Mdot
.706 .06199 Mdot
.706 .06204 Mdot
.706 .06205 Mdot
.706 .06206 Mdot
.706 .06242 Mdot
.706 .06251 Mdot
.706 .06269 Mdot
.706 .06286 Mdot
.706 .06292 Mdot
.706 .06328 Mdot
.706 .06335 Mdot
.706 .06336 Mdot
.706 .06359 Mdot
.706 .0638 Mdot
.706 .06423 Mdot
.706 .06452 Mdot
.706 .06519 Mdot
.706 .06527 Mdot
.706 .06594 Mdot
.706 .06628 Mdot
.706 .06664 Mdot
.706 .06682 Mdot
.706 .06685 Mdot
.706 .06693 Mdot
.706 .06703 Mdot
.706 .06704 Mdot
.706 .06708 Mdot
.706 .06778 Mdot
.706 .0683 Mdot
.706 .0683 Mdot
.706 .06846 Mdot
.706 .06883 Mdot
.706 .0699 Mdot
.706 .07019 Mdot
.706 .07031 Mdot
.706 .07039 Mdot
.706 .07066 Mdot
.706 .07071 Mdot
.706 .07129 Mdot
.706 .07132 Mdot
.706 .07149 Mdot
.706 .07155 Mdot
.706 .07163 Mdot
.706 .07207 Mdot
.706 .07218 Mdot
.706 .07295 Mdot
.706 .07353 Mdot
.706 .07356 Mdot
.706 .07398 Mdot
.706 .07416 Mdot
.706 .07528 Mdot
.706 .07627 Mdot
.706 .07661 Mdot
.706 .07678 Mdot
.706 .07685 Mdot
.706 .07686 Mdot
.706 .07696 Mdot
.706 .07717 Mdot
.706 .07783 Mdot
.706 .078 Mdot
.706 .07829 Mdot
.706 .07844 Mdot
.706 .07867 Mdot
.706 .07938 Mdot
.706 .07944 Mdot
.706 .07973 Mdot
.706 .08033 Mdot
.706 .08035 Mdot
.706 .08045 Mdot
.706 .08047 Mdot
.706 .08052 Mdot
.706 .08146 Mdot
.706 .08154 Mdot
.706 .08155 Mdot
.706 .08156 Mdot
.706 .08173 Mdot
.706 .08177 Mdot
.706 .08196 Mdot
.706 .08207 Mdot
.706 .08221 Mdot
.706 .08246 Mdot
.706 .0827 Mdot
.706 .08278 Mdot
.706 .0833 Mdot
.706 .08339 Mdot
.706 .08341 Mdot
.706 .08373 Mdot
.706 .08403 Mdot
.706 .08464 Mdot
.706 .08502 Mdot
.706 .08504 Mdot
.706 .08507 Mdot
.706 .08598 Mdot
.706 .0861 Mdot
.706 .08705 Mdot
.706 .08753 Mdot
.706 .08776 Mdot
.706 .08803 Mdot
.706 .08827 Mdot
.706 .08829 Mdot
.706 .08833 Mdot
.706 .08844 Mdot
.706 .08846 Mdot
.706 .08858 Mdot
.706 .08859 Mdot
.706 .08865 Mdot
.706 .08906 Mdot
.706 .08963 Mdot
.706 .08964 Mdot
.706 .08973 Mdot
.706 .09037 Mdot
.706 .09038 Mdot
.706 .09049 Mdot
.706 .0906 Mdot
.706 .09113 Mdot
.706 .09215 Mdot
.706 .09217 Mdot
.706 .09264 Mdot
.706 .09304 Mdot
.706 .09321 Mdot
.706 .09333 Mdot
.706 .09371 Mdot
.706 .09377 Mdot
.706 .0946 Mdot
.706 .09465 Mdot
.706 .09488 Mdot
.706 .09496 Mdot
.706 .09507 Mdot
.706 .09512 Mdot
.706 .0957 Mdot
.706 .09586 Mdot
.706 .09652 Mdot
.706 .09694 Mdot
.706 .09739 Mdot
.706 .09777 Mdot
.706 .09781 Mdot
.706 .09811 Mdot
.706 .0984 Mdot
.706 .09865 Mdot
.706 .09874 Mdot
.706 .10023 Mdot
.706 .10104 Mdot
.706 .10108 Mdot
.706 .10163 Mdot
.706 .10164 Mdot
.706 .10211 Mdot
.706 .10224 Mdot
.706 .10235 Mdot
.706 .10245 Mdot
.706 .10246 Mdot
.706 .1026 Mdot
.706 .1029 Mdot
.706 .1029 Mdot
.706 .10383 Mdot
.706 .10407 Mdot
.706 .10408 Mdot
.706 .10448 Mdot
.706 .10469 Mdot
.706 .10502 Mdot
.706 .10568 Mdot
.706 .10602 Mdot
.706 .1061 Mdot
.706 .10652 Mdot
.706 .10736 Mdot
.706 .10738 Mdot
.706 .10754 Mdot
.706 .10756 Mdot
.706 .10763 Mdot
.706 .1078 Mdot
.706 .10896 Mdot
.706 .10907 Mdot
.706 .10909 Mdot
.706 .10911 Mdot
.706 .10934 Mdot
.706 .10939 Mdot
.706 .10966 Mdot
.706 .10969 Mdot
.706 .10982 Mdot
.706 .11001 Mdot
.706 .11015 Mdot
.706 .11036 Mdot
.706 .11071 Mdot
.706 .11082 Mdot
.706 .11155 Mdot
.706 .11168 Mdot
.706 .11171 Mdot
.706 .11177 Mdot
.706 .11189 Mdot
.706 .11216 Mdot
.706 .11248 Mdot
.706 .11258 Mdot
.706 .11344 Mdot
.706 .11398 Mdot
.706 .11401 Mdot
.706 .11406 Mdot
.706 .11535 Mdot
.706 .11551 Mdot
.706 .11685 Mdot
.706 .11723 Mdot
.706 .11734 Mdot
.706 .11753 Mdot
.706 .11786 Mdot
.706 .11819 Mdot
.706 .11824 Mdot
.706 .11831 Mdot
.706 .11857 Mdot
.706 .1186 Mdot
.706 .11866 Mdot
.706 .11872 Mdot
.706 .11881 Mdot
.706 .11884 Mdot
.706 .11888 Mdot
.706 .11902 Mdot
.706 .11903 Mdot
.706 .11912 Mdot
.706 .11968 Mdot
.706 .11969 Mdot
.706 .1205 Mdot
.706 .12051 Mdot
.706 .12063 Mdot
.706 .12118 Mdot
.706 .12154 Mdot
.706 .12155 Mdot
.706 .12171 Mdot
.706 .12187 Mdot
.706 .1226 Mdot
.706 .12261 Mdot
.706 .12405 Mdot
.706 .12409 Mdot
.706 .12475 Mdot
.706 .12531 Mdot
.706 .12556 Mdot
.706 .12572 Mdot
.706 .12621 Mdot
.706 .12625 Mdot
.706 .12635 Mdot
.706 .12681 Mdot
.706 .12689 Mdot
.706 .127 Mdot
.706 .12751 Mdot
.706 .12758 Mdot
.706 .12791 Mdot
.706 .12803 Mdot
.706 .12818 Mdot
.706 .12825 Mdot
.706 .12829 Mdot
.706 .12862 Mdot
.706 .12907 Mdot
.706 .12929 Mdot
.706 .13012 Mdot
.706 .13023 Mdot
.706 .13031 Mdot
.706 .13082 Mdot
.706 .13102 Mdot
.706 .13146 Mdot
.706 .13199 Mdot
.706 .13204 Mdot
.706 .1321 Mdot
.706 .13246 Mdot
.706 .13285 Mdot
.706 .13288 Mdot
.706 .13323 Mdot
.706 .13336 Mdot
.706 .13406 Mdot
.706 .13546 Mdot
.706 .13601 Mdot
.706 .1366 Mdot
.706 .13662 Mdot
.706 .13666 Mdot
.706 .13743 Mdot
.706 .13745 Mdot
.706 .13812 Mdot
.706 .1383 Mdot
.706 .13845 Mdot
.706 .13859 Mdot
.706 .13862 Mdot
.706 .13881 Mdot
.706 .13923 Mdot
.706 .13923 Mdot
.706 .13997 Mdot
.706 .14033 Mdot
.706 .14055 Mdot
.706 .14073 Mdot
.706 .14089 Mdot
.706 .1409 Mdot
.706 .14146 Mdot
.706 .14147 Mdot
.706 .14161 Mdot
.706 .14176 Mdot
.706 .14193 Mdot
.706 .14223 Mdot
.706 .14263 Mdot
.706 .14316 Mdot
.706 .14364 Mdot
.706 .14375 Mdot
.706 .14416 Mdot
.706 .14419 Mdot
.706 .14434 Mdot
.706 .14554 Mdot
.706 .14556 Mdot
.706 .14578 Mdot
.706 .14581 Mdot
.706 .14591 Mdot
.706 .14595 Mdot
.706 .14615 Mdot
.706 .14653 Mdot
.706 .14689 Mdot
.706 .1478 Mdot
.706 .14795 Mdot
.706 .14797 Mdot
.706 .14799 Mdot
.706 .14832 Mdot
.706 .1484 Mdot
.706 .14878 Mdot
.706 .14883 Mdot
.706 .14901 Mdot
.706 .14928 Mdot
.706 .14947 Mdot
.706 .14977 Mdot
.706 .15026 Mdot
.706 .15041 Mdot
.706 .15126 Mdot
.706 .15135 Mdot
.706 .15145 Mdot
.706 .15164 Mdot
.706 .15167 Mdot
.706 .15175 Mdot
.706 .15193 Mdot
.706 .15231 Mdot
.706 .15232 Mdot
.706 .15276 Mdot
.706 .15291 Mdot
.706 .153 Mdot
.706 .1541 Mdot
.706 .15412 Mdot
.706 .15436 Mdot
.706 .15453 Mdot
.706 .15481 Mdot
.706 .15488 Mdot
.706 .15492 Mdot
.706 .15499 Mdot
.706 .15681 Mdot
.706 .15703 Mdot
.706 .15892 Mdot
.706 .15946 Mdot
.706 .15963 Mdot
.706 .15988 Mdot
.706 .16036 Mdot
.706 .16082 Mdot
.706 .16089 Mdot
.706 .16099 Mdot
.706 .16136 Mdot
.706 .1614 Mdot
.706 .16148 Mdot
.706 .16157 Mdot
.706 .1617 Mdot
.706 .16174 Mdot
.706 .1618 Mdot
.706 .16199 Mdot
.706 .16201 Mdot
.706 .16203 Mdot
.706 .16213 Mdot
.706 .16292 Mdot
.706 .16293 Mdot
.706 .16294 Mdot
.706 .16408 Mdot
.706 .16409 Mdot
.706 .16427 Mdot
.706 .16504 Mdot
.706 .16556 Mdot
.706 .16557 Mdot
.706 .16579 Mdot
.706 .16602 Mdot
.706 .16705 Mdot
.706 .16707 Mdot
.706 .16909 Mdot
.706 .16915 Mdot
.706 .17008 Mdot
.706 .17044 Mdot
.706 .17087 Mdot
.706 .17122 Mdot
.706 .17145 Mdot
.706 .17215 Mdot
.706 .17221 Mdot
.706 .17234 Mdot
.706 .1726 Mdot
.706 .173 Mdot
.706 .17311 Mdot
.706 .17324 Mdot
.706 .17326 Mdot
.706 .17399 Mdot
.706 .17408 Mdot
.706 .17426 Mdot
.706 .17455 Mdot
.706 .17471 Mdot
.706 .17493 Mdot
.706 .17502 Mdot
.706 .17509 Mdot
.706 .17555 Mdot
.706 .17613 Mdot
.706 .17618 Mdot
.706 .1765 Mdot
.706 .17767 Mdot
.706 .17782 Mdot
.706 .17793 Mdot
.706 .17797 Mdot
.706 .17825 Mdot
.706 .17865 Mdot
.706 .17865 Mdot
.706 .17894 Mdot
.706 .17956 Mdot
.706 .18014 Mdot
.706 .1803 Mdot
.706 .1803 Mdot
.706 .18038 Mdot
.706 .18046 Mdot
.706 .18061 Mdot
.706 .18095 Mdot
.706 .18098 Mdot
.706 .18146 Mdot
.706 .18153 Mdot
.706 .18157 Mdot
.706 .18162 Mdot
.706 .18187 Mdot
.706 .18205 Mdot
.706 .18224 Mdot
.706 .18262 Mdot
.706 .18272 Mdot
.706 .1828 Mdot
.706 .18319 Mdot
.706 .18324 Mdot
.706 .1852 Mdot
.706 .18599 Mdot
.706 .18633 Mdot
.706 .18638 Mdot
.706 .18639 Mdot
.706 .18682 Mdot
.706 .18684 Mdot
.706 .18691 Mdot
.706 .18799 Mdot
.706 .18801 Mdot
.706 .18897 Mdot
.706 .18921 Mdot
.706 .18943 Mdot
.706 .18963 Mdot
.706 .18967 Mdot
.706 .18994 Mdot
.706 .19052 Mdot
.706 .19053 Mdot
.706 .19158 Mdot
.706 .19208 Mdot
.706 .19239 Mdot
.706 .19264 Mdot
.706 .19287 Mdot
.706 .19289 Mdot
.706 .19368 Mdot
.706 .1937 Mdot
.706 .1939 Mdot
.706 .19411 Mdot
.706 .19434 Mdot
.706 .19476 Mdot
.706 .19533 Mdot
.706 .19609 Mdot
.706 .19676 Mdot
.706 .19692 Mdot
.706 .19749 Mdot
.706 .19754 Mdot
.706 .19775 Mdot
.706 .19943 Mdot
.706 .19948 Mdot
.706 .19977 Mdot
.706 .19982 Mdot
.706 .19996 Mdot
.706 .20002 Mdot
.706 .20031 Mdot
.706 .20084 Mdot
.706 .20134 Mdot
.706 .20262 Mdot
.706 .20284 Mdot
.706 .20287 Mdot
.706 .2029 Mdot
.706 .20336 Mdot
.706 .20348 Mdot
.706 .20401 Mdot
.706 .20408 Mdot
.706 .20433 Mdot
.706 .20472 Mdot
.706 .20498 Mdot
.706 .20541 Mdot
.706 .20611 Mdot
.706 .20632 Mdot
.706 .20751 Mdot
.706 .20764 Mdot
.706 .20778 Mdot
.706 .20805 Mdot
.706 .2081 Mdot
.706 .20821 Mdot
.706 .20846 Mdot
.706 .209 Mdot
.706 .20901 Mdot
.706 .20964 Mdot
.706 .20984 Mdot
.706 .20997 Mdot
.706 .21152 Mdot
.706 .21155 Mdot
.706 .2119 Mdot
.706 .21214 Mdot
.706 .21253 Mdot
.706 .21263 Mdot
.706 .21269 Mdot
.706 .21278 Mdot
.706 .21535 Mdot
.706 .21566 Mdot
.706 .21834 Mdot
.706 .2191 Mdot
.706 .21933 Mdot
.706 .21969 Mdot
.706 .22036 Mdot
.706 .22101 Mdot
.706 .22111 Mdot
.706 .22125 Mdot
.706 .22178 Mdot
.706 .22184 Mdot
.706 .22195 Mdot
.706 .22207 Mdot
.706 .22225 Mdot
.706 .22231 Mdot
.706 .2224 Mdot
.706 .22266 Mdot
.706 .2227 Mdot
.706 .22273 Mdot
.706 .22286 Mdot
.706 .22398 Mdot
.706 .224 Mdot
.706 .224 Mdot
.706 .22562 Mdot
.706 .22564 Mdot
.706 .22589 Mdot
.706 .22697 Mdot
.706 .2277 Mdot
.706 .22772 Mdot
.706 .22804 Mdot
.706 .22835 Mdot
.706 .22982 Mdot
.706 .22984 Mdot
.706 .2327 Mdot
.706 .23277 Mdot
.706 .23409 Mdot
.706 .23461 Mdot
.706 .23521 Mdot
.706 .2357 Mdot
.706 .23603 Mdot
.706 .23701 Mdot
.706 .23709 Mdot
.706 .23728 Mdot
.706 .23764 Mdot
.706 .23821 Mdot
.706 .23836 Mdot
.706 .23855 Mdot
.706 .23858 Mdot
.706 .23961 Mdot
.706 .23973 Mdot
.706 .24 Mdot
.706 .2404 Mdot
.706 .24063 Mdot
.706 .24093 Mdot
.706 .24107 Mdot
.706 .24116 Mdot
.706 .24181 Mdot
.706 .24264 Mdot
.706 .24271 Mdot
.706 .24316 Mdot
.706 .24481 Mdot
.706 .24501 Mdot
.706 .24517 Mdot
.706 .24524 Mdot
.706 .24563 Mdot
.706 .24619 Mdot
.706 .2462 Mdot
.706 .2466 Mdot
.706 .24747 Mdot
.706 .2483 Mdot
.706 .24852 Mdot
.706 .24852 Mdot
.706 .24864 Mdot
.706 .24874 Mdot
.706 .24896 Mdot
.706 .24944 Mdot
.706 .24948 Mdot
.706 .25016 Mdot
.706 .25026 Mdot
.706 .25031 Mdot
.706 .25039 Mdot
.706 .25074 Mdot
.706 .251 Mdot
.706 .25127 Mdot
.706 .2518 Mdot
.706 .25194 Mdot
.706 .25205 Mdot
.706 .2526 Mdot
.706 .25267 Mdot
.706 .25545 Mdot
.706 .25655 Mdot
.706 .25703 Mdot
.706 .2571 Mdot
.706 .25713 Mdot
.706 .25773 Mdot
.706 .25775 Mdot
.706 .25785 Mdot
.706 .25938 Mdot
.706 .25941 Mdot
.706 .26076 Mdot
.706 .26111 Mdot
.706 .26141 Mdot
.706 .2617 Mdot
.706 .26174 Mdot
.706 .26213 Mdot
.706 .26296 Mdot
.706 .26297 Mdot
.706 .26445 Mdot
.706 .26515 Mdot
.706 .26559 Mdot
.706 .26595 Mdot
.706 .26627 Mdot
.706 .2663 Mdot
.706 .26742 Mdot
.706 .26744 Mdot
.706 .26772 Mdot
.706 .26802 Mdot
.706 .26835 Mdot
.706 .26894 Mdot
.706 .26975 Mdot
.706 .27081 Mdot
.706 .27176 Mdot
.706 .27199 Mdot
.706 .2728 Mdot
.706 .27286 Mdot
.706 .27316 Mdot
.706 .27554 Mdot
.706 .2756 Mdot
.706 .27602 Mdot
.706 .27608 Mdot
.706 .27629 Mdot
.706 .27637 Mdot
.706 .27677 Mdot
.706 .27752 Mdot
.706 .27823 Mdot
.706 .28004 Mdot
.706 .28035 Mdot
.706 .28038 Mdot
.706 .28044 Mdot
.706 .28109 Mdot
.706 .28125 Mdot
.706 .28201 Mdot
.706 .2821 Mdot
.706 .28246 Mdot
.706 .283 Mdot
.706 .28338 Mdot
.706 .28398 Mdot
.706 .28496 Mdot
.706 .28526 Mdot
.706 .28695 Mdot
.706 .28712 Mdot
.706 .28732 Mdot
.706 .2877 Mdot
.706 .28777 Mdot
.706 .28793 Mdot
.706 .28828 Mdot
.706 .28905 Mdot
.706 .28906 Mdot
.706 .28995 Mdot
.706 .29023 Mdot
.706 .29041 Mdot
.706 .29261 Mdot
.706 .29265 Mdot
.706 .29314 Mdot
.706 .29348 Mdot
.706 .29403 Mdot
.706 .29416 Mdot
.706 .29425 Mdot
.706 .29439 Mdot
.706 .29801 Mdot
.706 .29846 Mdot
.706 .30223 Mdot
.706 .30331 Mdot
.706 .30363 Mdot
.706 .30415 Mdot
.706 .30508 Mdot
.706 .30601 Mdot
.706 .30615 Mdot
.706 .30635 Mdot
.706 .30709 Mdot
.706 .30717 Mdot
.706 .30733 Mdot
.706 .3075 Mdot
.706 .30776 Mdot
.706 .30784 Mdot
.706 .30796 Mdot
.706 .30834 Mdot
.706 .30839 Mdot
.706 .30843 Mdot
.706 .30862 Mdot
.706 .3102 Mdot
.706 .31022 Mdot
.706 .31023 Mdot
.706 .31251 Mdot
.706 .31254 Mdot
.706 .31289 Mdot
.706 .31442 Mdot
.706 .31545 Mdot
.706 .31548 Mdot
.706 .31593 Mdot
.706 .31637 Mdot
.706 .31844 Mdot
.706 .31847 Mdot
.706 .32251 Mdot
.706 .32261 Mdot
.706 .32447 Mdot
.706 .3252 Mdot
.706 .32605 Mdot
.706 .32675 Mdot
.706 .32721 Mdot
.706 .32859 Mdot
.706 .32871 Mdot
.706 .32898 Mdot
.706 .32949 Mdot
.706 .33029 Mdot
.706 .3305 Mdot
.706 .33077 Mdot
.706 .33081 Mdot
.706 .33226 Mdot
.706 .33244 Mdot
.706 .33282 Mdot
.706 .33339 Mdot
.706 .33371 Mdot
.706 .33414 Mdot
.706 .33432 Mdot
.706 .33446 Mdot
.706 .33538 Mdot
.706 .33654 Mdot
.706 .33664 Mdot
.706 .33727 Mdot
.706 .3396 Mdot
.706 .3399 Mdot
.706 .34012 Mdot
.706 .34021 Mdot
.706 .34077 Mdot
.706 .34156 Mdot
.706 .34157 Mdot
.706 .34214 Mdot
.706 .34337 Mdot
.706 .34453 Mdot
.706 .34484 Mdot
.706 .34485 Mdot
.706 .34501 Mdot
.706 .34516 Mdot
.706 .34547 Mdot
.706 .34614 Mdot
.706 .3462 Mdot
.706 .34717 Mdot
.706 .3473 Mdot
.706 .34737 Mdot
.706 .34748 Mdot
.706 .34798 Mdot
.706 .34834 Mdot
.706 .34872 Mdot
.706 .34948 Mdot
.706 .34968 Mdot
.706 .34983 Mdot
.706 .35061 Mdot
.706 .3507 Mdot
.706 .35463 Mdot
.706 .35619 Mdot
.706 .35687 Mdot
.706 .35696 Mdot
.706 .357 Mdot
.706 .35786 Mdot
.706 .35788 Mdot
.706 .35802 Mdot
.706 .36018 Mdot
.706 .36022 Mdot
.706 .36213 Mdot
.706 .36262 Mdot
.706 .36305 Mdot
.706 .36345 Mdot
.706 .36352 Mdot
.706 .36406 Mdot
.706 .36523 Mdot
.706 .36525 Mdot
.706 .36734 Mdot
.706 .36833 Mdot
.706 .36895 Mdot
.706 .36946 Mdot
.706 .36991 Mdot
.706 .36995 Mdot
.706 .37153 Mdot
.706 .37156 Mdot
.706 .37195 Mdot
.706 .37238 Mdot
.706 .37285 Mdot
.706 .37369 Mdot
.706 .37482 Mdot
.706 .37632 Mdot
.706 .37766 Mdot
.706 .37798 Mdot
.706 .37913 Mdot
.706 .37922 Mdot
.706 .37964 Mdot
.706 .383 Mdot
.706 .38308 Mdot
.706 .38368 Mdot
.706 .38376 Mdot
.706 .38405 Mdot
.706 .38417 Mdot
.706 .38474 Mdot
.706 .38579 Mdot
.706 .3868 Mdot
.706 .38936 Mdot
.706 .38978 Mdot
.706 .38984 Mdot
.706 .38992 Mdot
.706 .39083 Mdot
.706 .39107 Mdot
.706 .39213 Mdot
.706 .39226 Mdot
.706 .39277 Mdot
.706 .39353 Mdot
.706 .39406 Mdot
.706 .39492 Mdot
.706 .3963 Mdot
.706 .39673 Mdot
.706 .39911 Mdot
.706 .39936 Mdot
.706 .39964 Mdot
.706 .40017 Mdot
.706 .40027 Mdot
.706 .40049 Mdot
.706 .40099 Mdot
.706 .40207 Mdot
.706 .40209 Mdot
.706 .40334 Mdot
.706 .40375 Mdot
.706 .404 Mdot
.706 .4071 Mdot
.706 .40716 Mdot
.706 .40785 Mdot
.706 .40833 Mdot
.706 .40911 Mdot
.706 .4093 Mdot
.706 .40942 Mdot
.706 .40961 Mdot
.706 .41473 Mdot
.706 .41536 Mdot
.706 .42069 Mdot
.706 .42221 Mdot
.706 .42266 Mdot
.706 .42339 Mdot
.706 .42472 Mdot
.706 .42602 Mdot
.706 .42622 Mdot
.706 .4265 Mdot
.706 .42755 Mdot
.706 .42766 Mdot
.706 .42789 Mdot
.706 .42813 Mdot
.706 .42849 Mdot
.706 .4286 Mdot
.706 .42878 Mdot
.706 .42931 Mdot
.706 .42938 Mdot
.706 .42943 Mdot
.706 .42971 Mdot
.706 .43193 Mdot
.706 .43197 Mdot
.706 .43198 Mdot
.708 .01477 Mdot
.708 .0148 Mdot
.708 .01483 Mdot
.708 .01487 Mdot
.708 .01488 Mdot
.708 .01493 Mdot
.708 .01494 Mdot
.708 .01501 Mdot
.708 .01502 Mdot
.708 .01504 Mdot
.708 .01513 Mdot
.708 .01515 Mdot
.708 .01517 Mdot
.708 .01526 Mdot
.708 .01531 Mdot
.708 .01533 Mdot
.708 .01536 Mdot
.708 .01549 Mdot
.708 .01555 Mdot
.708 .01558 Mdot
.708 .01563 Mdot
.708 .01581 Mdot
.708 .0159 Mdot
.708 .01595 Mdot
.708 .01601 Mdot
.708 .01626 Mdot
.708 .0164 Mdot
.708 .01646 Mdot
.708 .01654 Mdot
.708 .01689 Mdot
.708 .01691 Mdot
.708 .01694 Mdot
.708 .0171 Mdot
.708 .01718 Mdot
.708 .01731 Mdot
.708 .0178 Mdot
.708 .01782 Mdot
.708 .01787 Mdot
.708 .01809 Mdot
.708 .01809 Mdot
.708 .01817 Mdot
.708 .01821 Mdot
.708 .01838 Mdot
.708 .01863 Mdot
.708 .01879 Mdot
.708 .01908 Mdot
.708 .01911 Mdot
.708 .01918 Mdot
.708 .01949 Mdot
.708 .01949 Mdot
.708 .0196 Mdot
.708 .01967 Mdot
.708 .01991 Mdot
.708 .02026 Mdot
.708 .02045 Mdot
.708 .02048 Mdot
.708 .02089 Mdot
.708 .02094 Mdot
.708 .02101 Mdot
.708 .02104 Mdot
.708 .02126 Mdot
.708 .02141 Mdot
.708 .02147 Mdot
.708 .02148 Mdot
.708 .02163 Mdot
.708 .02173 Mdot
.708 .02207 Mdot
.708 .02256 Mdot
.708 .02261 Mdot
.708 .02283 Mdot
.708 .02288 Mdot
.708 .02346 Mdot
.708 .02353 Mdot
.708 .02363 Mdot
.708 .02363 Mdot
.708 .02367 Mdot
.708 .02398 Mdot
.708 .02409 Mdot
.708 .0242 Mdot
.708 .02429 Mdot
.708 .02429 Mdot
.708 .02451 Mdot
.708 .02464 Mdot
.708 .02479 Mdot
.708 .02513 Mdot
.708 .02582 Mdot
.708 .02589 Mdot
.708 .02613 Mdot
.708 .02621 Mdot
.708 .02627 Mdot
.708 .0271 Mdot
.708 .0272 Mdot
.708 .02733 Mdot
.708 .02734 Mdot
.708 .02739 Mdot
.708 .02783 Mdot
.708 .02799 Mdot
.708 .02814 Mdot
.708 .02827 Mdot
.708 .02827 Mdot
.708 .02859 Mdot
.708 .02877 Mdot
.708 .02898 Mdot
.708 .02946 Mdot
.708 .03045 Mdot
.708 .03054 Mdot
.708 .03087 Mdot
.708 .03099 Mdot
.708 .03102 Mdot
.708 .03108 Mdot
.708 .0312 Mdot
.708 .03226 Mdot
.708 .03239 Mdot
.708 .03258 Mdot
.708 .03259 Mdot
.708 .03267 Mdot
.708 .03283 Mdot
.708 .03289 Mdot
.708 .03328 Mdot
.708 .03345 Mdot
.708 .03351 Mdot
.708 .03373 Mdot
.708 .03391 Mdot
.708 .03391 Mdot
.708 .03397 Mdot
.708 .03436 Mdot
.708 .03462 Mdot
.708 .03473 Mdot
.708 .03491 Mdot
.708 .03523 Mdot
.708 .03532 Mdot
.708 .0356 Mdot
.708 .03625 Mdot
.708 .03681 Mdot
.708 .03699 Mdot
.708 .03712 Mdot
.708 .03736 Mdot
.708 .0376 Mdot
.708 .03776 Mdot
.708 .03781 Mdot
.708 .03789 Mdot
.708 .03806 Mdot
.708 .03891 Mdot
.708 .03933 Mdot
.708 .03951 Mdot
.708 .03956 Mdot
.708 .03975 Mdot
.708 .04002 Mdot
.708 .04002 Mdot
.708 .04013 Mdot
.708 .04036 Mdot
.708 .04046 Mdot
.708 .04101 Mdot
.708 .04124 Mdot
.708 .04133 Mdot
.708 .04164 Mdot
.708 .04189 Mdot
.708 .04189 Mdot
.708 .04199 Mdot
.708 .04253 Mdot
.708 .0429 Mdot
.708 .04305 Mdot
.708 .04332 Mdot
.708 .04376 Mdot
.708 .04389 Mdot
.708 .04429 Mdot
.708 .04446 Mdot
.708 .04449 Mdot
.708 .04494 Mdot
.708 .04503 Mdot
.708 .04513 Mdot
.708 .04521 Mdot
.708 .04544 Mdot
.708 .04564 Mdot
.708 .046 Mdot
.708 .04626 Mdot
.708 .04644 Mdot
.708 .04677 Mdot
.708 .04712 Mdot
.708 .04734 Mdot
.708 .04735 Mdot
.708 .04741 Mdot
.708 .04753 Mdot
.708 .04777 Mdot
.708 .04898 Mdot
.708 .04958 Mdot
.708 .04983 Mdot
.708 .04989 Mdot
.708 .05016 Mdot
.708 .05054 Mdot
.708 .05055 Mdot
.708 .05071 Mdot
.708 .05088 Mdot
.708 .05103 Mdot
.708 .05116 Mdot
.708 .0514 Mdot
.708 .05159 Mdot
.708 .05175 Mdot
.708 .05195 Mdot
.708 .05197 Mdot
.708 .05218 Mdot
.708 .05228 Mdot
.708 .0524 Mdot
.708 .05284 Mdot
.708 .05319 Mdot
.708 .0532 Mdot
.708 .05333 Mdot
.708 .05357 Mdot
.708 .05406 Mdot
.708 .05411 Mdot
.708 .05463 Mdot
.708 .05484 Mdot
.708 .05521 Mdot
.708 .05584 Mdot
.708 .05603 Mdot
.708 .05659 Mdot
.708 .05684 Mdot
.708 .05688 Mdot
.708 .05737 Mdot
.708 .05751 Mdot
.708 .05764 Mdot
.708 .05778 Mdot
.708 .05789 Mdot
.708 .05822 Mdot
.708 .0583 Mdot
.708 .05831 Mdot
.708 .05831 Mdot
.708 .05851 Mdot
.708 .05895 Mdot
.708 .05902 Mdot
.708 .05938 Mdot
.708 .05942 Mdot
.708 .05943 Mdot
.708 .05963 Mdot
.708 .05968 Mdot
.708 .06011 Mdot
.708 .06053 Mdot
.708 .06059 Mdot
.708 .06092 Mdot
.708 .06093 Mdot
.708 .06101 Mdot
.708 .06118 Mdot
.708 .06152 Mdot
.708 .06224 Mdot
.708 .06323 Mdot
.708 .0639 Mdot
.708 .06408 Mdot
.708 .06444 Mdot
.708 .06452 Mdot
.708 .06491 Mdot
.708 .06543 Mdot
.708 .06545 Mdot
.708 .06546 Mdot
.708 .06568 Mdot
.708 .06592 Mdot
.708 .06614 Mdot
.708 .06633 Mdot
.708 .06666 Mdot
.708 .06667 Mdot
.708 .06693 Mdot
.708 .06693 Mdot
.708 .06716 Mdot
.708 .06744 Mdot
.708 .06747 Mdot
.708 .06763 Mdot
.708 .06776 Mdot
.708 .06791 Mdot
.708 .06807 Mdot
.708 .0687 Mdot
.708 .0692 Mdot
.708 .06921 Mdot
.708 .0694 Mdot
.708 .06973 Mdot
.708 .07043 Mdot
.708 .07049 Mdot
.708 .07123 Mdot
.708 .0713 Mdot
.708 .07154 Mdot
.708 .07195 Mdot
.708 .07206 Mdot
.708 .07206 Mdot
.708 .07295 Mdot
.708 .07322 Mdot
.708 .07368 Mdot
.708 .07376 Mdot
.708 .07377 Mdot
.708 .07398 Mdot
.708 .07401 Mdot
.708 .07436 Mdot
.708 .07443 Mdot
.708 .07512 Mdot
.708 .07532 Mdot
.708 .0755 Mdot
.708 .07569 Mdot
.708 .07586 Mdot
.708 .07632 Mdot
.708 .07643 Mdot
.708 .07644 Mdot
.708 .07645 Mdot
.708 .07673 Mdot
.708 .07682 Mdot
.708 .07735 Mdot
.708 .07745 Mdot
.708 .07782 Mdot
.708 .07795 Mdot
.708 .07802 Mdot
.708 .07804 Mdot
.708 .07832 Mdot
.708 .07839 Mdot
.708 .079 Mdot
.708 .07959 Mdot
.708 .07968 Mdot
.708 .07986 Mdot
.708 .08013 Mdot
.708 .08015 Mdot
.708 .08019 Mdot
.708 .08027 Mdot
.708 .08051 Mdot
.708 .08099 Mdot
.708 .08201 Mdot
.708 .08291 Mdot
.708 .08341 Mdot
.708 .08436 Mdot
.708 .08453 Mdot
.708 .08461 Mdot
.708 .08512 Mdot
.708 .08524 Mdot
.708 .08579 Mdot
.708 .08601 Mdot
.708 .08653 Mdot
.708 .08655 Mdot
.708 .08657 Mdot
.708 .08688 Mdot
.708 .08692 Mdot
.708 .08722 Mdot
.708 .08753 Mdot
.708 .08753 Mdot
.708 .0878 Mdot
.708 .08827 Mdot
.708 .08829 Mdot
.708 .08865 Mdot
.708 .08865 Mdot
.708 .08887 Mdot
.708 .08898 Mdot
.708 .08937 Mdot
.708 .08941 Mdot
.708 .08965 Mdot
.708 .08983 Mdot
.708 .09003 Mdot
.708 .09027 Mdot
.708 .09116 Mdot
.708 .09146 Mdot
.708 .09187 Mdot
.708 .09188 Mdot
.708 .09214 Mdot
.708 .09259 Mdot
.708 .09262 Mdot
.708 .09349 Mdot
.708 .09349 Mdot
.708 .09357 Mdot
.708 .0936 Mdot
.708 .09366 Mdot
.708 .0937 Mdot
.708 .09474 Mdot
.708 .09484 Mdot
.708 .09517 Mdot
.708 .09576 Mdot
.708 .09592 Mdot
.708 .09592 Mdot
.708 .09592 Mdot
.708 .09612 Mdot
.708 .09661 Mdot
.708 .09717 Mdot
.708 .09756 Mdot
.708 .0982 Mdot
.708 .09832 Mdot
.708 .09834 Mdot
.708 .09863 Mdot
.708 .09867 Mdot
.708 .09917 Mdot
.708 .10024 Mdot
.708 .10053 Mdot
.708 .10079 Mdot
.708 .10095 Mdot
.708 .10105 Mdot
.708 .10129 Mdot
.708 .10174 Mdot
.708 .10194 Mdot
.708 .1021 Mdot
.708 .10212 Mdot
.708 .10213 Mdot
.708 .10253 Mdot
.708 .10265 Mdot
.708 .10341 Mdot
.708 .10355 Mdot
.708 .10407 Mdot
.708 .10426 Mdot
.708 .10435 Mdot
.708 .10438 Mdot
.708 .10469 Mdot
.708 .10477 Mdot
.708 .10488 Mdot
.708 .10574 Mdot
.708 .1058 Mdot
.708 .1063 Mdot
.708 .10644 Mdot
.708 .10658 Mdot
.708 .1067 Mdot
.708 .10697 Mdot
.708 .10735 Mdot
.708 .10738 Mdot
.708 .10743 Mdot
.708 .10755 Mdot
.708 .10788 Mdot
.708 .10826 Mdot
.708 .10856 Mdot
.708 .10871 Mdot
.708 .10931 Mdot
.708 .11 Mdot
.708 .11129 Mdot
.708 .11199 Mdot
.708 .11333 Mdot
.708 .11357 Mdot
.708 .11369 Mdot
.708 .11419 Mdot
.708 .11441 Mdot
.708 .11452 Mdot
.708 .11458 Mdot
.708 .11536 Mdot
.708 .11566 Mdot
.708 .11641 Mdot
.708 .11644 Mdot
.708 .11646 Mdot
.708 .1169 Mdot
.708 .11695 Mdot
.708 .11738 Mdot
.708 .1174 Mdot
.708 .11782 Mdot
.708 .11782 Mdot
.708 .1182 Mdot
.708 .11822 Mdot
.708 .11887 Mdot
.708 .1189 Mdot
.708 .11899 Mdot
.708 .1194 Mdot
.708 .11941 Mdot
.708 .1197 Mdot
.708 .11972 Mdot
.708 .11987 Mdot
.708 .12042 Mdot
.708 .12049 Mdot
.708 .12082 Mdot
.708 .12108 Mdot
.708 .12119 Mdot
.708 .12136 Mdot
.708 .1217 Mdot
.708 .12292 Mdot
.708 .12296 Mdot
.708 .12336 Mdot
.708 .12338 Mdot
.708 .12352 Mdot
.708 .12384 Mdot
.708 .12396 Mdot
.708 .12398 Mdot
.708 .12436 Mdot
.708 .12449 Mdot
.708 .12498 Mdot
.708 .12503 Mdot
.708 .12626 Mdot
.708 .12627 Mdot
.708 .12638 Mdot
.708 .1264 Mdot
.708 .12642 Mdot
.708 .1265 Mdot
.708 .12655 Mdot
.708 .12697 Mdot
.708 .12803 Mdot
.708 .12818 Mdot
.708 .12852 Mdot
.708 .12865 Mdot
.708 .12947 Mdot
.708 .1297 Mdot
.708 .1297 Mdot
.708 .1297 Mdot
.708 .12998 Mdot
.708 .13026 Mdot
.708 .13068 Mdot
.708 .13109 Mdot
.708 .13147 Mdot
.708 .13202 Mdot
.708 .13293 Mdot
.708 .1331 Mdot
.708 .13312 Mdot
.708 .13354 Mdot
.708 .1336 Mdot
.708 .13431 Mdot
.708 .13456 Mdot
.708 .13582 Mdot
.708 .13623 Mdot
.708 .13659 Mdot
.708 .13682 Mdot
.708 .13697 Mdot
.708 .1373 Mdot
.708 .13795 Mdot
.708 .13823 Mdot
.708 .13845 Mdot
.708 .13845 Mdot
.708 .13847 Mdot
.708 .1385 Mdot
.708 .13906 Mdot
.708 .13911 Mdot
.708 .13923 Mdot
.708 .14031 Mdot
.708 .14051 Mdot
.708 .14124 Mdot
.708 .14151 Mdot
.708 .14164 Mdot
.708 .14168 Mdot
.708 .14213 Mdot
.708 .14224 Mdot
.708 .14239 Mdot
.708 .1436 Mdot
.708 .14369 Mdot
.708 .1444 Mdot
.708 .1446 Mdot
.708 .1448 Mdot
.708 .14497 Mdot
.708 .14534 Mdot
.708 .14577 Mdot
.708 .14588 Mdot
.708 .14592 Mdot
.708 .146 Mdot
.708 .14616 Mdot
.708 .14664 Mdot
.708 .14678 Mdot
.708 .14717 Mdot
.708 .1476 Mdot
.708 .14781 Mdot
.708 .14867 Mdot
.708 .14964 Mdot
.708 .1498 Mdot
.708 .15146 Mdot
.708 .15246 Mdot
.708 .15436 Mdot
.708 .1547 Mdot
.708 .15486 Mdot
.708 .15557 Mdot
.708 .15588 Mdot
.708 .15604 Mdot
.708 .15613 Mdot
.708 .15723 Mdot
.708 .15743 Mdot
.708 .15766 Mdot
.708 .15871 Mdot
.708 .15875 Mdot
.708 .15879 Mdot
.708 .1588 Mdot
.708 .15942 Mdot
.708 .15946 Mdot
.708 .15948 Mdot
.708 .16009 Mdot
.708 .16011 Mdot
.708 .16071 Mdot
.708 .16071 Mdot
.708 .16125 Mdot
.708 .16128 Mdot
.708 .1622 Mdot
.708 .16224 Mdot
.708 .16229 Mdot
.708 .16237 Mdot
.708 .16295 Mdot
.708 .16297 Mdot
.708 .16337 Mdot
.708 .1634 Mdot
.708 .16356 Mdot
.708 .16362 Mdot
.708 .1642 Mdot
.708 .1644 Mdot
.708 .16449 Mdot
.708 .16454 Mdot
.708 .16496 Mdot
.708 .16532 Mdot
.708 .16548 Mdot
.708 .16573 Mdot
.708 .1662 Mdot
.708 .16793 Mdot
.708 .16799 Mdot
.708 .16856 Mdot
.708 .16859 Mdot
.708 .16878 Mdot
.708 .16897 Mdot
.708 .16923 Mdot
.708 .16941 Mdot
.708 .16944 Mdot
.708 .16977 Mdot
.708 .16997 Mdot
.708 .17016 Mdot
.708 .17071 Mdot
.708 .17085 Mdot
.708 .17092 Mdot
.708 .17266 Mdot
.708 .17267 Mdot
.708 .17283 Mdot
.708 .17286 Mdot
.708 .17289 Mdot
.708 .173 Mdot
.708 .17308 Mdot
.708 .17367 Mdot
.708 .17492 Mdot
.708 .1751 Mdot
.708 .17517 Mdot
.708 .17523 Mdot
.708 .1753 Mdot
.708 .17538 Mdot
.708 .17587 Mdot
.708 .17604 Mdot
.708 .17721 Mdot
.708 .17753 Mdot
.708 .17754 Mdot
.708 .17754 Mdot
.708 .17776 Mdot
.708 .17793 Mdot
.708 .17793 Mdot
.708 .17802 Mdot
.708 .17832 Mdot
.708 .17892 Mdot
.708 .17951 Mdot
.708 .18005 Mdot
.708 .18048 Mdot
.708 .18057 Mdot
.708 .18082 Mdot
.708 .18211 Mdot
.708 .18234 Mdot
.708 .18238 Mdot
.708 .18295 Mdot
.708 .18298 Mdot
.708 .18298 Mdot
.708 .18306 Mdot
.708 .18406 Mdot
.708 .18441 Mdot
.708 .18513 Mdot
.708 .18525 Mdot
.708 .1862 Mdot
.708 .18677 Mdot
.708 .18729 Mdot
.708 .18761 Mdot
.708 .18783 Mdot
.708 .1883 Mdot
.708 .18921 Mdot
.708 .18961 Mdot
.708 .18993 Mdot
.708 .18993 Mdot
.708 .18996 Mdot
.708 .18999 Mdot
.708 .19078 Mdot
.708 .19085 Mdot
.708 .19103 Mdot
.708 .19255 Mdot
.708 .19284 Mdot
.708 .19388 Mdot
.708 .19426 Mdot
.708 .19444 Mdot
.708 .19449 Mdot
.708 .19513 Mdot
.708 .19529 Mdot
.708 .1955 Mdot
.708 .19722 Mdot
.708 .19734 Mdot
.708 .19835 Mdot
.708 .19864 Mdot
.708 .19891 Mdot
.708 .19916 Mdot
.708 .19969 Mdot
.708 .20029 Mdot
.708 .20045 Mdot
.708 .20051 Mdot
.708 .20062 Mdot
.708 .20085 Mdot
.708 .20152 Mdot
.708 .20172 Mdot
.708 .20227 Mdot
.708 .20288 Mdot
.708 .20317 Mdot
.708 .20439 Mdot
.708 .20577 Mdot
.708 .206 Mdot
.708 .20834 Mdot
.708 .20976 Mdot
.708 .21245 Mdot
.708 .21293 Mdot
.708 .21316 Mdot
.708 .21416 Mdot
.708 .21461 Mdot
.708 .21483 Mdot
.708 .21495 Mdot
.708 .21651 Mdot
.708 .21679 Mdot
.708 .21713 Mdot
.708 .21861 Mdot
.708 .21867 Mdot
.708 .21872 Mdot
.708 .21875 Mdot
.708 .21961 Mdot
.708 .21967 Mdot
.708 .2197 Mdot
.708 .22057 Mdot
.708 .2206 Mdot
.708 .22144 Mdot
.708 .22145 Mdot
.708 .22221 Mdot
.708 .22225 Mdot
.708 .22356 Mdot
.708 .22361 Mdot
.708 .22368 Mdot
.708 .2238 Mdot
.708 .22461 Mdot
.708 .22464 Mdot
.708 .22521 Mdot
.708 .22525 Mdot
.708 .22548 Mdot
.708 .22556 Mdot
.708 .22639 Mdot
.708 .22667 Mdot
.708 .22679 Mdot
.708 .22687 Mdot
.708 .22746 Mdot
.708 .22797 Mdot
.708 .2282 Mdot
.708 .22855 Mdot
.708 .22922 Mdot
.708 .23166 Mdot
.708 .23175 Mdot
.708 .23256 Mdot
.708 .2326 Mdot
.708 .23287 Mdot
.708 .23314 Mdot
.708 .23351 Mdot
.708 .23376 Mdot
.708 .23381 Mdot
.708 .23427 Mdot
.708 .23455 Mdot
.708 .23482 Mdot
.708 .2356 Mdot
.708 .23581 Mdot
.708 .2359 Mdot
.708 .23837 Mdot
.708 .23838 Mdot
.708 .2386 Mdot
.708 .23865 Mdot
.708 .2387 Mdot
.708 .23885 Mdot
.708 .23895 Mdot
.708 .2398 Mdot
.708 .24156 Mdot
.708 .24183 Mdot
.708 .24192 Mdot
.708 .242 Mdot
.708 .24211 Mdot
.708 .24221 Mdot
.708 .24291 Mdot
.708 .24315 Mdot
.708 .2448 Mdot
.708 .24527 Mdot
.708 .24527 Mdot
.708 .24527 Mdot
.708 .24559 Mdot
.708 .24583 Mdot
.708 .24583 Mdot
.708 .24596 Mdot
.708 .24638 Mdot
.708 .24723 Mdot
.708 .24806 Mdot
.708 .24882 Mdot
.708 .24944 Mdot
.708 .24957 Mdot
.708 .24992 Mdot
.708 .25175 Mdot
.708 .25207 Mdot
.708 .25213 Mdot
.708 .25294 Mdot
.708 .25298 Mdot
.708 .25298 Mdot
.708 .25309 Mdot
.708 .2545 Mdot
.708 .255 Mdot
.708 .25602 Mdot
.708 .25619 Mdot
.708 .25754 Mdot
.708 .25835 Mdot
.708 .25909 Mdot
.708 .25954 Mdot
.708 .25985 Mdot
.708 .26051 Mdot
.708 .2618 Mdot
.708 .26237 Mdot
.708 .26282 Mdot
.708 .26282 Mdot
.708 .26286 Mdot
.708 .2629 Mdot
.708 .26403 Mdot
.708 .26413 Mdot
.708 .26437 Mdot
.708 .26654 Mdot
.708 .26693 Mdot
.708 .26841 Mdot
.708 .26895 Mdot
.708 .26921 Mdot
.708 .26928 Mdot
.708 .27018 Mdot
.708 .27041 Mdot
.708 .27071 Mdot
.708 .27314 Mdot
.708 .27331 Mdot
.708 .27474 Mdot
.708 .27515 Mdot
.708 .27554 Mdot
.708 .27589 Mdot
.708 .27663 Mdot
.708 .27749 Mdot
.708 .27772 Mdot
.708 .27779 Mdot
.708 .27795 Mdot
.708 .27828 Mdot
.708 .27923 Mdot
.708 .27952 Mdot
.708 .28029 Mdot
.708 .28115 Mdot
.708 .28157 Mdot
.708 .2833 Mdot
.708 .28524 Mdot
.708 .28557 Mdot
.708 .28889 Mdot
.708 .2909 Mdot
.708 .29471 Mdot
.708 .29539 Mdot
.708 .29572 Mdot
.708 .29713 Mdot
.708 .29776 Mdot
.708 .29808 Mdot
.708 .29825 Mdot
.708 .30046 Mdot
.708 .30086 Mdot
.708 .30133 Mdot
.708 .30343 Mdot
.708 .30352 Mdot
.708 .30358 Mdot
.708 .30362 Mdot
.708 .30485 Mdot
.708 .30493 Mdot
.708 .30498 Mdot
.708 .3062 Mdot
.708 .30625 Mdot
.708 .30743 Mdot
.708 .30745 Mdot
.708 .30852 Mdot
.708 .30858 Mdot
.708 .31044 Mdot
.708 .3105 Mdot
.708 .3106 Mdot
.708 .31078 Mdot
.708 .31193 Mdot
.708 .31197 Mdot
.708 .31278 Mdot
.708 .31283 Mdot
.708 .31316 Mdot
.708 .31327 Mdot
.708 .31444 Mdot
.708 .31484 Mdot
.708 .31502 Mdot
.708 .31513 Mdot
.708 .31597 Mdot
.708 .31669 Mdot
.708 .31702 Mdot
.708 .31751 Mdot
.708 .31846 Mdot
.708 .32191 Mdot
.708 .32204 Mdot
.708 .32319 Mdot
.708 .32323 Mdot
.708 .32363 Mdot
.708 .324 Mdot
.708 .32453 Mdot
.708 .32488 Mdot
.708 .32495 Mdot
.708 .3256 Mdot
.708 .326 Mdot
.708 .32639 Mdot
.708 .32748 Mdot
.708 .32778 Mdot
.708 .32791 Mdot
.708 .3314 Mdot
.708 .33143 Mdot
.708 .33174 Mdot
.708 .33181 Mdot
.708 .33187 Mdot
.708 .33209 Mdot
.708 .33224 Mdot
.708 .33344 Mdot
.708 .33593 Mdot
.708 .3363 Mdot
.708 .33644 Mdot
.708 .33655 Mdot
.708 .33671 Mdot
.708 .33685 Mdot
.708 .33784 Mdot
.708 .33818 Mdot
.708 .34052 Mdot
.708 .34117 Mdot
.708 .34118 Mdot
.708 .34119 Mdot
.708 .34164 Mdot
.708 .34197 Mdot
.708 .34198 Mdot
.708 .34215 Mdot
.708 .34275 Mdot
.708 .34396 Mdot
.708 .34513 Mdot
.708 .34621 Mdot
.708 .34709 Mdot
.708 .34727 Mdot
.708 .34777 Mdot
.708 .35036 Mdot
.708 .35081 Mdot
.708 .3509 Mdot
.708 .35204 Mdot
.708 .35209 Mdot
.708 .3521 Mdot
.708 .35225 Mdot
.708 .35425 Mdot
.708 .35496 Mdot
.708 .35641 Mdot
.708 .35664 Mdot
.708 .35856 Mdot
.708 .3597 Mdot
.708 .36074 Mdot
.708 .36138 Mdot
.708 .36182 Mdot
.708 .36276 Mdot
.708 .36459 Mdot
.708 .36539 Mdot
.708 .36603 Mdot
.708 .36603 Mdot
.708 .36609 Mdot
.708 .36615 Mdot
.708 .36774 Mdot
.708 .36788 Mdot
.708 .36823 Mdot
.708 .37129 Mdot
.708 .37186 Mdot
.708 .37394 Mdot
.708 .37472 Mdot
.708 .37508 Mdot
.708 .37518 Mdot
.708 .37646 Mdot
.708 .37677 Mdot
.708 .3772 Mdot
.708 .38064 Mdot
.708 .38088 Mdot
.708 .38291 Mdot
.708 .38349 Mdot
.708 .38404 Mdot
.708 .38454 Mdot
.708 .38559 Mdot
.708 .38681 Mdot
.708 .38713 Mdot
.708 .38724 Mdot
.708 .38746 Mdot
.708 .38792 Mdot
.708 .38927 Mdot
.708 .38968 Mdot
.708 .39077 Mdot
.708 .39199 Mdot
.708 .39258 Mdot
.708 .39503 Mdot
.708 .39778 Mdot
.708 .39824 Mdot
.708 .40295 Mdot
.708 .4058 Mdot
.708 .41118 Mdot
.708 .41215 Mdot
.708 .41261 Mdot
.708 .41461 Mdot
.708 .41551 Mdot
.708 .41597 Mdot
.708 .41621 Mdot
.708 .41933 Mdot
.708 .4199 Mdot
.708 .42056 Mdot
.708 .42353 Mdot
.708 .42367 Mdot
.708 .42375 Mdot
.708 .42381 Mdot
.708 .42554 Mdot
.708 .42566 Mdot
.708 .42573 Mdot
.708 .42746 Mdot
.708 .42753 Mdot
.708 .42921 Mdot
.708 .42923 Mdot
.708 .43075 Mdot
.708 .43083 Mdot
.71 .01473 Mdot
.71 .01474 Mdot
.71 .01474 Mdot
.71 .01476 Mdot
.71 .01477 Mdot
.71 .0148 Mdot
.71 .01483 Mdot
.71 .01488 Mdot
.71 .01495 Mdot
.71 .01505 Mdot
.71 .01519 Mdot
.71 .01539 Mdot
.71 .01568 Mdot
.71 .01608 Mdot
.71 .01665 Mdot
.71 .01678 Mdot
.71 .01733 Mdot
.71 .01747 Mdot
.71 .01764 Mdot
.71 .01842 Mdot
.71 .01862 Mdot
.71 .01864 Mdot
.71 .01887 Mdot
.71 .01954 Mdot
.71 .01998 Mdot
.71 .02026 Mdot
.71 .02029 Mdot
.71 .02062 Mdot
.71 .02147 Mdot
.71 .02157 Mdot
.71 .02219 Mdot
.71 .02259 Mdot
.71 .02263 Mdot
.71 .02296 Mdot
.71 .02302 Mdot
.71 .02309 Mdot
.71 .02319 Mdot
.71 .02333 Mdot
.71 .02431 Mdot
.71 .02445 Mdot
.71 .02533 Mdot
.71 .0259 Mdot
.71 .02595 Mdot
.71 .02605 Mdot
.71 .02642 Mdot
.71 .02651 Mdot
.71 .02661 Mdot
.71 .02674 Mdot
.71 .02685 Mdot
.71 .02689 Mdot
.71 .02695 Mdot
.71 .02751 Mdot
.71 .02834 Mdot
.71 .02854 Mdot
.71 .02979 Mdot
.71 .0306 Mdot
.71 .03067 Mdot
.71 .03081 Mdot
.71 .03133 Mdot
.71 .03147 Mdot
.71 .03161 Mdot
.71 .0318 Mdot
.71 .03195 Mdot
.71 .03201 Mdot
.71 .03209 Mdot
.71 .03289 Mdot
.71 .03406 Mdot
.71 .03417 Mdot
.71 .03434 Mdot
.71 .03464 Mdot
.71 .03596 Mdot
.71 .03612 Mdot
.71 .03709 Mdot
.71 .03727 Mdot
.71 .03738 Mdot
.71 .03748 Mdot
.71 .03756 Mdot
.71 .03831 Mdot
.71 .03831 Mdot
.71 .0385 Mdot
.71 .0387 Mdot
.71 .03897 Mdot
.71 .03919 Mdot
.71 .03927 Mdot
.71 .03939 Mdot
.71 .04052 Mdot
.71 .04085 Mdot
.71 .04089 Mdot
.71 .04218 Mdot
.71 .04234 Mdot
.71 .04258 Mdot
.71 .04294 Mdot
.71 .043 Mdot
.71 .0438 Mdot
.71 .04488 Mdot
.71 .04511 Mdot
.71 .04606 Mdot
.71 .04624 Mdot
.71 .04648 Mdot
.71 .04675 Mdot
.71 .04689 Mdot
.71 .04693 Mdot
.71 .04705 Mdot
.71 .04716 Mdot
.71 .04722 Mdot
.71 .04821 Mdot
.71 .04822 Mdot
.71 .04823 Mdot
.71 .04825 Mdot
.71 .04849 Mdot
.71 .04878 Mdot
.71 .04889 Mdot
.71 .04916 Mdot
.71 .04946 Mdot
.71 .04958 Mdot
.71 .04965 Mdot
.71 .04966 Mdot
.71 .04975 Mdot
.71 .05044 Mdot
.71 .05066 Mdot
.71 .05112 Mdot
.71 .05136 Mdot
.71 .05152 Mdot
.71 .05183 Mdot
.71 .05188 Mdot
.71 .05281 Mdot
.71 .05349 Mdot
.71 .05372 Mdot
.71 .05394 Mdot
.71 .05417 Mdot
.71 .05421 Mdot
.71 .05429 Mdot
.71 .05468 Mdot
.71 .05479 Mdot
.71 .05488 Mdot
.71 .05507 Mdot
.71 .05555 Mdot
.71 .0556 Mdot
.71 .05569 Mdot
.71 .05569 Mdot
.71 .05602 Mdot
.71 .05703 Mdot
.71 .05755 Mdot
.71 .05788 Mdot
.71 .0584 Mdot
.71 .05922 Mdot
.71 .05949 Mdot
.71 .05983 Mdot
.71 .06012 Mdot
.71 .0602 Mdot
.71 .06036 Mdot
.71 .06041 Mdot
.71 .06046 Mdot
.71 .06047 Mdot
.71 .06063 Mdot
.71 .06073 Mdot
.71 .06079 Mdot
.71 .06082 Mdot
.71 .06087 Mdot
.71 .06105 Mdot
.71 .06142 Mdot
.71 .06228 Mdot
.71 .06229 Mdot
.71 .0623 Mdot
.71 .06234 Mdot
.71 .06246 Mdot
.71 .06268 Mdot
.71 .06307 Mdot
.71 .06309 Mdot
.71 .06324 Mdot
.71 .06344 Mdot
.71 .06352 Mdot
.71 .06363 Mdot
.71 .06363 Mdot
.71 .06372 Mdot
.71 .06374 Mdot
.71 .06406 Mdot
.71 .06422 Mdot
.71 .06432 Mdot
.71 .06434 Mdot
.71 .06447 Mdot
.71 .06461 Mdot
.71 .06544 Mdot
.71 .06574 Mdot
.71 .06576 Mdot
.71 .06641 Mdot
.71 .06675 Mdot
.71 .06698 Mdot
.71 .06741 Mdot
.71 .06749 Mdot
.71 .0683 Mdot
.71 .06852 Mdot
.71 .06881 Mdot
.71 .06912 Mdot
.71 .06977 Mdot
.71 .07002 Mdot
.71 .0701 Mdot
.71 .07019 Mdot
.71 .07042 Mdot
.71 .07075 Mdot
.71 .0708 Mdot
.71 .07085 Mdot
.71 .07091 Mdot
.71 .07147 Mdot
.71 .07163 Mdot
.71 .07175 Mdot
.71 .07183 Mdot
.71 .07191 Mdot
.71 .07191 Mdot
.71 .07201 Mdot
.71 .07256 Mdot
.71 .07269 Mdot
.71 .07278 Mdot
.71 .07289 Mdot
.71 .0729 Mdot
.71 .07336 Mdot
.71 .0748 Mdot
.71 .07554 Mdot
.71 .07566 Mdot
.71 .07601 Mdot
.71 .07675 Mdot
.71 .07792 Mdot
.71 .07829 Mdot
.71 .07877 Mdot
.71 .07912 Mdot
.71 .0792 Mdot
.71 .07931 Mdot
.71 .07953 Mdot
.71 .0796 Mdot
.71 .07967 Mdot
.71 .07969 Mdot
.71 .07991 Mdot
.71 .08006 Mdot
.71 .08014 Mdot
.71 .08018 Mdot
.71 .08026 Mdot
.71 .08051 Mdot
.71 .08084 Mdot
.71 .08104 Mdot
.71 .08192 Mdot
.71 .08226 Mdot
.71 .08227 Mdot
.71 .08229 Mdot
.71 .08234 Mdot
.71 .08251 Mdot
.71 .08282 Mdot
.71 .08338 Mdot
.71 .0834 Mdot
.71 .08343 Mdot
.71 .08363 Mdot
.71 .0839 Mdot
.71 .08402 Mdot
.71 .08417 Mdot
.71 .08418 Mdot
.71 .0843 Mdot
.71 .08433 Mdot
.71 .08478 Mdot
.71 .08502 Mdot
.71 .08515 Mdot
.71 .08519 Mdot
.71 .08537 Mdot
.71 .08556 Mdot
.71 .08589 Mdot
.71 .08674 Mdot
.71 .08718 Mdot
.71 .0872 Mdot
.71 .08744 Mdot
.71 .08812 Mdot
.71 .08861 Mdot
.71 .08893 Mdot
.71 .08955 Mdot
.71 .08965 Mdot
.71 .09081 Mdot
.71 .09112 Mdot
.71 .09152 Mdot
.71 .09196 Mdot
.71 .09201 Mdot
.71 .0929 Mdot
.71 .09324 Mdot
.71 .09336 Mdot
.71 .09349 Mdot
.71 .09349 Mdot
.71 .09362 Mdot
.71 .09381 Mdot
.71 .09427 Mdot
.71 .09428 Mdot
.71 .09436 Mdot
.71 .09443 Mdot
.71 .09451 Mdot
.71 .09452 Mdot
.71 .0953 Mdot
.71 .09553 Mdot
.71 .09571 Mdot
.71 .09581 Mdot
.71 .09591 Mdot
.71 .09593 Mdot
.71 .09593 Mdot
.71 .09608 Mdot
.71 .09686 Mdot
.71 .09705 Mdot
.71 .09716 Mdot
.71 .09733 Mdot
.71 .09734 Mdot
.71 .09734 Mdot
.71 .09799 Mdot
.71 .09859 Mdot
.71 .10003 Mdot
.71 .10108 Mdot
.71 .10126 Mdot
.71 .1015 Mdot
.71 .10175 Mdot
.71 .10281 Mdot
.71 .10304 Mdot
.71 .10347 Mdot
.71 .10446 Mdot
.71 .10474 Mdot
.71 .10477 Mdot
.71 .10499 Mdot
.71 .10567 Mdot
.71 .10617 Mdot
.71 .10628 Mdot
.71 .10644 Mdot
.71 .10675 Mdot
.71 .10686 Mdot
.71 .10695 Mdot
.71 .10698 Mdot
.71 .10729 Mdot
.71 .1073 Mdot
.71 .1075 Mdot
.71 .10762 Mdot
.71 .10768 Mdot
.71 .10779 Mdot
.71 .10814 Mdot
.71 .10862 Mdot
.71 .1089 Mdot
.71 .11015 Mdot
.71 .11063 Mdot
.71 .11065 Mdot
.71 .11067 Mdot
.71 .11074 Mdot
.71 .11099 Mdot
.71 .11143 Mdot
.71 .11222 Mdot
.71 .11225 Mdot
.71 .11225 Mdot
.71 .1123 Mdot
.71 .11257 Mdot
.71 .11296 Mdot
.71 .11299 Mdot
.71 .11313 Mdot
.71 .11334 Mdot
.71 .11335 Mdot
.71 .11352 Mdot
.71 .11357 Mdot
.71 .11421 Mdot
.71 .11454 Mdot
.71 .1146 Mdot
.71 .11473 Mdot
.71 .11478 Mdot
.71 .1148 Mdot
.71 .11504 Mdot
.71 .11531 Mdot
.71 .11579 Mdot
.71 .11608 Mdot
.71 .11699 Mdot
.71 .11761 Mdot
.71 .11765 Mdot
.71 .11798 Mdot
.71 .11895 Mdot
.71 .11964 Mdot
.71 .12001 Mdot
.71 .1201 Mdot
.71 .12098 Mdot
.71 .12113 Mdot
.71 .12277 Mdot
.71 .12288 Mdot
.71 .12321 Mdot
.71 .12348 Mdot
.71 .12378 Mdot
.71 .12441 Mdot
.71 .12442 Mdot
.71 .12447 Mdot
.71 .12574 Mdot
.71 .12622 Mdot
.71 .12623 Mdot
.71 .12639 Mdot
.71 .12657 Mdot
.71 .12658 Mdot
.71 .12677 Mdot
.71 .12682 Mdot
.71 .12703 Mdot
.71 .12735 Mdot
.71 .12752 Mdot
.71 .12769 Mdot
.71 .1277 Mdot
.71 .12781 Mdot
.71 .12791 Mdot
.71 .12802 Mdot
.71 .12804 Mdot
.71 .12806 Mdot
.71 .12839 Mdot
.71 .12915 Mdot
.71 .12932 Mdot
.71 .12938 Mdot
.71 .12947 Mdot
.71 .12972 Mdot
.71 .12987 Mdot
.71 .13001 Mdot
.71 .13003 Mdot
.71 .13004 Mdot
.71 .13025 Mdot
.71 .13053 Mdot
.71 .13121 Mdot
.71 .13136 Mdot
.71 .13158 Mdot
.71 .13163 Mdot
.71 .13179 Mdot
.71 .13203 Mdot
.71 .13205 Mdot
.71 .13205 Mdot
.71 .13221 Mdot
.71 .13297 Mdot
.71 .13382 Mdot
.71 .13425 Mdot
.71 .13549 Mdot
.71 .13587 Mdot
.71 .13699 Mdot
.71 .13736 Mdot
.71 .13761 Mdot
.71 .13795 Mdot
.71 .1383 Mdot
.71 .13861 Mdot
.71 .13933 Mdot
.71 .1397 Mdot
.71 .13981 Mdot
.71 .14012 Mdot
.71 .14013 Mdot
.71 .14075 Mdot
.71 .14197 Mdot
.71 .14215 Mdot
.71 .14255 Mdot
.71 .1426 Mdot
.71 .14291 Mdot
.71 .14388 Mdot
.71 .14458 Mdot
.71 .14473 Mdot
.71 .14496 Mdot
.71 .14541 Mdot
.71 .14555 Mdot
.71 .14568 Mdot
.71 .14573 Mdot
.71 .14586 Mdot
.71 .14617 Mdot
.71 .14618 Mdot
.71 .14647 Mdot
.71 .14663 Mdot
.71 .14672 Mdot
.71 .14688 Mdot
.71 .14738 Mdot
.71 .14769 Mdot
.71 .14806 Mdot
.71 .14845 Mdot
.71 .14863 Mdot
.71 .14872 Mdot
.71 .14883 Mdot
.71 .14928 Mdot
.71 .15024 Mdot
.71 .15069 Mdot
.71 .15092 Mdot
.71 .15094 Mdot
.71 .15097 Mdot
.71 .15108 Mdot
.71 .15142 Mdot
.71 .15205 Mdot
.71 .15317 Mdot
.71 .15321 Mdot
.71 .15322 Mdot
.71 .15322 Mdot
.71 .15328 Mdot
.71 .15367 Mdot
.71 .15422 Mdot
.71 .15427 Mdot
.71 .15446 Mdot
.71 .15476 Mdot
.71 .15477 Mdot
.71 .15502 Mdot
.71 .15509 Mdot
.71 .156 Mdot
.71 .15647 Mdot
.71 .15655 Mdot
.71 .15674 Mdot
.71 .15681 Mdot
.71 .15684 Mdot
.71 .15717 Mdot
.71 .15757 Mdot
.71 .1578 Mdot
.71 .15797 Mdot
.71 .15798 Mdot
.71 .158 Mdot
.71 .15823 Mdot
.71 .15824 Mdot
.71 .15865 Mdot
.71 .15982 Mdot
.71 .15995 Mdot
.71 .16083 Mdot
.71 .16088 Mdot
.71 .16136 Mdot
.71 .16207 Mdot
.71 .16227 Mdot
.71 .16272 Mdot
.71 .16304 Mdot
.71 .16371 Mdot
.71 .16423 Mdot
.71 .16425 Mdot
.71 .16431 Mdot
.71 .16436 Mdot
.71 .16531 Mdot
.71 .16559 Mdot
.71 .16561 Mdot
.71 .16582 Mdot
.71 .16815 Mdot
.71 .16831 Mdot
.71 .16877 Mdot
.71 .16917 Mdot
.71 .1693 Mdot
.71 .16959 Mdot
.71 .17048 Mdot
.71 .17049 Mdot
.71 .17057 Mdot
.71 .17121 Mdot
.71 .17151 Mdot
.71 .1723 Mdot
.71 .17236 Mdot
.71 .1726 Mdot
.71 .17271 Mdot
.71 .17306 Mdot
.71 .17307 Mdot
.71 .17329 Mdot
.71 .17355 Mdot
.71 .17356 Mdot
.71 .17383 Mdot
.71 .17391 Mdot
.71 .17407 Mdot
.71 .17421 Mdot
.71 .17466 Mdot
.71 .17489 Mdot
.71 .17513 Mdot
.71 .17515 Mdot
.71 .17531 Mdot
.71 .17545 Mdot
.71 .17561 Mdot
.71 .17563 Mdot
.71 .17566 Mdot
.71 .17566 Mdot
.71 .17613 Mdot
.71 .17661 Mdot
.71 .17721 Mdot
.71 .17729 Mdot
.71 .17733 Mdot
.71 .17742 Mdot
.71 .17746 Mdot
.71 .17753 Mdot
.71 .17767 Mdot
.71 .17803 Mdot
.71 .17824 Mdot
.71 .17837 Mdot
.71 .1784 Mdot
.71 .17844 Mdot
.71 .17847 Mdot
.71 .17848 Mdot
.71 .17878 Mdot
.71 .17917 Mdot
.71 .18007 Mdot
.71 .18014 Mdot
.71 .18035 Mdot
.71 .18067 Mdot
.71 .18073 Mdot
.71 .18096 Mdot
.71 .1813 Mdot
.71 .18133 Mdot
.71 .18133 Mdot
.71 .18156 Mdot
.71 .18264 Mdot
.71 .18385 Mdot
.71 .18445 Mdot
.71 .18483 Mdot
.71 .18535 Mdot
.71 .18621 Mdot
.71 .18675 Mdot
.71 .18835 Mdot
.71 .18887 Mdot
.71 .18891 Mdot
.71 .18914 Mdot
.71 .18922 Mdot
.71 .18971 Mdot
.71 .19021 Mdot
.71 .19065 Mdot
.71 .19166 Mdot
.71 .1922 Mdot
.71 .19235 Mdot
.71 .19279 Mdot
.71 .19281 Mdot
.71 .19369 Mdot
.71 .19542 Mdot
.71 .19568 Mdot
.71 .19624 Mdot
.71 .19631 Mdot
.71 .19675 Mdot
.71 .19813 Mdot
.71 .19913 Mdot
.71 .19934 Mdot
.71 .19967 Mdot
.71 .2003 Mdot
.71 .20051 Mdot
.71 .20069 Mdot
.71 .20075 Mdot
.71 .20094 Mdot
.71 .20138 Mdot
.71 .2014 Mdot
.71 .2018 Mdot
.71 .20204 Mdot
.71 .20217 Mdot
.71 .20239 Mdot
.71 .2031 Mdot
.71 .20353 Mdot
.71 .20406 Mdot
.71 .20462 Mdot
.71 .20487 Mdot
.71 .20501 Mdot
.71 .20515 Mdot
.71 .2058 Mdot
.71 .20715 Mdot
.71 .20779 Mdot
.71 .20812 Mdot
.71 .20816 Mdot
.71 .20819 Mdot
.71 .20835 Mdot
.71 .20884 Mdot
.71 .20973 Mdot
.71 .21133 Mdot
.71 .21138 Mdot
.71 .21139 Mdot
.71 .2114 Mdot
.71 .21148 Mdot
.71 .21203 Mdot
.71 .21282 Mdot
.71 .21288 Mdot
.71 .21316 Mdot
.71 .21358 Mdot
.71 .2136 Mdot
.71 .21395 Mdot
.71 .21405 Mdot
.71 .21534 Mdot
.71 .21601 Mdot
.71 .21611 Mdot
.71 .21639 Mdot
.71 .2165 Mdot
.71 .21653 Mdot
.71 .21701 Mdot
.71 .21756 Mdot
.71 .2179 Mdot
.71 .21813 Mdot
.71 .21815 Mdot
.71 .21818 Mdot
.71 .21851 Mdot
.71 .21852 Mdot
.71 .2191 Mdot
.71 .22076 Mdot
.71 .22095 Mdot
.71 .22219 Mdot
.71 .22227 Mdot
.71 .22295 Mdot
.71 .22396 Mdot
.71 .22424 Mdot
.71 .22489 Mdot
.71 .22534 Mdot
.71 .22629 Mdot
.71 .22703 Mdot
.71 .22706 Mdot
.71 .22714 Mdot
.71 .22721 Mdot
.71 .22856 Mdot
.71 .22896 Mdot
.71 .22898 Mdot
.71 .22929 Mdot
.71 .23259 Mdot
.71 .23282 Mdot
.71 .23348 Mdot
.71 .23404 Mdot
.71 .23423 Mdot
.71 .23464 Mdot
.71 .2359 Mdot
.71 .23592 Mdot
.71 .23603 Mdot
.71 .23694 Mdot
.71 .23737 Mdot
.71 .23849 Mdot
.71 .23858 Mdot
.71 .23892 Mdot
.71 .23906 Mdot
.71 .23956 Mdot
.71 .23957 Mdot
.71 .23989 Mdot
.71 .24026 Mdot
.71 .24027 Mdot
.71 .24066 Mdot
.71 .24077 Mdot
.71 .24099 Mdot
.71 .24119 Mdot
.71 .24183 Mdot
.71 .24217 Mdot
.71 .24251 Mdot
.71 .24253 Mdot
.71 .24276 Mdot
.71 .24295 Mdot
.71 .24319 Mdot
.71 .24322 Mdot
.71 .24326 Mdot
.71 .24326 Mdot
.71 .24393 Mdot
.71 .24461 Mdot
.71 .24546 Mdot
.71 .24558 Mdot
.71 .24563 Mdot
.71 .24576 Mdot
.71 .24581 Mdot
.71 .24592 Mdot
.71 .24611 Mdot
.71 .24662 Mdot
.71 .24692 Mdot
.71 .2471 Mdot
.71 .24715 Mdot
.71 .2472 Mdot
.71 .24724 Mdot
.71 .24725 Mdot
.71 .24768 Mdot
.71 .24825 Mdot
.71 .24952 Mdot
.71 .24962 Mdot
.71 .24992 Mdot
.71 .25037 Mdot
.71 .25045 Mdot
.71 .25078 Mdot
.71 .25126 Mdot
.71 .2513 Mdot
.71 .25131 Mdot
.71 .25163 Mdot
.71 .25317 Mdot
.71 .25488 Mdot
.71 .25574 Mdot
.71 .25627 Mdot
.71 .25702 Mdot
.71 .25824 Mdot
.71 .25901 Mdot
.71 .26127 Mdot
.71 .26201 Mdot
.71 .26208 Mdot
.71 .2624 Mdot
.71 .26252 Mdot
.71 .26321 Mdot
.71 .26392 Mdot
.71 .26454 Mdot
.71 .26598 Mdot
.71 .26674 Mdot
.71 .26696 Mdot
.71 .26759 Mdot
.71 .2676 Mdot
.71 .26886 Mdot
.71 .27131 Mdot
.71 .27168 Mdot
.71 .27248 Mdot
.71 .27258 Mdot
.71 .27321 Mdot
.71 .27516 Mdot
.71 .27658 Mdot
.71 .27688 Mdot
.71 .27735 Mdot
.71 .27825 Mdot
.71 .27854 Mdot
.71 .2788 Mdot
.71 .27888 Mdot
.71 .27915 Mdot
.71 .27978 Mdot
.71 .27981 Mdot
.71 .28038 Mdot
.71 .28072 Mdot
.71 .2809 Mdot
.71 .28121 Mdot
.71 .28222 Mdot
.71 .28284 Mdot
.71 .28358 Mdot
.71 .28439 Mdot
.71 .28474 Mdot
.71 .28493 Mdot
.71 .28513 Mdot
.71 .28605 Mdot
.71 .28798 Mdot
.71 .28889 Mdot
.71 .28935 Mdot
.71 .2894 Mdot
.71 .28945 Mdot
.71 .28968 Mdot
.71 .29037 Mdot
.71 .29163 Mdot
.71 .2939 Mdot
.71 .29398 Mdot
.71 .29399 Mdot
.71 .294 Mdot
.71 .29412 Mdot
.71 .2949 Mdot
.71 .29602 Mdot
.71 .29612 Mdot
.71 .2965 Mdot
.71 .2971 Mdot
.71 .29713 Mdot
.71 .29763 Mdot
.71 .29777 Mdot
.71 .29961 Mdot
.71 .30055 Mdot
.71 .3007 Mdot
.71 .30109 Mdot
.71 .30124 Mdot
.71 .30129 Mdot
.71 .30197 Mdot
.71 .30276 Mdot
.71 .30323 Mdot
.71 .30357 Mdot
.71 .30359 Mdot
.71 .30363 Mdot
.71 .3041 Mdot
.71 .30412 Mdot
.71 .30495 Mdot
.71 .3073 Mdot
.71 .30757 Mdot
.71 .30933 Mdot
.71 .30944 Mdot
.71 .31041 Mdot
.71 .31185 Mdot
.71 .31223 Mdot
.71 .31316 Mdot
.71 .3138 Mdot
.71 .31515 Mdot
.71 .3162 Mdot
.71 .31625 Mdot
.71 .31636 Mdot
.71 .31646 Mdot
.71 .31838 Mdot
.71 .31894 Mdot
.71 .31897 Mdot
.71 .31941 Mdot
.71 .3241 Mdot
.71 .32442 Mdot
.71 .32536 Mdot
.71 .32615 Mdot
.71 .32643 Mdot
.71 .32701 Mdot
.71 .3288 Mdot
.71 .32883 Mdot
.71 .32898 Mdot
.71 .33027 Mdot
.71 .33088 Mdot
.71 .33247 Mdot
.71 .3326 Mdot
.71 .33308 Mdot
.71 .33329 Mdot
.71 .334 Mdot
.71 .33401 Mdot
.71 .33446 Mdot
.71 .335 Mdot
.71 .33501 Mdot
.71 .33555 Mdot
.71 .33571 Mdot
.71 .33603 Mdot
.71 .33632 Mdot
.71 .33722 Mdot
.71 .3377 Mdot
.71 .33818 Mdot
.71 .33821 Mdot
.71 .33854 Mdot
.71 .33881 Mdot
.71 .33915 Mdot
.71 .33919 Mdot
.71 .33925 Mdot
.71 .33925 Mdot
.71 .34019 Mdot
.71 .34116 Mdot
.71 .34237 Mdot
.71 .34254 Mdot
.71 .34262 Mdot
.71 .3428 Mdot
.71 .34286 Mdot
.71 .34303 Mdot
.71 .34329 Mdot
.71 .34402 Mdot
.71 .34445 Mdot
.71 .34471 Mdot
.71 .34477 Mdot
.71 .34484 Mdot
.71 .3449 Mdot
.71 .34492 Mdot
.71 .34553 Mdot
.71 .34633 Mdot
.71 .34813 Mdot
.71 .34829 Mdot
.71 .34871 Mdot
.71 .34934 Mdot
.71 .34946 Mdot
.71 .34993 Mdot
.71 .35062 Mdot
.71 .35067 Mdot
.71 .35067 Mdot
.71 .35113 Mdot
.71 .35332 Mdot
.71 .35575 Mdot
.71 .35697 Mdot
.71 .35773 Mdot
.71 .35879 Mdot
.71 .36052 Mdot
.71 .36161 Mdot
.71 .36483 Mdot
.71 .36587 Mdot
.71 .36597 Mdot
.71 .36642 Mdot
.71 .3666 Mdot
.71 .36758 Mdot
.71 .36859 Mdot
.71 .36947 Mdot
.71 .37151 Mdot
.71 .37259 Mdot
.71 .3729 Mdot
.71 .37379 Mdot
.71 .37382 Mdot
.71 .3756 Mdot
.71 .37908 Mdot
.71 .37961 Mdot
.71 .38073 Mdot
.71 .38088 Mdot
.71 .38178 Mdot
.71 .38455 Mdot
.71 .38657 Mdot
.71 .38699 Mdot
.71 .38765 Mdot
.71 .38893 Mdot
.71 .38935 Mdot
.71 .38972 Mdot
.71 .38983 Mdot
.71 .39022 Mdot
.71 .3911 Mdot
.71 .39114 Mdot
.71 .39196 Mdot
.71 .39244 Mdot
.71 .3927 Mdot
.71 .39314 Mdot
.71 .39457 Mdot
.71 .39545 Mdot
.71 .39651 Mdot
.71 .39765 Mdot
.71 .39815 Mdot
.71 .39842 Mdot
.71 .39871 Mdot
.71 .40001 Mdot
.71 .40275 Mdot
.71 .40404 Mdot
.71 .4047 Mdot
.71 .40477 Mdot
.71 .40484 Mdot
.71 .40516 Mdot
.71 .40615 Mdot
.71 .40794 Mdot
.71 .41116 Mdot
.71 .41128 Mdot
.71 .41128 Mdot
.71 .4113 Mdot
.71 .41146 Mdot
.71 .41258 Mdot
.71 .41417 Mdot
.71 .4143 Mdot
.71 .41485 Mdot
.71 .41571 Mdot
.71 .41575 Mdot
.71 .41645 Mdot
.71 .41665 Mdot
.71 .41926 Mdot
.71 .4206 Mdot
.71 .42082 Mdot
.71 .42137 Mdot
.71 .42158 Mdot
.71 .42166 Mdot
.71 .42262 Mdot
.71 .42374 Mdot
.71 .42441 Mdot
.71 .42489 Mdot
.71 .42492 Mdot
.71 .42498 Mdot
.71 .42565 Mdot
.71 .42567 Mdot
.71 .42684 Mdot
.71 .43019 Mdot
.71 .43056 Mdot
.71 .43307 Mdot
.71 .43323 Mdot
.712 .0153 Mdot
.712 .01555 Mdot
.712 .01591 Mdot
.712 .01606 Mdot
.712 .01619 Mdot
.712 .01641 Mdot
.712 .01663 Mdot
.712 .01682 Mdot
.712 .01682 Mdot
.712 .01713 Mdot
.712 .01744 Mdot
.712 .01753 Mdot
.712 .01771 Mdot
.712 .01771 Mdot
.712 .01816 Mdot
.712 .01822 Mdot
.712 .01859 Mdot
.712 .01872 Mdot
.712 .01897 Mdot
.712 .01898 Mdot
.712 .01912 Mdot
.712 .01962 Mdot
.712 .01971 Mdot
.712 .02024 Mdot
.712 .02042 Mdot
.712 .02063 Mdot
.712 .02078 Mdot
.712 .02079 Mdot
.712 .02099 Mdot
.712 .0214 Mdot
.712 .0217 Mdot
.712 .02182 Mdot
.712 .02183 Mdot
.712 .02254 Mdot
.712 .02258 Mdot
.712 .02284 Mdot
.712 .02314 Mdot
.712 .02335 Mdot
.712 .02337 Mdot
.712 .02364 Mdot
.712 .02409 Mdot
.712 .02416 Mdot
.712 .02423 Mdot
.712 .02435 Mdot
.712 .02462 Mdot
.712 .02466 Mdot
.712 .02485 Mdot
.712 .02519 Mdot
.712 .02526 Mdot
.712 .02586 Mdot
.712 .02591 Mdot
.712 .02628 Mdot
.712 .02672 Mdot
.712 .02701 Mdot
.712 .02704 Mdot
.712 .02704 Mdot
.712 .02743 Mdot
.712 .02785 Mdot
.712 .02794 Mdot
.712 .02806 Mdot
.712 .02817 Mdot
.712 .02827 Mdot
.712 .02843 Mdot
.712 .02882 Mdot
.712 .02888 Mdot
.712 .02914 Mdot
.712 .02963 Mdot
.712 .02964 Mdot
.712 .02973 Mdot
.712 .03059 Mdot
.712 .03066 Mdot
.712 .03119 Mdot
.712 .0316 Mdot
.712 .03181 Mdot
.712 .03223 Mdot
.712 .03226 Mdot
.712 .03226 Mdot
.712 .03264 Mdot
.712 .03282 Mdot
.712 .03342 Mdot
.712 .03355 Mdot
.712 .03372 Mdot
.712 .03387 Mdot
.712 .03401 Mdot
.712 .03421 Mdot
.712 .03425 Mdot
.712 .03481 Mdot
.712 .03489 Mdot
.712 .03526 Mdot
.712 .03559 Mdot
.712 .03596 Mdot
.712 .03596 Mdot
.712 .03609 Mdot
.712 .03722 Mdot
.712 .03732 Mdot
.712 .03742 Mdot
.712 .03744 Mdot
.712 .03748 Mdot
.712 .03794 Mdot
.712 .03818 Mdot
.712 .03876 Mdot
.712 .03905 Mdot
.712 .03965 Mdot
.712 .0397 Mdot
.712 .03971 Mdot
.712 .04024 Mdot
.712 .04035 Mdot
.712 .0405 Mdot
.712 .04062 Mdot
.712 .04096 Mdot
.712 .04135 Mdot
.712 .04154 Mdot
.712 .04178 Mdot
.712 .04199 Mdot
.712 .04219 Mdot
.712 .04235 Mdot
.712 .04247 Mdot
.712 .04253 Mdot
.712 .04297 Mdot
.712 .04333 Mdot
.712 .04344 Mdot
.712 .04392 Mdot
.712 .04397 Mdot
.712 .04444 Mdot
.712 .04486 Mdot
.712 .04497 Mdot
.712 .04497 Mdot
.712 .04516 Mdot
.712 .04579 Mdot
.712 .04677 Mdot
.712 .04691 Mdot
.712 .04705 Mdot
.712 .04708 Mdot
.712 .04714 Mdot
.712 .04716 Mdot
.712 .04779 Mdot
.712 .04812 Mdot
.712 .04896 Mdot
.712 .04937 Mdot
.712 .04953 Mdot
.712 .05023 Mdot
.712 .05029 Mdot
.712 .0503 Mdot
.712 .05106 Mdot
.712 .05122 Mdot
.712 .05129 Mdot
.712 .05143 Mdot
.712 .0516 Mdot
.712 .05207 Mdot
.712 .05209 Mdot
.712 .05256 Mdot
.712 .05264 Mdot
.712 .05272 Mdot
.712 .05291 Mdot
.712 .05326 Mdot
.712 .05332 Mdot
.712 .05356 Mdot
.712 .05384 Mdot
.712 .05407 Mdot
.712 .05424 Mdot
.712 .05433 Mdot
.712 .05488 Mdot
.712 .05495 Mdot
.712 .05546 Mdot
.712 .05562 Mdot
.712 .05626 Mdot
.712 .0563 Mdot
.712 .05637 Mdot
.712 .05704 Mdot
.712 .05765 Mdot
.712 .0578 Mdot
.712 .0578 Mdot
.712 .05806 Mdot
.712 .05826 Mdot
.712 .05895 Mdot
.712 .05896 Mdot
.712 .05959 Mdot
.712 .06008 Mdot
.712 .06036 Mdot
.712 .06056 Mdot
.712 .06066 Mdot
.712 .06075 Mdot
.712 .0608 Mdot
.712 .06086 Mdot
.712 .06088 Mdot
.712 .06092 Mdot
.712 .06093 Mdot
.712 .06133 Mdot
.712 .06181 Mdot
.712 .06229 Mdot
.712 .06298 Mdot
.712 .06347 Mdot
.712 .06402 Mdot
.712 .06406 Mdot
.712 .0643 Mdot
.712 .06528 Mdot
.712 .06537 Mdot
.712 .06539 Mdot
.712 .0664 Mdot
.712 .06647 Mdot
.712 .06669 Mdot
.712 .0668 Mdot
.712 .067 Mdot
.712 .06724 Mdot
.712 .06791 Mdot
.712 .06794 Mdot
.712 .06829 Mdot
.712 .06836 Mdot
.712 .0686 Mdot
.712 .06872 Mdot
.712 .06883 Mdot
.712 .0691 Mdot
.712 .0696 Mdot
.712 .06969 Mdot
.712 .06977 Mdot
.712 .07003 Mdot
.712 .0702 Mdot
.712 .07044 Mdot
.712 .07052 Mdot
.712 .0706 Mdot
.712 .07072 Mdot
.712 .07076 Mdot
.712 .071 Mdot
.712 .07113 Mdot
.712 .07141 Mdot
.712 .07191 Mdot
.712 .07201 Mdot
.712 .07273 Mdot
.712 .07296 Mdot
.712 .07306 Mdot
.712 .07364 Mdot
.712 .07388 Mdot
.712 .07393 Mdot
.712 .07403 Mdot
.712 .07498 Mdot
.712 .07585 Mdot
.712 .07606 Mdot
.712 .07607 Mdot
.712 .07628 Mdot
.712 .07644 Mdot
.712 .07673 Mdot
.712 .0769 Mdot
.712 .07739 Mdot
.712 .07769 Mdot
.712 .0777 Mdot
.712 .07772 Mdot
.712 .07777 Mdot
.712 .07862 Mdot
.712 .07931 Mdot
.712 .07933 Mdot
.712 .07971 Mdot
.712 .08 Mdot
.712 .08014 Mdot
.712 .08017 Mdot
.712 .08027 Mdot
.712 .08033 Mdot
.712 .08042 Mdot
.712 .08046 Mdot
.712 .08051 Mdot
.712 .08052 Mdot
.712 .0811 Mdot
.712 .08178 Mdot
.712 .08246 Mdot
.712 .08345 Mdot
.712 .08351 Mdot
.712 .08415 Mdot
.712 .08493 Mdot
.712 .08499 Mdot
.712 .08501 Mdot
.712 .08512 Mdot
.712 .08532 Mdot
.712 .08672 Mdot
.712 .08685 Mdot
.712 .08688 Mdot
.712 .08698 Mdot
.712 .08738 Mdot
.712 .08824 Mdot
.712 .08832 Mdot
.712 .08841 Mdot
.712 .08873 Mdot
.712 .08888 Mdot
.712 .08917 Mdot
.712 .08951 Mdot
.712 .09047 Mdot
.712 .09051 Mdot
.712 .09059 Mdot
.712 .091 Mdot
.712 .09111 Mdot
.712 .09145 Mdot
.712 .09161 Mdot
.712 .09177 Mdot
.712 .09217 Mdot
.712 .09287 Mdot
.712 .093 Mdot
.712 .09311 Mdot
.712 .09348 Mdot
.712 .09372 Mdot
.712 .09406 Mdot
.712 .09418 Mdot
.712 .09429 Mdot
.712 .09437 Mdot
.712 .09447 Mdot
.712 .09452 Mdot
.712 .09487 Mdot
.712 .09504 Mdot
.712 .09545 Mdot
.712 .09579 Mdot
.712 .09615 Mdot
.712 .09617 Mdot
.712 .09631 Mdot
.712 .09669 Mdot
.712 .09733 Mdot
.712 .09766 Mdot
.712 .0978 Mdot
.712 .09863 Mdot
.712 .09897 Mdot
.712 .09903 Mdot
.712 .09918 Mdot
.712 .10054 Mdot
.712 .10062 Mdot
.712 .10173 Mdot
.712 .10177 Mdot
.712 .10208 Mdot
.712 .10209 Mdot
.712 .10238 Mdot
.712 .10262 Mdot
.712 .10302 Mdot
.712 .10315 Mdot
.712 .10326 Mdot
.712 .10339 Mdot
.712 .10396 Mdot
.712 .10439 Mdot
.712 .10441 Mdot
.712 .10444 Mdot
.712 .1045 Mdot
.712 .10466 Mdot
.712 .10519 Mdot
.712 .10526 Mdot
.712 .1054 Mdot
.712 .10572 Mdot
.712 .10605 Mdot
.712 .10644 Mdot
.712 .1067 Mdot
.712 .10673 Mdot
.712 .10697 Mdot
.712 .10726 Mdot
.712 .10768 Mdot
.712 .10788 Mdot
.712 .10792 Mdot
.712 .10807 Mdot
.712 .10816 Mdot
.712 .10828 Mdot
.712 .10833 Mdot
.712 .10836 Mdot
.712 .1084 Mdot
.712 .10843 Mdot
.712 .10924 Mdot
.712 .11 Mdot
.712 .11021 Mdot
.712 .11071 Mdot
.712 .11118 Mdot
.712 .11146 Mdot
.712 .1121 Mdot
.712 .11215 Mdot
.712 .11259 Mdot
.712 .11268 Mdot
.712 .11287 Mdot
.712 .11359 Mdot
.712 .1147 Mdot
.712 .11478 Mdot
.712 .11481 Mdot
.712 .11498 Mdot
.712 .11517 Mdot
.712 .11526 Mdot
.712 .11624 Mdot
.712 .11632 Mdot
.712 .11693 Mdot
.712 .11726 Mdot
.712 .11744 Mdot
.712 .11747 Mdot
.712 .11763 Mdot
.712 .11797 Mdot
.712 .11818 Mdot
.712 .11855 Mdot
.712 .11874 Mdot
.712 .11884 Mdot
.712 .11902 Mdot
.712 .11939 Mdot
.712 .11941 Mdot
.712 .11952 Mdot
.712 .11966 Mdot
.712 .12011 Mdot
.712 .12031 Mdot
.712 .12033 Mdot
.712 .12074 Mdot
.712 .12122 Mdot
.712 .12259 Mdot
.712 .12264 Mdot
.712 .12276 Mdot
.712 .12335 Mdot
.712 .12341 Mdot
.712 .1235 Mdot
.712 .12383 Mdot
.712 .12399 Mdot
.712 .12422 Mdot
.712 .12445 Mdot
.712 .12467 Mdot
.712 .125 Mdot
.712 .12601 Mdot
.712 .1262 Mdot
.712 .12636 Mdot
.712 .1265 Mdot
.712 .12688 Mdot
.712 .12722 Mdot
.712 .1277 Mdot
.712 .12787 Mdot
.712 .12803 Mdot
.712 .12815 Mdot
.712 .12829 Mdot
.712 .12835 Mdot
.712 .12845 Mdot
.712 .12885 Mdot
.712 .1291 Mdot
.712 .12968 Mdot
.712 .13016 Mdot
.712 .13068 Mdot
.712 .1307 Mdot
.712 .13073 Mdot
.712 .1309 Mdot
.712 .13144 Mdot
.712 .13224 Mdot
.712 .13236 Mdot
.712 .13243 Mdot
.712 .13283 Mdot
.712 .13303 Mdot
.712 .13384 Mdot
.712 .13421 Mdot
.712 .13469 Mdot
.712 .13478 Mdot
.712 .13499 Mdot
.712 .13557 Mdot
.712 .13692 Mdot
.712 .13705 Mdot
.712 .13801 Mdot
.712 .13827 Mdot
.712 .13862 Mdot
.712 .13868 Mdot
.712 .13912 Mdot
.712 .13913 Mdot
.712 .13917 Mdot
.712 .13942 Mdot
.712 .13955 Mdot
.712 .13989 Mdot
.712 .14029 Mdot
.712 .14046 Mdot
.712 .14064 Mdot
.712 .1408 Mdot
.712 .14081 Mdot
.712 .14099 Mdot
.712 .14154 Mdot
.712 .1418 Mdot
.712 .14182 Mdot
.712 .14197 Mdot
.712 .14222 Mdot
.712 .14237 Mdot
.712 .14241 Mdot
.712 .14244 Mdot
.712 .14248 Mdot
.712 .14257 Mdot
.712 .14279 Mdot
.712 .14355 Mdot
.712 .14365 Mdot
.712 .14385 Mdot
.712 .1443 Mdot
.712 .14477 Mdot
.712 .14533 Mdot
.712 .14569 Mdot
.712 .14574 Mdot
.712 .14609 Mdot
.712 .1465 Mdot
.712 .1471 Mdot
.712 .14716 Mdot
.712 .14738 Mdot
.712 .14744 Mdot
.712 .14765 Mdot
.712 .14778 Mdot
.712 .14796 Mdot
.712 .14803 Mdot
.712 .14806 Mdot
.712 .14812 Mdot
.712 .14816 Mdot
.712 .14932 Mdot
.712 .1504 Mdot
.712 .1507 Mdot
.712 .15142 Mdot
.712 .15159 Mdot
.712 .15208 Mdot
.712 .15248 Mdot
.712 .15281 Mdot
.712 .15339 Mdot
.712 .15346 Mdot
.712 .15409 Mdot
.712 .15422 Mdot
.712 .15449 Mdot
.712 .15551 Mdot
.712 .15576 Mdot
.712 .15646 Mdot
.712 .15709 Mdot
.712 .15721 Mdot
.712 .15725 Mdot
.712 .15749 Mdot
.712 .15776 Mdot
.712 .15789 Mdot
.712 .15851 Mdot
.712 .15928 Mdot
.712 .1594 Mdot
.712 .16015 Mdot
.712 .16027 Mdot
.712 .16073 Mdot
.712 .161 Mdot
.712 .16104 Mdot
.712 .16126 Mdot
.712 .1615 Mdot
.712 .16175 Mdot
.712 .16206 Mdot
.712 .16258 Mdot
.712 .16284 Mdot
.712 .16299 Mdot
.712 .16324 Mdot
.712 .16378 Mdot
.712 .1638 Mdot
.712 .16387 Mdot
.712 .16396 Mdot
.712 .16416 Mdot
.712 .16418 Mdot
.712 .1648 Mdot
.712 .16508 Mdot
.712 .16511 Mdot
.712 .1657 Mdot
.712 .16638 Mdot
.712 .16674 Mdot
.712 .16728 Mdot
.712 .16833 Mdot
.712 .1684 Mdot
.712 .16842 Mdot
.712 .16857 Mdot
.712 .16941 Mdot
.712 .1695 Mdot
.712 .16962 Mdot
.712 .1701 Mdot
.712 .17032 Mdot
.712 .17064 Mdot
.712 .17097 Mdot
.712 .17129 Mdot
.712 .17177 Mdot
.712 .17259 Mdot
.712 .1732 Mdot
.712 .17347 Mdot
.712 .17364 Mdot
.712 .17369 Mdot
.712 .1739 Mdot
.712 .17444 Mdot
.712 .17492 Mdot
.712 .17561 Mdot
.712 .17585 Mdot
.712 .17607 Mdot
.712 .17624 Mdot
.712 .17644 Mdot
.712 .17651 Mdot
.712 .17653 Mdot
.712 .17667 Mdot
.712 .17725 Mdot
.712 .17761 Mdot
.712 .17843 Mdot
.712 .17908 Mdot
.712 .17911 Mdot
.712 .1796 Mdot
.712 .17974 Mdot
.712 .17986 Mdot
.712 .17988 Mdot
.712 .17993 Mdot
.712 .18017 Mdot
.712 .18074 Mdot
.712 .18094 Mdot
.712 .18185 Mdot
.712 .18207 Mdot
.712 .18224 Mdot
.712 .18234 Mdot
.712 .18237 Mdot
.712 .18291 Mdot
.712 .1832 Mdot
.712 .18436 Mdot
.712 .18487 Mdot
.712 .18491 Mdot
.712 .18556 Mdot
.712 .18569 Mdot
.712 .18599 Mdot
.712 .18681 Mdot
.712 .18812 Mdot
.712 .18861 Mdot
.712 .18874 Mdot
.712 .18892 Mdot
.712 .19028 Mdot
.712 .19066 Mdot
.712 .19116 Mdot
.712 .19124 Mdot
.712 .19168 Mdot
.712 .19186 Mdot
.712 .19189 Mdot
.712 .19194 Mdot
.712 .19216 Mdot
.712 .1923 Mdot
.712 .19248 Mdot
.712 .19296 Mdot
.712 .19353 Mdot
.712 .19378 Mdot
.712 .19404 Mdot
.712 .19426 Mdot
.712 .19427 Mdot
.712 .19452 Mdot
.712 .19532 Mdot
.712 .19569 Mdot
.712 .19572 Mdot
.712 .19593 Mdot
.712 .19629 Mdot
.712 .19649 Mdot
.712 .19656 Mdot
.712 .19659 Mdot
.712 .19665 Mdot
.712 .19678 Mdot
.712 .1971 Mdot
.712 .19817 Mdot
.712 .19832 Mdot
.712 .19861 Mdot
.712 .19924 Mdot
.712 .19992 Mdot
.712 .20071 Mdot
.712 .20123 Mdot
.712 .2013 Mdot
.712 .20179 Mdot
.712 .20238 Mdot
.712 .20323 Mdot
.712 .20332 Mdot
.712 .20363 Mdot
.712 .20372 Mdot
.712 .20402 Mdot
.712 .20419 Mdot
.712 .20445 Mdot
.712 .20455 Mdot
.712 .2046 Mdot
.712 .20469 Mdot
.712 .20474 Mdot
.712 .2064 Mdot
.712 .20793 Mdot
.712 .20836 Mdot
.712 .20938 Mdot
.712 .20962 Mdot
.712 .21033 Mdot
.712 .2109 Mdot
.712 .21137 Mdot
.712 .21218 Mdot
.712 .21229 Mdot
.712 .21318 Mdot
.712 .21337 Mdot
.712 .21376 Mdot
.712 .2152 Mdot
.712 .21557 Mdot
.712 .21656 Mdot
.712 .21745 Mdot
.712 .21763 Mdot
.712 .21768 Mdot
.712 .21803 Mdot
.712 .21841 Mdot
.712 .21859 Mdot
.712 .21947 Mdot
.712 .22058 Mdot
.712 .22075 Mdot
.712 .22182 Mdot
.712 .22198 Mdot
.712 .22265 Mdot
.712 .22302 Mdot
.712 .22308 Mdot
.712 .22339 Mdot
.712 .22374 Mdot
.712 .22409 Mdot
.712 .22453 Mdot
.712 .22528 Mdot
.712 .22565 Mdot
.712 .22586 Mdot
.712 .22622 Mdot
.712 .22698 Mdot
.712 .22702 Mdot
.712 .22711 Mdot
.712 .22724 Mdot
.712 .22752 Mdot
.712 .22756 Mdot
.712 .22843 Mdot
.712 .22883 Mdot
.712 .22888 Mdot
.712 .22971 Mdot
.712 .23068 Mdot
.712 .2312 Mdot
.712 .23197 Mdot
.712 .23346 Mdot
.712 .23356 Mdot
.712 .23358 Mdot
.712 .23381 Mdot
.712 .235 Mdot
.712 .23513 Mdot
.712 .2353 Mdot
.712 .23599 Mdot
.712 .23629 Mdot
.712 .23676 Mdot
.712 .23722 Mdot
.712 .23768 Mdot
.712 .23836 Mdot
.712 .23953 Mdot
.712 .24039 Mdot
.712 .24078 Mdot
.712 .24102 Mdot
.712 .2411 Mdot
.712 .2414 Mdot
.712 .24216 Mdot
.712 .24285 Mdot
.712 .24383 Mdot
.712 .24417 Mdot
.712 .24449 Mdot
.712 .24473 Mdot
.712 .24501 Mdot
.712 .24511 Mdot
.712 .24515 Mdot
.712 .24535 Mdot
.712 .24616 Mdot
.712 .24667 Mdot
.712 .24785 Mdot
.712 .24878 Mdot
.712 .24881 Mdot
.712 .24951 Mdot
.712 .24972 Mdot
.712 .24988 Mdot
.712 .24991 Mdot
.712 .24998 Mdot
.712 .25032 Mdot
.712 .25113 Mdot
.712 .25142 Mdot
.712 .25272 Mdot
.712 .25302 Mdot
.712 .25326 Mdot
.712 .25341 Mdot
.712 .25345 Mdot
.712 .25422 Mdot
.712 .25464 Mdot
.712 .25628 Mdot
.712 .25702 Mdot
.712 .25708 Mdot
.712 .258 Mdot
.712 .25819 Mdot
.712 .25861 Mdot
.712 .25977 Mdot
.712 .26164 Mdot
.712 .26234 Mdot
.712 .26252 Mdot
.712 .26278 Mdot
.712 .26472 Mdot
.712 .26527 Mdot
.712 .26597 Mdot
.712 .26609 Mdot
.712 .26671 Mdot
.712 .26697 Mdot
.712 .26701 Mdot
.712 .26708 Mdot
.712 .2674 Mdot
.712 .26759 Mdot
.712 .26785 Mdot
.712 .26854 Mdot
.712 .26935 Mdot
.712 .2697 Mdot
.712 .27007 Mdot
.712 .27038 Mdot
.712 .27041 Mdot
.712 .27076 Mdot
.712 .27189 Mdot
.712 .27242 Mdot
.712 .27246 Mdot
.712 .27276 Mdot
.712 .27327 Mdot
.712 .27356 Mdot
.712 .27366 Mdot
.712 .27371 Mdot
.712 .27379 Mdot
.712 .27398 Mdot
.712 .27443 Mdot
.712 .27596 Mdot
.712 .27617 Mdot
.712 .27658 Mdot
.712 .27748 Mdot
.712 .27845 Mdot
.712 .27957 Mdot
.712 .28031 Mdot
.712 .28041 Mdot
.712 .28111 Mdot
.712 .28195 Mdot
.712 .28316 Mdot
.712 .28329 Mdot
.712 .28373 Mdot
.712 .28385 Mdot
.712 .28428 Mdot
.712 .28453 Mdot
.712 .2849 Mdot
.712 .28504 Mdot
.712 .28511 Mdot
.712 .28524 Mdot
.712 .28531 Mdot
.712 .28767 Mdot
.712 .28985 Mdot
.712 .29046 Mdot
.712 .29191 Mdot
.712 .29226 Mdot
.712 .29327 Mdot
.712 .29408 Mdot
.712 .29475 Mdot
.712 .29591 Mdot
.712 .29607 Mdot
.712 .29733 Mdot
.712 .29759 Mdot
.712 .29815 Mdot
.712 .30021 Mdot
.712 .30073 Mdot
.712 .30215 Mdot
.712 .30341 Mdot
.712 .30367 Mdot
.712 .30374 Mdot
.712 .30423 Mdot
.712 .30478 Mdot
.712 .30503 Mdot
.712 .30629 Mdot
.712 .30787 Mdot
.712 .30811 Mdot
.712 .30963 Mdot
.712 .30986 Mdot
.712 .31081 Mdot
.712 .31134 Mdot
.712 .31143 Mdot
.712 .31187 Mdot
.712 .31237 Mdot
.712 .31286 Mdot
.712 .31349 Mdot
.712 .31455 Mdot
.712 .31509 Mdot
.712 .31538 Mdot
.712 .31589 Mdot
.712 .31698 Mdot
.712 .31703 Mdot
.712 .31716 Mdot
.712 .31735 Mdot
.712 .31775 Mdot
.712 .3178 Mdot
.712 .31905 Mdot
.712 .31962 Mdot
.712 .31968 Mdot
.712 .32087 Mdot
.712 .32225 Mdot
.712 .32298 Mdot
.712 .32408 Mdot
.712 .3262 Mdot
.712 .32635 Mdot
.712 .32638 Mdot
.712 .32671 Mdot
.712 .3284 Mdot
.712 .32859 Mdot
.712 .32883 Mdot
.712 .3298 Mdot
.712 .33024 Mdot
.712 .3309 Mdot
.712 .33157 Mdot
.712 .33222 Mdot
.712 .33318 Mdot
.712 .33485 Mdot
.712 .33608 Mdot
.712 .33663 Mdot
.712 .33697 Mdot
.712 .33708 Mdot
.712 .33751 Mdot
.712 .3386 Mdot
.712 .33957 Mdot
.712 .34098 Mdot
.712 .34146 Mdot
.712 .34191 Mdot
.712 .34225 Mdot
.712 .34266 Mdot
.712 .3428 Mdot
.712 .34285 Mdot
.712 .34313 Mdot
.712 .34429 Mdot
.712 .34502 Mdot
.712 .34669 Mdot
.712 .34802 Mdot
.712 .34807 Mdot
.712 .34906 Mdot
.712 .34936 Mdot
.712 .34958 Mdot
.712 .34964 Mdot
.712 .34973 Mdot
.712 .35021 Mdot
.712 .35137 Mdot
.712 .35178 Mdot
.712 .35363 Mdot
.712 .35406 Mdot
.712 .35441 Mdot
.712 .35462 Mdot
.712 .35467 Mdot
.712 .35577 Mdot
.712 .35636 Mdot
.712 .35871 Mdot
.712 .35976 Mdot
.712 .35984 Mdot
.712 .36115 Mdot
.712 .36142 Mdot
.712 .36203 Mdot
.712 .36368 Mdot
.712 .36633 Mdot
.712 .36733 Mdot
.712 .3676 Mdot
.712 .36796 Mdot
.712 .37073 Mdot
.712 .3715 Mdot
.712 .3725 Mdot
.712 .37267 Mdot
.712 .37356 Mdot
.712 .37393 Mdot
.712 .37398 Mdot
.712 .37408 Mdot
.712 .37453 Mdot
.712 .37481 Mdot
.712 .37518 Mdot
.712 .37616 Mdot
.712 .37731 Mdot
.712 .37781 Mdot
.712 .37834 Mdot
.712 .37878 Mdot
.712 .37882 Mdot
.712 .37933 Mdot
.712 .38094 Mdot
.712 .38169 Mdot
.712 .38175 Mdot
.712 .38218 Mdot
.712 .3829 Mdot
.712 .38332 Mdot
.712 .38345 Mdot
.712 .38352 Mdot
.712 .38364 Mdot
.712 .38391 Mdot
.712 .38455 Mdot
.712 .38673 Mdot
.712 .38703 Mdot
.712 .38761 Mdot
.712 .3889 Mdot
.712 .39027 Mdot
.712 .39187 Mdot
.712 .39293 Mdot
.712 .39306 Mdot
.712 .39405 Mdot
.712 .39526 Mdot
.712 .39698 Mdot
.712 .39717 Mdot
.712 .39779 Mdot
.712 .39797 Mdot
.712 .39858 Mdot
.712 .39894 Mdot
.712 .39946 Mdot
.712 .39966 Mdot
.712 .39976 Mdot
.712 .39994 Mdot
.712 .40004 Mdot
.712 .40341 Mdot
.712 .40651 Mdot
.712 .40737 Mdot
.712 .40945 Mdot
.712 .40994 Mdot
.712 .41137 Mdot
.712 .41253 Mdot
.712 .41348 Mdot
.712 .41514 Mdot
.712 .41536 Mdot
.712 .41715 Mdot
.712 .41754 Mdot
.712 .41833 Mdot
.712 .42126 Mdot
.712 .422 Mdot
.712 .42402 Mdot
.712 .42582 Mdot
.712 .42618 Mdot
.712 .42629 Mdot
.712 .42698 Mdot
.712 .42777 Mdot
.712 .42813 Mdot
.712 .42992 Mdot
.712 .43217 Mdot
.712 .43251 Mdot
.712 .43467 Mdot
.712 .43501 Mdot
.714 .0156 Mdot
.714 .01582 Mdot
.714 .01597 Mdot
.714 .01598 Mdot
.714 .0163 Mdot
.714 .01651 Mdot
.714 .01653 Mdot
.714 .0167 Mdot
.714 .01697 Mdot
.714 .01698 Mdot
.714 .01728 Mdot
.714 .0173 Mdot
.714 .01755 Mdot
.714 .01776 Mdot
.714 .01794 Mdot
.714 .01795 Mdot
.714 .01838 Mdot
.714 .01841 Mdot
.714 .01877 Mdot
.714 .01887 Mdot
.714 .01889 Mdot
.714 .01897 Mdot
.714 .01907 Mdot
.714 .01917 Mdot
.714 .01931 Mdot
.714 .01933 Mdot
.714 .01946 Mdot
.714 .01995 Mdot
.714 .01999 Mdot
.714 .0205 Mdot
.714 .02065 Mdot
.714 .02068 Mdot
.714 .02079 Mdot
.714 .02093 Mdot
.714 .02108 Mdot
.714 .02128 Mdot
.714 .0213 Mdot
.714 .02149 Mdot
.714 .02161 Mdot
.714 .02219 Mdot
.714 .02225 Mdot
.714 .02298 Mdot
.714 .02319 Mdot
.714 .02324 Mdot
.714 .02336 Mdot
.714 .0234 Mdot
.714 .02359 Mdot
.714 .0238 Mdot
.714 .02407 Mdot
.714 .02409 Mdot
.714 .02412 Mdot
.714 .0244 Mdot
.714 .02457 Mdot
.714 .02463 Mdot
.714 .02539 Mdot
.714 .02548 Mdot
.714 .02652 Mdot
.714 .02681 Mdot
.714 .02689 Mdot
.714 .02706 Mdot
.714 .02711 Mdot
.714 .0272 Mdot
.714 .02739 Mdot
.714 .02762 Mdot
.714 .02769 Mdot
.714 .02776 Mdot
.714 .0279 Mdot
.714 .02807 Mdot
.714 .02811 Mdot
.714 .02815 Mdot
.714 .02838 Mdot
.714 .02854 Mdot
.714 .02879 Mdot
.714 .02887 Mdot
.714 .02928 Mdot
.714 .02938 Mdot
.714 .0296 Mdot
.714 .02995 Mdot
.714 .03008 Mdot
.714 .03078 Mdot
.714 .03119 Mdot
.714 .03136 Mdot
.714 .03157 Mdot
.714 .03186 Mdot
.714 .03199 Mdot
.714 .03209 Mdot
.714 .03222 Mdot
.714 .03234 Mdot
.714 .03242 Mdot
.714 .03252 Mdot
.714 .03254 Mdot
.714 .03281 Mdot
.714 .03314 Mdot
.714 .03324 Mdot
.714 .03335 Mdot
.714 .03355 Mdot
.714 .03377 Mdot
.714 .03379 Mdot
.714 .03384 Mdot
.714 .03389 Mdot
.714 .03408 Mdot
.714 .03422 Mdot
.714 .03446 Mdot
.714 .03481 Mdot
.714 .03494 Mdot
.714 .03551 Mdot
.714 .03565 Mdot
.714 .03597 Mdot
.714 .03608 Mdot
.714 .03628 Mdot
.714 .03647 Mdot
.714 .03666 Mdot
.714 .03766 Mdot
.714 .03788 Mdot
.714 .03824 Mdot
.714 .03848 Mdot
.714 .03863 Mdot
.714 .03879 Mdot
.714 .0392 Mdot
.714 .03925 Mdot
.714 .03926 Mdot
.714 .03938 Mdot
.714 .03953 Mdot
.714 .03971 Mdot
.714 .03988 Mdot
.714 .03999 Mdot
.714 .04015 Mdot
.714 .04016 Mdot
.714 .04024 Mdot
.714 .04055 Mdot
.714 .04103 Mdot
.714 .0411 Mdot
.714 .04117 Mdot
.714 .04132 Mdot
.714 .04161 Mdot
.714 .04186 Mdot
.714 .04192 Mdot
.714 .04195 Mdot
.714 .04202 Mdot
.714 .0421 Mdot
.714 .04238 Mdot
.714 .04257 Mdot
.714 .04291 Mdot
.714 .04341 Mdot
.714 .04359 Mdot
.714 .0444 Mdot
.714 .04441 Mdot
.714 .04448 Mdot
.714 .04461 Mdot
.714 .04507 Mdot
.714 .04523 Mdot
.714 .04551 Mdot
.714 .04579 Mdot
.714 .04606 Mdot
.714 .04748 Mdot
.714 .04752 Mdot
.714 .04758 Mdot
.714 .04779 Mdot
.714 .04831 Mdot
.714 .04865 Mdot
.714 .0487 Mdot
.714 .04887 Mdot
.714 .04909 Mdot
.714 .04968 Mdot
.714 .04975 Mdot
.714 .04977 Mdot
.714 .04993 Mdot
.714 .04993 Mdot
.714 .04994 Mdot
.714 .05016 Mdot
.714 .0504 Mdot
.714 .05065 Mdot
.714 .05079 Mdot
.714 .0508 Mdot
.714 .05081 Mdot
.714 .051 Mdot
.714 .05103 Mdot
.714 .05106 Mdot
.714 .05116 Mdot
.714 .05161 Mdot
.714 .05229 Mdot
.714 .05239 Mdot
.714 .05249 Mdot
.714 .05256 Mdot
.714 .05271 Mdot
.714 .05312 Mdot
.714 .05347 Mdot
.714 .05357 Mdot
.714 .05361 Mdot
.714 .05371 Mdot
.714 .05383 Mdot
.714 .05421 Mdot
.714 .05431 Mdot
.714 .0545 Mdot
.714 .05497 Mdot
.714 .0554 Mdot
.714 .05569 Mdot
.714 .05595 Mdot
.714 .0571 Mdot
.714 .05713 Mdot
.714 .05721 Mdot
.714 .05731 Mdot
.714 .05741 Mdot
.714 .05754 Mdot
.714 .05807 Mdot
.714 .05829 Mdot
.714 .05845 Mdot
.714 .05869 Mdot
.714 .05909 Mdot
.714 .05947 Mdot
.714 .0615 Mdot
.714 .06156 Mdot
.714 .06165 Mdot
.714 .06181 Mdot
.714 .06195 Mdot
.714 .0624 Mdot
.714 .06268 Mdot
.714 .06296 Mdot
.714 .06318 Mdot
.714 .06324 Mdot
.714 .06343 Mdot
.714 .06349 Mdot
.714 .0638 Mdot
.714 .06406 Mdot
.714 .06461 Mdot
.714 .06464 Mdot
.714 .06474 Mdot
.714 .06478 Mdot
.714 .065 Mdot
.714 .065 Mdot
.714 .06501 Mdot
.714 .06532 Mdot
.714 .06568 Mdot
.714 .06603 Mdot
.714 .06607 Mdot
.714 .06623 Mdot
.714 .06624 Mdot
.714 .06627 Mdot
.714 .06653 Mdot
.714 .06657 Mdot
.714 .06661 Mdot
.714 .06676 Mdot
.714 .06705 Mdot
.714 .0674 Mdot
.714 .06771 Mdot
.714 .06838 Mdot
.714 .06852 Mdot
.714 .06866 Mdot
.714 .06876 Mdot
.714 .06879 Mdot
.714 .06897 Mdot
.714 .06956 Mdot
.714 .07006 Mdot
.714 .0702 Mdot
.714 .07025 Mdot
.714 .07039 Mdot
.714 .07057 Mdot
.714 .07076 Mdot
.714 .07089 Mdot
.714 .07112 Mdot
.714 .07125 Mdot
.714 .07152 Mdot
.714 .07186 Mdot
.714 .07187 Mdot
.714 .0722 Mdot
.714 .07281 Mdot
.714 .07322 Mdot
.714 .07349 Mdot
.714 .07359 Mdot
.714 .07406 Mdot
.714 .07419 Mdot
.714 .07525 Mdot
.714 .07528 Mdot
.714 .0754 Mdot
.714 .07554 Mdot
.714 .07568 Mdot
.714 .07586 Mdot
.714 .07662 Mdot
.714 .07694 Mdot
.714 .07703 Mdot
.714 .07714 Mdot
.714 .07716 Mdot
.714 .07751 Mdot
.714 .07808 Mdot
.714 .07862 Mdot
.714 .07994 Mdot
.714 .07996 Mdot
.714 .08061 Mdot
.714 .08152 Mdot
.714 .08161 Mdot
.714 .08173 Mdot
.714 .08196 Mdot
.714 .08216 Mdot
.714 .0826 Mdot
.714 .08281 Mdot
.714 .08321 Mdot
.714 .08361 Mdot
.714 .08392 Mdot
.714 .08401 Mdot
.714 .08428 Mdot
.714 .08436 Mdot
.714 .08467 Mdot
.714 .08481 Mdot
.714 .08508 Mdot
.714 .08518 Mdot
.714 .08597 Mdot
.714 .08601 Mdot
.714 .08616 Mdot
.714 .0862 Mdot
.714 .08652 Mdot
.714 .08653 Mdot
.714 .08654 Mdot
.714 .08698 Mdot
.714 .08749 Mdot
.714 .088 Mdot
.714 .08804 Mdot
.714 .08827 Mdot
.714 .08829 Mdot
.714 .08833 Mdot
.714 .0886 Mdot
.714 .08871 Mdot
.714 .08877 Mdot
.714 .08882 Mdot
.714 .08903 Mdot
.714 .08942 Mdot
.714 .08945 Mdot
.714 .08995 Mdot
.714 .09012 Mdot
.714 .09027 Mdot
.714 .09039 Mdot
.714 .09083 Mdot
.714 .09135 Mdot
.714 .09136 Mdot
.714 .09154 Mdot
.714 .09175 Mdot
.714 .09175 Mdot
.714 .0919 Mdot
.714 .09193 Mdot
.714 .0922 Mdot
.714 .09303 Mdot
.714 .09375 Mdot
.714 .09385 Mdot
.714 .09395 Mdot
.714 .09403 Mdot
.714 .09423 Mdot
.714 .09447 Mdot
.714 .09475 Mdot
.714 .09493 Mdot
.714 .09526 Mdot
.714 .09545 Mdot
.714 .09572 Mdot
.714 .09584 Mdot
.714 .09632 Mdot
.714 .09633 Mdot
.714 .09681 Mdot
.714 .09681 Mdot
.714 .09767 Mdot
.714 .09826 Mdot
.714 .0984 Mdot
.714 .09864 Mdot
.714 .0988 Mdot
.714 .09946 Mdot
.714 .09965 Mdot
.714 .10047 Mdot
.714 .10115 Mdot
.714 .1012 Mdot
.714 .10138 Mdot
.714 .1014 Mdot
.714 .10158 Mdot
.714 .10169 Mdot
.714 .10177 Mdot
.714 .10204 Mdot
.714 .10311 Mdot
.714 .10357 Mdot
.714 .10371 Mdot
.714 .10386 Mdot
.714 .10389 Mdot
.714 .10438 Mdot
.714 .1052 Mdot
.714 .10575 Mdot
.714 .10598 Mdot
.714 .10603 Mdot
.714 .10708 Mdot
.714 .1072 Mdot
.714 .10785 Mdot
.714 .10788 Mdot
.714 .10828 Mdot
.714 .10881 Mdot
.714 .10897 Mdot
.714 .10939 Mdot
.714 .1094 Mdot
.714 .11011 Mdot
.714 .11024 Mdot
.714 .11042 Mdot
.714 .11074 Mdot
.714 .111 Mdot
.714 .11103 Mdot
.714 .11166 Mdot
.714 .11196 Mdot
.714 .11253 Mdot
.714 .11309 Mdot
.714 .11355 Mdot
.714 .11367 Mdot
.714 .11405 Mdot
.714 .11417 Mdot
.714 .11461 Mdot
.714 .11482 Mdot
.714 .1152 Mdot
.714 .11534 Mdot
.714 .11647 Mdot
.714 .11652 Mdot
.714 .11673 Mdot
.714 .1168 Mdot
.714 .11725 Mdot
.714 .11726 Mdot
.714 .11728 Mdot
.714 .11733 Mdot
.714 .1174 Mdot
.714 .11791 Mdot
.714 .1185 Mdot
.714 .11864 Mdot
.714 .11936 Mdot
.714 .11943 Mdot
.714 .11976 Mdot
.714 .11978 Mdot
.714 .11984 Mdot
.714 .12012 Mdot
.714 .12022 Mdot
.714 .12026 Mdot
.714 .12038 Mdot
.714 .12046 Mdot
.714 .12054 Mdot
.714 .12084 Mdot
.714 .12091 Mdot
.714 .12139 Mdot
.714 .12144 Mdot
.714 .12183 Mdot
.714 .12201 Mdot
.714 .12216 Mdot
.714 .12239 Mdot
.714 .1226 Mdot
.714 .12278 Mdot
.714 .12341 Mdot
.714 .12414 Mdot
.714 .12416 Mdot
.714 .12443 Mdot
.714 .12472 Mdot
.714 .12472 Mdot
.714 .12493 Mdot
.714 .12493 Mdot
.714 .12498 Mdot
.714 .12536 Mdot
.714 .12604 Mdot
.714 .12655 Mdot
.714 .12758 Mdot
.714 .12772 Mdot
.714 .12786 Mdot
.714 .12797 Mdot
.714 .12826 Mdot
.714 .1286 Mdot
.714 .129 Mdot
.714 .12926 Mdot
.714 .12973 Mdot
.714 .12976 Mdot
.714 .13 Mdot
.714 .13039 Mdot
.714 .13056 Mdot
.714 .13124 Mdot
.714 .13127 Mdot
.714 .13194 Mdot
.714 .13194 Mdot
.714 .13308 Mdot
.714 .13318 Mdot
.714 .13402 Mdot
.714 .13422 Mdot
.714 .13439 Mdot
.714 .13456 Mdot
.714 .13469 Mdot
.714 .13478 Mdot
.714 .13574 Mdot
.714 .136 Mdot
.714 .13638 Mdot
.714 .1371 Mdot
.714 .13717 Mdot
.714 .13815 Mdot
.714 .13821 Mdot
.714 .13847 Mdot
.714 .1385 Mdot
.714 .13876 Mdot
.714 .13892 Mdot
.714 .13903 Mdot
.714 .13941 Mdot
.714 .14093 Mdot
.714 .14095 Mdot
.714 .1416 Mdot
.714 .14164 Mdot
.714 .14179 Mdot
.714 .14201 Mdot
.714 .14206 Mdot
.714 .14276 Mdot
.714 .14303 Mdot
.714 .14392 Mdot
.714 .14472 Mdot
.714 .14504 Mdot
.714 .14511 Mdot
.714 .14551 Mdot
.714 .14569 Mdot
.714 .14661 Mdot
.714 .14678 Mdot
.714 .14711 Mdot
.714 .14771 Mdot
.714 .14775 Mdot
.714 .1481 Mdot
.714 .14833 Mdot
.714 .14909 Mdot
.714 .14931 Mdot
.714 .14991 Mdot
.714 .14993 Mdot
.714 .15094 Mdot
.714 .15112 Mdot
.714 .15123 Mdot
.714 .15138 Mdot
.714 .15184 Mdot
.714 .15216 Mdot
.714 .1522 Mdot
.714 .15225 Mdot
.714 .15315 Mdot
.714 .15358 Mdot
.714 .1544 Mdot
.714 .15464 Mdot
.714 .15474 Mdot
.714 .1552 Mdot
.714 .15584 Mdot
.714 .15603 Mdot
.714 .15657 Mdot
.714 .15673 Mdot
.714 .15736 Mdot
.714 .15766 Mdot
.714 .15821 Mdot
.714 .15841 Mdot
.714 .15894 Mdot
.714 .1597 Mdot
.714 .16002 Mdot
.714 .1601 Mdot
.714 .16015 Mdot
.714 .1604 Mdot
.714 .16049 Mdot
.714 .16076 Mdot
.714 .16114 Mdot
.714 .16115 Mdot
.714 .16118 Mdot
.714 .16124 Mdot
.714 .16135 Mdot
.714 .16208 Mdot
.714 .16268 Mdot
.714 .16293 Mdot
.714 .16312 Mdot
.714 .164 Mdot
.714 .16415 Mdot
.714 .1642 Mdot
.714 .16424 Mdot
.714 .16441 Mdot
.714 .16472 Mdot
.714 .16475 Mdot
.714 .16483 Mdot
.714 .16523 Mdot
.714 .16537 Mdot
.714 .16543 Mdot
.714 .1656 Mdot
.714 .16573 Mdot
.714 .16583 Mdot
.714 .16626 Mdot
.714 .16637 Mdot
.714 .16705 Mdot
.714 .16712 Mdot
.714 .16767 Mdot
.714 .16793 Mdot
.714 .16814 Mdot
.714 .16815 Mdot
.714 .16848 Mdot
.714 .16878 Mdot
.714 .16904 Mdot
.714 .16991 Mdot
.714 .16993 Mdot
.714 .17098 Mdot
.714 .171 Mdot
.714 .17139 Mdot
.714 .17181 Mdot
.714 .17181 Mdot
.714 .1721 Mdot
.714 .17211 Mdot
.714 .17218 Mdot
.714 .17271 Mdot
.714 .17331 Mdot
.714 .17369 Mdot
.714 .17434 Mdot
.714 .17442 Mdot
.714 .17473 Mdot
.714 .17589 Mdot
.714 .17609 Mdot
.714 .17628 Mdot
.714 .17644 Mdot
.714 .17666 Mdot
.714 .17685 Mdot
.714 .17735 Mdot
.714 .17791 Mdot
.714 .17828 Mdot
.714 .17896 Mdot
.714 .179 Mdot
.714 .17934 Mdot
.714 .17934 Mdot
.714 .1799 Mdot
.714 .1801 Mdot
.714 .18014 Mdot
.714 .18112 Mdot
.714 .18115 Mdot
.714 .18211 Mdot
.714 .18212 Mdot
.714 .18234 Mdot
.714 .18303 Mdot
.714 .18374 Mdot
.714 .18388 Mdot
.714 .18509 Mdot
.714 .18537 Mdot
.714 .18561 Mdot
.714 .18566 Mdot
.714 .18585 Mdot
.714 .18603 Mdot
.714 .18617 Mdot
.714 .18689 Mdot
.714 .18753 Mdot
.714 .18791 Mdot
.714 .18845 Mdot
.714 .18916 Mdot
.714 .18948 Mdot
.714 .18958 Mdot
.714 .19098 Mdot
.714 .19107 Mdot
.714 .19143 Mdot
.714 .19147 Mdot
.714 .19185 Mdot
.714 .19208 Mdot
.714 .19223 Mdot
.714 .19223 Mdot
.714 .19278 Mdot
.714 .19495 Mdot
.714 .19498 Mdot
.714 .19536 Mdot
.714 .19591 Mdot
.714 .19596 Mdot
.714 .19618 Mdot
.714 .1965 Mdot
.714 .19656 Mdot
.714 .19756 Mdot
.714 .19794 Mdot
.714 .19922 Mdot
.714 .20036 Mdot
.714 .20081 Mdot
.714 .20091 Mdot
.714 .2015 Mdot
.714 .20174 Mdot
.714 .20306 Mdot
.714 .2033 Mdot
.714 .20378 Mdot
.714 .20463 Mdot
.714 .20469 Mdot
.714 .20518 Mdot
.714 .20552 Mdot
.714 .2066 Mdot
.714 .20691 Mdot
.714 .20777 Mdot
.714 .2078 Mdot
.714 .20924 Mdot
.714 .2095 Mdot
.714 .20966 Mdot
.714 .20987 Mdot
.714 .21053 Mdot
.714 .21098 Mdot
.714 .21105 Mdot
.714 .21112 Mdot
.714 .2124 Mdot
.714 .21301 Mdot
.714 .21418 Mdot
.714 .21453 Mdot
.714 .21467 Mdot
.714 .21533 Mdot
.714 .21625 Mdot
.714 .21651 Mdot
.714 .21728 Mdot
.714 .21752 Mdot
.714 .21842 Mdot
.714 .21884 Mdot
.714 .21962 Mdot
.714 .22067 Mdot
.714 .22175 Mdot
.714 .22221 Mdot
.714 .22232 Mdot
.714 .2224 Mdot
.714 .22275 Mdot
.714 .22288 Mdot
.714 .22327 Mdot
.714 .22381 Mdot
.714 .22382 Mdot
.714 .22386 Mdot
.714 .22396 Mdot
.714 .2241 Mdot
.714 .22516 Mdot
.714 .22601 Mdot
.714 .22636 Mdot
.714 .22664 Mdot
.714 .22789 Mdot
.714 .2281 Mdot
.714 .22817 Mdot
.714 .22824 Mdot
.714 .22847 Mdot
.714 .22892 Mdot
.714 .22896 Mdot
.714 .22908 Mdot
.714 .22965 Mdot
.714 .22985 Mdot
.714 .22994 Mdot
.714 .23018 Mdot
.714 .23036 Mdot
.714 .23051 Mdot
.714 .23112 Mdot
.714 .23127 Mdot
.714 .23225 Mdot
.714 .23235 Mdot
.714 .23313 Mdot
.714 .2335 Mdot
.714 .23381 Mdot
.714 .23381 Mdot
.714 .23429 Mdot
.714 .23471 Mdot
.714 .23509 Mdot
.714 .23633 Mdot
.714 .23637 Mdot
.714 .23786 Mdot
.714 .23789 Mdot
.714 .23844 Mdot
.714 .23904 Mdot
.714 .23904 Mdot
.714 .23946 Mdot
.714 .23947 Mdot
.714 .23957 Mdot
.714 .24034 Mdot
.714 .24119 Mdot
.714 .24172 Mdot
.714 .24266 Mdot
.714 .24277 Mdot
.714 .24322 Mdot
.714 .24487 Mdot
.714 .24516 Mdot
.714 .24543 Mdot
.714 .24566 Mdot
.714 .24597 Mdot
.714 .24624 Mdot
.714 .24696 Mdot
.714 .24776 Mdot
.714 .24829 Mdot
.714 .24926 Mdot
.714 .24932 Mdot
.714 .2498 Mdot
.714 .2498 Mdot
.714 .2506 Mdot
.714 .25088 Mdot
.714 .25094 Mdot
.714 .25234 Mdot
.714 .25239 Mdot
.714 .25376 Mdot
.714 .25377 Mdot
.714 .25409 Mdot
.714 .25507 Mdot
.714 .25608 Mdot
.714 .25628 Mdot
.714 .25801 Mdot
.714 .25841 Mdot
.714 .25875 Mdot
.714 .25882 Mdot
.714 .2591 Mdot
.714 .25936 Mdot
.714 .25955 Mdot
.714 .26058 Mdot
.714 .2615 Mdot
.714 .26203 Mdot
.714 .26281 Mdot
.714 .26383 Mdot
.714 .26428 Mdot
.714 .26443 Mdot
.714 .26642 Mdot
.714 .26655 Mdot
.714 .26707 Mdot
.714 .26713 Mdot
.714 .26766 Mdot
.714 .268 Mdot
.714 .2682 Mdot
.714 .26821 Mdot
.714 .26899 Mdot
.714 .27209 Mdot
.714 .27213 Mdot
.714 .27267 Mdot
.714 .27346 Mdot
.714 .27353 Mdot
.714 .27385 Mdot
.714 .2743 Mdot
.714 .27439 Mdot
.714 .27582 Mdot
.714 .27637 Mdot
.714 .27819 Mdot
.714 .27982 Mdot
.714 .28046 Mdot
.714 .28061 Mdot
.714 .28144 Mdot
.714 .28179 Mdot
.714 .28367 Mdot
.714 .28402 Mdot
.714 .2847 Mdot
.714 .28592 Mdot
.714 .286 Mdot
.714 .2867 Mdot
.714 .28718 Mdot
.714 .28872 Mdot
.714 .28917 Mdot
.714 .29039 Mdot
.714 .29044 Mdot
.714 .2925 Mdot
.714 .29287 Mdot
.714 .2931 Mdot
.714 .29339 Mdot
.714 .29434 Mdot
.714 .29498 Mdot
.714 .29508 Mdot
.714 .29518 Mdot
.714 .29702 Mdot
.714 .29788 Mdot
.714 .29955 Mdot
.714 .30006 Mdot
.714 .30025 Mdot
.714 .30119 Mdot
.714 .3025 Mdot
.714 .30288 Mdot
.714 .30398 Mdot
.714 .30431 Mdot
.714 .3056 Mdot
.714 .30621 Mdot
.714 .30732 Mdot
.714 .30882 Mdot
.714 .31036 Mdot
.714 .31101 Mdot
.714 .31117 Mdot
.714 .31128 Mdot
.714 .31179 Mdot
.714 .31198 Mdot
.714 .31253 Mdot
.714 .3133 Mdot
.714 .31332 Mdot
.714 .31338 Mdot
.714 .31352 Mdot
.714 .31372 Mdot
.714 .31523 Mdot
.714 .31645 Mdot
.714 .31695 Mdot
.714 .31734 Mdot
.714 .31914 Mdot
.714 .31943 Mdot
.714 .31953 Mdot
.714 .31963 Mdot
.714 .31996 Mdot
.714 .3206 Mdot
.714 .32066 Mdot
.714 .32082 Mdot
.714 .32165 Mdot
.714 .32193 Mdot
.714 .32205 Mdot
.714 .3224 Mdot
.714 .32265 Mdot
.714 .32287 Mdot
.714 .32374 Mdot
.714 .32396 Mdot
.714 .32536 Mdot
.714 .3255 Mdot
.714 .32662 Mdot
.714 .32714 Mdot
.714 .32758 Mdot
.714 .32759 Mdot
.714 .32827 Mdot
.714 .32887 Mdot
.714 .3294 Mdot
.714 .33118 Mdot
.714 .33124 Mdot
.714 .33337 Mdot
.714 .33341 Mdot
.714 .33419 Mdot
.714 .33506 Mdot
.714 .33506 Mdot
.714 .33566 Mdot
.714 .33566 Mdot
.714 .33581 Mdot
.714 .3369 Mdot
.714 .33812 Mdot
.714 .33888 Mdot
.714 .34023 Mdot
.714 .34038 Mdot
.714 .34102 Mdot
.714 .34337 Mdot
.714 .34379 Mdot
.714 .34418 Mdot
.714 .34451 Mdot
.714 .34495 Mdot
.714 .34534 Mdot
.714 .34636 Mdot
.714 .34751 Mdot
.714 .34826 Mdot
.714 .34964 Mdot
.714 .34973 Mdot
.714 .35041 Mdot
.714 .35042 Mdot
.714 .35155 Mdot
.714 .35196 Mdot
.714 .35205 Mdot
.714 .35404 Mdot
.714 .35411 Mdot
.714 .35607 Mdot
.714 .35608 Mdot
.714 .35654 Mdot
.714 .35794 Mdot
.714 .35938 Mdot
.714 .35967 Mdot
.714 .36213 Mdot
.714 .36271 Mdot
.714 .3632 Mdot
.714 .3633 Mdot
.714 .3637 Mdot
.714 .36407 Mdot
.714 .36434 Mdot
.714 .36581 Mdot
.714 .36712 Mdot
.714 .36788 Mdot
.714 .369 Mdot
.714 .37045 Mdot
.714 .3711 Mdot
.714 .37131 Mdot
.714 .37415 Mdot
.714 .37434 Mdot
.714 .37508 Mdot
.714 .37516 Mdot
.714 .37592 Mdot
.714 .3764 Mdot
.714 .37669 Mdot
.714 .3767 Mdot
.714 .37782 Mdot
.714 .38225 Mdot
.714 .3823 Mdot
.714 .38308 Mdot
.714 .38421 Mdot
.714 .38431 Mdot
.714 .38476 Mdot
.714 .3854 Mdot
.714 .38553 Mdot
.714 .38758 Mdot
.714 .38835 Mdot
.714 .39096 Mdot
.714 .39328 Mdot
.714 .3942 Mdot
.714 .39441 Mdot
.714 .3956 Mdot
.714 .3961 Mdot
.714 .39878 Mdot
.714 .39928 Mdot
.714 .40025 Mdot
.714 .40199 Mdot
.714 .40211 Mdot
.714 .40311 Mdot
.714 .4038 Mdot
.714 .406 Mdot
.714 .40664 Mdot
.714 .40839 Mdot
.714 .40845 Mdot
.714 .4114 Mdot
.714 .41192 Mdot
.714 .41224 Mdot
.714 .41267 Mdot
.714 .41401 Mdot
.714 .41494 Mdot
.714 .41507 Mdot
.714 .41522 Mdot
.714 .41784 Mdot
.714 .41908 Mdot
.714 .42146 Mdot
.714 .42218 Mdot
.714 .42245 Mdot
.714 .4238 Mdot
.714 .42568 Mdot
.714 .42621 Mdot
.714 .42778 Mdot
.714 .42826 Mdot
.714 .43011 Mdot
.714 .43097 Mdot
.714 .43256 Mdot
.714 .4347 Mdot
.714 .4369 Mdot
.716 .01579 Mdot
.716 .01625 Mdot
.716 .01635 Mdot
.716 .01691 Mdot
.716 .01706 Mdot
.716 .01786 Mdot
.716 .01807 Mdot
.716 .01851 Mdot
.716 .01922 Mdot
.716 .01952 Mdot
.716 .01997 Mdot
.716 .02015 Mdot
.716 .02117 Mdot
.716 .02159 Mdot
.716 .02224 Mdot
.716 .02242 Mdot
.716 .02249 Mdot
.716 .0227 Mdot
.716 .02294 Mdot
.716 .02349 Mdot
.716 .02369 Mdot
.716 .0238 Mdot
.716 .02395 Mdot
.716 .02403 Mdot
.716 .02435 Mdot
.716 .02457 Mdot
.716 .02549 Mdot
.716 .02575 Mdot
.716 .02585 Mdot
.716 .02615 Mdot
.716 .0265 Mdot
.716 .02729 Mdot
.716 .02756 Mdot
.716 .02772 Mdot
.716 .02794 Mdot
.716 .02805 Mdot
.716 .02842 Mdot
.716 .02852 Mdot
.716 .02882 Mdot
.716 .03015 Mdot
.716 .03045 Mdot
.716 .03052 Mdot
.716 .03066 Mdot
.716 .03088 Mdot
.716 .03101 Mdot
.716 .03109 Mdot
.716 .03159 Mdot
.716 .03206 Mdot
.716 .03212 Mdot
.716 .03227 Mdot
.716 .03272 Mdot
.716 .03288 Mdot
.716 .03303 Mdot
.716 .0331 Mdot
.716 .03311 Mdot
.716 .03334 Mdot
.716 .03349 Mdot
.716 .03366 Mdot
.716 .03382 Mdot
.716 .03384 Mdot
.716 .03433 Mdot
.716 .03448 Mdot
.716 .03492 Mdot
.716 .0355 Mdot
.716 .0355 Mdot
.716 .03581 Mdot
.716 .03681 Mdot
.716 .03699 Mdot
.716 .03725 Mdot
.716 .03735 Mdot
.716 .03753 Mdot
.716 .03755 Mdot
.716 .03786 Mdot
.716 .03804 Mdot
.716 .03817 Mdot
.716 .03887 Mdot
.716 .03917 Mdot
.716 .03955 Mdot
.716 .03964 Mdot
.716 .03964 Mdot
.716 .03985 Mdot
.716 .04042 Mdot
.716 .0405 Mdot
.716 .04073 Mdot
.716 .04088 Mdot
.716 .04094 Mdot
.716 .04104 Mdot
.716 .04106 Mdot
.716 .04139 Mdot
.716 .0416 Mdot
.716 .04184 Mdot
.716 .04207 Mdot
.716 .0421 Mdot
.716 .04221 Mdot
.716 .04226 Mdot
.716 .04281 Mdot
.716 .04302 Mdot
.716 .04364 Mdot
.716 .04421 Mdot
.716 .04447 Mdot
.716 .04448 Mdot
.716 .04492 Mdot
.716 .04573 Mdot
.716 .04579 Mdot
.716 .04584 Mdot
.716 .04585 Mdot
.716 .04636 Mdot
.716 .04662 Mdot
.716 .04696 Mdot
.716 .04699 Mdot
.716 .04713 Mdot
.716 .04718 Mdot
.716 .04738 Mdot
.716 .04741 Mdot
.716 .04741 Mdot
.716 .04786 Mdot
.716 .04812 Mdot
.716 .0483 Mdot
.716 .0484 Mdot
.716 .04843 Mdot
.716 .04931 Mdot
.716 .04974 Mdot
.716 .05028 Mdot
.716 .05041 Mdot
.716 .05041 Mdot
.716 .05071 Mdot
.716 .05124 Mdot
.716 .05153 Mdot
.716 .05163 Mdot
.716 .05174 Mdot
.716 .05196 Mdot
.716 .05218 Mdot
.716 .05227 Mdot
.716 .05242 Mdot
.716 .05244 Mdot
.716 .05291 Mdot
.716 .05322 Mdot
.716 .05356 Mdot
.716 .05388 Mdot
.716 .05388 Mdot
.716 .05393 Mdot
.716 .05395 Mdot
.716 .05409 Mdot
.716 .05416 Mdot
.716 .05494 Mdot
.716 .05495 Mdot
.716 .05505 Mdot
.716 .05525 Mdot
.716 .05573 Mdot
.716 .05614 Mdot
.716 .05688 Mdot
.716 .05689 Mdot
.716 .05695 Mdot
.716 .05697 Mdot
.716 .05711 Mdot
.716 .05712 Mdot
.716 .05733 Mdot
.716 .05735 Mdot
.716 .05797 Mdot
.716 .05827 Mdot
.716 .05847 Mdot
.716 .05905 Mdot
.716 .05912 Mdot
.716 .05921 Mdot
.716 .05929 Mdot
.716 .0593 Mdot
.716 .06003 Mdot
.716 .0604 Mdot
.716 .06089 Mdot
.716 .06093 Mdot
.716 .06113 Mdot
.716 .06121 Mdot
.716 .0615 Mdot
.716 .06154 Mdot
.716 .06154 Mdot
.716 .06218 Mdot
.716 .06255 Mdot
.716 .06281 Mdot
.716 .06296 Mdot
.716 .06298 Mdot
.716 .06299 Mdot
.716 .06426 Mdot
.716 .06487 Mdot
.716 .06564 Mdot
.716 .06583 Mdot
.716 .06584 Mdot
.716 .06595 Mdot
.716 .06626 Mdot
.716 .0664 Mdot
.716 .06671 Mdot
.716 .0668 Mdot
.716 .06701 Mdot
.716 .06743 Mdot
.716 .06758 Mdot
.716 .06773 Mdot
.716 .06805 Mdot
.716 .06837 Mdot
.716 .0685 Mdot
.716 .06871 Mdot
.716 .06874 Mdot
.716 .06889 Mdot
.716 .06896 Mdot
.716 .06941 Mdot
.716 .06985 Mdot
.716 .07034 Mdot
.716 .07079 Mdot
.716 .07081 Mdot
.716 .07087 Mdot
.716 .0709 Mdot
.716 .07097 Mdot
.716 .0711 Mdot
.716 .07121 Mdot
.716 .07232 Mdot
.716 .07233 Mdot
.716 .07241 Mdot
.716 .07248 Mdot
.716 .07262 Mdot
.716 .07276 Mdot
.716 .07345 Mdot
.716 .07404 Mdot
.716 .07486 Mdot
.716 .07496 Mdot
.716 .07509 Mdot
.716 .07511 Mdot
.716 .07519 Mdot
.716 .07522 Mdot
.716 .07542 Mdot
.716 .07544 Mdot
.716 .07554 Mdot
.716 .07574 Mdot
.716 .07575 Mdot
.716 .07576 Mdot
.716 .07638 Mdot
.716 .07666 Mdot
.716 .07709 Mdot
.716 .07737 Mdot
.716 .07753 Mdot
.716 .0782 Mdot
.716 .07831 Mdot
.716 .07843 Mdot
.716 .07855 Mdot
.716 .07856 Mdot
.716 .0796 Mdot
.716 .07996 Mdot
.716 .08013 Mdot
.716 .08084 Mdot
.716 .08089 Mdot
.716 .08118 Mdot
.716 .0813 Mdot
.716 .0817 Mdot
.716 .08176 Mdot
.716 .08177 Mdot
.716 .08177 Mdot
.716 .08209 Mdot
.716 .08256 Mdot
.716 .08268 Mdot
.716 .08282 Mdot
.716 .08322 Mdot
.716 .08358 Mdot
.716 .0838 Mdot
.716 .08382 Mdot
.716 .08385 Mdot
.716 .08521 Mdot
.716 .08566 Mdot
.716 .08636 Mdot
.716 .08654 Mdot
.716 .08764 Mdot
.716 .08791 Mdot
.716 .08792 Mdot
.716 .08795 Mdot
.716 .08805 Mdot
.716 .08807 Mdot
.716 .08808 Mdot
.716 .08815 Mdot
.716 .08848 Mdot
.716 .08853 Mdot
.716 .08873 Mdot
.716 .08882 Mdot
.716 .08917 Mdot
.716 .0893 Mdot
.716 .08938 Mdot
.716 .08961 Mdot
.716 .0902 Mdot
.716 .09042 Mdot
.716 .09063 Mdot
.716 .09063 Mdot
.716 .0911 Mdot
.716 .09118 Mdot
.716 .09155 Mdot
.716 .09171 Mdot
.716 .09173 Mdot
.716 .09184 Mdot
.716 .09203 Mdot
.716 .09207 Mdot
.716 .09207 Mdot
.716 .0923 Mdot
.716 .09239 Mdot
.716 .09305 Mdot
.716 .09367 Mdot
.716 .09437 Mdot
.716 .09502 Mdot
.716 .09504 Mdot
.716 .09513 Mdot
.716 .09517 Mdot
.716 .09527 Mdot
.716 .09546 Mdot
.716 .09622 Mdot
.716 .09719 Mdot
.716 .09721 Mdot
.716 .09721 Mdot
.716 .09734 Mdot
.716 .09743 Mdot
.716 .09764 Mdot
.716 .09773 Mdot
.716 .09784 Mdot
.716 .09788 Mdot
.716 .09857 Mdot
.716 .09882 Mdot
.716 .09967 Mdot
.716 .10084 Mdot
.716 .10099 Mdot
.716 .10117 Mdot
.716 .10119 Mdot
.716 .10131 Mdot
.716 .10136 Mdot
.716 .10165 Mdot
.716 .10168 Mdot
.716 .10182 Mdot
.716 .1021 Mdot
.716 .10212 Mdot
.716 .10213 Mdot
.716 .10284 Mdot
.716 .10303 Mdot
.716 .10342 Mdot
.716 .10404 Mdot
.716 .10444 Mdot
.716 .10465 Mdot
.716 .10467 Mdot
.716 .10562 Mdot
.716 .10578 Mdot
.716 .10596 Mdot
.716 .10613 Mdot
.716 .10614 Mdot
.716 .10763 Mdot
.716 .10814 Mdot
.716 .10839 Mdot
.716 .10941 Mdot
.716 .10948 Mdot
.716 .10989 Mdot
.716 .1099 Mdot
.716 .11006 Mdot
.716 .11064 Mdot
.716 .11073 Mdot
.716 .11073 Mdot
.716 .11074 Mdot
.716 .11083 Mdot
.716 .11119 Mdot
.716 .11187 Mdot
.716 .11192 Mdot
.716 .11204 Mdot
.716 .11204 Mdot
.716 .11224 Mdot
.716 .11267 Mdot
.716 .11277 Mdot
.716 .11281 Mdot
.716 .11303 Mdot
.716 .11333 Mdot
.716 .11364 Mdot
.716 .11368 Mdot
.716 .11372 Mdot
.716 .11478 Mdot
.716 .11495 Mdot
.716 .11566 Mdot
.716 .1158 Mdot
.716 .11631 Mdot
.716 .11666 Mdot
.716 .11731 Mdot
.716 .11736 Mdot
.716 .11749 Mdot
.716 .11757 Mdot
.716 .11762 Mdot
.716 .1177 Mdot
.716 .11915 Mdot
.716 .11953 Mdot
.716 .11955 Mdot
.716 .11958 Mdot
.716 .11973 Mdot
.716 .11976 Mdot
.716 .11978 Mdot
.716 .11987 Mdot
.716 .12035 Mdot
.716 .12035 Mdot
.716 .12042 Mdot
.716 .1207 Mdot
.716 .12083 Mdot
.716 .12122 Mdot
.716 .12134 Mdot
.716 .12152 Mdot
.716 .12163 Mdot
.716 .12195 Mdot
.716 .12196 Mdot
.716 .12281 Mdot
.716 .12308 Mdot
.716 .12313 Mdot
.716 .12342 Mdot
.716 .12342 Mdot
.716 .12409 Mdot
.716 .12421 Mdot
.716 .12474 Mdot
.716 .12497 Mdot
.716 .125 Mdot
.716 .12516 Mdot
.716 .12543 Mdot
.716 .12544 Mdot
.716 .12545 Mdot
.716 .12549 Mdot
.716 .12549 Mdot
.716 .12577 Mdot
.716 .12581 Mdot
.716 .12595 Mdot
.716 .12688 Mdot
.716 .12777 Mdot
.716 .12878 Mdot
.716 .12918 Mdot
.716 .12971 Mdot
.716 .12973 Mdot
.716 .12987 Mdot
.716 .12992 Mdot
.716 .13007 Mdot
.716 .13034 Mdot
.716 .13143 Mdot
.716 .1316 Mdot
.716 .13282 Mdot
.716 .13285 Mdot
.716 .13285 Mdot
.716 .13287 Mdot
.716 .13295 Mdot
.716 .13303 Mdot
.716 .13316 Mdot
.716 .13346 Mdot
.716 .13359 Mdot
.716 .13375 Mdot
.716 .1338 Mdot
.716 .13479 Mdot
.716 .13515 Mdot
.716 .13636 Mdot
.716 .13804 Mdot
.716 .13826 Mdot
.716 .13852 Mdot
.716 .13855 Mdot
.716 .1387 Mdot
.716 .13872 Mdot
.716 .13879 Mdot
.716 .1392 Mdot
.716 .13924 Mdot
.716 .13944 Mdot
.716 .13965 Mdot
.716 .13985 Mdot
.716 .13988 Mdot
.716 .1399 Mdot
.716 .14074 Mdot
.716 .14091 Mdot
.716 .14118 Mdot
.716 .14174 Mdot
.716 .14174 Mdot
.716 .14182 Mdot
.716 .14263 Mdot
.716 .1432 Mdot
.716 .14351 Mdot
.716 .14352 Mdot
.716 .14489 Mdot
.716 .14512 Mdot
.716 .14538 Mdot
.716 .14562 Mdot
.716 .14563 Mdot
.716 .14777 Mdot
.716 .1485 Mdot
.716 .14886 Mdot
.716 .15032 Mdot
.716 .15042 Mdot
.716 .15081 Mdot
.716 .15101 Mdot
.716 .15102 Mdot
.716 .15125 Mdot
.716 .15209 Mdot
.716 .15221 Mdot
.716 .15221 Mdot
.716 .15222 Mdot
.716 .15234 Mdot
.716 .15287 Mdot
.716 .15385 Mdot
.716 .15388 Mdot
.716 .15391 Mdot
.716 .15408 Mdot
.716 .15409 Mdot
.716 .15437 Mdot
.716 .15498 Mdot
.716 .15513 Mdot
.716 .15519 Mdot
.716 .15541 Mdot
.716 .1555 Mdot
.716 .15593 Mdot
.716 .15638 Mdot
.716 .15643 Mdot
.716 .15649 Mdot
.716 .15801 Mdot
.716 .15825 Mdot
.716 .15927 Mdot
.716 .15946 Mdot
.716 .1602 Mdot
.716 .1607 Mdot
.716 .16153 Mdot
.716 .16163 Mdot
.716 .16171 Mdot
.716 .1619 Mdot
.716 .16196 Mdot
.716 .162 Mdot
.716 .16208 Mdot
.716 .16219 Mdot
.716 .16357 Mdot
.716 .16427 Mdot
.716 .16441 Mdot
.716 .16445 Mdot
.716 .16481 Mdot
.716 .16483 Mdot
.716 .16488 Mdot
.716 .16509 Mdot
.716 .16514 Mdot
.716 .16517 Mdot
.716 .1653 Mdot
.716 .16542 Mdot
.716 .16598 Mdot
.716 .16599 Mdot
.716 .16609 Mdot
.716 .16649 Mdot
.716 .16667 Mdot
.716 .16724 Mdot
.716 .1674 Mdot
.716 .16766 Mdot
.716 .16782 Mdot
.716 .16827 Mdot
.716 .16829 Mdot
.716 .16895 Mdot
.716 .16947 Mdot
.716 .16949 Mdot
.716 .16951 Mdot
.716 .16951 Mdot
.716 .16989 Mdot
.716 .16996 Mdot
.716 .17004 Mdot
.716 .17038 Mdot
.716 .17039 Mdot
.716 .17134 Mdot
.716 .17151 Mdot
.716 .17224 Mdot
.716 .17227 Mdot
.716 .17261 Mdot
.716 .17264 Mdot
.716 .17287 Mdot
.716 .17326 Mdot
.716 .17327 Mdot
.716 .17329 Mdot
.716 .17334 Mdot
.716 .17335 Mdot
.716 .17374 Mdot
.716 .17381 Mdot
.716 .174 Mdot
.716 .17534 Mdot
.716 .17635 Mdot
.716 .17651 Mdot
.716 .17661 Mdot
.716 .17664 Mdot
.716 .17736 Mdot
.716 .17738 Mdot
.716 .17806 Mdot
.716 .17855 Mdot
.716 .17863 Mdot
.716 .17939 Mdot
.716 .17942 Mdot
.716 .17962 Mdot
.716 .17969 Mdot
.716 .17991 Mdot
.716 .1803 Mdot
.716 .18112 Mdot
.716 .18174 Mdot
.716 .18185 Mdot
.716 .18201 Mdot
.716 .1821 Mdot
.716 .18291 Mdot
.716 .1833 Mdot
.716 .18384 Mdot
.716 .18388 Mdot
.716 .18389 Mdot
.716 .18391 Mdot
.716 .18403 Mdot
.716 .18414 Mdot
.716 .18433 Mdot
.716 .18476 Mdot
.716 .18494 Mdot
.716 .18513 Mdot
.716 .18517 Mdot
.716 .18525 Mdot
.716 .18666 Mdot
.716 .18699 Mdot
.716 .18718 Mdot
.716 .18723 Mdot
.716 .18746 Mdot
.716 .18892 Mdot
.716 .19132 Mdot
.716 .19164 Mdot
.716 .19201 Mdot
.716 .19205 Mdot
.716 .19226 Mdot
.716 .1923 Mdot
.716 .19239 Mdot
.716 .19298 Mdot
.716 .19304 Mdot
.716 .19333 Mdot
.716 .19362 Mdot
.716 .19386 Mdot
.716 .19391 Mdot
.716 .19395 Mdot
.716 .19398 Mdot
.716 .19488 Mdot
.716 .19518 Mdot
.716 .19542 Mdot
.716 .19581 Mdot
.716 .19661 Mdot
.716 .19662 Mdot
.716 .19672 Mdot
.716 .19789 Mdot
.716 .19871 Mdot
.716 .19914 Mdot
.716 .19917 Mdot
.716 .20113 Mdot
.716 .20145 Mdot
.716 .20182 Mdot
.716 .20216 Mdot
.716 .20219 Mdot
.716 .20525 Mdot
.716 .2063 Mdot
.716 .20682 Mdot
.716 .2089 Mdot
.716 .20905 Mdot
.716 .2096 Mdot
.716 .20988 Mdot
.716 .2099 Mdot
.716 .21023 Mdot
.716 .21143 Mdot
.716 .21161 Mdot
.716 .21161 Mdot
.716 .21162 Mdot
.716 .2118 Mdot
.716 .21255 Mdot
.716 .21395 Mdot
.716 .214 Mdot
.716 .21405 Mdot
.716 .21429 Mdot
.716 .2143 Mdot
.716 .2147 Mdot
.716 .21557 Mdot
.716 .21578 Mdot
.716 .21588 Mdot
.716 .21618 Mdot
.716 .21632 Mdot
.716 .21694 Mdot
.716 .21757 Mdot
.716 .21765 Mdot
.716 .21773 Mdot
.716 .21991 Mdot
.716 .22026 Mdot
.716 .22172 Mdot
.716 .22199 Mdot
.716 .22305 Mdot
.716 .22376 Mdot
.716 .22495 Mdot
.716 .22509 Mdot
.716 .22521 Mdot
.716 .22548 Mdot
.716 .22557 Mdot
.716 .22563 Mdot
.716 .22574 Mdot
.716 .2259 Mdot
.716 .22788 Mdot
.716 .22887 Mdot
.716 .22908 Mdot
.716 .22914 Mdot
.716 .22965 Mdot
.716 .22968 Mdot
.716 .22976 Mdot
.716 .23005 Mdot
.716 .23013 Mdot
.716 .23016 Mdot
.716 .23035 Mdot
.716 .23052 Mdot
.716 .23133 Mdot
.716 .23133 Mdot
.716 .23148 Mdot
.716 .23206 Mdot
.716 .23232 Mdot
.716 .23312 Mdot
.716 .23335 Mdot
.716 .23373 Mdot
.716 .23396 Mdot
.716 .23461 Mdot
.716 .23463 Mdot
.716 .23558 Mdot
.716 .23632 Mdot
.716 .23635 Mdot
.716 .23638 Mdot
.716 .23638 Mdot
.716 .23692 Mdot
.716 .23703 Mdot
.716 .23714 Mdot
.716 .23762 Mdot
.716 .23764 Mdot
.716 .23901 Mdot
.716 .23925 Mdot
.716 .24029 Mdot
.716 .24033 Mdot
.716 .24081 Mdot
.716 .24087 Mdot
.716 .2412 Mdot
.716 .24176 Mdot
.716 .24176 Mdot
.716 .2418 Mdot
.716 .24187 Mdot
.716 .24188 Mdot
.716 .24244 Mdot
.716 .24253 Mdot
.716 .24281 Mdot
.716 .24473 Mdot
.716 .24618 Mdot
.716 .2464 Mdot
.716 .24655 Mdot
.716 .2466 Mdot
.716 .24762 Mdot
.716 .24765 Mdot
.716 .24863 Mdot
.716 .24933 Mdot
.716 .24943 Mdot
.716 .25052 Mdot
.716 .25058 Mdot
.716 .25086 Mdot
.716 .25096 Mdot
.716 .25127 Mdot
.716 .25183 Mdot
.716 .25301 Mdot
.716 .25389 Mdot
.716 .25405 Mdot
.716 .25428 Mdot
.716 .25441 Mdot
.716 .25557 Mdot
.716 .25613 Mdot
.716 .25691 Mdot
.716 .25696 Mdot
.716 .25697 Mdot
.716 .25701 Mdot
.716 .25717 Mdot
.716 .25733 Mdot
.716 .2576 Mdot
.716 .25821 Mdot
.716 .25848 Mdot
.716 .25874 Mdot
.716 .25881 Mdot
.716 .25892 Mdot
.716 .26094 Mdot
.716 .26142 Mdot
.716 .26168 Mdot
.716 .26175 Mdot
.716 .26209 Mdot
.716 .26417 Mdot
.716 .26505 Mdot
.716 .26761 Mdot
.716 .26807 Mdot
.716 .2686 Mdot
.716 .26866 Mdot
.716 .26896 Mdot
.716 .26901 Mdot
.716 .26914 Mdot
.716 .26999 Mdot
.716 .27008 Mdot
.716 .27049 Mdot
.716 .27091 Mdot
.716 .27125 Mdot
.716 .27132 Mdot
.716 .27138 Mdot
.716 .27142 Mdot
.716 .27271 Mdot
.716 .27314 Mdot
.716 .27349 Mdot
.716 .27404 Mdot
.716 .27519 Mdot
.716 .2752 Mdot
.716 .27535 Mdot
.716 .27701 Mdot
.716 .2782 Mdot
.716 .27882 Mdot
.716 .27885 Mdot
.716 .28166 Mdot
.716 .28212 Mdot
.716 .28265 Mdot
.716 .28314 Mdot
.716 .28318 Mdot
.716 .28756 Mdot
.716 .28906 Mdot
.716 .2898 Mdot
.716 .29279 Mdot
.716 .293 Mdot
.716 .29379 Mdot
.716 .2942 Mdot
.716 .29422 Mdot
.716 .29469 Mdot
.716 .29641 Mdot
.716 .29666 Mdot
.716 .29667 Mdot
.716 .29668 Mdot
.716 .29694 Mdot
.716 .29802 Mdot
.716 .30002 Mdot
.716 .3001 Mdot
.716 .30016 Mdot
.716 .30051 Mdot
.716 .30052 Mdot
.716 .30109 Mdot
.716 .30235 Mdot
.716 .30265 Mdot
.716 .30278 Mdot
.716 .30322 Mdot
.716 .30341 Mdot
.716 .3043 Mdot
.716 .30521 Mdot
.716 .30532 Mdot
.716 .30544 Mdot
.716 .30856 Mdot
.716 .30905 Mdot
.716 .31114 Mdot
.716 .31154 Mdot
.716 .31304 Mdot
.716 .31407 Mdot
.716 .31578 Mdot
.716 .31597 Mdot
.716 .31614 Mdot
.716 .31653 Mdot
.716 .31666 Mdot
.716 .31674 Mdot
.716 .3169 Mdot
.716 .31713 Mdot
.716 .31996 Mdot
.716 .32139 Mdot
.716 .32168 Mdot
.716 .32177 Mdot
.716 .32251 Mdot
.716 .32255 Mdot
.716 .32266 Mdot
.716 .32308 Mdot
.716 .32319 Mdot
.716 .32324 Mdot
.716 .32351 Mdot
.716 .32375 Mdot
.716 .32491 Mdot
.716 .32491 Mdot
.716 .32513 Mdot
.716 .32595 Mdot
.716 .32633 Mdot
.716 .32748 Mdot
.716 .32781 Mdot
.716 .32835 Mdot
.716 .32867 Mdot
.716 .3296 Mdot
.716 .32963 Mdot
.716 .33099 Mdot
.716 .33205 Mdot
.716 .33209 Mdot
.716 .33213 Mdot
.716 .33214 Mdot
.716 .33292 Mdot
.716 .33307 Mdot
.716 .33323 Mdot
.716 .33392 Mdot
.716 .33394 Mdot
.716 .3359 Mdot
.716 .33625 Mdot
.716 .33774 Mdot
.716 .33779 Mdot
.716 .33849 Mdot
.716 .33856 Mdot
.716 .33904 Mdot
.716 .33984 Mdot
.716 .33985 Mdot
.716 .3399 Mdot
.716 .34 Mdot
.716 .34001 Mdot
.716 .34081 Mdot
.716 .34095 Mdot
.716 .34135 Mdot
.716 .3441 Mdot
.716 .34618 Mdot
.716 .34649 Mdot
.716 .3467 Mdot
.716 .34677 Mdot
.716 .34823 Mdot
.716 .34828 Mdot
.716 .34968 Mdot
.716 .35069 Mdot
.716 .35083 Mdot
.716 .35239 Mdot
.716 .35247 Mdot
.716 .35287 Mdot
.716 .35302 Mdot
.716 .35346 Mdot
.716 .35426 Mdot
.716 .35596 Mdot
.716 .35722 Mdot
.716 .35744 Mdot
.716 .35778 Mdot
.716 .35795 Mdot
.716 .35962 Mdot
.716 .36043 Mdot
.716 .36153 Mdot
.716 .36161 Mdot
.716 .36162 Mdot
.716 .36168 Mdot
.716 .36191 Mdot
.716 .36214 Mdot
.716 .36253 Mdot
.716 .36341 Mdot
.716 .36379 Mdot
.716 .36416 Mdot
.716 .36426 Mdot
.716 .36442 Mdot
.716 .36731 Mdot
.716 .36799 Mdot
.716 .36837 Mdot
.716 .36847 Mdot
.716 .36895 Mdot
.716 .37193 Mdot
.716 .3732 Mdot
.716 .37686 Mdot
.716 .37751 Mdot
.716 .37828 Mdot
.716 .37836 Mdot
.716 .3788 Mdot
.716 .37887 Mdot
.716 .37905 Mdot
.716 .38027 Mdot
.716 .38039 Mdot
.716 .38098 Mdot
.716 .38158 Mdot
.716 .38208 Mdot
.716 .38217 Mdot
.716 .38226 Mdot
.716 .38231 Mdot
.716 .38416 Mdot
.716 .38477 Mdot
.716 .38528 Mdot
.716 .38607 Mdot
.716 .38772 Mdot
.716 .38773 Mdot
.716 .38795 Mdot
.716 .39033 Mdot
.716 .39202 Mdot
.716 .39291 Mdot
.716 .39296 Mdot
.716 .39698 Mdot
.716 .39764 Mdot
.716 .3984 Mdot
.716 .3991 Mdot
.716 .39915 Mdot
.716 .40543 Mdot
.716 .40758 Mdot
.716 .40864 Mdot
.716 .41292 Mdot
.716 .41322 Mdot
.716 .41435 Mdot
.716 .41493 Mdot
.716 .41496 Mdot
.716 .41564 Mdot
.716 .4181 Mdot
.716 .41846 Mdot
.716 .41848 Mdot
.716 .41849 Mdot
.716 .41886 Mdot
.716 .4204 Mdot
.716 .42327 Mdot
.716 .42338 Mdot
.716 .42347 Mdot
.716 .42397 Mdot
.716 .42399 Mdot
.716 .42481 Mdot
.716 .4266 Mdot
.716 .42703 Mdot
.716 .42722 Mdot
.716 .42785 Mdot
.716 .42813 Mdot
.716 .4294 Mdot
.716 .4307 Mdot
.716 .43086 Mdot
.716 .43103 Mdot
.716 .4355 Mdot
.716 .43621 Mdot
.718 .01506 Mdot
.718 .01521 Mdot
.718 .01543 Mdot
.718 .01574 Mdot
.718 .01619 Mdot
.718 .01683 Mdot
.718 .01776 Mdot
.718 .01808 Mdot
.718 .01829 Mdot
.718 .01859 Mdot
.718 .01879 Mdot
.718 .01884 Mdot
.718 .01908 Mdot
.718 .01955 Mdot
.718 .01985 Mdot
.718 .01995 Mdot
.718 .01998 Mdot
.718 .02028 Mdot
.718 .02029 Mdot
.718 .02057 Mdot
.718 .02063 Mdot
.718 .02098 Mdot
.718 .0215 Mdot
.718 .02164 Mdot
.718 .02166 Mdot
.718 .02209 Mdot
.718 .0221 Mdot
.718 .0221 Mdot
.718 .02223 Mdot
.718 .02227 Mdot
.718 .02257 Mdot
.718 .02271 Mdot
.718 .02272 Mdot
.718 .02312 Mdot
.718 .02321 Mdot
.718 .02372 Mdot
.718 .02393 Mdot
.718 .0241 Mdot
.718 .02445 Mdot
.718 .02465 Mdot
.718 .02468 Mdot
.718 .0253 Mdot
.718 .02531 Mdot
.718 .02533 Mdot
.718 .02551 Mdot
.718 .02556 Mdot
.718 .026 Mdot
.718 .02619 Mdot
.718 .02621 Mdot
.718 .02679 Mdot
.718 .02692 Mdot
.718 .02764 Mdot
.718 .02795 Mdot
.718 .02808 Mdot
.718 .0282 Mdot
.718 .0287 Mdot
.718 .02899 Mdot
.718 .02903 Mdot
.718 .02992 Mdot
.718 .02994 Mdot
.718 .02995 Mdot
.718 .02999 Mdot
.718 .03021 Mdot
.718 .03029 Mdot
.718 .0307 Mdot
.718 .03092 Mdot
.718 .0312 Mdot
.718 .03122 Mdot
.718 .03127 Mdot
.718 .03206 Mdot
.718 .03224 Mdot
.718 .03328 Mdot
.718 .03372 Mdot
.718 .03391 Mdot
.718 .03408 Mdot
.718 .0348 Mdot
.718 .03521 Mdot
.718 .03527 Mdot
.718 .0364 Mdot
.718 .03655 Mdot
.718 .03657 Mdot
.718 .03659 Mdot
.718 .03664 Mdot
.718 .03697 Mdot
.718 .03709 Mdot
.718 .03768 Mdot
.718 .03798 Mdot
.718 .03838 Mdot
.718 .03841 Mdot
.718 .03849 Mdot
.718 .03962 Mdot
.718 .03988 Mdot
.718 .04035 Mdot
.718 .04082 Mdot
.718 .04137 Mdot
.718 .042 Mdot
.718 .04228 Mdot
.718 .04252 Mdot
.718 .04313 Mdot
.718 .04355 Mdot
.718 .04384 Mdot
.718 .04415 Mdot
.718 .04424 Mdot
.718 .04429 Mdot
.718 .04474 Mdot
.718 .04511 Mdot
.718 .04512 Mdot
.718 .04585 Mdot
.718 .04607 Mdot
.718 .0461 Mdot
.718 .04613 Mdot
.718 .0462 Mdot
.718 .04627 Mdot
.718 .04644 Mdot
.718 .04667 Mdot
.718 .04684 Mdot
.718 .04688 Mdot
.718 .04765 Mdot
.718 .04769 Mdot
.718 .04787 Mdot
.718 .04802 Mdot
.718 .04812 Mdot
.718 .0487 Mdot
.718 .04872 Mdot
.718 .04874 Mdot
.718 .04885 Mdot
.718 .04902 Mdot
.718 .05047 Mdot
.718 .05082 Mdot
.718 .05085 Mdot
.718 .05094 Mdot
.718 .05099 Mdot
.718 .05153 Mdot
.718 .05193 Mdot
.718 .0522 Mdot
.718 .05279 Mdot
.718 .053 Mdot
.718 .05371 Mdot
.718 .0539 Mdot
.718 .0543 Mdot
.718 .05443 Mdot
.718 .05464 Mdot
.718 .05484 Mdot
.718 .05552 Mdot
.718 .05573 Mdot
.718 .05613 Mdot
.718 .0565 Mdot
.718 .05654 Mdot
.718 .05698 Mdot
.718 .05711 Mdot
.718 .05718 Mdot
.718 .05783 Mdot
.718 .05836 Mdot
.718 .05838 Mdot
.718 .05846 Mdot
.718 .0587 Mdot
.718 .05943 Mdot
.718 .05974 Mdot
.718 .05979 Mdot
.718 .05983 Mdot
.718 .05993 Mdot
.718 .06003 Mdot
.718 .06027 Mdot
.718 .06041 Mdot
.718 .0606 Mdot
.718 .06084 Mdot
.718 .0609 Mdot
.718 .06169 Mdot
.718 .062 Mdot
.718 .06206 Mdot
.718 .06213 Mdot
.718 .06233 Mdot
.718 .06253 Mdot
.718 .06269 Mdot
.718 .06352 Mdot
.718 .06355 Mdot
.718 .06358 Mdot
.718 .06374 Mdot
.718 .06398 Mdot
.718 .06606 Mdot
.718 .06656 Mdot
.718 .0666 Mdot
.718 .06674 Mdot
.718 .06676 Mdot
.718 .06681 Mdot
.718 .06705 Mdot
.718 .06758 Mdot
.718 .06815 Mdot
.718 .06835 Mdot
.718 .06855 Mdot
.718 .06939 Mdot
.718 .06954 Mdot
.718 .06969 Mdot
.718 .06986 Mdot
.718 .07071 Mdot
.718 .07083 Mdot
.718 .07098 Mdot
.718 .07156 Mdot
.718 .07174 Mdot
.718 .07174 Mdot
.718 .07205 Mdot
.718 .07213 Mdot
.718 .07233 Mdot
.718 .07331 Mdot
.718 .07361 Mdot
.718 .07366 Mdot
.718 .07418 Mdot
.718 .07472 Mdot
.718 .07477 Mdot
.718 .07541 Mdot
.718 .07559 Mdot
.718 .0757 Mdot
.718 .07622 Mdot
.718 .07663 Mdot
.718 .07687 Mdot
.718 .07697 Mdot
.718 .0774 Mdot
.718 .07741 Mdot
.718 .07753 Mdot
.718 .07788 Mdot
.718 .07793 Mdot
.718 .07843 Mdot
.718 .07893 Mdot
.718 .07938 Mdot
.718 .07944 Mdot
.718 .0795 Mdot
.718 .07965 Mdot
.718 .07979 Mdot
.718 .08013 Mdot
.718 .08033 Mdot
.718 .08061 Mdot
.718 .08096 Mdot
.718 .08104 Mdot
.718 .0811 Mdot
.718 .08215 Mdot
.718 .08217 Mdot
.718 .0824 Mdot
.718 .08262 Mdot
.718 .08271 Mdot
.718 .08281 Mdot
.718 .08309 Mdot
.718 .08338 Mdot
.718 .08346 Mdot
.718 .08348 Mdot
.718 .0836 Mdot
.718 .08384 Mdot
.718 .08425 Mdot
.718 .0848 Mdot
.718 .08484 Mdot
.718 .08489 Mdot
.718 .08511 Mdot
.718 .08546 Mdot
.718 .08675 Mdot
.718 .08845 Mdot
.718 .08853 Mdot
.718 .08917 Mdot
.718 .08923 Mdot
.718 .08942 Mdot
.718 .08945 Mdot
.718 .08952 Mdot
.718 .08982 Mdot
.718 .08987 Mdot
.718 .09016 Mdot
.718 .09018 Mdot
.718 .09034 Mdot
.718 .09064 Mdot
.718 .09145 Mdot
.718 .09173 Mdot
.718 .09202 Mdot
.718 .09282 Mdot
.718 .09303 Mdot
.718 .09323 Mdot
.718 .09344 Mdot
.718 .09359 Mdot
.718 .09365 Mdot
.718 .0939 Mdot
.718 .09512 Mdot
.718 .09529 Mdot
.718 .09534 Mdot
.718 .09551 Mdot
.718 .09605 Mdot
.718 .09634 Mdot
.718 .09661 Mdot
.718 .09661 Mdot
.718 .09704 Mdot
.718 .09717 Mdot
.718 .09745 Mdot
.718 .09819 Mdot
.718 .09885 Mdot
.718 .09929 Mdot
.718 .09936 Mdot
.718 .09983 Mdot
.718 .10005 Mdot
.718 .10011 Mdot
.718 .10082 Mdot
.718 .10089 Mdot
.718 .10096 Mdot
.718 .10187 Mdot
.718 .10213 Mdot
.718 .10218 Mdot
.718 .10229 Mdot
.718 .10304 Mdot
.718 .10362 Mdot
.718 .10389 Mdot
.718 .10397 Mdot
.718 .10411 Mdot
.718 .10472 Mdot
.718 .10475 Mdot
.718 .10492 Mdot
.718 .10541 Mdot
.718 .10549 Mdot
.718 .10578 Mdot
.718 .10622 Mdot
.718 .10656 Mdot
.718 .10693 Mdot
.718 .10695 Mdot
.718 .10757 Mdot
.718 .10765 Mdot
.718 .10775 Mdot
.718 .10796 Mdot
.718 .10811 Mdot
.718 .10817 Mdot
.718 .10865 Mdot
.718 .10893 Mdot
.718 .10934 Mdot
.718 .10983 Mdot
.718 .10984 Mdot
.718 .10995 Mdot
.718 .11004 Mdot
.718 .11118 Mdot
.718 .11153 Mdot
.718 .11156 Mdot
.718 .11158 Mdot
.718 .11192 Mdot
.718 .11223 Mdot
.718 .11235 Mdot
.718 .11249 Mdot
.718 .1129 Mdot
.718 .11332 Mdot
.718 .11343 Mdot
.718 .11346 Mdot
.718 .11364 Mdot
.718 .11397 Mdot
.718 .11457 Mdot
.718 .11536 Mdot
.718 .11541 Mdot
.718 .11548 Mdot
.718 .11554 Mdot
.718 .1158 Mdot
.718 .11581 Mdot
.718 .11588 Mdot
.718 .1163 Mdot
.718 .11631 Mdot
.718 .11673 Mdot
.718 .11771 Mdot
.718 .11816 Mdot
.718 .11833 Mdot
.718 .1206 Mdot
.718 .12071 Mdot
.718 .12125 Mdot
.718 .12152 Mdot
.718 .12163 Mdot
.718 .12172 Mdot
.718 .12172 Mdot
.718 .12199 Mdot
.718 .12203 Mdot
.718 .12213 Mdot
.718 .12231 Mdot
.718 .1224 Mdot
.718 .12256 Mdot
.718 .12264 Mdot
.718 .12306 Mdot
.718 .12309 Mdot
.718 .12332 Mdot
.718 .12374 Mdot
.718 .12391 Mdot
.718 .12421 Mdot
.718 .12486 Mdot
.718 .12491 Mdot
.718 .12531 Mdot
.718 .12561 Mdot
.718 .12572 Mdot
.718 .12681 Mdot
.718 .12688 Mdot
.718 .12718 Mdot
.718 .12746 Mdot
.718 .12754 Mdot
.718 .12776 Mdot
.718 .12798 Mdot
.718 .12807 Mdot
.718 .12843 Mdot
.718 .12919 Mdot
.718 .12943 Mdot
.718 .13018 Mdot
.718 .13043 Mdot
.718 .13049 Mdot
.718 .13074 Mdot
.718 .13151 Mdot
.718 .13193 Mdot
.718 .13223 Mdot
.718 .13231 Mdot
.718 .13232 Mdot
.718 .13294 Mdot
.718 .13299 Mdot
.718 .13312 Mdot
.718 .13353 Mdot
.718 .13458 Mdot
.718 .13464 Mdot
.718 .13514 Mdot
.718 .13554 Mdot
.718 .13598 Mdot
.718 .13617 Mdot
.718 .13626 Mdot
.718 .13694 Mdot
.718 .13725 Mdot
.718 .13734 Mdot
.718 .13828 Mdot
.718 .13836 Mdot
.718 .13846 Mdot
.718 .13856 Mdot
.718 .13962 Mdot
.718 .13973 Mdot
.718 .13987 Mdot
.718 .13989 Mdot
.718 .14025 Mdot
.718 .14032 Mdot
.718 .14047 Mdot
.718 .14093 Mdot
.718 .14149 Mdot
.718 .14155 Mdot
.718 .14238 Mdot
.718 .14277 Mdot
.718 .14289 Mdot
.718 .14309 Mdot
.718 .14394 Mdot
.718 .14397 Mdot
.718 .14401 Mdot
.718 .14425 Mdot
.718 .14438 Mdot
.718 .14496 Mdot
.718 .14506 Mdot
.718 .14548 Mdot
.718 .14611 Mdot
.718 .14616 Mdot
.718 .1466 Mdot
.718 .14713 Mdot
.718 .14717 Mdot
.718 .14805 Mdot
.718 .14818 Mdot
.718 .14832 Mdot
.718 .14861 Mdot
.718 .14883 Mdot
.718 .14884 Mdot
.718 .14891 Mdot
.718 .14903 Mdot
.718 .1496 Mdot
.718 .15001 Mdot
.718 .1506 Mdot
.718 .15092 Mdot
.718 .15117 Mdot
.718 .1513 Mdot
.718 .15131 Mdot
.718 .15148 Mdot
.718 .15161 Mdot
.718 .15317 Mdot
.718 .15323 Mdot
.718 .15335 Mdot
.718 .15375 Mdot
.718 .15378 Mdot
.718 .15381 Mdot
.718 .15429 Mdot
.718 .15475 Mdot
.718 .15492 Mdot
.718 .15513 Mdot
.718 .15571 Mdot
.718 .15632 Mdot
.718 .15647 Mdot
.718 .15652 Mdot
.718 .15677 Mdot
.718 .1571 Mdot
.718 .15725 Mdot
.718 .15762 Mdot
.718 .1581 Mdot
.718 .15822 Mdot
.718 .15924 Mdot
.718 .15931 Mdot
.718 .15941 Mdot
.718 .15948 Mdot
.718 .1595 Mdot
.718 .15987 Mdot
.718 .15988 Mdot
.718 .15999 Mdot
.718 .16039 Mdot
.718 .16044 Mdot
.718 .1606 Mdot
.718 .1606 Mdot
.718 .16076 Mdot
.718 .16122 Mdot
.718 .16127 Mdot
.718 .16262 Mdot
.718 .16326 Mdot
.718 .1635 Mdot
.718 .16369 Mdot
.718 .16543 Mdot
.718 .16676 Mdot
.718 .16692 Mdot
.718 .1677 Mdot
.718 .16794 Mdot
.718 .16809 Mdot
.718 .16824 Mdot
.718 .16837 Mdot
.718 .16837 Mdot
.718 .16876 Mdot
.718 .16882 Mdot
.718 .16896 Mdot
.718 .16922 Mdot
.718 .1693 Mdot
.718 .16935 Mdot
.718 .16959 Mdot
.718 .16969 Mdot
.718 .1703 Mdot
.718 .17034 Mdot
.718 .17035 Mdot
.718 .17067 Mdot
.718 .17089 Mdot
.718 .17096 Mdot
.718 .17127 Mdot
.718 .17152 Mdot
.718 .17165 Mdot
.718 .17195 Mdot
.718 .17222 Mdot
.718 .17288 Mdot
.718 .17296 Mdot
.718 .17353 Mdot
.718 .17397 Mdot
.718 .17412 Mdot
.718 .17568 Mdot
.718 .17578 Mdot
.718 .17622 Mdot
.718 .17662 Mdot
.718 .17673 Mdot
.718 .17705 Mdot
.718 .17736 Mdot
.718 .17749 Mdot
.718 .17801 Mdot
.718 .17887 Mdot
.718 .17909 Mdot
.718 .17913 Mdot
.718 .17945 Mdot
.718 .17962 Mdot
.718 .18052 Mdot
.718 .18088 Mdot
.718 .18096 Mdot
.718 .18132 Mdot
.718 .18133 Mdot
.718 .18145 Mdot
.718 .18159 Mdot
.718 .18243 Mdot
.718 .18303 Mdot
.718 .18347 Mdot
.718 .18358 Mdot
.718 .18359 Mdot
.718 .18364 Mdot
.718 .18448 Mdot
.718 .18455 Mdot
.718 .18474 Mdot
.718 .18533 Mdot
.718 .18557 Mdot
.718 .18629 Mdot
.718 .18685 Mdot
.718 .18692 Mdot
.718 .18718 Mdot
.718 .18764 Mdot
.718 .18822 Mdot
.718 .18886 Mdot
.718 .18912 Mdot
.718 .18925 Mdot
.718 .18964 Mdot
.718 .19022 Mdot
.718 .19068 Mdot
.718 .1908 Mdot
.718 .19215 Mdot
.718 .19224 Mdot
.718 .19227 Mdot
.718 .19241 Mdot
.718 .19256 Mdot
.718 .19289 Mdot
.718 .19309 Mdot
.718 .19408 Mdot
.718 .19417 Mdot
.718 .19424 Mdot
.718 .19444 Mdot
.718 .19447 Mdot
.718 .19498 Mdot
.718 .19508 Mdot
.718 .1953 Mdot
.718 .19555 Mdot
.718 .19596 Mdot
.718 .1962 Mdot
.718 .19676 Mdot
.718 .19684 Mdot
.718 .19779 Mdot
.718 .19804 Mdot
.718 .1986 Mdot
.718 .19877 Mdot
.718 .19906 Mdot
.718 .19983 Mdot
.718 .20029 Mdot
.718 .20032 Mdot
.718 .20038 Mdot
.718 .20073 Mdot
.718 .20092 Mdot
.718 .20174 Mdot
.718 .20189 Mdot
.718 .20249 Mdot
.718 .2034 Mdot
.718 .20346 Mdot
.718 .2041 Mdot
.718 .20486 Mdot
.718 .20492 Mdot
.718 .20619 Mdot
.718 .20636 Mdot
.718 .20657 Mdot
.718 .20699 Mdot
.718 .2073 Mdot
.718 .20732 Mdot
.718 .20742 Mdot
.718 .2076 Mdot
.718 .20841 Mdot
.718 .209 Mdot
.718 .20985 Mdot
.718 .21031 Mdot
.718 .21066 Mdot
.718 .21085 Mdot
.718 .21087 Mdot
.718 .2111 Mdot
.718 .21129 Mdot
.718 .21354 Mdot
.718 .21363 Mdot
.718 .21379 Mdot
.718 .21437 Mdot
.718 .21441 Mdot
.718 .21446 Mdot
.718 .21515 Mdot
.718 .2158 Mdot
.718 .21605 Mdot
.718 .21635 Mdot
.718 .21718 Mdot
.718 .21805 Mdot
.718 .21827 Mdot
.718 .21834 Mdot
.718 .21871 Mdot
.718 .21917 Mdot
.718 .21939 Mdot
.718 .21993 Mdot
.718 .22062 Mdot
.718 .22079 Mdot
.718 .22225 Mdot
.718 .22236 Mdot
.718 .2225 Mdot
.718 .2226 Mdot
.718 .22262 Mdot
.718 .22316 Mdot
.718 .22317 Mdot
.718 .22332 Mdot
.718 .22391 Mdot
.718 .22398 Mdot
.718 .2242 Mdot
.718 .2242 Mdot
.718 .22443 Mdot
.718 .22509 Mdot
.718 .22517 Mdot
.718 .2271 Mdot
.718 .22803 Mdot
.718 .22838 Mdot
.718 .22865 Mdot
.718 .23114 Mdot
.718 .23305 Mdot
.718 .23328 Mdot
.718 .2344 Mdot
.718 .23474 Mdot
.718 .23496 Mdot
.718 .23518 Mdot
.718 .23536 Mdot
.718 .23537 Mdot
.718 .23593 Mdot
.718 .236 Mdot
.718 .23622 Mdot
.718 .23659 Mdot
.718 .2367 Mdot
.718 .23677 Mdot
.718 .23711 Mdot
.718 .23726 Mdot
.718 .23813 Mdot
.718 .23819 Mdot
.718 .23821 Mdot
.718 .23867 Mdot
.718 .23909 Mdot
.718 .23953 Mdot
.718 .23988 Mdot
.718 .24008 Mdot
.718 .24051 Mdot
.718 .24089 Mdot
.718 .24183 Mdot
.718 .24195 Mdot
.718 .24278 Mdot
.718 .2434 Mdot
.718 .24362 Mdot
.718 .24586 Mdot
.718 .246 Mdot
.718 .24663 Mdot
.718 .24721 Mdot
.718 .24736 Mdot
.718 .24783 Mdot
.718 .24828 Mdot
.718 .24847 Mdot
.718 .2492 Mdot
.718 .25045 Mdot
.718 .25076 Mdot
.718 .25081 Mdot
.718 .25127 Mdot
.718 .25152 Mdot
.718 .25281 Mdot
.718 .25332 Mdot
.718 .25345 Mdot
.718 .25396 Mdot
.718 .25397 Mdot
.718 .25414 Mdot
.718 .25434 Mdot
.718 .25555 Mdot
.718 .25642 Mdot
.718 .25704 Mdot
.718 .25721 Mdot
.718 .25722 Mdot
.718 .2573 Mdot
.718 .2585 Mdot
.718 .2586 Mdot
.718 .25887 Mdot
.718 .25972 Mdot
.718 .26006 Mdot
.718 .2611 Mdot
.718 .2619 Mdot
.718 .262 Mdot
.718 .26238 Mdot
.718 .26304 Mdot
.718 .26387 Mdot
.718 .26478 Mdot
.718 .26516 Mdot
.718 .26535 Mdot
.718 .26591 Mdot
.718 .26675 Mdot
.718 .2674 Mdot
.718 .26757 Mdot
.718 .26951 Mdot
.718 .26964 Mdot
.718 .26968 Mdot
.718 .26989 Mdot
.718 .27009 Mdot
.718 .27057 Mdot
.718 .27087 Mdot
.718 .27228 Mdot
.718 .27242 Mdot
.718 .27251 Mdot
.718 .2728 Mdot
.718 .27284 Mdot
.718 .27357 Mdot
.718 .27372 Mdot
.718 .27403 Mdot
.718 .2744 Mdot
.718 .27498 Mdot
.718 .27533 Mdot
.718 .27613 Mdot
.718 .27625 Mdot
.718 .27761 Mdot
.718 .27798 Mdot
.718 .27878 Mdot
.718 .27902 Mdot
.718 .27943 Mdot
.718 .28054 Mdot
.718 .28119 Mdot
.718 .28125 Mdot
.718 .28132 Mdot
.718 .28183 Mdot
.718 .2821 Mdot
.718 .28329 Mdot
.718 .2835 Mdot
.718 .28436 Mdot
.718 .28566 Mdot
.718 .28576 Mdot
.718 .28667 Mdot
.718 .28777 Mdot
.718 .28785 Mdot
.718 .28967 Mdot
.718 .28992 Mdot
.718 .29021 Mdot
.718 .29082 Mdot
.718 .29127 Mdot
.718 .29129 Mdot
.718 .29144 Mdot
.718 .29169 Mdot
.718 .29287 Mdot
.718 .29371 Mdot
.718 .29493 Mdot
.718 .29559 Mdot
.718 .2961 Mdot
.718 .29636 Mdot
.718 .29639 Mdot
.718 .29673 Mdot
.718 .297 Mdot
.718 .30023 Mdot
.718 .30035 Mdot
.718 .30059 Mdot
.718 .30141 Mdot
.718 .30148 Mdot
.718 .30154 Mdot
.718 .30254 Mdot
.718 .30348 Mdot
.718 .30383 Mdot
.718 .30426 Mdot
.718 .30545 Mdot
.718 .30671 Mdot
.718 .30702 Mdot
.718 .30712 Mdot
.718 .30765 Mdot
.718 .30832 Mdot
.718 .30863 Mdot
.718 .3094 Mdot
.718 .31039 Mdot
.718 .31064 Mdot
.718 .31274 Mdot
.718 .31289 Mdot
.718 .3131 Mdot
.718 .31324 Mdot
.718 .31327 Mdot
.718 .31404 Mdot
.718 .31406 Mdot
.718 .31428 Mdot
.718 .31512 Mdot
.718 .31522 Mdot
.718 .31554 Mdot
.718 .31554 Mdot
.718 .31587 Mdot
.718 .31681 Mdot
.718 .31693 Mdot
.718 .3197 Mdot
.718 .32103 Mdot
.718 .32153 Mdot
.718 .32192 Mdot
.718 .3255 Mdot
.718 .32825 Mdot
.718 .32857 Mdot
.718 .33018 Mdot
.718 .33068 Mdot
.718 .33099 Mdot
.718 .3313 Mdot
.718 .33156 Mdot
.718 .33157 Mdot
.718 .33237 Mdot
.718 .33249 Mdot
.718 .33279 Mdot
.718 .33333 Mdot
.718 .33349 Mdot
.718 .33359 Mdot
.718 .33408 Mdot
.718 .33429 Mdot
.718 .33554 Mdot
.718 .33562 Mdot
.718 .33566 Mdot
.718 .33631 Mdot
.718 .33691 Mdot
.718 .33755 Mdot
.718 .33805 Mdot
.718 .33834 Mdot
.718 .33896 Mdot
.718 .3395 Mdot
.718 .34086 Mdot
.718 .34103 Mdot
.718 .34221 Mdot
.718 .34311 Mdot
.718 .34342 Mdot
.718 .34664 Mdot
.718 .34684 Mdot
.718 .34775 Mdot
.718 .34857 Mdot
.718 .3488 Mdot
.718 .34947 Mdot
.718 .35011 Mdot
.718 .35038 Mdot
.718 .35144 Mdot
.718 .35323 Mdot
.718 .35368 Mdot
.718 .35375 Mdot
.718 .35441 Mdot
.718 .35477 Mdot
.718 .35663 Mdot
.718 .35736 Mdot
.718 .35753 Mdot
.718 .35827 Mdot
.718 .35828 Mdot
.718 .35853 Mdot
.718 .35882 Mdot
.718 .36056 Mdot
.718 .3618 Mdot
.718 .3627 Mdot
.718 .36294 Mdot
.718 .36295 Mdot
.718 .36306 Mdot
.718 .36479 Mdot
.718 .36494 Mdot
.718 .36532 Mdot
.718 .36654 Mdot
.718 .36703 Mdot
.718 .36853 Mdot
.718 .36967 Mdot
.718 .36982 Mdot
.718 .37036 Mdot
.718 .37131 Mdot
.718 .3725 Mdot
.718 .37381 Mdot
.718 .37435 Mdot
.718 .37463 Mdot
.718 .37543 Mdot
.718 .37663 Mdot
.718 .37757 Mdot
.718 .37782 Mdot
.718 .38061 Mdot
.718 .38079 Mdot
.718 .38084 Mdot
.718 .38114 Mdot
.718 .38144 Mdot
.718 .38212 Mdot
.718 .38255 Mdot
.718 .38458 Mdot
.718 .38477 Mdot
.718 .38491 Mdot
.718 .38532 Mdot
.718 .38539 Mdot
.718 .38644 Mdot
.718 .38665 Mdot
.718 .3871 Mdot
.718 .38762 Mdot
.718 .38845 Mdot
.718 .38896 Mdot
.718 .39011 Mdot
.718 .39028 Mdot
.718 .39223 Mdot
.718 .39276 Mdot
.718 .39391 Mdot
.718 .39426 Mdot
.718 .39484 Mdot
.718 .39644 Mdot
.718 .39738 Mdot
.718 .39746 Mdot
.718 .39757 Mdot
.718 .39829 Mdot
.718 .39868 Mdot
.718 .40039 Mdot
.718 .40069 Mdot
.718 .40193 Mdot
.718 .4038 Mdot
.718 .40393 Mdot
.718 .40525 Mdot
.718 .40542 Mdot
.718 .40682 Mdot
.718 .40694 Mdot
.718 .40955 Mdot
.718 .40991 Mdot
.718 .41033 Mdot
.718 .41121 Mdot
.718 .41184 Mdot
.718 .41188 Mdot
.718 .4121 Mdot
.718 .41246 Mdot
.718 .41414 Mdot
.718 .41535 Mdot
.718 .4171 Mdot
.718 .41805 Mdot
.718 .41878 Mdot
.718 .41916 Mdot
.718 .4192 Mdot
.718 .41968 Mdot
.718 .42008 Mdot
.718 .42471 Mdot
.718 .42489 Mdot
.718 .42523 Mdot
.718 .42642 Mdot
.718 .4265 Mdot
.718 .4266 Mdot
.718 .42803 Mdot
.718 .42938 Mdot
.718 .42988 Mdot
.718 .4305 Mdot
.718 .43221 Mdot
.718 .43402 Mdot
.718 .43447 Mdot
.718 .43462 Mdot
.718 .43537 Mdot
.718 .43633 Mdot
.718 .43678 Mdot
.718 .43788 Mdot
.718 .43931 Mdot
.72 .01652 Mdot
.72 .01669 Mdot
.72 .01732 Mdot
.72 .01756 Mdot
.72 .01791 Mdot
.72 .0182 Mdot
.72 .01845 Mdot
.72 .01846 Mdot
.72 .01881 Mdot
.72 .01885 Mdot
.72 .01932 Mdot
.72 .01962 Mdot
.72 .01974 Mdot
.72 .01997 Mdot
.72 .0201 Mdot
.72 .02011 Mdot
.72 .02061 Mdot
.72 .02067 Mdot
.72 .02108 Mdot
.72 .02135 Mdot
.72 .02161 Mdot
.72 .02178 Mdot
.72 .02192 Mdot
.72 .02195 Mdot
.72 .02229 Mdot
.72 .02246 Mdot
.72 .02249 Mdot
.72 .02305 Mdot
.72 .0232 Mdot
.72 .02328 Mdot
.72 .02368 Mdot
.72 .02371 Mdot
.72 .02387 Mdot
.72 .02427 Mdot
.72 .02464 Mdot
.72 .02489 Mdot
.72 .02509 Mdot
.72 .02513 Mdot
.72 .02513 Mdot
.72 .02562 Mdot
.72 .02587 Mdot
.72 .0259 Mdot
.72 .02672 Mdot
.72 .0269 Mdot
.72 .02693 Mdot
.72 .02705 Mdot
.72 .02734 Mdot
.72 .02763 Mdot
.72 .02767 Mdot
.72 .0279 Mdot
.72 .0284 Mdot
.72 .02847 Mdot
.72 .02901 Mdot
.72 .02937 Mdot
.72 .02966 Mdot
.72 .02972 Mdot
.72 .02972 Mdot
.72 .02975 Mdot
.72 .0299 Mdot
.72 .03042 Mdot
.72 .03078 Mdot
.72 .03083 Mdot
.72 .032 Mdot
.72 .03226 Mdot
.72 .03231 Mdot
.72 .03248 Mdot
.72 .03254 Mdot
.72 .0329 Mdot
.72 .03331 Mdot
.72 .03336 Mdot
.72 .03337 Mdot
.72 .03371 Mdot
.72 .03442 Mdot
.72 .03452 Mdot
.72 .03476 Mdot
.72 .035 Mdot
.72 .0353 Mdot
.72 .03582 Mdot
.72 .03599 Mdot
.72 .03624 Mdot
.72 .03632 Mdot
.72 .03632 Mdot
.72 .03636 Mdot
.72 .03658 Mdot
.72 .03733 Mdot
.72 .03763 Mdot
.72 .03785 Mdot
.72 .03792 Mdot
.72 .03813 Mdot
.72 .03871 Mdot
.72 .0396 Mdot
.72 .03998 Mdot
.72 .04003 Mdot
.72 .04005 Mdot
.72 .0403 Mdot
.72 .04038 Mdot
.72 .0409 Mdot
.72 .04149 Mdot
.72 .04157 Mdot
.72 .04157 Mdot
.72 .04206 Mdot
.72 .04307 Mdot
.72 .04309 Mdot
.72 .04323 Mdot
.72 .04339 Mdot
.72 .04358 Mdot
.72 .04393 Mdot
.72 .04396 Mdot
.72 .04436 Mdot
.72 .04454 Mdot
.72 .0446 Mdot
.72 .04511 Mdot
.72 .04535 Mdot
.72 .04571 Mdot
.72 .04582 Mdot
.72 .04582 Mdot
.72 .04588 Mdot
.72 .0462 Mdot
.72 .04719 Mdot
.72 .04728 Mdot
.72 .04771 Mdot
.72 .04803 Mdot
.72 .04813 Mdot
.72 .04844 Mdot
.72 .04906 Mdot
.72 .04927 Mdot
.72 .05055 Mdot
.72 .0511 Mdot
.72 .05116 Mdot
.72 .0512 Mdot
.72 .05128 Mdot
.72 .05156 Mdot
.72 .05168 Mdot
.72 .05241 Mdot
.72 .05304 Mdot
.72 .05313 Mdot
.72 .05328 Mdot
.72 .05339 Mdot
.72 .05339 Mdot
.72 .0541 Mdot
.72 .05478 Mdot
.72 .0555 Mdot
.72 .05555 Mdot
.72 .05558 Mdot
.72 .05558 Mdot
.72 .05578 Mdot
.72 .05598 Mdot
.72 .05601 Mdot
.72 .05611 Mdot
.72 .05628 Mdot
.72 .05678 Mdot
.72 .05682 Mdot
.72 .05692 Mdot
.72 .0574 Mdot
.72 .0574 Mdot
.72 .05766 Mdot
.72 .05769 Mdot
.72 .05775 Mdot
.72 .05846 Mdot
.72 .05848 Mdot
.72 .05883 Mdot
.72 .05934 Mdot
.72 .05951 Mdot
.72 .05951 Mdot
.72 .05959 Mdot
.72 .06005 Mdot
.72 .06148 Mdot
.72 .06161 Mdot
.72 .06195 Mdot
.72 .06198 Mdot
.72 .06223 Mdot
.72 .06246 Mdot
.72 .06269 Mdot
.72 .06283 Mdot
.72 .06328 Mdot
.72 .06348 Mdot
.72 .06417 Mdot
.72 .06447 Mdot
.72 .06456 Mdot
.72 .06531 Mdot
.72 .06632 Mdot
.72 .06696 Mdot
.72 .06711 Mdot
.72 .0672 Mdot
.72 .06726 Mdot
.72 .06738 Mdot
.72 .06777 Mdot
.72 .06794 Mdot
.72 .069 Mdot
.72 .0699 Mdot
.72 .07003 Mdot
.72 .07024 Mdot
.72 .0704 Mdot
.72 .07041 Mdot
.72 .07143 Mdot
.72 .0724 Mdot
.72 .07296 Mdot
.72 .073 Mdot
.72 .07345 Mdot
.72 .07351 Mdot
.72 .07356 Mdot
.72 .07356 Mdot
.72 .07385 Mdot
.72 .07413 Mdot
.72 .07417 Mdot
.72 .07432 Mdot
.72 .07458 Mdot
.72 .07529 Mdot
.72 .07535 Mdot
.72 .07549 Mdot
.72 .07618 Mdot
.72 .07619 Mdot
.72 .07656 Mdot
.72 .0766 Mdot
.72 .07669 Mdot
.72 .07737 Mdot
.72 .07771 Mdot
.72 .07774 Mdot
.72 .0779 Mdot
.72 .07823 Mdot
.72 .07898 Mdot
.72 .07921 Mdot
.72 .07922 Mdot
.72 .07934 Mdot
.72 .07999 Mdot
.72 .08001 Mdot
.72 .08033 Mdot
.72 .08084 Mdot
.72 .081 Mdot
.72 .08192 Mdot
.72 .08205 Mdot
.72 .0821 Mdot
.72 .08224 Mdot
.72 .08236 Mdot
.72 .08239 Mdot
.72 .08273 Mdot
.72 .08275 Mdot
.72 .08277 Mdot
.72 .08313 Mdot
.72 .08337 Mdot
.72 .08347 Mdot
.72 .08377 Mdot
.72 .0838 Mdot
.72 .084 Mdot
.72 .08404 Mdot
.72 .08433 Mdot
.72 .08465 Mdot
.72 .08493 Mdot
.72 .08545 Mdot
.72 .08552 Mdot
.72 .08593 Mdot
.72 .08636 Mdot
.72 .08649 Mdot
.72 .08757 Mdot
.72 .08806 Mdot
.72 .0882 Mdot
.72 .0883 Mdot
.72 .08903 Mdot
.72 .08995 Mdot
.72 .09017 Mdot
.72 .0903 Mdot
.72 .09038 Mdot
.72 .09055 Mdot
.72 .09111 Mdot
.72 .09136 Mdot
.72 .09289 Mdot
.72 .09419 Mdot
.72 .09436 Mdot
.72 .09457 Mdot
.72 .09468 Mdot
.72 .0949 Mdot
.72 .09492 Mdot
.72 .09535 Mdot
.72 .09638 Mdot
.72 .09778 Mdot
.72 .09859 Mdot
.72 .09864 Mdot
.72 .09929 Mdot
.72 .09939 Mdot
.72 .09945 Mdot
.72 .09946 Mdot
.72 .09987 Mdot
.72 .10027 Mdot
.72 .10033 Mdot
.72 .10055 Mdot
.72 .10091 Mdot
.72 .10194 Mdot
.72 .10203 Mdot
.72 .10223 Mdot
.72 .1025 Mdot
.72 .10323 Mdot
.72 .10324 Mdot
.72 .10327 Mdot
.72 .10377 Mdot
.72 .10384 Mdot
.72 .10396 Mdot
.72 .10493 Mdot
.72 .10542 Mdot
.72 .10547 Mdot
.72 .1057 Mdot
.72 .10618 Mdot
.72 .10671 Mdot
.72 .10685 Mdot
.72 .10725 Mdot
.72 .10759 Mdot
.72 .10761 Mdot
.72 .10778 Mdot
.72 .10827 Mdot
.72 .10859 Mdot
.72 .10872 Mdot
.72 .10874 Mdot
.72 .10884 Mdot
.72 .10921 Mdot
.72 .10993 Mdot
.72 .11017 Mdot
.72 .11028 Mdot
.72 .11149 Mdot
.72 .11149 Mdot
.72 .11168 Mdot
.72 .11174 Mdot
.72 .11195 Mdot
.72 .11212 Mdot
.72 .11217 Mdot
.72 .1126 Mdot
.72 .11265 Mdot
.72 .11269 Mdot
.72 .11272 Mdot
.72 .1132 Mdot
.72 .11323 Mdot
.72 .11358 Mdot
.72 .1136 Mdot
.72 .11362 Mdot
.72 .11372 Mdot
.72 .11416 Mdot
.72 .1142 Mdot
.72 .11448 Mdot
.72 .11455 Mdot
.72 .1147 Mdot
.72 .11488 Mdot
.72 .11496 Mdot
.72 .11534 Mdot
.72 .11541 Mdot
.72 .11582 Mdot
.72 .11583 Mdot
.72 .11616 Mdot
.72 .11657 Mdot
.72 .11667 Mdot
.72 .11727 Mdot
.72 .11788 Mdot
.72 .11808 Mdot
.72 .1184 Mdot
.72 .11869 Mdot
.72 .11907 Mdot
.72 .11932 Mdot
.72 .11962 Mdot
.72 .12033 Mdot
.72 .12041 Mdot
.72 .12054 Mdot
.72 .12067 Mdot
.72 .12069 Mdot
.72 .12173 Mdot
.72 .12224 Mdot
.72 .12265 Mdot
.72 .12305 Mdot
.72 .12324 Mdot
.72 .12337 Mdot
.72 .12355 Mdot
.72 .12367 Mdot
.72 .12391 Mdot
.72 .12473 Mdot
.72 .12508 Mdot
.72 .12728 Mdot
.72 .12729 Mdot
.72 .12831 Mdot
.72 .12892 Mdot
.72 .129 Mdot
.72 .12912 Mdot
.72 .12915 Mdot
.72 .12941 Mdot
.72 .12947 Mdot
.72 .12956 Mdot
.72 .12971 Mdot
.72 .12986 Mdot
.72 .13019 Mdot
.72 .13021 Mdot
.72 .1308 Mdot
.72 .13083 Mdot
.72 .13085 Mdot
.72 .13231 Mdot
.72 .13249 Mdot
.72 .13415 Mdot
.72 .13433 Mdot
.72 .1355 Mdot
.72 .13557 Mdot
.72 .1365 Mdot
.72 .13664 Mdot
.72 .13673 Mdot
.72 .13674 Mdot
.72 .13699 Mdot
.72 .13703 Mdot
.72 .13725 Mdot
.72 .13733 Mdot
.72 .13792 Mdot
.72 .13801 Mdot
.72 .13832 Mdot
.72 .13838 Mdot
.72 .13884 Mdot
.72 .13898 Mdot
.72 .14032 Mdot
.72 .14034 Mdot
.72 .14045 Mdot
.72 .14073 Mdot
.72 .14075 Mdot
.72 .14113 Mdot
.72 .14152 Mdot
.72 .14218 Mdot
.72 .14219 Mdot
.72 .14224 Mdot
.72 .14296 Mdot
.72 .14305 Mdot
.72 .14323 Mdot
.72 .14463 Mdot
.72 .14534 Mdot
.72 .1454 Mdot
.72 .14543 Mdot
.72 .1457 Mdot
.72 .14573 Mdot
.72 .14619 Mdot
.72 .14643 Mdot
.72 .14719 Mdot
.72 .1474 Mdot
.72 .14755 Mdot
.72 .14797 Mdot
.72 .14807 Mdot
.72 .14846 Mdot
.72 .14848 Mdot
.72 .14872 Mdot
.72 .14943 Mdot
.72 .14989 Mdot
.72 .15008 Mdot
.72 .15011 Mdot
.72 .15025 Mdot
.72 .15058 Mdot
.72 .15078 Mdot
.72 .15084 Mdot
.72 .15097 Mdot
.72 .15182 Mdot
.72 .15214 Mdot
.72 .15217 Mdot
.72 .15228 Mdot
.72 .15232 Mdot
.72 .15407 Mdot
.72 .15408 Mdot
.72 .15423 Mdot
.72 .15434 Mdot
.72 .15444 Mdot
.72 .15474 Mdot
.72 .15498 Mdot
.72 .15505 Mdot
.72 .15528 Mdot
.72 .15567 Mdot
.72 .15575 Mdot
.72 .1558 Mdot
.72 .15584 Mdot
.72 .15653 Mdot
.72 .15658 Mdot
.72 .15708 Mdot
.72 .1571 Mdot
.72 .15714 Mdot
.72 .15729 Mdot
.72 .15791 Mdot
.72 .15797 Mdot
.72 .15838 Mdot
.72 .15848 Mdot
.72 .15856 Mdot
.72 .15869 Mdot
.72 .15895 Mdot
.72 .15907 Mdot
.72 .15944 Mdot
.72 .15962 Mdot
.72 .15972 Mdot
.72 .1601 Mdot
.72 .16031 Mdot
.72 .16032 Mdot
.72 .1608 Mdot
.72 .16139 Mdot
.72 .16154 Mdot
.72 .16189 Mdot
.72 .16234 Mdot
.72 .16239 Mdot
.72 .16328 Mdot
.72 .16355 Mdot
.72 .16402 Mdot
.72 .1641 Mdot
.72 .16443 Mdot
.72 .16498 Mdot
.72 .16515 Mdot
.72 .16534 Mdot
.72 .16579 Mdot
.72 .1668 Mdot
.72 .16691 Mdot
.72 .1671 Mdot
.72 .1673 Mdot
.72 .16732 Mdot
.72 .16818 Mdot
.72 .16881 Mdot
.72 .16956 Mdot
.72 .17014 Mdot
.72 .17017 Mdot
.72 .17072 Mdot
.72 .17097 Mdot
.72 .17099 Mdot
.72 .17113 Mdot
.72 .17117 Mdot
.72 .17144 Mdot
.72 .1716 Mdot
.72 .1717 Mdot
.72 .17196 Mdot
.72 .17313 Mdot
.72 .17314 Mdot
.72 .17364 Mdot
.72 .174 Mdot
.72 .17425 Mdot
.72 .17481 Mdot
.72 .17681 Mdot
.72 .17683 Mdot
.72 .17829 Mdot
.72 .17847 Mdot
.72 .17918 Mdot
.72 .17928 Mdot
.72 .17945 Mdot
.72 .17951 Mdot
.72 .17982 Mdot
.72 .17987 Mdot
.72 .17996 Mdot
.72 .17997 Mdot
.72 .18009 Mdot
.72 .1803 Mdot
.72 .18044 Mdot
.72 .18053 Mdot
.72 .18062 Mdot
.72 .181 Mdot
.72 .18102 Mdot
.72 .18187 Mdot
.72 .18192 Mdot
.72 .18195 Mdot
.72 .18405 Mdot
.72 .18431 Mdot
.72 .18671 Mdot
.72 .18697 Mdot
.72 .18812 Mdot
.72 .18817 Mdot
.72 .18864 Mdot
.72 .18875 Mdot
.72 .18883 Mdot
.72 .18931 Mdot
.72 .18972 Mdot
.72 .19009 Mdot
.72 .19029 Mdot
.72 .19042 Mdot
.72 .19043 Mdot
.72 .19079 Mdot
.72 .19085 Mdot
.72 .19101 Mdot
.72 .19117 Mdot
.72 .19128 Mdot
.72 .19203 Mdot
.72 .19213 Mdot
.72 .19226 Mdot
.72 .19234 Mdot
.72 .1927 Mdot
.72 .1928 Mdot
.72 .19332 Mdot
.72 .19346 Mdot
.72 .19365 Mdot
.72 .19501 Mdot
.72 .19535 Mdot
.72 .19556 Mdot
.72 .19558 Mdot
.72 .19562 Mdot
.72 .19574 Mdot
.72 .19577 Mdot
.72 .19618 Mdot
.72 .1962 Mdot
.72 .19675 Mdot
.72 .19731 Mdot
.72 .19826 Mdot
.72 .19827 Mdot
.72 .19835 Mdot
.72 .19872 Mdot
.72 .19892 Mdot
.72 .19938 Mdot
.72 .19952 Mdot
.72 .19977 Mdot
.72 .20108 Mdot
.72 .20117 Mdot
.72 .20134 Mdot
.72 .20179 Mdot
.72 .20197 Mdot
.72 .20281 Mdot
.72 .2029 Mdot
.72 .20294 Mdot
.72 .20333 Mdot
.72 .20338 Mdot
.72 .20403 Mdot
.72 .20438 Mdot
.72 .20548 Mdot
.72 .20578 Mdot
.72 .206 Mdot
.72 .2066 Mdot
.72 .20675 Mdot
.72 .20731 Mdot
.72 .20734 Mdot
.72 .20769 Mdot
.72 .2087 Mdot
.72 .20937 Mdot
.72 .20964 Mdot
.72 .20969 Mdot
.72 .20988 Mdot
.72 .21036 Mdot
.72 .21065 Mdot
.72 .21074 Mdot
.72 .21092 Mdot
.72 .21215 Mdot
.72 .2126 Mdot
.72 .21265 Mdot
.72 .21281 Mdot
.72 .21287 Mdot
.72 .21538 Mdot
.72 .2154 Mdot
.72 .21562 Mdot
.72 .21578 Mdot
.72 .21592 Mdot
.72 .21635 Mdot
.72 .21669 Mdot
.72 .21679 Mdot
.72 .21712 Mdot
.72 .21769 Mdot
.72 .2178 Mdot
.72 .21787 Mdot
.72 .21793 Mdot
.72 .21893 Mdot
.72 .219 Mdot
.72 .21972 Mdot
.72 .21975 Mdot
.72 .21981 Mdot
.72 .22002 Mdot
.72 .22092 Mdot
.72 .221 Mdot
.72 .22159 Mdot
.72 .22173 Mdot
.72 .22185 Mdot
.72 .22204 Mdot
.72 .22242 Mdot
.72 .22259 Mdot
.72 .22312 Mdot
.72 .22337 Mdot
.72 .22352 Mdot
.72 .22407 Mdot
.72 .22437 Mdot
.72 .22439 Mdot
.72 .22507 Mdot
.72 .22593 Mdot
.72 .22614 Mdot
.72 .22665 Mdot
.72 .2273 Mdot
.72 .22737 Mdot
.72 .22865 Mdot
.72 .22904 Mdot
.72 .22972 Mdot
.72 .22983 Mdot
.72 .23031 Mdot
.72 .2311 Mdot
.72 .23134 Mdot
.72 .23162 Mdot
.72 .23226 Mdot
.72 .23372 Mdot
.72 .23388 Mdot
.72 .23415 Mdot
.72 .23443 Mdot
.72 .23446 Mdot
.72 .23571 Mdot
.72 .23661 Mdot
.72 .23769 Mdot
.72 .23853 Mdot
.72 .23857 Mdot
.72 .23937 Mdot
.72 .23972 Mdot
.72 .23976 Mdot
.72 .23995 Mdot
.72 .24001 Mdot
.72 .2404 Mdot
.72 .24063 Mdot
.72 .24078 Mdot
.72 .24115 Mdot
.72 .24283 Mdot
.72 .24284 Mdot
.72 .24357 Mdot
.72 .24409 Mdot
.72 .24445 Mdot
.72 .24525 Mdot
.72 .24814 Mdot
.72 .24816 Mdot
.72 .25026 Mdot
.72 .25052 Mdot
.72 .25154 Mdot
.72 .25169 Mdot
.72 .25194 Mdot
.72 .25202 Mdot
.72 .25246 Mdot
.72 .25254 Mdot
.72 .25267 Mdot
.72 .25269 Mdot
.72 .25286 Mdot
.72 .25316 Mdot
.72 .25335 Mdot
.72 .25348 Mdot
.72 .25362 Mdot
.72 .25416 Mdot
.72 .2542 Mdot
.72 .25542 Mdot
.72 .25549 Mdot
.72 .25553 Mdot
.72 .25856 Mdot
.72 .25894 Mdot
.72 .26238 Mdot
.72 .26276 Mdot
.72 .26442 Mdot
.72 .26448 Mdot
.72 .26516 Mdot
.72 .26532 Mdot
.72 .26544 Mdot
.72 .26613 Mdot
.72 .26672 Mdot
.72 .26725 Mdot
.72 .26754 Mdot
.72 .26773 Mdot
.72 .26775 Mdot
.72 .26827 Mdot
.72 .26835 Mdot
.72 .26858 Mdot
.72 .26881 Mdot
.72 .26897 Mdot
.72 .27005 Mdot
.72 .27019 Mdot
.72 .27037 Mdot
.72 .27049 Mdot
.72 .27102 Mdot
.72 .27116 Mdot
.72 .2719 Mdot
.72 .2721 Mdot
.72 .27239 Mdot
.72 .27434 Mdot
.72 .27483 Mdot
.72 .27513 Mdot
.72 .27516 Mdot
.72 .27522 Mdot
.72 .27539 Mdot
.72 .27543 Mdot
.72 .27603 Mdot
.72 .27606 Mdot
.72 .27685 Mdot
.72 .27765 Mdot
.72 .27902 Mdot
.72 .27904 Mdot
.72 .27914 Mdot
.72 .27969 Mdot
.72 .27998 Mdot
.72 .28063 Mdot
.72 .28083 Mdot
.72 .2812 Mdot
.72 .28309 Mdot
.72 .28322 Mdot
.72 .28345 Mdot
.72 .28411 Mdot
.72 .28436 Mdot
.72 .28557 Mdot
.72 .2857 Mdot
.72 .28576 Mdot
.72 .28632 Mdot
.72 .28639 Mdot
.72 .28733 Mdot
.72 .28783 Mdot
.72 .28942 Mdot
.72 .28984 Mdot
.72 .29016 Mdot
.72 .29103 Mdot
.72 .29124 Mdot
.72 .29205 Mdot
.72 .29209 Mdot
.72 .2926 Mdot
.72 .29406 Mdot
.72 .29502 Mdot
.72 .2954 Mdot
.72 .29548 Mdot
.72 .29576 Mdot
.72 .29644 Mdot
.72 .29687 Mdot
.72 .29699 Mdot
.72 .29725 Mdot
.72 .29902 Mdot
.72 .29967 Mdot
.72 .29975 Mdot
.72 .29997 Mdot
.72 .30006 Mdot
.72 .30367 Mdot
.72 .3037 Mdot
.72 .30402 Mdot
.72 .30425 Mdot
.72 .30444 Mdot
.72 .30507 Mdot
.72 .30556 Mdot
.72 .30571 Mdot
.72 .30618 Mdot
.72 .307 Mdot
.72 .30716 Mdot
.72 .30726 Mdot
.72 .30735 Mdot
.72 .30879 Mdot
.72 .30888 Mdot
.72 .30993 Mdot
.72 .30997 Mdot
.72 .31005 Mdot
.72 .31035 Mdot
.72 .31165 Mdot
.72 .31177 Mdot
.72 .31262 Mdot
.72 .31282 Mdot
.72 .31299 Mdot
.72 .31327 Mdot
.72 .3138 Mdot
.72 .31405 Mdot
.72 .31481 Mdot
.72 .31518 Mdot
.72 .3154 Mdot
.72 .31618 Mdot
.72 .31662 Mdot
.72 .31664 Mdot
.72 .31763 Mdot
.72 .31886 Mdot
.72 .31916 Mdot
.72 .3199 Mdot
.72 .32083 Mdot
.72 .32094 Mdot
.72 .32277 Mdot
.72 .32335 Mdot
.72 .32432 Mdot
.72 .32448 Mdot
.72 .32517 Mdot
.72 .32631 Mdot
.72 .32666 Mdot
.72 .32706 Mdot
.72 .32797 Mdot
.72 .33009 Mdot
.72 .33031 Mdot
.72 .3307 Mdot
.72 .33111 Mdot
.72 .33115 Mdot
.72 .33295 Mdot
.72 .33425 Mdot
.72 .33579 Mdot
.72 .33701 Mdot
.72 .33707 Mdot
.72 .33822 Mdot
.72 .33872 Mdot
.72 .33877 Mdot
.72 .33905 Mdot
.72 .33914 Mdot
.72 .3397 Mdot
.72 .34004 Mdot
.72 .34024 Mdot
.72 .34077 Mdot
.72 .3432 Mdot
.72 .34322 Mdot
.72 .34426 Mdot
.72 .34501 Mdot
.72 .34553 Mdot
.72 .34668 Mdot
.72 .35085 Mdot
.72 .35087 Mdot
.72 .3539 Mdot
.72 .35427 Mdot
.72 .35574 Mdot
.72 .35597 Mdot
.72 .35631 Mdot
.72 .35643 Mdot
.72 .35707 Mdot
.72 .35719 Mdot
.72 .35737 Mdot
.72 .35739 Mdot
.72 .35764 Mdot
.72 .35807 Mdot
.72 .35835 Mdot
.72 .35854 Mdot
.72 .35874 Mdot
.72 .35952 Mdot
.72 .35957 Mdot
.72 .36133 Mdot
.72 .36143 Mdot
.72 .3615 Mdot
.72 .36585 Mdot
.72 .36639 Mdot
.72 .37136 Mdot
.72 .37189 Mdot
.72 .37428 Mdot
.72 .37438 Mdot
.72 .37536 Mdot
.72 .37559 Mdot
.72 .37576 Mdot
.72 .37676 Mdot
.72 .3776 Mdot
.72 .37837 Mdot
.72 .37879 Mdot
.72 .37906 Mdot
.72 .37908 Mdot
.72 .37983 Mdot
.72 .37995 Mdot
.72 .38028 Mdot
.72 .38061 Mdot
.72 .38084 Mdot
.72 .3824 Mdot
.72 .3826 Mdot
.72 .38286 Mdot
.72 .38304 Mdot
.72 .38379 Mdot
.72 .38399 Mdot
.72 .38507 Mdot
.72 .38535 Mdot
.72 .38576 Mdot
.72 .38858 Mdot
.72 .38928 Mdot
.72 .38971 Mdot
.72 .38976 Mdot
.72 .38984 Mdot
.72 .39009 Mdot
.72 .39015 Mdot
.72 .39101 Mdot
.72 .39105 Mdot
.72 .39219 Mdot
.72 .39334 Mdot
.72 .39531 Mdot
.72 .39534 Mdot
.72 .39549 Mdot
.72 .39628 Mdot
.72 .39669 Mdot
.72 .39764 Mdot
.72 .39792 Mdot
.72 .39845 Mdot
.72 .40117 Mdot
.72 .40136 Mdot
.72 .40169 Mdot
.72 .40264 Mdot
.72 .403 Mdot
.72 .40475 Mdot
.72 .40493 Mdot
.72 .40502 Mdot
.72 .40583 Mdot
.72 .40593 Mdot
.72 .40728 Mdot
.72 .40801 Mdot
.72 .41029 Mdot
.72 .4109 Mdot
.72 .41136 Mdot
.72 .4126 Mdot
.72 .41291 Mdot
.72 .41408 Mdot
.72 .41414 Mdot
.72 .41487 Mdot
.72 .41697 Mdot
.72 .41835 Mdot
.72 .4189 Mdot
.72 .41901 Mdot
.72 .41941 Mdot
.72 .4204 Mdot
.72 .42101 Mdot
.72 .42119 Mdot
.72 .42157 Mdot
.72 .42411 Mdot
.72 .42505 Mdot
.72 .42516 Mdot
.72 .42548 Mdot
.72 .42561 Mdot
.72 .43081 Mdot
.72 .43085 Mdot
.72 .43131 Mdot
.72 .43164 Mdot
.72 .43193 Mdot
.72 .43282 Mdot
.72 .43353 Mdot
.72 .43375 Mdot
.72 .43443 Mdot
.72 .4356 Mdot
.72 .43584 Mdot
.72 .43598 Mdot
.72 .43611 Mdot
.72 .43818 Mdot
.72 .43832 Mdot
.72 .43982 Mdot
.72 .43988 Mdot
.72 .43999 Mdot
.72 .44043 Mdot
.722 .01479 Mdot
.722 .01483 Mdot
.722 .01488 Mdot
.722 .01495 Mdot
.722 .01506 Mdot
.722 .01521 Mdot
.722 .01543 Mdot
.722 .01574 Mdot
.722 .01579 Mdot
.722 .0162 Mdot
.722 .01626 Mdot
.722 .01631 Mdot
.722 .01686 Mdot
.722 .01695 Mdot
.722 .01701 Mdot
.722 .01781 Mdot
.722 .01793 Mdot
.722 .01794 Mdot
.722 .01804 Mdot
.722 .01919 Mdot
.722 .01936 Mdot
.722 .01937 Mdot
.722 .01951 Mdot
.722 .02068 Mdot
.722 .02117 Mdot
.722 .02138 Mdot
.722 .02142 Mdot
.722 .02144 Mdot
.722 .02164 Mdot
.722 .02299 Mdot
.722 .02333 Mdot
.722 .02404 Mdot
.722 .02434 Mdot
.722 .0244 Mdot
.722 .02443 Mdot
.722 .02471 Mdot
.722 .02535 Mdot
.722 .02667 Mdot
.722 .02681 Mdot
.722 .02716 Mdot
.722 .02766 Mdot
.722 .02818 Mdot
.722 .02861 Mdot
.722 .0287 Mdot
.722 .02874 Mdot
.722 .02891 Mdot
.722 .02915 Mdot
.722 .03007 Mdot
.722 .03115 Mdot
.722 .03145 Mdot
.722 .03198 Mdot
.722 .03218 Mdot
.722 .03268 Mdot
.722 .03268 Mdot
.722 .0334 Mdot
.722 .03416 Mdot
.722 .03425 Mdot
.722 .03478 Mdot
.722 .03491 Mdot
.722 .03496 Mdot
.722 .03521 Mdot
.722 .03535 Mdot
.722 .03552 Mdot
.722 .03556 Mdot
.722 .03565 Mdot
.722 .03602 Mdot
.722 .03617 Mdot
.722 .03639 Mdot
.722 .03689 Mdot
.722 .03799 Mdot
.722 .03843 Mdot
.722 .03844 Mdot
.722 .03845 Mdot
.722 .03888 Mdot
.722 .03899 Mdot
.722 .03901 Mdot
.722 .03923 Mdot
.722 .03964 Mdot
.722 .03993 Mdot
.722 .04025 Mdot
.722 .04065 Mdot
.722 .04066 Mdot
.722 .04163 Mdot
.722 .0417 Mdot
.722 .04279 Mdot
.722 .04292 Mdot
.722 .04347 Mdot
.722 .04369 Mdot
.722 .04387 Mdot
.722 .04395 Mdot
.722 .04431 Mdot
.722 .0445 Mdot
.722 .04452 Mdot
.722 .04463 Mdot
.722 .04476 Mdot
.722 .04482 Mdot
.722 .04495 Mdot
.722 .04544 Mdot
.722 .04548 Mdot
.722 .04569 Mdot
.722 .04601 Mdot
.722 .04663 Mdot
.722 .04674 Mdot
.722 .04701 Mdot
.722 .04832 Mdot
.722 .04896 Mdot
.722 .04897 Mdot
.722 .04899 Mdot
.722 .04939 Mdot
.722 .04962 Mdot
.722 .04977 Mdot
.722 .0498 Mdot
.722 .05012 Mdot
.722 .0507 Mdot
.722 .05093 Mdot
.722 .05113 Mdot
.722 .05125 Mdot
.722 .05159 Mdot
.722 .05167 Mdot
.722 .05217 Mdot
.722 .05218 Mdot
.722 .05244 Mdot
.722 .05325 Mdot
.722 .05359 Mdot
.722 .05368 Mdot
.722 .05461 Mdot
.722 .05526 Mdot
.722 .05544 Mdot
.722 .05624 Mdot
.722 .05655 Mdot
.722 .05656 Mdot
.722 .05682 Mdot
.722 .05694 Mdot
.722 .05706 Mdot
.722 .05745 Mdot
.722 .05773 Mdot
.722 .05776 Mdot
.722 .05791 Mdot
.722 .0581 Mdot
.722 .05819 Mdot
.722 .05837 Mdot
.722 .05889 Mdot
.722 .05908 Mdot
.722 .05914 Mdot
.722 .05944 Mdot
.722 .0599 Mdot
.722 .0608 Mdot
.722 .06096 Mdot
.722 .06135 Mdot
.722 .06144 Mdot
.722 .06182 Mdot
.722 .06324 Mdot
.722 .06379 Mdot
.722 .06416 Mdot
.722 .06418 Mdot
.722 .0642 Mdot
.722 .06443 Mdot
.722 .06443 Mdot
.722 .06478 Mdot
.722 .06511 Mdot
.722 .0652 Mdot
.722 .06533 Mdot
.722 .06537 Mdot
.722 .06584 Mdot
.722 .06597 Mdot
.722 .06668 Mdot
.722 .06701 Mdot
.722 .06723 Mdot
.722 .06729 Mdot
.722 .06747 Mdot
.722 .06796 Mdot
.722 .06808 Mdot
.722 .0688 Mdot
.722 .06882 Mdot
.722 .06919 Mdot
.722 .07037 Mdot
.722 .07046 Mdot
.722 .07085 Mdot
.722 .07098 Mdot
.722 .07136 Mdot
.722 .07157 Mdot
.722 .07163 Mdot
.722 .07232 Mdot
.722 .07259 Mdot
.722 .07326 Mdot
.722 .07352 Mdot
.722 .07447 Mdot
.722 .0746 Mdot
.722 .07467 Mdot
.722 .07513 Mdot
.722 .07514 Mdot
.722 .07552 Mdot
.722 .07568 Mdot
.722 .07586 Mdot
.722 .07642 Mdot
.722 .07683 Mdot
.722 .07687 Mdot
.722 .07708 Mdot
.722 .07736 Mdot
.722 .07749 Mdot
.722 .07776 Mdot
.722 .07806 Mdot
.722 .07821 Mdot
.722 .07851 Mdot
.722 .07878 Mdot
.722 .07887 Mdot
.722 .0793 Mdot
.722 .07986 Mdot
.722 .07996 Mdot
.722 .07998 Mdot
.722 .08021 Mdot
.722 .08028 Mdot
.722 .08032 Mdot
.722 .08126 Mdot
.722 .08149 Mdot
.722 .08165 Mdot
.722 .08206 Mdot
.722 .08218 Mdot
.722 .08273 Mdot
.722 .08323 Mdot
.722 .08367 Mdot
.722 .08442 Mdot
.722 .08465 Mdot
.722 .08478 Mdot
.722 .08539 Mdot
.722 .08558 Mdot
.722 .08583 Mdot
.722 .08612 Mdot
.722 .08614 Mdot
.722 .08617 Mdot
.722 .08643 Mdot
.722 .0865 Mdot
.722 .0865 Mdot
.722 .08679 Mdot
.722 .08701 Mdot
.722 .08749 Mdot
.722 .08762 Mdot
.722 .08781 Mdot
.722 .08787 Mdot
.722 .08854 Mdot
.722 .08861 Mdot
.722 .08873 Mdot
.722 .08947 Mdot
.722 .08976 Mdot
.722 .09016 Mdot
.722 .09023 Mdot
.722 .09054 Mdot
.722 .09064 Mdot
.722 .09089 Mdot
.722 .0916 Mdot
.722 .09174 Mdot
.722 .09178 Mdot
.722 .09179 Mdot
.722 .09226 Mdot
.722 .09281 Mdot
.722 .09284 Mdot
.722 .0931 Mdot
.722 .09315 Mdot
.722 .09338 Mdot
.722 .09449 Mdot
.722 .09474 Mdot
.722 .09507 Mdot
.722 .09522 Mdot
.722 .09577 Mdot
.722 .09597 Mdot
.722 .09651 Mdot
.722 .09662 Mdot
.722 .09682 Mdot
.722 .0969 Mdot
.722 .09788 Mdot
.722 .09789 Mdot
.722 .09828 Mdot
.722 .09925 Mdot
.722 .09963 Mdot
.722 .10095 Mdot
.722 .101 Mdot
.722 .10119 Mdot
.722 .10129 Mdot
.722 .1013 Mdot
.722 .10194 Mdot
.722 .10195 Mdot
.722 .10198 Mdot
.722 .10251 Mdot
.722 .10257 Mdot
.722 .10275 Mdot
.722 .10301 Mdot
.722 .10321 Mdot
.722 .10373 Mdot
.722 .10381 Mdot
.722 .10441 Mdot
.722 .10447 Mdot
.722 .10477 Mdot
.722 .10518 Mdot
.722 .10537 Mdot
.722 .10575 Mdot
.722 .10618 Mdot
.722 .1064 Mdot
.722 .10683 Mdot
.722 .10722 Mdot
.722 .10735 Mdot
.722 .10798 Mdot
.722 .10837 Mdot
.722 .10878 Mdot
.722 .10878 Mdot
.722 .10893 Mdot
.722 .10896 Mdot
.722 .10929 Mdot
.722 .10938 Mdot
.722 .10946 Mdot
.722 .10987 Mdot
.722 .10996 Mdot
.722 .1108 Mdot
.722 .11114 Mdot
.722 .11137 Mdot
.722 .11196 Mdot
.722 .11213 Mdot
.722 .11239 Mdot
.722 .11243 Mdot
.722 .11269 Mdot
.722 .11294 Mdot
.722 .11328 Mdot
.722 .11366 Mdot
.722 .11429 Mdot
.722 .11445 Mdot
.722 .11536 Mdot
.722 .1157 Mdot
.722 .11589 Mdot
.722 .11677 Mdot
.722 .11705 Mdot
.722 .11741 Mdot
.722 .11782 Mdot
.722 .11785 Mdot
.722 .1179 Mdot
.722 .11827 Mdot
.722 .11837 Mdot
.722 .11837 Mdot
.722 .1185 Mdot
.722 .11851 Mdot
.722 .11879 Mdot
.722 .11911 Mdot
.722 .1198 Mdot
.722 .11998 Mdot
.722 .12026 Mdot
.722 .12035 Mdot
.722 .12089 Mdot
.722 .12132 Mdot
.722 .12142 Mdot
.722 .1216 Mdot
.722 .12266 Mdot
.722 .12308 Mdot
.722 .12366 Mdot
.722 .12375 Mdot
.722 .12421 Mdot
.722 .12435 Mdot
.722 .12471 Mdot
.722 .12499 Mdot
.722 .12574 Mdot
.722 .12595 Mdot
.722 .12599 Mdot
.722 .12601 Mdot
.722 .12666 Mdot
.722 .12669 Mdot
.722 .12749 Mdot
.722 .12752 Mdot
.722 .1279 Mdot
.722 .12793 Mdot
.722 .12798 Mdot
.722 .12831 Mdot
.722 .12895 Mdot
.722 .12917 Mdot
.722 .12927 Mdot
.722 .12941 Mdot
.722 .12949 Mdot
.722 .12991 Mdot
.722 .13027 Mdot
.722 .13064 Mdot
.722 .13075 Mdot
.722 .13096 Mdot
.722 .13127 Mdot
.722 .13132 Mdot
.722 .13175 Mdot
.722 .13205 Mdot
.722 .13283 Mdot
.722 .13298 Mdot
.722 .13327 Mdot
.722 .13339 Mdot
.722 .13446 Mdot
.722 .13455 Mdot
.722 .1348 Mdot
.722 .13482 Mdot
.722 .13538 Mdot
.722 .13539 Mdot
.722 .13545 Mdot
.722 .13559 Mdot
.722 .13679 Mdot
.722 .13734 Mdot
.722 .13867 Mdot
.722 .13896 Mdot
.722 .13924 Mdot
.722 .1393 Mdot
.722 .13932 Mdot
.722 .13958 Mdot
.722 .13972 Mdot
.722 .13974 Mdot
.722 .14046 Mdot
.722 .14048 Mdot
.722 .14067 Mdot
.722 .14069 Mdot
.722 .14072 Mdot
.722 .14143 Mdot
.722 .14149 Mdot
.722 .14157 Mdot
.722 .14184 Mdot
.722 .14206 Mdot
.722 .14221 Mdot
.722 .14251 Mdot
.722 .14326 Mdot
.722 .14337 Mdot
.722 .14337 Mdot
.722 .14374 Mdot
.722 .14423 Mdot
.722 .14432 Mdot
.722 .14476 Mdot
.722 .14534 Mdot
.722 .14561 Mdot
.722 .14616 Mdot
.722 .14662 Mdot
.722 .14679 Mdot
.722 .14711 Mdot
.722 .14712 Mdot
.722 .14713 Mdot
.722 .14773 Mdot
.722 .14781 Mdot
.722 .1483 Mdot
.722 .14848 Mdot
.722 .14858 Mdot
.722 .14873 Mdot
.722 .14933 Mdot
.722 .14939 Mdot
.722 .14995 Mdot
.722 .15054 Mdot
.722 .15054 Mdot
.722 .15077 Mdot
.722 .1508 Mdot
.722 .15087 Mdot
.722 .15124 Mdot
.722 .15128 Mdot
.722 .15142 Mdot
.722 .15152 Mdot
.722 .15212 Mdot
.722 .15224 Mdot
.722 .15315 Mdot
.722 .15346 Mdot
.722 .15396 Mdot
.722 .15426 Mdot
.722 .15428 Mdot
.722 .15514 Mdot
.722 .15539 Mdot
.722 .1557 Mdot
.722 .15576 Mdot
.722 .15582 Mdot
.722 .15619 Mdot
.722 .15655 Mdot
.722 .15688 Mdot
.722 .15705 Mdot
.722 .15759 Mdot
.722 .1585 Mdot
.722 .15873 Mdot
.722 .15927 Mdot
.722 .16005 Mdot
.722 .16054 Mdot
.722 .16082 Mdot
.722 .16123 Mdot
.722 .16198 Mdot
.722 .16208 Mdot
.722 .16248 Mdot
.722 .16301 Mdot
.722 .16337 Mdot
.722 .16343 Mdot
.722 .16347 Mdot
.722 .1636 Mdot
.722 .16364 Mdot
.722 .16372 Mdot
.722 .16425 Mdot
.722 .1644 Mdot
.722 .1644 Mdot
.722 .16458 Mdot
.722 .16459 Mdot
.722 .165 Mdot
.722 .16546 Mdot
.722 .16607 Mdot
.722 .16642 Mdot
.722 .16645 Mdot
.722 .16672 Mdot
.722 .16712 Mdot
.722 .16725 Mdot
.722 .16803 Mdot
.722 .16855 Mdot
.722 .16865 Mdot
.722 .16879 Mdot
.722 .16905 Mdot
.722 .16932 Mdot
.722 .16977 Mdot
.722 .17042 Mdot
.722 .17058 Mdot
.722 .17119 Mdot
.722 .17204 Mdot
.722 .17216 Mdot
.722 .17282 Mdot
.722 .17303 Mdot
.722 .17303 Mdot
.722 .17329 Mdot
.722 .17354 Mdot
.722 .17396 Mdot
.722 .17503 Mdot
.722 .17533 Mdot
.722 .1754 Mdot
.722 .17542 Mdot
.722 .17574 Mdot
.722 .17637 Mdot
.722 .17641 Mdot
.722 .17756 Mdot
.722 .17761 Mdot
.722 .17815 Mdot
.722 .1782 Mdot
.722 .17827 Mdot
.722 .17829 Mdot
.722 .17831 Mdot
.722 .17875 Mdot
.722 .17928 Mdot
.722 .17942 Mdot
.722 .17967 Mdot
.722 .17975 Mdot
.722 .17999 Mdot
.722 .18014 Mdot
.722 .18034 Mdot
.722 .18046 Mdot
.722 .18106 Mdot
.722 .18135 Mdot
.722 .18158 Mdot
.722 .1821 Mdot
.722 .18212 Mdot
.722 .18227 Mdot
.722 .18255 Mdot
.722 .18257 Mdot
.722 .18302 Mdot
.722 .1831 Mdot
.722 .18372 Mdot
.722 .18414 Mdot
.722 .18516 Mdot
.722 .18527 Mdot
.722 .18549 Mdot
.722 .1857 Mdot
.722 .18591 Mdot
.722 .18608 Mdot
.722 .18762 Mdot
.722 .18776 Mdot
.722 .18812 Mdot
.722 .18815 Mdot
.722 .18896 Mdot
.722 .18897 Mdot
.722 .18906 Mdot
.722 .18926 Mdot
.722 .18964 Mdot
.722 .19099 Mdot
.722 .19099 Mdot
.722 .19178 Mdot
.722 .19315 Mdot
.722 .1937 Mdot
.722 .19412 Mdot
.722 .19446 Mdot
.722 .19453 Mdot
.722 .19457 Mdot
.722 .19461 Mdot
.722 .19464 Mdot
.722 .19502 Mdot
.722 .19523 Mdot
.722 .19525 Mdot
.722 .19629 Mdot
.722 .19632 Mdot
.722 .1966 Mdot
.722 .19662 Mdot
.722 .19666 Mdot
.722 .19769 Mdot
.722 .19778 Mdot
.722 .1979 Mdot
.722 .19828 Mdot
.722 .19829 Mdot
.722 .1986 Mdot
.722 .19881 Mdot
.722 .19925 Mdot
.722 .19937 Mdot
.722 .20033 Mdot
.722 .20049 Mdot
.722 .2005 Mdot
.722 .20072 Mdot
.722 .20098 Mdot
.722 .20103 Mdot
.722 .20123 Mdot
.722 .20174 Mdot
.722 .20186 Mdot
.722 .2025 Mdot
.722 .20286 Mdot
.722 .20334 Mdot
.722 .20373 Mdot
.722 .20453 Mdot
.722 .20518 Mdot
.722 .20543 Mdot
.722 .20589 Mdot
.722 .20591 Mdot
.722 .20593 Mdot
.722 .20679 Mdot
.722 .2069 Mdot
.722 .20761 Mdot
.722 .20787 Mdot
.722 .20802 Mdot
.722 .20823 Mdot
.722 .2091 Mdot
.722 .20918 Mdot
.722 .21 Mdot
.722 .21085 Mdot
.722 .21085 Mdot
.722 .21117 Mdot
.722 .21122 Mdot
.722 .21133 Mdot
.722 .21186 Mdot
.722 .21191 Mdot
.722 .21211 Mdot
.722 .21226 Mdot
.722 .21313 Mdot
.722 .21331 Mdot
.722 .21462 Mdot
.722 .21506 Mdot
.722 .21578 Mdot
.722 .21622 Mdot
.722 .21625 Mdot
.722 .21749 Mdot
.722 .21785 Mdot
.722 .2183 Mdot
.722 .21838 Mdot
.722 .21846 Mdot
.722 .21901 Mdot
.722 .21952 Mdot
.722 .21999 Mdot
.722 .22024 Mdot
.722 .22102 Mdot
.722 .22234 Mdot
.722 .22268 Mdot
.722 .22345 Mdot
.722 .22458 Mdot
.722 .22528 Mdot
.722 .22569 Mdot
.722 .22629 Mdot
.722 .22736 Mdot
.722 .22751 Mdot
.722 .22809 Mdot
.722 .22885 Mdot
.722 .22937 Mdot
.722 .22946 Mdot
.722 .22952 Mdot
.722 .2297 Mdot
.722 .22977 Mdot
.722 .22987 Mdot
.722 .23064 Mdot
.722 .23085 Mdot
.722 .23086 Mdot
.722 .23112 Mdot
.722 .23113 Mdot
.722 .23173 Mdot
.722 .23239 Mdot
.722 .23327 Mdot
.722 .23378 Mdot
.722 .23382 Mdot
.722 .23422 Mdot
.722 .23478 Mdot
.722 .23497 Mdot
.722 .23611 Mdot
.722 .23685 Mdot
.722 .237 Mdot
.722 .23721 Mdot
.722 .23757 Mdot
.722 .23796 Mdot
.722 .23861 Mdot
.722 .23955 Mdot
.722 .23979 Mdot
.722 .24067 Mdot
.722 .24189 Mdot
.722 .24207 Mdot
.722 .24302 Mdot
.722 .24332 Mdot
.722 .24332 Mdot
.722 .24369 Mdot
.722 .24406 Mdot
.722 .24466 Mdot
.722 .24622 Mdot
.722 .24665 Mdot
.722 .24675 Mdot
.722 .24678 Mdot
.722 .24723 Mdot
.722 .24814 Mdot
.722 .2482 Mdot
.722 .24986 Mdot
.722 .24993 Mdot
.722 .25072 Mdot
.722 .25078 Mdot
.722 .25089 Mdot
.722 .25092 Mdot
.722 .25095 Mdot
.722 .25158 Mdot
.722 .25234 Mdot
.722 .25255 Mdot
.722 .25291 Mdot
.722 .25302 Mdot
.722 .25337 Mdot
.722 .25359 Mdot
.722 .25387 Mdot
.722 .25405 Mdot
.722 .25492 Mdot
.722 .25533 Mdot
.722 .25566 Mdot
.722 .25642 Mdot
.722 .25644 Mdot
.722 .25667 Mdot
.722 .25707 Mdot
.722 .2571 Mdot
.722 .25774 Mdot
.722 .25786 Mdot
.722 .25876 Mdot
.722 .25936 Mdot
.722 .26084 Mdot
.722 .261 Mdot
.722 .26131 Mdot
.722 .26161 Mdot
.722 .26192 Mdot
.722 .26217 Mdot
.722 .2644 Mdot
.722 .26459 Mdot
.722 .26512 Mdot
.722 .26516 Mdot
.722 .26632 Mdot
.722 .26634 Mdot
.722 .26647 Mdot
.722 .26675 Mdot
.722 .26731 Mdot
.722 .26925 Mdot
.722 .26926 Mdot
.722 .2704 Mdot
.722 .27237 Mdot
.722 .27317 Mdot
.722 .27378 Mdot
.722 .27427 Mdot
.722 .27437 Mdot
.722 .27442 Mdot
.722 .27449 Mdot
.722 .27453 Mdot
.722 .27508 Mdot
.722 .27538 Mdot
.722 .2754 Mdot
.722 .27691 Mdot
.722 .27695 Mdot
.722 .27736 Mdot
.722 .27738 Mdot
.722 .27745 Mdot
.722 .27893 Mdot
.722 .27906 Mdot
.722 .27923 Mdot
.722 .27979 Mdot
.722 .2798 Mdot
.722 .28025 Mdot
.722 .28055 Mdot
.722 .28118 Mdot
.722 .28136 Mdot
.722 .28274 Mdot
.722 .28298 Mdot
.722 .28299 Mdot
.722 .28331 Mdot
.722 .28368 Mdot
.722 .28375 Mdot
.722 .28404 Mdot
.722 .28478 Mdot
.722 .28496 Mdot
.722 .28587 Mdot
.722 .2864 Mdot
.722 .28709 Mdot
.722 .28766 Mdot
.722 .28881 Mdot
.722 .28975 Mdot
.722 .29011 Mdot
.722 .29077 Mdot
.722 .2908 Mdot
.722 .29082 Mdot
.722 .29207 Mdot
.722 .29224 Mdot
.722 .29326 Mdot
.722 .29363 Mdot
.722 .29384 Mdot
.722 .29415 Mdot
.722 .29541 Mdot
.722 .29553 Mdot
.722 .29671 Mdot
.722 .29793 Mdot
.722 .29794 Mdot
.722 .2984 Mdot
.722 .29847 Mdot
.722 .29863 Mdot
.722 .29939 Mdot
.722 .29947 Mdot
.722 .29976 Mdot
.722 .29997 Mdot
.722 .30122 Mdot
.722 .30148 Mdot
.722 .30337 Mdot
.722 .30402 Mdot
.722 .30505 Mdot
.722 .30568 Mdot
.722 .30573 Mdot
.722 .30752 Mdot
.722 .30804 Mdot
.722 .30869 Mdot
.722 .30881 Mdot
.722 .30893 Mdot
.722 .30971 Mdot
.722 .31045 Mdot
.722 .31114 Mdot
.722 .3115 Mdot
.722 .31262 Mdot
.722 .31453 Mdot
.722 .31501 Mdot
.722 .31613 Mdot
.722 .31776 Mdot
.722 .31877 Mdot
.722 .31936 Mdot
.722 .32022 Mdot
.722 .32178 Mdot
.722 .32199 Mdot
.722 .32284 Mdot
.722 .32392 Mdot
.722 .32468 Mdot
.722 .32481 Mdot
.722 .3249 Mdot
.722 .32515 Mdot
.722 .32525 Mdot
.722 .3254 Mdot
.722 .32651 Mdot
.722 .32682 Mdot
.722 .32682 Mdot
.722 .32721 Mdot
.722 .32722 Mdot
.722 .32808 Mdot
.722 .32904 Mdot
.722 .33031 Mdot
.722 .33104 Mdot
.722 .33111 Mdot
.722 .33167 Mdot
.722 .3325 Mdot
.722 .33276 Mdot
.722 .33441 Mdot
.722 .33547 Mdot
.722 .33569 Mdot
.722 .33599 Mdot
.722 .33652 Mdot
.722 .33709 Mdot
.722 .33802 Mdot
.722 .33938 Mdot
.722 .33972 Mdot
.722 .34099 Mdot
.722 .34275 Mdot
.722 .34302 Mdot
.722 .34438 Mdot
.722 .34482 Mdot
.722 .34482 Mdot
.722 .34536 Mdot
.722 .34589 Mdot
.722 .34676 Mdot
.722 .349 Mdot
.722 .34962 Mdot
.722 .34977 Mdot
.722 .34981 Mdot
.722 .35047 Mdot
.722 .35178 Mdot
.722 .35187 Mdot
.722 .35426 Mdot
.722 .35437 Mdot
.722 .35551 Mdot
.722 .35559 Mdot
.722 .35575 Mdot
.722 .3558 Mdot
.722 .35583 Mdot
.722 .35675 Mdot
.722 .35785 Mdot
.722 .35815 Mdot
.722 .35867 Mdot
.722 .35883 Mdot
.722 .35934 Mdot
.722 .35965 Mdot
.722 .36006 Mdot
.722 .36031 Mdot
.722 .36157 Mdot
.722 .36216 Mdot
.722 .36265 Mdot
.722 .36374 Mdot
.722 .36377 Mdot
.722 .3641 Mdot
.722 .36468 Mdot
.722 .36472 Mdot
.722 .36564 Mdot
.722 .36581 Mdot
.722 .36711 Mdot
.722 .36799 Mdot
.722 .37012 Mdot
.722 .37035 Mdot
.722 .3708 Mdot
.722 .37123 Mdot
.722 .37168 Mdot
.722 .37204 Mdot
.722 .37525 Mdot
.722 .37554 Mdot
.722 .37629 Mdot
.722 .37635 Mdot
.722 .37804 Mdot
.722 .37807 Mdot
.722 .37825 Mdot
.722 .37866 Mdot
.722 .37946 Mdot
.722 .38227 Mdot
.722 .38227 Mdot
.722 .38393 Mdot
.722 .38677 Mdot
.722 .38792 Mdot
.722 .3888 Mdot
.722 .38951 Mdot
.722 .38966 Mdot
.722 .38973 Mdot
.722 .38983 Mdot
.722 .38988 Mdot
.722 .39068 Mdot
.722 .39111 Mdot
.722 .39115 Mdot
.722 .39332 Mdot
.722 .39339 Mdot
.722 .39397 Mdot
.722 .39401 Mdot
.722 .3941 Mdot
.722 .39623 Mdot
.722 .39644 Mdot
.722 .39667 Mdot
.722 .39748 Mdot
.722 .39749 Mdot
.722 .39815 Mdot
.722 .39859 Mdot
.722 .39949 Mdot
.722 .39975 Mdot
.722 .40174 Mdot
.722 .40209 Mdot
.722 .4021 Mdot
.722 .40257 Mdot
.722 .4031 Mdot
.722 .4032 Mdot
.722 .40362 Mdot
.722 .40469 Mdot
.722 .40494 Mdot
.722 .40627 Mdot
.722 .40703 Mdot
.722 .40803 Mdot
.722 .40884 Mdot
.722 .4105 Mdot
.722 .41186 Mdot
.722 .41238 Mdot
.722 .41334 Mdot
.722 .41338 Mdot
.722 .41341 Mdot
.722 .41521 Mdot
.722 .41545 Mdot
.722 .41693 Mdot
.722 .41746 Mdot
.722 .41777 Mdot
.722 .41822 Mdot
.722 .42003 Mdot
.722 .42021 Mdot
.722 .42191 Mdot
.722 .42368 Mdot
.722 .42369 Mdot
.722 .42436 Mdot
.722 .42446 Mdot
.722 .42468 Mdot
.722 .42579 Mdot
.722 .42632 Mdot
.722 .42663 Mdot
.722 .42843 Mdot
.722 .4288 Mdot
.722 .43154 Mdot
.722 .43247 Mdot
.722 .43396 Mdot
.722 .43487 Mdot
.722 .43495 Mdot
.722 .43752 Mdot
.722 .43827 Mdot
.722 .43921 Mdot
.722 .43939 Mdot
.722 .43956 Mdot
.722 .44069 Mdot
.724 .01482 Mdot
.724 .01487 Mdot
.724 .01494 Mdot
.724 .01505 Mdot
.724 .0152 Mdot
.724 .01541 Mdot
.724 .01572 Mdot
.724 .01618 Mdot
.724 .01683 Mdot
.724 .01685 Mdot
.724 .01693 Mdot
.724 .01732 Mdot
.724 .01778 Mdot
.724 .01781 Mdot
.724 .01793 Mdot
.724 .01849 Mdot
.724 .01915 Mdot
.724 .0192 Mdot
.724 .01937 Mdot
.724 .01942 Mdot
.724 .02008 Mdot
.724 .02018 Mdot
.724 .02114 Mdot
.724 .02121 Mdot
.724 .02127 Mdot
.724 .02145 Mdot
.724 .02152 Mdot
.724 .02162 Mdot
.724 .02248 Mdot
.724 .02263 Mdot
.724 .02307 Mdot
.724 .02363 Mdot
.724 .02386 Mdot
.724 .02389 Mdot
.724 .02401 Mdot
.724 .02411 Mdot
.724 .02421 Mdot
.724 .02447 Mdot
.724 .02457 Mdot
.724 .02458 Mdot
.724 .02471 Mdot
.724 .02498 Mdot
.724 .02507 Mdot
.724 .02596 Mdot
.724 .02618 Mdot
.724 .02681 Mdot
.724 .02762 Mdot
.724 .02796 Mdot
.724 .02799 Mdot
.724 .02818 Mdot
.724 .02833 Mdot
.724 .02842 Mdot
.724 .02846 Mdot
.724 .02884 Mdot
.724 .02899 Mdot
.724 .029 Mdot
.724 .02919 Mdot
.724 .02955 Mdot
.724 .02959 Mdot
.724 .02971 Mdot
.724 .03002 Mdot
.724 .031 Mdot
.724 .03122 Mdot
.724 .03131 Mdot
.724 .03221 Mdot
.724 .03222 Mdot
.724 .03223 Mdot
.724 .03272 Mdot
.724 .0334 Mdot
.724 .03368 Mdot
.724 .03389 Mdot
.724 .03394 Mdot
.724 .03421 Mdot
.724 .03442 Mdot
.724 .03448 Mdot
.724 .03455 Mdot
.724 .03461 Mdot
.724 .03517 Mdot
.724 .03539 Mdot
.724 .03539 Mdot
.724 .03557 Mdot
.724 .03568 Mdot
.724 .03588 Mdot
.724 .03619 Mdot
.724 .03625 Mdot
.724 .0363 Mdot
.724 .03643 Mdot
.724 .03687 Mdot
.724 .03772 Mdot
.724 .03799 Mdot
.724 .0383 Mdot
.724 .03861 Mdot
.724 .03874 Mdot
.724 .04005 Mdot
.724 .04006 Mdot
.724 .04008 Mdot
.724 .04079 Mdot
.724 .04177 Mdot
.724 .04197 Mdot
.724 .04218 Mdot
.724 .04229 Mdot
.724 .04248 Mdot
.724 .04256 Mdot
.724 .04294 Mdot
.724 .04311 Mdot
.724 .04325 Mdot
.724 .04334 Mdot
.724 .04344 Mdot
.724 .04353 Mdot
.724 .04364 Mdot
.724 .04378 Mdot
.724 .04414 Mdot
.724 .0442 Mdot
.724 .04433 Mdot
.724 .04465 Mdot
.724 .04466 Mdot
.724 .04492 Mdot
.724 .04507 Mdot
.724 .04536 Mdot
.724 .04582 Mdot
.724 .04589 Mdot
.724 .04597 Mdot
.724 .04615 Mdot
.724 .04672 Mdot
.724 .0468 Mdot
.724 .04715 Mdot
.724 .04748 Mdot
.724 .04782 Mdot
.724 .04803 Mdot
.724 .04838 Mdot
.724 .04841 Mdot
.724 .04886 Mdot
.724 .04932 Mdot
.724 .04951 Mdot
.724 .04964 Mdot
.724 .05006 Mdot
.724 .05033 Mdot
.724 .05096 Mdot
.724 .0514 Mdot
.724 .05142 Mdot
.724 .05144 Mdot
.724 .05195 Mdot
.724 .05247 Mdot
.724 .05269 Mdot
.724 .05355 Mdot
.724 .05362 Mdot
.724 .05389 Mdot
.724 .05418 Mdot
.724 .05449 Mdot
.724 .05464 Mdot
.724 .05491 Mdot
.724 .05503 Mdot
.724 .05558 Mdot
.724 .05583 Mdot
.724 .05604 Mdot
.724 .05616 Mdot
.724 .05631 Mdot
.724 .05644 Mdot
.724 .0566 Mdot
.724 .0568 Mdot
.724 .0572 Mdot
.724 .05732 Mdot
.724 .05741 Mdot
.724 .0576 Mdot
.724 .05806 Mdot
.724 .05807 Mdot
.724 .05832 Mdot
.724 .05845 Mdot
.724 .05853 Mdot
.724 .05867 Mdot
.724 .05875 Mdot
.724 .05909 Mdot
.724 .05975 Mdot
.724 .05986 Mdot
.724 .05997 Mdot
.724 .06024 Mdot
.724 .06106 Mdot
.724 .06118 Mdot
.724 .06167 Mdot
.724 .06188 Mdot
.724 .06213 Mdot
.724 .06216 Mdot
.724 .06265 Mdot
.724 .06277 Mdot
.724 .06295 Mdot
.724 .06306 Mdot
.724 .06346 Mdot
.724 .06351 Mdot
.724 .06416 Mdot
.724 .06436 Mdot
.724 .06482 Mdot
.724 .0651 Mdot
.724 .06528 Mdot
.724 .06589 Mdot
.724 .06628 Mdot
.724 .0672 Mdot
.724 .06766 Mdot
.724 .06784 Mdot
.724 .06786 Mdot
.724 .0679 Mdot
.724 .0686 Mdot
.724 .06864 Mdot
.724 .06912 Mdot
.724 .06939 Mdot
.724 .0697 Mdot
.724 .06995 Mdot
.724 .07037 Mdot
.724 .07095 Mdot
.724 .07104 Mdot
.724 .07114 Mdot
.724 .07144 Mdot
.724 .07179 Mdot
.724 .07186 Mdot
.724 .0723 Mdot
.724 .07253 Mdot
.724 .07292 Mdot
.724 .07309 Mdot
.724 .07389 Mdot
.724 .07425 Mdot
.724 .07455 Mdot
.724 .07461 Mdot
.724 .07473 Mdot
.724 .07494 Mdot
.724 .07513 Mdot
.724 .07536 Mdot
.724 .07565 Mdot
.724 .07624 Mdot
.724 .07625 Mdot
.724 .07641 Mdot
.724 .07643 Mdot
.724 .07654 Mdot
.724 .07679 Mdot
.724 .07682 Mdot
.724 .07748 Mdot
.724 .0775 Mdot
.724 .07752 Mdot
.724 .07785 Mdot
.724 .07804 Mdot
.724 .07816 Mdot
.724 .07836 Mdot
.724 .07848 Mdot
.724 .07897 Mdot
.724 .07992 Mdot
.724 .08009 Mdot
.724 .08023 Mdot
.724 .08025 Mdot
.724 .08063 Mdot
.724 .08182 Mdot
.724 .08199 Mdot
.724 .08271 Mdot
.724 .083 Mdot
.724 .08329 Mdot
.724 .08337 Mdot
.724 .08341 Mdot
.724 .08359 Mdot
.724 .08413 Mdot
.724 .0843 Mdot
.724 .08457 Mdot
.724 .08472 Mdot
.724 .0848 Mdot
.724 .0853 Mdot
.724 .08536 Mdot
.724 .08631 Mdot
.724 .08661 Mdot
.724 .08726 Mdot
.724 .08753 Mdot
.724 .08767 Mdot
.724 .08794 Mdot
.724 .08809 Mdot
.724 .08865 Mdot
.724 .08882 Mdot
.724 .08938 Mdot
.724 .09052 Mdot
.724 .09072 Mdot
.724 .09138 Mdot
.724 .09164 Mdot
.724 .09167 Mdot
.724 .09173 Mdot
.724 .09275 Mdot
.724 .09279 Mdot
.724 .09341 Mdot
.724 .0935 Mdot
.724 .09388 Mdot
.724 .09434 Mdot
.724 .09469 Mdot
.724 .09565 Mdot
.724 .09614 Mdot
.724 .09628 Mdot
.724 .09642 Mdot
.724 .09685 Mdot
.724 .09737 Mdot
.724 .09747 Mdot
.724 .0981 Mdot
.724 .09843 Mdot
.724 .09884 Mdot
.724 .099 Mdot
.724 .09925 Mdot
.724 .09931 Mdot
.724 .1004 Mdot
.724 .10092 Mdot
.724 .10135 Mdot
.724 .10144 Mdot
.724 .10161 Mdot
.724 .10178 Mdot
.724 .10193 Mdot
.724 .10219 Mdot
.724 .10226 Mdot
.724 .10254 Mdot
.724 .10295 Mdot
.724 .1038 Mdot
.724 .10381 Mdot
.724 .10405 Mdot
.724 .10409 Mdot
.724 .10424 Mdot
.724 .1046 Mdot
.724 .10464 Mdot
.724 .10492 Mdot
.724 .1056 Mdot
.724 .10562 Mdot
.724 .10565 Mdot
.724 .10578 Mdot
.724 .10614 Mdot
.724 .10641 Mdot
.724 .10658 Mdot
.724 .1067 Mdot
.724 .10687 Mdot
.724 .10705 Mdot
.724 .10775 Mdot
.724 .10914 Mdot
.724 .10937 Mdot
.724 .10944 Mdot
.724 .10959 Mdot
.724 .10961 Mdot
.724 .11016 Mdot
.724 .11154 Mdot
.724 .11189 Mdot
.724 .11213 Mdot
.724 .11259 Mdot
.724 .1127 Mdot
.724 .11318 Mdot
.724 .11333 Mdot
.724 .1136 Mdot
.724 .11401 Mdot
.724 .11413 Mdot
.724 .11419 Mdot
.724 .11444 Mdot
.724 .11522 Mdot
.724 .11548 Mdot
.724 .11586 Mdot
.724 .11609 Mdot
.724 .11609 Mdot
.724 .1162 Mdot
.724 .11685 Mdot
.724 .11692 Mdot
.724 .11702 Mdot
.724 .11734 Mdot
.724 .1174 Mdot
.724 .11838 Mdot
.724 .11881 Mdot
.724 .11948 Mdot
.724 .11976 Mdot
.724 .12005 Mdot
.724 .12015 Mdot
.724 .12021 Mdot
.724 .12035 Mdot
.724 .12058 Mdot
.724 .12074 Mdot
.724 .12095 Mdot
.724 .12177 Mdot
.724 .12202 Mdot
.724 .12207 Mdot
.724 .12283 Mdot
.724 .12304 Mdot
.724 .1231 Mdot
.724 .12448 Mdot
.724 .12467 Mdot
.724 .12477 Mdot
.724 .12509 Mdot
.724 .12573 Mdot
.724 .1261 Mdot
.724 .12615 Mdot
.724 .12623 Mdot
.724 .1277 Mdot
.724 .12777 Mdot
.724 .12867 Mdot
.724 .1288 Mdot
.724 .12892 Mdot
.724 .12935 Mdot
.724 .13001 Mdot
.724 .13052 Mdot
.724 .13124 Mdot
.724 .13135 Mdot
.724 .13191 Mdot
.724 .13202 Mdot
.724 .13262 Mdot
.724 .13282 Mdot
.724 .13303 Mdot
.724 .13365 Mdot
.724 .13437 Mdot
.724 .13439 Mdot
.724 .13454 Mdot
.724 .13534 Mdot
.724 .13546 Mdot
.724 .13594 Mdot
.724 .13607 Mdot
.724 .13653 Mdot
.724 .13676 Mdot
.724 .13712 Mdot
.724 .13721 Mdot
.724 .13808 Mdot
.724 .13861 Mdot
.724 .13879 Mdot
.724 .13932 Mdot
.724 .13954 Mdot
.724 .13971 Mdot
.724 .14017 Mdot
.724 .14029 Mdot
.724 .14045 Mdot
.724 .14054 Mdot
.724 .14071 Mdot
.724 .14077 Mdot
.724 .14078 Mdot
.724 .14078 Mdot
.724 .141 Mdot
.724 .1412 Mdot
.724 .14138 Mdot
.724 .14148 Mdot
.724 .14173 Mdot
.724 .14188 Mdot
.724 .14212 Mdot
.724 .14247 Mdot
.724 .14263 Mdot
.724 .1434 Mdot
.724 .14371 Mdot
.724 .14373 Mdot
.724 .14385 Mdot
.724 .14407 Mdot
.724 .14412 Mdot
.724 .14435 Mdot
.724 .14487 Mdot
.724 .14492 Mdot
.724 .14496 Mdot
.724 .14533 Mdot
.724 .14561 Mdot
.724 .14631 Mdot
.724 .14635 Mdot
.724 .14639 Mdot
.724 .14658 Mdot
.724 .14666 Mdot
.724 .14709 Mdot
.724 .14748 Mdot
.724 .14774 Mdot
.724 .1479 Mdot
.724 .14815 Mdot
.724 .14822 Mdot
.724 .14841 Mdot
.724 .14889 Mdot
.724 .14909 Mdot
.724 .14944 Mdot
.724 .15144 Mdot
.724 .15178 Mdot
.724 .15187 Mdot
.724 .15209 Mdot
.724 .15212 Mdot
.724 .1523 Mdot
.724 .15292 Mdot
.724 .15366 Mdot
.724 .15373 Mdot
.724 .15425 Mdot
.724 .15492 Mdot
.724 .15524 Mdot
.724 .15542 Mdot
.724 .15547 Mdot
.724 .15577 Mdot
.724 .15644 Mdot
.724 .15647 Mdot
.724 .1566 Mdot
.724 .15729 Mdot
.724 .1575 Mdot
.724 .1579 Mdot
.724 .15801 Mdot
.724 .15849 Mdot
.724 .15867 Mdot
.724 .15875 Mdot
.724 .15876 Mdot
.724 .15899 Mdot
.724 .15912 Mdot
.724 .15915 Mdot
.724 .16025 Mdot
.724 .16062 Mdot
.724 .16078 Mdot
.724 .16117 Mdot
.724 .1615 Mdot
.724 .1615 Mdot
.724 .16167 Mdot
.724 .16198 Mdot
.724 .16225 Mdot
.724 .16261 Mdot
.724 .16271 Mdot
.724 .16285 Mdot
.724 .16332 Mdot
.724 .1634 Mdot
.724 .16471 Mdot
.724 .16482 Mdot
.724 .16509 Mdot
.724 .16526 Mdot
.724 .16531 Mdot
.724 .16543 Mdot
.724 .16545 Mdot
.724 .16628 Mdot
.724 .16642 Mdot
.724 .16664 Mdot
.724 .16683 Mdot
.724 .16724 Mdot
.724 .16738 Mdot
.724 .16747 Mdot
.724 .16768 Mdot
.724 .168 Mdot
.724 .16824 Mdot
.724 .16853 Mdot
.724 .16855 Mdot
.724 .16973 Mdot
.724 .1701 Mdot
.724 .17017 Mdot
.724 .17024 Mdot
.724 .17127 Mdot
.724 .17135 Mdot
.724 .17157 Mdot
.724 .17166 Mdot
.724 .17209 Mdot
.724 .17318 Mdot
.724 .17349 Mdot
.724 .17366 Mdot
.724 .17393 Mdot
.724 .17407 Mdot
.724 .17432 Mdot
.724 .17454 Mdot
.724 .17546 Mdot
.724 .176 Mdot
.724 .17607 Mdot
.724 .17618 Mdot
.724 .17642 Mdot
.724 .17732 Mdot
.724 .17832 Mdot
.724 .17842 Mdot
.724 .17882 Mdot
.724 .17972 Mdot
.724 .1799 Mdot
.724 .18009 Mdot
.724 .18071 Mdot
.724 .18166 Mdot
.724 .1824 Mdot
.724 .18345 Mdot
.724 .1836 Mdot
.724 .18441 Mdot
.724 .18457 Mdot
.724 .18545 Mdot
.724 .18573 Mdot
.724 .18603 Mdot
.724 .18694 Mdot
.724 .18763 Mdot
.724 .18798 Mdot
.724 .18801 Mdot
.724 .18822 Mdot
.724 .18913 Mdot
.724 .18938 Mdot
.724 .18954 Mdot
.724 .18956 Mdot
.724 .19025 Mdot
.724 .19043 Mdot
.724 .19048 Mdot
.724 .19061 Mdot
.724 .1911 Mdot
.724 .19142 Mdot
.724 .19144 Mdot
.724 .19195 Mdot
.724 .19209 Mdot
.724 .19335 Mdot
.724 .19412 Mdot
.724 .19415 Mdot
.724 .19437 Mdot
.724 .19515 Mdot
.724 .19547 Mdot
.724 .19571 Mdot
.724 .19637 Mdot
.724 .19655 Mdot
.724 .19678 Mdot
.724 .19691 Mdot
.724 .19715 Mdot
.724 .19724 Mdot
.724 .19726 Mdot
.724 .19726 Mdot
.724 .1974 Mdot
.724 .19757 Mdot
.724 .1977 Mdot
.724 .19787 Mdot
.724 .19812 Mdot
.724 .19827 Mdot
.724 .19864 Mdot
.724 .19885 Mdot
.724 .1992 Mdot
.724 .19971 Mdot
.724 .19993 Mdot
.724 .2 Mdot
.724 .20105 Mdot
.724 .2015 Mdot
.724 .20153 Mdot
.724 .2017 Mdot
.724 .20202 Mdot
.724 .2021 Mdot
.724 .20243 Mdot
.724 .20294 Mdot
.724 .20318 Mdot
.724 .20326 Mdot
.724 .20331 Mdot
.724 .20385 Mdot
.724 .20424 Mdot
.724 .20433 Mdot
.724 .20514 Mdot
.724 .20527 Mdot
.724 .20532 Mdot
.724 .20534 Mdot
.724 .20538 Mdot
.724 .20566 Mdot
.724 .20578 Mdot
.724 .2064 Mdot
.724 .20696 Mdot
.724 .20733 Mdot
.724 .20757 Mdot
.724 .20793 Mdot
.724 .20803 Mdot
.724 .20831 Mdot
.724 .209 Mdot
.724 .20929 Mdot
.724 .20979 Mdot
.724 .21269 Mdot
.724 .21318 Mdot
.724 .21332 Mdot
.724 .21363 Mdot
.724 .21367 Mdot
.724 .21394 Mdot
.724 .21484 Mdot
.724 .21591 Mdot
.724 .21601 Mdot
.724 .21677 Mdot
.724 .21773 Mdot
.724 .21819 Mdot
.724 .21846 Mdot
.724 .21852 Mdot
.724 .21897 Mdot
.724 .21993 Mdot
.724 .21997 Mdot
.724 .22016 Mdot
.724 .22116 Mdot
.724 .22147 Mdot
.724 .22204 Mdot
.724 .22221 Mdot
.724 .2229 Mdot
.724 .22316 Mdot
.724 .22328 Mdot
.724 .22329 Mdot
.724 .22362 Mdot
.724 .22381 Mdot
.724 .22385 Mdot
.724 .22545 Mdot
.724 .22599 Mdot
.724 .22621 Mdot
.724 .22679 Mdot
.724 .22726 Mdot
.724 .22726 Mdot
.724 .2275 Mdot
.724 .22796 Mdot
.724 .22834 Mdot
.724 .22886 Mdot
.724 .22901 Mdot
.724 .22921 Mdot
.724 .22989 Mdot
.724 .23001 Mdot
.724 .23191 Mdot
.724 .23207 Mdot
.724 .23246 Mdot
.724 .23271 Mdot
.724 .23278 Mdot
.724 .23295 Mdot
.724 .23298 Mdot
.724 .23418 Mdot
.724 .23438 Mdot
.724 .2347 Mdot
.724 .23497 Mdot
.724 .23557 Mdot
.724 .23577 Mdot
.724 .2359 Mdot
.724 .2362 Mdot
.724 .23668 Mdot
.724 .23703 Mdot
.724 .23744 Mdot
.724 .23747 Mdot
.724 .23918 Mdot
.724 .23971 Mdot
.724 .23981 Mdot
.724 .23992 Mdot
.724 .24141 Mdot
.724 .24153 Mdot
.724 .24184 Mdot
.724 .24197 Mdot
.724 .24259 Mdot
.724 .24417 Mdot
.724 .24462 Mdot
.724 .24486 Mdot
.724 .24526 Mdot
.724 .24546 Mdot
.724 .24583 Mdot
.724 .24614 Mdot
.724 .24748 Mdot
.724 .24826 Mdot
.724 .24835 Mdot
.724 .24852 Mdot
.724 .24887 Mdot
.724 .25016 Mdot
.724 .25162 Mdot
.724 .25176 Mdot
.724 .25234 Mdot
.724 .25364 Mdot
.724 .25391 Mdot
.724 .25418 Mdot
.724 .25507 Mdot
.724 .25645 Mdot
.724 .25752 Mdot
.724 .25904 Mdot
.724 .25926 Mdot
.724 .26044 Mdot
.724 .26067 Mdot
.724 .26194 Mdot
.724 .26235 Mdot
.724 .26278 Mdot
.724 .26409 Mdot
.724 .2651 Mdot
.724 .2656 Mdot
.724 .26565 Mdot
.724 .26595 Mdot
.724 .26726 Mdot
.724 .26763 Mdot
.724 .26786 Mdot
.724 .26789 Mdot
.724 .26888 Mdot
.724 .26915 Mdot
.724 .26923 Mdot
.724 .2694 Mdot
.724 .27012 Mdot
.724 .27058 Mdot
.724 .27061 Mdot
.724 .27136 Mdot
.724 .27156 Mdot
.724 .27339 Mdot
.724 .27449 Mdot
.724 .27454 Mdot
.724 .27486 Mdot
.724 .27598 Mdot
.724 .27644 Mdot
.724 .27679 Mdot
.724 .27775 Mdot
.724 .27801 Mdot
.724 .27835 Mdot
.724 .27853 Mdot
.724 .27888 Mdot
.724 .27901 Mdot
.724 .27903 Mdot
.724 .27904 Mdot
.724 .27924 Mdot
.724 .27949 Mdot
.724 .27968 Mdot
.724 .27992 Mdot
.724 .28029 Mdot
.724 .2805 Mdot
.724 .28103 Mdot
.724 .28134 Mdot
.724 .28185 Mdot
.724 .28259 Mdot
.724 .28291 Mdot
.724 .283 Mdot
.724 .28453 Mdot
.724 .28518 Mdot
.724 .28522 Mdot
.724 .28547 Mdot
.724 .28594 Mdot
.724 .28604 Mdot
.724 .28652 Mdot
.724 .28726 Mdot
.724 .28761 Mdot
.724 .28772 Mdot
.724 .2878 Mdot
.724 .28858 Mdot
.724 .28915 Mdot
.724 .28928 Mdot
.724 .29046 Mdot
.724 .29063 Mdot
.724 .29072 Mdot
.724 .29074 Mdot
.724 .2908 Mdot
.724 .2912 Mdot
.724 .29137 Mdot
.724 .29227 Mdot
.724 .29309 Mdot
.724 .29362 Mdot
.724 .29397 Mdot
.724 .29449 Mdot
.724 .29464 Mdot
.724 .29504 Mdot
.724 .29604 Mdot
.724 .29647 Mdot
.724 .29718 Mdot
.724 .30138 Mdot
.724 .3021 Mdot
.724 .3023 Mdot
.724 .30275 Mdot
.724 .3028 Mdot
.724 .30319 Mdot
.724 .3045 Mdot
.724 .30604 Mdot
.724 .30619 Mdot
.724 .30728 Mdot
.724 .30868 Mdot
.724 .30935 Mdot
.724 .30974 Mdot
.724 .30983 Mdot
.724 .31047 Mdot
.724 .31187 Mdot
.724 .31193 Mdot
.724 .3122 Mdot
.724 .31364 Mdot
.724 .3141 Mdot
.724 .31492 Mdot
.724 .31516 Mdot
.724 .31617 Mdot
.724 .31655 Mdot
.724 .31671 Mdot
.724 .31673 Mdot
.724 .31721 Mdot
.724 .31749 Mdot
.724 .31755 Mdot
.724 .31986 Mdot
.724 .32064 Mdot
.724 .32096 Mdot
.724 .32179 Mdot
.724 .32248 Mdot
.724 .32249 Mdot
.724 .32283 Mdot
.724 .3235 Mdot
.724 .32405 Mdot
.724 .3248 Mdot
.724 .32501 Mdot
.724 .3253 Mdot
.724 .32629 Mdot
.724 .32647 Mdot
.724 .32922 Mdot
.724 .32944 Mdot
.724 .33001 Mdot
.724 .33037 Mdot
.724 .33047 Mdot
.724 .33072 Mdot
.724 .33076 Mdot
.724 .3325 Mdot
.724 .33279 Mdot
.724 .33326 Mdot
.724 .33364 Mdot
.724 .33451 Mdot
.724 .33481 Mdot
.724 .33499 Mdot
.724 .33543 Mdot
.724 .33611 Mdot
.724 .33662 Mdot
.724 .33722 Mdot
.724 .33726 Mdot
.724 .33974 Mdot
.724 .34051 Mdot
.724 .34065 Mdot
.724 .34081 Mdot
.724 .34297 Mdot
.724 .34314 Mdot
.724 .34359 Mdot
.724 .34379 Mdot
.724 .34468 Mdot
.724 .34696 Mdot
.724 .34761 Mdot
.724 .34797 Mdot
.724 .34854 Mdot
.724 .34883 Mdot
.724 .34937 Mdot
.724 .34982 Mdot
.724 .35176 Mdot
.724 .35289 Mdot
.724 .35302 Mdot
.724 .35327 Mdot
.724 .35377 Mdot
.724 .35564 Mdot
.724 .35775 Mdot
.724 .35796 Mdot
.724 .3588 Mdot
.724 .36068 Mdot
.724 .36107 Mdot
.724 .36146 Mdot
.724 .36275 Mdot
.724 .36474 Mdot
.724 .36629 Mdot
.724 .36849 Mdot
.724 .36882 Mdot
.724 .37052 Mdot
.724 .37086 Mdot
.724 .37269 Mdot
.724 .37329 Mdot
.724 .37392 Mdot
.724 .37581 Mdot
.724 .37727 Mdot
.724 .37799 Mdot
.724 .37806 Mdot
.724 .3785 Mdot
.724 .3804 Mdot
.724 .38093 Mdot
.724 .38127 Mdot
.724 .38131 Mdot
.724 .38275 Mdot
.724 .38314 Mdot
.724 .38325 Mdot
.724 .3835 Mdot
.724 .38454 Mdot
.724 .3852 Mdot
.724 .38525 Mdot
.724 .38633 Mdot
.724 .38662 Mdot
.724 .38927 Mdot
.724 .39087 Mdot
.724 .39094 Mdot
.724 .39141 Mdot
.724 .39303 Mdot
.724 .3937 Mdot
.724 .3942 Mdot
.724 .3956 Mdot
.724 .39596 Mdot
.724 .39645 Mdot
.724 .39672 Mdot
.724 .39723 Mdot
.724 .39741 Mdot
.724 .39745 Mdot
.724 .39746 Mdot
.724 .39775 Mdot
.724 .39812 Mdot
.724 .39838 Mdot
.724 .39873 Mdot
.724 .39927 Mdot
.724 .39958 Mdot
.724 .40034 Mdot
.724 .40079 Mdot
.724 .40152 Mdot
.724 .4026 Mdot
.724 .40306 Mdot
.724 .4032 Mdot
.724 .40541 Mdot
.724 .40635 Mdot
.724 .4064 Mdot
.724 .40676 Mdot
.724 .40744 Mdot
.724 .4076 Mdot
.724 .40829 Mdot
.724 .40936 Mdot
.724 .40987 Mdot
.724 .41003 Mdot
.724 .41014 Mdot
.724 .41127 Mdot
.724 .4121 Mdot
.724 .41228 Mdot
.724 .41399 Mdot
.724 .41425 Mdot
.724 .41437 Mdot
.724 .4144 Mdot
.724 .41448 Mdot
.724 .41507 Mdot
.724 .41532 Mdot
.724 .41662 Mdot
.724 .4178 Mdot
.724 .41857 Mdot
.724 .41908 Mdot
.724 .41983 Mdot
.724 .42005 Mdot
.724 .42062 Mdot
.724 .42207 Mdot
.724 .42269 Mdot
.724 .42373 Mdot
.724 .42981 Mdot
.724 .43085 Mdot
.724 .43113 Mdot
.724 .43178 Mdot
.724 .43187 Mdot
.724 .43243 Mdot
.724 .43432 Mdot
.724 .43656 Mdot
.724 .43677 Mdot
.724 .43835 Mdot
.724 .44038 Mdot
.724 .44135 Mdot
.724 .44191 Mdot
.724 .44204 Mdot
.726 .01514 Mdot
.726 .01533 Mdot
.726 .01552 Mdot
.726 .01561 Mdot
.726 .01582 Mdot
.726 .01589 Mdot
.726 .01595 Mdot
.726 .01601 Mdot
.726 .01604 Mdot
.726 .01631 Mdot
.726 .01642 Mdot
.726 .01651 Mdot
.726 .0166 Mdot
.726 .0166 Mdot
.726 .01664 Mdot
.726 .01677 Mdot
.726 .01704 Mdot
.726 .01709 Mdot
.726 .01718 Mdot
.726 .01732 Mdot
.726 .01745 Mdot
.726 .01745 Mdot
.726 .01752 Mdot
.726 .0177 Mdot
.726 .01808 Mdot
.726 .01809 Mdot
.726 .01816 Mdot
.726 .0183 Mdot
.726 .0185 Mdot
.726 .01868 Mdot
.726 .01869 Mdot
.726 .01878 Mdot
.726 .01905 Mdot
.726 .0196 Mdot
.726 .01961 Mdot
.726 .01972 Mdot
.726 .01992 Mdot
.726 .02006 Mdot
.726 .02021 Mdot
.726 .02048 Mdot
.726 .02049 Mdot
.726 .02062 Mdot
.726 .02101 Mdot
.726 .02181 Mdot
.726 .02182 Mdot
.726 .02198 Mdot
.726 .02217 Mdot
.726 .02227 Mdot
.726 .02247 Mdot
.726 .0227 Mdot
.726 .02308 Mdot
.726 .0231 Mdot
.726 .02329 Mdot
.726 .0247 Mdot
.726 .02502 Mdot
.726 .02503 Mdot
.726 .02526 Mdot
.726 .02555 Mdot
.726 .02569 Mdot
.726 .02598 Mdot
.726 .02631 Mdot
.726 .02686 Mdot
.726 .02689 Mdot
.726 .02716 Mdot
.726 .02921 Mdot
.726 .02962 Mdot
.726 .02968 Mdot
.726 .0297 Mdot
.726 .02972 Mdot
.726 .03003 Mdot
.726 .03044 Mdot
.726 .03064 Mdot
.726 .03065 Mdot
.726 .03107 Mdot
.726 .03155 Mdot
.726 .03173 Mdot
.726 .03188 Mdot
.726 .03236 Mdot
.726 .03239 Mdot
.726 .03279 Mdot
.726 .03476 Mdot
.726 .03576 Mdot
.726 .03608 Mdot
.726 .03635 Mdot
.726 .03644 Mdot
.726 .03647 Mdot
.726 .03651 Mdot
.726 .03651 Mdot
.726 .03695 Mdot
.726 .03755 Mdot
.726 .03784 Mdot
.726 .03785 Mdot
.726 .03787 Mdot
.726 .03847 Mdot
.726 .03915 Mdot
.726 .03942 Mdot
.726 .03952 Mdot
.726 .03963 Mdot
.726 .03993 Mdot
.726 .04033 Mdot
.726 .04038 Mdot
.726 .04096 Mdot
.726 .04237 Mdot
.726 .04243 Mdot
.726 .04282 Mdot
.726 .04383 Mdot
.726 .04528 Mdot
.726 .04541 Mdot
.726 .04543 Mdot
.726 .04549 Mdot
.726 .04573 Mdot
.726 .04613 Mdot
.726 .04626 Mdot
.726 .0463 Mdot
.726 .04636 Mdot
.726 .04636 Mdot
.726 .047 Mdot
.726 .04736 Mdot
.726 .04787 Mdot
.726 .04797 Mdot
.726 .0483 Mdot
.726 .0483 Mdot
.726 .04833 Mdot
.726 .04871 Mdot
.726 .04921 Mdot
.726 .04995 Mdot
.726 .0502 Mdot
.726 .05059 Mdot
.726 .05073 Mdot
.726 .0509 Mdot
.726 .05119 Mdot
.726 .05133 Mdot
.726 .05144 Mdot
.726 .05188 Mdot
.726 .05191 Mdot
.726 .05199 Mdot
.726 .05282 Mdot
.726 .05471 Mdot
.726 .05487 Mdot
.726 .05496 Mdot
.726 .05516 Mdot
.726 .05536 Mdot
.726 .05553 Mdot
.726 .05602 Mdot
.726 .0564 Mdot
.726 .05699 Mdot
.726 .05909 Mdot
.726 .05928 Mdot
.726 .05931 Mdot
.726 .05932 Mdot
.726 .0594 Mdot
.726 .05975 Mdot
.726 .05996 Mdot
.726 .06033 Mdot
.726 .06052 Mdot
.726 .06057 Mdot
.726 .06061 Mdot
.726 .06066 Mdot
.726 .06067 Mdot
.726 .06078 Mdot
.726 .06159 Mdot
.726 .06212 Mdot
.726 .06285 Mdot
.726 .063 Mdot
.726 .06348 Mdot
.726 .06349 Mdot
.726 .06353 Mdot
.726 .06408 Mdot
.726 .06442 Mdot
.726 .0648 Mdot
.726 .06487 Mdot
.726 .06588 Mdot
.726 .06624 Mdot
.726 .0668 Mdot
.726 .067 Mdot
.726 .06718 Mdot
.726 .06725 Mdot
.726 .06768 Mdot
.726 .06775 Mdot
.726 .06787 Mdot
.726 .06804 Mdot
.726 .06821 Mdot
.726 .06853 Mdot
.726 .06868 Mdot
.726 .06872 Mdot
.726 .06883 Mdot
.726 .06923 Mdot
.726 .06949 Mdot
.726 .07004 Mdot
.726 .07279 Mdot
.726 .07302 Mdot
.726 .07315 Mdot
.726 .07344 Mdot
.726 .07348 Mdot
.726 .07373 Mdot
.726 .07378 Mdot
.726 .07398 Mdot
.726 .0747 Mdot
.726 .07486 Mdot
.726 .07524 Mdot
.726 .07538 Mdot
.726 .07539 Mdot
.726 .07605 Mdot
.726 .07609 Mdot
.726 .07705 Mdot
.726 .07732 Mdot
.726 .07763 Mdot
.726 .07771 Mdot
.726 .07806 Mdot
.726 .07837 Mdot
.726 .07845 Mdot
.726 .07864 Mdot
.726 .07915 Mdot
.726 .07942 Mdot
.726 .07946 Mdot
.726 .07948 Mdot
.726 .0796 Mdot
.726 .08011 Mdot
.726 .0804 Mdot
.726 .08066 Mdot
.726 .08095 Mdot
.726 .08099 Mdot
.726 .08122 Mdot
.726 .0813 Mdot
.726 .08136 Mdot
.726 .08143 Mdot
.726 .08144 Mdot
.726 .0816 Mdot
.726 .08176 Mdot
.726 .08239 Mdot
.726 .08278 Mdot
.726 .08354 Mdot
.726 .08356 Mdot
.726 .08455 Mdot
.726 .08461 Mdot
.726 .08482 Mdot
.726 .08514 Mdot
.726 .08552 Mdot
.726 .08553 Mdot
.726 .08559 Mdot
.726 .08599 Mdot
.726 .08629 Mdot
.726 .08639 Mdot
.726 .0867 Mdot
.726 .08689 Mdot
.726 .08743 Mdot
.726 .08753 Mdot
.726 .08764 Mdot
.726 .08825 Mdot
.726 .08835 Mdot
.726 .08837 Mdot
.726 .08901 Mdot
.726 .08952 Mdot
.726 .08968 Mdot
.726 .09034 Mdot
.726 .09064 Mdot
.726 .09089 Mdot
.726 .091 Mdot
.726 .09114 Mdot
.726 .09145 Mdot
.726 .0915 Mdot
.726 .09162 Mdot
.726 .09172 Mdot
.726 .0919 Mdot
.726 .09215 Mdot
.726 .09239 Mdot
.726 .09253 Mdot
.726 .09285 Mdot
.726 .09308 Mdot
.726 .09313 Mdot
.726 .09329 Mdot
.726 .09356 Mdot
.726 .09387 Mdot
.726 .09425 Mdot
.726 .09426 Mdot
.726 .09504 Mdot
.726 .09624 Mdot
.726 .09627 Mdot
.726 .09727 Mdot
.726 .09838 Mdot
.726 .09842 Mdot
.726 .0987 Mdot
.726 .09877 Mdot
.726 .09904 Mdot
.726 .09937 Mdot
.726 .09957 Mdot
.726 .09961 Mdot
.726 .09999 Mdot
.726 .10004 Mdot
.726 .1004 Mdot
.726 .10047 Mdot
.726 .10076 Mdot
.726 .10181 Mdot
.726 .10204 Mdot
.726 .1026 Mdot
.726 .1028 Mdot
.726 .10281 Mdot
.726 .10377 Mdot
.726 .10383 Mdot
.726 .10383 Mdot
.726 .10501 Mdot
.726 .10522 Mdot
.726 .10562 Mdot
.726 .10574 Mdot
.726 .10607 Mdot
.726 .10619 Mdot
.726 .10669 Mdot
.726 .10714 Mdot
.726 .10726 Mdot
.726 .10754 Mdot
.726 .10827 Mdot
.726 .10858 Mdot
.726 .10867 Mdot
.726 .10873 Mdot
.726 .10875 Mdot
.726 .10892 Mdot
.726 .10967 Mdot
.726 .1101 Mdot
.726 .11047 Mdot
.726 .11089 Mdot
.726 .11094 Mdot
.726 .11122 Mdot
.726 .11128 Mdot
.726 .1114 Mdot
.726 .11148 Mdot
.726 .11155 Mdot
.726 .11158 Mdot
.726 .1116 Mdot
.726 .11177 Mdot
.726 .11184 Mdot
.726 .11206 Mdot
.726 .11251 Mdot
.726 .11298 Mdot
.726 .11355 Mdot
.726 .11466 Mdot
.726 .11468 Mdot
.726 .11581 Mdot
.726 .11611 Mdot
.726 .11621 Mdot
.726 .11651 Mdot
.726 .11698 Mdot
.726 .11752 Mdot
.726 .11754 Mdot
.726 .11763 Mdot
.726 .11821 Mdot
.726 .11823 Mdot
.726 .11865 Mdot
.726 .11878 Mdot
.726 .11923 Mdot
.726 .11951 Mdot
.726 .11957 Mdot
.726 .1203 Mdot
.726 .12045 Mdot
.726 .1206 Mdot
.726 .12068 Mdot
.726 .12148 Mdot
.726 .12163 Mdot
.726 .12167 Mdot
.726 .12259 Mdot
.726 .12334 Mdot
.726 .12341 Mdot
.726 .12357 Mdot
.726 .12452 Mdot
.726 .12495 Mdot
.726 .12495 Mdot
.726 .12533 Mdot
.726 .12539 Mdot
.726 .12548 Mdot
.726 .12555 Mdot
.726 .12564 Mdot
.726 .12568 Mdot
.726 .12614 Mdot
.726 .12621 Mdot
.726 .12639 Mdot
.726 .12653 Mdot
.726 .12679 Mdot
.726 .12715 Mdot
.726 .12734 Mdot
.726 .12741 Mdot
.726 .1275 Mdot
.726 .12771 Mdot
.726 .12787 Mdot
.726 .12817 Mdot
.726 .1285 Mdot
.726 .12857 Mdot
.726 .12858 Mdot
.726 .12881 Mdot
.726 .12904 Mdot
.726 .1292 Mdot
.726 .12964 Mdot
.726 .12965 Mdot
.726 .13014 Mdot
.726 .1302 Mdot
.726 .13021 Mdot
.726 .13135 Mdot
.726 .13178 Mdot
.726 .13242 Mdot
.726 .13301 Mdot
.726 .13309 Mdot
.726 .13314 Mdot
.726 .1333 Mdot
.726 .13459 Mdot
.726 .13514 Mdot
.726 .13576 Mdot
.726 .1361 Mdot
.726 .1362 Mdot
.726 .13626 Mdot
.726 .13666 Mdot
.726 .13676 Mdot
.726 .13716 Mdot
.726 .13727 Mdot
.726 .13764 Mdot
.726 .13792 Mdot
.726 .13798 Mdot
.726 .1384 Mdot
.726 .13853 Mdot
.726 .13861 Mdot
.726 .13887 Mdot
.726 .13913 Mdot
.726 .13924 Mdot
.726 .13966 Mdot
.726 .14075 Mdot
.726 .14117 Mdot
.726 .14151 Mdot
.726 .14232 Mdot
.726 .14262 Mdot
.726 .14263 Mdot
.726 .14403 Mdot
.726 .14411 Mdot
.726 .14412 Mdot
.726 .14559 Mdot
.726 .14583 Mdot
.726 .14613 Mdot
.726 .14671 Mdot
.726 .14688 Mdot
.726 .1472 Mdot
.726 .14727 Mdot
.726 .14736 Mdot
.726 .14748 Mdot
.726 .14753 Mdot
.726 .14827 Mdot
.726 .14892 Mdot
.726 .149 Mdot
.726 .14909 Mdot
.726 .14949 Mdot
.726 .15056 Mdot
.726 .151 Mdot
.726 .15113 Mdot
.726 .15122 Mdot
.726 .15126 Mdot
.726 .15151 Mdot
.726 .15259 Mdot
.726 .1526 Mdot
.726 .15321 Mdot
.726 .15376 Mdot
.726 .1539 Mdot
.726 .15398 Mdot
.726 .15436 Mdot
.726 .15443 Mdot
.726 .15484 Mdot
.726 .15493 Mdot
.726 .1551 Mdot
.726 .15522 Mdot
.726 .15532 Mdot
.726 .15537 Mdot
.726 .15539 Mdot
.726 .15558 Mdot
.726 .15563 Mdot
.726 .15574 Mdot
.726 .15606 Mdot
.726 .15671 Mdot
.726 .1574 Mdot
.726 .15822 Mdot
.726 .15983 Mdot
.726 .15986 Mdot
.726 .16016 Mdot
.726 .16052 Mdot
.726 .16057 Mdot
.726 .16151 Mdot
.726 .16194 Mdot
.726 .16208 Mdot
.726 .16252 Mdot
.726 .16306 Mdot
.726 .1632 Mdot
.726 .16399 Mdot
.726 .16402 Mdot
.726 .16414 Mdot
.726 .16499 Mdot
.726 .16499 Mdot
.726 .16501 Mdot
.726 .16563 Mdot
.726 .16582 Mdot
.726 .16607 Mdot
.726 .16647 Mdot
.726 .16688 Mdot
.726 .16696 Mdot
.726 .1671 Mdot
.726 .16803 Mdot
.726 .16817 Mdot
.726 .16824 Mdot
.726 .16846 Mdot
.726 .16858 Mdot
.726 .16953 Mdot
.726 .16974 Mdot
.726 .16995 Mdot
.726 .17001 Mdot
.726 .1712 Mdot
.726 .17134 Mdot
.726 .1721 Mdot
.726 .17229 Mdot
.726 .17244 Mdot
.726 .17254 Mdot
.726 .17277 Mdot
.726 .17285 Mdot
.726 .17416 Mdot
.726 .17425 Mdot
.726 .17461 Mdot
.726 .17478 Mdot
.726 .17478 Mdot
.726 .175 Mdot
.726 .17532 Mdot
.726 .17541 Mdot
.726 .17551 Mdot
.726 .17554 Mdot
.726 .17565 Mdot
.726 .17576 Mdot
.726 .17578 Mdot
.726 .17584 Mdot
.726 .1765 Mdot
.726 .17661 Mdot
.726 .17686 Mdot
.726 .17707 Mdot
.726 .17745 Mdot
.726 .17777 Mdot
.726 .17797 Mdot
.726 .17825 Mdot
.726 .17834 Mdot
.726 .17847 Mdot
.726 .17878 Mdot
.726 .17898 Mdot
.726 .17901 Mdot
.726 .17902 Mdot
.726 .17945 Mdot
.726 .17993 Mdot
.726 .18003 Mdot
.726 .18005 Mdot
.726 .18038 Mdot
.726 .18072 Mdot
.726 .18095 Mdot
.726 .18159 Mdot
.726 .1816 Mdot
.726 .18193 Mdot
.726 .18229 Mdot
.726 .18231 Mdot
.726 .18239 Mdot
.726 .18242 Mdot
.726 .18269 Mdot
.726 .18407 Mdot
.726 .18446 Mdot
.726 .18469 Mdot
.726 .18562 Mdot
.726 .18649 Mdot
.726 .18659 Mdot
.726 .18666 Mdot
.726 .18691 Mdot
.726 .18877 Mdot
.726 .18921 Mdot
.726 .18958 Mdot
.726 .19047 Mdot
.726 .19097 Mdot
.726 .19111 Mdot
.726 .19117 Mdot
.726 .1912 Mdot
.726 .19175 Mdot
.726 .19177 Mdot
.726 .19192 Mdot
.726 .19216 Mdot
.726 .19231 Mdot
.726 .1925 Mdot
.726 .19266 Mdot
.726 .1932 Mdot
.726 .19341 Mdot
.726 .1936 Mdot
.726 .1937 Mdot
.726 .1943 Mdot
.726 .1945 Mdot
.726 .19461 Mdot
.726 .195 Mdot
.726 .19536 Mdot
.726 .19552 Mdot
.726 .19613 Mdot
.726 .19771 Mdot
.726 .19824 Mdot
.726 .19826 Mdot
.726 .19833 Mdot
.726 .19883 Mdot
.726 .2 Mdot
.726 .20043 Mdot
.726 .20045 Mdot
.726 .20098 Mdot
.726 .20247 Mdot
.726 .20259 Mdot
.726 .20261 Mdot
.726 .20342 Mdot
.726 .20405 Mdot
.726 .2044 Mdot
.726 .20474 Mdot
.726 .20509 Mdot
.726 .20553 Mdot
.726 .20608 Mdot
.726 .20637 Mdot
.726 .20643 Mdot
.726 .20662 Mdot
.726 .20708 Mdot
.726 .20719 Mdot
.726 .20732 Mdot
.726 .20749 Mdot
.726 .20757 Mdot
.726 .20823 Mdot
.726 .20862 Mdot
.726 .20863 Mdot
.726 .20958 Mdot
.726 .2097 Mdot
.726 .20983 Mdot
.726 .21041 Mdot
.726 .21196 Mdot
.726 .2126 Mdot
.726 .21279 Mdot
.726 .21292 Mdot
.726 .21297 Mdot
.726 .21333 Mdot
.726 .21491 Mdot
.726 .21492 Mdot
.726 .21581 Mdot
.726 .2166 Mdot
.726 .21681 Mdot
.726 .21692 Mdot
.726 .21747 Mdot
.726 .21759 Mdot
.726 .21817 Mdot
.726 .2183 Mdot
.726 .21855 Mdot
.726 .21873 Mdot
.726 .21887 Mdot
.726 .21894 Mdot
.726 .21898 Mdot
.726 .21925 Mdot
.726 .21933 Mdot
.726 .21948 Mdot
.726 .21995 Mdot
.726 .22089 Mdot
.726 .22189 Mdot
.726 .22309 Mdot
.726 .22542 Mdot
.726 .22547 Mdot
.726 .22591 Mdot
.726 .22642 Mdot
.726 .22649 Mdot
.726 .22786 Mdot
.726 .22848 Mdot
.726 .22869 Mdot
.726 .22933 Mdot
.726 .23012 Mdot
.726 .23031 Mdot
.726 .23147 Mdot
.726 .2315 Mdot
.726 .23168 Mdot
.726 .23291 Mdot
.726 .23292 Mdot
.726 .23295 Mdot
.726 .23384 Mdot
.726 .23412 Mdot
.726 .23448 Mdot
.726 .23507 Mdot
.726 .23565 Mdot
.726 .23577 Mdot
.726 .23598 Mdot
.726 .23732 Mdot
.726 .23754 Mdot
.726 .23763 Mdot
.726 .23795 Mdot
.726 .23812 Mdot
.726 .23951 Mdot
.726 .23981 Mdot
.726 .24012 Mdot
.726 .2402 Mdot
.726 .24193 Mdot
.726 .24214 Mdot
.726 .24324 Mdot
.726 .24351 Mdot
.726 .24373 Mdot
.726 .24388 Mdot
.726 .24421 Mdot
.726 .24433 Mdot
.726 .24623 Mdot
.726 .24637 Mdot
.726 .24688 Mdot
.726 .24713 Mdot
.726 .24713 Mdot
.726 .24744 Mdot
.726 .24792 Mdot
.726 .24805 Mdot
.726 .24819 Mdot
.726 .24823 Mdot
.726 .2484 Mdot
.726 .24855 Mdot
.726 .24858 Mdot
.726 .24867 Mdot
.726 .24963 Mdot
.726 .24979 Mdot
.726 .25015 Mdot
.726 .25045 Mdot
.726 .25101 Mdot
.726 .25147 Mdot
.726 .25176 Mdot
.726 .25216 Mdot
.726 .2523 Mdot
.726 .25249 Mdot
.726 .25294 Mdot
.726 .25323 Mdot
.726 .25328 Mdot
.726 .25329 Mdot
.726 .25391 Mdot
.726 .2546 Mdot
.726 .25475 Mdot
.726 .25477 Mdot
.726 .25526 Mdot
.726 .25575 Mdot
.726 .25608 Mdot
.726 .25702 Mdot
.726 .25704 Mdot
.726 .25751 Mdot
.726 .25804 Mdot
.726 .25806 Mdot
.726 .25819 Mdot
.726 .25822 Mdot
.726 .25862 Mdot
.726 .26062 Mdot
.726 .26118 Mdot
.726 .26153 Mdot
.726 .26287 Mdot
.726 .26413 Mdot
.726 .26428 Mdot
.726 .26438 Mdot
.726 .26474 Mdot
.726 .26745 Mdot
.726 .26808 Mdot
.726 .26861 Mdot
.726 .26991 Mdot
.726 .27064 Mdot
.726 .27085 Mdot
.726 .27092 Mdot
.726 .27097 Mdot
.726 .27177 Mdot
.726 .2718 Mdot
.726 .27202 Mdot
.726 .27236 Mdot
.726 .27258 Mdot
.726 .27286 Mdot
.726 .2731 Mdot
.726 .27388 Mdot
.726 .27418 Mdot
.726 .27446 Mdot
.726 .2746 Mdot
.726 .27547 Mdot
.726 .27576 Mdot
.726 .27593 Mdot
.726 .27648 Mdot
.726 .27702 Mdot
.726 .27724 Mdot
.726 .27813 Mdot
.726 .28043 Mdot
.726 .28119 Mdot
.726 .28123 Mdot
.726 .28132 Mdot
.726 .28205 Mdot
.726 .28375 Mdot
.726 .28437 Mdot
.726 .28441 Mdot
.726 .28516 Mdot
.726 .28734 Mdot
.726 .28751 Mdot
.726 .28753 Mdot
.726 .28872 Mdot
.726 .28963 Mdot
.726 .29014 Mdot
.726 .29063 Mdot
.726 .29114 Mdot
.726 .29178 Mdot
.726 .29257 Mdot
.726 .293 Mdot
.726 .29309 Mdot
.726 .29336 Mdot
.726 .29402 Mdot
.726 .29419 Mdot
.726 .29438 Mdot
.726 .29462 Mdot
.726 .29474 Mdot
.726 .29569 Mdot
.726 .29627 Mdot
.726 .29629 Mdot
.726 .29766 Mdot
.726 .29784 Mdot
.726 .29803 Mdot
.726 .29886 Mdot
.726 .30112 Mdot
.726 .30205 Mdot
.726 .30232 Mdot
.726 .30252 Mdot
.726 .30259 Mdot
.726 .30311 Mdot
.726 .3054 Mdot
.726 .30541 Mdot
.726 .3067 Mdot
.726 .30786 Mdot
.726 .30816 Mdot
.726 .30832 Mdot
.726 .30912 Mdot
.726 .30929 Mdot
.726 .31014 Mdot
.726 .31032 Mdot
.726 .31069 Mdot
.726 .31095 Mdot
.726 .31115 Mdot
.726 .31125 Mdot
.726 .31131 Mdot
.726 .31169 Mdot
.726 .31181 Mdot
.726 .31203 Mdot
.726 .31271 Mdot
.726 .31408 Mdot
.726 .31553 Mdot
.726 .31727 Mdot
.726 .32066 Mdot
.726 .32073 Mdot
.726 .32137 Mdot
.726 .32211 Mdot
.726 .32222 Mdot
.726 .3242 Mdot
.726 .32511 Mdot
.726 .32541 Mdot
.726 .32634 Mdot
.726 .32748 Mdot
.726 .32776 Mdot
.726 .32944 Mdot
.726 .32949 Mdot
.726 .32975 Mdot
.726 .33153 Mdot
.726 .33155 Mdot
.726 .33159 Mdot
.726 .33288 Mdot
.726 .3333 Mdot
.726 .33381 Mdot
.726 .33466 Mdot
.726 .33552 Mdot
.726 .33569 Mdot
.726 .33599 Mdot
.726 .33794 Mdot
.726 .33825 Mdot
.726 .33839 Mdot
.726 .33885 Mdot
.726 .3391 Mdot
.726 .34111 Mdot
.726 .34155 Mdot
.726 .34201 Mdot
.726 .34212 Mdot
.726 .34463 Mdot
.726 .34493 Mdot
.726 .34653 Mdot
.726 .34692 Mdot
.726 .34724 Mdot
.726 .34746 Mdot
.726 .34794 Mdot
.726 .34812 Mdot
.726 .35087 Mdot
.726 .35107 Mdot
.726 .35182 Mdot
.726 .35218 Mdot
.726 .35218 Mdot
.726 .35264 Mdot
.726 .35333 Mdot
.726 .35351 Mdot
.726 .35373 Mdot
.726 .35378 Mdot
.726 .35402 Mdot
.726 .35424 Mdot
.726 .35429 Mdot
.726 .35442 Mdot
.726 .35582 Mdot
.726 .35604 Mdot
.726 .35657 Mdot
.726 .35701 Mdot
.726 .35781 Mdot
.726 .35849 Mdot
.726 .3589 Mdot
.726 .35949 Mdot
.726 .35969 Mdot
.726 .35997 Mdot
.726 .36062 Mdot
.726 .36104 Mdot
.726 .36111 Mdot
.726 .36113 Mdot
.726 .36203 Mdot
.726 .36303 Mdot
.726 .36325 Mdot
.726 .36328 Mdot
.726 .36399 Mdot
.726 .3647 Mdot
.726 .36518 Mdot
.726 .36654 Mdot
.726 .36657 Mdot
.726 .36725 Mdot
.726 .36802 Mdot
.726 .36805 Mdot
.726 .36823 Mdot
.726 .36828 Mdot
.726 .36886 Mdot
.726 .37177 Mdot
.726 .37258 Mdot
.726 .37308 Mdot
.726 .37504 Mdot
.726 .37686 Mdot
.726 .37709 Mdot
.726 .37724 Mdot
.726 .37774 Mdot
.726 .38169 Mdot
.726 .38261 Mdot
.726 .38338 Mdot
.726 .38525 Mdot
.726 .38632 Mdot
.726 .38662 Mdot
.726 .38673 Mdot
.726 .38679 Mdot
.726 .38796 Mdot
.726 .38801 Mdot
.726 .38833 Mdot
.726 .38881 Mdot
.726 .38913 Mdot
.726 .38955 Mdot
.726 .38989 Mdot
.726 .39102 Mdot
.726 .39146 Mdot
.726 .39187 Mdot
.726 .39207 Mdot
.726 .39334 Mdot
.726 .39376 Mdot
.726 .394 Mdot
.726 .3948 Mdot
.726 .39558 Mdot
.726 .39591 Mdot
.726 .39719 Mdot
.726 .40053 Mdot
.726 .40164 Mdot
.726 .40169 Mdot
.726 .40183 Mdot
.726 .40288 Mdot
.726 .40536 Mdot
.726 .40625 Mdot
.726 .40631 Mdot
.726 .40741 Mdot
.726 .41057 Mdot
.726 .41081 Mdot
.726 .41085 Mdot
.726 .41256 Mdot
.726 .41389 Mdot
.726 .41463 Mdot
.726 .41535 Mdot
.726 .41608 Mdot
.726 .41702 Mdot
.726 .41817 Mdot
.726 .41879 Mdot
.726 .41892 Mdot
.726 .41931 Mdot
.726 .42027 Mdot
.726 .42051 Mdot
.726 .42078 Mdot
.726 .42114 Mdot
.726 .42131 Mdot
.726 .42269 Mdot
.726 .42353 Mdot
.726 .42356 Mdot
.726 .42556 Mdot
.726 .42581 Mdot
.726 .42608 Mdot
.726 .4273 Mdot
.726 .43057 Mdot
.726 .43192 Mdot
.726 .43232 Mdot
.726 .4326 Mdot
.726 .4327 Mdot
.726 .43346 Mdot
.726 .43679 Mdot
.726 .43681 Mdot
.726 .43867 Mdot
.726 .44036 Mdot
.726 .44079 Mdot
.726 .44103 Mdot
.726 .44219 Mdot
.726 .44243 Mdot
.726 .44367 Mdot
.726 .44394 Mdot
.728 .016 Mdot
.728 .01613 Mdot
.728 .01659 Mdot
.728 .01677 Mdot
.728 .01718 Mdot
.728 .01745 Mdot
.728 .01753 Mdot
.728 .01771 Mdot
.728 .01831 Mdot
.728 .01869 Mdot
.728 .01882 Mdot
.728 .01908 Mdot
.728 .01995 Mdot
.728 .02023 Mdot
.728 .02051 Mdot
.728 .02069 Mdot
.728 .02107 Mdot
.728 .02194 Mdot
.728 .02234 Mdot
.728 .02234 Mdot
.728 .02274 Mdot
.728 .02288 Mdot
.728 .02298 Mdot
.728 .02315 Mdot
.728 .0232 Mdot
.728 .02341 Mdot
.728 .02354 Mdot
.728 .02397 Mdot
.728 .02443 Mdot
.728 .02523 Mdot
.728 .02549 Mdot
.728 .02581 Mdot
.728 .02581 Mdot
.728 .0264 Mdot
.728 .0266 Mdot
.728 .02665 Mdot
.728 .02675 Mdot
.728 .02699 Mdot
.728 .02706 Mdot
.728 .02737 Mdot
.728 .02756 Mdot
.728 .02819 Mdot
.728 .02886 Mdot
.728 .02965 Mdot
.728 .03003 Mdot
.728 .03041 Mdot
.728 .03087 Mdot
.728 .03087 Mdot
.728 .03132 Mdot
.728 .03173 Mdot
.728 .03202 Mdot
.728 .0321 Mdot
.728 .03224 Mdot
.728 .03259 Mdot
.728 .03269 Mdot
.728 .03314 Mdot
.728 .03342 Mdot
.728 .0335 Mdot
.728 .03434 Mdot
.728 .03443 Mdot
.728 .03532 Mdot
.728 .03609 Mdot
.728 .03647 Mdot
.728 .03662 Mdot
.728 .03701 Mdot
.728 .03756 Mdot
.728 .03824 Mdot
.728 .03824 Mdot
.728 .03889 Mdot
.728 .03905 Mdot
.728 .03947 Mdot
.728 .03949 Mdot
.728 .03986 Mdot
.728 .03991 Mdot
.728 .04003 Mdot
.728 .04023 Mdot
.728 .04074 Mdot
.728 .04076 Mdot
.728 .04089 Mdot
.728 .04154 Mdot
.728 .04163 Mdot
.728 .04195 Mdot
.728 .04207 Mdot
.728 .0421 Mdot
.728 .04224 Mdot
.728 .04329 Mdot
.728 .04341 Mdot
.728 .04371 Mdot
.728 .04404 Mdot
.728 .04405 Mdot
.728 .04443 Mdot
.728 .04471 Mdot
.728 .0456 Mdot
.728 .04584 Mdot
.728 .04639 Mdot
.728 .04661 Mdot
.728 .04717 Mdot
.728 .04729 Mdot
.728 .04798 Mdot
.728 .04897 Mdot
.728 .04897 Mdot
.728 .04988 Mdot
.728 .04991 Mdot
.728 .05008 Mdot
.728 .05014 Mdot
.728 .05032 Mdot
.728 .05066 Mdot
.728 .05076 Mdot
.728 .05078 Mdot
.728 .05133 Mdot
.728 .0514 Mdot
.728 .05157 Mdot
.728 .05187 Mdot
.728 .0526 Mdot
.728 .05264 Mdot
.728 .05283 Mdot
.728 .05378 Mdot
.728 .05388 Mdot
.728 .0539 Mdot
.728 .05399 Mdot
.728 .05437 Mdot
.728 .05452 Mdot
.728 .05455 Mdot
.728 .05459 Mdot
.728 .05478 Mdot
.728 .05632 Mdot
.728 .05648 Mdot
.728 .0565 Mdot
.728 .05663 Mdot
.728 .05693 Mdot
.728 .05741 Mdot
.728 .05743 Mdot
.728 .05797 Mdot
.728 .05818 Mdot
.728 .05839 Mdot
.728 .05933 Mdot
.728 .05936 Mdot
.728 .05955 Mdot
.728 .05968 Mdot
.728 .06004 Mdot
.728 .06016 Mdot
.728 .0602 Mdot
.728 .06083 Mdot
.728 .06116 Mdot
.728 .06197 Mdot
.728 .06215 Mdot
.728 .0625 Mdot
.728 .06278 Mdot
.728 .06314 Mdot
.728 .06446 Mdot
.728 .06459 Mdot
.728 .06459 Mdot
.728 .06461 Mdot
.728 .06561 Mdot
.728 .06591 Mdot
.728 .06596 Mdot
.728 .06621 Mdot
.728 .0663 Mdot
.728 .06655 Mdot
.728 .06705 Mdot
.728 .0672 Mdot
.728 .06723 Mdot
.728 .06803 Mdot
.728 .06808 Mdot
.728 .06812 Mdot
.728 .06837 Mdot
.728 .06881 Mdot
.728 .0691 Mdot
.728 .06988 Mdot
.728 .06993 Mdot
.728 .07021 Mdot
.728 .07159 Mdot
.728 .07173 Mdot
.728 .07178 Mdot
.728 .0719 Mdot
.728 .07199 Mdot
.728 .07245 Mdot
.728 .07247 Mdot
.728 .07267 Mdot
.728 .07271 Mdot
.728 .07277 Mdot
.728 .07306 Mdot
.728 .0748 Mdot
.728 .07529 Mdot
.728 .07553 Mdot
.728 .07555 Mdot
.728 .07565 Mdot
.728 .07574 Mdot
.728 .07618 Mdot
.728 .07688 Mdot
.728 .07691 Mdot
.728 .0777 Mdot
.728 .078 Mdot
.728 .0781 Mdot
.728 .07812 Mdot
.728 .07831 Mdot
.728 .07843 Mdot
.728 .07968 Mdot
.728 .07972 Mdot
.728 .07972 Mdot
.728 .08 Mdot
.728 .08019 Mdot
.728 .0807 Mdot
.728 .08072 Mdot
.728 .08089 Mdot
.728 .08094 Mdot
.728 .08161 Mdot
.728 .08177 Mdot
.728 .0818 Mdot
.728 .08186 Mdot
.728 .08233 Mdot
.728 .08279 Mdot
.728 .08338 Mdot
.728 .08352 Mdot
.728 .08378 Mdot
.728 .08423 Mdot
.728 .08429 Mdot
.728 .08435 Mdot
.728 .08449 Mdot
.728 .08469 Mdot
.728 .08471 Mdot
.728 .08499 Mdot
.728 .08523 Mdot
.728 .08595 Mdot
.728 .08715 Mdot
.728 .08733 Mdot
.728 .08733 Mdot
.728 .08736 Mdot
.728 .08882 Mdot
.728 .08926 Mdot
.728 .08933 Mdot
.728 .08969 Mdot
.728 .08982 Mdot
.728 .09019 Mdot
.728 .09076 Mdot
.728 .09076 Mdot
.728 .09091 Mdot
.728 .09113 Mdot
.728 .09117 Mdot
.728 .09213 Mdot
.728 .09234 Mdot
.728 .09242 Mdot
.728 .09248 Mdot
.728 .09256 Mdot
.728 .09265 Mdot
.728 .09284 Mdot
.728 .09304 Mdot
.728 .09348 Mdot
.728 .0936 Mdot
.728 .09389 Mdot
.728 .09414 Mdot
.728 .09504 Mdot
.728 .09511 Mdot
.728 .09543 Mdot
.728 .09551 Mdot
.728 .09635 Mdot
.728 .09669 Mdot
.728 .09688 Mdot
.728 .09753 Mdot
.728 .09754 Mdot
.728 .09757 Mdot
.728 .09773 Mdot
.728 .09779 Mdot
.728 .09796 Mdot
.728 .09798 Mdot
.728 .0981 Mdot
.728 .09878 Mdot
.728 .09881 Mdot
.728 .09909 Mdot
.728 .09916 Mdot
.728 .09924 Mdot
.728 .09958 Mdot
.728 .09966 Mdot
.728 .10039 Mdot
.728 .1016 Mdot
.728 .1021 Mdot
.728 .1022 Mdot
.728 .1023 Mdot
.728 .10291 Mdot
.728 .10326 Mdot
.728 .10329 Mdot
.728 .10344 Mdot
.728 .10356 Mdot
.728 .10389 Mdot
.728 .1042 Mdot
.728 .10496 Mdot
.728 .10522 Mdot
.728 .10527 Mdot
.728 .10642 Mdot
.728 .10686 Mdot
.728 .10689 Mdot
.728 .107 Mdot
.728 .10703 Mdot
.728 .1073 Mdot
.728 .10748 Mdot
.728 .10753 Mdot
.728 .10852 Mdot
.728 .10931 Mdot
.728 .10936 Mdot
.728 .10937 Mdot
.728 .10977 Mdot
.728 .10979 Mdot
.728 .11005 Mdot
.728 .11021 Mdot
.728 .11023 Mdot
.728 .1108 Mdot
.728 .11082 Mdot
.728 .11106 Mdot
.728 .11114 Mdot
.728 .11212 Mdot
.728 .11233 Mdot
.728 .11235 Mdot
.728 .1124 Mdot
.728 .11247 Mdot
.728 .11291 Mdot
.728 .11317 Mdot
.728 .11383 Mdot
.728 .1142 Mdot
.728 .11469 Mdot
.728 .1149 Mdot
.728 .11527 Mdot
.728 .11592 Mdot
.728 .11602 Mdot
.728 .11611 Mdot
.728 .1163 Mdot
.728 .1165 Mdot
.728 .1166 Mdot
.728 .11663 Mdot
.728 .11703 Mdot
.728 .11704 Mdot
.728 .11738 Mdot
.728 .11838 Mdot
.728 .11843 Mdot
.728 .11922 Mdot
.728 .11984 Mdot
.728 .12018 Mdot
.728 .12044 Mdot
.728 .12044 Mdot
.728 .12049 Mdot
.728 .12062 Mdot
.728 .12158 Mdot
.728 .12183 Mdot
.728 .12238 Mdot
.728 .12261 Mdot
.728 .12325 Mdot
.728 .12336 Mdot
.728 .12388 Mdot
.728 .12407 Mdot
.728 .12461 Mdot
.728 .12469 Mdot
.728 .12539 Mdot
.728 .12543 Mdot
.728 .12544 Mdot
.728 .12566 Mdot
.728 .12598 Mdot
.728 .12603 Mdot
.728 .12608 Mdot
.728 .12615 Mdot
.728 .12636 Mdot
.728 .12743 Mdot
.728 .12743 Mdot
.728 .12773 Mdot
.728 .12783 Mdot
.728 .12785 Mdot
.728 .12794 Mdot
.728 .12806 Mdot
.728 .12818 Mdot
.728 .12847 Mdot
.728 .12875 Mdot
.728 .12894 Mdot
.728 .12895 Mdot
.728 .12903 Mdot
.728 .12939 Mdot
.728 .12957 Mdot
.728 .12984 Mdot
.728 .12995 Mdot
.728 .13 Mdot
.728 .13035 Mdot
.728 .13059 Mdot
.728 .13166 Mdot
.728 .13176 Mdot
.728 .13176 Mdot
.728 .13223 Mdot
.728 .13236 Mdot
.728 .13265 Mdot
.728 .13358 Mdot
.728 .13407 Mdot
.728 .13429 Mdot
.728 .13434 Mdot
.728 .13447 Mdot
.728 .13498 Mdot
.728 .13529 Mdot
.728 .1353 Mdot
.728 .13535 Mdot
.728 .13559 Mdot
.728 .13568 Mdot
.728 .13593 Mdot
.728 .13595 Mdot
.728 .13613 Mdot
.728 .13675 Mdot
.728 .13712 Mdot
.728 .13716 Mdot
.728 .13727 Mdot
.728 .13766 Mdot
.728 .13778 Mdot
.728 .13828 Mdot
.728 .1384 Mdot
.728 .13946 Mdot
.728 .13953 Mdot
.728 .14004 Mdot
.728 .14122 Mdot
.728 .14194 Mdot
.728 .14209 Mdot
.728 .14225 Mdot
.728 .14312 Mdot
.728 .14363 Mdot
.728 .14369 Mdot
.728 .14389 Mdot
.728 .14408 Mdot
.728 .14456 Mdot
.728 .14482 Mdot
.728 .14501 Mdot
.728 .14514 Mdot
.728 .14612 Mdot
.728 .14649 Mdot
.728 .14656 Mdot
.728 .14743 Mdot
.728 .14824 Mdot
.728 .14888 Mdot
.728 .14892 Mdot
.728 .14908 Mdot
.728 .14912 Mdot
.728 .14952 Mdot
.728 .14978 Mdot
.728 .14985 Mdot
.728 .1499 Mdot
.728 .15129 Mdot
.728 .15244 Mdot
.728 .15252 Mdot
.728 .15253 Mdot
.728 .15272 Mdot
.728 .15312 Mdot
.728 .15314 Mdot
.728 .15352 Mdot
.728 .15375 Mdot
.728 .15379 Mdot
.728 .15461 Mdot
.728 .15465 Mdot
.728 .15499 Mdot
.728 .1551 Mdot
.728 .15598 Mdot
.728 .15653 Mdot
.728 .15666 Mdot
.728 .15684 Mdot
.728 .15687 Mdot
.728 .15694 Mdot
.728 .15705 Mdot
.728 .15734 Mdot
.728 .15768 Mdot
.728 .15806 Mdot
.728 .15903 Mdot
.728 .15957 Mdot
.728 .16028 Mdot
.728 .16058 Mdot
.728 .16112 Mdot
.728 .16129 Mdot
.728 .16207 Mdot
.728 .16221 Mdot
.728 .16234 Mdot
.728 .16263 Mdot
.728 .16291 Mdot
.728 .16306 Mdot
.728 .16311 Mdot
.728 .16358 Mdot
.728 .16369 Mdot
.728 .1637 Mdot
.728 .16382 Mdot
.728 .1642 Mdot
.728 .16475 Mdot
.728 .16558 Mdot
.728 .16565 Mdot
.728 .16573 Mdot
.728 .16584 Mdot
.728 .16688 Mdot
.728 .16692 Mdot
.728 .16709 Mdot
.728 .16772 Mdot
.728 .16777 Mdot
.728 .16827 Mdot
.728 .16865 Mdot
.728 .16866 Mdot
.728 .16872 Mdot
.728 .16892 Mdot
.728 .16893 Mdot
.728 .16967 Mdot
.728 .16976 Mdot
.728 .17031 Mdot
.728 .17036 Mdot
.728 .17068 Mdot
.728 .17148 Mdot
.728 .17181 Mdot
.728 .17275 Mdot
.728 .1729 Mdot
.728 .17366 Mdot
.728 .17393 Mdot
.728 .17473 Mdot
.728 .17473 Mdot
.728 .17483 Mdot
.728 .17525 Mdot
.728 .17558 Mdot
.728 .17586 Mdot
.728 .17592 Mdot
.728 .17593 Mdot
.728 .17625 Mdot
.728 .17644 Mdot
.728 .17671 Mdot
.728 .17675 Mdot
.728 .1768 Mdot
.728 .17687 Mdot
.728 .17696 Mdot
.728 .17727 Mdot
.728 .17883 Mdot
.728 .17883 Mdot
.728 .17927 Mdot
.728 .17941 Mdot
.728 .17944 Mdot
.728 .17957 Mdot
.728 .17975 Mdot
.728 .17992 Mdot
.728 .18034 Mdot
.728 .18064 Mdot
.728 .18075 Mdot
.728 .18081 Mdot
.728 .18102 Mdot
.728 .18103 Mdot
.728 .18116 Mdot
.728 .18169 Mdot
.728 .18195 Mdot
.728 .18234 Mdot
.728 .1825 Mdot
.728 .18257 Mdot
.728 .18308 Mdot
.728 .18343 Mdot
.728 .18405 Mdot
.728 .18426 Mdot
.728 .18458 Mdot
.728 .18499 Mdot
.728 .18513 Mdot
.728 .18514 Mdot
.728 .18582 Mdot
.728 .186 Mdot
.728 .18642 Mdot
.728 .18717 Mdot
.728 .18734 Mdot
.728 .18778 Mdot
.728 .18805 Mdot
.728 .18825 Mdot
.728 .1885 Mdot
.728 .18881 Mdot
.728 .1889 Mdot
.728 .18907 Mdot
.728 .18982 Mdot
.728 .19005 Mdot
.728 .19027 Mdot
.728 .19029 Mdot
.728 .19036 Mdot
.728 .19071 Mdot
.728 .19084 Mdot
.728 .1912 Mdot
.728 .1912 Mdot
.728 .19123 Mdot
.728 .19149 Mdot
.728 .19153 Mdot
.728 .19173 Mdot
.728 .1924 Mdot
.728 .19293 Mdot
.728 .19299 Mdot
.728 .19315 Mdot
.728 .19373 Mdot
.728 .1939 Mdot
.728 .19463 Mdot
.728 .19479 Mdot
.728 .19634 Mdot
.728 .19645 Mdot
.728 .19719 Mdot
.728 .19799 Mdot
.728 .1989 Mdot
.728 .19996 Mdot
.728 .20018 Mdot
.728 .2004 Mdot
.728 .20168 Mdot
.728 .20242 Mdot
.728 .2025 Mdot
.728 .2028 Mdot
.728 .20307 Mdot
.728 .20315 Mdot
.728 .2035 Mdot
.728 .20356 Mdot
.728 .20376 Mdot
.728 .20415 Mdot
.728 .20439 Mdot
.728 .20442 Mdot
.728 .20462 Mdot
.728 .20603 Mdot
.728 .2062 Mdot
.728 .20631 Mdot
.728 .20659 Mdot
.728 .20669 Mdot
.728 .20795 Mdot
.728 .208 Mdot
.728 .20905 Mdot
.728 .20912 Mdot
.728 .20922 Mdot
.728 .21006 Mdot
.728 .21012 Mdot
.728 .21035 Mdot
.728 .21041 Mdot
.728 .211 Mdot
.728 .21137 Mdot
.728 .21147 Mdot
.728 .21154 Mdot
.728 .21357 Mdot
.728 .21524 Mdot
.728 .21535 Mdot
.728 .21537 Mdot
.728 .21564 Mdot
.728 .21623 Mdot
.728 .21626 Mdot
.728 .21681 Mdot
.728 .21715 Mdot
.728 .21721 Mdot
.728 .2184 Mdot
.728 .21846 Mdot
.728 .21896 Mdot
.728 .21912 Mdot
.728 .22039 Mdot
.728 .2212 Mdot
.728 .22139 Mdot
.728 .22164 Mdot
.728 .22169 Mdot
.728 .22179 Mdot
.728 .22196 Mdot
.728 .22238 Mdot
.728 .22288 Mdot
.728 .22342 Mdot
.728 .22484 Mdot
.728 .22562 Mdot
.728 .22666 Mdot
.728 .22709 Mdot
.728 .22788 Mdot
.728 .22813 Mdot
.728 .22927 Mdot
.728 .22947 Mdot
.728 .22966 Mdot
.728 .23008 Mdot
.728 .23049 Mdot
.728 .23071 Mdot
.728 .23077 Mdot
.728 .23147 Mdot
.728 .23162 Mdot
.728 .23163 Mdot
.728 .23181 Mdot
.728 .23236 Mdot
.728 .23316 Mdot
.728 .23438 Mdot
.728 .23448 Mdot
.728 .23459 Mdot
.728 .23475 Mdot
.728 .23627 Mdot
.728 .23632 Mdot
.728 .23657 Mdot
.728 .23749 Mdot
.728 .23756 Mdot
.728 .2383 Mdot
.728 .23884 Mdot
.728 .23885 Mdot
.728 .23894 Mdot
.728 .23923 Mdot
.728 .23925 Mdot
.728 .24033 Mdot
.728 .24046 Mdot
.728 .24126 Mdot
.728 .24133 Mdot
.728 .2418 Mdot
.728 .24297 Mdot
.728 .24344 Mdot
.728 .24481 Mdot
.728 .24504 Mdot
.728 .24614 Mdot
.728 .24654 Mdot
.728 .24769 Mdot
.728 .2477 Mdot
.728 .24785 Mdot
.728 .24846 Mdot
.728 .24893 Mdot
.728 .24935 Mdot
.728 .24942 Mdot
.728 .24944 Mdot
.728 .2499 Mdot
.728 .25018 Mdot
.728 .25058 Mdot
.728 .25064 Mdot
.728 .25071 Mdot
.728 .25081 Mdot
.728 .25094 Mdot
.728 .25139 Mdot
.728 .25366 Mdot
.728 .25366 Mdot
.728 .25431 Mdot
.728 .25451 Mdot
.728 .25455 Mdot
.728 .25474 Mdot
.728 .255 Mdot
.728 .25526 Mdot
.728 .25586 Mdot
.728 .2563 Mdot
.728 .25646 Mdot
.728 .25655 Mdot
.728 .25686 Mdot
.728 .25688 Mdot
.728 .25706 Mdot
.728 .25783 Mdot
.728 .25821 Mdot
.728 .25878 Mdot
.728 .25901 Mdot
.728 .25911 Mdot
.728 .25986 Mdot
.728 .26036 Mdot
.728 .26127 Mdot
.728 .26157 Mdot
.728 .26204 Mdot
.728 .26264 Mdot
.728 .26284 Mdot
.728 .26285 Mdot
.728 .26384 Mdot
.728 .26411 Mdot
.728 .26472 Mdot
.728 .26581 Mdot
.728 .26606 Mdot
.728 .26669 Mdot
.728 .26709 Mdot
.728 .26738 Mdot
.728 .26775 Mdot
.728 .2682 Mdot
.728 .26832 Mdot
.728 .26858 Mdot
.728 .26967 Mdot
.728 .27 Mdot
.728 .27033 Mdot
.728 .27036 Mdot
.728 .27046 Mdot
.728 .27096 Mdot
.728 .27115 Mdot
.728 .27167 Mdot
.728 .27168 Mdot
.728 .27172 Mdot
.728 .2721 Mdot
.728 .27215 Mdot
.728 .27245 Mdot
.728 .27342 Mdot
.728 .2742 Mdot
.728 .27428 Mdot
.728 .27452 Mdot
.728 .27536 Mdot
.728 .2756 Mdot
.728 .27667 Mdot
.728 .27691 Mdot
.728 .27917 Mdot
.728 .27932 Mdot
.728 .2804 Mdot
.728 .28156 Mdot
.728 .28289 Mdot
.728 .28443 Mdot
.728 .28475 Mdot
.728 .28507 Mdot
.728 .28693 Mdot
.728 .28802 Mdot
.728 .28813 Mdot
.728 .28856 Mdot
.728 .28896 Mdot
.728 .28908 Mdot
.728 .28959 Mdot
.728 .28967 Mdot
.728 .28997 Mdot
.728 .29054 Mdot
.728 .29089 Mdot
.728 .29093 Mdot
.728 .29121 Mdot
.728 .29327 Mdot
.728 .29352 Mdot
.728 .29367 Mdot
.728 .29408 Mdot
.728 .29423 Mdot
.728 .29606 Mdot
.728 .29614 Mdot
.728 .29767 Mdot
.728 .29777 Mdot
.728 .29792 Mdot
.728 .29914 Mdot
.728 .29922 Mdot
.728 .29956 Mdot
.728 .29965 Mdot
.728 .3005 Mdot
.728 .30104 Mdot
.728 .3012 Mdot
.728 .30129 Mdot
.728 .30424 Mdot
.728 .30668 Mdot
.728 .30685 Mdot
.728 .30687 Mdot
.728 .30727 Mdot
.728 .30812 Mdot
.728 .30817 Mdot
.728 .30897 Mdot
.728 .30946 Mdot
.728 .30955 Mdot
.728 .31128 Mdot
.728 .31137 Mdot
.728 .31209 Mdot
.728 .31233 Mdot
.728 .31418 Mdot
.728 .31536 Mdot
.728 .31563 Mdot
.728 .316 Mdot
.728 .31607 Mdot
.728 .31622 Mdot
.728 .31646 Mdot
.728 .31707 Mdot
.728 .3178 Mdot
.728 .3186 Mdot
.728 .32066 Mdot
.728 .3218 Mdot
.728 .3233 Mdot
.728 .32393 Mdot
.728 .32508 Mdot
.728 .32544 Mdot
.728 .32711 Mdot
.728 .3274 Mdot
.728 .32767 Mdot
.728 .32828 Mdot
.728 .32888 Mdot
.728 .3292 Mdot
.728 .3293 Mdot
.728 .33031 Mdot
.728 .33054 Mdot
.728 .33055 Mdot
.728 .3308 Mdot
.728 .33161 Mdot
.728 .33277 Mdot
.728 .33455 Mdot
.728 .33469 Mdot
.728 .33485 Mdot
.728 .33508 Mdot
.728 .33729 Mdot
.728 .33737 Mdot
.728 .33773 Mdot
.728 .33908 Mdot
.728 .33918 Mdot
.728 .34025 Mdot
.728 .34104 Mdot
.728 .34106 Mdot
.728 .34119 Mdot
.728 .34161 Mdot
.728 .34163 Mdot
.728 .34322 Mdot
.728 .34341 Mdot
.728 .34456 Mdot
.728 .34466 Mdot
.728 .34535 Mdot
.728 .34705 Mdot
.728 .34775 Mdot
.728 .34973 Mdot
.728 .35006 Mdot
.728 .35166 Mdot
.728 .35225 Mdot
.728 .35393 Mdot
.728 .35394 Mdot
.728 .35415 Mdot
.728 .35504 Mdot
.728 .35573 Mdot
.728 .35634 Mdot
.728 .35645 Mdot
.728 .35647 Mdot
.728 .35715 Mdot
.728 .35756 Mdot
.728 .35814 Mdot
.728 .35822 Mdot
.728 .35832 Mdot
.728 .35847 Mdot
.728 .35866 Mdot
.728 .35932 Mdot
.728 .36262 Mdot
.728 .36263 Mdot
.728 .36356 Mdot
.728 .36386 Mdot
.728 .36392 Mdot
.728 .36419 Mdot
.728 .36458 Mdot
.728 .36494 Mdot
.728 .36583 Mdot
.728 .36646 Mdot
.728 .3667 Mdot
.728 .36683 Mdot
.728 .36728 Mdot
.728 .3673 Mdot
.728 .36757 Mdot
.728 .36868 Mdot
.728 .36924 Mdot
.728 .37007 Mdot
.728 .37041 Mdot
.728 .37055 Mdot
.728 .37164 Mdot
.728 .37238 Mdot
.728 .3737 Mdot
.728 .37414 Mdot
.728 .37482 Mdot
.728 .37569 Mdot
.728 .37598 Mdot
.728 .376 Mdot
.728 .37744 Mdot
.728 .37784 Mdot
.728 .37873 Mdot
.728 .3803 Mdot
.728 .38067 Mdot
.728 .38159 Mdot
.728 .38217 Mdot
.728 .38259 Mdot
.728 .38313 Mdot
.728 .38379 Mdot
.728 .38397 Mdot
.728 .38434 Mdot
.728 .38593 Mdot
.728 .38641 Mdot
.728 .38689 Mdot
.728 .38693 Mdot
.728 .38708 Mdot
.728 .38781 Mdot
.728 .38809 Mdot
.728 .38885 Mdot
.728 .38885 Mdot
.728 .38891 Mdot
.728 .38947 Mdot
.728 .38954 Mdot
.728 .38998 Mdot
.728 .39139 Mdot
.728 .39252 Mdot
.728 .39264 Mdot
.728 .393 Mdot
.728 .39421 Mdot
.728 .39457 Mdot
.728 .39612 Mdot
.728 .39647 Mdot
.728 .39976 Mdot
.728 .39997 Mdot
.728 .40155 Mdot
.728 .40324 Mdot
.728 .40518 Mdot
.728 .40742 Mdot
.728 .40789 Mdot
.728 .40835 Mdot
.728 .41106 Mdot
.728 .41264 Mdot
.728 .4128 Mdot
.728 .41344 Mdot
.728 .41401 Mdot
.728 .41419 Mdot
.728 .41493 Mdot
.728 .41505 Mdot
.728 .41548 Mdot
.728 .41631 Mdot
.728 .41682 Mdot
.728 .41688 Mdot
.728 .41729 Mdot
.728 .4203 Mdot
.728 .42065 Mdot
.728 .42088 Mdot
.728 .42147 Mdot
.728 .42169 Mdot
.728 .42436 Mdot
.728 .42447 Mdot
.728 .4267 Mdot
.728 .42684 Mdot
.728 .42706 Mdot
.728 .42884 Mdot
.728 .42896 Mdot
.728 .42944 Mdot
.728 .42958 Mdot
.728 .43082 Mdot
.728 .43161 Mdot
.728 .43183 Mdot
.728 .43197 Mdot
.728 .43627 Mdot
.728 .43982 Mdot
.728 .44006 Mdot
.728 .44009 Mdot
.728 .44067 Mdot
.728 .44191 Mdot
.728 .44198 Mdot
.728 .44315 Mdot
.728 .44387 Mdot
.728 .44399 Mdot
.73 .0154 Mdot
.73 .01572 Mdot
.73 .01593 Mdot
.73 .01618 Mdot
.73 .01648 Mdot
.73 .01686 Mdot
.73 .0173 Mdot
.73 .01784 Mdot
.73 .01806 Mdot
.73 .01815 Mdot
.73 .01848 Mdot
.73 .01928 Mdot
.73 .01959 Mdot
.73 .01969 Mdot
.73 .01972 Mdot
.73 .02002 Mdot
.73 .02022 Mdot
.73 .02059 Mdot
.73 .02119 Mdot
.73 .02138 Mdot
.73 .02145 Mdot
.73 .02184 Mdot
.73 .02184 Mdot
.73 .02199 Mdot
.73 .022 Mdot
.73 .02203 Mdot
.73 .02203 Mdot
.73 .02247 Mdot
.73 .02267 Mdot
.73 .02275 Mdot
.73 .02298 Mdot
.73 .02329 Mdot
.73 .02417 Mdot
.73 .02445 Mdot
.73 .02455 Mdot
.73 .02511 Mdot
.73 .02512 Mdot
.73 .02533 Mdot
.73 .02534 Mdot
.73 .02539 Mdot
.73 .0254 Mdot
.73 .02555 Mdot
.73 .02555 Mdot
.73 .02603 Mdot
.73 .02633 Mdot
.73 .02644 Mdot
.73 .02678 Mdot
.73 .02723 Mdot
.73 .02727 Mdot
.73 .02853 Mdot
.73 .02892 Mdot
.73 .02908 Mdot
.73 .02989 Mdot
.73 .0299 Mdot
.73 .03021 Mdot
.73 .03023 Mdot
.73 .0303 Mdot
.73 .03031 Mdot
.73 .03053 Mdot
.73 .03054 Mdot
.73 .03124 Mdot
.73 .03168 Mdot
.73 .03183 Mdot
.73 .03233 Mdot
.73 .03259 Mdot
.73 .03299 Mdot
.73 .03305 Mdot
.73 .03428 Mdot
.73 .03439 Mdot
.73 .03446 Mdot
.73 .03488 Mdot
.73 .03546 Mdot
.73 .03568 Mdot
.73 .03598 Mdot
.73 .03688 Mdot
.73 .03689 Mdot
.73 .03734 Mdot
.73 .03737 Mdot
.73 .03747 Mdot
.73 .03749 Mdot
.73 .0378 Mdot
.73 .03782 Mdot
.73 .03884 Mdot
.73 .03928 Mdot
.73 .03948 Mdot
.73 .03971 Mdot
.73 .04044 Mdot
.73 .04053 Mdot
.73 .04075 Mdot
.73 .04082 Mdot
.73 .0414 Mdot
.73 .04148 Mdot
.73 .04165 Mdot
.73 .04186 Mdot
.73 .04244 Mdot
.73 .04265 Mdot
.73 .04278 Mdot
.73 .04291 Mdot
.73 .04328 Mdot
.73 .04344 Mdot
.73 .04354 Mdot
.73 .04401 Mdot
.73 .04415 Mdot
.73 .045 Mdot
.73 .04533 Mdot
.73 .04562 Mdot
.73 .04576 Mdot
.73 .04707 Mdot
.73 .04708 Mdot
.73 .04775 Mdot
.73 .04779 Mdot
.73 .04794 Mdot
.73 .04796 Mdot
.73 .04842 Mdot
.73 .04845 Mdot
.73 .04885 Mdot
.73 .04993 Mdot
.73 .05016 Mdot
.73 .05058 Mdot
.73 .05077 Mdot
.73 .05087 Mdot
.73 .0512 Mdot
.73 .05121 Mdot
.73 .0513 Mdot
.73 .05227 Mdot
.73 .0524 Mdot
.73 .05272 Mdot
.73 .05283 Mdot
.73 .05288 Mdot
.73 .05319 Mdot
.73 .05339 Mdot
.73 .05368 Mdot
.73 .05379 Mdot
.73 .05404 Mdot
.73 .05434 Mdot
.73 .05481 Mdot
.73 .05519 Mdot
.73 .0555 Mdot
.73 .05569 Mdot
.73 .05588 Mdot
.73 .05642 Mdot
.73 .05666 Mdot
.73 .0568 Mdot
.73 .05698 Mdot
.73 .05704 Mdot
.73 .05749 Mdot
.73 .05769 Mdot
.73 .05819 Mdot
.73 .05893 Mdot
.73 .05936 Mdot
.73 .05941 Mdot
.73 .05963 Mdot
.73 .05983 Mdot
.73 .06004 Mdot
.73 .06004 Mdot
.73 .06195 Mdot
.73 .06197 Mdot
.73 .06295 Mdot
.73 .06301 Mdot
.73 .06323 Mdot
.73 .06326 Mdot
.73 .06343 Mdot
.73 .06392 Mdot
.73 .06397 Mdot
.73 .06455 Mdot
.73 .06571 Mdot
.73 .06613 Mdot
.73 .06646 Mdot
.73 .06708 Mdot
.73 .06736 Mdot
.73 .06751 Mdot
.73 .06777 Mdot
.73 .06799 Mdot
.73 .068 Mdot
.73 .06813 Mdot
.73 .06954 Mdot
.73 .06973 Mdot
.73 .0702 Mdot
.73 .0703 Mdot
.73 .07036 Mdot
.73 .07044 Mdot
.73 .07084 Mdot
.73 .07089 Mdot
.73 .07099 Mdot
.73 .07119 Mdot
.73 .0716 Mdot
.73 .07176 Mdot
.73 .07213 Mdot
.73 .07228 Mdot
.73 .07257 Mdot
.73 .07326 Mdot
.73 .0738 Mdot
.73 .07397 Mdot
.73 .07426 Mdot
.73 .07454 Mdot
.73 .07482 Mdot
.73 .07501 Mdot
.73 .07561 Mdot
.73 .07595 Mdot
.73 .07616 Mdot
.73 .07642 Mdot
.73 .07651 Mdot
.73 .07689 Mdot
.73 .07717 Mdot
.73 .07747 Mdot
.73 .07819 Mdot
.73 .07927 Mdot
.73 .07989 Mdot
.73 .07997 Mdot
.73 .08029 Mdot
.73 .08059 Mdot
.73 .08089 Mdot
.73 .08089 Mdot
.73 .08104 Mdot
.73 .08142 Mdot
.73 .08349 Mdot
.73 .08368 Mdot
.73 .08371 Mdot
.73 .08385 Mdot
.73 .08421 Mdot
.73 .08513 Mdot
.73 .08523 Mdot
.73 .08529 Mdot
.73 .08554 Mdot
.73 .08559 Mdot
.73 .08583 Mdot
.73 .08656 Mdot
.73 .08662 Mdot
.73 .08748 Mdot
.73 .08827 Mdot
.73 .08916 Mdot
.73 .08979 Mdot
.73 .09021 Mdot
.73 .09027 Mdot
.73 .09117 Mdot
.73 .0915 Mdot
.73 .09156 Mdot
.73 .09158 Mdot
.73 .09179 Mdot
.73 .09217 Mdot
.73 .09243 Mdot
.73 .0925 Mdot
.73 .09251 Mdot
.73 .0927 Mdot
.73 .09278 Mdot
.73 .09291 Mdot
.73 .09361 Mdot
.73 .09433 Mdot
.73 .09476 Mdot
.73 .09504 Mdot
.73 .09573 Mdot
.73 .09587 Mdot
.73 .09596 Mdot
.73 .09608 Mdot
.73 .09666 Mdot
.73 .09673 Mdot
.73 .09685 Mdot
.73 .09687 Mdot
.73 .09716 Mdot
.73 .09717 Mdot
.73 .09777 Mdot
.73 .09797 Mdot
.73 .098 Mdot
.73 .09854 Mdot
.73 .09856 Mdot
.73 .09877 Mdot
.73 .099 Mdot
.73 .09904 Mdot
.73 .09913 Mdot
.73 .09919 Mdot
.73 .0995 Mdot
.73 .10019 Mdot
.73 .10034 Mdot
.73 .10087 Mdot
.73 .10098 Mdot
.73 .10122 Mdot
.73 .10165 Mdot
.73 .10173 Mdot
.73 .10204 Mdot
.73 .10207 Mdot
.73 .10247 Mdot
.73 .10275 Mdot
.73 .10362 Mdot
.73 .10412 Mdot
.73 .10442 Mdot
.73 .10481 Mdot
.73 .10493 Mdot
.73 .10549 Mdot
.73 .1059 Mdot
.73 .10633 Mdot
.73 .10639 Mdot
.73 .10669 Mdot
.73 .10677 Mdot
.73 .10739 Mdot
.73 .10896 Mdot
.73 .10988 Mdot
.73 .10999 Mdot
.73 .11046 Mdot
.73 .11089 Mdot
.73 .11115 Mdot
.73 .11121 Mdot
.73 .11133 Mdot
.73 .11133 Mdot
.73 .11148 Mdot
.73 .11154 Mdot
.73 .11211 Mdot
.73 .11249 Mdot
.73 .11366 Mdot
.73 .11403 Mdot
.73 .11407 Mdot
.73 .11513 Mdot
.73 .1154 Mdot
.73 .11545 Mdot
.73 .11565 Mdot
.73 .11587 Mdot
.73 .1159 Mdot
.73 .11617 Mdot
.73 .11724 Mdot
.73 .11752 Mdot
.73 .11766 Mdot
.73 .11776 Mdot
.73 .11812 Mdot
.73 .11819 Mdot
.73 .11855 Mdot
.73 .11961 Mdot
.73 .1197 Mdot
.73 .12044 Mdot
.73 .12095 Mdot
.73 .1214 Mdot
.73 .12196 Mdot
.73 .12208 Mdot
.73 .12211 Mdot
.73 .12276 Mdot
.73 .12341 Mdot
.73 .12432 Mdot
.73 .12486 Mdot
.73 .12494 Mdot
.73 .12502 Mdot
.73 .12634 Mdot
.73 .12664 Mdot
.73 .12683 Mdot
.73 .1269 Mdot
.73 .12693 Mdot
.73 .12709 Mdot
.73 .12725 Mdot
.73 .1278 Mdot
.73 .12787 Mdot
.73 .12805 Mdot
.73 .12818 Mdot
.73 .12827 Mdot
.73 .12828 Mdot
.73 .1283 Mdot
.73 .12857 Mdot
.73 .12868 Mdot
.73 .12887 Mdot
.73 .1299 Mdot
.73 .12997 Mdot
.73 .12998 Mdot
.73 .13095 Mdot
.73 .13096 Mdot
.73 .13102 Mdot
.73 .13158 Mdot
.73 .13199 Mdot
.73 .13199 Mdot
.73 .13229 Mdot
.73 .13299 Mdot
.73 .1332 Mdot
.73 .13333 Mdot
.73 .1335 Mdot
.73 .13397 Mdot
.73 .13436 Mdot
.73 .13446 Mdot
.73 .13463 Mdot
.73 .13467 Mdot
.73 .13509 Mdot
.73 .13509 Mdot
.73 .13532 Mdot
.73 .13553 Mdot
.73 .13597 Mdot
.73 .13627 Mdot
.73 .13631 Mdot
.73 .13668 Mdot
.73 .1371 Mdot
.73 .13713 Mdot
.73 .1372 Mdot
.73 .13743 Mdot
.73 .13778 Mdot
.73 .13783 Mdot
.73 .1379 Mdot
.73 .13795 Mdot
.73 .13805 Mdot
.73 .13839 Mdot
.73 .1385 Mdot
.73 .13912 Mdot
.73 .13925 Mdot
.73 .13951 Mdot
.73 .13955 Mdot
.73 .13973 Mdot
.73 .14 Mdot
.73 .1405 Mdot
.73 .1406 Mdot
.73 .14067 Mdot
.73 .14102 Mdot
.73 .14164 Mdot
.73 .14176 Mdot
.73 .14217 Mdot
.73 .14221 Mdot
.73 .14225 Mdot
.73 .14244 Mdot
.73 .14272 Mdot
.73 .14284 Mdot
.73 .14299 Mdot
.73 .14324 Mdot
.73 .14341 Mdot
.73 .14432 Mdot
.73 .14452 Mdot
.73 .14497 Mdot
.73 .14524 Mdot
.73 .14545 Mdot
.73 .14568 Mdot
.73 .14625 Mdot
.73 .14643 Mdot
.73 .14725 Mdot
.73 .14785 Mdot
.73 .14828 Mdot
.73 .14847 Mdot
.73 .14857 Mdot
.73 .14888 Mdot
.73 .149 Mdot
.73 .14911 Mdot
.73 .15002 Mdot
.73 .15003 Mdot
.73 .15022 Mdot
.73 .15105 Mdot
.73 .15228 Mdot
.73 .15232 Mdot
.73 .15286 Mdot
.73 .15301 Mdot
.73 .15365 Mdot
.73 .15382 Mdot
.73 .1545 Mdot
.73 .15453 Mdot
.73 .15503 Mdot
.73 .15513 Mdot
.73 .15532 Mdot
.73 .15551 Mdot
.73 .15559 Mdot
.73 .15572 Mdot
.73 .15577 Mdot
.73 .15578 Mdot
.73 .15599 Mdot
.73 .15608 Mdot
.73 .15691 Mdot
.73 .15691 Mdot
.73 .15746 Mdot
.73 .15917 Mdot
.73 .15972 Mdot
.73 .15975 Mdot
.73 .15977 Mdot
.73 .16026 Mdot
.73 .16132 Mdot
.73 .16172 Mdot
.73 .16179 Mdot
.73 .16208 Mdot
.73 .16215 Mdot
.73 .16234 Mdot
.73 .1624 Mdot
.73 .16245 Mdot
.73 .16249 Mdot
.73 .16284 Mdot
.73 .16336 Mdot
.73 .1644 Mdot
.73 .16482 Mdot
.73 .16501 Mdot
.73 .16516 Mdot
.73 .16518 Mdot
.73 .16569 Mdot
.73 .16579 Mdot
.73 .16586 Mdot
.73 .16631 Mdot
.73 .16701 Mdot
.73 .1674 Mdot
.73 .16777 Mdot
.73 .16786 Mdot
.73 .16799 Mdot
.73 .16908 Mdot
.73 .16981 Mdot
.73 .17048 Mdot
.73 .17129 Mdot
.73 .17146 Mdot
.73 .17151 Mdot
.73 .17193 Mdot
.73 .17247 Mdot
.73 .1728 Mdot
.73 .17341 Mdot
.73 .17474 Mdot
.73 .17486 Mdot
.73 .17553 Mdot
.73 .17564 Mdot
.73 .17576 Mdot
.73 .17611 Mdot
.73 .17706 Mdot
.73 .17769 Mdot
.73 .1781 Mdot
.73 .17812 Mdot
.73 .1784 Mdot
.73 .17851 Mdot
.73 .17855 Mdot
.73 .17878 Mdot
.73 .17901 Mdot
.73 .17982 Mdot
.73 .17992 Mdot
.73 .18018 Mdot
.73 .18037 Mdot
.73 .18051 Mdot
.73 .18052 Mdot
.73 .18055 Mdot
.73 .18067 Mdot
.73 .18094 Mdot
.73 .18111 Mdot
.73 .18139 Mdot
.73 .18149 Mdot
.73 .18289 Mdot
.73 .18298 Mdot
.73 .18301 Mdot
.73 .18442 Mdot
.73 .18443 Mdot
.73 .18452 Mdot
.73 .18484 Mdot
.73 .18522 Mdot
.73 .18534 Mdot
.73 .18535 Mdot
.73 .18593 Mdot
.73 .18594 Mdot
.73 .18637 Mdot
.73 .1874 Mdot
.73 .18771 Mdot
.73 .18789 Mdot
.73 .18793 Mdot
.73 .18815 Mdot
.73 .18882 Mdot
.73 .18939 Mdot
.73 .18954 Mdot
.73 .18979 Mdot
.73 .18984 Mdot
.73 .18992 Mdot
.73 .19046 Mdot
.73 .19047 Mdot
.73 .19078 Mdot
.73 .1908 Mdot
.73 .19111 Mdot
.73 .19121 Mdot
.73 .19175 Mdot
.73 .19218 Mdot
.73 .19225 Mdot
.73 .19262 Mdot
.73 .19278 Mdot
.73 .19301 Mdot
.73 .19317 Mdot
.73 .1934 Mdot
.73 .19344 Mdot
.73 .19354 Mdot
.73 .19369 Mdot
.73 .19388 Mdot
.73 .19438 Mdot
.73 .19447 Mdot
.73 .19456 Mdot
.73 .19465 Mdot
.73 .19478 Mdot
.73 .19507 Mdot
.73 .19528 Mdot
.73 .19544 Mdot
.73 .19635 Mdot
.73 .19654 Mdot
.73 .19691 Mdot
.73 .19697 Mdot
.73 .19724 Mdot
.73 .19763 Mdot
.73 .19782 Mdot
.73 .19786 Mdot
.73 .19835 Mdot
.73 .19851 Mdot
.73 .19861 Mdot
.73 .19874 Mdot
.73 .19912 Mdot
.73 .20003 Mdot
.73 .2002 Mdot
.73 .2008 Mdot
.73 .20086 Mdot
.73 .20091 Mdot
.73 .20119 Mdot
.73 .20161 Mdot
.73 .20178 Mdot
.73 .20199 Mdot
.73 .20236 Mdot
.73 .20249 Mdot
.73 .20261 Mdot
.73 .20394 Mdot
.73 .20423 Mdot
.73 .20489 Mdot
.73 .20529 Mdot
.73 .20559 Mdot
.73 .20593 Mdot
.73 .20675 Mdot
.73 .20702 Mdot
.73 .20809 Mdot
.73 .20822 Mdot
.73 .20826 Mdot
.73 .20908 Mdot
.73 .20973 Mdot
.73 .21 Mdot
.73 .21014 Mdot
.73 .21059 Mdot
.73 .21072 Mdot
.73 .21077 Mdot
.73 .21094 Mdot
.73 .21138 Mdot
.73 .21226 Mdot
.73 .21228 Mdot
.73 .21256 Mdot
.73 .21376 Mdot
.73 .21557 Mdot
.73 .21562 Mdot
.73 .21641 Mdot
.73 .21662 Mdot
.73 .21756 Mdot
.73 .2178 Mdot
.73 .2188 Mdot
.73 .21885 Mdot
.73 .21957 Mdot
.73 .21973 Mdot
.73 .21999 Mdot
.73 .22028 Mdot
.73 .2204 Mdot
.73 .22058 Mdot
.73 .22065 Mdot
.73 .22067 Mdot
.73 .22097 Mdot
.73 .22111 Mdot
.73 .22232 Mdot
.73 .22232 Mdot
.73 .22313 Mdot
.73 .22562 Mdot
.73 .22642 Mdot
.73 .22647 Mdot
.73 .2265 Mdot
.73 .22721 Mdot
.73 .22876 Mdot
.73 .22935 Mdot
.73 .22945 Mdot
.73 .22987 Mdot
.73 .22997 Mdot
.73 .23024 Mdot
.73 .23034 Mdot
.73 .2304 Mdot
.73 .23047 Mdot
.73 .23098 Mdot
.73 .23173 Mdot
.73 .23325 Mdot
.73 .23386 Mdot
.73 .23415 Mdot
.73 .23436 Mdot
.73 .2344 Mdot
.73 .23514 Mdot
.73 .23529 Mdot
.73 .23538 Mdot
.73 .23605 Mdot
.73 .23706 Mdot
.73 .23709 Mdot
.73 .23763 Mdot
.73 .23818 Mdot
.73 .23831 Mdot
.73 .2385 Mdot
.73 .24009 Mdot
.73 .24116 Mdot
.73 .24212 Mdot
.73 .24331 Mdot
.73 .24357 Mdot
.73 .24364 Mdot
.73 .24424 Mdot
.73 .24503 Mdot
.73 .24552 Mdot
.73 .24641 Mdot
.73 .24835 Mdot
.73 .24853 Mdot
.73 .2495 Mdot
.73 .24967 Mdot
.73 .24984 Mdot
.73 .25035 Mdot
.73 .25174 Mdot
.73 .25265 Mdot
.73 .25326 Mdot
.73 .25329 Mdot
.73 .25369 Mdot
.73 .25386 Mdot
.73 .25392 Mdot
.73 .25425 Mdot
.73 .25458 Mdot
.73 .25577 Mdot
.73 .25592 Mdot
.73 .25629 Mdot
.73 .25657 Mdot
.73 .25678 Mdot
.73 .2568 Mdot
.73 .25684 Mdot
.73 .25701 Mdot
.73 .25741 Mdot
.73 .25765 Mdot
.73 .25806 Mdot
.73 .2582 Mdot
.73 .26025 Mdot
.73 .26038 Mdot
.73 .26042 Mdot
.73 .26248 Mdot
.73 .2625 Mdot
.73 .26263 Mdot
.73 .2631 Mdot
.73 .26365 Mdot
.73 .26383 Mdot
.73 .26385 Mdot
.73 .26469 Mdot
.73 .26471 Mdot
.73 .26533 Mdot
.73 .26684 Mdot
.73 .26729 Mdot
.73 .26755 Mdot
.73 .2676 Mdot
.73 .26793 Mdot
.73 .26891 Mdot
.73 .26974 Mdot
.73 .26995 Mdot
.73 .27032 Mdot
.73 .2704 Mdot
.73 .27051 Mdot
.73 .2713 Mdot
.73 .27131 Mdot
.73 .27177 Mdot
.73 .2718 Mdot
.73 .27225 Mdot
.73 .27239 Mdot
.73 .27318 Mdot
.73 .27382 Mdot
.73 .27392 Mdot
.73 .27445 Mdot
.73 .2747 Mdot
.73 .27502 Mdot
.73 .27526 Mdot
.73 .2756 Mdot
.73 .27566 Mdot
.73 .2758 Mdot
.73 .27601 Mdot
.73 .2763 Mdot
.73 .27703 Mdot
.73 .27716 Mdot
.73 .27729 Mdot
.73 .27741 Mdot
.73 .27761 Mdot
.73 .27804 Mdot
.73 .27834 Mdot
.73 .27857 Mdot
.73 .2799 Mdot
.73 .28018 Mdot
.73 .28072 Mdot
.73 .28081 Mdot
.73 .2812 Mdot
.73 .28177 Mdot
.73 .28205 Mdot
.73 .28211 Mdot
.73 .28283 Mdot
.73 .28306 Mdot
.73 .2832 Mdot
.73 .28338 Mdot
.73 .28395 Mdot
.73 .28528 Mdot
.73 .28552 Mdot
.73 .2864 Mdot
.73 .28649 Mdot
.73 .28656 Mdot
.73 .28697 Mdot
.73 .28758 Mdot
.73 .28783 Mdot
.73 .28814 Mdot
.73 .28868 Mdot
.73 .28886 Mdot
.73 .28904 Mdot
.73 .29099 Mdot
.73 .2914 Mdot
.73 .29237 Mdot
.73 .29295 Mdot
.73 .2934 Mdot
.73 .29389 Mdot
.73 .29509 Mdot
.73 .29547 Mdot
.73 .29705 Mdot
.73 .29723 Mdot
.73 .29729 Mdot
.73 .2985 Mdot
.73 .29943 Mdot
.73 .29983 Mdot
.73 .30003 Mdot
.73 .3007 Mdot
.73 .30088 Mdot
.73 .30095 Mdot
.73 .3012 Mdot
.73 .30185 Mdot
.73 .30314 Mdot
.73 .30316 Mdot
.73 .30357 Mdot
.73 .30533 Mdot
.73 .30796 Mdot
.73 .30803 Mdot
.73 .30919 Mdot
.73 .3095 Mdot
.73 .31087 Mdot
.73 .31123 Mdot
.73 .31268 Mdot
.73 .31275 Mdot
.73 .31381 Mdot
.73 .31403 Mdot
.73 .31442 Mdot
.73 .31483 Mdot
.73 .31501 Mdot
.73 .31528 Mdot
.73 .31538 Mdot
.73 .31541 Mdot
.73 .31585 Mdot
.73 .31606 Mdot
.73 .31781 Mdot
.73 .31782 Mdot
.73 .319 Mdot
.73 .32264 Mdot
.73 .3238 Mdot
.73 .32387 Mdot
.73 .32392 Mdot
.73 .32496 Mdot
.73 .32722 Mdot
.73 .32808 Mdot
.73 .32823 Mdot
.73 .32885 Mdot
.73 .32899 Mdot
.73 .32938 Mdot
.73 .32953 Mdot
.73 .32962 Mdot
.73 .32971 Mdot
.73 .33046 Mdot
.73 .33156 Mdot
.73 .33378 Mdot
.73 .33467 Mdot
.73 .33509 Mdot
.73 .33539 Mdot
.73 .33545 Mdot
.73 .33654 Mdot
.73 .33675 Mdot
.73 .33689 Mdot
.73 .33786 Mdot
.73 .33934 Mdot
.73 .33938 Mdot
.73 .34018 Mdot
.73 .34097 Mdot
.73 .34116 Mdot
.73 .34144 Mdot
.73 .34376 Mdot
.73 .34532 Mdot
.73 .34673 Mdot
.73 .34847 Mdot
.73 .34884 Mdot
.73 .34894 Mdot
.73 .34983 Mdot
.73 .35098 Mdot
.73 .35169 Mdot
.73 .35298 Mdot
.73 .35582 Mdot
.73 .35609 Mdot
.73 .3575 Mdot
.73 .35775 Mdot
.73 .35799 Mdot
.73 .35874 Mdot
.73 .36078 Mdot
.73 .36211 Mdot
.73 .36299 Mdot
.73 .36303 Mdot
.73 .36362 Mdot
.73 .36386 Mdot
.73 .36395 Mdot
.73 .36443 Mdot
.73 .36492 Mdot
.73 .36665 Mdot
.73 .36687 Mdot
.73 .36742 Mdot
.73 .36783 Mdot
.73 .36813 Mdot
.73 .36816 Mdot
.73 .36821 Mdot
.73 .36847 Mdot
.73 .36904 Mdot
.73 .3694 Mdot
.73 .37 Mdot
.73 .37021 Mdot
.73 .37319 Mdot
.73 .37339 Mdot
.73 .37345 Mdot
.73 .37645 Mdot
.73 .37649 Mdot
.73 .37667 Mdot
.73 .37736 Mdot
.73 .37817 Mdot
.73 .37842 Mdot
.73 .37845 Mdot
.73 .37968 Mdot
.73 .3797 Mdot
.73 .38062 Mdot
.73 .38281 Mdot
.73 .38347 Mdot
.73 .38385 Mdot
.73 .38393 Mdot
.73 .3844 Mdot
.73 .38584 Mdot
.73 .38705 Mdot
.73 .38736 Mdot
.73 .3879 Mdot
.73 .38802 Mdot
.73 .38818 Mdot
.73 .38934 Mdot
.73 .38935 Mdot
.73 .39002 Mdot
.73 .39006 Mdot
.73 .39072 Mdot
.73 .39093 Mdot
.73 .39207 Mdot
.73 .393 Mdot
.73 .39315 Mdot
.73 .39393 Mdot
.73 .39429 Mdot
.73 .39477 Mdot
.73 .39511 Mdot
.73 .39561 Mdot
.73 .39569 Mdot
.73 .3959 Mdot
.73 .39621 Mdot
.73 .39662 Mdot
.73 .3977 Mdot
.73 .39788 Mdot
.73 .39807 Mdot
.73 .39825 Mdot
.73 .39854 Mdot
.73 .39917 Mdot
.73 .39961 Mdot
.73 .39994 Mdot
.73 .40188 Mdot
.73 .40229 Mdot
.73 .40308 Mdot
.73 .40321 Mdot
.73 .40378 Mdot
.73 .40462 Mdot
.73 .40502 Mdot
.73 .40512 Mdot
.73 .40616 Mdot
.73 .4065 Mdot
.73 .4067 Mdot
.73 .40697 Mdot
.73 .40779 Mdot
.73 .40974 Mdot
.73 .41009 Mdot
.73 .41138 Mdot
.73 .41151 Mdot
.73 .41161 Mdot
.73 .41221 Mdot
.73 .41309 Mdot
.73 .41346 Mdot
.73 .41392 Mdot
.73 .41471 Mdot
.73 .41497 Mdot
.73 .41523 Mdot
.73 .41808 Mdot
.73 .41868 Mdot
.73 .42009 Mdot
.73 .42094 Mdot
.73 .42159 Mdot
.73 .42231 Mdot
.73 .42406 Mdot
.73 .42462 Mdot
.73 .42692 Mdot
.73 .42718 Mdot
.73 .42727 Mdot
.73 .42903 Mdot
.73 .4304 Mdot
.73 .43099 Mdot
.73 .43128 Mdot
.73 .43225 Mdot
.73 .43252 Mdot
.73 .43262 Mdot
.73 .43298 Mdot
.73 .43393 Mdot
.73 .43581 Mdot
.73 .43584 Mdot
.73 .43644 Mdot
.73 .43901 Mdot
.73 .44285 Mdot
.73 .44296 Mdot
.73 .44464 Mdot
.73 .4451 Mdot
.732 .01484 Mdot
.732 .0149 Mdot
.732 .01498 Mdot
.732 .015 Mdot
.732 .0151 Mdot
.732 .01513 Mdot
.732 .01528 Mdot
.732 .01532 Mdot
.732 .01545 Mdot
.732 .01555 Mdot
.732 .0156 Mdot
.732 .01579 Mdot
.732 .01593 Mdot
.732 .01601 Mdot
.732 .01629 Mdot
.732 .0165 Mdot
.732 .0166 Mdot
.732 .01661 Mdot
.732 .01699 Mdot
.732 .01702 Mdot
.732 .01733 Mdot
.732 .01747 Mdot
.732 .01749 Mdot
.732 .01805 Mdot
.732 .01805 Mdot
.732 .01809 Mdot
.732 .01809 Mdot
.732 .01823 Mdot
.732 .01854 Mdot
.732 .01876 Mdot
.732 .01878 Mdot
.732 .01959 Mdot
.732 .0196 Mdot
.732 .01965 Mdot
.732 .01966 Mdot
.732 .01987 Mdot
.732 .02032 Mdot
.732 .02063 Mdot
.732 .02067 Mdot
.732 .02126 Mdot
.732 .02185 Mdot
.732 .02187 Mdot
.732 .02194 Mdot
.732 .02195 Mdot
.732 .02224 Mdot
.732 .02226 Mdot
.732 .02266 Mdot
.732 .02291 Mdot
.732 .02337 Mdot
.732 .02343 Mdot
.732 .02363 Mdot
.732 .02429 Mdot
.732 .02517 Mdot
.732 .02518 Mdot
.732 .02529 Mdot
.732 .02531 Mdot
.732 .02538 Mdot
.732 .02542 Mdot
.732 .02565 Mdot
.732 .02573 Mdot
.732 .02576 Mdot
.732 .02592 Mdot
.732 .02635 Mdot
.732 .02672 Mdot
.732 .02691 Mdot
.732 .02739 Mdot
.732 .02748 Mdot
.732 .02777 Mdot
.732 .02859 Mdot
.732 .02863 Mdot
.732 .02874 Mdot
.732 .0292 Mdot
.732 .02928 Mdot
.732 .02954 Mdot
.732 .02974 Mdot
.732 .03002 Mdot
.732 .03004 Mdot
.732 .0302 Mdot
.732 .03023 Mdot
.732 .03033 Mdot
.732 .03039 Mdot
.732 .03072 Mdot
.732 .03084 Mdot
.732 .03088 Mdot
.732 .03112 Mdot
.732 .03175 Mdot
.732 .03185 Mdot
.732 .03229 Mdot
.732 .03257 Mdot
.732 .03282 Mdot
.732 .03327 Mdot
.732 .0334 Mdot
.732 .03382 Mdot
.732 .034 Mdot
.732 .03471 Mdot
.732 .03503 Mdot
.732 .03504 Mdot
.732 .03509 Mdot
.732 .03524 Mdot
.732 .03592 Mdot
.732 .03604 Mdot
.732 .03642 Mdot
.732 .03671 Mdot
.732 .03711 Mdot
.732 .03715 Mdot
.732 .03738 Mdot
.732 .03743 Mdot
.732 .03757 Mdot
.732 .03767 Mdot
.732 .03814 Mdot
.732 .03832 Mdot
.732 .03833 Mdot
.732 .03838 Mdot
.732 .03874 Mdot
.732 .03966 Mdot
.732 .0398 Mdot
.732 .03982 Mdot
.732 .04044 Mdot
.732 .04086 Mdot
.732 .04088 Mdot
.732 .04121 Mdot
.732 .04143 Mdot
.732 .04166 Mdot
.732 .04176 Mdot
.732 .04189 Mdot
.732 .04207 Mdot
.732 .04252 Mdot
.732 .04269 Mdot
.732 .04295 Mdot
.732 .04398 Mdot
.732 .04411 Mdot
.732 .04446 Mdot
.732 .04446 Mdot
.732 .04454 Mdot
.732 .04457 Mdot
.732 .04477 Mdot
.732 .04552 Mdot
.732 .04576 Mdot
.732 .04594 Mdot
.732 .04608 Mdot
.732 .04649 Mdot
.732 .04692 Mdot
.732 .04719 Mdot
.732 .04751 Mdot
.732 .04756 Mdot
.732 .0478 Mdot
.732 .0479 Mdot
.732 .04796 Mdot
.732 .04818 Mdot
.732 .04832 Mdot
.732 .04845 Mdot
.732 .04902 Mdot
.732 .04928 Mdot
.732 .04929 Mdot
.732 .04937 Mdot
.732 .04988 Mdot
.732 .04992 Mdot
.732 .04995 Mdot
.732 .05123 Mdot
.732 .05145 Mdot
.732 .05147 Mdot
.732 .05238 Mdot
.732 .05299 Mdot
.732 .05302 Mdot
.732 .05351 Mdot
.732 .05382 Mdot
.732 .05417 Mdot
.732 .05431 Mdot
.732 .05433 Mdot
.732 .05449 Mdot
.732 .05451 Mdot
.732 .05477 Mdot
.732 .05519 Mdot
.732 .05532 Mdot
.732 .05542 Mdot
.732 .05567 Mdot
.732 .05605 Mdot
.732 .05755 Mdot
.732 .05756 Mdot
.732 .05774 Mdot
.732 .05826 Mdot
.732 .05827 Mdot
.732 .05838 Mdot
.732 .05842 Mdot
.732 .05869 Mdot
.732 .05871 Mdot
.732 .05982 Mdot
.732 .06009 Mdot
.732 .06015 Mdot
.732 .06016 Mdot
.732 .06042 Mdot
.732 .06064 Mdot
.732 .06108 Mdot
.732 .06123 Mdot
.732 .06187 Mdot
.732 .06226 Mdot
.732 .06272 Mdot
.732 .06281 Mdot
.732 .06315 Mdot
.732 .0633 Mdot
.732 .06339 Mdot
.732 .06371 Mdot
.732 .06391 Mdot
.732 .0641 Mdot
.732 .06421 Mdot
.732 .06479 Mdot
.732 .06493 Mdot
.732 .06527 Mdot
.732 .06532 Mdot
.732 .06533 Mdot
.732 .06545 Mdot
.732 .06549 Mdot
.732 .06616 Mdot
.732 .0662 Mdot
.732 .06625 Mdot
.732 .0663 Mdot
.732 .06793 Mdot
.732 .06803 Mdot
.732 .06818 Mdot
.732 .06825 Mdot
.732 .06849 Mdot
.732 .06849 Mdot
.732 .06852 Mdot
.732 .06915 Mdot
.732 .06985 Mdot
.732 .07075 Mdot
.732 .07079 Mdot
.732 .07151 Mdot
.732 .07196 Mdot
.732 .07247 Mdot
.732 .07268 Mdot
.732 .07272 Mdot
.732 .07295 Mdot
.732 .07298 Mdot
.732 .07335 Mdot
.732 .07398 Mdot
.732 .07416 Mdot
.732 .07431 Mdot
.732 .07464 Mdot
.732 .07468 Mdot
.732 .07484 Mdot
.732 .07485 Mdot
.732 .07523 Mdot
.732 .07596 Mdot
.732 .07625 Mdot
.732 .07705 Mdot
.732 .07743 Mdot
.732 .07745 Mdot
.732 .07771 Mdot
.732 .07846 Mdot
.732 .07848 Mdot
.732 .07865 Mdot
.732 .0787 Mdot
.732 .0791 Mdot
.732 .07912 Mdot
.732 .07958 Mdot
.732 .0796 Mdot
.732 .08005 Mdot
.732 .0802 Mdot
.732 .08075 Mdot
.732 .08114 Mdot
.732 .08115 Mdot
.732 .08124 Mdot
.732 .08125 Mdot
.732 .08129 Mdot
.732 .08132 Mdot
.732 .08163 Mdot
.732 .08177 Mdot
.732 .08195 Mdot
.732 .08259 Mdot
.732 .08281 Mdot
.732 .08309 Mdot
.732 .0831 Mdot
.732 .08375 Mdot
.732 .08432 Mdot
.732 .085 Mdot
.732 .08512 Mdot
.732 .08562 Mdot
.732 .08584 Mdot
.732 .08598 Mdot
.732 .08644 Mdot
.732 .0866 Mdot
.732 .08673 Mdot
.732 .08701 Mdot
.732 .08704 Mdot
.732 .08708 Mdot
.732 .08718 Mdot
.732 .08802 Mdot
.732 .08823 Mdot
.732 .08835 Mdot
.732 .08873 Mdot
.732 .08873 Mdot
.732 .0888 Mdot
.732 .08882 Mdot
.732 .08898 Mdot
.732 .08905 Mdot
.732 .08925 Mdot
.732 .08925 Mdot
.732 .08977 Mdot
.732 .09003 Mdot
.732 .09009 Mdot
.732 .09016 Mdot
.732 .09024 Mdot
.732 .09262 Mdot
.732 .09277 Mdot
.732 .09299 Mdot
.732 .09309 Mdot
.732 .0932 Mdot
.732 .09344 Mdot
.732 .09344 Mdot
.732 .09349 Mdot
.732 .0944 Mdot
.732 .09543 Mdot
.732 .09675 Mdot
.732 .09681 Mdot
.732 .09786 Mdot
.732 .09853 Mdot
.732 .09927 Mdot
.732 .09958 Mdot
.732 .09963 Mdot
.732 .09997 Mdot
.732 .10002 Mdot
.732 .10056 Mdot
.732 .10116 Mdot
.732 .10147 Mdot
.732 .10175 Mdot
.732 .10197 Mdot
.732 .10244 Mdot
.732 .1025 Mdot
.732 .10274 Mdot
.732 .10275 Mdot
.732 .10313 Mdot
.732 .10331 Mdot
.732 .10438 Mdot
.732 .10481 Mdot
.732 .10579 Mdot
.732 .10597 Mdot
.732 .10653 Mdot
.732 .10655 Mdot
.732 .10678 Mdot
.732 .10694 Mdot
.732 .10804 Mdot
.732 .10806 Mdot
.732 .10823 Mdot
.732 .10831 Mdot
.732 .10838 Mdot
.732 .10839 Mdot
.732 .1089 Mdot
.732 .10897 Mdot
.732 .10901 Mdot
.732 .10936 Mdot
.732 .10967 Mdot
.732 .10968 Mdot
.732 .10971 Mdot
.732 .11037 Mdot
.732 .11059 Mdot
.732 .11127 Mdot
.732 .11128 Mdot
.732 .11139 Mdot
.732 .1116 Mdot
.732 .11197 Mdot
.732 .11198 Mdot
.732 .1121 Mdot
.732 .11212 Mdot
.732 .11217 Mdot
.732 .11222 Mdot
.732 .11268 Mdot
.732 .11289 Mdot
.732 .11315 Mdot
.732 .11409 Mdot
.732 .11441 Mdot
.732 .11481 Mdot
.732 .11483 Mdot
.732 .11565 Mdot
.732 .11578 Mdot
.732 .11662 Mdot
.732 .11761 Mdot
.732 .11776 Mdot
.732 .11779 Mdot
.732 .11852 Mdot
.732 .11884 Mdot
.732 .11904 Mdot
.732 .11972 Mdot
.732 .11995 Mdot
.732 .12015 Mdot
.732 .12055 Mdot
.732 .1206 Mdot
.732 .12065 Mdot
.732 .1208 Mdot
.732 .12204 Mdot
.732 .12234 Mdot
.732 .12252 Mdot
.732 .12307 Mdot
.732 .12307 Mdot
.732 .12317 Mdot
.732 .1232 Mdot
.732 .12345 Mdot
.732 .12355 Mdot
.732 .12383 Mdot
.732 .12383 Mdot
.732 .1246 Mdot
.732 .12469 Mdot
.732 .1247 Mdot
.732 .12498 Mdot
.732 .12506 Mdot
.732 .12517 Mdot
.732 .12529 Mdot
.732 .12777 Mdot
.732 .12877 Mdot
.732 .12899 Mdot
.732 .1293 Mdot
.732 .12945 Mdot
.732 .12962 Mdot
.732 .12968 Mdot
.732 .12997 Mdot
.732 .12997 Mdot
.732 .13004 Mdot
.732 .13138 Mdot
.732 .13289 Mdot
.732 .13356 Mdot
.732 .13397 Mdot
.732 .13482 Mdot
.732 .13491 Mdot
.732 .13644 Mdot
.732 .13741 Mdot
.732 .13851 Mdot
.732 .13895 Mdot
.732 .13903 Mdot
.732 .13953 Mdot
.732 .1396 Mdot
.732 .14039 Mdot
.732 .14083 Mdot
.732 .14102 Mdot
.732 .14127 Mdot
.732 .14173 Mdot
.732 .14213 Mdot
.732 .14245 Mdot
.732 .1425 Mdot
.732 .14314 Mdot
.732 .14315 Mdot
.732 .14323 Mdot
.732 .14359 Mdot
.732 .1436 Mdot
.732 .14415 Mdot
.732 .14442 Mdot
.732 .14548 Mdot
.732 .14554 Mdot
.732 .14598 Mdot
.732 .14661 Mdot
.732 .14789 Mdot
.732 .14806 Mdot
.732 .14831 Mdot
.732 .14913 Mdot
.732 .14916 Mdot
.732 .14927 Mdot
.732 .1495 Mdot
.732 .14973 Mdot
.732 .1505 Mdot
.732 .15134 Mdot
.732 .15138 Mdot
.732 .15162 Mdot
.732 .15174 Mdot
.732 .15184 Mdot
.732 .15185 Mdot
.732 .15254 Mdot
.732 .1526 Mdot
.732 .15271 Mdot
.732 .15276 Mdot
.732 .15291 Mdot
.732 .15327 Mdot
.732 .1534 Mdot
.732 .15373 Mdot
.732 .15375 Mdot
.732 .15379 Mdot
.732 .15476 Mdot
.732 .15507 Mdot
.732 .1552 Mdot
.732 .15551 Mdot
.732 .15607 Mdot
.732 .15608 Mdot
.732 .15616 Mdot
.732 .15624 Mdot
.732 .15656 Mdot
.732 .15709 Mdot
.732 .15711 Mdot
.732 .15729 Mdot
.732 .15731 Mdot
.732 .1574 Mdot
.732 .15746 Mdot
.732 .15813 Mdot
.732 .15844 Mdot
.732 .15882 Mdot
.732 .15904 Mdot
.732 .15915 Mdot
.732 .1602 Mdot
.732 .16067 Mdot
.732 .16101 Mdot
.732 .16118 Mdot
.732 .16126 Mdot
.732 .16129 Mdot
.732 .16153 Mdot
.732 .16204 Mdot
.732 .16249 Mdot
.732 .16267 Mdot
.732 .16302 Mdot
.732 .16321 Mdot
.732 .16342 Mdot
.732 .16389 Mdot
.732 .1639 Mdot
.732 .1653 Mdot
.732 .16536 Mdot
.732 .16557 Mdot
.732 .16561 Mdot
.732 .16632 Mdot
.732 .16669 Mdot
.732 .16713 Mdot
.732 .16715 Mdot
.732 .16745 Mdot
.732 .16845 Mdot
.732 .16863 Mdot
.732 .16878 Mdot
.732 .16885 Mdot
.732 .16907 Mdot
.732 .16963 Mdot
.732 .16966 Mdot
.732 .16973 Mdot
.732 .16981 Mdot
.732 .17002 Mdot
.732 .17177 Mdot
.732 .17183 Mdot
.732 .17184 Mdot
.732 .17219 Mdot
.732 .17228 Mdot
.732 .17254 Mdot
.732 .17334 Mdot
.732 .17335 Mdot
.732 .17349 Mdot
.732 .17354 Mdot
.732 .17384 Mdot
.732 .17389 Mdot
.732 .1739 Mdot
.732 .17404 Mdot
.732 .17446 Mdot
.732 .17447 Mdot
.732 .17558 Mdot
.732 .17572 Mdot
.732 .17573 Mdot
.732 .17614 Mdot
.732 .17626 Mdot
.732 .17642 Mdot
.732 .17643 Mdot
.732 .17659 Mdot
.732 .17768 Mdot
.732 .18022 Mdot
.732 .18085 Mdot
.732 .1817 Mdot
.732 .18201 Mdot
.732 .18247 Mdot
.732 .18252 Mdot
.732 .18269 Mdot
.732 .18283 Mdot
.732 .18293 Mdot
.732 .18302 Mdot
.732 .18344 Mdot
.732 .18345 Mdot
.732 .18355 Mdot
.732 .18484 Mdot
.732 .18551 Mdot
.732 .18772 Mdot
.732 .18772 Mdot
.732 .1887 Mdot
.732 .18931 Mdot
.732 .19055 Mdot
.732 .19068 Mdot
.732 .19286 Mdot
.732 .19292 Mdot
.732 .1934 Mdot
.732 .1936 Mdot
.732 .19434 Mdot
.732 .19437 Mdot
.732 .19511 Mdot
.732 .19555 Mdot
.732 .19595 Mdot
.732 .1966 Mdot
.732 .19671 Mdot
.732 .19687 Mdot
.732 .19744 Mdot
.732 .19754 Mdot
.732 .19775 Mdot
.732 .19867 Mdot
.732 .1987 Mdot
.732 .19929 Mdot
.732 .19935 Mdot
.732 .19946 Mdot
.732 .19962 Mdot
.732 .19994 Mdot
.732 .2 Mdot
.732 .20006 Mdot
.732 .20021 Mdot
.732 .20066 Mdot
.732 .20099 Mdot
.732 .20125 Mdot
.732 .20172 Mdot
.732 .20179 Mdot
.732 .20204 Mdot
.732 .20272 Mdot
.732 .20274 Mdot
.732 .20286 Mdot
.732 .20339 Mdot
.732 .2034 Mdot
.732 .20421 Mdot
.732 .20461 Mdot
.732 .20562 Mdot
.732 .20615 Mdot
.732 .20625 Mdot
.732 .20689 Mdot
.732 .20781 Mdot
.732 .20945 Mdot
.732 .20962 Mdot
.732 .20968 Mdot
.732 .20993 Mdot
.732 .21016 Mdot
.732 .2103 Mdot
.732 .21072 Mdot
.732 .211 Mdot
.732 .2113 Mdot
.732 .2115 Mdot
.732 .21155 Mdot
.732 .2117 Mdot
.732 .21174 Mdot
.732 .21179 Mdot
.732 .21204 Mdot
.732 .21237 Mdot
.732 .21351 Mdot
.732 .21473 Mdot
.732 .21479 Mdot
.732 .21496 Mdot
.732 .21514 Mdot
.732 .21523 Mdot
.732 .21532 Mdot
.732 .21546 Mdot
.732 .21548 Mdot
.732 .21649 Mdot
.732 .21657 Mdot
.732 .21674 Mdot
.732 .21681 Mdot
.732 .21703 Mdot
.732 .21756 Mdot
.732 .21775 Mdot
.732 .21824 Mdot
.732 .21826 Mdot
.732 .21833 Mdot
.732 .21974 Mdot
.732 .22019 Mdot
.732 .22039 Mdot
.732 .22084 Mdot
.732 .22166 Mdot
.732 .22168 Mdot
.732 .22178 Mdot
.732 .22191 Mdot
.732 .22237 Mdot
.732 .22316 Mdot
.732 .22318 Mdot
.732 .22344 Mdot
.732 .22348 Mdot
.732 .2236 Mdot
.732 .22369 Mdot
.732 .22468 Mdot
.732 .22513 Mdot
.732 .22568 Mdot
.732 .22601 Mdot
.732 .22616 Mdot
.732 .2277 Mdot
.732 .2284 Mdot
.732 .22889 Mdot
.732 .22915 Mdot
.732 .22926 Mdot
.732 .2293 Mdot
.732 .22966 Mdot
.732 .2304 Mdot
.732 .23061 Mdot
.732 .23106 Mdot
.732 .23132 Mdot
.732 .23184 Mdot
.732 .23212 Mdot
.732 .23242 Mdot
.732 .23311 Mdot
.732 .23312 Mdot
.732 .23517 Mdot
.732 .23525 Mdot
.732 .23557 Mdot
.732 .23563 Mdot
.732 .23667 Mdot
.732 .2372 Mdot
.732 .23785 Mdot
.732 .23788 Mdot
.732 .23832 Mdot
.732 .23978 Mdot
.732 .24005 Mdot
.732 .24027 Mdot
.732 .24037 Mdot
.732 .24069 Mdot
.732 .24151 Mdot
.732 .24156 Mdot
.732 .24166 Mdot
.732 .24177 Mdot
.732 .24208 Mdot
.732 .24464 Mdot
.732 .24474 Mdot
.732 .24474 Mdot
.732 .24526 Mdot
.732 .24539 Mdot
.732 .24577 Mdot
.732 .24695 Mdot
.732 .24696 Mdot
.732 .24717 Mdot
.732 .24724 Mdot
.732 .24768 Mdot
.732 .24774 Mdot
.732 .24776 Mdot
.732 .24797 Mdot
.732 .24858 Mdot
.732 .24859 Mdot
.732 .25022 Mdot
.732 .25043 Mdot
.732 .25045 Mdot
.732 .25104 Mdot
.732 .25121 Mdot
.732 .25146 Mdot
.732 .25146 Mdot
.732 .2517 Mdot
.732 .2533 Mdot
.732 .25702 Mdot
.732 .25793 Mdot
.732 .25918 Mdot
.732 .25964 Mdot
.732 .26031 Mdot
.732 .26038 Mdot
.732 .26063 Mdot
.732 .26084 Mdot
.732 .26099 Mdot
.732 .26112 Mdot
.732 .26173 Mdot
.732 .26174 Mdot
.732 .26189 Mdot
.732 .26378 Mdot
.732 .26476 Mdot
.732 .268 Mdot
.732 .268 Mdot
.732 .26943 Mdot
.732 .27032 Mdot
.732 .27213 Mdot
.732 .27233 Mdot
.732 .27553 Mdot
.732 .27561 Mdot
.732 .2763 Mdot
.732 .2766 Mdot
.732 .27769 Mdot
.732 .27772 Mdot
.732 .27882 Mdot
.732 .27946 Mdot
.732 .28004 Mdot
.732 .28099 Mdot
.732 .28116 Mdot
.732 .28139 Mdot
.732 .28223 Mdot
.732 .28238 Mdot
.732 .28267 Mdot
.732 .28402 Mdot
.732 .28407 Mdot
.732 .28494 Mdot
.732 .28502 Mdot
.732 .28518 Mdot
.732 .28542 Mdot
.732 .28588 Mdot
.732 .28597 Mdot
.732 .28606 Mdot
.732 .28628 Mdot
.732 .28694 Mdot
.732 .28742 Mdot
.732 .2878 Mdot
.732 .2885 Mdot
.732 .2886 Mdot
.732 .28896 Mdot
.732 .28996 Mdot
.732 .28999 Mdot
.732 .29016 Mdot
.732 .29093 Mdot
.732 .29095 Mdot
.732 .29213 Mdot
.732 .29272 Mdot
.732 .2942 Mdot
.732 .29498 Mdot
.732 .29512 Mdot
.732 .29606 Mdot
.732 .2974 Mdot
.732 .2998 Mdot
.732 .30005 Mdot
.732 .30014 Mdot
.732 .3005 Mdot
.732 .30085 Mdot
.732 .30106 Mdot
.732 .30167 Mdot
.732 .30208 Mdot
.732 .30251 Mdot
.732 .3028 Mdot
.732 .30288 Mdot
.732 .3031 Mdot
.732 .30316 Mdot
.732 .30323 Mdot
.732 .30359 Mdot
.732 .30408 Mdot
.732 .30575 Mdot
.732 .30754 Mdot
.732 .30762 Mdot
.732 .30787 Mdot
.732 .30813 Mdot
.732 .30827 Mdot
.732 .3084 Mdot
.732 .30861 Mdot
.732 .30863 Mdot
.732 .31011 Mdot
.732 .31024 Mdot
.732 .31048 Mdot
.732 .31059 Mdot
.732 .3109 Mdot
.732 .31168 Mdot
.732 .31195 Mdot
.732 .31267 Mdot
.732 .3127 Mdot
.732 .3128 Mdot
.732 .31486 Mdot
.732 .31554 Mdot
.732 .31583 Mdot
.732 .31649 Mdot
.732 .31768 Mdot
.732 .31771 Mdot
.732 .31786 Mdot
.732 .31805 Mdot
.732 .31873 Mdot
.732 .31987 Mdot
.732 .3199 Mdot
.732 .32029 Mdot
.732 .32035 Mdot
.732 .32052 Mdot
.732 .32066 Mdot
.732 .3221 Mdot
.732 .32276 Mdot
.732 .32357 Mdot
.732 .32405 Mdot
.732 .32428 Mdot
.732 .32653 Mdot
.732 .32754 Mdot
.732 .32827 Mdot
.732 .32864 Mdot
.732 .3288 Mdot
.732 .32887 Mdot
.732 .32939 Mdot
.732 .33047 Mdot
.732 .33079 Mdot
.732 .33144 Mdot
.732 .33182 Mdot
.732 .33258 Mdot
.732 .33299 Mdot
.732 .33344 Mdot
.732 .33444 Mdot
.732 .33447 Mdot
.732 .33746 Mdot
.732 .33758 Mdot
.732 .33805 Mdot
.732 .33813 Mdot
.732 .33966 Mdot
.732 .34044 Mdot
.732 .34139 Mdot
.732 .34143 Mdot
.732 .34207 Mdot
.732 .3442 Mdot
.732 .3446 Mdot
.732 .34493 Mdot
.732 .34508 Mdot
.732 .34554 Mdot
.732 .34675 Mdot
.732 .34681 Mdot
.732 .34696 Mdot
.732 .34713 Mdot
.732 .34758 Mdot
.732 .35133 Mdot
.732 .35147 Mdot
.732 .35147 Mdot
.732 .35223 Mdot
.732 .35243 Mdot
.732 .35297 Mdot
.732 .3547 Mdot
.732 .35472 Mdot
.732 .35503 Mdot
.732 .35513 Mdot
.732 .35578 Mdot
.732 .35587 Mdot
.732 .35589 Mdot
.732 .3562 Mdot
.732 .3571 Mdot
.732 .35711 Mdot
.732 .3595 Mdot
.732 .3598 Mdot
.732 .35982 Mdot
.732 .36069 Mdot
.732 .36095 Mdot
.732 .36131 Mdot
.732 .36131 Mdot
.732 .36166 Mdot
.732 .36401 Mdot
.732 .36944 Mdot
.732 .37079 Mdot
.732 .37261 Mdot
.732 .37328 Mdot
.732 .37427 Mdot
.732 .37437 Mdot
.732 .37473 Mdot
.732 .37504 Mdot
.732 .37526 Mdot
.732 .37635 Mdot
.732 .37635 Mdot
.732 .37658 Mdot
.732 .37934 Mdot
.732 .38078 Mdot
.732 .38552 Mdot
.732 .38552 Mdot
.732 .38762 Mdot
.732 .38892 Mdot
.732 .39157 Mdot
.732 .39186 Mdot
.732 .39654 Mdot
.732 .39667 Mdot
.732 .39768 Mdot
.732 .39812 Mdot
.732 .39971 Mdot
.732 .39976 Mdot
.732 .40136 Mdot
.732 .4023 Mdot
.732 .40315 Mdot
.732 .40454 Mdot
.732 .40479 Mdot
.732 .40512 Mdot
.732 .40636 Mdot
.732 .40657 Mdot
.732 .40701 Mdot
.732 .40898 Mdot
.732 .40905 Mdot
.732 .41032 Mdot
.732 .41044 Mdot
.732 .41068 Mdot
.732 .41103 Mdot
.732 .4117 Mdot
.732 .41183 Mdot
.732 .41197 Mdot
.732 .41229 Mdot
.732 .41325 Mdot
.732 .41395 Mdot
.732 .41451 Mdot
.732 .41553 Mdot
.732 .41568 Mdot
.732 .41621 Mdot
.732 .41767 Mdot
.732 .41772 Mdot
.732 .41796 Mdot
.732 .41909 Mdot
.732 .41912 Mdot
.732 .42085 Mdot
.732 .42171 Mdot
.732 .42387 Mdot
.732 .42502 Mdot
.732 .42523 Mdot
.732 .4266 Mdot
.732 .42857 Mdot
.732 .43208 Mdot
.732 .43245 Mdot
.732 .43258 Mdot
.732 .43311 Mdot
.732 .43362 Mdot
.732 .43392 Mdot
.732 .43482 Mdot
.732 .43542 Mdot
.732 .43605 Mdot
.732 .43648 Mdot
.732 .43659 Mdot
.732 .43691 Mdot
.732 .437 Mdot
.732 .4371 Mdot
.732 .43763 Mdot
.732 .43835 Mdot
.732 .44079 Mdot
.732 .44341 Mdot
.732 .44353 Mdot
.732 .4439 Mdot
.732 .44428 Mdot
.732 .44447 Mdot
.732 .44467 Mdot
.732 .44498 Mdot
.732 .44501 Mdot
.732 .44718 Mdot
.732 .44736 Mdot
.734 .01537 Mdot
.734 .01567 Mdot
.734 .01579 Mdot
.734 .01612 Mdot
.734 .01629 Mdot
.734 .01642 Mdot
.734 .01677 Mdot
.734 .01702 Mdot
.734 .01722 Mdot
.734 .01732 Mdot
.734 .01774 Mdot
.734 .01811 Mdot
.734 .01839 Mdot
.734 .0184 Mdot
.734 .01854 Mdot
.734 .01854 Mdot
.734 .01915 Mdot
.734 .01969 Mdot
.734 .01981 Mdot
.734 .02011 Mdot
.734 .02012 Mdot
.734 .02032 Mdot
.734 .02034 Mdot
.734 .02036 Mdot
.734 .02042 Mdot
.734 .02116 Mdot
.734 .02123 Mdot
.734 .02174 Mdot
.734 .02202 Mdot
.734 .02219 Mdot
.734 .02263 Mdot
.734 .02265 Mdot
.734 .02295 Mdot
.734 .02297 Mdot
.734 .023 Mdot
.734 .02308 Mdot
.734 .02413 Mdot
.734 .02418 Mdot
.734 .02428 Mdot
.734 .02502 Mdot
.734 .02527 Mdot
.734 .02544 Mdot
.734 .02569 Mdot
.734 .02634 Mdot
.734 .02636 Mdot
.734 .02661 Mdot
.734 .0268 Mdot
.734 .02683 Mdot
.734 .02687 Mdot
.734 .027 Mdot
.734 .02771 Mdot
.734 .02854 Mdot
.734 .0286 Mdot
.734 .02876 Mdot
.734 .0302 Mdot
.734 .03046 Mdot
.734 .0306 Mdot
.734 .03082 Mdot
.734 .03157 Mdot
.734 .03172 Mdot
.734 .03178 Mdot
.734 .03182 Mdot
.734 .03217 Mdot
.734 .03246 Mdot
.734 .0325 Mdot
.734 .03256 Mdot
.734 .03275 Mdot
.734 .03379 Mdot
.734 .03501 Mdot
.734 .0351 Mdot
.734 .03533 Mdot
.734 .0366 Mdot
.734 .03745 Mdot
.734 .03783 Mdot
.734 .03804 Mdot
.734 .03836 Mdot
.734 .03946 Mdot
.734 .03967 Mdot
.734 .03976 Mdot
.734 .03982 Mdot
.734 .04 Mdot
.734 .04035 Mdot
.734 .04076 Mdot
.734 .04082 Mdot
.734 .04092 Mdot
.734 .04119 Mdot
.734 .04128 Mdot
.734 .04215 Mdot
.734 .04226 Mdot
.734 .04272 Mdot
.734 .04317 Mdot
.734 .04331 Mdot
.734 .04444 Mdot
.734 .04451 Mdot
.734 .04452 Mdot
.734 .04465 Mdot
.734 .04498 Mdot
.734 .04684 Mdot
.734 .04799 Mdot
.734 .04809 Mdot
.734 .04865 Mdot
.734 .04895 Mdot
.734 .04942 Mdot
.734 .05056 Mdot
.734 .05102 Mdot
.734 .05104 Mdot
.734 .05111 Mdot
.734 .05136 Mdot
.734 .05148 Mdot
.734 .05157 Mdot
.734 .05183 Mdot
.734 .05234 Mdot
.734 .05261 Mdot
.734 .05295 Mdot
.734 .05303 Mdot
.734 .05318 Mdot
.734 .05322 Mdot
.734 .05358 Mdot
.734 .05371 Mdot
.734 .0538 Mdot
.734 .05499 Mdot
.734 .05515 Mdot
.734 .05583 Mdot
.734 .05648 Mdot
.734 .0567 Mdot
.734 .05785 Mdot
.734 .05835 Mdot
.734 .05845 Mdot
.734 .05847 Mdot
.734 .05866 Mdot
.734 .05914 Mdot
.734 .05978 Mdot
.734 .06187 Mdot
.734 .06199 Mdot
.734 .06344 Mdot
.734 .06356 Mdot
.734 .06371 Mdot
.734 .06375 Mdot
.734 .06396 Mdot
.734 .06453 Mdot
.734 .06488 Mdot
.734 .06498 Mdot
.734 .06531 Mdot
.734 .06567 Mdot
.734 .06568 Mdot
.734 .06734 Mdot
.734 .06801 Mdot
.734 .06804 Mdot
.734 .06814 Mdot
.734 .06835 Mdot
.734 .0685 Mdot
.734 .06869 Mdot
.734 .06881 Mdot
.734 .06899 Mdot
.734 .0692 Mdot
.734 .06955 Mdot
.734 .06995 Mdot
.734 .07034 Mdot
.734 .07084 Mdot
.734 .07097 Mdot
.734 .07104 Mdot
.734 .07118 Mdot
.734 .07124 Mdot
.734 .07145 Mdot
.734 .07177 Mdot
.734 .07196 Mdot
.734 .07209 Mdot
.734 .07233 Mdot
.734 .07294 Mdot
.734 .07322 Mdot
.734 .0734 Mdot
.734 .07351 Mdot
.734 .07384 Mdot
.734 .07394 Mdot
.734 .07394 Mdot
.734 .07408 Mdot
.734 .07507 Mdot
.734 .07603 Mdot
.734 .07635 Mdot
.734 .07717 Mdot
.734 .07723 Mdot
.734 .07804 Mdot
.734 .07805 Mdot
.734 .07877 Mdot
.734 .07892 Mdot
.734 .07894 Mdot
.734 .07921 Mdot
.734 .07922 Mdot
.734 .07933 Mdot
.734 .07941 Mdot
.734 .07993 Mdot
.734 .08088 Mdot
.734 .08242 Mdot
.734 .08256 Mdot
.734 .08274 Mdot
.734 .08275 Mdot
.734 .08364 Mdot
.734 .08371 Mdot
.734 .08394 Mdot
.734 .08403 Mdot
.734 .08412 Mdot
.734 .08625 Mdot
.734 .08643 Mdot
.734 .08664 Mdot
.734 .08671 Mdot
.734 .08696 Mdot
.734 .08701 Mdot
.734 .08707 Mdot
.734 .08754 Mdot
.734 .08767 Mdot
.734 .08784 Mdot
.734 .08836 Mdot
.734 .0885 Mdot
.734 .089 Mdot
.734 .08951 Mdot
.734 .08953 Mdot
.734 .08968 Mdot
.734 .09061 Mdot
.734 .09068 Mdot
.734 .09171 Mdot
.734 .09197 Mdot
.734 .09215 Mdot
.734 .09296 Mdot
.734 .093 Mdot
.734 .09314 Mdot
.734 .09345 Mdot
.734 .09368 Mdot
.734 .09395 Mdot
.734 .09413 Mdot
.734 .09439 Mdot
.734 .09469 Mdot
.734 .09522 Mdot
.734 .09566 Mdot
.734 .0958 Mdot
.734 .09621 Mdot
.734 .09637 Mdot
.734 .09692 Mdot
.734 .09705 Mdot
.734 .09711 Mdot
.734 .09725 Mdot
.734 .09729 Mdot
.734 .09739 Mdot
.734 .0976 Mdot
.734 .09769 Mdot
.734 .09801 Mdot
.734 .09807 Mdot
.734 .09847 Mdot
.734 .09854 Mdot
.734 .09874 Mdot
.734 .09894 Mdot
.734 .09906 Mdot
.734 .09929 Mdot
.734 .1002 Mdot
.734 .1006 Mdot
.734 .10087 Mdot
.734 .10102 Mdot
.734 .10151 Mdot
.734 .10165 Mdot
.734 .10166 Mdot
.734 .10172 Mdot
.734 .10186 Mdot
.734 .10242 Mdot
.734 .10331 Mdot
.734 .10473 Mdot
.734 .10519 Mdot
.734 .10559 Mdot
.734 .10597 Mdot
.734 .1064 Mdot
.734 .10648 Mdot
.734 .10733 Mdot
.734 .1076 Mdot
.734 .10768 Mdot
.734 .10769 Mdot
.734 .10855 Mdot
.734 .10874 Mdot
.734 .10897 Mdot
.734 .109 Mdot
.734 .10939 Mdot
.734 .10941 Mdot
.734 .10957 Mdot
.734 .10969 Mdot
.734 .11045 Mdot
.734 .11098 Mdot
.734 .1116 Mdot
.734 .11184 Mdot
.734 .11362 Mdot
.734 .11409 Mdot
.734 .11411 Mdot
.734 .11431 Mdot
.734 .11434 Mdot
.734 .11458 Mdot
.734 .1146 Mdot
.734 .11534 Mdot
.734 .1159 Mdot
.734 .116 Mdot
.734 .11634 Mdot
.734 .11647 Mdot
.734 .1166 Mdot
.734 .11747 Mdot
.734 .11836 Mdot
.734 .11898 Mdot
.734 .11907 Mdot
.734 .11973 Mdot
.734 .11999 Mdot
.734 .12031 Mdot
.734 .1204 Mdot
.734 .12078 Mdot
.734 .12082 Mdot
.734 .12084 Mdot
.734 .12093 Mdot
.734 .12093 Mdot
.734 .12163 Mdot
.734 .12182 Mdot
.734 .12207 Mdot
.734 .12209 Mdot
.734 .12283 Mdot
.734 .12304 Mdot
.734 .12376 Mdot
.734 .12386 Mdot
.734 .12389 Mdot
.734 .12452 Mdot
.734 .12454 Mdot
.734 .12476 Mdot
.734 .12485 Mdot
.734 .12561 Mdot
.734 .12591 Mdot
.734 .12595 Mdot
.734 .12613 Mdot
.734 .12623 Mdot
.734 .12775 Mdot
.734 .12783 Mdot
.734 .12812 Mdot
.734 .12818 Mdot
.734 .12838 Mdot
.734 .12948 Mdot
.734 .12958 Mdot
.734 .12963 Mdot
.734 .12985 Mdot
.734 .1303 Mdot
.734 .13063 Mdot
.734 .13103 Mdot
.734 .13105 Mdot
.734 .1313 Mdot
.734 .13168 Mdot
.734 .13212 Mdot
.734 .13213 Mdot
.734 .13254 Mdot
.734 .13261 Mdot
.734 .13289 Mdot
.734 .13346 Mdot
.734 .13355 Mdot
.734 .13375 Mdot
.734 .13435 Mdot
.734 .13459 Mdot
.734 .13538 Mdot
.734 .13558 Mdot
.734 .13568 Mdot
.734 .13587 Mdot
.734 .13594 Mdot
.734 .13609 Mdot
.734 .13627 Mdot
.734 .13639 Mdot
.734 .13653 Mdot
.734 .13699 Mdot
.734 .13708 Mdot
.734 .13735 Mdot
.734 .13767 Mdot
.734 .13777 Mdot
.734 .13807 Mdot
.734 .13836 Mdot
.734 .13853 Mdot
.734 .13887 Mdot
.734 .1402 Mdot
.734 .14079 Mdot
.734 .14106 Mdot
.734 .14119 Mdot
.734 .14142 Mdot
.734 .14164 Mdot
.734 .14198 Mdot
.734 .14213 Mdot
.734 .14234 Mdot
.734 .14235 Mdot
.734 .14241 Mdot
.734 .14244 Mdot
.734 .14264 Mdot
.734 .14332 Mdot
.734 .14346 Mdot
.734 .14365 Mdot
.734 .14432 Mdot
.734 .14478 Mdot
.734 .14515 Mdot
.734 .14575 Mdot
.734 .14636 Mdot
.734 .14685 Mdot
.734 .14753 Mdot
.734 .14812 Mdot
.734 .14852 Mdot
.734 .14867 Mdot
.734 .14882 Mdot
.734 .14895 Mdot
.734 .14931 Mdot
.734 .14943 Mdot
.734 .15019 Mdot
.734 .15067 Mdot
.734 .15107 Mdot
.734 .15119 Mdot
.734 .1512 Mdot
.734 .15166 Mdot
.734 .15213 Mdot
.734 .15246 Mdot
.734 .15274 Mdot
.734 .15308 Mdot
.734 .15313 Mdot
.734 .15353 Mdot
.734 .1537 Mdot
.734 .15372 Mdot
.734 .15396 Mdot
.734 .15414 Mdot
.734 .1549 Mdot
.734 .15526 Mdot
.734 .15568 Mdot
.734 .15603 Mdot
.734 .15694 Mdot
.734 .15725 Mdot
.734 .15729 Mdot
.734 .15884 Mdot
.734 .15991 Mdot
.734 .16032 Mdot
.734 .16059 Mdot
.734 .16063 Mdot
.734 .16091 Mdot
.734 .16096 Mdot
.734 .16132 Mdot
.734 .16134 Mdot
.734 .16244 Mdot
.734 .16325 Mdot
.734 .1634 Mdot
.734 .16342 Mdot
.734 .1639 Mdot
.734 .16409 Mdot
.734 .16428 Mdot
.734 .16556 Mdot
.734 .16617 Mdot
.734 .16686 Mdot
.734 .16732 Mdot
.734 .16742 Mdot
.734 .16749 Mdot
.734 .16778 Mdot
.734 .16792 Mdot
.734 .16803 Mdot
.734 .16888 Mdot
.734 .16908 Mdot
.734 .16925 Mdot
.734 .16972 Mdot
.734 .16986 Mdot
.734 .17013 Mdot
.734 .17033 Mdot
.734 .17041 Mdot
.734 .17047 Mdot
.734 .17051 Mdot
.734 .17064 Mdot
.734 .17064 Mdot
.734 .17166 Mdot
.734 .17168 Mdot
.734 .17194 Mdot
.734 .17231 Mdot
.734 .17234 Mdot
.734 .17237 Mdot
.734 .17332 Mdot
.734 .17336 Mdot
.734 .17342 Mdot
.734 .17343 Mdot
.734 .17371 Mdot
.734 .17373 Mdot
.734 .17383 Mdot
.734 .17476 Mdot
.734 .17479 Mdot
.734 .17494 Mdot
.734 .17498 Mdot
.734 .17562 Mdot
.734 .17591 Mdot
.734 .17593 Mdot
.734 .17626 Mdot
.734 .1764 Mdot
.734 .17751 Mdot
.734 .17768 Mdot
.734 .1779 Mdot
.734 .17795 Mdot
.734 .17801 Mdot
.734 .17827 Mdot
.734 .17842 Mdot
.734 .17858 Mdot
.734 .17942 Mdot
.734 .17964 Mdot
.734 .18065 Mdot
.734 .18077 Mdot
.734 .18119 Mdot
.734 .18128 Mdot
.734 .18158 Mdot
.734 .18235 Mdot
.734 .18255 Mdot
.734 .18319 Mdot
.734 .18333 Mdot
.734 .18341 Mdot
.734 .18373 Mdot
.734 .1844 Mdot
.734 .18468 Mdot
.734 .18488 Mdot
.734 .18491 Mdot
.734 .18546 Mdot
.734 .1855 Mdot
.734 .18586 Mdot
.734 .18642 Mdot
.734 .18643 Mdot
.734 .18673 Mdot
.734 .18697 Mdot
.734 .18707 Mdot
.734 .18708 Mdot
.734 .18768 Mdot
.734 .18779 Mdot
.734 .1882 Mdot
.734 .18869 Mdot
.734 .18904 Mdot
.734 .18916 Mdot
.734 .18919 Mdot
.734 .18946 Mdot
.734 .19034 Mdot
.734 .19069 Mdot
.734 .19186 Mdot
.734 .19204 Mdot
.734 .19215 Mdot
.734 .19229 Mdot
.734 .19257 Mdot
.734 .19268 Mdot
.734 .19289 Mdot
.734 .19315 Mdot
.734 .19334 Mdot
.734 .19353 Mdot
.734 .19422 Mdot
.734 .19431 Mdot
.734 .19435 Mdot
.734 .19475 Mdot
.734 .19521 Mdot
.734 .19536 Mdot
.734 .1958 Mdot
.734 .19623 Mdot
.734 .19648 Mdot
.734 .19698 Mdot
.734 .19748 Mdot
.734 .19794 Mdot
.734 .19893 Mdot
.734 .19979 Mdot
.734 .20019 Mdot
.734 .20021 Mdot
.734 .20038 Mdot
.734 .20071 Mdot
.734 .20105 Mdot
.734 .20111 Mdot
.734 .20154 Mdot
.734 .20176 Mdot
.734 .20206 Mdot
.734 .20207 Mdot
.734 .20209 Mdot
.734 .20218 Mdot
.734 .20222 Mdot
.734 .20251 Mdot
.734 .20278 Mdot
.734 .20343 Mdot
.734 .2035 Mdot
.734 .20372 Mdot
.734 .20398 Mdot
.734 .20405 Mdot
.734 .20491 Mdot
.734 .20497 Mdot
.734 .20565 Mdot
.734 .20572 Mdot
.734 .2062 Mdot
.734 .2063 Mdot
.734 .20637 Mdot
.734 .20691 Mdot
.734 .20707 Mdot
.734 .20797 Mdot
.734 .20869 Mdot
.734 .20969 Mdot
.734 .20984 Mdot
.734 .21056 Mdot
.734 .21084 Mdot
.734 .21114 Mdot
.734 .21137 Mdot
.734 .21157 Mdot
.734 .21177 Mdot
.734 .21204 Mdot
.734 .2123 Mdot
.734 .21248 Mdot
.734 .2125 Mdot
.734 .21267 Mdot
.734 .2136 Mdot
.734 .21392 Mdot
.734 .21429 Mdot
.734 .21444 Mdot
.734 .2145 Mdot
.734 .21489 Mdot
.734 .21505 Mdot
.734 .21507 Mdot
.734 .21575 Mdot
.734 .21643 Mdot
.734 .21663 Mdot
.734 .21692 Mdot
.734 .21734 Mdot
.734 .21784 Mdot
.734 .21791 Mdot
.734 .2185 Mdot
.734 .21875 Mdot
.734 .21878 Mdot
.734 .21912 Mdot
.734 .21939 Mdot
.734 .2205 Mdot
.734 .22103 Mdot
.734 .22165 Mdot
.734 .22216 Mdot
.734 .22351 Mdot
.734 .22395 Mdot
.734 .22402 Mdot
.734 .22629 Mdot
.734 .22786 Mdot
.734 .22846 Mdot
.734 .22886 Mdot
.734 .22891 Mdot
.734 .22934 Mdot
.734 .2294 Mdot
.734 .22992 Mdot
.734 .22996 Mdot
.734 .23157 Mdot
.734 .23277 Mdot
.734 .23298 Mdot
.734 .23302 Mdot
.734 .23372 Mdot
.734 .234 Mdot
.734 .23427 Mdot
.734 .23615 Mdot
.734 .23705 Mdot
.734 .23807 Mdot
.734 .23874 Mdot
.734 .23889 Mdot
.734 .23898 Mdot
.734 .23941 Mdot
.734 .23961 Mdot
.734 .23978 Mdot
.734 .24102 Mdot
.734 .24132 Mdot
.734 .24158 Mdot
.734 .24227 Mdot
.734 .24246 Mdot
.734 .24287 Mdot
.734 .24315 Mdot
.734 .24328 Mdot
.734 .24337 Mdot
.734 .24341 Mdot
.734 .24361 Mdot
.734 .24362 Mdot
.734 .24511 Mdot
.734 .24514 Mdot
.734 .24552 Mdot
.734 .24606 Mdot
.734 .24612 Mdot
.734 .24615 Mdot
.734 .24755 Mdot
.734 .24761 Mdot
.734 .2477 Mdot
.734 .24771 Mdot
.734 .24812 Mdot
.734 .24815 Mdot
.734 .2483 Mdot
.734 .24966 Mdot
.734 .24971 Mdot
.734 .24993 Mdot
.734 .24999 Mdot
.734 .25092 Mdot
.734 .25135 Mdot
.734 .25138 Mdot
.734 .25186 Mdot
.734 .25206 Mdot
.734 .2537 Mdot
.734 .25395 Mdot
.734 .25428 Mdot
.734 .25434 Mdot
.734 .25443 Mdot
.734 .25481 Mdot
.734 .25503 Mdot
.734 .25527 Mdot
.734 .25651 Mdot
.734 .25683 Mdot
.734 .2583 Mdot
.734 .25848 Mdot
.734 .25911 Mdot
.734 .25923 Mdot
.734 .25967 Mdot
.734 .2608 Mdot
.734 .26109 Mdot
.734 .26203 Mdot
.734 .26224 Mdot
.734 .26236 Mdot
.734 .26283 Mdot
.734 .26381 Mdot
.734 .26423 Mdot
.734 .26452 Mdot
.734 .26456 Mdot
.734 .26537 Mdot
.734 .26542 Mdot
.734 .26596 Mdot
.734 .26678 Mdot
.734 .26679 Mdot
.734 .26724 Mdot
.734 .26759 Mdot
.734 .26773 Mdot
.734 .26775 Mdot
.734 .26862 Mdot
.734 .26878 Mdot
.734 .26939 Mdot
.734 .27012 Mdot
.734 .27062 Mdot
.734 .27081 Mdot
.734 .27084 Mdot
.734 .27124 Mdot
.734 .27254 Mdot
.734 .27304 Mdot
.734 .27476 Mdot
.734 .27503 Mdot
.734 .27519 Mdot
.734 .27539 Mdot
.734 .27581 Mdot
.734 .27596 Mdot
.734 .27627 Mdot
.734 .27666 Mdot
.734 .27694 Mdot
.734 .27722 Mdot
.734 .27822 Mdot
.734 .27836 Mdot
.734 .27842 Mdot
.734 .279 Mdot
.734 .27968 Mdot
.734 .2799 Mdot
.734 .28055 Mdot
.734 .28118 Mdot
.734 .28154 Mdot
.734 .28227 Mdot
.734 .28301 Mdot
.734 .2837 Mdot
.734 .28514 Mdot
.734 .28641 Mdot
.734 .28699 Mdot
.734 .28702 Mdot
.734 .28728 Mdot
.734 .28776 Mdot
.734 .28825 Mdot
.734 .28834 Mdot
.734 .28897 Mdot
.734 .28929 Mdot
.734 .28973 Mdot
.734 .28975 Mdot
.734 .28978 Mdot
.734 .28991 Mdot
.734 .28997 Mdot
.734 .2904 Mdot
.734 .2908 Mdot
.734 .29175 Mdot
.734 .29186 Mdot
.734 .29217 Mdot
.734 .29256 Mdot
.734 .29266 Mdot
.734 .29392 Mdot
.734 .29401 Mdot
.734 .295 Mdot
.734 .29511 Mdot
.734 .29581 Mdot
.734 .29596 Mdot
.734 .29607 Mdot
.734 .29686 Mdot
.734 .29709 Mdot
.734 .29842 Mdot
.734 .29947 Mdot
.734 .30094 Mdot
.734 .30116 Mdot
.734 .30221 Mdot
.734 .30263 Mdot
.734 .30306 Mdot
.734 .3034 Mdot
.734 .3037 Mdot
.734 .30399 Mdot
.734 .30439 Mdot
.734 .30476 Mdot
.734 .30503 Mdot
.734 .30507 Mdot
.734 .30532 Mdot
.734 .30668 Mdot
.734 .30714 Mdot
.734 .3077 Mdot
.734 .30791 Mdot
.734 .30799 Mdot
.734 .30857 Mdot
.734 .30881 Mdot
.734 .30884 Mdot
.734 .30983 Mdot
.734 .31084 Mdot
.734 .31113 Mdot
.734 .31156 Mdot
.734 .31217 Mdot
.734 .3129 Mdot
.734 .313 Mdot
.734 .31386 Mdot
.734 .31424 Mdot
.734 .31428 Mdot
.734 .31479 Mdot
.734 .31518 Mdot
.734 .31681 Mdot
.734 .31758 Mdot
.734 .3185 Mdot
.734 .31925 Mdot
.734 .32122 Mdot
.734 .32188 Mdot
.734 .32198 Mdot
.734 .3253 Mdot
.734 .32762 Mdot
.734 .32849 Mdot
.734 .32908 Mdot
.734 .32916 Mdot
.734 .32978 Mdot
.734 .32988 Mdot
.734 .33064 Mdot
.734 .3307 Mdot
.734 .33306 Mdot
.734 .33482 Mdot
.734 .33513 Mdot
.734 .33519 Mdot
.734 .33621 Mdot
.734 .33663 Mdot
.734 .33702 Mdot
.734 .33978 Mdot
.734 .3411 Mdot
.734 .3426 Mdot
.734 .34359 Mdot
.734 .3438 Mdot
.734 .34394 Mdot
.734 .34457 Mdot
.734 .34486 Mdot
.734 .34511 Mdot
.734 .34693 Mdot
.734 .34737 Mdot
.734 .34775 Mdot
.734 .34876 Mdot
.734 .34905 Mdot
.734 .34964 Mdot
.734 .35006 Mdot
.734 .35025 Mdot
.734 .35038 Mdot
.734 .35045 Mdot
.734 .35074 Mdot
.734 .35074 Mdot
.734 .35294 Mdot
.734 .35298 Mdot
.734 .35354 Mdot
.734 .35433 Mdot
.734 .35441 Mdot
.734 .35447 Mdot
.734 .35652 Mdot
.734 .35661 Mdot
.734 .35674 Mdot
.734 .35674 Mdot
.734 .35735 Mdot
.734 .35739 Mdot
.734 .35761 Mdot
.734 .35961 Mdot
.734 .35968 Mdot
.734 .36001 Mdot
.734 .36009 Mdot
.734 .36146 Mdot
.734 .3621 Mdot
.734 .36214 Mdot
.734 .36285 Mdot
.734 .36314 Mdot
.734 .36554 Mdot
.734 .36591 Mdot
.734 .36639 Mdot
.734 .36648 Mdot
.734 .36662 Mdot
.734 .36718 Mdot
.734 .3675 Mdot
.734 .36785 Mdot
.734 .36967 Mdot
.734 .37014 Mdot
.734 .3723 Mdot
.734 .37256 Mdot
.734 .37348 Mdot
.734 .37367 Mdot
.734 .37431 Mdot
.734 .37597 Mdot
.734 .37639 Mdot
.734 .37777 Mdot
.734 .37809 Mdot
.734 .37826 Mdot
.734 .37894 Mdot
.734 .38039 Mdot
.734 .381 Mdot
.734 .38142 Mdot
.734 .38149 Mdot
.734 .38267 Mdot
.734 .38275 Mdot
.734 .38354 Mdot
.734 .38475 Mdot
.734 .38477 Mdot
.734 .38542 Mdot
.734 .38594 Mdot
.734 .38614 Mdot
.734 .38617 Mdot
.734 .38745 Mdot
.734 .38769 Mdot
.734 .38857 Mdot
.734 .38964 Mdot
.734 .39038 Mdot
.734 .39066 Mdot
.734 .39071 Mdot
.734 .39129 Mdot
.734 .3932 Mdot
.734 .39394 Mdot
.734 .39646 Mdot
.734 .39686 Mdot
.734 .39709 Mdot
.734 .39738 Mdot
.734 .398 Mdot
.734 .39822 Mdot
.734 .39868 Mdot
.734 .39925 Mdot
.734 .39966 Mdot
.734 .40007 Mdot
.734 .40154 Mdot
.734 .40175 Mdot
.734 .40184 Mdot
.734 .40268 Mdot
.734 .40368 Mdot
.734 .404 Mdot
.734 .40496 Mdot
.734 .40589 Mdot
.734 .40642 Mdot
.734 .40749 Mdot
.734 .40857 Mdot
.734 .40958 Mdot
.734 .4117 Mdot
.734 .41356 Mdot
.734 .41442 Mdot
.734 .41446 Mdot
.734 .41483 Mdot
.734 .41555 Mdot
.734 .41627 Mdot
.734 .4164 Mdot
.734 .41732 Mdot
.734 .41779 Mdot
.734 .41844 Mdot
.734 .41847 Mdot
.734 .41851 Mdot
.734 .4187 Mdot
.734 .41879 Mdot
.734 .41942 Mdot
.734 .42 Mdot
.734 .42141 Mdot
.734 .42156 Mdot
.734 .42202 Mdot
.734 .4226 Mdot
.734 .42275 Mdot
.734 .42459 Mdot
.734 .42472 Mdot
.734 .42618 Mdot
.734 .42633 Mdot
.734 .42737 Mdot
.734 .42758 Mdot
.734 .42774 Mdot
.734 .42891 Mdot
.734 .42925 Mdot
.734 .43119 Mdot
.734 .43274 Mdot
.734 .43489 Mdot
.734 .43521 Mdot
.734 .43676 Mdot
.734 .43737 Mdot
.734 .43801 Mdot
.734 .43851 Mdot
.734 .43895 Mdot
.734 .43937 Mdot
.734 .43996 Mdot
.734 .44051 Mdot
.734 .4409 Mdot
.734 .44095 Mdot
.734 .44132 Mdot
.734 .44331 Mdot
.734 .444 Mdot
.734 .44481 Mdot
.734 .44513 Mdot
.734 .44525 Mdot
.734 .44609 Mdot
.734 .44645 Mdot
.734 .44649 Mdot
.734 .44794 Mdot
.736 .01643 Mdot
.736 .01695 Mdot
.736 .01703 Mdot
.736 .01725 Mdot
.736 .01776 Mdot
.736 .01801 Mdot
.736 .01805 Mdot
.736 .01812 Mdot
.736 .01814 Mdot
.736 .01844 Mdot
.736 .0192 Mdot
.736 .01956 Mdot
.736 .01962 Mdot
.736 .01967 Mdot
.736 .01973 Mdot
.736 .01976 Mdot
.736 .02005 Mdot
.736 .0202 Mdot
.736 .02049 Mdot
.736 .02098 Mdot
.736 .02098 Mdot
.736 .02132 Mdot
.736 .02175 Mdot
.736 .02184 Mdot
.736 .02194 Mdot
.736 .02201 Mdot
.736 .02201 Mdot
.736 .0221 Mdot
.736 .02215 Mdot
.736 .02248 Mdot
.736 .02257 Mdot
.736 .02279 Mdot
.736 .02322 Mdot
.736 .02393 Mdot
.736 .02394 Mdot
.736 .02444 Mdot
.736 .02507 Mdot
.736 .02521 Mdot
.736 .02535 Mdot
.736 .02545 Mdot
.736 .02545 Mdot
.736 .02559 Mdot
.736 .02565 Mdot
.736 .02615 Mdot
.736 .02627 Mdot
.736 .0266 Mdot
.736 .02724 Mdot
.736 .02736 Mdot
.736 .02771 Mdot
.736 .02793 Mdot
.736 .02803 Mdot
.736 .02828 Mdot
.736 .02829 Mdot
.736 .02903 Mdot
.736 .02941 Mdot
.736 .02995 Mdot
.736 .03016 Mdot
.736 .03036 Mdot
.736 .0305 Mdot
.736 .03051 Mdot
.736 .03052 Mdot
.736 .03072 Mdot
.736 .03082 Mdot
.736 .03154 Mdot
.736 .03173 Mdot
.736 .0322 Mdot
.736 .03315 Mdot
.736 .03316 Mdot
.736 .03333 Mdot
.736 .03385 Mdot
.736 .03417 Mdot
.736 .03431 Mdot
.736 .0346 Mdot
.736 .03469 Mdot
.736 .0347 Mdot
.736 .03506 Mdot
.736 .03576 Mdot
.736 .03579 Mdot
.736 .03592 Mdot
.736 .03633 Mdot
.736 .03635 Mdot
.736 .03688 Mdot
.736 .03715 Mdot
.736 .03746 Mdot
.736 .03775 Mdot
.736 .03796 Mdot
.736 .03797 Mdot
.736 .03798 Mdot
.736 .03802 Mdot
.736 .03828 Mdot
.736 .03834 Mdot
.736 .03842 Mdot
.736 .03925 Mdot
.736 .03949 Mdot
.736 .03967 Mdot
.736 .03976 Mdot
.736 .03989 Mdot
.736 .04015 Mdot
.736 .04046 Mdot
.736 .04184 Mdot
.736 .04186 Mdot
.736 .04212 Mdot
.736 .04288 Mdot
.736 .04335 Mdot
.736 .04344 Mdot
.736 .04356 Mdot
.736 .04394 Mdot
.736 .04398 Mdot
.736 .04411 Mdot
.736 .04414 Mdot
.736 .04417 Mdot
.736 .04463 Mdot
.736 .04467 Mdot
.736 .04536 Mdot
.736 .0457 Mdot
.736 .04573 Mdot
.736 .04593 Mdot
.736 .04654 Mdot
.736 .04656 Mdot
.736 .04689 Mdot
.736 .04734 Mdot
.736 .04773 Mdot
.736 .04819 Mdot
.736 .04862 Mdot
.736 .04893 Mdot
.736 .04894 Mdot
.736 .04896 Mdot
.736 .04903 Mdot
.736 .0494 Mdot
.736 .04949 Mdot
.736 .0496 Mdot
.736 .05082 Mdot
.736 .05118 Mdot
.736 .05144 Mdot
.736 .05158 Mdot
.736 .05177 Mdot
.736 .05215 Mdot
.736 .05235 Mdot
.736 .05261 Mdot
.736 .05322 Mdot
.736 .05465 Mdot
.736 .05468 Mdot
.736 .05505 Mdot
.736 .05597 Mdot
.736 .05618 Mdot
.736 .05636 Mdot
.736 .05687 Mdot
.736 .057 Mdot
.736 .05717 Mdot
.736 .05773 Mdot
.736 .0578 Mdot
.736 .05799 Mdot
.736 .05802 Mdot
.736 .05807 Mdot
.736 .05874 Mdot
.736 .05881 Mdot
.736 .05931 Mdot
.736 .05982 Mdot
.736 .05991 Mdot
.736 .06032 Mdot
.736 .06037 Mdot
.736 .06066 Mdot
.736 .06128 Mdot
.736 .06155 Mdot
.736 .06159 Mdot
.736 .06188 Mdot
.736 .06208 Mdot
.736 .06214 Mdot
.736 .06274 Mdot
.736 .06298 Mdot
.736 .06332 Mdot
.736 .0636 Mdot
.736 .06367 Mdot
.736 .06399 Mdot
.736 .06463 Mdot
.736 .06505 Mdot
.736 .06508 Mdot
.736 .0651 Mdot
.736 .06512 Mdot
.736 .06522 Mdot
.736 .06577 Mdot
.736 .06591 Mdot
.736 .06607 Mdot
.736 .06643 Mdot
.736 .06787 Mdot
.736 .068 Mdot
.736 .06835 Mdot
.736 .06839 Mdot
.736 .06878 Mdot
.736 .06881 Mdot
.736 .06898 Mdot
.736 .06926 Mdot
.736 .06982 Mdot
.736 .07011 Mdot
.736 .07049 Mdot
.736 .0705 Mdot
.736 .07111 Mdot
.736 .0714 Mdot
.736 .07153 Mdot
.736 .07242 Mdot
.736 .0735 Mdot
.736 .07354 Mdot
.736 .07391 Mdot
.736 .07409 Mdot
.736 .07467 Mdot
.736 .07575 Mdot
.736 .07602 Mdot
.736 .0763 Mdot
.736 .07675 Mdot
.736 .07676 Mdot
.736 .0768 Mdot
.736 .07696 Mdot
.736 .07721 Mdot
.736 .07753 Mdot
.736 .07803 Mdot
.736 .07813 Mdot
.736 .07841 Mdot
.736 .07847 Mdot
.736 .07853 Mdot
.736 .07952 Mdot
.736 .07961 Mdot
.736 .07962 Mdot
.736 .08036 Mdot
.736 .08064 Mdot
.736 .08074 Mdot
.736 .08082 Mdot
.736 .08107 Mdot
.736 .08111 Mdot
.736 .08124 Mdot
.736 .08185 Mdot
.736 .08192 Mdot
.736 .08202 Mdot
.736 .08235 Mdot
.736 .08327 Mdot
.736 .08366 Mdot
.736 .08372 Mdot
.736 .08415 Mdot
.736 .08443 Mdot
.736 .08452 Mdot
.736 .08456 Mdot
.736 .0854 Mdot
.736 .08552 Mdot
.736 .08577 Mdot
.736 .08626 Mdot
.736 .08667 Mdot
.736 .08678 Mdot
.736 .08725 Mdot
.736 .08726 Mdot
.736 .08819 Mdot
.736 .08881 Mdot
.736 .08885 Mdot
.736 .08888 Mdot
.736 .08892 Mdot
.736 .08906 Mdot
.736 .08986 Mdot
.736 .09007 Mdot
.736 .09031 Mdot
.736 .09083 Mdot
.736 .09156 Mdot
.736 .09179 Mdot
.736 .09202 Mdot
.736 .09227 Mdot
.736 .09296 Mdot
.736 .09315 Mdot
.736 .09326 Mdot
.736 .09366 Mdot
.736 .09373 Mdot
.736 .0943 Mdot
.736 .09434 Mdot
.736 .09459 Mdot
.736 .09501 Mdot
.736 .09583 Mdot
.736 .09626 Mdot
.736 .09682 Mdot
.736 .09683 Mdot
.736 .09759 Mdot
.736 .09772 Mdot
.736 .09816 Mdot
.736 .09834 Mdot
.736 .09858 Mdot
.736 .09883 Mdot
.736 .09966 Mdot
.736 .09966 Mdot
.736 .1 Mdot
.736 .10023 Mdot
.736 .10124 Mdot
.736 .10131 Mdot
.736 .10151 Mdot
.736 .10185 Mdot
.736 .10189 Mdot
.736 .10211 Mdot
.736 .10297 Mdot
.736 .10437 Mdot
.736 .10455 Mdot
.736 .10496 Mdot
.736 .10535 Mdot
.736 .10537 Mdot
.736 .10552 Mdot
.736 .10603 Mdot
.736 .10605 Mdot
.736 .1061 Mdot
.736 .10633 Mdot
.736 .1067 Mdot
.736 .10718 Mdot
.736 .10779 Mdot
.736 .10791 Mdot
.736 .10807 Mdot
.736 .10813 Mdot
.736 .10847 Mdot
.736 .10856 Mdot
.736 .10865 Mdot
.736 .11011 Mdot
.736 .11019 Mdot
.736 .11023 Mdot
.736 .11025 Mdot
.736 .11055 Mdot
.736 .11135 Mdot
.736 .11175 Mdot
.736 .1119 Mdot
.736 .11194 Mdot
.736 .11202 Mdot
.736 .11214 Mdot
.736 .11238 Mdot
.736 .11245 Mdot
.736 .11264 Mdot
.736 .11273 Mdot
.736 .11284 Mdot
.736 .11354 Mdot
.736 .11364 Mdot
.736 .11369 Mdot
.736 .11379 Mdot
.736 .11427 Mdot
.736 .11544 Mdot
.736 .11562 Mdot
.736 .11621 Mdot
.736 .11629 Mdot
.736 .11692 Mdot
.736 .11705 Mdot
.736 .11734 Mdot
.736 .11747 Mdot
.736 .11752 Mdot
.736 .1177 Mdot
.736 .11814 Mdot
.736 .11877 Mdot
.736 .11894 Mdot
.736 .1193 Mdot
.736 .11952 Mdot
.736 .12003 Mdot
.736 .12019 Mdot
.736 .12063 Mdot
.736 .1208 Mdot
.736 .12148 Mdot
.736 .1215 Mdot
.736 .12155 Mdot
.736 .12176 Mdot
.736 .1223 Mdot
.736 .12287 Mdot
.736 .12379 Mdot
.736 .12384 Mdot
.736 .12388 Mdot
.736 .12394 Mdot
.736 .12415 Mdot
.736 .12507 Mdot
.736 .12534 Mdot
.736 .12551 Mdot
.736 .12563 Mdot
.736 .12591 Mdot
.736 .12599 Mdot
.736 .12676 Mdot
.736 .12775 Mdot
.736 .12783 Mdot
.736 .12817 Mdot
.736 .1285 Mdot
.736 .12887 Mdot
.736 .12945 Mdot
.736 .12974 Mdot
.736 .12988 Mdot
.736 .13018 Mdot
.736 .13033 Mdot
.736 .13092 Mdot
.736 .13102 Mdot
.736 .1315 Mdot
.736 .13186 Mdot
.736 .13192 Mdot
.736 .13229 Mdot
.736 .13269 Mdot
.736 .1329 Mdot
.736 .13334 Mdot
.736 .13412 Mdot
.736 .13436 Mdot
.736 .13475 Mdot
.736 .13557 Mdot
.736 .13559 Mdot
.736 .13599 Mdot
.736 .13643 Mdot
.736 .13663 Mdot
.736 .13671 Mdot
.736 .1369 Mdot
.736 .137 Mdot
.736 .13754 Mdot
.736 .13781 Mdot
.736 .13817 Mdot
.736 .13853 Mdot
.736 .13975 Mdot
.736 .13975 Mdot
.736 .14007 Mdot
.736 .14025 Mdot
.736 .1406 Mdot
.736 .14121 Mdot
.736 .14209 Mdot
.736 .14218 Mdot
.736 .14247 Mdot
.736 .14298 Mdot
.736 .14303 Mdot
.736 .14304 Mdot
.736 .14336 Mdot
.736 .14463 Mdot
.736 .14668 Mdot
.736 .1469 Mdot
.736 .14696 Mdot
.736 .14698 Mdot
.736 .14755 Mdot
.736 .14755 Mdot
.736 .14814 Mdot
.736 .14816 Mdot
.736 .14838 Mdot
.736 .14883 Mdot
.736 .14913 Mdot
.736 .14916 Mdot
.736 .14923 Mdot
.736 .14958 Mdot
.736 .15012 Mdot
.736 .15082 Mdot
.736 .1509 Mdot
.736 .15171 Mdot
.736 .15188 Mdot
.736 .1519 Mdot
.736 .15213 Mdot
.736 .15222 Mdot
.736 .15225 Mdot
.736 .15273 Mdot
.736 .15285 Mdot
.736 .15299 Mdot
.736 .15314 Mdot
.736 .15361 Mdot
.736 .15514 Mdot
.736 .15525 Mdot
.736 .15532 Mdot
.736 .15535 Mdot
.736 .15578 Mdot
.736 .15613 Mdot
.736 .15696 Mdot
.736 .15741 Mdot
.736 .15756 Mdot
.736 .15778 Mdot
.736 .15782 Mdot
.736 .15795 Mdot
.736 .15812 Mdot
.736 .15848 Mdot
.736 .15858 Mdot
.736 .15887 Mdot
.736 .159 Mdot
.736 .15907 Mdot
.736 .15915 Mdot
.736 .16018 Mdot
.736 .16034 Mdot
.736 .16041 Mdot
.736 .16055 Mdot
.736 .16078 Mdot
.736 .16126 Mdot
.736 .16298 Mdot
.736 .16325 Mdot
.736 .16411 Mdot
.736 .16423 Mdot
.736 .16516 Mdot
.736 .16535 Mdot
.736 .16578 Mdot
.736 .16596 Mdot
.736 .16604 Mdot
.736 .16631 Mdot
.736 .1665 Mdot
.736 .16653 Mdot
.736 .16696 Mdot
.736 .16739 Mdot
.736 .16788 Mdot
.736 .16799 Mdot
.736 .16814 Mdot
.736 .16867 Mdot
.736 .16886 Mdot
.736 .16899 Mdot
.736 .16927 Mdot
.736 .16974 Mdot
.736 .16997 Mdot
.736 .17048 Mdot
.736 .17062 Mdot
.736 .17064 Mdot
.736 .17087 Mdot
.736 .17152 Mdot
.736 .17184 Mdot
.736 .17188 Mdot
.736 .1719 Mdot
.736 .17198 Mdot
.736 .17228 Mdot
.736 .17307 Mdot
.736 .17338 Mdot
.736 .17392 Mdot
.736 .17527 Mdot
.736 .17534 Mdot
.736 .17541 Mdot
.736 .17549 Mdot
.736 .1758 Mdot
.736 .17716 Mdot
.736 .17747 Mdot
.736 .17755 Mdot
.736 .17781 Mdot
.736 .17791 Mdot
.736 .17799 Mdot
.736 .17839 Mdot
.736 .17851 Mdot
.736 .17928 Mdot
.736 .17965 Mdot
.736 .18036 Mdot
.736 .18046 Mdot
.736 .18111 Mdot
.736 .18122 Mdot
.736 .18166 Mdot
.736 .18172 Mdot
.736 .18191 Mdot
.736 .18194 Mdot
.736 .18221 Mdot
.736 .18275 Mdot
.736 .18326 Mdot
.736 .18346 Mdot
.736 .1836 Mdot
.736 .18404 Mdot
.736 .18425 Mdot
.736 .18467 Mdot
.736 .18474 Mdot
.736 .18491 Mdot
.736 .18578 Mdot
.736 .18591 Mdot
.736 .18604 Mdot
.736 .18662 Mdot
.736 .18715 Mdot
.736 .18724 Mdot
.736 .18779 Mdot
.736 .18816 Mdot
.736 .18837 Mdot
.736 .18869 Mdot
.736 .1892 Mdot
.736 .18934 Mdot
.736 .1894 Mdot
.736 .18952 Mdot
.736 .19048 Mdot
.736 .19084 Mdot
.736 .19141 Mdot
.736 .19262 Mdot
.736 .19264 Mdot
.736 .19282 Mdot
.736 .19323 Mdot
.736 .19387 Mdot
.736 .19418 Mdot
.736 .1943 Mdot
.736 .19458 Mdot
.736 .19472 Mdot
.736 .19551 Mdot
.736 .19591 Mdot
.736 .19643 Mdot
.736 .19697 Mdot
.736 .19877 Mdot
.736 .19877 Mdot
.736 .19904 Mdot
.736 .19923 Mdot
.736 .1995 Mdot
.736 .19963 Mdot
.736 .20001 Mdot
.736 .20006 Mdot
.736 .20034 Mdot
.736 .20044 Mdot
.736 .20092 Mdot
.736 .2022 Mdot
.736 .20234 Mdot
.736 .20277 Mdot
.736 .20311 Mdot
.736 .20314 Mdot
.736 .20352 Mdot
.736 .2036 Mdot
.736 .20361 Mdot
.736 .20402 Mdot
.736 .20408 Mdot
.736 .20448 Mdot
.736 .20489 Mdot
.736 .20556 Mdot
.736 .20588 Mdot
.736 .20594 Mdot
.736 .20598 Mdot
.736 .20702 Mdot
.736 .20897 Mdot
.736 .20915 Mdot
.736 .20929 Mdot
.736 .20937 Mdot
.736 .20941 Mdot
.736 .21024 Mdot
.736 .21025 Mdot
.736 .21053 Mdot
.736 .21067 Mdot
.736 .2108 Mdot
.736 .21101 Mdot
.736 .21111 Mdot
.736 .21114 Mdot
.736 .21147 Mdot
.736 .21214 Mdot
.736 .21257 Mdot
.736 .21261 Mdot
.736 .21265 Mdot
.736 .21272 Mdot
.736 .21324 Mdot
.736 .21404 Mdot
.736 .21506 Mdot
.736 .21517 Mdot
.736 .21521 Mdot
.736 .21638 Mdot
.736 .21662 Mdot
.736 .21665 Mdot
.736 .21699 Mdot
.736 .21712 Mdot
.736 .21717 Mdot
.736 .21787 Mdot
.736 .21805 Mdot
.736 .21825 Mdot
.736 .21848 Mdot
.736 .21848 Mdot
.736 .21883 Mdot
.736 .21895 Mdot
.736 .21917 Mdot
.736 .22142 Mdot
.736 .22158 Mdot
.736 .22168 Mdot
.736 .22173 Mdot
.736 .22237 Mdot
.736 .22287 Mdot
.736 .2241 Mdot
.736 .22476 Mdot
.736 .22498 Mdot
.736 .2253 Mdot
.736 .22537 Mdot
.736 .22556 Mdot
.736 .22581 Mdot
.736 .22634 Mdot
.736 .22649 Mdot
.736 .22691 Mdot
.736 .2271 Mdot
.736 .2272 Mdot
.736 .22732 Mdot
.736 .22884 Mdot
.736 .22907 Mdot
.736 .22918 Mdot
.736 .22939 Mdot
.736 .22973 Mdot
.736 .23043 Mdot
.736 .23295 Mdot
.736 .23336 Mdot
.736 .23462 Mdot
.736 .23481 Mdot
.736 .23617 Mdot
.736 .23644 Mdot
.736 .23708 Mdot
.736 .23735 Mdot
.736 .23747 Mdot
.736 .23786 Mdot
.736 .23815 Mdot
.736 .23818 Mdot
.736 .23882 Mdot
.736 .23945 Mdot
.736 .24018 Mdot
.736 .24034 Mdot
.736 .24055 Mdot
.736 .24133 Mdot
.736 .24161 Mdot
.736 .2418 Mdot
.736 .24222 Mdot
.736 .2429 Mdot
.736 .24326 Mdot
.736 .24401 Mdot
.736 .24421 Mdot
.736 .24424 Mdot
.736 .24457 Mdot
.736 .24553 Mdot
.736 .24601 Mdot
.736 .24606 Mdot
.736 .24609 Mdot
.736 .24621 Mdot
.736 .24665 Mdot
.736 .24782 Mdot
.736 .24826 Mdot
.736 .24907 Mdot
.736 .25105 Mdot
.736 .25116 Mdot
.736 .25126 Mdot
.736 .25138 Mdot
.736 .25183 Mdot
.736 .25384 Mdot
.736 .25429 Mdot
.736 .25441 Mdot
.736 .25479 Mdot
.736 .25494 Mdot
.736 .25505 Mdot
.736 .25564 Mdot
.736 .25582 Mdot
.736 .25696 Mdot
.736 .25749 Mdot
.736 .25854 Mdot
.736 .2587 Mdot
.736 .25965 Mdot
.736 .25981 Mdot
.736 .26045 Mdot
.736 .26055 Mdot
.736 .26082 Mdot
.736 .26087 Mdot
.736 .26126 Mdot
.736 .26207 Mdot
.736 .26281 Mdot
.736 .26311 Mdot
.736 .26332 Mdot
.736 .26395 Mdot
.736 .26426 Mdot
.736 .26489 Mdot
.736 .26499 Mdot
.736 .26523 Mdot
.736 .26652 Mdot
.736 .26672 Mdot
.736 .2669 Mdot
.736 .26775 Mdot
.736 .26854 Mdot
.736 .26867 Mdot
.736 .26948 Mdot
.736 .27003 Mdot
.736 .27033 Mdot
.736 .2708 Mdot
.736 .27155 Mdot
.736 .27176 Mdot
.736 .27185 Mdot
.736 .27202 Mdot
.736 .27344 Mdot
.736 .27397 Mdot
.736 .27481 Mdot
.736 .27659 Mdot
.736 .27663 Mdot
.736 .27689 Mdot
.736 .27748 Mdot
.736 .27843 Mdot
.736 .27889 Mdot
.736 .27906 Mdot
.736 .27947 Mdot
.736 .27969 Mdot
.736 .28085 Mdot
.736 .28144 Mdot
.736 .28221 Mdot
.736 .283 Mdot
.736 .28564 Mdot
.736 .28565 Mdot
.736 .28605 Mdot
.736 .28632 Mdot
.736 .28672 Mdot
.736 .28691 Mdot
.736 .28748 Mdot
.736 .28755 Mdot
.736 .28795 Mdot
.736 .2881 Mdot
.736 .28881 Mdot
.736 .2907 Mdot
.736 .2909 Mdot
.736 .29154 Mdot
.736 .29203 Mdot
.736 .29208 Mdot
.736 .29263 Mdot
.736 .29275 Mdot
.736 .29276 Mdot
.736 .29337 Mdot
.736 .29347 Mdot
.736 .29405 Mdot
.736 .29465 Mdot
.736 .29563 Mdot
.736 .29611 Mdot
.736 .29621 Mdot
.736 .29626 Mdot
.736 .29778 Mdot
.736 .30066 Mdot
.736 .30093 Mdot
.736 .30113 Mdot
.736 .30125 Mdot
.736 .3013 Mdot
.736 .30253 Mdot
.736 .30255 Mdot
.736 .30295 Mdot
.736 .30317 Mdot
.736 .30335 Mdot
.736 .30366 Mdot
.736 .30381 Mdot
.736 .30386 Mdot
.736 .30434 Mdot
.736 .30532 Mdot
.736 .30596 Mdot
.736 .30602 Mdot
.736 .30608 Mdot
.736 .30618 Mdot
.736 .30694 Mdot
.736 .30812 Mdot
.736 .30962 Mdot
.736 .30979 Mdot
.736 .30984 Mdot
.736 .31156 Mdot
.736 .31191 Mdot
.736 .31197 Mdot
.736 .31247 Mdot
.736 .31266 Mdot
.736 .31273 Mdot
.736 .31376 Mdot
.736 .31402 Mdot
.736 .31432 Mdot
.736 .31465 Mdot
.736 .31465 Mdot
.736 .31517 Mdot
.736 .31535 Mdot
.736 .31567 Mdot
.736 .31899 Mdot
.736 .31923 Mdot
.736 .31937 Mdot
.736 .31944 Mdot
.736 .32038 Mdot
.736 .32112 Mdot
.736 .32293 Mdot
.736 .3239 Mdot
.736 .32422 Mdot
.736 .3247 Mdot
.736 .3248 Mdot
.736 .32508 Mdot
.736 .32545 Mdot
.736 .32623 Mdot
.736 .32645 Mdot
.736 .32706 Mdot
.736 .32735 Mdot
.736 .3275 Mdot
.736 .32767 Mdot
.736 .32991 Mdot
.736 .33025 Mdot
.736 .3304 Mdot
.736 .33072 Mdot
.736 .33121 Mdot
.736 .33225 Mdot
.736 .33596 Mdot
.736 .33656 Mdot
.736 .33842 Mdot
.736 .33869 Mdot
.736 .34069 Mdot
.736 .3411 Mdot
.736 .34203 Mdot
.736 .34244 Mdot
.736 .34261 Mdot
.736 .34319 Mdot
.736 .3436 Mdot
.736 .34366 Mdot
.736 .34459 Mdot
.736 .34553 Mdot
.736 .3466 Mdot
.736 .34683 Mdot
.736 .34714 Mdot
.736 .34829 Mdot
.736 .34871 Mdot
.736 .34899 Mdot
.736 .3496 Mdot
.736 .35061 Mdot
.736 .35113 Mdot
.736 .35223 Mdot
.736 .35254 Mdot
.736 .35257 Mdot
.736 .35307 Mdot
.736 .35448 Mdot
.736 .35518 Mdot
.736 .35525 Mdot
.736 .35531 Mdot
.736 .35547 Mdot
.736 .35612 Mdot
.736 .35784 Mdot
.736 .3585 Mdot
.736 .35968 Mdot
.736 .3626 Mdot
.736 .36276 Mdot
.736 .36291 Mdot
.736 .36308 Mdot
.736 .36376 Mdot
.736 .3667 Mdot
.736 .36737 Mdot
.736 .36754 Mdot
.736 .3681 Mdot
.736 .36833 Mdot
.736 .36849 Mdot
.736 .36936 Mdot
.736 .36962 Mdot
.736 .3713 Mdot
.736 .37208 Mdot
.736 .37362 Mdot
.736 .37386 Mdot
.736 .37526 Mdot
.736 .3755 Mdot
.736 .37644 Mdot
.736 .37658 Mdot
.736 .37698 Mdot
.736 .37705 Mdot
.736 .37764 Mdot
.736 .37882 Mdot
.736 .37991 Mdot
.736 .38036 Mdot
.736 .38066 Mdot
.736 .3816 Mdot
.736 .38205 Mdot
.736 .38298 Mdot
.736 .38311 Mdot
.736 .38348 Mdot
.736 .38537 Mdot
.736 .38567 Mdot
.736 .38593 Mdot
.736 .38719 Mdot
.736 .38834 Mdot
.736 .38854 Mdot
.736 .38973 Mdot
.736 .39054 Mdot
.736 .39099 Mdot
.736 .39168 Mdot
.736 .39278 Mdot
.736 .39308 Mdot
.736 .39322 Mdot
.736 .39347 Mdot
.736 .39555 Mdot
.736 .39633 Mdot
.736 .39757 Mdot
.736 .40019 Mdot
.736 .40025 Mdot
.736 .40063 Mdot
.736 .40151 Mdot
.736 .40291 Mdot
.736 .40358 Mdot
.736 .40383 Mdot
.736 .40443 Mdot
.736 .40475 Mdot
.736 .40646 Mdot
.736 .40734 Mdot
.736 .40846 Mdot
.736 .40963 Mdot
.736 .41351 Mdot
.736 .41353 Mdot
.736 .41411 Mdot
.736 .41452 Mdot
.736 .41511 Mdot
.736 .41539 Mdot
.736 .41622 Mdot
.736 .41632 Mdot
.736 .41692 Mdot
.736 .41714 Mdot
.736 .41818 Mdot
.736 .42096 Mdot
.736 .42127 Mdot
.736 .4222 Mdot
.736 .42292 Mdot
.736 .423 Mdot
.736 .42381 Mdot
.736 .42398 Mdot
.736 .424 Mdot
.736 .4249 Mdot
.736 .42504 Mdot
.736 .4259 Mdot
.736 .42678 Mdot
.736 .42823 Mdot
.736 .42893 Mdot
.736 .42907 Mdot
.736 .42915 Mdot
.736 .43139 Mdot
.736 .43562 Mdot
.736 .43602 Mdot
.736 .43631 Mdot
.736 .4365 Mdot
.736 .43657 Mdot
.736 .43838 Mdot
.736 .4384 Mdot
.736 .439 Mdot
.736 .43931 Mdot
.736 .43959 Mdot
.736 .44004 Mdot
.736 .44026 Mdot
.736 .44033 Mdot
.736 .44104 Mdot
.736 .44249 Mdot
.736 .44342 Mdot
.736 .44352 Mdot
.736 .44361 Mdot
.736 .44375 Mdot
.736 .44487 Mdot
.736 .4466 Mdot
.736 .44882 Mdot
.736 .44906 Mdot
.736 .44914 Mdot
.738 .01497 Mdot
.738 .01509 Mdot
.738 .01517 Mdot
.738 .01527 Mdot
.738 .01531 Mdot
.738 .01538 Mdot
.738 .01554 Mdot
.738 .01559 Mdot
.738 .0157 Mdot
.738 .01593 Mdot
.738 .01595 Mdot
.738 .01601 Mdot
.738 .01616 Mdot
.738 .0165 Mdot
.738 .01654 Mdot
.738 .01658 Mdot
.738 .01663 Mdot
.738 .01685 Mdot
.738 .01735 Mdot
.738 .01741 Mdot
.738 .01746 Mdot
.738 .01748 Mdot
.738 .01754 Mdot
.738 .01787 Mdot
.738 .01861 Mdot
.738 .01869 Mdot
.738 .01877 Mdot
.738 .0188 Mdot
.738 .01889 Mdot
.738 .01893 Mdot
.738 .01905 Mdot
.738 .01937 Mdot
.738 .02046 Mdot
.738 .02049 Mdot
.738 .02058 Mdot
.738 .0207 Mdot
.738 .02075 Mdot
.738 .02088 Mdot
.738 .02093 Mdot
.738 .02112 Mdot
.738 .02159 Mdot
.738 .02176 Mdot
.738 .02205 Mdot
.738 .02237 Mdot
.738 .02271 Mdot
.738 .0232 Mdot
.738 .02324 Mdot
.738 .02337 Mdot
.738 .02355 Mdot
.738 .02362 Mdot
.738 .02381 Mdot
.738 .02389 Mdot
.738 .02417 Mdot
.738 .02476 Mdot
.738 .02476 Mdot
.738 .02486 Mdot
.738 .02511 Mdot
.738 .02531 Mdot
.738 .02554 Mdot
.738 .02602 Mdot
.738 .02629 Mdot
.738 .02652 Mdot
.738 .02723 Mdot
.738 .02729 Mdot
.738 .02746 Mdot
.738 .02748 Mdot
.738 .02776 Mdot
.738 .02786 Mdot
.738 .02814 Mdot
.738 .02826 Mdot
.738 .0285 Mdot
.738 .02863 Mdot
.738 .02867 Mdot
.738 .02892 Mdot
.738 .02954 Mdot
.738 .02955 Mdot
.738 .02969 Mdot
.738 .03006 Mdot
.738 .03035 Mdot
.738 .03069 Mdot
.738 .03139 Mdot
.738 .03156 Mdot
.738 .03181 Mdot
.738 .03214 Mdot
.738 .03319 Mdot
.738 .03328 Mdot
.738 .03353 Mdot
.738 .03356 Mdot
.738 .0338 Mdot
.738 .03396 Mdot
.738 .03412 Mdot
.738 .03454 Mdot
.738 .0347 Mdot
.738 .03507 Mdot
.738 .03526 Mdot
.738 .03531 Mdot
.738 .03568 Mdot
.738 .0366 Mdot
.738 .03661 Mdot
.738 .0367 Mdot
.738 .03682 Mdot
.738 .03737 Mdot
.738 .0378 Mdot
.738 .03786 Mdot
.738 .0381 Mdot
.738 .03829 Mdot
.738 .03926 Mdot
.738 .0393 Mdot
.738 .03933 Mdot
.738 .03958 Mdot
.738 .03994 Mdot
.738 .04043 Mdot
.738 .04083 Mdot
.738 .0411 Mdot
.738 .04199 Mdot
.738 .04211 Mdot
.738 .0422 Mdot
.738 .04248 Mdot
.738 .04253 Mdot
.738 .04288 Mdot
.738 .04313 Mdot
.738 .04335 Mdot
.738 .04379 Mdot
.738 .04381 Mdot
.738 .04397 Mdot
.738 .04421 Mdot
.738 .04475 Mdot
.738 .04504 Mdot
.738 .04511 Mdot
.738 .04566 Mdot
.738 .04701 Mdot
.738 .04703 Mdot
.738 .04717 Mdot
.738 .04734 Mdot
.738 .04815 Mdot
.738 .04878 Mdot
.738 .04884 Mdot
.738 .04887 Mdot
.738 .04923 Mdot
.738 .04951 Mdot
.738 .04957 Mdot
.738 .05053 Mdot
.738 .05094 Mdot
.738 .051 Mdot
.738 .05105 Mdot
.738 .05142 Mdot
.738 .05195 Mdot
.738 .05223 Mdot
.738 .05241 Mdot
.738 .05249 Mdot
.738 .05268 Mdot
.738 .05326 Mdot
.738 .05348 Mdot
.738 .05366 Mdot
.738 .05424 Mdot
.738 .0543 Mdot
.738 .05497 Mdot
.738 .05515 Mdot
.738 .05528 Mdot
.738 .0557 Mdot
.738 .05578 Mdot
.738 .05614 Mdot
.738 .05629 Mdot
.738 .05665 Mdot
.738 .05698 Mdot
.738 .05763 Mdot
.738 .05766 Mdot
.738 .05789 Mdot
.738 .05826 Mdot
.738 .05905 Mdot
.738 .05945 Mdot
.738 .05947 Mdot
.738 .05958 Mdot
.738 .06039 Mdot
.738 .06067 Mdot
.738 .06239 Mdot
.738 .06241 Mdot
.738 .06262 Mdot
.738 .06288 Mdot
.738 .06386 Mdot
.738 .06406 Mdot
.738 .06423 Mdot
.738 .06437 Mdot
.738 .065 Mdot
.738 .06509 Mdot
.738 .06513 Mdot
.738 .06566 Mdot
.738 .06608 Mdot
.738 .06616 Mdot
.738 .06641 Mdot
.738 .06707 Mdot
.738 .0671 Mdot
.738 .06719 Mdot
.738 .06741 Mdot
.738 .06758 Mdot
.738 .06818 Mdot
.738 .06827 Mdot
.738 .06835 Mdot
.738 .0689 Mdot
.738 .06967 Mdot
.738 .07009 Mdot
.738 .07035 Mdot
.738 .07047 Mdot
.738 .07074 Mdot
.738 .07124 Mdot
.738 .07143 Mdot
.738 .0716 Mdot
.738 .07193 Mdot
.738 .07208 Mdot
.738 .0722 Mdot
.738 .07305 Mdot
.738 .07315 Mdot
.738 .07363 Mdot
.738 .07413 Mdot
.738 .0744 Mdot
.738 .0746 Mdot
.738 .0752 Mdot
.738 .07532 Mdot
.738 .07586 Mdot
.738 .07608 Mdot
.738 .07627 Mdot
.738 .07642 Mdot
.738 .07661 Mdot
.738 .07665 Mdot
.738 .07708 Mdot
.738 .0771 Mdot
.738 .07728 Mdot
.738 .07784 Mdot
.738 .07806 Mdot
.738 .07811 Mdot
.738 .07845 Mdot
.738 .07898 Mdot
.738 .07974 Mdot
.738 .08015 Mdot
.738 .08052 Mdot
.738 .08074 Mdot
.738 .08078 Mdot
.738 .08094 Mdot
.738 .08199 Mdot
.738 .08213 Mdot
.738 .08239 Mdot
.738 .08255 Mdot
.738 .0834 Mdot
.738 .08403 Mdot
.738 .08449 Mdot
.738 .08508 Mdot
.738 .08511 Mdot
.738 .08542 Mdot
.738 .0858 Mdot
.738 .0863 Mdot
.738 .08641 Mdot
.738 .08691 Mdot
.738 .08725 Mdot
.738 .08755 Mdot
.738 .0878 Mdot
.738 .08801 Mdot
.738 .08851 Mdot
.738 .08893 Mdot
.738 .08906 Mdot
.738 .08913 Mdot
.738 .0899 Mdot
.738 .09027 Mdot
.738 .09052 Mdot
.738 .09065 Mdot
.738 .09101 Mdot
.738 .09172 Mdot
.738 .092 Mdot
.738 .09202 Mdot
.738 .09204 Mdot
.738 .09216 Mdot
.738 .0925 Mdot
.738 .09274 Mdot
.738 .09297 Mdot
.738 .09305 Mdot
.738 .09363 Mdot
.738 .09376 Mdot
.738 .09388 Mdot
.738 .09468 Mdot
.738 .09528 Mdot
.738 .09528 Mdot
.738 .09583 Mdot
.738 .09644 Mdot
.738 .09683 Mdot
.738 .09701 Mdot
.738 .09741 Mdot
.738 .09814 Mdot
.738 .09823 Mdot
.738 .09843 Mdot
.738 .09868 Mdot
.738 .09914 Mdot
.738 .09917 Mdot
.738 .09939 Mdot
.738 .09957 Mdot
.738 .09959 Mdot
.738 .10082 Mdot
.738 .10096 Mdot
.738 .10112 Mdot
.738 .10168 Mdot
.738 .1024 Mdot
.738 .10281 Mdot
.738 .1031 Mdot
.738 .104 Mdot
.738 .10417 Mdot
.738 .10496 Mdot
.738 .10501 Mdot
.738 .10529 Mdot
.738 .10557 Mdot
.738 .10579 Mdot
.738 .10607 Mdot
.738 .10613 Mdot
.738 .10676 Mdot
.738 .10679 Mdot
.738 .10706 Mdot
.738 .10758 Mdot
.738 .10788 Mdot
.738 .10821 Mdot
.738 .10828 Mdot
.738 .10878 Mdot
.738 .1089 Mdot
.738 .10935 Mdot
.738 .10957 Mdot
.738 .11022 Mdot
.738 .11069 Mdot
.738 .1113 Mdot
.738 .11159 Mdot
.738 .11184 Mdot
.738 .11185 Mdot
.738 .11217 Mdot
.738 .11223 Mdot
.738 .11246 Mdot
.738 .11279 Mdot
.738 .11386 Mdot
.738 .11401 Mdot
.738 .11421 Mdot
.738 .11457 Mdot
.738 .11461 Mdot
.738 .11463 Mdot
.738 .11484 Mdot
.738 .11609 Mdot
.738 .11702 Mdot
.738 .1177 Mdot
.738 .11771 Mdot
.738 .11772 Mdot
.738 .11777 Mdot
.738 .11858 Mdot
.738 .11862 Mdot
.738 .11908 Mdot
.738 .11964 Mdot
.738 .11967 Mdot
.738 .11981 Mdot
.738 .11997 Mdot
.738 .12037 Mdot
.738 .12053 Mdot
.738 .12084 Mdot
.738 .12127 Mdot
.738 .12137 Mdot
.738 .12177 Mdot
.738 .12222 Mdot
.738 .12259 Mdot
.738 .12289 Mdot
.738 .12295 Mdot
.738 .12316 Mdot
.738 .12317 Mdot
.738 .12364 Mdot
.738 .12364 Mdot
.738 .12426 Mdot
.738 .12446 Mdot
.738 .12455 Mdot
.738 .12487 Mdot
.738 .12569 Mdot
.738 .12623 Mdot
.738 .12651 Mdot
.738 .12661 Mdot
.738 .12679 Mdot
.738 .12708 Mdot
.738 .12713 Mdot
.738 .12733 Mdot
.738 .12756 Mdot
.738 .12837 Mdot
.738 .12838 Mdot
.738 .12878 Mdot
.738 .12881 Mdot
.738 .12884 Mdot
.738 .12903 Mdot
.738 .12947 Mdot
.738 .12952 Mdot
.738 .12952 Mdot
.738 .12988 Mdot
.738 .13022 Mdot
.738 .13034 Mdot
.738 .13035 Mdot
.738 .13086 Mdot
.738 .13114 Mdot
.738 .1312 Mdot
.738 .13138 Mdot
.738 .13156 Mdot
.738 .13202 Mdot
.738 .13275 Mdot
.738 .13286 Mdot
.738 .13362 Mdot
.738 .13364 Mdot
.738 .1339 Mdot
.738 .13444 Mdot
.738 .13502 Mdot
.738 .13534 Mdot
.738 .13592 Mdot
.738 .13618 Mdot
.738 .13678 Mdot
.738 .13785 Mdot
.738 .13798 Mdot
.738 .13828 Mdot
.738 .13851 Mdot
.738 .13865 Mdot
.738 .13902 Mdot
.738 .13932 Mdot
.738 .13936 Mdot
.738 .1397 Mdot
.738 .13995 Mdot
.738 .13999 Mdot
.738 .14181 Mdot
.738 .14181 Mdot
.738 .14201 Mdot
.738 .14225 Mdot
.738 .14266 Mdot
.738 .14271 Mdot
.738 .14307 Mdot
.738 .14394 Mdot
.738 .14414 Mdot
.738 .14475 Mdot
.738 .14517 Mdot
.738 .1465 Mdot
.738 .14651 Mdot
.738 .14675 Mdot
.738 .14717 Mdot
.738 .14792 Mdot
.738 .148 Mdot
.738 .1484 Mdot
.738 .14882 Mdot
.738 .14914 Mdot
.738 .14928 Mdot
.738 .14956 Mdot
.738 .14965 Mdot
.738 .15025 Mdot
.738 .15058 Mdot
.738 .15062 Mdot
.738 .15082 Mdot
.738 .15102 Mdot
.738 .15179 Mdot
.738 .15223 Mdot
.738 .15272 Mdot
.738 .15282 Mdot
.738 .15356 Mdot
.738 .15356 Mdot
.738 .15373 Mdot
.738 .15404 Mdot
.738 .1544 Mdot
.738 .15472 Mdot
.738 .15477 Mdot
.738 .15568 Mdot
.738 .15637 Mdot
.738 .15728 Mdot
.738 .15763 Mdot
.738 .15771 Mdot
.738 .15807 Mdot
.738 .15808 Mdot
.738 .15856 Mdot
.738 .15864 Mdot
.738 .15898 Mdot
.738 .15948 Mdot
.738 .15949 Mdot
.738 .16105 Mdot
.738 .16128 Mdot
.738 .16157 Mdot
.738 .1621 Mdot
.738 .16216 Mdot
.738 .16218 Mdot
.738 .16249 Mdot
.738 .16273 Mdot
.738 .16275 Mdot
.738 .16332 Mdot
.738 .16435 Mdot
.738 .16473 Mdot
.738 .16572 Mdot
.738 .16584 Mdot
.738 .16588 Mdot
.738 .16651 Mdot
.738 .16672 Mdot
.738 .16673 Mdot
.738 .16676 Mdot
.738 .16683 Mdot
.738 .16801 Mdot
.738 .16808 Mdot
.738 .16828 Mdot
.738 .16876 Mdot
.738 .16958 Mdot
.738 .16963 Mdot
.738 .1697 Mdot
.738 .16983 Mdot
.738 .16989 Mdot
.738 .17007 Mdot
.738 .17066 Mdot
.738 .1709 Mdot
.738 .17136 Mdot
.738 .17148 Mdot
.738 .1718 Mdot
.738 .17199 Mdot
.738 .17214 Mdot
.738 .1727 Mdot
.738 .17273 Mdot
.738 .17289 Mdot
.738 .17339 Mdot
.738 .17393 Mdot
.738 .17439 Mdot
.738 .17448 Mdot
.738 .17477 Mdot
.738 .1748 Mdot
.738 .17549 Mdot
.738 .17549 Mdot
.738 .17641 Mdot
.738 .17669 Mdot
.738 .17683 Mdot
.738 .17731 Mdot
.738 .17852 Mdot
.738 .17932 Mdot
.738 .17973 Mdot
.738 .17987 Mdot
.738 .18014 Mdot
.738 .18057 Mdot
.738 .18064 Mdot
.738 .18094 Mdot
.738 .18127 Mdot
.738 .18149 Mdot
.738 .18151 Mdot
.738 .18246 Mdot
.738 .18247 Mdot
.738 .18249 Mdot
.738 .18308 Mdot
.738 .18312 Mdot
.738 .18317 Mdot
.738 .18344 Mdot
.738 .18361 Mdot
.738 .1841 Mdot
.738 .18416 Mdot
.738 .18417 Mdot
.738 .18431 Mdot
.738 .18469 Mdot
.738 .1852 Mdot
.738 .18538 Mdot
.738 .1854 Mdot
.738 .18553 Mdot
.738 .18578 Mdot
.738 .18613 Mdot
.738 .18614 Mdot
.738 .1864 Mdot
.738 .18656 Mdot
.738 .18664 Mdot
.738 .18692 Mdot
.738 .18718 Mdot
.738 .1875 Mdot
.738 .18785 Mdot
.738 .18894 Mdot
.738 .1891 Mdot
.738 .18996 Mdot
.738 .19023 Mdot
.738 .19024 Mdot
.738 .19063 Mdot
.738 .19142 Mdot
.738 .19163 Mdot
.738 .19229 Mdot
.738 .19259 Mdot
.738 .19276 Mdot
.738 .19362 Mdot
.738 .19376 Mdot
.738 .19399 Mdot
.738 .19488 Mdot
.738 .19546 Mdot
.738 .19647 Mdot
.738 .19647 Mdot
.738 .19665 Mdot
.738 .19709 Mdot
.738 .19743 Mdot
.738 .19745 Mdot
.738 .19764 Mdot
.738 .19819 Mdot
.738 .19864 Mdot
.738 .1987 Mdot
.738 .19919 Mdot
.738 .19929 Mdot
.738 .19957 Mdot
.738 .19963 Mdot
.738 .2023 Mdot
.738 .20231 Mdot
.738 .20261 Mdot
.738 .20296 Mdot
.738 .20318 Mdot
.738 .20356 Mdot
.738 .20364 Mdot
.738 .20374 Mdot
.738 .20383 Mdot
.738 .20417 Mdot
.738 .20494 Mdot
.738 .20546 Mdot
.738 .20575 Mdot
.738 .20665 Mdot
.738 .20696 Mdot
.738 .20726 Mdot
.738 .20784 Mdot
.738 .20905 Mdot
.738 .20922 Mdot
.738 .20925 Mdot
.738 .20959 Mdot
.738 .21022 Mdot
.738 .2105 Mdot
.738 .21087 Mdot
.738 .21132 Mdot
.738 .21144 Mdot
.738 .21203 Mdot
.738 .21265 Mdot
.738 .21277 Mdot
.738 .21313 Mdot
.738 .21334 Mdot
.738 .21374 Mdot
.738 .21388 Mdot
.738 .21476 Mdot
.738 .21476 Mdot
.738 .21516 Mdot
.738 .21525 Mdot
.738 .21531 Mdot
.738 .21561 Mdot
.738 .2159 Mdot
.738 .21631 Mdot
.738 .21697 Mdot
.738 .21703 Mdot
.738 .21769 Mdot
.738 .21827 Mdot
.738 .21841 Mdot
.738 .21856 Mdot
.738 .21871 Mdot
.738 .21965 Mdot
.738 .21965 Mdot
.738 .2199 Mdot
.738 .22036 Mdot
.738 .22089 Mdot
.738 .22137 Mdot
.738 .22143 Mdot
.738 .22156 Mdot
.738 .22278 Mdot
.738 .2238 Mdot
.738 .22513 Mdot
.738 .22566 Mdot
.738 .22577 Mdot
.738 .22631 Mdot
.738 .22632 Mdot
.738 .22703 Mdot
.738 .22715 Mdot
.738 .22766 Mdot
.738 .22839 Mdot
.738 .2284 Mdot
.738 .23071 Mdot
.738 .23104 Mdot
.738 .23148 Mdot
.738 .23226 Mdot
.738 .23234 Mdot
.738 .23238 Mdot
.738 .23283 Mdot
.738 .23318 Mdot
.738 .23321 Mdot
.738 .23406 Mdot
.738 .23557 Mdot
.738 .23614 Mdot
.738 .2376 Mdot
.738 .23777 Mdot
.738 .23783 Mdot
.738 .23877 Mdot
.738 .23907 Mdot
.738 .23909 Mdot
.738 .23913 Mdot
.738 .23923 Mdot
.738 .24099 Mdot
.738 .24107 Mdot
.738 .24137 Mdot
.738 .24209 Mdot
.738 .2433 Mdot
.738 .24336 Mdot
.738 .24347 Mdot
.738 .24367 Mdot
.738 .24376 Mdot
.738 .24402 Mdot
.738 .24489 Mdot
.738 .24525 Mdot
.738 .24592 Mdot
.738 .24611 Mdot
.738 .24657 Mdot
.738 .24686 Mdot
.738 .24707 Mdot
.738 .2479 Mdot
.738 .24795 Mdot
.738 .24818 Mdot
.738 .24892 Mdot
.738 .24972 Mdot
.738 .25039 Mdot
.738 .25052 Mdot
.738 .25096 Mdot
.738 .251 Mdot
.738 .25202 Mdot
.738 .25202 Mdot
.738 .25337 Mdot
.738 .25379 Mdot
.738 .254 Mdot
.738 .2547 Mdot
.738 .25649 Mdot
.738 .25767 Mdot
.738 .25827 Mdot
.738 .25848 Mdot
.738 .25888 Mdot
.738 .25951 Mdot
.738 .25963 Mdot
.738 .26006 Mdot
.738 .26055 Mdot
.738 .26088 Mdot
.738 .2609 Mdot
.738 .26231 Mdot
.738 .26232 Mdot
.738 .26235 Mdot
.738 .26322 Mdot
.738 .26328 Mdot
.738 .26335 Mdot
.738 .26375 Mdot
.738 .264 Mdot
.738 .26472 Mdot
.738 .26482 Mdot
.738 .26482 Mdot
.738 .26504 Mdot
.738 .26561 Mdot
.738 .26636 Mdot
.738 .26662 Mdot
.738 .26664 Mdot
.738 .26684 Mdot
.738 .26721 Mdot
.738 .26772 Mdot
.738 .26774 Mdot
.738 .26812 Mdot
.738 .26835 Mdot
.738 .26848 Mdot
.738 .26888 Mdot
.738 .26927 Mdot
.738 .26975 Mdot
.738 .27026 Mdot
.738 .27186 Mdot
.738 .2721 Mdot
.738 .27338 Mdot
.738 .27377 Mdot
.738 .27379 Mdot
.738 .27436 Mdot
.738 .27554 Mdot
.738 .27584 Mdot
.738 .27681 Mdot
.738 .27725 Mdot
.738 .27752 Mdot
.738 .27877 Mdot
.738 .27899 Mdot
.738 .27933 Mdot
.738 .28064 Mdot
.738 .28149 Mdot
.738 .28298 Mdot
.738 .28299 Mdot
.738 .28325 Mdot
.738 .2839 Mdot
.738 .28441 Mdot
.738 .28443 Mdot
.738 .28472 Mdot
.738 .28553 Mdot
.738 .28618 Mdot
.738 .28627 Mdot
.738 .287 Mdot
.738 .28714 Mdot
.738 .28756 Mdot
.738 .28764 Mdot
.738 .29159 Mdot
.738 .2916 Mdot
.738 .29204 Mdot
.738 .29256 Mdot
.738 .29289 Mdot
.738 .29345 Mdot
.738 .29356 Mdot
.738 .29372 Mdot
.738 .29385 Mdot
.738 .29435 Mdot
.738 .29548 Mdot
.738 .29625 Mdot
.738 .29669 Mdot
.738 .29801 Mdot
.738 .29847 Mdot
.738 .29892 Mdot
.738 .29976 Mdot
.738 .30155 Mdot
.738 .30181 Mdot
.738 .30185 Mdot
.738 .30236 Mdot
.738 .30329 Mdot
.738 .30369 Mdot
.738 .30424 Mdot
.738 .30491 Mdot
.738 .30508 Mdot
.738 .30595 Mdot
.738 .30687 Mdot
.738 .30705 Mdot
.738 .30758 Mdot
.738 .30788 Mdot
.738 .30848 Mdot
.738 .30868 Mdot
.738 .30998 Mdot
.738 .30999 Mdot
.738 .31057 Mdot
.738 .3107 Mdot
.738 .3108 Mdot
.738 .31123 Mdot
.738 .31166 Mdot
.738 .31227 Mdot
.738 .31325 Mdot
.738 .31334 Mdot
.738 .31431 Mdot
.738 .31517 Mdot
.738 .31536 Mdot
.738 .31558 Mdot
.738 .31581 Mdot
.738 .3172 Mdot
.738 .3172 Mdot
.738 .31757 Mdot
.738 .31824 Mdot
.738 .31903 Mdot
.738 .31974 Mdot
.738 .31983 Mdot
.738 .32002 Mdot
.738 .32181 Mdot
.738 .32332 Mdot
.738 .32529 Mdot
.738 .32607 Mdot
.738 .32624 Mdot
.738 .32702 Mdot
.738 .32705 Mdot
.738 .32809 Mdot
.738 .32827 Mdot
.738 .32902 Mdot
.738 .3301 Mdot
.738 .33011 Mdot
.738 .33352 Mdot
.738 .33401 Mdot
.738 .33466 Mdot
.738 .33581 Mdot
.738 .33593 Mdot
.738 .33599 Mdot
.738 .33666 Mdot
.738 .33717 Mdot
.738 .33722 Mdot
.738 .33846 Mdot
.738 .3407 Mdot
.738 .34153 Mdot
.738 .34369 Mdot
.738 .34394 Mdot
.738 .34404 Mdot
.738 .34542 Mdot
.738 .34587 Mdot
.738 .34589 Mdot
.738 .34595 Mdot
.738 .3461 Mdot
.738 .34869 Mdot
.738 .34882 Mdot
.738 .34926 Mdot
.738 .35031 Mdot
.738 .3521 Mdot
.738 .3522 Mdot
.738 .35236 Mdot
.738 .35265 Mdot
.738 .35278 Mdot
.738 .35316 Mdot
.738 .35445 Mdot
.738 .35498 Mdot
.738 .35597 Mdot
.738 .35625 Mdot
.738 .35693 Mdot
.738 .35736 Mdot
.738 .35767 Mdot
.738 .35889 Mdot
.738 .35897 Mdot
.738 .35931 Mdot
.738 .3604 Mdot
.738 .36159 Mdot
.738 .36257 Mdot
.738 .36277 Mdot
.738 .36342 Mdot
.738 .36347 Mdot
.738 .36498 Mdot
.738 .36498 Mdot
.738 .36698 Mdot
.738 .36759 Mdot
.738 .3679 Mdot
.738 .36894 Mdot
.738 .37157 Mdot
.738 .37331 Mdot
.738 .37421 Mdot
.738 .37451 Mdot
.738 .3751 Mdot
.738 .37603 Mdot
.738 .3762 Mdot
.738 .37685 Mdot
.738 .37757 Mdot
.738 .37805 Mdot
.738 .37809 Mdot
.738 .38017 Mdot
.738 .38018 Mdot
.738 .38022 Mdot
.738 .3815 Mdot
.738 .3816 Mdot
.738 .38171 Mdot
.738 .3823 Mdot
.738 .38266 Mdot
.738 .38373 Mdot
.738 .38387 Mdot
.738 .38388 Mdot
.738 .3842 Mdot
.738 .38503 Mdot
.738 .38614 Mdot
.738 .38652 Mdot
.738 .38656 Mdot
.738 .38685 Mdot
.738 .3874 Mdot
.738 .38815 Mdot
.738 .38817 Mdot
.738 .38874 Mdot
.738 .38908 Mdot
.738 .38927 Mdot
.738 .38987 Mdot
.738 .39044 Mdot
.738 .39114 Mdot
.738 .3919 Mdot
.738 .39427 Mdot
.738 .39462 Mdot
.738 .3965 Mdot
.738 .39708 Mdot
.738 .39711 Mdot
.738 .39795 Mdot
.738 .39969 Mdot
.738 .40014 Mdot
.738 .40157 Mdot
.738 .40222 Mdot
.738 .40261 Mdot
.738 .40447 Mdot
.738 .40479 Mdot
.738 .40528 Mdot
.738 .40722 Mdot
.738 .40848 Mdot
.738 .41068 Mdot
.738 .41069 Mdot
.738 .41108 Mdot
.738 .41203 Mdot
.738 .41278 Mdot
.738 .41281 Mdot
.738 .41324 Mdot
.738 .41444 Mdot
.738 .4154 Mdot
.738 .41553 Mdot
.738 .41661 Mdot
.738 .41682 Mdot
.738 .41743 Mdot
.738 .41756 Mdot
.738 .42339 Mdot
.738 .4234 Mdot
.738 .42405 Mdot
.738 .42482 Mdot
.738 .4253 Mdot
.738 .42612 Mdot
.738 .42629 Mdot
.738 .42653 Mdot
.738 .42671 Mdot
.738 .42746 Mdot
.738 .42913 Mdot
.738 .43026 Mdot
.738 .4309 Mdot
.738 .43285 Mdot
.738 .43354 Mdot
.738 .4342 Mdot
.738 .43545 Mdot
.738 .43808 Mdot
.738 .43846 Mdot
.738 .43852 Mdot
.738 .43927 Mdot
.738 .44064 Mdot
.738 .44124 Mdot
.738 .44206 Mdot
.738 .44304 Mdot
.738 .44329 Mdot
.738 .44458 Mdot
.738 .44593 Mdot
.738 .4462 Mdot
.738 .44698 Mdot
.738 .44743 Mdot
.738 .44831 Mdot
.738 .44861 Mdot
.738 .45052 Mdot
.738 .45054 Mdot
.74 .0148 Mdot
.74 .01485 Mdot
.74 .01491 Mdot
.74 .015 Mdot
.74 .01514 Mdot
.74 .01534 Mdot
.74 .01564 Mdot
.74 .0157 Mdot
.74 .0158 Mdot
.74 .01608 Mdot
.74 .01613 Mdot
.74 .01617 Mdot
.74 .01632 Mdot
.74 .01644 Mdot
.74 .01674 Mdot
.74 .01681 Mdot
.74 .01687 Mdot
.74 .01693 Mdot
.74 .01709 Mdot
.74 .01727 Mdot
.74 .01771 Mdot
.74 .01772 Mdot
.74 .01781 Mdot
.74 .01791 Mdot
.74 .018 Mdot
.74 .01803 Mdot
.74 .01823 Mdot
.74 .0185 Mdot
.74 .01915 Mdot
.74 .01917 Mdot
.74 .01929 Mdot
.74 .01944 Mdot
.74 .01958 Mdot
.74 .01962 Mdot
.74 .01976 Mdot
.74 .01988 Mdot
.74 .01992 Mdot
.74 .02015 Mdot
.74 .02031 Mdot
.74 .02128 Mdot
.74 .0213 Mdot
.74 .02149 Mdot
.74 .02171 Mdot
.74 .02191 Mdot
.74 .02197 Mdot
.74 .02218 Mdot
.74 .02236 Mdot
.74 .02242 Mdot
.74 .02276 Mdot
.74 .023 Mdot
.74 .02334 Mdot
.74 .02382 Mdot
.74 .02386 Mdot
.74 .02443 Mdot
.74 .02446 Mdot
.74 .02474 Mdot
.74 .02507 Mdot
.74 .02517 Mdot
.74 .02536 Mdot
.74 .02546 Mdot
.74 .02577 Mdot
.74 .02603 Mdot
.74 .02612 Mdot
.74 .02627 Mdot
.74 .02663 Mdot
.74 .02697 Mdot
.74 .02748 Mdot
.74 .02819 Mdot
.74 .02825 Mdot
.74 .02849 Mdot
.74 .02878 Mdot
.74 .02909 Mdot
.74 .02914 Mdot
.74 .02956 Mdot
.74 .03004 Mdot
.74 .03018 Mdot
.74 .03047 Mdot
.74 .03061 Mdot
.74 .03072 Mdot
.74 .03107 Mdot
.74 .03138 Mdot
.74 .03146 Mdot
.74 .0316 Mdot
.74 .03182 Mdot
.74 .03184 Mdot
.74 .03234 Mdot
.74 .03286 Mdot
.74 .0334 Mdot
.74 .03355 Mdot
.74 .03361 Mdot
.74 .03466 Mdot
.74 .03474 Mdot
.74 .03511 Mdot
.74 .03512 Mdot
.74 .03553 Mdot
.74 .03584 Mdot
.74 .03599 Mdot
.74 .03607 Mdot
.74 .03618 Mdot
.74 .03653 Mdot
.74 .03668 Mdot
.74 .03714 Mdot
.74 .0374 Mdot
.74 .03761 Mdot
.74 .0377 Mdot
.74 .03804 Mdot
.74 .03812 Mdot
.74 .03817 Mdot
.74 .03825 Mdot
.74 .0384 Mdot
.74 .03892 Mdot
.74 .03924 Mdot
.74 .03936 Mdot
.74 .03938 Mdot
.74 .0395 Mdot
.74 .03971 Mdot
.74 .04003 Mdot
.74 .04006 Mdot
.74 .04081 Mdot
.74 .04123 Mdot
.74 .04157 Mdot
.74 .04237 Mdot
.74 .04259 Mdot
.74 .04261 Mdot
.74 .04268 Mdot
.74 .04423 Mdot
.74 .04436 Mdot
.74 .04443 Mdot
.74 .04489 Mdot
.74 .04491 Mdot
.74 .04553 Mdot
.74 .04597 Mdot
.74 .04621 Mdot
.74 .04631 Mdot
.74 .04649 Mdot
.74 .0465 Mdot
.74 .04676 Mdot
.74 .047 Mdot
.74 .04722 Mdot
.74 .04773 Mdot
.74 .04791 Mdot
.74 .04829 Mdot
.74 .0486 Mdot
.74 .04873 Mdot
.74 .04923 Mdot
.74 .04935 Mdot
.74 .04943 Mdot
.74 .04954 Mdot
.74 .04977 Mdot
.74 .05005 Mdot
.74 .05054 Mdot
.74 .051 Mdot
.74 .05119 Mdot
.74 .05122 Mdot
.74 .0514 Mdot
.74 .0517 Mdot
.74 .05218 Mdot
.74 .05223 Mdot
.74 .05333 Mdot
.74 .05343 Mdot
.74 .0539 Mdot
.74 .05395 Mdot
.74 .05445 Mdot
.74 .05496 Mdot
.74 .055 Mdot
.74 .05565 Mdot
.74 .05596 Mdot
.74 .056 Mdot
.74 .05603 Mdot
.74 .0561 Mdot
.74 .05636 Mdot
.74 .0584 Mdot
.74 .05858 Mdot
.74 .05859 Mdot
.74 .05869 Mdot
.74 .05938 Mdot
.74 .0594 Mdot
.74 .06008 Mdot
.74 .06032 Mdot
.74 .06098 Mdot
.74 .06119 Mdot
.74 .06132 Mdot
.74 .06137 Mdot
.74 .06148 Mdot
.74 .06174 Mdot
.74 .06176 Mdot
.74 .0621 Mdot
.74 .06214 Mdot
.74 .0625 Mdot
.74 .06283 Mdot
.74 .06331 Mdot
.74 .06357 Mdot
.74 .06384 Mdot
.74 .06441 Mdot
.74 .06486 Mdot
.74 .06505 Mdot
.74 .06544 Mdot
.74 .06556 Mdot
.74 .0658 Mdot
.74 .06597 Mdot
.74 .0661 Mdot
.74 .06626 Mdot
.74 .0666 Mdot
.74 .06692 Mdot
.74 .06701 Mdot
.74 .06741 Mdot
.74 .06773 Mdot
.74 .06842 Mdot
.74 .06842 Mdot
.74 .06858 Mdot
.74 .0687 Mdot
.74 .06875 Mdot
.74 .06901 Mdot
.74 .06901 Mdot
.74 .06945 Mdot
.74 .07017 Mdot
.74 .07024 Mdot
.74 .0713 Mdot
.74 .07152 Mdot
.74 .07187 Mdot
.74 .07201 Mdot
.74 .07271 Mdot
.74 .07279 Mdot
.74 .07353 Mdot
.74 .07428 Mdot
.74 .07434 Mdot
.74 .07446 Mdot
.74 .0751 Mdot
.74 .07529 Mdot
.74 .07546 Mdot
.74 .07576 Mdot
.74 .07582 Mdot
.74 .07587 Mdot
.74 .07596 Mdot
.74 .07598 Mdot
.74 .07631 Mdot
.74 .07636 Mdot
.74 .07763 Mdot
.74 .07932 Mdot
.74 .07937 Mdot
.74 .07964 Mdot
.74 .07965 Mdot
.74 .0798 Mdot
.74 .08053 Mdot
.74 .08082 Mdot
.74 .08086 Mdot
.74 .08186 Mdot
.74 .08216 Mdot
.74 .08221 Mdot
.74 .08273 Mdot
.74 .08319 Mdot
.74 .0835 Mdot
.74 .0837 Mdot
.74 .08376 Mdot
.74 .08393 Mdot
.74 .08399 Mdot
.74 .08431 Mdot
.74 .08434 Mdot
.74 .08485 Mdot
.74 .0849 Mdot
.74 .08544 Mdot
.74 .08592 Mdot
.74 .0861 Mdot
.74 .08663 Mdot
.74 .08702 Mdot
.74 .08742 Mdot
.74 .0878 Mdot
.74 .08826 Mdot
.74 .08834 Mdot
.74 .08894 Mdot
.74 .08922 Mdot
.74 .08979 Mdot
.74 .08997 Mdot
.74 .09032 Mdot
.74 .09056 Mdot
.74 .09058 Mdot
.74 .09076 Mdot
.74 .091 Mdot
.74 .0915 Mdot
.74 .09198 Mdot
.74 .09211 Mdot
.74 .0927 Mdot
.74 .09318 Mdot
.74 .09336 Mdot
.74 .09361 Mdot
.74 .09382 Mdot
.74 .0942 Mdot
.74 .0942 Mdot
.74 .09444 Mdot
.74 .09462 Mdot
.74 .09469 Mdot
.74 .09507 Mdot
.74 .09507 Mdot
.74 .09573 Mdot
.74 .09605 Mdot
.74 .09679 Mdot
.74 .09689 Mdot
.74 .09809 Mdot
.74 .09845 Mdot
.74 .09879 Mdot
.74 .0993 Mdot
.74 .09933 Mdot
.74 .09952 Mdot
.74 .09991 Mdot
.74 .10055 Mdot
.74 .10066 Mdot
.74 .10176 Mdot
.74 .10261 Mdot
.74 .10261 Mdot
.74 .10287 Mdot
.74 .10296 Mdot
.74 .10314 Mdot
.74 .10409 Mdot
.74 .10413 Mdot
.74 .10437 Mdot
.74 .10462 Mdot
.74 .10506 Mdot
.74 .10515 Mdot
.74 .10522 Mdot
.74 .10536 Mdot
.74 .10538 Mdot
.74 .10555 Mdot
.74 .10588 Mdot
.74 .10594 Mdot
.74 .10613 Mdot
.74 .10628 Mdot
.74 .10783 Mdot
.74 .10982 Mdot
.74 .10985 Mdot
.74 .11018 Mdot
.74 .11033 Mdot
.74 .1104 Mdot
.74 .1106 Mdot
.74 .1108 Mdot
.74 .11081 Mdot
.74 .11103 Mdot
.74 .11145 Mdot
.74 .11212 Mdot
.74 .11255 Mdot
.74 .1126 Mdot
.74 .11399 Mdot
.74 .11409 Mdot
.74 .11431 Mdot
.74 .11454 Mdot
.74 .1146 Mdot
.74 .11538 Mdot
.74 .11561 Mdot
.74 .11565 Mdot
.74 .1158 Mdot
.74 .11605 Mdot
.74 .11652 Mdot
.74 .11681 Mdot
.74 .11691 Mdot
.74 .11712 Mdot
.74 .11715 Mdot
.74 .11724 Mdot
.74 .11772 Mdot
.74 .11776 Mdot
.74 .11838 Mdot
.74 .11851 Mdot
.74 .11859 Mdot
.74 .11869 Mdot
.74 .11876 Mdot
.74 .11939 Mdot
.74 .11964 Mdot
.74 .1201 Mdot
.74 .12036 Mdot
.74 .12116 Mdot
.74 .12173 Mdot
.74 .12232 Mdot
.74 .12237 Mdot
.74 .12288 Mdot
.74 .12356 Mdot
.74 .12368 Mdot
.74 .12456 Mdot
.74 .12498 Mdot
.74 .12575 Mdot
.74 .12582 Mdot
.74 .12609 Mdot
.74 .12662 Mdot
.74 .12668 Mdot
.74 .12695 Mdot
.74 .12696 Mdot
.74 .12699 Mdot
.74 .12727 Mdot
.74 .12761 Mdot
.74 .12836 Mdot
.74 .12907 Mdot
.74 .12926 Mdot
.74 .13013 Mdot
.74 .13035 Mdot
.74 .13084 Mdot
.74 .13087 Mdot
.74 .13111 Mdot
.74 .13148 Mdot
.74 .13179 Mdot
.74 .13192 Mdot
.74 .13235 Mdot
.74 .13236 Mdot
.74 .13271 Mdot
.74 .13297 Mdot
.74 .13307 Mdot
.74 .13364 Mdot
.74 .13364 Mdot
.74 .13427 Mdot
.74 .13438 Mdot
.74 .13441 Mdot
.74 .13461 Mdot
.74 .13509 Mdot
.74 .13554 Mdot
.74 .13618 Mdot
.74 .13633 Mdot
.74 .13688 Mdot
.74 .13732 Mdot
.74 .1381 Mdot
.74 .1384 Mdot
.74 .13865 Mdot
.74 .13879 Mdot
.74 .13915 Mdot
.74 .13942 Mdot
.74 .1399 Mdot
.74 .13995 Mdot
.74 .14022 Mdot
.74 .14081 Mdot
.74 .14149 Mdot
.74 .14155 Mdot
.74 .14175 Mdot
.74 .14191 Mdot
.74 .14323 Mdot
.74 .14354 Mdot
.74 .14448 Mdot
.74 .14448 Mdot
.74 .14479 Mdot
.74 .1448 Mdot
.74 .14496 Mdot
.74 .14519 Mdot
.74 .14531 Mdot
.74 .14559 Mdot
.74 .14699 Mdot
.74 .14706 Mdot
.74 .14741 Mdot
.74 .14767 Mdot
.74 .1477 Mdot
.74 .14778 Mdot
.74 .14843 Mdot
.74 .14856 Mdot
.74 .14866 Mdot
.74 .14888 Mdot
.74 .1489 Mdot
.74 .14915 Mdot
.74 .14964 Mdot
.74 .14973 Mdot
.74 .15001 Mdot
.74 .15024 Mdot
.74 .15073 Mdot
.74 .15126 Mdot
.74 .15138 Mdot
.74 .15237 Mdot
.74 .15252 Mdot
.74 .15464 Mdot
.74 .15547 Mdot
.74 .15551 Mdot
.74 .156 Mdot
.74 .15622 Mdot
.74 .15633 Mdot
.74 .15662 Mdot
.74 .15679 Mdot
.74 .15692 Mdot
.74 .15694 Mdot
.74 .15727 Mdot
.74 .15731 Mdot
.74 .15788 Mdot
.74 .15831 Mdot
.74 .15887 Mdot
.74 .15951 Mdot
.74 .15959 Mdot
.74 .15989 Mdot
.74 .1606 Mdot
.74 .16165 Mdot
.74 .16179 Mdot
.74 .16212 Mdot
.74 .16213 Mdot
.74 .16245 Mdot
.74 .16255 Mdot
.74 .16324 Mdot
.74 .1637 Mdot
.74 .16404 Mdot
.74 .1641 Mdot
.74 .16432 Mdot
.74 .16469 Mdot
.74 .16535 Mdot
.74 .16539 Mdot
.74 .16581 Mdot
.74 .16596 Mdot
.74 .16627 Mdot
.74 .16632 Mdot
.74 .16645 Mdot
.74 .16716 Mdot
.74 .16723 Mdot
.74 .16814 Mdot
.74 .16833 Mdot
.74 .16844 Mdot
.74 .1686 Mdot
.74 .16871 Mdot
.74 .16911 Mdot
.74 .16963 Mdot
.74 .17001 Mdot
.74 .17051 Mdot
.74 .17069 Mdot
.74 .17107 Mdot
.74 .17172 Mdot
.74 .17225 Mdot
.74 .17242 Mdot
.74 .1731 Mdot
.74 .17396 Mdot
.74 .17404 Mdot
.74 .17411 Mdot
.74 .17479 Mdot
.74 .17542 Mdot
.74 .17581 Mdot
.74 .17599 Mdot
.74 .17682 Mdot
.74 .17682 Mdot
.74 .17729 Mdot
.74 .17772 Mdot
.74 .1779 Mdot
.74 .17795 Mdot
.74 .17905 Mdot
.74 .17915 Mdot
.74 .17928 Mdot
.74 .17954 Mdot
.74 .18033 Mdot
.74 .18043 Mdot
.74 .18083 Mdot
.74 .18084 Mdot
.74 .18089 Mdot
.74 .18129 Mdot
.74 .18168 Mdot
.74 .18178 Mdot
.74 .1818 Mdot
.74 .18207 Mdot
.74 .18291 Mdot
.74 .18396 Mdot
.74 .18424 Mdot
.74 .18433 Mdot
.74 .18538 Mdot
.74 .18554 Mdot
.74 .18586 Mdot
.74 .18658 Mdot
.74 .18662 Mdot
.74 .18663 Mdot
.74 .18697 Mdot
.74 .18739 Mdot
.74 .18752 Mdot
.74 .18786 Mdot
.74 .18798 Mdot
.74 .18817 Mdot
.74 .18881 Mdot
.74 .18883 Mdot
.74 .18935 Mdot
.74 .18973 Mdot
.74 .18973 Mdot
.74 .18988 Mdot
.74 .19072 Mdot
.74 .19073 Mdot
.74 .19166 Mdot
.74 .19183 Mdot
.74 .19186 Mdot
.74 .19217 Mdot
.74 .19287 Mdot
.74 .19353 Mdot
.74 .19369 Mdot
.74 .194 Mdot
.74 .19449 Mdot
.74 .19471 Mdot
.74 .19518 Mdot
.74 .19552 Mdot
.74 .19617 Mdot
.74 .19733 Mdot
.74 .19776 Mdot
.74 .19814 Mdot
.74 .19835 Mdot
.74 .19887 Mdot
.74 .19928 Mdot
.74 .19971 Mdot
.74 .19971 Mdot
.74 .19999 Mdot
.74 .20006 Mdot
.74 .20047 Mdot
.74 .20121 Mdot
.74 .20124 Mdot
.74 .20133 Mdot
.74 .20203 Mdot
.74 .20235 Mdot
.74 .20273 Mdot
.74 .20297 Mdot
.74 .20311 Mdot
.74 .20369 Mdot
.74 .20491 Mdot
.74 .20501 Mdot
.74 .20537 Mdot
.74 .20677 Mdot
.74 .20677 Mdot
.74 .20723 Mdot
.74 .20724 Mdot
.74 .20748 Mdot
.74 .20782 Mdot
.74 .208 Mdot
.74 .2084 Mdot
.74 .21049 Mdot
.74 .21058 Mdot
.74 .2111 Mdot
.74 .21149 Mdot
.74 .21153 Mdot
.74 .21164 Mdot
.74 .21176 Mdot
.74 .21206 Mdot
.74 .21261 Mdot
.74 .2128 Mdot
.74 .21296 Mdot
.74 .21327 Mdot
.74 .21331 Mdot
.74 .21368 Mdot
.74 .21374 Mdot
.74 .2144 Mdot
.74 .21454 Mdot
.74 .21495 Mdot
.74 .215 Mdot
.74 .21514 Mdot
.74 .21529 Mdot
.74 .21551 Mdot
.74 .21587 Mdot
.74 .21601 Mdot
.74 .2168 Mdot
.74 .21686 Mdot
.74 .21698 Mdot
.74 .21844 Mdot
.74 .21866 Mdot
.74 .21867 Mdot
.74 .21927 Mdot
.74 .21978 Mdot
.74 .22079 Mdot
.74 .22092 Mdot
.74 .22181 Mdot
.74 .22211 Mdot
.74 .22232 Mdot
.74 .22303 Mdot
.74 .2231 Mdot
.74 .22381 Mdot
.74 .22414 Mdot
.74 .2243 Mdot
.74 .22446 Mdot
.74 .22474 Mdot
.74 .22499 Mdot
.74 .22518 Mdot
.74 .22521 Mdot
.74 .22569 Mdot
.74 .22575 Mdot
.74 .2266 Mdot
.74 .22724 Mdot
.74 .22806 Mdot
.74 .22901 Mdot
.74 .22913 Mdot
.74 .22957 Mdot
.74 .23063 Mdot
.74 .23217 Mdot
.74 .23239 Mdot
.74 .23287 Mdot
.74 .23289 Mdot
.74 .23336 Mdot
.74 .23351 Mdot
.74 .23453 Mdot
.74 .23521 Mdot
.74 .23572 Mdot
.74 .2358 Mdot
.74 .23613 Mdot
.74 .23668 Mdot
.74 .23766 Mdot
.74 .23771 Mdot
.74 .23833 Mdot
.74 .23856 Mdot
.74 .23902 Mdot
.74 .23909 Mdot
.74 .23929 Mdot
.74 .24033 Mdot
.74 .24043 Mdot
.74 .24178 Mdot
.74 .24207 Mdot
.74 .24223 Mdot
.74 .24247 Mdot
.74 .24262 Mdot
.74 .24322 Mdot
.74 .24399 Mdot
.74 .24455 Mdot
.74 .24529 Mdot
.74 .24555 Mdot
.74 .24613 Mdot
.74 .24709 Mdot
.74 .24786 Mdot
.74 .24811 Mdot
.74 .24912 Mdot
.74 .2504 Mdot
.74 .25052 Mdot
.74 .25061 Mdot
.74 .25163 Mdot
.74 .25256 Mdot
.74 .25313 Mdot
.74 .25339 Mdot
.74 .25463 Mdot
.74 .25463 Mdot
.74 .25532 Mdot
.74 .25597 Mdot
.74 .25623 Mdot
.74 .2563 Mdot
.74 .25792 Mdot
.74 .25793 Mdot
.74 .25808 Mdot
.74 .25827 Mdot
.74 .25866 Mdot
.74 .25982 Mdot
.74 .25997 Mdot
.74 .26056 Mdot
.74 .26058 Mdot
.74 .26065 Mdot
.74 .26125 Mdot
.74 .26183 Mdot
.74 .26197 Mdot
.74 .262 Mdot
.74 .2624 Mdot
.74 .26365 Mdot
.74 .26519 Mdot
.74 .26562 Mdot
.74 .26574 Mdot
.74 .26729 Mdot
.74 .26753 Mdot
.74 .26801 Mdot
.74 .26908 Mdot
.74 .26913 Mdot
.74 .26914 Mdot
.74 .26966 Mdot
.74 .27027 Mdot
.74 .27047 Mdot
.74 .27096 Mdot
.74 .27115 Mdot
.74 .27143 Mdot
.74 .27238 Mdot
.74 .2724 Mdot
.74 .27317 Mdot
.74 .27374 Mdot
.74 .27374 Mdot
.74 .27396 Mdot
.74 .2752 Mdot
.74 .27521 Mdot
.74 .27659 Mdot
.74 .27684 Mdot
.74 .27689 Mdot
.74 .27734 Mdot
.74 .27838 Mdot
.74 .27936 Mdot
.74 .2796 Mdot
.74 .28006 Mdot
.74 .28078 Mdot
.74 .2811 Mdot
.74 .2818 Mdot
.74 .28231 Mdot
.74 .28327 Mdot
.74 .28499 Mdot
.74 .28563 Mdot
.74 .28618 Mdot
.74 .2865 Mdot
.74 .28727 Mdot
.74 .28787 Mdot
.74 .28851 Mdot
.74 .28851 Mdot
.74 .28892 Mdot
.74 .28902 Mdot
.74 .28963 Mdot
.74 .29073 Mdot
.74 .29077 Mdot
.74 .2909 Mdot
.74 .29193 Mdot
.74 .29241 Mdot
.74 .29298 Mdot
.74 .29333 Mdot
.74 .29355 Mdot
.74 .2944 Mdot
.74 .29621 Mdot
.74 .29635 Mdot
.74 .29689 Mdot
.74 .29896 Mdot
.74 .29896 Mdot
.74 .29964 Mdot
.74 .29965 Mdot
.74 .30001 Mdot
.74 .30051 Mdot
.74 .30078 Mdot
.74 .30138 Mdot
.74 .30446 Mdot
.74 .30459 Mdot
.74 .30536 Mdot
.74 .30593 Mdot
.74 .306 Mdot
.74 .30617 Mdot
.74 .30634 Mdot
.74 .30679 Mdot
.74 .30761 Mdot
.74 .30789 Mdot
.74 .30812 Mdot
.74 .30858 Mdot
.74 .30864 Mdot
.74 .30918 Mdot
.74 .30928 Mdot
.74 .31026 Mdot
.74 .31046 Mdot
.74 .31106 Mdot
.74 .31113 Mdot
.74 .31135 Mdot
.74 .31156 Mdot
.74 .3119 Mdot
.74 .31243 Mdot
.74 .31264 Mdot
.74 .3138 Mdot
.74 .31389 Mdot
.74 .31407 Mdot
.74 .31622 Mdot
.74 .31655 Mdot
.74 .31657 Mdot
.74 .31746 Mdot
.74 .31821 Mdot
.74 .31971 Mdot
.74 .3199 Mdot
.74 .32121 Mdot
.74 .32166 Mdot
.74 .32197 Mdot
.74 .32302 Mdot
.74 .32312 Mdot
.74 .32418 Mdot
.74 .32467 Mdot
.74 .3249 Mdot
.74 .32514 Mdot
.74 .32555 Mdot
.74 .32592 Mdot
.74 .32621 Mdot
.74 .32625 Mdot
.74 .32696 Mdot
.74 .32705 Mdot
.74 .32831 Mdot
.74 .32925 Mdot
.74 .33047 Mdot
.74 .33187 Mdot
.74 .33205 Mdot
.74 .3327 Mdot
.74 .33427 Mdot
.74 .33656 Mdot
.74 .33687 Mdot
.74 .33759 Mdot
.74 .33762 Mdot
.74 .33831 Mdot
.74 .33854 Mdot
.74 .34004 Mdot
.74 .34105 Mdot
.74 .3418 Mdot
.74 .34192 Mdot
.74 .34241 Mdot
.74 .34323 Mdot
.74 .34467 Mdot
.74 .34475 Mdot
.74 .34567 Mdot
.74 .346 Mdot
.74 .34668 Mdot
.74 .34679 Mdot
.74 .34708 Mdot
.74 .34863 Mdot
.74 .34878 Mdot
.74 .35077 Mdot
.74 .3512 Mdot
.74 .35144 Mdot
.74 .35179 Mdot
.74 .35202 Mdot
.74 .35291 Mdot
.74 .35405 Mdot
.74 .35486 Mdot
.74 .35597 Mdot
.74 .35635 Mdot
.74 .3572 Mdot
.74 .35863 Mdot
.74 .35978 Mdot
.74 .36014 Mdot
.74 .36164 Mdot
.74 .36353 Mdot
.74 .3637 Mdot
.74 .36384 Mdot
.74 .36535 Mdot
.74 .36673 Mdot
.74 .36757 Mdot
.74 .36796 Mdot
.74 .36978 Mdot
.74 .36979 Mdot
.74 .37081 Mdot
.74 .37177 Mdot
.74 .37216 Mdot
.74 .37227 Mdot
.74 .37466 Mdot
.74 .37468 Mdot
.74 .3749 Mdot
.74 .37518 Mdot
.74 .37576 Mdot
.74 .37748 Mdot
.74 .37769 Mdot
.74 .37857 Mdot
.74 .37859 Mdot
.74 .3787 Mdot
.74 .37959 Mdot
.74 .38044 Mdot
.74 .38065 Mdot
.74 .3807 Mdot
.74 .38129 Mdot
.74 .38313 Mdot
.74 .38542 Mdot
.74 .38605 Mdot
.74 .38623 Mdot
.74 .38853 Mdot
.74 .38888 Mdot
.74 .38959 Mdot
.74 .39118 Mdot
.74 .39125 Mdot
.74 .39127 Mdot
.74 .39203 Mdot
.74 .39294 Mdot
.74 .39324 Mdot
.74 .39396 Mdot
.74 .39423 Mdot
.74 .39466 Mdot
.74 .39606 Mdot
.74 .39609 Mdot
.74 .39723 Mdot
.74 .39808 Mdot
.74 .39808 Mdot
.74 .3984 Mdot
.74 .40023 Mdot
.74 .40025 Mdot
.74 .4023 Mdot
.74 .40266 Mdot
.74 .40274 Mdot
.74 .4034 Mdot
.74 .40494 Mdot
.74 .4064 Mdot
.74 .40674 Mdot
.74 .40742 Mdot
.74 .40849 Mdot
.74 .40897 Mdot
.74 .41 Mdot
.74 .41075 Mdot
.74 .41218 Mdot
.74 .41472 Mdot
.74 .41566 Mdot
.74 .41648 Mdot
.74 .41695 Mdot
.74 .41809 Mdot
.74 .41898 Mdot
.74 .41992 Mdot
.74 .41993 Mdot
.74 .42054 Mdot
.74 .42069 Mdot
.74 .42159 Mdot
.74 .42321 Mdot
.74 .42328 Mdot
.74 .42347 Mdot
.74 .425 Mdot
.74 .42571 Mdot
.74 .42655 Mdot
.74 .42707 Mdot
.74 .42738 Mdot
.74 .42865 Mdot
.74 .43133 Mdot
.74 .43153 Mdot
.74 .43233 Mdot
.74 .43539 Mdot
.74 .43539 Mdot
.74 .43641 Mdot
.74 .43643 Mdot
.74 .43696 Mdot
.74 .43769 Mdot
.74 .43808 Mdot
.74 .43897 Mdot
.74 .44353 Mdot
.74 .44374 Mdot
.74 .44488 Mdot
.74 .44572 Mdot
.74 .44582 Mdot
.74 .44607 Mdot
.74 .44631 Mdot
.74 .44698 Mdot
.74 .44819 Mdot
.74 .44861 Mdot
.74 .44895 Mdot
.74 .44964 Mdot
.74 .44973 Mdot
.74 .45053 Mdot
.74 .45067 Mdot
.74 .45212 Mdot
.742 .01536 Mdot
.742 .01568 Mdot
.742 .01614 Mdot
.742 .01676 Mdot
.742 .01683 Mdot
.742 .01776 Mdot
.742 .01782 Mdot
.742 .01785 Mdot
.742 .01802 Mdot
.742 .01811 Mdot
.742 .01878 Mdot
.742 .01915 Mdot
.742 .01923 Mdot
.742 .01932 Mdot
.742 .01937 Mdot
.742 .01962 Mdot
.742 .01975 Mdot
.742 .02015 Mdot
.742 .02075 Mdot
.742 .02129 Mdot
.742 .02141 Mdot
.742 .02155 Mdot
.742 .02163 Mdot
.742 .022 Mdot
.742 .02218 Mdot
.742 .02278 Mdot
.742 .02367 Mdot
.742 .02443 Mdot
.742 .02447 Mdot
.742 .02465 Mdot
.742 .02485 Mdot
.742 .02497 Mdot
.742 .02501 Mdot
.742 .02535 Mdot
.742 .02552 Mdot
.742 .0258 Mdot
.742 .02591 Mdot
.742 .02668 Mdot
.742 .02761 Mdot
.742 .028 Mdot
.742 .02803 Mdot
.742 .02913 Mdot
.742 .02919 Mdot
.742 .02933 Mdot
.742 .02946 Mdot
.742 .02976 Mdot
.742 .02994 Mdot
.742 .02996 Mdot
.742 .03 Mdot
.742 .0305 Mdot
.742 .03053 Mdot
.742 .03076 Mdot
.742 .03116 Mdot
.742 .03134 Mdot
.742 .03136 Mdot
.742 .03247 Mdot
.742 .03385 Mdot
.742 .03443 Mdot
.742 .03447 Mdot
.742 .03484 Mdot
.742 .0349 Mdot
.742 .03527 Mdot
.742 .03577 Mdot
.742 .03611 Mdot
.742 .03617 Mdot
.742 .0362 Mdot
.742 .03641 Mdot
.742 .03645 Mdot
.742 .0366 Mdot
.742 .03704 Mdot
.742 .03731 Mdot
.742 .03733 Mdot
.742 .03739 Mdot
.742 .0377 Mdot
.742 .03795 Mdot
.742 .03813 Mdot
.742 .03818 Mdot
.742 .03818 Mdot
.742 .03852 Mdot
.742 .03872 Mdot
.742 .03903 Mdot
.742 .03912 Mdot
.742 .03938 Mdot
.742 .03942 Mdot
.742 .03968 Mdot
.742 .03993 Mdot
.742 .04063 Mdot
.742 .04077 Mdot
.742 .04107 Mdot
.742 .04159 Mdot
.742 .04169 Mdot
.742 .04311 Mdot
.742 .04397 Mdot
.742 .04399 Mdot
.742 .04403 Mdot
.742 .04458 Mdot
.742 .04466 Mdot
.742 .04522 Mdot
.742 .04533 Mdot
.742 .04534 Mdot
.742 .04595 Mdot
.742 .04646 Mdot
.742 .04655 Mdot
.742 .0466 Mdot
.742 .04691 Mdot
.742 .04697 Mdot
.742 .04719 Mdot
.742 .04785 Mdot
.742 .04824 Mdot
.742 .04828 Mdot
.742 .04837 Mdot
.742 .04883 Mdot
.742 .0492 Mdot
.742 .04935 Mdot
.742 .04936 Mdot
.742 .04947 Mdot
.742 .04954 Mdot
.742 .04954 Mdot
.742 .05002 Mdot
.742 .05004 Mdot
.742 .05034 Mdot
.742 .0506 Mdot
.742 .05079 Mdot
.742 .05093 Mdot
.742 .05132 Mdot
.742 .05137 Mdot
.742 .05177 Mdot
.742 .05214 Mdot
.742 .05317 Mdot
.742 .05339 Mdot
.742 .05354 Mdot
.742 .05382 Mdot
.742 .05399 Mdot
.742 .0546 Mdot
.742 .05475 Mdot
.742 .05558 Mdot
.742 .05599 Mdot
.742 .05685 Mdot
.742 .05814 Mdot
.742 .05816 Mdot
.742 .05822 Mdot
.742 .05831 Mdot
.742 .05904 Mdot
.742 .05916 Mdot
.742 .05943 Mdot
.742 .05998 Mdot
.742 .06011 Mdot
.742 .06015 Mdot
.742 .06016 Mdot
.742 .06075 Mdot
.742 .06107 Mdot
.742 .06119 Mdot
.742 .06136 Mdot
.742 .06138 Mdot
.742 .06182 Mdot
.742 .06196 Mdot
.742 .06202 Mdot
.742 .06204 Mdot
.742 .06249 Mdot
.742 .06259 Mdot
.742 .06291 Mdot
.742 .06389 Mdot
.742 .06447 Mdot
.742 .06452 Mdot
.742 .06452 Mdot
.742 .06466 Mdot
.742 .06534 Mdot
.742 .06588 Mdot
.742 .06589 Mdot
.742 .06611 Mdot
.742 .06613 Mdot
.742 .06629 Mdot
.742 .06639 Mdot
.742 .06639 Mdot
.742 .0671 Mdot
.742 .06714 Mdot
.742 .06758 Mdot
.742 .0676 Mdot
.742 .06797 Mdot
.742 .06825 Mdot
.742 .06846 Mdot
.742 .06903 Mdot
.742 .06911 Mdot
.742 .0697 Mdot
.742 .07025 Mdot
.742 .0703 Mdot
.742 .07108 Mdot
.742 .07179 Mdot
.742 .0721 Mdot
.742 .07233 Mdot
.742 .07236 Mdot
.742 .07275 Mdot
.742 .073 Mdot
.742 .07373 Mdot
.742 .07391 Mdot
.742 .07412 Mdot
.742 .07415 Mdot
.742 .07435 Mdot
.742 .07536 Mdot
.742 .07597 Mdot
.742 .07611 Mdot
.742 .07724 Mdot
.742 .07771 Mdot
.742 .07906 Mdot
.742 .07915 Mdot
.742 .07918 Mdot
.742 .07928 Mdot
.742 .07942 Mdot
.742 .07994 Mdot
.742 .08049 Mdot
.742 .08049 Mdot
.742 .08059 Mdot
.742 .08067 Mdot
.742 .08108 Mdot
.742 .08114 Mdot
.742 .08136 Mdot
.742 .08189 Mdot
.742 .08199 Mdot
.742 .08208 Mdot
.742 .08214 Mdot
.742 .08216 Mdot
.742 .0826 Mdot
.742 .08303 Mdot
.742 .08351 Mdot
.742 .08369 Mdot
.742 .08388 Mdot
.742 .08394 Mdot
.742 .08397 Mdot
.742 .08462 Mdot
.742 .08483 Mdot
.742 .08491 Mdot
.742 .08494 Mdot
.742 .08562 Mdot
.742 .08576 Mdot
.742 .08622 Mdot
.742 .08624 Mdot
.742 .08724 Mdot
.742 .08769 Mdot
.742 .08856 Mdot
.742 .08862 Mdot
.742 .08863 Mdot
.742 .08883 Mdot
.742 .08984 Mdot
.742 .09054 Mdot
.742 .09065 Mdot
.742 .09066 Mdot
.742 .09073 Mdot
.742 .09098 Mdot
.742 .09102 Mdot
.742 .09125 Mdot
.742 .09141 Mdot
.742 .09141 Mdot
.742 .09246 Mdot
.742 .09248 Mdot
.742 .09251 Mdot
.742 .09317 Mdot
.742 .09319 Mdot
.742 .09375 Mdot
.742 .09417 Mdot
.742 .09448 Mdot
.742 .09451 Mdot
.742 .09532 Mdot
.742 .09544 Mdot
.742 .09632 Mdot
.742 .09701 Mdot
.742 .09713 Mdot
.742 .0972 Mdot
.742 .09794 Mdot
.742 .09827 Mdot
.742 .09836 Mdot
.742 .09863 Mdot
.742 .09941 Mdot
.742 .09944 Mdot
.742 .09988 Mdot
.742 .10018 Mdot
.742 .10022 Mdot
.742 .10026 Mdot
.742 .10084 Mdot
.742 .10111 Mdot
.742 .10116 Mdot
.742 .10121 Mdot
.742 .10229 Mdot
.742 .10256 Mdot
.742 .10287 Mdot
.742 .10291 Mdot
.742 .10321 Mdot
.742 .10472 Mdot
.742 .10474 Mdot
.742 .10561 Mdot
.742 .10583 Mdot
.742 .10719 Mdot
.742 .10738 Mdot
.742 .1075 Mdot
.742 .10785 Mdot
.742 .10791 Mdot
.742 .1082 Mdot
.742 .10934 Mdot
.742 .10943 Mdot
.742 .10993 Mdot
.742 .11003 Mdot
.742 .11014 Mdot
.742 .1102 Mdot
.742 .11034 Mdot
.742 .11039 Mdot
.742 .11053 Mdot
.742 .11073 Mdot
.742 .11122 Mdot
.742 .1115 Mdot
.742 .11233 Mdot
.742 .11233 Mdot
.742 .11247 Mdot
.742 .11259 Mdot
.742 .11319 Mdot
.742 .11329 Mdot
.742 .11362 Mdot
.742 .11441 Mdot
.742 .11455 Mdot
.742 .11468 Mdot
.742 .11477 Mdot
.742 .11481 Mdot
.742 .11546 Mdot
.742 .11574 Mdot
.742 .11609 Mdot
.742 .11665 Mdot
.742 .11681 Mdot
.742 .11707 Mdot
.742 .11736 Mdot
.742 .11744 Mdot
.742 .11748 Mdot
.742 .11846 Mdot
.742 .11877 Mdot
.742 .11888 Mdot
.742 .11893 Mdot
.742 .11945 Mdot
.742 .11993 Mdot
.742 .12014 Mdot
.742 .12082 Mdot
.742 .12086 Mdot
.742 .12122 Mdot
.742 .12164 Mdot
.742 .12235 Mdot
.742 .12242 Mdot
.742 .12249 Mdot
.742 .123 Mdot
.742 .12301 Mdot
.742 .1243 Mdot
.742 .12439 Mdot
.742 .1244 Mdot
.742 .1247 Mdot
.742 .12482 Mdot
.742 .12484 Mdot
.742 .12486 Mdot
.742 .12509 Mdot
.742 .12621 Mdot
.742 .12678 Mdot
.742 .12724 Mdot
.742 .1274 Mdot
.742 .12741 Mdot
.742 .12752 Mdot
.742 .12789 Mdot
.742 .1279 Mdot
.742 .1279 Mdot
.742 .12795 Mdot
.742 .1283 Mdot
.742 .12852 Mdot
.742 .12853 Mdot
.742 .13009 Mdot
.742 .13012 Mdot
.742 .13017 Mdot
.742 .13114 Mdot
.742 .13118 Mdot
.742 .132 Mdot
.742 .13262 Mdot
.742 .13308 Mdot
.742 .13313 Mdot
.742 .13415 Mdot
.742 .13434 Mdot
.742 .13452 Mdot
.742 .1348 Mdot
.742 .13548 Mdot
.742 .13562 Mdot
.742 .13582 Mdot
.742 .13586 Mdot
.742 .13685 Mdot
.742 .13699 Mdot
.742 .13702 Mdot
.742 .13712 Mdot
.742 .13822 Mdot
.742 .13871 Mdot
.742 .13885 Mdot
.742 .13925 Mdot
.742 .13959 Mdot
.742 .14041 Mdot
.742 .14045 Mdot
.742 .14059 Mdot
.742 .14075 Mdot
.742 .14109 Mdot
.742 .14115 Mdot
.742 .14154 Mdot
.742 .1416 Mdot
.742 .14166 Mdot
.742 .14253 Mdot
.742 .14293 Mdot
.742 .14299 Mdot
.742 .14308 Mdot
.742 .14468 Mdot
.742 .14473 Mdot
.742 .14505 Mdot
.742 .14508 Mdot
.742 .14554 Mdot
.742 .1456 Mdot
.742 .14588 Mdot
.742 .14605 Mdot
.742 .14775 Mdot
.742 .14828 Mdot
.742 .14831 Mdot
.742 .14918 Mdot
.742 .1496 Mdot
.742 .14993 Mdot
.742 .14999 Mdot
.742 .15022 Mdot
.742 .15033 Mdot
.742 .15195 Mdot
.742 .15213 Mdot
.742 .15223 Mdot
.742 .1524 Mdot
.742 .15292 Mdot
.742 .15302 Mdot
.742 .15305 Mdot
.742 .15345 Mdot
.742 .15407 Mdot
.742 .15514 Mdot
.742 .15515 Mdot
.742 .15527 Mdot
.742 .15601 Mdot
.742 .15609 Mdot
.742 .15616 Mdot
.742 .15632 Mdot
.742 .15642 Mdot
.742 .15662 Mdot
.742 .15669 Mdot
.742 .15691 Mdot
.742 .15695 Mdot
.742 .1572 Mdot
.742 .15794 Mdot
.742 .15835 Mdot
.742 .15835 Mdot
.742 .15957 Mdot
.742 .15958 Mdot
.742 .15978 Mdot
.742 .15996 Mdot
.742 .16086 Mdot
.742 .161 Mdot
.742 .16148 Mdot
.742 .16161 Mdot
.742 .16232 Mdot
.742 .16266 Mdot
.742 .16287 Mdot
.742 .16306 Mdot
.742 .1632 Mdot
.742 .16325 Mdot
.742 .16326 Mdot
.742 .16345 Mdot
.742 .16422 Mdot
.742 .16463 Mdot
.742 .16516 Mdot
.742 .16598 Mdot
.742 .16622 Mdot
.742 .16662 Mdot
.742 .16704 Mdot
.742 .16716 Mdot
.742 .16723 Mdot
.742 .16776 Mdot
.742 .16825 Mdot
.742 .16867 Mdot
.742 .16893 Mdot
.742 .1691 Mdot
.742 .16913 Mdot
.742 .1693 Mdot
.742 .16937 Mdot
.742 .16956 Mdot
.742 .17014 Mdot
.742 .17086 Mdot
.742 .17117 Mdot
.742 .17218 Mdot
.742 .17224 Mdot
.742 .17277 Mdot
.742 .17339 Mdot
.742 .17416 Mdot
.742 .17444 Mdot
.742 .17454 Mdot
.742 .17465 Mdot
.742 .1749 Mdot
.742 .17513 Mdot
.742 .17541 Mdot
.742 .17543 Mdot
.742 .17652 Mdot
.742 .17727 Mdot
.742 .17733 Mdot
.742 .17747 Mdot
.742 .17749 Mdot
.742 .17793 Mdot
.742 .17796 Mdot
.742 .17811 Mdot
.742 .17814 Mdot
.742 .17818 Mdot
.742 .17851 Mdot
.742 .17989 Mdot
.742 .18017 Mdot
.742 .18103 Mdot
.742 .18157 Mdot
.742 .1817 Mdot
.742 .18193 Mdot
.742 .18196 Mdot
.742 .18211 Mdot
.742 .18267 Mdot
.742 .18267 Mdot
.742 .18268 Mdot
.742 .18275 Mdot
.742 .18327 Mdot
.742 .18361 Mdot
.742 .18361 Mdot
.742 .18552 Mdot
.742 .18572 Mdot
.742 .18593 Mdot
.742 .18597 Mdot
.742 .18605 Mdot
.742 .18639 Mdot
.742 .18719 Mdot
.742 .18749 Mdot
.742 .18754 Mdot
.742 .18766 Mdot
.742 .18876 Mdot
.742 .18886 Mdot
.742 .18911 Mdot
.742 .18968 Mdot
.742 .19012 Mdot
.742 .19037 Mdot
.742 .19044 Mdot
.742 .19047 Mdot
.742 .19102 Mdot
.742 .19131 Mdot
.742 .19162 Mdot
.742 .19195 Mdot
.742 .19224 Mdot
.742 .1925 Mdot
.742 .19293 Mdot
.742 .19392 Mdot
.742 .19414 Mdot
.742 .19443 Mdot
.742 .19449 Mdot
.742 .19581 Mdot
.742 .19596 Mdot
.742 .19617 Mdot
.742 .19622 Mdot
.742 .19636 Mdot
.742 .19777 Mdot
.742 .19799 Mdot
.742 .19806 Mdot
.742 .19849 Mdot
.742 .19872 Mdot
.742 .19893 Mdot
.742 .19952 Mdot
.742 .20003 Mdot
.742 .20124 Mdot
.742 .2013 Mdot
.742 .20151 Mdot
.742 .20175 Mdot
.742 .2019 Mdot
.742 .20226 Mdot
.742 .20234 Mdot
.742 .20265 Mdot
.742 .20276 Mdot
.742 .20293 Mdot
.742 .20301 Mdot
.742 .20311 Mdot
.742 .20439 Mdot
.742 .20499 Mdot
.742 .20508 Mdot
.742 .20521 Mdot
.742 .20625 Mdot
.742 .20648 Mdot
.742 .20652 Mdot
.742 .20759 Mdot
.742 .20766 Mdot
.742 .20767 Mdot
.742 .20802 Mdot
.742 .20813 Mdot
.742 .20818 Mdot
.742 .20819 Mdot
.742 .20822 Mdot
.742 .20833 Mdot
.742 .20869 Mdot
.742 .20886 Mdot
.742 .20895 Mdot
.742 .20936 Mdot
.742 .20961 Mdot
.742 .20986 Mdot
.742 .21042 Mdot
.742 .2107 Mdot
.742 .21206 Mdot
.742 .21214 Mdot
.742 .21287 Mdot
.742 .21292 Mdot
.742 .21296 Mdot
.742 .21369 Mdot
.742 .21426 Mdot
.742 .21489 Mdot
.742 .21537 Mdot
.742 .21546 Mdot
.742 .2155 Mdot
.742 .21581 Mdot
.742 .21597 Mdot
.742 .21643 Mdot
.742 .21837 Mdot
.742 .21864 Mdot
.742 .21879 Mdot
.742 .21905 Mdot
.742 .21981 Mdot
.742 .21996 Mdot
.742 .22001 Mdot
.742 .2206 Mdot
.742 .22088 Mdot
.742 .22114 Mdot
.742 .22152 Mdot
.742 .2231 Mdot
.742 .22312 Mdot
.742 .2233 Mdot
.742 .22352 Mdot
.742 .2237 Mdot
.742 .22383 Mdot
.742 .2244 Mdot
.742 .22451 Mdot
.742 .22462 Mdot
.742 .22486 Mdot
.742 .225 Mdot
.742 .2253 Mdot
.742 .22541 Mdot
.742 .22573 Mdot
.742 .22579 Mdot
.742 .22617 Mdot
.742 .22621 Mdot
.742 .22725 Mdot
.742 .22786 Mdot
.742 .22787 Mdot
.742 .22969 Mdot
.742 .22969 Mdot
.742 .22999 Mdot
.742 .23026 Mdot
.742 .23159 Mdot
.742 .2318 Mdot
.742 .23252 Mdot
.742 .2327 Mdot
.742 .23376 Mdot
.742 .23427 Mdot
.742 .23457 Mdot
.742 .23486 Mdot
.742 .23507 Mdot
.742 .23514 Mdot
.742 .23515 Mdot
.742 .23544 Mdot
.742 .23658 Mdot
.742 .23719 Mdot
.742 .23797 Mdot
.742 .2392 Mdot
.742 .23956 Mdot
.742 .24014 Mdot
.742 .24076 Mdot
.742 .24095 Mdot
.742 .24104 Mdot
.742 .24184 Mdot
.742 .24257 Mdot
.742 .24318 Mdot
.742 .24358 Mdot
.742 .24383 Mdot
.742 .24387 Mdot
.742 .24412 Mdot
.742 .24422 Mdot
.742 .24451 Mdot
.742 .24537 Mdot
.742 .24643 Mdot
.742 .2469 Mdot
.742 .24839 Mdot
.742 .24848 Mdot
.742 .24927 Mdot
.742 .25019 Mdot
.742 .25133 Mdot
.742 .25175 Mdot
.742 .2519 Mdot
.742 .25207 Mdot
.742 .25243 Mdot
.742 .25277 Mdot
.742 .25319 Mdot
.742 .25321 Mdot
.742 .25484 Mdot
.742 .25595 Mdot
.742 .25604 Mdot
.742 .25625 Mdot
.742 .25628 Mdot
.742 .25693 Mdot
.742 .25697 Mdot
.742 .2572 Mdot
.742 .25724 Mdot
.742 .25729 Mdot
.742 .25778 Mdot
.742 .25983 Mdot
.742 .26025 Mdot
.742 .26152 Mdot
.742 .26232 Mdot
.742 .26251 Mdot
.742 .26287 Mdot
.742 .2629 Mdot
.742 .26314 Mdot
.742 .26396 Mdot
.742 .26397 Mdot
.742 .26398 Mdot
.742 .26408 Mdot
.742 .26485 Mdot
.742 .26535 Mdot
.742 .26536 Mdot
.742 .26819 Mdot
.742 .26849 Mdot
.742 .2688 Mdot
.742 .26886 Mdot
.742 .26897 Mdot
.742 .26948 Mdot
.742 .27067 Mdot
.742 .27112 Mdot
.742 .27119 Mdot
.742 .27137 Mdot
.742 .273 Mdot
.742 .27314 Mdot
.742 .27352 Mdot
.742 .27437 Mdot
.742 .27502 Mdot
.742 .27539 Mdot
.742 .27549 Mdot
.742 .27554 Mdot
.742 .27636 Mdot
.742 .27678 Mdot
.742 .27724 Mdot
.742 .27773 Mdot
.742 .27816 Mdot
.742 .27855 Mdot
.742 .27918 Mdot
.742 .28066 Mdot
.742 .28098 Mdot
.742 .28141 Mdot
.742 .2815 Mdot
.742 .28346 Mdot
.742 .28368 Mdot
.742 .28399 Mdot
.742 .28407 Mdot
.742 .28427 Mdot
.742 .28636 Mdot
.742 .2867 Mdot
.742 .2868 Mdot
.742 .28743 Mdot
.742 .28778 Mdot
.742 .28809 Mdot
.742 .28896 Mdot
.742 .28973 Mdot
.742 .29152 Mdot
.742 .29161 Mdot
.742 .29192 Mdot
.742 .29228 Mdot
.742 .29249 Mdot
.742 .29304 Mdot
.742 .29315 Mdot
.742 .29361 Mdot
.742 .29377 Mdot
.742 .29402 Mdot
.742 .29415 Mdot
.742 .29429 Mdot
.742 .29619 Mdot
.742 .29708 Mdot
.742 .29722 Mdot
.742 .29741 Mdot
.742 .29896 Mdot
.742 .2993 Mdot
.742 .29935 Mdot
.742 .30093 Mdot
.742 .30104 Mdot
.742 .30105 Mdot
.742 .30158 Mdot
.742 .30174 Mdot
.742 .30181 Mdot
.742 .30183 Mdot
.742 .30188 Mdot
.742 .30204 Mdot
.742 .30257 Mdot
.742 .30282 Mdot
.742 .30295 Mdot
.742 .30357 Mdot
.742 .30394 Mdot
.742 .30431 Mdot
.742 .30513 Mdot
.742 .30556 Mdot
.742 .30758 Mdot
.742 .3077 Mdot
.742 .30878 Mdot
.742 .30886 Mdot
.742 .30892 Mdot
.742 .31 Mdot
.742 .31083 Mdot
.742 .31178 Mdot
.742 .31249 Mdot
.742 .31262 Mdot
.742 .31268 Mdot
.742 .31314 Mdot
.742 .31338 Mdot
.742 .31406 Mdot
.742 .31694 Mdot
.742 .31734 Mdot
.742 .31756 Mdot
.742 .31794 Mdot
.742 .31908 Mdot
.742 .31937 Mdot
.742 .32025 Mdot
.742 .32067 Mdot
.742 .32105 Mdot
.742 .32161 Mdot
.742 .32396 Mdot
.742 .32399 Mdot
.742 .32425 Mdot
.742 .32458 Mdot
.742 .32485 Mdot
.742 .32504 Mdot
.742 .32589 Mdot
.742 .32605 Mdot
.742 .32621 Mdot
.742 .32657 Mdot
.742 .32678 Mdot
.742 .32722 Mdot
.742 .32739 Mdot
.742 .32786 Mdot
.742 .32796 Mdot
.742 .32851 Mdot
.742 .32857 Mdot
.742 .33012 Mdot
.742 .33103 Mdot
.742 .33103 Mdot
.742 .33373 Mdot
.742 .33374 Mdot
.742 .33418 Mdot
.742 .33458 Mdot
.742 .33656 Mdot
.742 .33686 Mdot
.742 .33794 Mdot
.742 .33821 Mdot
.742 .33978 Mdot
.742 .34053 Mdot
.742 .34098 Mdot
.742 .34142 Mdot
.742 .34172 Mdot
.742 .34183 Mdot
.742 .34184 Mdot
.742 .34227 Mdot
.742 .34396 Mdot
.742 .34487 Mdot
.742 .34603 Mdot
.742 .34785 Mdot
.742 .34838 Mdot
.742 .34924 Mdot
.742 .35016 Mdot
.742 .35044 Mdot
.742 .35058 Mdot
.742 .35177 Mdot
.742 .35285 Mdot
.742 .35375 Mdot
.742 .35435 Mdot
.742 .35472 Mdot
.742 .35478 Mdot
.742 .35516 Mdot
.742 .3553 Mdot
.742 .35573 Mdot
.742 .357 Mdot
.742 .35858 Mdot
.742 .35927 Mdot
.742 .36149 Mdot
.742 .36162 Mdot
.742 .3628 Mdot
.742 .36417 Mdot
.742 .36585 Mdot
.742 .36648 Mdot
.742 .3667 Mdot
.742 .36694 Mdot
.742 .36749 Mdot
.742 .36799 Mdot
.742 .36862 Mdot
.742 .36864 Mdot
.742 .37106 Mdot
.742 .37271 Mdot
.742 .37284 Mdot
.742 .37315 Mdot
.742 .3732 Mdot
.742 .37416 Mdot
.742 .37422 Mdot
.742 .37456 Mdot
.742 .37462 Mdot
.742 .3747 Mdot
.742 .37543 Mdot
.742 .37847 Mdot
.742 .37908 Mdot
.742 .38097 Mdot
.742 .38217 Mdot
.742 .38245 Mdot
.742 .38297 Mdot
.742 .38302 Mdot
.742 .38337 Mdot
.742 .38459 Mdot
.742 .3846 Mdot
.742 .38462 Mdot
.742 .38477 Mdot
.742 .38591 Mdot
.742 .38666 Mdot
.742 .38667 Mdot
.742 .39087 Mdot
.742 .39132 Mdot
.742 .39177 Mdot
.742 .39187 Mdot
.742 .39203 Mdot
.742 .39279 Mdot
.742 .39454 Mdot
.742 .39522 Mdot
.742 .39533 Mdot
.742 .39559 Mdot
.742 .39801 Mdot
.742 .39822 Mdot
.742 .39878 Mdot
.742 .40004 Mdot
.742 .401 Mdot
.742 .40155 Mdot
.742 .40171 Mdot
.742 .40178 Mdot
.742 .40299 Mdot
.742 .40361 Mdot
.742 .4043 Mdot
.742 .40503 Mdot
.742 .40566 Mdot
.742 .40624 Mdot
.742 .40718 Mdot
.742 .40938 Mdot
.742 .40986 Mdot
.742 .41049 Mdot
.742 .41062 Mdot
.742 .41353 Mdot
.742 .41386 Mdot
.742 .41432 Mdot
.742 .41443 Mdot
.742 .41474 Mdot
.742 .41784 Mdot
.742 .41834 Mdot
.742 .41849 Mdot
.742 .41943 Mdot
.742 .41994 Mdot
.742 .4204 Mdot
.742 .4217 Mdot
.742 .42283 Mdot
.742 .42549 Mdot
.742 .42563 Mdot
.742 .42608 Mdot
.742 .42662 Mdot
.742 .42694 Mdot
.742 .42774 Mdot
.742 .42791 Mdot
.742 .42859 Mdot
.742 .42883 Mdot
.742 .4292 Mdot
.742 .42939 Mdot
.742 .4296 Mdot
.742 .43243 Mdot
.742 .43375 Mdot
.742 .43395 Mdot
.742 .43423 Mdot
.742 .43653 Mdot
.742 .43704 Mdot
.742 .43711 Mdot
.742 .43946 Mdot
.742 .43962 Mdot
.742 .43964 Mdot
.742 .44042 Mdot
.742 .44065 Mdot
.742 .44077 Mdot
.742 .44079 Mdot
.742 .44087 Mdot
.742 .44111 Mdot
.742 .4419 Mdot
.742 .44227 Mdot
.742 .44246 Mdot
.742 .44338 Mdot
.742 .44392 Mdot
.742 .44448 Mdot
.742 .4457 Mdot
.742 .44632 Mdot
.742 .44932 Mdot
.742 .4495 Mdot
.742 .4511 Mdot
.742 .45122 Mdot
.742 .45131 Mdot
.742 .45291 Mdot
.744 .01655 Mdot
.744 .01659 Mdot
.744 .01745 Mdot
.744 .0175 Mdot
.744 .01758 Mdot
.744 .01804 Mdot
.744 .01879 Mdot
.744 .01886 Mdot
.744 .01898 Mdot
.744 .01966 Mdot
.744 .01998 Mdot
.744 .02041 Mdot
.744 .02058 Mdot
.744 .02077 Mdot
.744 .02089 Mdot
.744 .02106 Mdot
.744 .02131 Mdot
.744 .02204 Mdot
.744 .02207 Mdot
.744 .02255 Mdot
.744 .02256 Mdot
.744 .02319 Mdot
.744 .02344 Mdot
.744 .02373 Mdot
.744 .0239 Mdot
.744 .02415 Mdot
.744 .02432 Mdot
.744 .02453 Mdot
.744 .02561 Mdot
.744 .02566 Mdot
.744 .02594 Mdot
.744 .02604 Mdot
.744 .02638 Mdot
.744 .02638 Mdot
.744 .02645 Mdot
.744 .02682 Mdot
.744 .02699 Mdot
.744 .0271 Mdot
.744 .02711 Mdot
.744 .02733 Mdot
.744 .0277 Mdot
.744 .02781 Mdot
.744 .02813 Mdot
.744 .02823 Mdot
.744 .02838 Mdot
.744 .02876 Mdot
.744 .02889 Mdot
.744 .029 Mdot
.744 .02908 Mdot
.744 .02932 Mdot
.744 .02968 Mdot
.744 .03061 Mdot
.744 .03065 Mdot
.744 .03086 Mdot
.744 .03092 Mdot
.744 .031 Mdot
.744 .03142 Mdot
.744 .03154 Mdot
.744 .03156 Mdot
.744 .03183 Mdot
.744 .03207 Mdot
.744 .03208 Mdot
.744 .03208 Mdot
.744 .03217 Mdot
.744 .03233 Mdot
.744 .03273 Mdot
.744 .03273 Mdot
.744 .03298 Mdot
.744 .03314 Mdot
.744 .03316 Mdot
.744 .03333 Mdot
.744 .03349 Mdot
.744 .03382 Mdot
.744 .03393 Mdot
.744 .03404 Mdot
.744 .03419 Mdot
.744 .03467 Mdot
.744 .03482 Mdot
.744 .03495 Mdot
.744 .03504 Mdot
.744 .03561 Mdot
.744 .03581 Mdot
.744 .03597 Mdot
.744 .03609 Mdot
.744 .03644 Mdot
.744 .03645 Mdot
.744 .03698 Mdot
.744 .03836 Mdot
.744 .03842 Mdot
.744 .03873 Mdot
.744 .03874 Mdot
.744 .03883 Mdot
.744 .03894 Mdot
.744 .03916 Mdot
.744 .03935 Mdot
.744 .03941 Mdot
.744 .03957 Mdot
.744 .03975 Mdot
.744 .03978 Mdot
.744 .03979 Mdot
.744 .04018 Mdot
.744 .04054 Mdot
.744 .04055 Mdot
.744 .04055 Mdot
.744 .04069 Mdot
.744 .04092 Mdot
.744 .04119 Mdot
.744 .04144 Mdot
.744 .04152 Mdot
.744 .04152 Mdot
.744 .04164 Mdot
.744 .0419 Mdot
.744 .04207 Mdot
.744 .04213 Mdot
.744 .04216 Mdot
.744 .04241 Mdot
.744 .04265 Mdot
.744 .04288 Mdot
.744 .04314 Mdot
.744 .0433 Mdot
.744 .04347 Mdot
.744 .04348 Mdot
.744 .04351 Mdot
.744 .04365 Mdot
.744 .0437 Mdot
.744 .04441 Mdot
.744 .04463 Mdot
.744 .04482 Mdot
.744 .04496 Mdot
.744 .0458 Mdot
.744 .04581 Mdot
.744 .0461 Mdot
.744 .04635 Mdot
.744 .04652 Mdot
.744 .04704 Mdot
.744 .04706 Mdot
.744 .0472 Mdot
.744 .04767 Mdot
.744 .04785 Mdot
.744 .0499 Mdot
.744 .04999 Mdot
.744 .05044 Mdot
.744 .05047 Mdot
.744 .0506 Mdot
.744 .05076 Mdot
.744 .05108 Mdot
.744 .05137 Mdot
.744 .05147 Mdot
.744 .0517 Mdot
.744 .05197 Mdot
.744 .05201 Mdot
.744 .05203 Mdot
.744 .05237 Mdot
.744 .05261 Mdot
.744 .05314 Mdot
.744 .05315 Mdot
.744 .05316 Mdot
.744 .05336 Mdot
.744 .05371 Mdot
.744 .05379 Mdot
.744 .05411 Mdot
.744 .05444 Mdot
.744 .05448 Mdot
.744 .0546 Mdot
.744 .0546 Mdot
.744 .05478 Mdot
.744 .05517 Mdot
.744 .05542 Mdot
.744 .05551 Mdot
.744 .05555 Mdot
.744 .05592 Mdot
.744 .05628 Mdot
.744 .05629 Mdot
.744 .05663 Mdot
.744 .05672 Mdot
.744 .05702 Mdot
.744 .05725 Mdot
.744 .0575 Mdot
.744 .05752 Mdot
.744 .05756 Mdot
.744 .05777 Mdot
.744 .05784 Mdot
.744 .0579 Mdot
.744 .05791 Mdot
.744 .05891 Mdot
.744 .05923 Mdot
.744 .05952 Mdot
.744 .05972 Mdot
.744 .06054 Mdot
.744 .06076 Mdot
.744 .06098 Mdot
.744 .06099 Mdot
.744 .06105 Mdot
.744 .06142 Mdot
.744 .06178 Mdot
.744 .06205 Mdot
.744 .06281 Mdot
.744 .06285 Mdot
.744 .06305 Mdot
.744 .06331 Mdot
.744 .06335 Mdot
.744 .06375 Mdot
.744 .06402 Mdot
.744 .06701 Mdot
.744 .06707 Mdot
.744 .0672 Mdot
.744 .06788 Mdot
.744 .06792 Mdot
.744 .06812 Mdot
.744 .06836 Mdot
.744 .06883 Mdot
.744 .06926 Mdot
.744 .0694 Mdot
.744 .06974 Mdot
.744 .07015 Mdot
.744 .07021 Mdot
.744 .07024 Mdot
.744 .07074 Mdot
.744 .0711 Mdot
.744 .07141 Mdot
.744 .07189 Mdot
.744 .07191 Mdot
.744 .07192 Mdot
.744 .07216 Mdot
.744 .07222 Mdot
.744 .07274 Mdot
.744 .07286 Mdot
.744 .07333 Mdot
.744 .07383 Mdot
.744 .07388 Mdot
.744 .07406 Mdot
.744 .07407 Mdot
.744 .07433 Mdot
.744 .07458 Mdot
.744 .07491 Mdot
.744 .07528 Mdot
.744 .07542 Mdot
.744 .07548 Mdot
.744 .07575 Mdot
.744 .07603 Mdot
.744 .07657 Mdot
.744 .07658 Mdot
.744 .07688 Mdot
.744 .077 Mdot
.744 .07708 Mdot
.744 .07721 Mdot
.744 .07737 Mdot
.744 .07765 Mdot
.744 .07766 Mdot
.744 .07801 Mdot
.744 .07838 Mdot
.744 .07841 Mdot
.744 .07847 Mdot
.744 .07878 Mdot
.744 .07889 Mdot
.744 .07897 Mdot
.744 .07899 Mdot
.744 .08047 Mdot
.744 .08095 Mdot
.744 .08095 Mdot
.744 .08138 Mdot
.744 .08169 Mdot
.744 .08169 Mdot
.744 .0829 Mdot
.744 .08324 Mdot
.744 .08355 Mdot
.744 .08357 Mdot
.744 .08366 Mdot
.744 .08421 Mdot
.744 .08475 Mdot
.744 .08514 Mdot
.744 .08564 Mdot
.744 .08629 Mdot
.744 .0863 Mdot
.744 .08634 Mdot
.744 .08663 Mdot
.744 .08702 Mdot
.744 .08708 Mdot
.744 .08768 Mdot
.744 .08808 Mdot
.744 .08851 Mdot
.744 .08862 Mdot
.744 .09006 Mdot
.744 .09216 Mdot
.744 .09252 Mdot
.744 .09262 Mdot
.744 .09282 Mdot
.744 .09309 Mdot
.744 .09382 Mdot
.744 .09388 Mdot
.744 .09418 Mdot
.744 .09453 Mdot
.744 .09524 Mdot
.744 .09587 Mdot
.744 .09609 Mdot
.744 .0966 Mdot
.744 .09683 Mdot
.744 .09697 Mdot
.744 .09721 Mdot
.744 .09722 Mdot
.744 .0973 Mdot
.744 .09733 Mdot
.744 .09808 Mdot
.744 .09862 Mdot
.744 .09879 Mdot
.744 .09907 Mdot
.744 .09938 Mdot
.744 .0998 Mdot
.744 .09982 Mdot
.744 .09984 Mdot
.744 .10019 Mdot
.744 .10028 Mdot
.744 .10106 Mdot
.744 .10124 Mdot
.744 .10193 Mdot
.744 .10205 Mdot
.744 .10222 Mdot
.744 .10262 Mdot
.744 .10268 Mdot
.744 .10275 Mdot
.744 .10302 Mdot
.744 .10303 Mdot
.744 .10342 Mdot
.744 .1038 Mdot
.744 .10428 Mdot
.744 .10484 Mdot
.744 .10505 Mdot
.744 .10514 Mdot
.744 .10554 Mdot
.744 .10595 Mdot
.744 .10675 Mdot
.744 .10677 Mdot
.744 .10699 Mdot
.744 .10699 Mdot
.744 .10722 Mdot
.744 .10739 Mdot
.744 .10751 Mdot
.744 .10771 Mdot
.744 .10775 Mdot
.744 .10795 Mdot
.744 .108 Mdot
.744 .10836 Mdot
.744 .10838 Mdot
.744 .10889 Mdot
.744 .10945 Mdot
.744 .10949 Mdot
.744 .10958 Mdot
.744 .10991 Mdot
.744 .10995 Mdot
.744 .11004 Mdot
.744 .11021 Mdot
.744 .11033 Mdot
.744 .11036 Mdot
.744 .1108 Mdot
.744 .11214 Mdot
.744 .11256 Mdot
.744 .11303 Mdot
.744 .11327 Mdot
.744 .11327 Mdot
.744 .11385 Mdot
.744 .11391 Mdot
.744 .11437 Mdot
.744 .11438 Mdot
.744 .11513 Mdot
.744 .11618 Mdot
.744 .11667 Mdot
.744 .11714 Mdot
.744 .11717 Mdot
.744 .11724 Mdot
.744 .1173 Mdot
.744 .11812 Mdot
.744 .11893 Mdot
.744 .11951 Mdot
.744 .12026 Mdot
.744 .12121 Mdot
.744 .12124 Mdot
.744 .12129 Mdot
.744 .12173 Mdot
.744 .12231 Mdot
.744 .12239 Mdot
.744 .12328 Mdot
.744 .12388 Mdot
.744 .12433 Mdot
.744 .12451 Mdot
.744 .12468 Mdot
.744 .12494 Mdot
.744 .12682 Mdot
.744 .12885 Mdot
.744 .12995 Mdot
.744 .13049 Mdot
.744 .13063 Mdot
.744 .13093 Mdot
.744 .13133 Mdot
.744 .13243 Mdot
.744 .13251 Mdot
.744 .13295 Mdot
.744 .13348 Mdot
.744 .13428 Mdot
.744 .13454 Mdot
.744 .13548 Mdot
.744 .1358 Mdot
.744 .13655 Mdot
.744 .13691 Mdot
.744 .13711 Mdot
.744 .13746 Mdot
.744 .13748 Mdot
.744 .1376 Mdot
.744 .13765 Mdot
.744 .13877 Mdot
.744 .13956 Mdot
.744 .13966 Mdot
.744 .13982 Mdot
.744 .14008 Mdot
.744 .14024 Mdot
.744 .1407 Mdot
.744 .14103 Mdot
.744 .14131 Mdot
.744 .14136 Mdot
.744 .14138 Mdot
.744 .1417 Mdot
.744 .1419 Mdot
.744 .14204 Mdot
.744 .14234 Mdot
.744 .14301 Mdot
.744 .14319 Mdot
.744 .14327 Mdot
.744 .14346 Mdot
.744 .14406 Mdot
.744 .14447 Mdot
.744 .1445 Mdot
.744 .14468 Mdot
.744 .14493 Mdot
.744 .14552 Mdot
.744 .1456 Mdot
.744 .14572 Mdot
.744 .14588 Mdot
.744 .14611 Mdot
.744 .14613 Mdot
.744 .14646 Mdot
.744 .14671 Mdot
.744 .14727 Mdot
.744 .14799 Mdot
.744 .14882 Mdot
.744 .14913 Mdot
.744 .14927 Mdot
.744 .14986 Mdot
.744 .15004 Mdot
.744 .15048 Mdot
.744 .15166 Mdot
.744 .15169 Mdot
.744 .15182 Mdot
.744 .15202 Mdot
.744 .15202 Mdot
.744 .15223 Mdot
.744 .15236 Mdot
.744 .15256 Mdot
.744 .15262 Mdot
.744 .1528 Mdot
.744 .15309 Mdot
.744 .15316 Mdot
.744 .15345 Mdot
.744 .15353 Mdot
.744 .15372 Mdot
.744 .15406 Mdot
.744 .15409 Mdot
.744 .1544 Mdot
.744 .15485 Mdot
.744 .15568 Mdot
.744 .15573 Mdot
.744 .15587 Mdot
.744 .15637 Mdot
.744 .15643 Mdot
.744 .15656 Mdot
.744 .15681 Mdot
.744 .15699 Mdot
.744 .157 Mdot
.744 .15704 Mdot
.744 .15769 Mdot
.744 .15969 Mdot
.744 .16012 Mdot
.744 .16032 Mdot
.744 .16088 Mdot
.744 .16101 Mdot
.744 .16136 Mdot
.744 .16137 Mdot
.744 .16217 Mdot
.744 .16223 Mdot
.744 .16232 Mdot
.744 .16301 Mdot
.744 .16302 Mdot
.744 .16413 Mdot
.744 .16546 Mdot
.744 .16569 Mdot
.744 .16643 Mdot
.744 .16678 Mdot
.744 .16713 Mdot
.744 .16716 Mdot
.744 .16728 Mdot
.744 .16736 Mdot
.744 .16836 Mdot
.744 .16859 Mdot
.744 .16979 Mdot
.744 .16999 Mdot
.744 .17065 Mdot
.744 .17069 Mdot
.744 .17112 Mdot
.744 .17176 Mdot
.744 .17204 Mdot
.744 .17318 Mdot
.744 .17322 Mdot
.744 .1733 Mdot
.744 .17378 Mdot
.744 .17396 Mdot
.744 .17477 Mdot
.744 .17482 Mdot
.744 .17494 Mdot
.744 .17626 Mdot
.744 .17626 Mdot
.744 .1765 Mdot
.744 .17657 Mdot
.744 .17673 Mdot
.744 .17715 Mdot
.744 .17716 Mdot
.744 .17742 Mdot
.744 .17783 Mdot
.744 .1781 Mdot
.744 .17835 Mdot
.744 .17873 Mdot
.744 .17938 Mdot
.744 .18153 Mdot
.744 .18171 Mdot
.744 .1829 Mdot
.744 .18455 Mdot
.744 .18618 Mdot
.744 .18631 Mdot
.744 .1866 Mdot
.744 .1868 Mdot
.744 .18699 Mdot
.744 .1872 Mdot
.744 .18728 Mdot
.744 .18751 Mdot
.744 .18764 Mdot
.744 .18807 Mdot
.744 .18824 Mdot
.744 .18933 Mdot
.744 .18987 Mdot
.744 .19 Mdot
.744 .1901 Mdot
.744 .19045 Mdot
.744 .19065 Mdot
.744 .19144 Mdot
.744 .19239 Mdot
.744 .19262 Mdot
.744 .19301 Mdot
.744 .19401 Mdot
.744 .19441 Mdot
.744 .19489 Mdot
.744 .19539 Mdot
.744 .1956 Mdot
.744 .19573 Mdot
.744 .19601 Mdot
.744 .19654 Mdot
.744 .19684 Mdot
.744 .19729 Mdot
.744 .19736 Mdot
.744 .19738 Mdot
.744 .19743 Mdot
.744 .19756 Mdot
.744 .19764 Mdot
.744 .19824 Mdot
.744 .19894 Mdot
.744 .1993 Mdot
.744 .20034 Mdot
.744 .20043 Mdot
.744 .20049 Mdot
.744 .20063 Mdot
.744 .20071 Mdot
.744 .20087 Mdot
.744 .20126 Mdot
.744 .20149 Mdot
.744 .2016 Mdot
.744 .20219 Mdot
.744 .20268 Mdot
.744 .20309 Mdot
.744 .20316 Mdot
.744 .2032 Mdot
.744 .20367 Mdot
.744 .20372 Mdot
.744 .20396 Mdot
.744 .20417 Mdot
.744 .2046 Mdot
.744 .20462 Mdot
.744 .20471 Mdot
.744 .20498 Mdot
.744 .20562 Mdot
.744 .20589 Mdot
.744 .20592 Mdot
.744 .20601 Mdot
.744 .20629 Mdot
.744 .20717 Mdot
.744 .2078 Mdot
.744 .20783 Mdot
.744 .2081 Mdot
.744 .20847 Mdot
.744 .20883 Mdot
.744 .20935 Mdot
.744 .20947 Mdot
.744 .20964 Mdot
.744 .20989 Mdot
.744 .21023 Mdot
.744 .21025 Mdot
.744 .21075 Mdot
.744 .21088 Mdot
.744 .21098 Mdot
.744 .21112 Mdot
.744 .21186 Mdot
.744 .21196 Mdot
.744 .21302 Mdot
.744 .21309 Mdot
.744 .21426 Mdot
.744 .21427 Mdot
.744 .21472 Mdot
.744 .21493 Mdot
.744 .2158 Mdot
.744 .216 Mdot
.744 .21607 Mdot
.744 .21641 Mdot
.744 .21673 Mdot
.744 .21697 Mdot
.744 .21776 Mdot
.744 .21849 Mdot
.744 .21854 Mdot
.744 .21872 Mdot
.744 .21889 Mdot
.744 .21897 Mdot
.744 .21902 Mdot
.744 .21902 Mdot
.744 .21934 Mdot
.744 .21953 Mdot
.744 .21983 Mdot
.744 .21991 Mdot
.744 .22018 Mdot
.744 .2206 Mdot
.744 .22062 Mdot
.744 .22072 Mdot
.744 .22103 Mdot
.744 .22116 Mdot
.744 .22127 Mdot
.744 .22138 Mdot
.744 .22156 Mdot
.744 .22183 Mdot
.744 .22205 Mdot
.744 .2221 Mdot
.744 .22256 Mdot
.744 .22324 Mdot
.744 .22427 Mdot
.744 .22446 Mdot
.744 .22455 Mdot
.744 .22458 Mdot
.744 .22475 Mdot
.744 .22549 Mdot
.744 .22559 Mdot
.744 .22578 Mdot
.744 .22615 Mdot
.744 .22642 Mdot
.744 .22643 Mdot
.744 .22649 Mdot
.744 .22747 Mdot
.744 .2281 Mdot
.744 .22831 Mdot
.744 .23043 Mdot
.744 .23107 Mdot
.744 .23137 Mdot
.744 .2322 Mdot
.744 .23239 Mdot
.744 .23293 Mdot
.744 .23294 Mdot
.744 .23412 Mdot
.744 .23422 Mdot
.744 .23435 Mdot
.744 .23537 Mdot
.744 .23539 Mdot
.744 .23704 Mdot
.744 .23903 Mdot
.744 .23937 Mdot
.744 .24046 Mdot
.744 .24099 Mdot
.744 .2415 Mdot
.744 .24155 Mdot
.744 .24173 Mdot
.744 .24185 Mdot
.744 .24334 Mdot
.744 .24368 Mdot
.744 .24546 Mdot
.744 .24576 Mdot
.744 .24675 Mdot
.744 .2468 Mdot
.744 .24745 Mdot
.744 .2484 Mdot
.744 .24882 Mdot
.744 .25051 Mdot
.744 .25057 Mdot
.744 .25069 Mdot
.744 .2514 Mdot
.744 .25167 Mdot
.744 .25287 Mdot
.744 .25295 Mdot
.744 .25313 Mdot
.744 .2551 Mdot
.744 .2551 Mdot
.744 .25545 Mdot
.744 .25556 Mdot
.744 .25642 Mdot
.744 .25644 Mdot
.744 .25682 Mdot
.744 .25743 Mdot
.744 .25783 Mdot
.744 .2582 Mdot
.744 .25878 Mdot
.744 .25973 Mdot
.744 .26293 Mdot
.744 .26321 Mdot
.744 .26497 Mdot
.744 .26742 Mdot
.744 .26986 Mdot
.744 .27005 Mdot
.744 .27048 Mdot
.744 .27078 Mdot
.744 .27107 Mdot
.744 .27137 Mdot
.744 .27149 Mdot
.744 .27184 Mdot
.744 .27203 Mdot
.744 .27266 Mdot
.744 .27293 Mdot
.744 .27454 Mdot
.744 .27535 Mdot
.744 .27553 Mdot
.744 .27568 Mdot
.744 .27621 Mdot
.744 .27651 Mdot
.744 .27769 Mdot
.744 .2791 Mdot
.744 .27944 Mdot
.744 .28002 Mdot
.744 .28151 Mdot
.744 .28211 Mdot
.744 .28282 Mdot
.744 .28355 Mdot
.744 .28387 Mdot
.744 .28407 Mdot
.744 .28448 Mdot
.744 .28526 Mdot
.744 .28571 Mdot
.744 .28639 Mdot
.744 .28649 Mdot
.744 .28653 Mdot
.744 .2866 Mdot
.744 .28679 Mdot
.744 .28691 Mdot
.744 .28779 Mdot
.744 .28885 Mdot
.744 .28938 Mdot
.744 .29092 Mdot
.744 .29105 Mdot
.744 .29115 Mdot
.744 .29136 Mdot
.744 .29147 Mdot
.744 .29172 Mdot
.744 .29229 Mdot
.744 .29263 Mdot
.744 .29279 Mdot
.744 .29367 Mdot
.744 .2944 Mdot
.744 .29502 Mdot
.744 .29512 Mdot
.744 .29518 Mdot
.744 .29588 Mdot
.744 .29595 Mdot
.744 .29631 Mdot
.744 .29663 Mdot
.744 .29726 Mdot
.744 .2973 Mdot
.744 .29743 Mdot
.744 .29783 Mdot
.744 .29879 Mdot
.744 .29918 Mdot
.744 .29923 Mdot
.744 .29936 Mdot
.744 .29978 Mdot
.744 .30109 Mdot
.744 .30202 Mdot
.744 .30207 Mdot
.744 .30247 Mdot
.744 .30302 Mdot
.744 .30355 Mdot
.744 .30433 Mdot
.744 .30452 Mdot
.744 .30477 Mdot
.744 .30513 Mdot
.744 .30564 Mdot
.744 .30568 Mdot
.744 .30641 Mdot
.744 .3066 Mdot
.744 .30676 Mdot
.744 .30697 Mdot
.744 .30807 Mdot
.744 .30821 Mdot
.744 .3098 Mdot
.744 .30989 Mdot
.744 .31163 Mdot
.744 .31165 Mdot
.744 .31232 Mdot
.744 .31263 Mdot
.744 .31394 Mdot
.744 .31423 Mdot
.744 .31434 Mdot
.744 .31483 Mdot
.744 .31532 Mdot
.744 .31567 Mdot
.744 .31685 Mdot
.744 .31794 Mdot
.744 .318 Mdot
.744 .31828 Mdot
.744 .31853 Mdot
.744 .31865 Mdot
.744 .31872 Mdot
.744 .31873 Mdot
.744 .31919 Mdot
.744 .31948 Mdot
.744 .31992 Mdot
.744 .32005 Mdot
.744 .32045 Mdot
.744 .32108 Mdot
.744 .3211 Mdot
.744 .32125 Mdot
.744 .3217 Mdot
.744 .3219 Mdot
.744 .32207 Mdot
.744 .32223 Mdot
.744 .3225 Mdot
.744 .3229 Mdot
.744 .32324 Mdot
.744 .32331 Mdot
.744 .32399 Mdot
.744 .325 Mdot
.744 .32653 Mdot
.744 .32682 Mdot
.744 .32695 Mdot
.744 .327 Mdot
.744 .32725 Mdot
.744 .32835 Mdot
.744 .32849 Mdot
.744 .32878 Mdot
.744 .32933 Mdot
.744 .32973 Mdot
.744 .32975 Mdot
.744 .32984 Mdot
.744 .33129 Mdot
.744 .33223 Mdot
.744 .33254 Mdot
.744 .3357 Mdot
.744 .33666 Mdot
.744 .33709 Mdot
.744 .33834 Mdot
.744 .33862 Mdot
.744 .33942 Mdot
.744 .33943 Mdot
.744 .34119 Mdot
.744 .34134 Mdot
.744 .34153 Mdot
.744 .34305 Mdot
.744 .34308 Mdot
.744 .34554 Mdot
.744 .34849 Mdot
.744 .349 Mdot
.744 .35063 Mdot
.744 .35141 Mdot
.744 .35217 Mdot
.744 .35225 Mdot
.744 .35251 Mdot
.744 .35269 Mdot
.744 .35491 Mdot
.744 .35541 Mdot
.744 .35806 Mdot
.744 .35851 Mdot
.744 .35999 Mdot
.744 .36006 Mdot
.744 .36103 Mdot
.744 .36244 Mdot
.744 .36307 Mdot
.744 .36558 Mdot
.744 .36567 Mdot
.744 .36584 Mdot
.744 .3669 Mdot
.744 .3673 Mdot
.744 .36909 Mdot
.744 .3692 Mdot
.744 .36947 Mdot
.744 .37241 Mdot
.744 .37241 Mdot
.744 .37292 Mdot
.744 .37309 Mdot
.744 .37437 Mdot
.744 .3744 Mdot
.744 .37497 Mdot
.744 .37587 Mdot
.744 .37647 Mdot
.744 .37702 Mdot
.744 .37788 Mdot
.744 .3793 Mdot
.744 .38406 Mdot
.744 .38447 Mdot
.744 .3871 Mdot
.744 .39075 Mdot
.744 .39436 Mdot
.744 .39465 Mdot
.744 .39529 Mdot
.744 .39574 Mdot
.744 .39617 Mdot
.744 .39662 Mdot
.744 .39679 Mdot
.744 .39732 Mdot
.744 .3976 Mdot
.744 .39854 Mdot
.744 .39893 Mdot
.744 .40134 Mdot
.744 .40253 Mdot
.744 .40281 Mdot
.744 .40303 Mdot
.744 .40382 Mdot
.744 .40427 Mdot
.744 .40602 Mdot
.744 .40811 Mdot
.744 .40862 Mdot
.744 .40949 Mdot
.744 .41171 Mdot
.744 .41259 Mdot
.744 .41365 Mdot
.744 .41474 Mdot
.744 .41522 Mdot
.744 .41551 Mdot
.744 .41613 Mdot
.744 .41729 Mdot
.744 .41796 Mdot
.744 .41896 Mdot
.744 .41912 Mdot
.744 .41917 Mdot
.744 .41928 Mdot
.744 .41957 Mdot
.744 .41974 Mdot
.744 .42106 Mdot
.744 .42263 Mdot
.744 .42342 Mdot
.744 .42571 Mdot
.744 .42591 Mdot
.744 .42605 Mdot
.744 .42636 Mdot
.744 .42653 Mdot
.744 .4269 Mdot
.744 .42775 Mdot
.744 .42826 Mdot
.744 .4285 Mdot
.744 .4298 Mdot
.744 .43089 Mdot
.744 .43181 Mdot
.744 .43196 Mdot
.744 .43205 Mdot
.744 .43309 Mdot
.744 .43319 Mdot
.744 .43373 Mdot
.744 .43421 Mdot
.744 .43514 Mdot
.744 .4352 Mdot
.744 .43539 Mdot
.744 .43599 Mdot
.744 .43741 Mdot
.744 .43801 Mdot
.744 .43808 Mdot
.744 .43826 Mdot
.744 .4389 Mdot
.744 .44085 Mdot
.744 .44223 Mdot
.744 .4423 Mdot
.744 .44289 Mdot
.744 .44371 Mdot
.744 .44451 Mdot
.744 .44567 Mdot
.744 .44594 Mdot
.744 .44632 Mdot
.744 .44685 Mdot
.744 .44761 Mdot
.744 .44766 Mdot
.744 .44876 Mdot
.744 .44905 Mdot
.744 .44928 Mdot
.744 .44959 Mdot
.744 .45123 Mdot
.744 .45143 Mdot
.744 .4538 Mdot
.744 .45394 Mdot
.746 .01721 Mdot
.746 .01746 Mdot
.746 .01844 Mdot
.746 .01882 Mdot
.746 .01882 Mdot
.746 .01968 Mdot
.746 .02028 Mdot
.746 .02083 Mdot
.746 .02083 Mdot
.746 .02124 Mdot
.746 .0216 Mdot
.746 .02213 Mdot
.746 .02233 Mdot
.746 .02296 Mdot
.746 .02301 Mdot
.746 .02384 Mdot
.746 .02385 Mdot
.746 .02405 Mdot
.746 .02444 Mdot
.746 .02445 Mdot
.746 .02467 Mdot
.746 .02499 Mdot
.746 .02513 Mdot
.746 .02543 Mdot
.746 .02577 Mdot
.746 .02608 Mdot
.746 .02689 Mdot
.746 .02701 Mdot
.746 .0271 Mdot
.746 .02722 Mdot
.746 .02728 Mdot
.746 .02833 Mdot
.746 .02834 Mdot
.746 .02852 Mdot
.746 .02864 Mdot
.746 .02875 Mdot
.746 .02893 Mdot
.746 .02898 Mdot
.746 .02922 Mdot
.746 .02924 Mdot
.746 .0295 Mdot
.746 .02957 Mdot
.746 .03005 Mdot
.746 .03025 Mdot
.746 .03047 Mdot
.746 .03071 Mdot
.746 .03086 Mdot
.746 .03122 Mdot
.746 .03167 Mdot
.746 .03181 Mdot
.746 .03251 Mdot
.746 .03288 Mdot
.746 .03306 Mdot
.746 .03319 Mdot
.746 .03338 Mdot
.746 .03341 Mdot
.746 .03346 Mdot
.746 .03354 Mdot
.746 .03386 Mdot
.746 .03503 Mdot
.746 .03504 Mdot
.746 .03531 Mdot
.746 .03549 Mdot
.746 .03566 Mdot
.746 .03581 Mdot
.746 .03592 Mdot
.746 .036 Mdot
.746 .03636 Mdot
.746 .03639 Mdot
.746 .03677 Mdot
.746 .03687 Mdot
.746 .03716 Mdot
.746 .03759 Mdot
.746 .03781 Mdot
.746 .0379 Mdot
.746 .03822 Mdot
.746 .03832 Mdot
.746 .03858 Mdot
.746 .0388 Mdot
.746 .03933 Mdot
.746 .03973 Mdot
.746 .04001 Mdot
.746 .04022 Mdot
.746 .0406 Mdot
.746 .0408 Mdot
.746 .04127 Mdot
.746 .04182 Mdot
.746 .04209 Mdot
.746 .04228 Mdot
.746 .04256 Mdot
.746 .0426 Mdot
.746 .04268 Mdot
.746 .0428 Mdot
.746 .04328 Mdot
.746 .04364 Mdot
.746 .04409 Mdot
.746 .04424 Mdot
.746 .0443 Mdot
.746 .04503 Mdot
.746 .04504 Mdot
.746 .04544 Mdot
.746 .04572 Mdot
.746 .04597 Mdot
.746 .04608 Mdot
.746 .04619 Mdot
.746 .04635 Mdot
.746 .04647 Mdot
.746 .04701 Mdot
.746 .04706 Mdot
.746 .04763 Mdot
.746 .04777 Mdot
.746 .0482 Mdot
.746 .04884 Mdot
.746 .04885 Mdot
.746 .04917 Mdot
.746 .04931 Mdot
.746 .04959 Mdot
.746 .04979 Mdot
.746 .04993 Mdot
.746 .05032 Mdot
.746 .05065 Mdot
.746 .05092 Mdot
.746 .05145 Mdot
.746 .05172 Mdot
.746 .05204 Mdot
.746 .05245 Mdot
.746 .05266 Mdot
.746 .05278 Mdot
.746 .05334 Mdot
.746 .05363 Mdot
.746 .05433 Mdot
.746 .05449 Mdot
.746 .05516 Mdot
.746 .05545 Mdot
.746 .05555 Mdot
.746 .05584 Mdot
.746 .056 Mdot
.746 .05614 Mdot
.746 .05626 Mdot
.746 .05632 Mdot
.746 .05644 Mdot
.746 .05662 Mdot
.746 .05698 Mdot
.746 .05707 Mdot
.746 .05733 Mdot
.746 .05755 Mdot
.746 .05787 Mdot
.746 .05855 Mdot
.746 .05876 Mdot
.746 .05886 Mdot
.746 .0589 Mdot
.746 .0594 Mdot
.746 .05995 Mdot
.746 .05996 Mdot
.746 .06048 Mdot
.746 .06056 Mdot
.746 .06064 Mdot
.746 .06092 Mdot
.746 .06097 Mdot
.746 .06134 Mdot
.746 .06152 Mdot
.746 .06168 Mdot
.746 .06192 Mdot
.746 .06209 Mdot
.746 .0629 Mdot
.746 .06297 Mdot
.746 .06359 Mdot
.746 .06382 Mdot
.746 .06404 Mdot
.746 .06468 Mdot
.746 .06479 Mdot
.746 .06562 Mdot
.746 .06565 Mdot
.746 .06613 Mdot
.746 .06632 Mdot
.746 .06652 Mdot
.746 .06674 Mdot
.746 .06704 Mdot
.746 .06726 Mdot
.746 .06783 Mdot
.746 .06834 Mdot
.746 .06874 Mdot
.746 .06905 Mdot
.746 .06952 Mdot
.746 .06993 Mdot
.746 .0704 Mdot
.746 .07043 Mdot
.746 .07102 Mdot
.746 .07115 Mdot
.746 .07134 Mdot
.746 .0715 Mdot
.746 .07159 Mdot
.746 .07234 Mdot
.746 .07252 Mdot
.746 .07262 Mdot
.746 .07278 Mdot
.746 .07284 Mdot
.746 .07383 Mdot
.746 .07406 Mdot
.746 .07506 Mdot
.746 .0755 Mdot
.746 .07565 Mdot
.746 .07608 Mdot
.746 .07625 Mdot
.746 .07631 Mdot
.746 .07651 Mdot
.746 .0767 Mdot
.746 .07679 Mdot
.746 .07697 Mdot
.746 .07724 Mdot
.746 .07777 Mdot
.746 .07791 Mdot
.746 .0783 Mdot
.746 .07836 Mdot
.746 .07863 Mdot
.746 .0791 Mdot
.746 .07928 Mdot
.746 .0801 Mdot
.746 .08011 Mdot
.746 .08018 Mdot
.746 .08043 Mdot
.746 .08057 Mdot
.746 .08063 Mdot
.746 .08139 Mdot
.746 .08192 Mdot
.746 .0822 Mdot
.746 .08222 Mdot
.746 .08299 Mdot
.746 .08312 Mdot
.746 .08323 Mdot
.746 .08324 Mdot
.746 .08347 Mdot
.746 .08365 Mdot
.746 .08373 Mdot
.746 .08378 Mdot
.746 .08422 Mdot
.746 .08428 Mdot
.746 .08454 Mdot
.746 .08478 Mdot
.746 .08514 Mdot
.746 .0854 Mdot
.746 .0866 Mdot
.746 .08671 Mdot
.746 .08744 Mdot
.746 .08754 Mdot
.746 .08763 Mdot
.746 .08791 Mdot
.746 .08798 Mdot
.746 .0883 Mdot
.746 .08912 Mdot
.746 .08927 Mdot
.746 .08943 Mdot
.746 .08982 Mdot
.746 .08985 Mdot
.746 .09011 Mdot
.746 .09067 Mdot
.746 .0907 Mdot
.746 .09142 Mdot
.746 .0916 Mdot
.746 .09172 Mdot
.746 .09201 Mdot
.746 .09234 Mdot
.746 .09275 Mdot
.746 .09279 Mdot
.746 .09311 Mdot
.746 .09329 Mdot
.746 .09355 Mdot
.746 .09397 Mdot
.746 .09403 Mdot
.746 .09422 Mdot
.746 .09472 Mdot
.746 .09532 Mdot
.746 .09566 Mdot
.746 .09578 Mdot
.746 .09611 Mdot
.746 .09616 Mdot
.746 .09648 Mdot
.746 .0971 Mdot
.746 .09779 Mdot
.746 .09784 Mdot
.746 .09873 Mdot
.746 .09891 Mdot
.746 .09904 Mdot
.746 .09919 Mdot
.746 .09944 Mdot
.746 .09957 Mdot
.746 .10069 Mdot
.746 .10096 Mdot
.746 .10111 Mdot
.746 .10134 Mdot
.746 .10144 Mdot
.746 .10291 Mdot
.746 .10326 Mdot
.746 .10474 Mdot
.746 .10506 Mdot
.746 .1054 Mdot
.746 .10562 Mdot
.746 .10584 Mdot
.746 .10627 Mdot
.746 .10653 Mdot
.746 .10661 Mdot
.746 .10692 Mdot
.746 .107 Mdot
.746 .10719 Mdot
.746 .10733 Mdot
.746 .1076 Mdot
.746 .108 Mdot
.746 .10827 Mdot
.746 .1085 Mdot
.746 .10879 Mdot
.746 .109 Mdot
.746 .10958 Mdot
.746 .10967 Mdot
.746 .11007 Mdot
.746 .11078 Mdot
.746 .11105 Mdot
.746 .11121 Mdot
.746 .11196 Mdot
.746 .11227 Mdot
.746 .11229 Mdot
.746 .11239 Mdot
.746 .11266 Mdot
.746 .11276 Mdot
.746 .11298 Mdot
.746 .11307 Mdot
.746 .1136 Mdot
.746 .1142 Mdot
.746 .11471 Mdot
.746 .11498 Mdot
.746 .11522 Mdot
.746 .11541 Mdot
.746 .11543 Mdot
.746 .11616 Mdot
.746 .11658 Mdot
.746 .11677 Mdot
.746 .11694 Mdot
.746 .11695 Mdot
.746 .1173 Mdot
.746 .11757 Mdot
.746 .11762 Mdot
.746 .11768 Mdot
.746 .11777 Mdot
.746 .11842 Mdot
.746 .11851 Mdot
.746 .11876 Mdot
.746 .1189 Mdot
.746 .1189 Mdot
.746 .11926 Mdot
.746 .11949 Mdot
.746 .1196 Mdot
.746 .11979 Mdot
.746 .12018 Mdot
.746 .12197 Mdot
.746 .12213 Mdot
.746 .12321 Mdot
.746 .12337 Mdot
.746 .12351 Mdot
.746 .1237 Mdot
.746 .12392 Mdot
.746 .12402 Mdot
.746 .12451 Mdot
.746 .12474 Mdot
.746 .12491 Mdot
.746 .12573 Mdot
.746 .12594 Mdot
.746 .12598 Mdot
.746 .12619 Mdot
.746 .12677 Mdot
.746 .12681 Mdot
.746 .12721 Mdot
.746 .12781 Mdot
.746 .12804 Mdot
.746 .12809 Mdot
.746 .12884 Mdot
.746 .12904 Mdot
.746 .12916 Mdot
.746 .12943 Mdot
.746 .1296 Mdot
.746 .13004 Mdot
.746 .13054 Mdot
.746 .13101 Mdot
.746 .13114 Mdot
.746 .1312 Mdot
.746 .13131 Mdot
.746 .13168 Mdot
.746 .13169 Mdot
.746 .13195 Mdot
.746 .13234 Mdot
.746 .13296 Mdot
.746 .13305 Mdot
.746 .13334 Mdot
.746 .13397 Mdot
.746 .13408 Mdot
.746 .13497 Mdot
.746 .13513 Mdot
.746 .13537 Mdot
.746 .13549 Mdot
.746 .13567 Mdot
.746 .13615 Mdot
.746 .13623 Mdot
.746 .13671 Mdot
.746 .13763 Mdot
.746 .13867 Mdot
.746 .13874 Mdot
.746 .13909 Mdot
.746 .14006 Mdot
.746 .1401 Mdot
.746 .14033 Mdot
.746 .14053 Mdot
.746 .14069 Mdot
.746 .14076 Mdot
.746 .14112 Mdot
.746 .14132 Mdot
.746 .142 Mdot
.746 .14286 Mdot
.746 .14299 Mdot
.746 .14339 Mdot
.746 .14362 Mdot
.746 .14396 Mdot
.746 .14411 Mdot
.746 .14503 Mdot
.746 .1463 Mdot
.746 .14683 Mdot
.746 .14749 Mdot
.746 .14837 Mdot
.746 .14904 Mdot
.746 .14951 Mdot
.746 .14962 Mdot
.746 .14983 Mdot
.746 .15002 Mdot
.746 .15035 Mdot
.746 .15047 Mdot
.746 .15068 Mdot
.746 .15077 Mdot
.746 .15121 Mdot
.746 .15131 Mdot
.746 .15132 Mdot
.746 .1517 Mdot
.746 .15177 Mdot
.746 .15182 Mdot
.746 .15229 Mdot
.746 .1524 Mdot
.746 .15269 Mdot
.746 .1529 Mdot
.746 .15317 Mdot
.746 .15321 Mdot
.746 .15331 Mdot
.746 .15389 Mdot
.746 .1543 Mdot
.746 .1545 Mdot
.746 .15465 Mdot
.746 .15507 Mdot
.746 .15534 Mdot
.746 .15539 Mdot
.746 .15625 Mdot
.746 .15639 Mdot
.746 .15643 Mdot
.746 .15699 Mdot
.746 .15804 Mdot
.746 .15844 Mdot
.746 .15868 Mdot
.746 .15952 Mdot
.746 .15981 Mdot
.746 .15997 Mdot
.746 .16027 Mdot
.746 .1603 Mdot
.746 .16044 Mdot
.746 .16084 Mdot
.746 .161 Mdot
.746 .16132 Mdot
.746 .16137 Mdot
.746 .16145 Mdot
.746 .16226 Mdot
.746 .16262 Mdot
.746 .16314 Mdot
.746 .1639 Mdot
.746 .16432 Mdot
.746 .16453 Mdot
.746 .16467 Mdot
.746 .16495 Mdot
.746 .16498 Mdot
.746 .16504 Mdot
.746 .16607 Mdot
.746 .1667 Mdot
.746 .16698 Mdot
.746 .16723 Mdot
.746 .16725 Mdot
.746 .16778 Mdot
.746 .16817 Mdot
.746 .16824 Mdot
.746 .16834 Mdot
.746 .16847 Mdot
.746 .16944 Mdot
.746 .16947 Mdot
.746 .16958 Mdot
.746 .16995 Mdot
.746 .17016 Mdot
.746 .17016 Mdot
.746 .17024 Mdot
.746 .17069 Mdot
.746 .17104 Mdot
.746 .1712 Mdot
.746 .17128 Mdot
.746 .17142 Mdot
.746 .17148 Mdot
.746 .17191 Mdot
.746 .17205 Mdot
.746 .17206 Mdot
.746 .17293 Mdot
.746 .17474 Mdot
.746 .17498 Mdot
.746 .17533 Mdot
.746 .17571 Mdot
.746 .17578 Mdot
.746 .1766 Mdot
.746 .17682 Mdot
.746 .17703 Mdot
.746 .17732 Mdot
.746 .17765 Mdot
.746 .1778 Mdot
.746 .17809 Mdot
.746 .17852 Mdot
.746 .17887 Mdot
.746 .17909 Mdot
.746 .17912 Mdot
.746 .18036 Mdot
.746 .18067 Mdot
.746 .18072 Mdot
.746 .18104 Mdot
.746 .18159 Mdot
.746 .1819 Mdot
.746 .18196 Mdot
.746 .18256 Mdot
.746 .18265 Mdot
.746 .18276 Mdot
.746 .18345 Mdot
.746 .1838 Mdot
.746 .18387 Mdot
.746 .18499 Mdot
.746 .18529 Mdot
.746 .18547 Mdot
.746 .18587 Mdot
.746 .18612 Mdot
.746 .18678 Mdot
.746 .18752 Mdot
.746 .18778 Mdot
.746 .18816 Mdot
.746 .18822 Mdot
.746 .18842 Mdot
.746 .18851 Mdot
.746 .18864 Mdot
.746 .18867 Mdot
.746 .18881 Mdot
.746 .18923 Mdot
.746 .18924 Mdot
.746 .18963 Mdot
.746 .18988 Mdot
.746 .19021 Mdot
.746 .19114 Mdot
.746 .19128 Mdot
.746 .1917 Mdot
.746 .19207 Mdot
.746 .19265 Mdot
.746 .1928 Mdot
.746 .19414 Mdot
.746 .19437 Mdot
.746 .19468 Mdot
.746 .19472 Mdot
.746 .19487 Mdot
.746 .19491 Mdot
.746 .19518 Mdot
.746 .1959 Mdot
.746 .19602 Mdot
.746 .19604 Mdot
.746 .19673 Mdot
.746 .19703 Mdot
.746 .19779 Mdot
.746 .1981 Mdot
.746 .19814 Mdot
.746 .19965 Mdot
.746 .19976 Mdot
.746 .19991 Mdot
.746 .19996 Mdot
.746 .20028 Mdot
.746 .20094 Mdot
.746 .20173 Mdot
.746 .20179 Mdot
.746 .20214 Mdot
.746 .20244 Mdot
.746 .20266 Mdot
.746 .20277 Mdot
.746 .2033 Mdot
.746 .20332 Mdot
.746 .20361 Mdot
.746 .20432 Mdot
.746 .20463 Mdot
.746 .20591 Mdot
.746 .2061 Mdot
.746 .2067 Mdot
.746 .20705 Mdot
.746 .20755 Mdot
.746 .20777 Mdot
.746 .20856 Mdot
.746 .20914 Mdot
.746 .20921 Mdot
.746 .21104 Mdot
.746 .21121 Mdot
.746 .21183 Mdot
.746 .21234 Mdot
.746 .21281 Mdot
.746 .21402 Mdot
.746 .21413 Mdot
.746 .21474 Mdot
.746 .21512 Mdot
.746 .21582 Mdot
.746 .21599 Mdot
.746 .21631 Mdot
.746 .21659 Mdot
.746 .21709 Mdot
.746 .21726 Mdot
.746 .21736 Mdot
.746 .21757 Mdot
.746 .21771 Mdot
.746 .21836 Mdot
.746 .21851 Mdot
.746 .21854 Mdot
.746 .21909 Mdot
.746 .2192 Mdot
.746 .21928 Mdot
.746 .2193 Mdot
.746 .21953 Mdot
.746 .21997 Mdot
.746 .22015 Mdot
.746 .22057 Mdot
.746 .22089 Mdot
.746 .22129 Mdot
.746 .22135 Mdot
.746 .22149 Mdot
.746 .22237 Mdot
.746 .22298 Mdot
.746 .22327 Mdot
.746 .2235 Mdot
.746 .22413 Mdot
.746 .22452 Mdot
.746 .22461 Mdot
.746 .22561 Mdot
.746 .22589 Mdot
.746 .22609 Mdot
.746 .22615 Mdot
.746 .22618 Mdot
.746 .22698 Mdot
.746 .22822 Mdot
.746 .22856 Mdot
.746 .22916 Mdot
.746 .22952 Mdot
.746 .22994 Mdot
.746 .23076 Mdot
.746 .23119 Mdot
.746 .23144 Mdot
.746 .2315 Mdot
.746 .23188 Mdot
.746 .23192 Mdot
.746 .23214 Mdot
.746 .23274 Mdot
.746 .23297 Mdot
.746 .23345 Mdot
.746 .23352 Mdot
.746 .23365 Mdot
.746 .23485 Mdot
.746 .23539 Mdot
.746 .23617 Mdot
.746 .2373 Mdot
.746 .23792 Mdot
.746 .23824 Mdot
.746 .23844 Mdot
.746 .23886 Mdot
.746 .23891 Mdot
.746 .239 Mdot
.746 .24054 Mdot
.746 .24148 Mdot
.746 .2419 Mdot
.746 .24227 Mdot
.746 .2423 Mdot
.746 .24308 Mdot
.746 .24367 Mdot
.746 .24378 Mdot
.746 .24392 Mdot
.746 .24412 Mdot
.746 .24556 Mdot
.746 .24561 Mdot
.746 .24577 Mdot
.746 .24632 Mdot
.746 .24663 Mdot
.746 .24664 Mdot
.746 .24676 Mdot
.746 .24743 Mdot
.746 .24795 Mdot
.746 .24819 Mdot
.746 .24831 Mdot
.746 .24852 Mdot
.746 .24861 Mdot
.746 .24926 Mdot
.746 .24946 Mdot
.746 .24948 Mdot
.746 .25078 Mdot
.746 .25348 Mdot
.746 .25383 Mdot
.746 .25435 Mdot
.746 .25492 Mdot
.746 .25503 Mdot
.746 .25624 Mdot
.746 .25658 Mdot
.746 .25689 Mdot
.746 .25732 Mdot
.746 .25781 Mdot
.746 .25804 Mdot
.746 .25846 Mdot
.746 .25912 Mdot
.746 .25963 Mdot
.746 .25996 Mdot
.746 .26001 Mdot
.746 .26185 Mdot
.746 .26232 Mdot
.746 .26239 Mdot
.746 .26287 Mdot
.746 .2637 Mdot
.746 .26416 Mdot
.746 .26425 Mdot
.746 .26513 Mdot
.746 .26527 Mdot
.746 .26544 Mdot
.746 .26647 Mdot
.746 .26698 Mdot
.746 .26709 Mdot
.746 .26876 Mdot
.746 .26922 Mdot
.746 .26948 Mdot
.746 .27007 Mdot
.746 .27046 Mdot
.746 .27143 Mdot
.746 .27254 Mdot
.746 .27293 Mdot
.746 .27349 Mdot
.746 .27359 Mdot
.746 .27388 Mdot
.746 .27401 Mdot
.746 .27421 Mdot
.746 .27426 Mdot
.746 .27446 Mdot
.746 .27509 Mdot
.746 .27511 Mdot
.746 .27569 Mdot
.746 .27606 Mdot
.746 .27655 Mdot
.746 .27794 Mdot
.746 .27815 Mdot
.746 .27877 Mdot
.746 .27934 Mdot
.746 .28019 Mdot
.746 .28042 Mdot
.746 .28241 Mdot
.746 .28276 Mdot
.746 .28322 Mdot
.746 .28329 Mdot
.746 .28351 Mdot
.746 .28357 Mdot
.746 .28397 Mdot
.746 .28504 Mdot
.746 .28522 Mdot
.746 .28525 Mdot
.746 .28628 Mdot
.746 .28673 Mdot
.746 .28786 Mdot
.746 .28833 Mdot
.746 .28838 Mdot
.746 .29064 Mdot
.746 .29081 Mdot
.746 .29102 Mdot
.746 .2911 Mdot
.746 .29158 Mdot
.746 .29257 Mdot
.746 .29374 Mdot
.746 .29382 Mdot
.746 .29435 Mdot
.746 .29479 Mdot
.746 .29513 Mdot
.746 .29529 Mdot
.746 .29609 Mdot
.746 .29611 Mdot
.746 .29655 Mdot
.746 .29761 Mdot
.746 .29807 Mdot
.746 .29997 Mdot
.746 .30026 Mdot
.746 .30116 Mdot
.746 .30167 Mdot
.746 .30242 Mdot
.746 .30275 Mdot
.746 .30393 Mdot
.746 .3048 Mdot
.746 .3049 Mdot
.746 .30763 Mdot
.746 .30789 Mdot
.746 .3088 Mdot
.746 .30958 Mdot
.746 .31028 Mdot
.746 .31207 Mdot
.746 .31224 Mdot
.746 .31315 Mdot
.746 .31373 Mdot
.746 .31477 Mdot
.746 .31501 Mdot
.746 .3155 Mdot
.746 .31592 Mdot
.746 .31665 Mdot
.746 .31691 Mdot
.746 .31707 Mdot
.746 .31738 Mdot
.746 .31758 Mdot
.746 .31856 Mdot
.746 .31878 Mdot
.746 .31882 Mdot
.746 .31965 Mdot
.746 .31981 Mdot
.746 .31992 Mdot
.746 .31996 Mdot
.746 .32031 Mdot
.746 .32096 Mdot
.746 .32122 Mdot
.746 .32186 Mdot
.746 .32232 Mdot
.746 .32292 Mdot
.746 .32301 Mdot
.746 .32323 Mdot
.746 .32454 Mdot
.746 .32544 Mdot
.746 .32588 Mdot
.746 .32622 Mdot
.746 .32716 Mdot
.746 .32775 Mdot
.746 .32788 Mdot
.746 .32978 Mdot
.746 .33009 Mdot
.746 .33018 Mdot
.746 .33023 Mdot
.746 .33142 Mdot
.746 .33327 Mdot
.746 .33377 Mdot
.746 .33466 Mdot
.746 .3352 Mdot
.746 .33583 Mdot
.746 .33706 Mdot
.746 .3377 Mdot
.746 .33806 Mdot
.746 .33816 Mdot
.746 .33872 Mdot
.746 .33879 Mdot
.746 .33911 Mdot
.746 .34001 Mdot
.746 .34035 Mdot
.746 .34107 Mdot
.746 .34118 Mdot
.746 .34136 Mdot
.746 .34315 Mdot
.746 .34396 Mdot
.746 .34512 Mdot
.746 .34681 Mdot
.746 .34774 Mdot
.746 .34822 Mdot
.746 .34852 Mdot
.746 .34914 Mdot
.746 .34921 Mdot
.746 .34935 Mdot
.746 .35164 Mdot
.746 .35305 Mdot
.746 .35367 Mdot
.746 .35422 Mdot
.746 .35427 Mdot
.746 .35544 Mdot
.746 .35632 Mdot
.746 .35648 Mdot
.746 .35669 Mdot
.746 .35698 Mdot
.746 .35914 Mdot
.746 .3592 Mdot
.746 .35945 Mdot
.746 .36027 Mdot
.746 .36073 Mdot
.746 .36075 Mdot
.746 .36093 Mdot
.746 .36193 Mdot
.746 .3627 Mdot
.746 .36306 Mdot
.746 .36324 Mdot
.746 .36356 Mdot
.746 .36368 Mdot
.746 .36465 Mdot
.746 .36495 Mdot
.746 .36498 Mdot
.746 .36692 Mdot
.746 .37095 Mdot
.746 .37147 Mdot
.746 .37225 Mdot
.746 .3731 Mdot
.746 .37326 Mdot
.746 .37507 Mdot
.746 .37558 Mdot
.746 .37604 Mdot
.746 .37668 Mdot
.746 .37741 Mdot
.746 .37776 Mdot
.746 .37839 Mdot
.746 .37937 Mdot
.746 .38013 Mdot
.746 .38062 Mdot
.746 .38069 Mdot
.746 .38344 Mdot
.746 .38414 Mdot
.746 .38425 Mdot
.746 .38497 Mdot
.746 .3862 Mdot
.746 .38689 Mdot
.746 .38702 Mdot
.746 .38834 Mdot
.746 .38854 Mdot
.746 .3888 Mdot
.746 .39033 Mdot
.746 .3911 Mdot
.746 .39126 Mdot
.746 .39376 Mdot
.746 .39443 Mdot
.746 .39483 Mdot
.746 .39571 Mdot
.746 .39628 Mdot
.746 .39774 Mdot
.746 .39939 Mdot
.746 .39998 Mdot
.746 .40081 Mdot
.746 .40096 Mdot
.746 .40138 Mdot
.746 .40159 Mdot
.746 .40188 Mdot
.746 .40196 Mdot
.746 .40226 Mdot
.746 .40319 Mdot
.746 .40322 Mdot
.746 .40408 Mdot
.746 .40465 Mdot
.746 .40538 Mdot
.746 .40745 Mdot
.746 .40775 Mdot
.746 .40869 Mdot
.746 .40953 Mdot
.746 .41081 Mdot
.746 .41115 Mdot
.746 .41412 Mdot
.746 .41464 Mdot
.746 .41533 Mdot
.746 .41543 Mdot
.746 .41576 Mdot
.746 .41585 Mdot
.746 .41644 Mdot
.746 .41805 Mdot
.746 .4183 Mdot
.746 .41835 Mdot
.746 .41989 Mdot
.746 .42057 Mdot
.746 .42224 Mdot
.746 .42295 Mdot
.746 .42303 Mdot
.746 .42639 Mdot
.746 .42665 Mdot
.746 .42697 Mdot
.746 .42708 Mdot
.746 .4278 Mdot
.746 .42927 Mdot
.746 .43102 Mdot
.746 .43115 Mdot
.746 .43193 Mdot
.746 .43259 Mdot
.746 .4331 Mdot
.746 .43333 Mdot
.746 .43452 Mdot
.746 .43455 Mdot
.746 .43521 Mdot
.746 .43679 Mdot
.746 .43748 Mdot
.746 .44032 Mdot
.746 .44076 Mdot
.746 .4421 Mdot
.746 .44286 Mdot
.746 .44398 Mdot
.746 .44446 Mdot
.746 .44622 Mdot
.746 .44752 Mdot
.746 .44767 Mdot
.746 .45175 Mdot
.746 .45213 Mdot
.746 .4535 Mdot
.746 .45465 Mdot
.746 .45569 Mdot
.748 .01499 Mdot
.748 .01513 Mdot
.748 .01533 Mdot
.748 .0155 Mdot
.748 .01564 Mdot
.748 .01574 Mdot
.748 .01589 Mdot
.748 .01604 Mdot
.748 .0161 Mdot
.748 .01625 Mdot
.748 .01647 Mdot
.748 .0166 Mdot
.748 .0167 Mdot
.748 .01679 Mdot
.748 .01701 Mdot
.748 .01707 Mdot
.748 .01733 Mdot
.748 .01753 Mdot
.748 .01769 Mdot
.748 .01782 Mdot
.748 .01814 Mdot
.748 .01824 Mdot
.748 .01863 Mdot
.748 .01892 Mdot
.748 .01916 Mdot
.748 .01936 Mdot
.748 .01985 Mdot
.748 .01998 Mdot
.748 .02058 Mdot
.748 .02086 Mdot
.748 .02101 Mdot
.748 .02136 Mdot
.748 .02143 Mdot
.748 .02166 Mdot
.748 .02199 Mdot
.748 .02239 Mdot
.748 .0226 Mdot
.748 .02271 Mdot
.748 .02309 Mdot
.748 .02348 Mdot
.748 .02353 Mdot
.748 .02391 Mdot
.748 .02413 Mdot
.748 .02449 Mdot
.748 .02466 Mdot
.748 .02476 Mdot
.748 .02499 Mdot
.748 .025 Mdot
.748 .0251 Mdot
.748 .02513 Mdot
.748 .02559 Mdot
.748 .02564 Mdot
.748 .0262 Mdot
.748 .02651 Mdot
.748 .02668 Mdot
.748 .02725 Mdot
.748 .02783 Mdot
.748 .02789 Mdot
.748 .0279 Mdot
.748 .02846 Mdot
.748 .02881 Mdot
.748 .02934 Mdot
.748 .02944 Mdot
.748 .0296 Mdot
.748 .02974 Mdot
.748 .03008 Mdot
.748 .0301 Mdot
.748 .03021 Mdot
.748 .03026 Mdot
.748 .0303 Mdot
.748 .03091 Mdot
.748 .03099 Mdot
.748 .03105 Mdot
.748 .03136 Mdot
.748 .03189 Mdot
.748 .03236 Mdot
.748 .03261 Mdot
.748 .0333 Mdot
.748 .03347 Mdot
.748 .03434 Mdot
.748 .03442 Mdot
.748 .03444 Mdot
.748 .03528 Mdot
.748 .0358 Mdot
.748 .03611 Mdot
.748 .03659 Mdot
.748 .03675 Mdot
.748 .03698 Mdot
.748 .03719 Mdot
.748 .0372 Mdot
.748 .03724 Mdot
.748 .0376 Mdot
.748 .0377 Mdot
.748 .03773 Mdot
.748 .03787 Mdot
.748 .03789 Mdot
.748 .03796 Mdot
.748 .03803 Mdot
.748 .03868 Mdot
.748 .03885 Mdot
.748 .03894 Mdot
.748 .03906 Mdot
.748 .03916 Mdot
.748 .03962 Mdot
.748 .03969 Mdot
.748 .04041 Mdot
.748 .04111 Mdot
.748 .04149 Mdot
.748 .04252 Mdot
.748 .04277 Mdot
.748 .04285 Mdot
.748 .04315 Mdot
.748 .04379 Mdot
.748 .04407 Mdot
.748 .04419 Mdot
.748 .04419 Mdot
.748 .04423 Mdot
.748 .04426 Mdot
.748 .04454 Mdot
.748 .04462 Mdot
.748 .04513 Mdot
.748 .04532 Mdot
.748 .04549 Mdot
.748 .04625 Mdot
.748 .04672 Mdot
.748 .04676 Mdot
.748 .0468 Mdot
.748 .04744 Mdot
.748 .04767 Mdot
.748 .04802 Mdot
.748 .04818 Mdot
.748 .04833 Mdot
.748 .04835 Mdot
.748 .04839 Mdot
.748 .04841 Mdot
.748 .04895 Mdot
.748 .0491 Mdot
.748 .04915 Mdot
.748 .04927 Mdot
.748 .04935 Mdot
.748 .04938 Mdot
.748 .0495 Mdot
.748 .0495 Mdot
.748 .04959 Mdot
.748 .05057 Mdot
.748 .05082 Mdot
.748 .05095 Mdot
.748 .05113 Mdot
.748 .05128 Mdot
.748 .05133 Mdot
.748 .05141 Mdot
.748 .05197 Mdot
.748 .05208 Mdot
.748 .0531 Mdot
.748 .05316 Mdot
.748 .0542 Mdot
.748 .05477 Mdot
.748 .05496 Mdot
.748 .05549 Mdot
.748 .05631 Mdot
.748 .05669 Mdot
.748 .05681 Mdot
.748 .05689 Mdot
.748 .05704 Mdot
.748 .05726 Mdot
.748 .0582 Mdot
.748 .05863 Mdot
.748 .0588 Mdot
.748 .05882 Mdot
.748 .05886 Mdot
.748 .05892 Mdot
.748 .05933 Mdot
.748 .05937 Mdot
.748 .05946 Mdot
.748 .05988 Mdot
.748 .06022 Mdot
.748 .0605 Mdot
.748 .06075 Mdot
.748 .06171 Mdot
.748 .06189 Mdot
.748 .0626 Mdot
.748 .06265 Mdot
.748 .06271 Mdot
.748 .06316 Mdot
.748 .06367 Mdot
.748 .06402 Mdot
.748 .06402 Mdot
.748 .06425 Mdot
.748 .06454 Mdot
.748 .06462 Mdot
.748 .06478 Mdot
.748 .06501 Mdot
.748 .06503 Mdot
.748 .06509 Mdot
.748 .06512 Mdot
.748 .06593 Mdot
.748 .06616 Mdot
.748 .06622 Mdot
.748 .06641 Mdot
.748 .06653 Mdot
.748 .06658 Mdot
.748 .0666 Mdot
.748 .06672 Mdot
.748 .06675 Mdot
.748 .06676 Mdot
.748 .06689 Mdot
.748 .06728 Mdot
.748 .06788 Mdot
.748 .06836 Mdot
.748 .06872 Mdot
.748 .06892 Mdot
.748 .06919 Mdot
.748 .06942 Mdot
.748 .06949 Mdot
.748 .06961 Mdot
.748 .07045 Mdot
.748 .07061 Mdot
.748 .07214 Mdot
.748 .07222 Mdot
.748 .07245 Mdot
.748 .07297 Mdot
.748 .07379 Mdot
.748 .07393 Mdot
.748 .07464 Mdot
.748 .07492 Mdot
.748 .07571 Mdot
.748 .07675 Mdot
.748 .07675 Mdot
.748 .07695 Mdot
.748 .0775 Mdot
.748 .07769 Mdot
.748 .07781 Mdot
.748 .07803 Mdot
.748 .07836 Mdot
.748 .07863 Mdot
.748 .07938 Mdot
.748 .07978 Mdot
.748 .08002 Mdot
.748 .08021 Mdot
.748 .08041 Mdot
.748 .08067 Mdot
.748 .08069 Mdot
.748 .08076 Mdot
.748 .08084 Mdot
.748 .08145 Mdot
.748 .08152 Mdot
.748 .08165 Mdot
.748 .08203 Mdot
.748 .08228 Mdot
.748 .08249 Mdot
.748 .08279 Mdot
.748 .08321 Mdot
.748 .08358 Mdot
.748 .08403 Mdot
.748 .08502 Mdot
.748 .0853 Mdot
.748 .0856 Mdot
.748 .08635 Mdot
.748 .08643 Mdot
.748 .08651 Mdot
.748 .08662 Mdot
.748 .08719 Mdot
.748 .08796 Mdot
.748 .0884 Mdot
.748 .08848 Mdot
.748 .08848 Mdot
.748 .08882 Mdot
.748 .08925 Mdot
.748 .08938 Mdot
.748 .08961 Mdot
.748 .08996 Mdot
.748 .08998 Mdot
.748 .09008 Mdot
.748 .09012 Mdot
.748 .09133 Mdot
.748 .09142 Mdot
.748 .09167 Mdot
.748 .09177 Mdot
.748 .09179 Mdot
.748 .09204 Mdot
.748 .09223 Mdot
.748 .0923 Mdot
.748 .09234 Mdot
.748 .09251 Mdot
.748 .09256 Mdot
.748 .09257 Mdot
.748 .09277 Mdot
.748 .09335 Mdot
.748 .09425 Mdot
.748 .09496 Mdot
.748 .09551 Mdot
.748 .09581 Mdot
.748 .09621 Mdot
.748 .09656 Mdot
.748 .09666 Mdot
.748 .09683 Mdot
.748 .0981 Mdot
.748 .09833 Mdot
.748 .09918 Mdot
.748 .10063 Mdot
.748 .10075 Mdot
.748 .10109 Mdot
.748 .10123 Mdot
.748 .10186 Mdot
.748 .10308 Mdot
.748 .10329 Mdot
.748 .1035 Mdot
.748 .10437 Mdot
.748 .10463 Mdot
.748 .10479 Mdot
.748 .10508 Mdot
.748 .10566 Mdot
.748 .10597 Mdot
.748 .10752 Mdot
.748 .10753 Mdot
.748 .10781 Mdot
.748 .10865 Mdot
.748 .10893 Mdot
.748 .1091 Mdot
.748 .10914 Mdot
.748 .10943 Mdot
.748 .10971 Mdot
.748 .10993 Mdot
.748 .11034 Mdot
.748 .11035 Mdot
.748 .11069 Mdot
.748 .11117 Mdot
.748 .11145 Mdot
.748 .11148 Mdot
.748 .11205 Mdot
.748 .11241 Mdot
.748 .1127 Mdot
.748 .11292 Mdot
.748 .11299 Mdot
.748 .11339 Mdot
.748 .11341 Mdot
.748 .11352 Mdot
.748 .11364 Mdot
.748 .11456 Mdot
.748 .11466 Mdot
.748 .11485 Mdot
.748 .11541 Mdot
.748 .11542 Mdot
.748 .11579 Mdot
.748 .11611 Mdot
.748 .11656 Mdot
.748 .11718 Mdot
.748 .11774 Mdot
.748 .11834 Mdot
.748 .11842 Mdot
.748 .11989 Mdot
.748 .1203 Mdot
.748 .12075 Mdot
.748 .12107 Mdot
.748 .12119 Mdot
.748 .12188 Mdot
.748 .12199 Mdot
.748 .12212 Mdot
.748 .12229 Mdot
.748 .12235 Mdot
.748 .12313 Mdot
.748 .12426 Mdot
.748 .12429 Mdot
.748 .12452 Mdot
.748 .12495 Mdot
.748 .12506 Mdot
.748 .12506 Mdot
.748 .12507 Mdot
.748 .12508 Mdot
.748 .12512 Mdot
.748 .12514 Mdot
.748 .12539 Mdot
.748 .12547 Mdot
.748 .12558 Mdot
.748 .12576 Mdot
.748 .12622 Mdot
.748 .12641 Mdot
.748 .1267 Mdot
.748 .12675 Mdot
.748 .1271 Mdot
.748 .12727 Mdot
.748 .12731 Mdot
.748 .12746 Mdot
.748 .12752 Mdot
.748 .12768 Mdot
.748 .12784 Mdot
.748 .12857 Mdot
.748 .12933 Mdot
.748 .12947 Mdot
.748 .12984 Mdot
.748 .12999 Mdot
.748 .13002 Mdot
.748 .1304 Mdot
.748 .13068 Mdot
.748 .13079 Mdot
.748 .13085 Mdot
.748 .1309 Mdot
.748 .1311 Mdot
.748 .13116 Mdot
.748 .13118 Mdot
.748 .13119 Mdot
.748 .13148 Mdot
.748 .13181 Mdot
.748 .13235 Mdot
.748 .1333 Mdot
.748 .13354 Mdot
.748 .13369 Mdot
.748 .13477 Mdot
.748 .13526 Mdot
.748 .13559 Mdot
.748 .13594 Mdot
.748 .13603 Mdot
.748 .13615 Mdot
.748 .13635 Mdot
.748 .13664 Mdot
.748 .13688 Mdot
.748 .13708 Mdot
.748 .13715 Mdot
.748 .1373 Mdot
.748 .13739 Mdot
.748 .13756 Mdot
.748 .13817 Mdot
.748 .13899 Mdot
.748 .13946 Mdot
.748 .13981 Mdot
.748 .14 Mdot
.748 .14107 Mdot
.748 .14266 Mdot
.748 .14324 Mdot
.748 .14342 Mdot
.748 .14346 Mdot
.748 .14393 Mdot
.748 .14415 Mdot
.748 .14453 Mdot
.748 .14508 Mdot
.748 .14647 Mdot
.748 .14692 Mdot
.748 .14707 Mdot
.748 .14714 Mdot
.748 .14723 Mdot
.748 .14754 Mdot
.748 .14867 Mdot
.748 .14884 Mdot
.748 .149 Mdot
.748 .14922 Mdot
.748 .14947 Mdot
.748 .14975 Mdot
.748 .1499 Mdot
.748 .1499 Mdot
.748 .15077 Mdot
.748 .15123 Mdot
.748 .15146 Mdot
.748 .15181 Mdot
.748 .15322 Mdot
.748 .15355 Mdot
.748 .15356 Mdot
.748 .15375 Mdot
.748 .15399 Mdot
.748 .15404 Mdot
.748 .15429 Mdot
.748 .15524 Mdot
.748 .15533 Mdot
.748 .15564 Mdot
.748 .15566 Mdot
.748 .15574 Mdot
.748 .15577 Mdot
.748 .15592 Mdot
.748 .15597 Mdot
.748 .1564 Mdot
.748 .15641 Mdot
.748 .15683 Mdot
.748 .15715 Mdot
.748 .15722 Mdot
.748 .15777 Mdot
.748 .15779 Mdot
.748 .1583 Mdot
.748 .15885 Mdot
.748 .15901 Mdot
.748 .15943 Mdot
.748 .15947 Mdot
.748 .16032 Mdot
.748 .16087 Mdot
.748 .1613 Mdot
.748 .16156 Mdot
.748 .16163 Mdot
.748 .16165 Mdot
.748 .16174 Mdot
.748 .16233 Mdot
.748 .16237 Mdot
.748 .16253 Mdot
.748 .16271 Mdot
.748 .16408 Mdot
.748 .16423 Mdot
.748 .16452 Mdot
.748 .16536 Mdot
.748 .16536 Mdot
.748 .16592 Mdot
.748 .16634 Mdot
.748 .1664 Mdot
.748 .16694 Mdot
.748 .16708 Mdot
.748 .16754 Mdot
.748 .168 Mdot
.748 .16831 Mdot
.748 .16884 Mdot
.748 .16974 Mdot
.748 .16985 Mdot
.748 .17206 Mdot
.748 .17267 Mdot
.748 .17335 Mdot
.748 .17369 Mdot
.748 .17382 Mdot
.748 .174 Mdot
.748 .17504 Mdot
.748 .17521 Mdot
.748 .1754 Mdot
.748 .1755 Mdot
.748 .17564 Mdot
.748 .17573 Mdot
.748 .17616 Mdot
.748 .17691 Mdot
.748 .17778 Mdot
.748 .1786 Mdot
.748 .17863 Mdot
.748 .17898 Mdot
.748 .17955 Mdot
.748 .17963 Mdot
.748 .17979 Mdot
.748 .17979 Mdot
.748 .17981 Mdot
.748 .17981 Mdot
.748 .17989 Mdot
.748 .17991 Mdot
.748 .18 Mdot
.748 .18028 Mdot
.748 .1804 Mdot
.748 .18057 Mdot
.748 .18062 Mdot
.748 .18084 Mdot
.748 .18153 Mdot
.748 .18162 Mdot
.748 .18181 Mdot
.748 .18225 Mdot
.748 .18232 Mdot
.748 .18284 Mdot
.748 .18304 Mdot
.748 .1831 Mdot
.748 .18316 Mdot
.748 .18332 Mdot
.748 .18338 Mdot
.748 .18347 Mdot
.748 .18371 Mdot
.748 .18395 Mdot
.748 .18425 Mdot
.748 .18505 Mdot
.748 .18529 Mdot
.748 .18561 Mdot
.748 .18619 Mdot
.748 .18636 Mdot
.748 .18638 Mdot
.748 .18684 Mdot
.748 .18694 Mdot
.748 .18717 Mdot
.748 .18721 Mdot
.748 .18768 Mdot
.748 .18778 Mdot
.748 .1882 Mdot
.748 .18836 Mdot
.748 .18845 Mdot
.748 .18852 Mdot
.748 .18883 Mdot
.748 .18892 Mdot
.748 .18895 Mdot
.748 .18896 Mdot
.748 .18915 Mdot
.748 .1894 Mdot
.748 .18988 Mdot
.748 .19069 Mdot
.748 .19072 Mdot
.748 .19212 Mdot
.748 .1923 Mdot
.748 .19248 Mdot
.748 .19271 Mdot
.748 .19431 Mdot
.748 .19486 Mdot
.748 .19505 Mdot
.748 .19554 Mdot
.748 .19607 Mdot
.748 .1962 Mdot
.748 .19639 Mdot
.748 .19668 Mdot
.748 .19711 Mdot
.748 .19719 Mdot
.748 .19747 Mdot
.748 .19778 Mdot
.748 .19787 Mdot
.748 .1981 Mdot
.748 .19824 Mdot
.748 .19849 Mdot
.748 .19893 Mdot
.748 .1994 Mdot
.748 .19987 Mdot
.748 .20064 Mdot
.748 .20133 Mdot
.748 .20185 Mdot
.748 .20214 Mdot
.748 .20375 Mdot
.748 .20527 Mdot
.748 .20612 Mdot
.748 .20698 Mdot
.748 .20726 Mdot
.748 .20732 Mdot
.748 .20803 Mdot
.748 .20835 Mdot
.748 .20892 Mdot
.748 .20975 Mdot
.748 .21036 Mdot
.748 .21183 Mdot
.748 .21249 Mdot
.748 .21271 Mdot
.748 .21282 Mdot
.748 .21296 Mdot
.748 .2132 Mdot
.748 .21341 Mdot
.748 .21511 Mdot
.748 .21536 Mdot
.748 .21561 Mdot
.748 .21594 Mdot
.748 .21611 Mdot
.748 .2163 Mdot
.748 .21673 Mdot
.748 .21695 Mdot
.748 .21696 Mdot
.748 .21702 Mdot
.748 .21724 Mdot
.748 .21825 Mdot
.748 .21894 Mdot
.748 .21928 Mdot
.748 .2196 Mdot
.748 .2198 Mdot
.748 .22067 Mdot
.748 .22192 Mdot
.748 .22241 Mdot
.748 .22243 Mdot
.748 .22259 Mdot
.748 .22271 Mdot
.748 .22307 Mdot
.748 .22315 Mdot
.748 .22352 Mdot
.748 .22494 Mdot
.748 .22507 Mdot
.748 .22535 Mdot
.748 .22553 Mdot
.748 .22557 Mdot
.748 .22569 Mdot
.748 .22573 Mdot
.748 .22595 Mdot
.748 .22604 Mdot
.748 .22668 Mdot
.748 .2267 Mdot
.748 .22732 Mdot
.748 .22741 Mdot
.748 .2278 Mdot
.748 .22791 Mdot
.748 .22872 Mdot
.748 .22876 Mdot
.748 .22952 Mdot
.748 .23035 Mdot
.748 .23058 Mdot
.748 .23121 Mdot
.748 .23127 Mdot
.748 .23232 Mdot
.748 .23254 Mdot
.748 .23336 Mdot
.748 .23401 Mdot
.748 .23439 Mdot
.748 .2345 Mdot
.748 .23453 Mdot
.748 .23466 Mdot
.748 .23555 Mdot
.748 .2356 Mdot
.748 .23585 Mdot
.748 .23612 Mdot
.748 .23816 Mdot
.748 .23839 Mdot
.748 .23882 Mdot
.748 .24008 Mdot
.748 .24008 Mdot
.748 .24092 Mdot
.748 .24154 Mdot
.748 .24163 Mdot
.748 .24244 Mdot
.748 .24265 Mdot
.748 .24334 Mdot
.748 .24403 Mdot
.748 .24449 Mdot
.748 .24529 Mdot
.748 .24664 Mdot
.748 .2468 Mdot
.748 .2501 Mdot
.748 .25102 Mdot
.748 .25203 Mdot
.748 .25254 Mdot
.748 .25274 Mdot
.748 .253 Mdot
.748 .25455 Mdot
.748 .25481 Mdot
.748 .2551 Mdot
.748 .25525 Mdot
.748 .25546 Mdot
.748 .2556 Mdot
.748 .25624 Mdot
.748 .25736 Mdot
.748 .25867 Mdot
.748 .25989 Mdot
.748 .25994 Mdot
.748 .26046 Mdot
.748 .26131 Mdot
.748 .26143 Mdot
.748 .26167 Mdot
.748 .26167 Mdot
.748 .2617 Mdot
.748 .2617 Mdot
.748 .26181 Mdot
.748 .26185 Mdot
.748 .26198 Mdot
.748 .2624 Mdot
.748 .26258 Mdot
.748 .26284 Mdot
.748 .26291 Mdot
.748 .26324 Mdot
.748 .26428 Mdot
.748 .2644 Mdot
.748 .26468 Mdot
.748 .26535 Mdot
.748 .26546 Mdot
.748 .26623 Mdot
.748 .26653 Mdot
.748 .26662 Mdot
.748 .26671 Mdot
.748 .26695 Mdot
.748 .26704 Mdot
.748 .26718 Mdot
.748 .26752 Mdot
.748 .26789 Mdot
.748 .26834 Mdot
.748 .26953 Mdot
.748 .26989 Mdot
.748 .27037 Mdot
.748 .27124 Mdot
.748 .2715 Mdot
.748 .27153 Mdot
.748 .27222 Mdot
.748 .27237 Mdot
.748 .2727 Mdot
.748 .27277 Mdot
.748 .27346 Mdot
.748 .27362 Mdot
.748 .27425 Mdot
.748 .27449 Mdot
.748 .27462 Mdot
.748 .27473 Mdot
.748 .27519 Mdot
.748 .27533 Mdot
.748 .27538 Mdot
.748 .27539 Mdot
.748 .27567 Mdot
.748 .27604 Mdot
.748 .27677 Mdot
.748 .27798 Mdot
.748 .27802 Mdot
.748 .28011 Mdot
.748 .28038 Mdot
.748 .28065 Mdot
.748 .28099 Mdot
.748 .2834 Mdot
.748 .28421 Mdot
.748 .2845 Mdot
.748 .28523 Mdot
.748 .28602 Mdot
.748 .28622 Mdot
.748 .28649 Mdot
.748 .28694 Mdot
.748 .28757 Mdot
.748 .2877 Mdot
.748 .28812 Mdot
.748 .28858 Mdot
.748 .28872 Mdot
.748 .28906 Mdot
.748 .28927 Mdot
.748 .28965 Mdot
.748 .29031 Mdot
.748 .29101 Mdot
.748 .29171 Mdot
.748 .29285 Mdot
.748 .2939 Mdot
.748 .29468 Mdot
.748 .2951 Mdot
.748 .29751 Mdot
.748 .29978 Mdot
.748 .30105 Mdot
.748 .30235 Mdot
.748 .30276 Mdot
.748 .30286 Mdot
.748 .30391 Mdot
.748 .30439 Mdot
.748 .30525 Mdot
.748 .30648 Mdot
.748 .3074 Mdot
.748 .30959 Mdot
.748 .31058 Mdot
.748 .31092 Mdot
.748 .31108 Mdot
.748 .31128 Mdot
.748 .31165 Mdot
.748 .31197 Mdot
.748 .3145 Mdot
.748 .31488 Mdot
.748 .31526 Mdot
.748 .31574 Mdot
.748 .316 Mdot
.748 .31629 Mdot
.748 .31693 Mdot
.748 .31726 Mdot
.748 .31727 Mdot
.748 .31736 Mdot
.748 .3177 Mdot
.748 .3192 Mdot
.748 .32024 Mdot
.748 .32075 Mdot
.748 .32122 Mdot
.748 .32152 Mdot
.748 .32282 Mdot
.748 .3247 Mdot
.748 .32542 Mdot
.748 .32545 Mdot
.748 .32569 Mdot
.748 .32587 Mdot
.748 .32642 Mdot
.748 .32653 Mdot
.748 .32709 Mdot
.748 .32921 Mdot
.748 .32941 Mdot
.748 .32983 Mdot
.748 .3301 Mdot
.748 .33015 Mdot
.748 .33033 Mdot
.748 .33039 Mdot
.748 .33073 Mdot
.748 .33085 Mdot
.748 .33181 Mdot
.748 .33184 Mdot
.748 .33276 Mdot
.748 .33291 Mdot
.748 .33349 Mdot
.748 .33365 Mdot
.748 .33487 Mdot
.748 .33492 Mdot
.748 .33606 Mdot
.748 .3373 Mdot
.748 .33765 Mdot
.748 .33859 Mdot
.748 .33869 Mdot
.748 .34025 Mdot
.748 .34059 Mdot
.748 .34181 Mdot
.748 .34278 Mdot
.748 .34335 Mdot
.748 .34351 Mdot
.748 .34376 Mdot
.748 .34508 Mdot
.748 .34516 Mdot
.748 .34553 Mdot
.748 .34593 Mdot
.748 .34899 Mdot
.748 .34933 Mdot
.748 .34998 Mdot
.748 .35186 Mdot
.748 .35187 Mdot
.748 .35312 Mdot
.748 .35405 Mdot
.748 .35418 Mdot
.748 .35539 Mdot
.748 .3557 Mdot
.748 .35673 Mdot
.748 .35778 Mdot
.748 .35846 Mdot
.748 .35965 Mdot
.748 .36167 Mdot
.748 .36192 Mdot
.748 .36686 Mdot
.748 .36823 Mdot
.748 .36974 Mdot
.748 .3705 Mdot
.748 .3708 Mdot
.748 .37119 Mdot
.748 .37351 Mdot
.748 .3739 Mdot
.748 .37433 Mdot
.748 .37455 Mdot
.748 .37487 Mdot
.748 .37508 Mdot
.748 .37604 Mdot
.748 .37771 Mdot
.748 .37967 Mdot
.748 .38149 Mdot
.748 .38157 Mdot
.748 .38234 Mdot
.748 .38362 Mdot
.748 .38379 Mdot
.748 .38416 Mdot
.748 .38417 Mdot
.748 .3842 Mdot
.748 .38421 Mdot
.748 .38438 Mdot
.748 .38443 Mdot
.748 .38462 Mdot
.748 .38526 Mdot
.748 .38552 Mdot
.748 .38591 Mdot
.748 .38602 Mdot
.748 .3865 Mdot
.748 .38806 Mdot
.748 .38825 Mdot
.748 .38867 Mdot
.748 .38966 Mdot
.748 .38982 Mdot
.748 .39098 Mdot
.748 .39143 Mdot
.748 .39157 Mdot
.748 .3917 Mdot
.748 .39206 Mdot
.748 .39219 Mdot
.748 .3924 Mdot
.748 .39292 Mdot
.748 .39347 Mdot
.748 .39414 Mdot
.748 .39592 Mdot
.748 .39646 Mdot
.748 .39717 Mdot
.748 .39847 Mdot
.748 .39887 Mdot
.748 .39891 Mdot
.748 .39994 Mdot
.748 .40016 Mdot
.748 .40066 Mdot
.748 .40076 Mdot
.748 .4018 Mdot
.748 .40203 Mdot
.748 .40298 Mdot
.748 .40333 Mdot
.748 .40353 Mdot
.748 .4037 Mdot
.748 .40439 Mdot
.748 .40459 Mdot
.748 .40466 Mdot
.748 .40468 Mdot
.748 .40511 Mdot
.748 .40566 Mdot
.748 .40675 Mdot
.748 .40855 Mdot
.748 .40862 Mdot
.748 .41175 Mdot
.748 .41215 Mdot
.748 .41255 Mdot
.748 .41307 Mdot
.748 .41666 Mdot
.748 .41787 Mdot
.748 .41832 Mdot
.748 .4194 Mdot
.748 .42058 Mdot
.748 .42088 Mdot
.748 .4213 Mdot
.748 .42196 Mdot
.748 .42291 Mdot
.748 .4231 Mdot
.748 .42372 Mdot
.748 .42441 Mdot
.748 .42463 Mdot
.748 .42513 Mdot
.748 .42545 Mdot
.748 .42601 Mdot
.748 .427 Mdot
.748 .42805 Mdot
.748 .4291 Mdot
.748 .43081 Mdot
.748 .43237 Mdot
.748 .43354 Mdot
.748 .43416 Mdot
.748 .43777 Mdot
.748 .44117 Mdot
.748 .44308 Mdot
.748 .44502 Mdot
.748 .44562 Mdot
.748 .44578 Mdot
.748 .44735 Mdot
.748 .44807 Mdot
.748 .44935 Mdot
.748 .4512 Mdot
.748 .45257 Mdot
.748 .45585 Mdot
.75 .01569 Mdot
.75 .01618 Mdot
.75 .01618 Mdot
.75 .01658 Mdot
.75 .01691 Mdot
.75 .01691 Mdot
.75 .01692 Mdot
.75 .01694 Mdot
.75 .01697 Mdot
.75 .01711 Mdot
.75 .01751 Mdot
.75 .018 Mdot
.75 .01801 Mdot
.75 .01802 Mdot
.75 .01805 Mdot
.75 .01809 Mdot
.75 .01815 Mdot
.75 .0183 Mdot
.75 .01891 Mdot
.75 .01932 Mdot
.75 .01965 Mdot
.75 .01966 Mdot
.75 .01967 Mdot
.75 .01972 Mdot
.75 .01978 Mdot
.75 .01987 Mdot
.75 .02009 Mdot
.75 .02018 Mdot
.75 .0203 Mdot
.75 .02101 Mdot
.75 .02163 Mdot
.75 .02211 Mdot
.75 .02213 Mdot
.75 .02215 Mdot
.75 .02223 Mdot
.75 .02232 Mdot
.75 .02245 Mdot
.75 .02278 Mdot
.75 .02291 Mdot
.75 .02309 Mdot
.75 .02327 Mdot
.75 .02384 Mdot
.75 .02384 Mdot
.75 .02385 Mdot
.75 .02393 Mdot
.75 .02416 Mdot
.75 .02508 Mdot
.75 .02581 Mdot
.75 .02584 Mdot
.75 .02587 Mdot
.75 .02599 Mdot
.75 .02612 Mdot
.75 .02631 Mdot
.75 .02682 Mdot
.75 .02701 Mdot
.75 .02717 Mdot
.75 .02728 Mdot
.75 .02728 Mdot
.75 .0273 Mdot
.75 .02748 Mdot
.75 .02755 Mdot
.75 .0284 Mdot
.75 .02841 Mdot
.75 .02842 Mdot
.75 .02854 Mdot
.75 .02889 Mdot
.75 .02905 Mdot
.75 .03014 Mdot
.75 .03026 Mdot
.75 .03136 Mdot
.75 .03141 Mdot
.75 .03142 Mdot
.75 .03144 Mdot
.75 .03162 Mdot
.75 .03182 Mdot
.75 .03199 Mdot
.75 .03211 Mdot
.75 .03287 Mdot
.75 .03315 Mdot
.75 .03321 Mdot
.75 .03324 Mdot
.75 .0334 Mdot
.75 .03356 Mdot
.75 .03356 Mdot
.75 .03357 Mdot
.75 .03359 Mdot
.75 .03386 Mdot
.75 .03397 Mdot
.75 .0349 Mdot
.75 .03499 Mdot
.75 .03524 Mdot
.75 .03525 Mdot
.75 .03527 Mdot
.75 .03545 Mdot
.75 .0356 Mdot
.75 .03596 Mdot
.75 .03598 Mdot
.75 .03613 Mdot
.75 .03621 Mdot
.75 .03651 Mdot
.75 .03785 Mdot
.75 .03804 Mdot
.75 .03807 Mdot
.75 .03967 Mdot
.75 .03968 Mdot
.75 .03975 Mdot
.75 .03977 Mdot
.75 .03981 Mdot
.75 .04007 Mdot
.75 .04016 Mdot
.75 .04032 Mdot
.75 .04037 Mdot
.75 .04059 Mdot
.75 .04063 Mdot
.75 .04081 Mdot
.75 .04195 Mdot
.75 .04237 Mdot
.75 .04246 Mdot
.75 .0425 Mdot
.75 .04274 Mdot
.75 .04285 Mdot
.75 .04298 Mdot
.75 .04298 Mdot
.75 .043 Mdot
.75 .04302 Mdot
.75 .0434 Mdot
.75 .04343 Mdot
.75 .0436 Mdot
.75 .04368 Mdot
.75 .04495 Mdot
.75 .04499 Mdot
.75 .04513 Mdot
.75 .04518 Mdot
.75 .0455 Mdot
.75 .04552 Mdot
.75 .04555 Mdot
.75 .04556 Mdot
.75 .04582 Mdot
.75 .04595 Mdot
.75 .04603 Mdot
.75 .04605 Mdot
.75 .04605 Mdot
.75 .04659 Mdot
.75 .04661 Mdot
.75 .04684 Mdot
.75 .04696 Mdot
.75 .04741 Mdot
.75 .04941 Mdot
.75 .04957 Mdot
.75 .0497 Mdot
.75 .04975 Mdot
.75 .04996 Mdot
.75 .0502 Mdot
.75 .05169 Mdot
.75 .05193 Mdot
.75 .05215 Mdot
.75 .05216 Mdot
.75 .05227 Mdot
.75 .0523 Mdot
.75 .05235 Mdot
.75 .05243 Mdot
.75 .05275 Mdot
.75 .05288 Mdot
.75 .05312 Mdot
.75 .05319 Mdot
.75 .05353 Mdot
.75 .05359 Mdot
.75 .05384 Mdot
.75 .05386 Mdot
.75 .05406 Mdot
.75 .05414 Mdot
.75 .05445 Mdot
.75 .05512 Mdot
.75 .05557 Mdot
.75 .0562 Mdot
.75 .05633 Mdot
.75 .05639 Mdot
.75 .05675 Mdot
.75 .05692 Mdot
.75 .05711 Mdot
.75 .05711 Mdot
.75 .05714 Mdot
.75 .05774 Mdot
.75 .05779 Mdot
.75 .05804 Mdot
.75 .05816 Mdot
.75 .05862 Mdot
.75 .05956 Mdot
.75 .06007 Mdot
.75 .06012 Mdot
.75 .06033 Mdot
.75 .06041 Mdot
.75 .0609 Mdot
.75 .06092 Mdot
.75 .06097 Mdot
.75 .06098 Mdot
.75 .06115 Mdot
.75 .06121 Mdot
.75 .06129 Mdot
.75 .06137 Mdot
.75 .06157 Mdot
.75 .06169 Mdot
.75 .06171 Mdot
.75 .06172 Mdot
.75 .06183 Mdot
.75 .06253 Mdot
.75 .06255 Mdot
.75 .06291 Mdot
.75 .06293 Mdot
.75 .06308 Mdot
.75 .06375 Mdot
.75 .06397 Mdot
.75 .06472 Mdot
.75 .06543 Mdot
.75 .06611 Mdot
.75 .06676 Mdot
.75 .067 Mdot
.75 .06719 Mdot
.75 .06727 Mdot
.75 .06759 Mdot
.75 .06786 Mdot
.75 .06794 Mdot
.75 .07018 Mdot
.75 .07053 Mdot
.75 .07087 Mdot
.75 .07089 Mdot
.75 .07104 Mdot
.75 .07109 Mdot
.75 .07117 Mdot
.75 .07129 Mdot
.75 .07132 Mdot
.75 .07177 Mdot
.75 .07196 Mdot
.75 .07232 Mdot
.75 .07243 Mdot
.75 .07294 Mdot
.75 .07303 Mdot
.75 .07337 Mdot
.75 .07341 Mdot
.75 .07344 Mdot
.75 .07373 Mdot
.75 .07386 Mdot
.75 .07432 Mdot
.75 .07501 Mdot
.75 .07532 Mdot
.75 .07599 Mdot
.75 .07694 Mdot
.75 .07713 Mdot
.75 .07723 Mdot
.75 .07776 Mdot
.75 .07802 Mdot
.75 .0783 Mdot
.75 .07831 Mdot
.75 .07835 Mdot
.75 .07844 Mdot
.75 .0789 Mdot
.75 .07925 Mdot
.75 .07933 Mdot
.75 .07971 Mdot
.75 .07989 Mdot
.75 .08058 Mdot
.75 .08157 Mdot
.75 .08199 Mdot
.75 .08204 Mdot
.75 .08244 Mdot
.75 .08274 Mdot
.75 .08283 Mdot
.75 .08287 Mdot
.75 .08314 Mdot
.75 .08325 Mdot
.75 .08399 Mdot
.75 .08403 Mdot
.75 .08409 Mdot
.75 .08411 Mdot
.75 .08436 Mdot
.75 .08438 Mdot
.75 .08443 Mdot
.75 .08446 Mdot
.75 .08458 Mdot
.75 .0847 Mdot
.75 .08499 Mdot
.75 .08518 Mdot
.75 .08521 Mdot
.75 .08522 Mdot
.75 .08539 Mdot
.75 .08547 Mdot
.75 .08643 Mdot
.75 .08647 Mdot
.75 .087 Mdot
.75 .08703 Mdot
.75 .08726 Mdot
.75 .08776 Mdot
.75 .08827 Mdot
.75 .08844 Mdot
.75 .08859 Mdot
.75 .08873 Mdot
.75 .08972 Mdot
.75 .09078 Mdot
.75 .09078 Mdot
.75 .09092 Mdot
.75 .09155 Mdot
.75 .09165 Mdot
.75 .09181 Mdot
.75 .09278 Mdot
.75 .09315 Mdot
.75 .09342 Mdot
.75 .09354 Mdot
.75 .09403 Mdot
.75 .09443 Mdot
.75 .09455 Mdot
.75 .09457 Mdot
.75 .09723 Mdot
.75 .09755 Mdot
.75 .09791 Mdot
.75 .09803 Mdot
.75 .09814 Mdot
.75 .09844 Mdot
.75 .09895 Mdot
.75 .09897 Mdot
.75 .09921 Mdot
.75 .09921 Mdot
.75 .09928 Mdot
.75 .0994 Mdot
.75 .09958 Mdot
.75 .09962 Mdot
.75 .10009 Mdot
.75 .10018 Mdot
.75 .1003 Mdot
.75 .10058 Mdot
.75 .10059 Mdot
.75 .10085 Mdot
.75 .10112 Mdot
.75 .10129 Mdot
.75 .1017 Mdot
.75 .10205 Mdot
.75 .10219 Mdot
.75 .10261 Mdot
.75 .10269 Mdot
.75 .10276 Mdot
.75 .1028 Mdot
.75 .10323 Mdot
.75 .10343 Mdot
.75 .10413 Mdot
.75 .10478 Mdot
.75 .10485 Mdot
.75 .10516 Mdot
.75 .10562 Mdot
.75 .10598 Mdot
.75 .10631 Mdot
.75 .10633 Mdot
.75 .10652 Mdot
.75 .10656 Mdot
.75 .10663 Mdot
.75 .10694 Mdot
.75 .10788 Mdot
.75 .10805 Mdot
.75 .10834 Mdot
.75 .10842 Mdot
.75 .10849 Mdot
.75 .10851 Mdot
.75 .10929 Mdot
.75 .10967 Mdot
.75 .1101 Mdot
.75 .11011 Mdot
.75 .11017 Mdot
.75 .11031 Mdot
.75 .111 Mdot
.75 .11152 Mdot
.75 .11163 Mdot
.75 .1122 Mdot
.75 .11248 Mdot
.75 .11351 Mdot
.75 .11391 Mdot
.75 .11491 Mdot
.75 .115 Mdot
.75 .11562 Mdot
.75 .1157 Mdot
.75 .11579 Mdot
.75 .11608 Mdot
.75 .1163 Mdot
.75 .11675 Mdot
.75 .11689 Mdot
.75 .11694 Mdot
.75 .11735 Mdot
.75 .11738 Mdot
.75 .11752 Mdot
.75 .11862 Mdot
.75 .11869 Mdot
.75 .11878 Mdot
.75 .1188 Mdot
.75 .11919 Mdot
.75 .11921 Mdot
.75 .11929 Mdot
.75 .11934 Mdot
.75 .11951 Mdot
.75 .11969 Mdot
.75 .12012 Mdot
.75 .12013 Mdot
.75 .12035 Mdot
.75 .12042 Mdot
.75 .12042 Mdot
.75 .12046 Mdot
.75 .12047 Mdot
.75 .12073 Mdot
.75 .12083 Mdot
.75 .12085 Mdot
.75 .12212 Mdot
.75 .12229 Mdot
.75 .12235 Mdot
.75 .12314 Mdot
.75 .12319 Mdot
.75 .12354 Mdot
.75 .12429 Mdot
.75 .12505 Mdot
.75 .12529 Mdot
.75 .12553 Mdot
.75 .12573 Mdot
.75 .1259 Mdot
.75 .12723 Mdot
.75 .12882 Mdot
.75 .12882 Mdot
.75 .12902 Mdot
.75 .12974 Mdot
.75 .12996 Mdot
.75 .13012 Mdot
.75 .13036 Mdot
.75 .131 Mdot
.75 .13181 Mdot
.75 .1322 Mdot
.75 .13236 Mdot
.75 .13278 Mdot
.75 .13296 Mdot
.75 .13323 Mdot
.75 .13368 Mdot
.75 .13409 Mdot
.75 .13429 Mdot
.75 .13447 Mdot
.75 .13449 Mdot
.75 .13849 Mdot
.75 .13897 Mdot
.75 .13951 Mdot
.75 .13969 Mdot
.75 .13984 Mdot
.75 .1403 Mdot
.75 .14078 Mdot
.75 .14107 Mdot
.75 .1411 Mdot
.75 .14146 Mdot
.75 .14146 Mdot
.75 .14156 Mdot
.75 .14174 Mdot
.75 .14201 Mdot
.75 .14207 Mdot
.75 .14278 Mdot
.75 .14292 Mdot
.75 .1431 Mdot
.75 .14351 Mdot
.75 .14353 Mdot
.75 .14392 Mdot
.75 .14432 Mdot
.75 .14457 Mdot
.75 .1452 Mdot
.75 .14571 Mdot
.75 .14593 Mdot
.75 .14656 Mdot
.75 .14668 Mdot
.75 .14678 Mdot
.75 .14684 Mdot
.75 .14749 Mdot
.75 .14778 Mdot
.75 .14883 Mdot
.75 .14883 Mdot
.75 .14884 Mdot
.75 .14982 Mdot
.75 .14986 Mdot
.75 .14991 Mdot
.75 .15038 Mdot
.75 .15108 Mdot
.75 .15162 Mdot
.75 .15211 Mdot
.75 .15214 Mdot
.75 .15242 Mdot
.75 .15247 Mdot
.75 .15259 Mdot
.75 .15305 Mdot
.75 .15352 Mdot
.75 .15367 Mdot
.75 .15447 Mdot
.75 .15463 Mdot
.75 .15471 Mdot
.75 .15515 Mdot
.75 .15527 Mdot
.75 .15538 Mdot
.75 .15541 Mdot
.75 .15541 Mdot
.75 .15657 Mdot
.75 .15664 Mdot
.75 .15715 Mdot
.75 .15779 Mdot
.75 .15781 Mdot
.75 .1579 Mdot
.75 .1581 Mdot
.75 .15914 Mdot
.75 .15989 Mdot
.75 .15991 Mdot
.75 .15993 Mdot
.75 .16009 Mdot
.75 .16095 Mdot
.75 .16136 Mdot
.75 .1629 Mdot
.75 .16351 Mdot
.75 .16399 Mdot
.75 .16501 Mdot
.75 .16515 Mdot
.75 .16594 Mdot
.75 .16608 Mdot
.75 .1662 Mdot
.75 .16632 Mdot
.75 .16677 Mdot
.75 .16679 Mdot
.75 .16709 Mdot
.75 .16777 Mdot
.75 .16797 Mdot
.75 .16806 Mdot
.75 .16867 Mdot
.75 .16871 Mdot
.75 .16889 Mdot
.75 .16892 Mdot
.75 .16979 Mdot
.75 .17058 Mdot
.75 .17067 Mdot
.75 .17082 Mdot
.75 .17085 Mdot
.75 .17116 Mdot
.75 .17143 Mdot
.75 .17145 Mdot
.75 .17157 Mdot
.75 .17165 Mdot
.75 .1719 Mdot
.75 .17217 Mdot
.75 .17282 Mdot
.75 .17283 Mdot
.75 .17317 Mdot
.75 .17327 Mdot
.75 .17327 Mdot
.75 .17333 Mdot
.75 .17334 Mdot
.75 .17345 Mdot
.75 .17373 Mdot
.75 .17389 Mdot
.75 .17392 Mdot
.75 .17552 Mdot
.75 .17582 Mdot
.75 .17608 Mdot
.75 .17616 Mdot
.75 .17655 Mdot
.75 .17736 Mdot
.75 .17743 Mdot
.75 .17745 Mdot
.75 .17757 Mdot
.75 .17795 Mdot
.75 .17907 Mdot
.75 .18021 Mdot
.75 .18058 Mdot
.75 .18094 Mdot
.75 .18124 Mdot
.75 .1815 Mdot
.75 .18348 Mdot
.75 .18587 Mdot
.75 .18587 Mdot
.75 .18617 Mdot
.75 .18726 Mdot
.75 .1873 Mdot
.75 .18758 Mdot
.75 .18782 Mdot
.75 .18818 Mdot
.75 .18914 Mdot
.75 .18915 Mdot
.75 .19036 Mdot
.75 .19094 Mdot
.75 .19119 Mdot
.75 .19181 Mdot
.75 .19208 Mdot
.75 .19248 Mdot
.75 .19316 Mdot
.75 .19377 Mdot
.75 .19408 Mdot
.75 .19435 Mdot
.75 .19438 Mdot
.75 .19727 Mdot
.75 .19781 Mdot
.75 .20022 Mdot
.75 .20038 Mdot
.75 .20109 Mdot
.75 .20191 Mdot
.75 .20218 Mdot
.75 .20241 Mdot
.75 .20297 Mdot
.75 .20309 Mdot
.75 .20381 Mdot
.75 .2039 Mdot
.75 .20425 Mdot
.75 .20429 Mdot
.75 .20466 Mdot
.75 .20483 Mdot
.75 .20483 Mdot
.75 .20499 Mdot
.75 .20525 Mdot
.75 .20566 Mdot
.75 .20575 Mdot
.75 .20657 Mdot
.75 .20681 Mdot
.75 .20697 Mdot
.75 .20702 Mdot
.75 .20729 Mdot
.75 .20791 Mdot
.75 .20794 Mdot
.75 .20852 Mdot
.75 .20913 Mdot
.75 .2094 Mdot
.75 .2095 Mdot
.75 .20969 Mdot
.75 .21044 Mdot
.75 .21088 Mdot
.75 .21102 Mdot
.75 .21121 Mdot
.75 .21153 Mdot
.75 .21227 Mdot
.75 .21249 Mdot
.75 .21267 Mdot
.75 .21281 Mdot
.75 .21283 Mdot
.75 .21284 Mdot
.75 .2129 Mdot
.75 .21336 Mdot
.75 .21388 Mdot
.75 .21426 Mdot
.75 .21432 Mdot
.75 .21564 Mdot
.75 .21589 Mdot
.75 .21589 Mdot
.75 .2159 Mdot
.75 .21593 Mdot
.75 .21737 Mdot
.75 .21743 Mdot
.75 .21751 Mdot
.75 .21821 Mdot
.75 .21869 Mdot
.75 .21926 Mdot
.75 .21952 Mdot
.75 .22006 Mdot
.75 .22007 Mdot
.75 .22022 Mdot
.75 .22081 Mdot
.75 .22085 Mdot
.75 .22112 Mdot
.75 .22128 Mdot
.75 .22135 Mdot
.75 .22152 Mdot
.75 .22222 Mdot
.75 .22293 Mdot
.75 .22314 Mdot
.75 .22321 Mdot
.75 .22334 Mdot
.75 .22434 Mdot
.75 .22458 Mdot
.75 .22471 Mdot
.75 .22527 Mdot
.75 .22537 Mdot
.75 .22554 Mdot
.75 .22572 Mdot
.75 .22576 Mdot
.75 .22576 Mdot
.75 .22733 Mdot
.75 .2275 Mdot
.75 .22761 Mdot
.75 .22827 Mdot
.75 .22837 Mdot
.75 .2286 Mdot
.75 .22923 Mdot
.75 .22932 Mdot
.75 .22936 Mdot
.75 .2295 Mdot
.75 .22979 Mdot
.75 .23135 Mdot
.75 .23177 Mdot
.75 .23247 Mdot
.75 .2325 Mdot
.75 .23254 Mdot
.75 .23278 Mdot
.75 .23326 Mdot
.75 .23373 Mdot
.75 .23406 Mdot
.75 .23437 Mdot
.75 .23468 Mdot
.75 .23546 Mdot
.75 .23699 Mdot
.75 .2379 Mdot
.75 .23863 Mdot
.75 .24016 Mdot
.75 .24036 Mdot
.75 .24155 Mdot
.75 .24176 Mdot
.75 .24194 Mdot
.75 .24213 Mdot
.75 .2428 Mdot
.75 .24282 Mdot
.75 .24328 Mdot
.75 .2443 Mdot
.75 .2446 Mdot
.75 .24473 Mdot
.75 .24564 Mdot
.75 .2457 Mdot
.75 .24598 Mdot
.75 .24603 Mdot
.75 .24733 Mdot
.75 .24851 Mdot
.75 .24865 Mdot
.75 .24887 Mdot
.75 .24891 Mdot
.75 .24939 Mdot
.75 .24978 Mdot
.75 .24982 Mdot
.75 .25 Mdot
.75 .25012 Mdot
.75 .2505 Mdot
.75 .2509 Mdot
.75 .25187 Mdot
.75 .25189 Mdot
.75 .2524 Mdot
.75 .25255 Mdot
.75 .25255 Mdot
.75 .25264 Mdot
.75 .25265 Mdot
.75 .25282 Mdot
.75 .25324 Mdot
.75 .25348 Mdot
.75 .25352 Mdot
.75 .25592 Mdot
.75 .25637 Mdot
.75 .25676 Mdot
.75 .25689 Mdot
.75 .25746 Mdot
.75 .25868 Mdot
.75 .25879 Mdot
.75 .25882 Mdot
.75 .259 Mdot
.75 .25957 Mdot
.75 .26125 Mdot
.75 .26296 Mdot
.75 .26352 Mdot
.75 .26405 Mdot
.75 .26451 Mdot
.75 .26489 Mdot
.75 .26787 Mdot
.75 .27144 Mdot
.75 .27145 Mdot
.75 .2719 Mdot
.75 .27353 Mdot
.75 .27359 Mdot
.75 .27402 Mdot
.75 .27437 Mdot
.75 .27491 Mdot
.75 .27636 Mdot
.75 .27637 Mdot
.75 .27818 Mdot
.75 .27905 Mdot
.75 .27942 Mdot
.75 .28036 Mdot
.75 .28076 Mdot
.75 .28137 Mdot
.75 .28239 Mdot
.75 .2833 Mdot
.75 .28376 Mdot
.75 .28416 Mdot
.75 .28422 Mdot
.75 .28854 Mdot
.75 .28936 Mdot
.75 .29297 Mdot
.75 .29321 Mdot
.75 .29428 Mdot
.75 .29551 Mdot
.75 .29592 Mdot
.75 .29626 Mdot
.75 .2971 Mdot
.75 .29728 Mdot
.75 .29836 Mdot
.75 .29849 Mdot
.75 .29902 Mdot
.75 .29908 Mdot
.75 .29964 Mdot
.75 .29988 Mdot
.75 .29989 Mdot
.75 .30012 Mdot
.75 .30052 Mdot
.75 .30114 Mdot
.75 .30127 Mdot
.75 .30249 Mdot
.75 .30286 Mdot
.75 .3031 Mdot
.75 .30317 Mdot
.75 .30357 Mdot
.75 .3045 Mdot
.75 .30456 Mdot
.75 .30542 Mdot
.75 .30633 Mdot
.75 .30675 Mdot
.75 .3069 Mdot
.75 .30717 Mdot
.75 .3083 Mdot
.75 .30897 Mdot
.75 .30917 Mdot
.75 .30946 Mdot
.75 .30994 Mdot
.75 .31105 Mdot
.75 .31138 Mdot
.75 .31164 Mdot
.75 .31186 Mdot
.75 .31188 Mdot
.75 .3119 Mdot
.75 .31199 Mdot
.75 .31269 Mdot
.75 .31347 Mdot
.75 .31404 Mdot
.75 .31412 Mdot
.75 .3161 Mdot
.75 .31648 Mdot
.75 .31648 Mdot
.75 .31649 Mdot
.75 .31654 Mdot
.75 .3187 Mdot
.75 .31878 Mdot
.75 .3189 Mdot
.75 .31995 Mdot
.75 .32068 Mdot
.75 .32153 Mdot
.75 .32192 Mdot
.75 .32273 Mdot
.75 .32275 Mdot
.75 .32297 Mdot
.75 .32385 Mdot
.75 .32391 Mdot
.75 .32432 Mdot
.75 .32456 Mdot
.75 .32467 Mdot
.75 .32493 Mdot
.75 .32597 Mdot
.75 .32704 Mdot
.75 .32736 Mdot
.75 .32746 Mdot
.75 .32765 Mdot
.75 .32915 Mdot
.75 .32952 Mdot
.75 .32971 Mdot
.75 .33055 Mdot
.75 .3307 Mdot
.75 .33096 Mdot
.75 .33122 Mdot
.75 .33128 Mdot
.75 .33129 Mdot
.75 .33364 Mdot
.75 .3339 Mdot
.75 .33405 Mdot
.75 .33505 Mdot
.75 .3352 Mdot
.75 .33554 Mdot
.75 .33648 Mdot
.75 .33662 Mdot
.75 .33668 Mdot
.75 .33689 Mdot
.75 .33733 Mdot
.75 .33967 Mdot
.75 .34029 Mdot
.75 .34135 Mdot
.75 .3414 Mdot
.75 .34145 Mdot
.75 .34181 Mdot
.75 .34254 Mdot
.75 .34323 Mdot
.75 .34373 Mdot
.75 .3442 Mdot
.75 .34466 Mdot
.75 .34583 Mdot
.75 .34813 Mdot
.75 .3495 Mdot
.75 .35059 Mdot
.75 .35288 Mdot
.75 .35319 Mdot
.75 .35497 Mdot
.75 .35528 Mdot
.75 .35555 Mdot
.75 .35583 Mdot
.75 .35684 Mdot
.75 .35687 Mdot
.75 .35757 Mdot
.75 .3591 Mdot
.75 .35954 Mdot
.75 .35974 Mdot
.75 .36111 Mdot
.75 .3612 Mdot
.75 .36162 Mdot
.75 .36169 Mdot
.75 .36363 Mdot
.75 .36541 Mdot
.75 .36562 Mdot
.75 .36594 Mdot
.75 .36601 Mdot
.75 .36673 Mdot
.75 .36731 Mdot
.75 .36737 Mdot
.75 .36765 Mdot
.75 .36782 Mdot
.75 .36839 Mdot
.75 .369 Mdot
.75 .37044 Mdot
.75 .37048 Mdot
.75 .37124 Mdot
.75 .37146 Mdot
.75 .37147 Mdot
.75 .3716 Mdot
.75 .37162 Mdot
.75 .37188 Mdot
.75 .37251 Mdot
.75 .37286 Mdot
.75 .37293 Mdot
.75 .37653 Mdot
.75 .37719 Mdot
.75 .37778 Mdot
.75 .37798 Mdot
.75 .37884 Mdot
.75 .38066 Mdot
.75 .38082 Mdot
.75 .38087 Mdot
.75 .38114 Mdot
.75 .382 Mdot
.75 .38452 Mdot
.75 .38708 Mdot
.75 .38792 Mdot
.75 .38872 Mdot
.75 .3894 Mdot
.75 .38998 Mdot
.75 .39444 Mdot
.75 .39981 Mdot
.75 .39981 Mdot
.75 .40049 Mdot
.75 .40294 Mdot
.75 .40303 Mdot
.75 .40367 Mdot
.75 .40419 Mdot
.75 .40501 Mdot
.75 .40718 Mdot
.75 .40719 Mdot
.75 .40992 Mdot
.75 .41121 Mdot
.75 .41178 Mdot
.75 .41318 Mdot
.75 .41378 Mdot
.75 .4147 Mdot
.75 .41622 Mdot
.75 .4176 Mdot
.75 .41828 Mdot
.75 .41889 Mdot
.75 .41897 Mdot
.75 .42545 Mdot
.75 .42668 Mdot
.75 .4321 Mdot
.75 .43246 Mdot
.75 .43406 Mdot
.75 .4359 Mdot
.75 .43652 Mdot
.75 .43703 Mdot
.75 .4383 Mdot
.75 .43857 Mdot
.75 .44019 Mdot
.75 .44038 Mdot
.75 .44118 Mdot
.75 .44127 Mdot
.75 .4421 Mdot
.75 .44247 Mdot
.75 .44248 Mdot
.75 .44283 Mdot
.75 .44343 Mdot
.75 .44435 Mdot
.75 .44454 Mdot
.75 .44638 Mdot
.75 .44693 Mdot
.75 .44729 Mdot
.75 .4474 Mdot
.75 .448 Mdot
.75 .4494 Mdot
.75 .44948 Mdot
.75 .45077 Mdot
.75 .45214 Mdot
.75 .45277 Mdot
.75 .45299 Mdot
.75 .4534 Mdot
.75 .4551 Mdot
.75 .45609 Mdot
.75 .4564 Mdot
.75 .45684 Mdot
.75 .45756 Mdot
.752 .01502 Mdot
.752 .01517 Mdot
.752 .0153 Mdot
.752 .0154 Mdot
.752 .0156 Mdot
.752 .01574 Mdot
.752 .01604 Mdot
.752 .01626 Mdot
.752 .01636 Mdot
.752 .01654 Mdot
.752 .01671 Mdot
.752 .01691 Mdot
.752 .01703 Mdot
.752 .01719 Mdot
.752 .01746 Mdot
.752 .01767 Mdot
.752 .01771 Mdot
.752 .01801 Mdot
.752 .0182 Mdot
.752 .01844 Mdot
.752 .01884 Mdot
.752 .01917 Mdot
.752 .01922 Mdot
.752 .01936 Mdot
.752 .01967 Mdot
.752 .01996 Mdot
.752 .02032 Mdot
.752 .02092 Mdot
.752 .02141 Mdot
.752 .02149 Mdot
.752 .0217 Mdot
.752 .02217 Mdot
.752 .02251 Mdot
.752 .02261 Mdot
.752 .02267 Mdot
.752 .02315 Mdot
.752 .02405 Mdot
.752 .02478 Mdot
.752 .0249 Mdot
.752 .02522 Mdot
.752 .02557 Mdot
.752 .0257 Mdot
.752 .02593 Mdot
.752 .02644 Mdot
.752 .02658 Mdot
.752 .02668 Mdot
.752 .02694 Mdot
.752 .02739 Mdot
.752 .02875 Mdot
.752 .02878 Mdot
.752 .02898 Mdot
.752 .02934 Mdot
.752 .02948 Mdot
.752 .02985 Mdot
.752 .02987 Mdot
.752 .03003 Mdot
.752 .03046 Mdot
.752 .03052 Mdot
.752 .03103 Mdot
.752 .03117 Mdot
.752 .03124 Mdot
.752 .03153 Mdot
.752 .03158 Mdot
.752 .03234 Mdot
.752 .03245 Mdot
.752 .03248 Mdot
.752 .03256 Mdot
.752 .03271 Mdot
.752 .0331 Mdot
.752 .03379 Mdot
.752 .03384 Mdot
.752 .03425 Mdot
.752 .03429 Mdot
.752 .03486 Mdot
.752 .03513 Mdot
.752 .03522 Mdot
.752 .0353 Mdot
.752 .03549 Mdot
.752 .03583 Mdot
.752 .03587 Mdot
.752 .03617 Mdot
.752 .03672 Mdot
.752 .03682 Mdot
.752 .03692 Mdot
.752 .03728 Mdot
.752 .03748 Mdot
.752 .03751 Mdot
.752 .03775 Mdot
.752 .0381 Mdot
.752 .03839 Mdot
.752 .03849 Mdot
.752 .03926 Mdot
.752 .03946 Mdot
.752 .03956 Mdot
.752 .04001 Mdot
.752 .04008 Mdot
.752 .04071 Mdot
.752 .04108 Mdot
.752 .04123 Mdot
.752 .04138 Mdot
.752 .04139 Mdot
.752 .04144 Mdot
.752 .04156 Mdot
.752 .04178 Mdot
.752 .04183 Mdot
.752 .04194 Mdot
.752 .04237 Mdot
.752 .0434 Mdot
.752 .04348 Mdot
.752 .04393 Mdot
.752 .0441 Mdot
.752 .04415 Mdot
.752 .04478 Mdot
.752 .04501 Mdot
.752 .04525 Mdot
.752 .04541 Mdot
.752 .04555 Mdot
.752 .04567 Mdot
.752 .04597 Mdot
.752 .04647 Mdot
.752 .04654 Mdot
.752 .04698 Mdot
.752 .04781 Mdot
.752 .04795 Mdot
.752 .04811 Mdot
.752 .04866 Mdot
.752 .04896 Mdot
.752 .049 Mdot
.752 .04936 Mdot
.752 .04989 Mdot
.752 .05006 Mdot
.752 .05032 Mdot
.752 .05042 Mdot
.752 .05047 Mdot
.752 .05096 Mdot
.752 .05132 Mdot
.752 .05136 Mdot
.752 .05163 Mdot
.752 .05193 Mdot
.752 .05201 Mdot
.752 .05208 Mdot
.752 .05222 Mdot
.752 .05276 Mdot
.752 .05286 Mdot
.752 .05381 Mdot
.752 .05437 Mdot
.752 .05459 Mdot
.752 .05483 Mdot
.752 .05483 Mdot
.752 .05491 Mdot
.752 .05509 Mdot
.752 .05542 Mdot
.752 .05549 Mdot
.752 .05566 Mdot
.752 .0563 Mdot
.752 .05736 Mdot
.752 .05785 Mdot
.752 .05791 Mdot
.752 .05798 Mdot
.752 .05818 Mdot
.752 .05865 Mdot
.752 .05891 Mdot
.752 .05899 Mdot
.752 .05993 Mdot
.752 .06028 Mdot
.752 .06064 Mdot
.752 .06088 Mdot
.752 .06099 Mdot
.752 .0611 Mdot
.752 .06128 Mdot
.752 .06172 Mdot
.752 .06201 Mdot
.752 .06203 Mdot
.752 .06239 Mdot
.752 .06248 Mdot
.752 .06257 Mdot
.752 .06274 Mdot
.752 .06324 Mdot
.752 .06364 Mdot
.752 .06449 Mdot
.752 .06471 Mdot
.752 .06494 Mdot
.752 .06577 Mdot
.752 .06606 Mdot
.752 .06622 Mdot
.752 .06627 Mdot
.752 .06682 Mdot
.752 .067 Mdot
.752 .06733 Mdot
.752 .06762 Mdot
.752 .06787 Mdot
.752 .06827 Mdot
.752 .06842 Mdot
.752 .06849 Mdot
.752 .06917 Mdot
.752 .06922 Mdot
.752 .06929 Mdot
.752 .06977 Mdot
.752 .06983 Mdot
.752 .06996 Mdot
.752 .07024 Mdot
.752 .07069 Mdot
.752 .0708 Mdot
.752 .0708 Mdot
.752 .07092 Mdot
.752 .07112 Mdot
.752 .07193 Mdot
.752 .07208 Mdot
.752 .07311 Mdot
.752 .07352 Mdot
.752 .07436 Mdot
.752 .07469 Mdot
.752 .07504 Mdot
.752 .07505 Mdot
.752 .07517 Mdot
.752 .07544 Mdot
.752 .07593 Mdot
.752 .07604 Mdot
.752 .07621 Mdot
.752 .0763 Mdot
.752 .0771 Mdot
.752 .07726 Mdot
.752 .07812 Mdot
.752 .07852 Mdot
.752 .0787 Mdot
.752 .07886 Mdot
.752 .07959 Mdot
.752 .07968 Mdot
.752 .07979 Mdot
.752 .08009 Mdot
.752 .08079 Mdot
.752 .08118 Mdot
.752 .08125 Mdot
.752 .0813 Mdot
.752 .08153 Mdot
.752 .08203 Mdot
.752 .08243 Mdot
.752 .08272 Mdot
.752 .08325 Mdot
.752 .08379 Mdot
.752 .08381 Mdot
.752 .08415 Mdot
.752 .08417 Mdot
.752 .08432 Mdot
.752 .08447 Mdot
.752 .08474 Mdot
.752 .08518 Mdot
.752 .08541 Mdot
.752 .08584 Mdot
.752 .08588 Mdot
.752 .08642 Mdot
.752 .08655 Mdot
.752 .0867 Mdot
.752 .08695 Mdot
.752 .08727 Mdot
.752 .08747 Mdot
.752 .0877 Mdot
.752 .088 Mdot
.752 .0883 Mdot
.752 .08957 Mdot
.752 .0899 Mdot
.752 .09026 Mdot
.752 .09115 Mdot
.752 .09149 Mdot
.752 .0915 Mdot
.752 .09193 Mdot
.752 .09218 Mdot
.752 .09226 Mdot
.752 .09309 Mdot
.752 .09313 Mdot
.752 .09335 Mdot
.752 .09338 Mdot
.752 .09384 Mdot
.752 .09428 Mdot
.752 .09467 Mdot
.752 .09523 Mdot
.752 .09526 Mdot
.752 .09548 Mdot
.752 .09559 Mdot
.752 .09661 Mdot
.752 .0967 Mdot
.752 .0968 Mdot
.752 .09687 Mdot
.752 .09739 Mdot
.752 .09751 Mdot
.752 .09761 Mdot
.752 .09781 Mdot
.752 .09822 Mdot
.752 .09875 Mdot
.752 .0989 Mdot
.752 .09907 Mdot
.752 .09907 Mdot
.752 .09924 Mdot
.752 .09954 Mdot
.752 .10077 Mdot
.752 .101 Mdot
.752 .10158 Mdot
.752 .10174 Mdot
.752 .10254 Mdot
.752 .10315 Mdot
.752 .10377 Mdot
.752 .10438 Mdot
.752 .10441 Mdot
.752 .10449 Mdot
.752 .1047 Mdot
.752 .10491 Mdot
.752 .10545 Mdot
.752 .10545 Mdot
.752 .10563 Mdot
.752 .10565 Mdot
.752 .10604 Mdot
.752 .10678 Mdot
.752 .10684 Mdot
.752 .10695 Mdot
.752 .1072 Mdot
.752 .10734 Mdot
.752 .10853 Mdot
.752 .10861 Mdot
.752 .10879 Mdot
.752 .10892 Mdot
.752 .10896 Mdot
.752 .10996 Mdot
.752 .11007 Mdot
.752 .11067 Mdot
.752 .11094 Mdot
.752 .11119 Mdot
.752 .11227 Mdot
.752 .11229 Mdot
.752 .11242 Mdot
.752 .11259 Mdot
.752 .11304 Mdot
.752 .11382 Mdot
.752 .11402 Mdot
.752 .1141 Mdot
.752 .11468 Mdot
.752 .11478 Mdot
.752 .11486 Mdot
.752 .1152 Mdot
.752 .11585 Mdot
.752 .11595 Mdot
.752 .11657 Mdot
.752 .11663 Mdot
.752 .117 Mdot
.752 .11736 Mdot
.752 .11768 Mdot
.752 .11779 Mdot
.752 .11805 Mdot
.752 .1186 Mdot
.752 .11864 Mdot
.752 .11915 Mdot
.752 .11917 Mdot
.752 .1194 Mdot
.752 .11963 Mdot
.752 .12004 Mdot
.752 .12069 Mdot
.752 .12103 Mdot
.752 .12169 Mdot
.752 .12175 Mdot
.752 .12182 Mdot
.752 .12256 Mdot
.752 .12275 Mdot
.752 .12281 Mdot
.752 .12297 Mdot
.752 .12311 Mdot
.752 .1232 Mdot
.752 .12335 Mdot
.752 .12384 Mdot
.752 .12394 Mdot
.752 .12414 Mdot
.752 .12449 Mdot
.752 .12462 Mdot
.752 .12494 Mdot
.752 .12507 Mdot
.752 .12538 Mdot
.752 .12589 Mdot
.752 .1273 Mdot
.752 .1278 Mdot
.752 .12833 Mdot
.752 .12835 Mdot
.752 .12873 Mdot
.752 .1289 Mdot
.752 .12967 Mdot
.752 .12989 Mdot
.752 .13018 Mdot
.752 .1302 Mdot
.752 .13085 Mdot
.752 .13122 Mdot
.752 .13134 Mdot
.752 .13168 Mdot
.752 .13234 Mdot
.752 .13259 Mdot
.752 .13265 Mdot
.752 .13298 Mdot
.752 .13303 Mdot
.752 .13341 Mdot
.752 .13372 Mdot
.752 .13399 Mdot
.752 .13438 Mdot
.752 .13469 Mdot
.752 .13496 Mdot
.752 .13581 Mdot
.752 .13585 Mdot
.752 .13619 Mdot
.752 .13627 Mdot
.752 .13636 Mdot
.752 .13788 Mdot
.752 .13802 Mdot
.752 .13817 Mdot
.752 .13828 Mdot
.752 .13885 Mdot
.752 .13906 Mdot
.752 .13924 Mdot
.752 .13939 Mdot
.752 .13969 Mdot
.752 .14019 Mdot
.752 .14031 Mdot
.752 .14111 Mdot
.752 .14133 Mdot
.752 .14158 Mdot
.752 .14158 Mdot
.752 .14184 Mdot
.752 .1423 Mdot
.752 .14414 Mdot
.752 .14449 Mdot
.752 .14536 Mdot
.752 .14552 Mdot
.752 .1456 Mdot
.752 .14607 Mdot
.752 .1468 Mdot
.752 .14772 Mdot
.752 .14862 Mdot
.752 .14866 Mdot
.752 .14957 Mdot
.752 .14962 Mdot
.752 .14973 Mdot
.752 .15006 Mdot
.752 .15027 Mdot
.752 .15037 Mdot
.752 .15117 Mdot
.752 .15118 Mdot
.752 .15135 Mdot
.752 .15143 Mdot
.752 .15146 Mdot
.752 .15148 Mdot
.752 .15206 Mdot
.752 .15318 Mdot
.752 .15327 Mdot
.752 .1534 Mdot
.752 .15343 Mdot
.752 .15381 Mdot
.752 .15402 Mdot
.752 .15427 Mdot
.752 .15582 Mdot
.752 .15593 Mdot
.752 .1562 Mdot
.752 .15639 Mdot
.752 .15645 Mdot
.752 .15797 Mdot
.752 .15813 Mdot
.752 .15821 Mdot
.752 .15903 Mdot
.752 .15933 Mdot
.752 .15944 Mdot
.752 .15981 Mdot
.752 .1608 Mdot
.752 .1609 Mdot
.752 .16144 Mdot
.752 .16147 Mdot
.752 .16167 Mdot
.752 .16192 Mdot
.752 .16259 Mdot
.752 .16377 Mdot
.752 .16407 Mdot
.752 .16418 Mdot
.752 .16424 Mdot
.752 .16499 Mdot
.752 .16507 Mdot
.752 .16522 Mdot
.752 .16534 Mdot
.752 .16574 Mdot
.752 .16585 Mdot
.752 .16614 Mdot
.752 .16676 Mdot
.752 .16682 Mdot
.752 .16697 Mdot
.752 .1679 Mdot
.752 .168 Mdot
.752 .16848 Mdot
.752 .16855 Mdot
.752 .1691 Mdot
.752 .16958 Mdot
.752 .16973 Mdot
.752 .17013 Mdot
.752 .17096 Mdot
.752 .17101 Mdot
.752 .17161 Mdot
.752 .17179 Mdot
.752 .17182 Mdot
.752 .17188 Mdot
.752 .17216 Mdot
.752 .17251 Mdot
.752 .17303 Mdot
.752 .17312 Mdot
.752 .17313 Mdot
.752 .17343 Mdot
.752 .17411 Mdot
.752 .17456 Mdot
.752 .17462 Mdot
.752 .17516 Mdot
.752 .17539 Mdot
.752 .1756 Mdot
.752 .1757 Mdot
.752 .17581 Mdot
.752 .17691 Mdot
.752 .1772 Mdot
.752 .17729 Mdot
.752 .17732 Mdot
.752 .17754 Mdot
.752 .17773 Mdot
.752 .17787 Mdot
.752 .17811 Mdot
.752 .17883 Mdot
.752 .17894 Mdot
.752 .17899 Mdot
.752 .17929 Mdot
.752 .17981 Mdot
.752 .18001 Mdot
.752 .18032 Mdot
.752 .18049 Mdot
.752 .1807 Mdot
.752 .18116 Mdot
.752 .18192 Mdot
.752 .18231 Mdot
.752 .18388 Mdot
.752 .18404 Mdot
.752 .18479 Mdot
.752 .18527 Mdot
.752 .18559 Mdot
.752 .18562 Mdot
.752 .1862 Mdot
.752 .18645 Mdot
.752 .18761 Mdot
.752 .18794 Mdot
.752 .18837 Mdot
.752 .1884 Mdot
.752 .18938 Mdot
.752 .1896 Mdot
.752 .18982 Mdot
.752 .18994 Mdot
.752 .19012 Mdot
.752 .19063 Mdot
.752 .19155 Mdot
.752 .19163 Mdot
.752 .19197 Mdot
.752 .192 Mdot
.752 .19208 Mdot
.752 .19242 Mdot
.752 .19259 Mdot
.752 .19266 Mdot
.752 .19323 Mdot
.752 .1937 Mdot
.752 .19411 Mdot
.752 .19469 Mdot
.752 .19515 Mdot
.752 .19556 Mdot
.752 .19684 Mdot
.752 .1969 Mdot
.752 .19741 Mdot
.752 .19753 Mdot
.752 .19766 Mdot
.752 .19996 Mdot
.752 .20016 Mdot
.752 .20023 Mdot
.752 .20039 Mdot
.752 .20055 Mdot
.752 .20091 Mdot
.752 .20114 Mdot
.752 .20142 Mdot
.752 .20168 Mdot
.752 .20173 Mdot
.752 .20201 Mdot
.752 .20222 Mdot
.752 .20224 Mdot
.752 .20267 Mdot
.752 .20343 Mdot
.752 .20346 Mdot
.752 .2036 Mdot
.752 .20425 Mdot
.752 .20481 Mdot
.752 .20514 Mdot
.752 .20519 Mdot
.752 .20552 Mdot
.752 .20553 Mdot
.752 .20592 Mdot
.752 .20609 Mdot
.752 .20626 Mdot
.752 .2066 Mdot
.752 .20719 Mdot
.752 .20793 Mdot
.752 .20797 Mdot
.752 .20937 Mdot
.752 .20946 Mdot
.752 .20989 Mdot
.752 .21121 Mdot
.752 .21144 Mdot
.752 .21157 Mdot
.752 .21204 Mdot
.752 .21212 Mdot
.752 .21228 Mdot
.752 .21262 Mdot
.752 .21337 Mdot
.752 .21476 Mdot
.752 .21483 Mdot
.752 .21611 Mdot
.752 .21617 Mdot
.752 .21672 Mdot
.752 .21753 Mdot
.752 .21762 Mdot
.752 .21778 Mdot
.752 .21784 Mdot
.752 .21801 Mdot
.752 .21827 Mdot
.752 .21858 Mdot
.752 .21875 Mdot
.752 .21915 Mdot
.752 .21917 Mdot
.752 .21995 Mdot
.752 .21996 Mdot
.752 .22022 Mdot
.752 .22033 Mdot
.752 .22038 Mdot
.752 .22041 Mdot
.752 .2205 Mdot
.752 .22108 Mdot
.752 .22129 Mdot
.752 .22165 Mdot
.752 .2228 Mdot
.752 .22297 Mdot
.752 .2231 Mdot
.752 .2233 Mdot
.752 .22335 Mdot
.752 .22423 Mdot
.752 .2246 Mdot
.752 .22481 Mdot
.752 .22694 Mdot
.752 .2271 Mdot
.752 .22733 Mdot
.752 .22749 Mdot
.752 .22751 Mdot
.752 .2278 Mdot
.752 .22789 Mdot
.752 .23017 Mdot
.752 .23041 Mdot
.752 .23053 Mdot
.752 .23177 Mdot
.752 .23222 Mdot
.752 .23223 Mdot
.752 .23239 Mdot
.752 .23254 Mdot
.752 .23294 Mdot
.752 .23401 Mdot
.752 .23443 Mdot
.752 .23457 Mdot
.752 .23538 Mdot
.752 .23544 Mdot
.752 .23574 Mdot
.752 .23611 Mdot
.752 .23713 Mdot
.752 .2385 Mdot
.752 .23889 Mdot
.752 .23934 Mdot
.752 .23952 Mdot
.752 .2396 Mdot
.752 .24073 Mdot
.752 .24085 Mdot
.752 .24107 Mdot
.752 .24125 Mdot
.752 .24186 Mdot
.752 .24202 Mdot
.752 .24246 Mdot
.752 .24339 Mdot
.752 .24347 Mdot
.752 .24371 Mdot
.752 .2451 Mdot
.752 .24525 Mdot
.752 .24598 Mdot
.752 .24609 Mdot
.752 .2469 Mdot
.752 .24763 Mdot
.752 .24786 Mdot
.752 .24846 Mdot
.752 .24971 Mdot
.752 .24978 Mdot
.752 .25068 Mdot
.752 .25095 Mdot
.752 .251 Mdot
.752 .25109 Mdot
.752 .25151 Mdot
.752 .25204 Mdot
.752 .25282 Mdot
.752 .25296 Mdot
.752 .25297 Mdot
.752 .25342 Mdot
.752 .25444 Mdot
.752 .25512 Mdot
.752 .25521 Mdot
.752 .25602 Mdot
.752 .25637 Mdot
.752 .25669 Mdot
.752 .25683 Mdot
.752 .25699 Mdot
.752 .25866 Mdot
.752 .2591 Mdot
.752 .25923 Mdot
.752 .25927 Mdot
.752 .2596 Mdot
.752 .2599 Mdot
.752 .2601 Mdot
.752 .26046 Mdot
.752 .26155 Mdot
.752 .26172 Mdot
.752 .26179 Mdot
.752 .26223 Mdot
.752 .26302 Mdot
.752 .26331 Mdot
.752 .26378 Mdot
.752 .26404 Mdot
.752 .26435 Mdot
.752 .26505 Mdot
.752 .26619 Mdot
.752 .26678 Mdot
.752 .26914 Mdot
.752 .26938 Mdot
.752 .27051 Mdot
.752 .27124 Mdot
.752 .27172 Mdot
.752 .27175 Mdot
.752 .27262 Mdot
.752 .27301 Mdot
.752 .27475 Mdot
.752 .27524 Mdot
.752 .27589 Mdot
.752 .27594 Mdot
.752 .27741 Mdot
.752 .27774 Mdot
.752 .27808 Mdot
.752 .27826 Mdot
.752 .27853 Mdot
.752 .27929 Mdot
.752 .28067 Mdot
.752 .28079 Mdot
.752 .2813 Mdot
.752 .28134 Mdot
.752 .28148 Mdot
.752 .28198 Mdot
.752 .28224 Mdot
.752 .28234 Mdot
.752 .2832 Mdot
.752 .28391 Mdot
.752 .28452 Mdot
.752 .2854 Mdot
.752 .2861 Mdot
.752 .28671 Mdot
.752 .28863 Mdot
.752 .28872 Mdot
.752 .28949 Mdot
.752 .28967 Mdot
.752 .28987 Mdot
.752 .29332 Mdot
.752 .29362 Mdot
.752 .29373 Mdot
.752 .29397 Mdot
.752 .29421 Mdot
.752 .29475 Mdot
.752 .2951 Mdot
.752 .29552 Mdot
.752 .29592 Mdot
.752 .29599 Mdot
.752 .2964 Mdot
.752 .29673 Mdot
.752 .29675 Mdot
.752 .2974 Mdot
.752 .29855 Mdot
.752 .29858 Mdot
.752 .2988 Mdot
.752 .29978 Mdot
.752 .30061 Mdot
.752 .30111 Mdot
.752 .30119 Mdot
.752 .30169 Mdot
.752 .3017 Mdot
.752 .30228 Mdot
.752 .30254 Mdot
.752 .30279 Mdot
.752 .3033 Mdot
.752 .30419 Mdot
.752 .30531 Mdot
.752 .30538 Mdot
.752 .30747 Mdot
.752 .30761 Mdot
.752 .30826 Mdot
.752 .31024 Mdot
.752 .3106 Mdot
.752 .31079 Mdot
.752 .31149 Mdot
.752 .31161 Mdot
.752 .31185 Mdot
.752 .31236 Mdot
.752 .31349 Mdot
.752 .31558 Mdot
.752 .31568 Mdot
.752 .31761 Mdot
.752 .3177 Mdot
.752 .31852 Mdot
.752 .31975 Mdot
.752 .31988 Mdot
.752 .32012 Mdot
.752 .32021 Mdot
.752 .32047 Mdot
.752 .32086 Mdot
.752 .32134 Mdot
.752 .32158 Mdot
.752 .32219 Mdot
.752 .32221 Mdot
.752 .32311 Mdot
.752 .32339 Mdot
.752 .32341 Mdot
.752 .32379 Mdot
.752 .32397 Mdot
.752 .32403 Mdot
.752 .32408 Mdot
.752 .32421 Mdot
.752 .32509 Mdot
.752 .3254 Mdot
.752 .32595 Mdot
.752 .32768 Mdot
.752 .32793 Mdot
.752 .32813 Mdot
.752 .32842 Mdot
.752 .3285 Mdot
.752 .32982 Mdot
.752 .33039 Mdot
.752 .3307 Mdot
.752 .3339 Mdot
.752 .33414 Mdot
.752 .33449 Mdot
.752 .33473 Mdot
.752 .33476 Mdot
.752 .33519 Mdot
.752 .33533 Mdot
.752 .33875 Mdot
.752 .33912 Mdot
.752 .3393 Mdot
.752 .34117 Mdot
.752 .34184 Mdot
.752 .34186 Mdot
.752 .3421 Mdot
.752 .34233 Mdot
.752 .34293 Mdot
.752 .34453 Mdot
.752 .34516 Mdot
.752 .34538 Mdot
.752 .3466 Mdot
.752 .34668 Mdot
.752 .34713 Mdot
.752 .34769 Mdot
.752 .34922 Mdot
.752 .35128 Mdot
.752 .35187 Mdot
.752 .35255 Mdot
.752 .35282 Mdot
.752 .35294 Mdot
.752 .35463 Mdot
.752 .35482 Mdot
.752 .35515 Mdot
.752 .35542 Mdot
.752 .35634 Mdot
.752 .35657 Mdot
.752 .35725 Mdot
.752 .35864 Mdot
.752 .35877 Mdot
.752 .35912 Mdot
.752 .36122 Mdot
.752 .36144 Mdot
.752 .36253 Mdot
.752 .3627 Mdot
.752 .36393 Mdot
.752 .36502 Mdot
.752 .36537 Mdot
.752 .36627 Mdot
.752 .36815 Mdot
.752 .36826 Mdot
.752 .36961 Mdot
.752 .37001 Mdot
.752 .37008 Mdot
.752 .37023 Mdot
.752 .37086 Mdot
.752 .37165 Mdot
.752 .37282 Mdot
.752 .37303 Mdot
.752 .37306 Mdot
.752 .37373 Mdot
.752 .37526 Mdot
.752 .37629 Mdot
.752 .37642 Mdot
.752 .37764 Mdot
.752 .37816 Mdot
.752 .37865 Mdot
.752 .37886 Mdot
.752 .3791 Mdot
.752 .38161 Mdot
.752 .38227 Mdot
.752 .38246 Mdot
.752 .38252 Mdot
.752 .38302 Mdot
.752 .38347 Mdot
.752 .38377 Mdot
.752 .38431 Mdot
.752 .38595 Mdot
.752 .3862 Mdot
.752 .38632 Mdot
.752 .38698 Mdot
.752 .38816 Mdot
.752 .38861 Mdot
.752 .38931 Mdot
.752 .3897 Mdot
.752 .39017 Mdot
.752 .39122 Mdot
.752 .39293 Mdot
.752 .39382 Mdot
.752 .39737 Mdot
.752 .39774 Mdot
.752 .39943 Mdot
.752 .40052 Mdot
.752 .40125 Mdot
.752 .4013 Mdot
.752 .40261 Mdot
.752 .40318 Mdot
.752 .4058 Mdot
.752 .40655 Mdot
.752 .40753 Mdot
.752 .40759 Mdot
.752 .40981 Mdot
.752 .41031 Mdot
.752 .41081 Mdot
.752 .41108 Mdot
.752 .41149 Mdot
.752 .41263 Mdot
.752 .41471 Mdot
.752 .4149 Mdot
.752 .41566 Mdot
.752 .41573 Mdot
.752 .41592 Mdot
.752 .41668 Mdot
.752 .41707 Mdot
.752 .41723 Mdot
.752 .41851 Mdot
.752 .41959 Mdot
.752 .4205 Mdot
.752 .42183 Mdot
.752 .42287 Mdot
.752 .4238 Mdot
.752 .42668 Mdot
.752 .42682 Mdot
.752 .42797 Mdot
.752 .42825 Mdot
.752 .42855 Mdot
.752 .43374 Mdot
.752 .4342 Mdot
.752 .43435 Mdot
.752 .43471 Mdot
.752 .43508 Mdot
.752 .43589 Mdot
.752 .43642 Mdot
.752 .43704 Mdot
.752 .43764 Mdot
.752 .43775 Mdot
.752 .43837 Mdot
.752 .43886 Mdot
.752 .43889 Mdot
.752 .43988 Mdot
.752 .4416 Mdot
.752 .44165 Mdot
.752 .44198 Mdot
.752 .44345 Mdot
.752 .44471 Mdot
.752 .44545 Mdot
.752 .44557 Mdot
.752 .44632 Mdot
.752 .44633 Mdot
.752 .44722 Mdot
.752 .44761 Mdot
.752 .44799 Mdot
.752 .44875 Mdot
.752 .45009 Mdot
.752 .45177 Mdot
.752 .45187 Mdot
.752 .45502 Mdot
.752 .45523 Mdot
.752 .4562 Mdot
.752 .45919 Mdot
.754 .01487 Mdot
.754 .01495 Mdot
.754 .01507 Mdot
.754 .01525 Mdot
.754 .01552 Mdot
.754 .01586 Mdot
.754 .01592 Mdot
.754 .01645 Mdot
.754 .01649 Mdot
.754 .01654 Mdot
.754 .01671 Mdot
.754 .01733 Mdot
.754 .0174 Mdot
.754 .01746 Mdot
.754 .01761 Mdot
.754 .01773 Mdot
.754 .01865 Mdot
.754 .01865 Mdot
.754 .01865 Mdot
.754 .01876 Mdot
.754 .01886 Mdot
.754 .01908 Mdot
.754 .01925 Mdot
.754 .01941 Mdot
.754 .01976 Mdot
.754 .02042 Mdot
.754 .02065 Mdot
.754 .02065 Mdot
.754 .02065 Mdot
.754 .02075 Mdot
.754 .02081 Mdot
.754 .02096 Mdot
.754 .02118 Mdot
.754 .0213 Mdot
.754 .02156 Mdot
.754 .0218 Mdot
.754 .02233 Mdot
.754 .02332 Mdot
.754 .02367 Mdot
.754 .02367 Mdot
.754 .02367 Mdot
.754 .02382 Mdot
.754 .02391 Mdot
.754 .02414 Mdot
.754 .02446 Mdot
.754 .02458 Mdot
.754 .02464 Mdot
.754 .02468 Mdot
.754 .02504 Mdot
.754 .0254 Mdot
.754 .02557 Mdot
.754 .02619 Mdot
.754 .0276 Mdot
.754 .02768 Mdot
.754 .02822 Mdot
.754 .02822 Mdot
.754 .02822 Mdot
.754 .02831 Mdot
.754 .02845 Mdot
.754 .02858 Mdot
.754 .02872 Mdot
.754 .02892 Mdot
.754 .02941 Mdot
.754 .02959 Mdot
.754 .02969 Mdot
.754 .02974 Mdot
.754 .03028 Mdot
.754 .03082 Mdot
.754 .03108 Mdot
.754 .0313 Mdot
.754 .03176 Mdot
.754 .03201 Mdot
.754 .03203 Mdot
.754 .03216 Mdot
.754 .03223 Mdot
.754 .03273 Mdot
.754 .03414 Mdot
.754 .03415 Mdot
.754 .03427 Mdot
.754 .03446 Mdot
.754 .03508 Mdot
.754 .03508 Mdot
.754 .03508 Mdot
.754 .03522 Mdot
.754 .03542 Mdot
.754 .03549 Mdot
.754 .03551 Mdot
.754 .03562 Mdot
.754 .03583 Mdot
.754 .03612 Mdot
.754 .03614 Mdot
.754 .03687 Mdot
.754 .03714 Mdot
.754 .03729 Mdot
.754 .03736 Mdot
.754 .03738 Mdot
.754 .03773 Mdot
.754 .03782 Mdot
.754 .03819 Mdot
.754 .03878 Mdot
.754 .03895 Mdot
.754 .03901 Mdot
.754 .03919 Mdot
.754 .03939 Mdot
.754 .03972 Mdot
.754 .03976 Mdot
.754 .04041 Mdot
.754 .04079 Mdot
.754 .04082 Mdot
.754 .04103 Mdot
.754 .04114 Mdot
.754 .04189 Mdot
.754 .04352 Mdot
.754 .04352 Mdot
.754 .0436 Mdot
.754 .04401 Mdot
.754 .04402 Mdot
.754 .04421 Mdot
.754 .04449 Mdot
.754 .04451 Mdot
.754 .0453 Mdot
.754 .04542 Mdot
.754 .04543 Mdot
.754 .04543 Mdot
.754 .04564 Mdot
.754 .04594 Mdot
.754 .04604 Mdot
.754 .04607 Mdot
.754 .04615 Mdot
.754 .04624 Mdot
.754 .04655 Mdot
.754 .047 Mdot
.754 .04703 Mdot
.754 .04812 Mdot
.754 .04854 Mdot
.754 .04876 Mdot
.754 .04887 Mdot
.754 .04889 Mdot
.754 .04942 Mdot
.754 .04956 Mdot
.754 .04998 Mdot
.754 .05011 Mdot
.754 .05041 Mdot
.754 .05072 Mdot
.754 .05101 Mdot
.754 .05123 Mdot
.754 .05126 Mdot
.754 .05135 Mdot
.754 .05163 Mdot
.754 .05193 Mdot
.754 .05242 Mdot
.754 .05249 Mdot
.754 .0528 Mdot
.754 .05347 Mdot
.754 .05404 Mdot
.754 .05408 Mdot
.754 .0544 Mdot
.754 .05456 Mdot
.754 .05508 Mdot
.754 .05569 Mdot
.754 .05574 Mdot
.754 .05694 Mdot
.754 .05735 Mdot
.754 .05807 Mdot
.754 .05815 Mdot
.754 .05816 Mdot
.754 .05827 Mdot
.754 .0589 Mdot
.754 .05891 Mdot
.754 .05919 Mdot
.754 .05962 Mdot
.754 .05964 Mdot
.754 .06084 Mdot
.754 .06102 Mdot
.754 .06103 Mdot
.754 .06103 Mdot
.754 .06135 Mdot
.754 .0618 Mdot
.754 .06196 Mdot
.754 .06199 Mdot
.754 .06212 Mdot
.754 .06225 Mdot
.754 .06238 Mdot
.754 .06273 Mdot
.754 .06304 Mdot
.754 .0634 Mdot
.754 .06344 Mdot
.754 .06384 Mdot
.754 .0651 Mdot
.754 .06543 Mdot
.754 .06572 Mdot
.754 .06606 Mdot
.754 .06622 Mdot
.754 .06625 Mdot
.754 .06705 Mdot
.754 .06726 Mdot
.754 .06789 Mdot
.754 .0679 Mdot
.754 .06791 Mdot
.754 .0681 Mdot
.754 .06855 Mdot
.754 .06861 Mdot
.754 .06901 Mdot
.754 .06945 Mdot
.754 .06945 Mdot
.754 .06979 Mdot
.754 .06983 Mdot
.754 .06996 Mdot
.754 .07017 Mdot
.754 .07038 Mdot
.754 .07084 Mdot
.754 .07156 Mdot
.754 .07158 Mdot
.754 .07168 Mdot
.754 .07215 Mdot
.754 .07316 Mdot
.754 .07364 Mdot
.754 .07402 Mdot
.754 .07408 Mdot
.754 .0742 Mdot
.754 .07456 Mdot
.754 .0748 Mdot
.754 .075 Mdot
.754 .07503 Mdot
.754 .07559 Mdot
.754 .07559 Mdot
.754 .07581 Mdot
.754 .07651 Mdot
.754 .07657 Mdot
.754 .07678 Mdot
.754 .07731 Mdot
.754 .07819 Mdot
.754 .07839 Mdot
.754 .07871 Mdot
.754 .07891 Mdot
.754 .079 Mdot
.754 .07952 Mdot
.754 .07963 Mdot
.754 .07973 Mdot
.754 .07985 Mdot
.754 .0801 Mdot
.754 .08022 Mdot
.754 .08023 Mdot
.754 .08039 Mdot
.754 .081 Mdot
.754 .08134 Mdot
.754 .08137 Mdot
.754 .08178 Mdot
.754 .08196 Mdot
.754 .08243 Mdot
.754 .08247 Mdot
.754 .08352 Mdot
.754 .08427 Mdot
.754 .08454 Mdot
.754 .08455 Mdot
.754 .08456 Mdot
.754 .08502 Mdot
.754 .08504 Mdot
.754 .08572 Mdot
.754 .08574 Mdot
.754 .08595 Mdot
.754 .08601 Mdot
.754 .08621 Mdot
.754 .0864 Mdot
.754 .0866 Mdot
.754 .08712 Mdot
.754 .08759 Mdot
.754 .08813 Mdot
.754 .08819 Mdot
.754 .0884 Mdot
.754 .08861 Mdot
.754 .08879 Mdot
.754 .09069 Mdot
.754 .09119 Mdot
.754 .09163 Mdot
.754 .09184 Mdot
.754 .09214 Mdot
.754 .09238 Mdot
.754 .09244 Mdot
.754 .09324 Mdot
.754 .09364 Mdot
.754 .09395 Mdot
.754 .09491 Mdot
.754 .09491 Mdot
.754 .09493 Mdot
.754 .09521 Mdot
.754 .09589 Mdot
.754 .09599 Mdot
.754 .09629 Mdot
.754 .09656 Mdot
.754 .0966 Mdot
.754 .09693 Mdot
.754 .0972 Mdot
.754 .09726 Mdot
.754 .09726 Mdot
.754 .09776 Mdot
.754 .09782 Mdot
.754 .09802 Mdot
.754 .09821 Mdot
.754 .09834 Mdot
.754 .09866 Mdot
.754 .09905 Mdot
.754 .09935 Mdot
.754 .10043 Mdot
.754 .10047 Mdot
.754 .10061 Mdot
.754 .10132 Mdot
.754 .10191 Mdot
.754 .10219 Mdot
.754 .10284 Mdot
.754 .10357 Mdot
.754 .10414 Mdot
.754 .10423 Mdot
.754 .10428 Mdot
.754 .10431 Mdot
.754 .10442 Mdot
.754 .10495 Mdot
.754 .10532 Mdot
.754 .10539 Mdot
.754 .10562 Mdot
.754 .10567 Mdot
.754 .10651 Mdot
.754 .10651 Mdot
.754 .10685 Mdot
.754 .1079 Mdot
.754 .108 Mdot
.754 .1083 Mdot
.754 .1091 Mdot
.754 .11028 Mdot
.754 .11044 Mdot
.754 .11074 Mdot
.754 .11122 Mdot
.754 .11122 Mdot
.754 .11152 Mdot
.754 .11166 Mdot
.754 .11244 Mdot
.754 .1126 Mdot
.754 .11275 Mdot
.754 .11294 Mdot
.754 .11331 Mdot
.754 .11335 Mdot
.754 .11347 Mdot
.754 .11349 Mdot
.754 .11351 Mdot
.754 .11353 Mdot
.754 .11376 Mdot
.754 .11394 Mdot
.754 .11467 Mdot
.754 .11519 Mdot
.754 .11523 Mdot
.754 .11585 Mdot
.754 .11612 Mdot
.754 .11671 Mdot
.754 .11683 Mdot
.754 .11689 Mdot
.754 .11708 Mdot
.754 .11724 Mdot
.754 .11826 Mdot
.754 .11847 Mdot
.754 .1196 Mdot
.754 .12001 Mdot
.754 .12003 Mdot
.754 .12005 Mdot
.754 .12073 Mdot
.754 .12076 Mdot
.754 .1218 Mdot
.754 .12183 Mdot
.754 .12214 Mdot
.754 .12223 Mdot
.754 .12252 Mdot
.754 .12259 Mdot
.754 .12275 Mdot
.754 .12282 Mdot
.754 .12311 Mdot
.754 .1239 Mdot
.754 .12439 Mdot
.754 .12461 Mdot
.754 .12482 Mdot
.754 .12543 Mdot
.754 .12552 Mdot
.754 .12583 Mdot
.754 .12615 Mdot
.754 .12635 Mdot
.754 .12642 Mdot
.754 .12669 Mdot
.754 .12749 Mdot
.754 .12785 Mdot
.754 .12929 Mdot
.754 .1294 Mdot
.754 .13004 Mdot
.754 .1307 Mdot
.754 .131 Mdot
.754 .13101 Mdot
.754 .13147 Mdot
.754 .13168 Mdot
.754 .13183 Mdot
.754 .13192 Mdot
.754 .13313 Mdot
.754 .13344 Mdot
.754 .13374 Mdot
.754 .1342 Mdot
.754 .13564 Mdot
.754 .13565 Mdot
.754 .13569 Mdot
.754 .13598 Mdot
.754 .13611 Mdot
.754 .13713 Mdot
.754 .13714 Mdot
.754 .13728 Mdot
.754 .13773 Mdot
.754 .13814 Mdot
.754 .13819 Mdot
.754 .13821 Mdot
.754 .13869 Mdot
.754 .1391 Mdot
.754 .13919 Mdot
.754 .13919 Mdot
.754 .1397 Mdot
.754 .13995 Mdot
.754 .14004 Mdot
.754 .14034 Mdot
.754 .14062 Mdot
.754 .14082 Mdot
.754 .14131 Mdot
.754 .14139 Mdot
.754 .14185 Mdot
.754 .14189 Mdot
.754 .14234 Mdot
.754 .14344 Mdot
.754 .14398 Mdot
.754 .14403 Mdot
.754 .14425 Mdot
.754 .14507 Mdot
.754 .14526 Mdot
.754 .14532 Mdot
.754 .14611 Mdot
.754 .14621 Mdot
.754 .1465 Mdot
.754 .14662 Mdot
.754 .14761 Mdot
.754 .1479 Mdot
.754 .1487 Mdot
.754 .14957 Mdot
.754 .14971 Mdot
.754 .14978 Mdot
.754 .14983 Mdot
.754 .14999 Mdot
.754 .1504 Mdot
.754 .1505 Mdot
.754 .1508 Mdot
.754 .15098 Mdot
.754 .15134 Mdot
.754 .15145 Mdot
.754 .15181 Mdot
.754 .15188 Mdot
.754 .15204 Mdot
.754 .15304 Mdot
.754 .15314 Mdot
.754 .15314 Mdot
.754 .15366 Mdot
.754 .15391 Mdot
.754 .15524 Mdot
.754 .15539 Mdot
.754 .15584 Mdot
.754 .15705 Mdot
.754 .15864 Mdot
.754 .15883 Mdot
.754 .15906 Mdot
.754 .15953 Mdot
.754 .16025 Mdot
.754 .16025 Mdot
.754 .1607 Mdot
.754 .16091 Mdot
.754 .16131 Mdot
.754 .16192 Mdot
.754 .16209 Mdot
.754 .16233 Mdot
.754 .16255 Mdot
.754 .16284 Mdot
.754 .1634 Mdot
.754 .16346 Mdot
.754 .16364 Mdot
.754 .16367 Mdot
.754 .1637 Mdot
.754 .16373 Mdot
.754 .16407 Mdot
.754 .16435 Mdot
.754 .16524 Mdot
.754 .16545 Mdot
.754 .16622 Mdot
.754 .16629 Mdot
.754 .16723 Mdot
.754 .16764 Mdot
.754 .16853 Mdot
.754 .1686 Mdot
.754 .16871 Mdot
.754 .16879 Mdot
.754 .16908 Mdot
.754 .16933 Mdot
.754 .17017 Mdot
.754 .17025 Mdot
.754 .17086 Mdot
.754 .17087 Mdot
.754 .17118 Mdot
.754 .17261 Mdot
.754 .17288 Mdot
.754 .1735 Mdot
.754 .17354 Mdot
.754 .17355 Mdot
.754 .17367 Mdot
.754 .17448 Mdot
.754 .17459 Mdot
.754 .17464 Mdot
.754 .17493 Mdot
.754 .1762 Mdot
.754 .17624 Mdot
.754 .17672 Mdot
.754 .17684 Mdot
.754 .17729 Mdot
.754 .17739 Mdot
.754 .17762 Mdot
.754 .17773 Mdot
.754 .17818 Mdot
.754 .17865 Mdot
.754 .17936 Mdot
.754 .1801 Mdot
.754 .18044 Mdot
.754 .18075 Mdot
.754 .18118 Mdot
.754 .18168 Mdot
.754 .18181 Mdot
.754 .18227 Mdot
.754 .18275 Mdot
.754 .1828 Mdot
.754 .18305 Mdot
.754 .18317 Mdot
.754 .18358 Mdot
.754 .18431 Mdot
.754 .18433 Mdot
.754 .18447 Mdot
.754 .18478 Mdot
.754 .18507 Mdot
.754 .18533 Mdot
.754 .18671 Mdot
.754 .18749 Mdot
.754 .18766 Mdot
.754 .18863 Mdot
.754 .18961 Mdot
.754 .19007 Mdot
.754 .19009 Mdot
.754 .19027 Mdot
.754 .19078 Mdot
.754 .19109 Mdot
.754 .19133 Mdot
.754 .19146 Mdot
.754 .19254 Mdot
.754 .19328 Mdot
.754 .19375 Mdot
.754 .19419 Mdot
.754 .1942 Mdot
.754 .19424 Mdot
.754 .19442 Mdot
.754 .19489 Mdot
.754 .19593 Mdot
.754 .19659 Mdot
.754 .19707 Mdot
.754 .19709 Mdot
.754 .19714 Mdot
.754 .19758 Mdot
.754 .19778 Mdot
.754 .19932 Mdot
.754 .19933 Mdot
.754 .19954 Mdot
.754 .20023 Mdot
.754 .20084 Mdot
.754 .20092 Mdot
.754 .20095 Mdot
.754 .20167 Mdot
.754 .2019 Mdot
.754 .20193 Mdot
.754 .20229 Mdot
.754 .20242 Mdot
.754 .20242 Mdot
.754 .20265 Mdot
.754 .20319 Mdot
.754 .20357 Mdot
.754 .20371 Mdot
.754 .20416 Mdot
.754 .20458 Mdot
.754 .20488 Mdot
.754 .205 Mdot
.754 .20562 Mdot
.754 .20574 Mdot
.754 .20644 Mdot
.754 .20649 Mdot
.754 .20709 Mdot
.754 .20718 Mdot
.754 .20738 Mdot
.754 .20747 Mdot
.754 .20883 Mdot
.754 .20965 Mdot
.754 .20972 Mdot
.754 .20994 Mdot
.754 .21005 Mdot
.754 .21074 Mdot
.754 .21086 Mdot
.754 .21129 Mdot
.754 .21157 Mdot
.754 .21167 Mdot
.754 .21206 Mdot
.754 .21252 Mdot
.754 .21252 Mdot
.754 .21286 Mdot
.754 .21301 Mdot
.754 .2133 Mdot
.754 .21345 Mdot
.754 .21363 Mdot
.754 .21513 Mdot
.754 .21517 Mdot
.754 .21556 Mdot
.754 .21646 Mdot
.754 .21677 Mdot
.754 .21695 Mdot
.754 .21808 Mdot
.754 .21828 Mdot
.754 .21839 Mdot
.754 .21846 Mdot
.754 .21849 Mdot
.754 .21871 Mdot
.754 .21933 Mdot
.754 .21947 Mdot
.754 .21993 Mdot
.754 .21993 Mdot
.754 .2202 Mdot
.754 .22075 Mdot
.754 .22091 Mdot
.754 .22095 Mdot
.754 .22137 Mdot
.754 .22145 Mdot
.754 .22155 Mdot
.754 .2218 Mdot
.754 .22346 Mdot
.754 .22346 Mdot
.754 .22349 Mdot
.754 .22389 Mdot
.754 .22424 Mdot
.754 .22461 Mdot
.754 .2263 Mdot
.754 .22649 Mdot
.754 .22662 Mdot
.754 .22685 Mdot
.754 .22754 Mdot
.754 .22854 Mdot
.754 .22883 Mdot
.754 .22936 Mdot
.754 .22954 Mdot
.754 .22986 Mdot
.754 .23175 Mdot
.754 .23204 Mdot
.754 .23239 Mdot
.754 .23309 Mdot
.754 .23418 Mdot
.754 .23418 Mdot
.754 .23449 Mdot
.754 .23486 Mdot
.754 .23517 Mdot
.754 .23579 Mdot
.754 .2367 Mdot
.754 .23695 Mdot
.754 .2373 Mdot
.754 .23731 Mdot
.754 .23756 Mdot
.754 .23766 Mdot
.754 .23808 Mdot
.754 .23831 Mdot
.754 .2387 Mdot
.754 .23893 Mdot
.754 .23902 Mdot
.754 .23929 Mdot
.754 .23933 Mdot
.754 .23938 Mdot
.754 .23943 Mdot
.754 .23994 Mdot
.754 .24036 Mdot
.754 .24105 Mdot
.754 .24171 Mdot
.754 .24202 Mdot
.754 .24319 Mdot
.754 .24328 Mdot
.754 .2447 Mdot
.754 .24532 Mdot
.754 .24666 Mdot
.754 .24678 Mdot
.754 .24694 Mdot
.754 .24706 Mdot
.754 .2475 Mdot
.754 .24787 Mdot
.754 .24913 Mdot
.754 .24925 Mdot
.754 .25018 Mdot
.754 .25019 Mdot
.754 .25066 Mdot
.754 .25281 Mdot
.754 .25323 Mdot
.754 .25416 Mdot
.754 .25422 Mdot
.754 .25424 Mdot
.754 .25442 Mdot
.754 .25564 Mdot
.754 .25581 Mdot
.754 .25588 Mdot
.754 .25632 Mdot
.754 .25823 Mdot
.754 .2583 Mdot
.754 .25902 Mdot
.754 .25921 Mdot
.754 .25988 Mdot
.754 .26003 Mdot
.754 .26038 Mdot
.754 .26054 Mdot
.754 .26122 Mdot
.754 .26192 Mdot
.754 .263 Mdot
.754 .26412 Mdot
.754 .26463 Mdot
.754 .2651 Mdot
.754 .26575 Mdot
.754 .26649 Mdot
.754 .2667 Mdot
.754 .26739 Mdot
.754 .26811 Mdot
.754 .26819 Mdot
.754 .26857 Mdot
.754 .26874 Mdot
.754 .26936 Mdot
.754 .27046 Mdot
.754 .2705 Mdot
.754 .27071 Mdot
.754 .27118 Mdot
.754 .27162 Mdot
.754 .272 Mdot
.754 .27408 Mdot
.754 .27526 Mdot
.754 .27552 Mdot
.754 .27698 Mdot
.754 .27846 Mdot
.754 .27915 Mdot
.754 .27918 Mdot
.754 .27945 Mdot
.754 .28022 Mdot
.754 .28069 Mdot
.754 .28105 Mdot
.754 .28124 Mdot
.754 .28288 Mdot
.754 .28399 Mdot
.754 .28471 Mdot
.754 .28537 Mdot
.754 .28538 Mdot
.754 .28544 Mdot
.754 .2857 Mdot
.754 .28642 Mdot
.754 .28799 Mdot
.754 .28899 Mdot
.754 .28971 Mdot
.754 .28974 Mdot
.754 .28981 Mdot
.754 .29048 Mdot
.754 .29077 Mdot
.754 .2931 Mdot
.754 .29312 Mdot
.754 .29343 Mdot
.754 .29447 Mdot
.754 .29539 Mdot
.754 .29551 Mdot
.754 .29555 Mdot
.754 .29664 Mdot
.754 .29699 Mdot
.754 .29704 Mdot
.754 .29757 Mdot
.754 .29777 Mdot
.754 .29777 Mdot
.754 .29812 Mdot
.754 .29894 Mdot
.754 .2995 Mdot
.754 .29972 Mdot
.754 .3004 Mdot
.754 .30103 Mdot
.754 .30148 Mdot
.754 .30167 Mdot
.754 .3026 Mdot
.754 .30277 Mdot
.754 .30383 Mdot
.754 .30392 Mdot
.754 .30482 Mdot
.754 .30494 Mdot
.754 .30526 Mdot
.754 .3054 Mdot
.754 .30743 Mdot
.754 .30867 Mdot
.754 .30878 Mdot
.754 .30912 Mdot
.754 .30929 Mdot
.754 .31032 Mdot
.754 .3105 Mdot
.754 .31116 Mdot
.754 .31157 Mdot
.754 .31172 Mdot
.754 .31232 Mdot
.754 .31301 Mdot
.754 .31301 Mdot
.754 .31351 Mdot
.754 .31374 Mdot
.754 .31418 Mdot
.754 .3144 Mdot
.754 .31468 Mdot
.754 .31694 Mdot
.754 .31701 Mdot
.754 .31759 Mdot
.754 .31894 Mdot
.754 .31941 Mdot
.754 .31968 Mdot
.754 .32139 Mdot
.754 .3217 Mdot
.754 .32186 Mdot
.754 .32197 Mdot
.754 .32201 Mdot
.754 .32235 Mdot
.754 .32328 Mdot
.754 .32349 Mdot
.754 .32417 Mdot
.754 .32418 Mdot
.754 .32459 Mdot
.754 .32541 Mdot
.754 .32566 Mdot
.754 .32572 Mdot
.754 .32636 Mdot
.754 .32647 Mdot
.754 .32663 Mdot
.754 .32701 Mdot
.754 .3295 Mdot
.754 .3295 Mdot
.754 .32955 Mdot
.754 .33015 Mdot
.754 .33068 Mdot
.754 .33124 Mdot
.754 .33378 Mdot
.754 .33407 Mdot
.754 .33427 Mdot
.754 .33461 Mdot
.754 .33565 Mdot
.754 .33716 Mdot
.754 .3376 Mdot
.754 .3384 Mdot
.754 .33867 Mdot
.754 .33915 Mdot
.754 .34201 Mdot
.754 .34244 Mdot
.754 .34297 Mdot
.754 .34403 Mdot
.754 .34566 Mdot
.754 .34567 Mdot
.754 .34614 Mdot
.754 .34669 Mdot
.754 .34717 Mdot
.754 .34809 Mdot
.754 .34947 Mdot
.754 .34984 Mdot
.754 .35037 Mdot
.754 .35039 Mdot
.754 .35076 Mdot
.754 .35091 Mdot
.754 .35155 Mdot
.754 .3519 Mdot
.754 .35249 Mdot
.754 .35283 Mdot
.754 .35297 Mdot
.754 .35337 Mdot
.754 .35344 Mdot
.754 .35351 Mdot
.754 .35359 Mdot
.754 .35435 Mdot
.754 .35499 Mdot
.754 .35602 Mdot
.754 .35702 Mdot
.754 .3575 Mdot
.754 .35926 Mdot
.754 .3594 Mdot
.754 .36154 Mdot
.754 .36247 Mdot
.754 .36449 Mdot
.754 .36467 Mdot
.754 .36491 Mdot
.754 .36509 Mdot
.754 .36576 Mdot
.754 .36632 Mdot
.754 .36822 Mdot
.754 .3684 Mdot
.754 .36979 Mdot
.754 .36981 Mdot
.754 .37052 Mdot
.754 .37377 Mdot
.754 .37439 Mdot
.754 .3758 Mdot
.754 .37588 Mdot
.754 .37593 Mdot
.754 .3762 Mdot
.754 .37803 Mdot
.754 .37828 Mdot
.754 .37839 Mdot
.754 .37906 Mdot
.754 .38193 Mdot
.754 .38203 Mdot
.754 .38312 Mdot
.754 .38341 Mdot
.754 .38442 Mdot
.754 .38465 Mdot
.754 .38518 Mdot
.754 .38542 Mdot
.754 .38645 Mdot
.754 .38751 Mdot
.754 .38913 Mdot
.754 .39081 Mdot
.754 .39158 Mdot
.754 .39229 Mdot
.754 .39328 Mdot
.754 .3944 Mdot
.754 .3947 Mdot
.754 .39575 Mdot
.754 .39684 Mdot
.754 .39696 Mdot
.754 .39753 Mdot
.754 .39779 Mdot
.754 .39872 Mdot
.754 .40038 Mdot
.754 .40044 Mdot
.754 .40076 Mdot
.754 .40146 Mdot
.754 .40212 Mdot
.754 .4027 Mdot
.754 .40584 Mdot
.754 .40761 Mdot
.754 .40801 Mdot
.754 .41021 Mdot
.754 .41245 Mdot
.754 .41348 Mdot
.754 .41353 Mdot
.754 .41394 Mdot
.754 .4151 Mdot
.754 .41581 Mdot
.754 .41634 Mdot
.754 .41664 Mdot
.754 .4191 Mdot
.754 .42079 Mdot
.754 .42186 Mdot
.754 .42286 Mdot
.754 .42287 Mdot
.754 .42297 Mdot
.754 .42337 Mdot
.754 .42445 Mdot
.754 .42681 Mdot
.754 .42832 Mdot
.754 .42941 Mdot
.754 .42945 Mdot
.754 .42956 Mdot
.754 .43057 Mdot
.754 .43101 Mdot
.754 .43452 Mdot
.754 .43455 Mdot
.754 .43502 Mdot
.754 .43658 Mdot
.754 .43797 Mdot
.754 .43816 Mdot
.754 .43822 Mdot
.754 .43986 Mdot
.754 .44038 Mdot
.754 .44046 Mdot
.754 .44126 Mdot
.754 .44157 Mdot
.754 .44157 Mdot
.754 .44208 Mdot
.754 .44333 Mdot
.754 .44418 Mdot
.754 .4445 Mdot
.754 .44553 Mdot
.754 .44648 Mdot
.754 .44716 Mdot
.754 .44744 Mdot
.754 .44884 Mdot
.754 .44911 Mdot
.754 .4507 Mdot
.754 .45083 Mdot
.754 .45219 Mdot
.754 .45238 Mdot
.754 .45285 Mdot
.754 .45306 Mdot
.754 .45614 Mdot
.754 .458 Mdot
.754 .45817 Mdot
.754 .45867 Mdot
.754 .45893 Mdot
.754 .46048 Mdot
.756 .01513 Mdot
.756 .01535 Mdot
.756 .01567 Mdot
.756 .01616 Mdot
.756 .01677 Mdot
.756 .01689 Mdot
.756 .01762 Mdot
.756 .01772 Mdot
.756 .01782 Mdot
.756 .01801 Mdot
.756 .01847 Mdot
.756 .01889 Mdot
.756 .01898 Mdot
.756 .0191 Mdot
.756 .01926 Mdot
.756 .01939 Mdot
.756 .01942 Mdot
.756 .01955 Mdot
.756 .0197 Mdot
.756 .02039 Mdot
.756 .02103 Mdot
.756 .02116 Mdot
.756 .02135 Mdot
.756 .02158 Mdot
.756 .02179 Mdot
.756 .02182 Mdot
.756 .02203 Mdot
.756 .02225 Mdot
.756 .0233 Mdot
.756 .02342 Mdot
.756 .02352 Mdot
.756 .02426 Mdot
.756 .02438 Mdot
.756 .02446 Mdot
.756 .02474 Mdot
.756 .0251 Mdot
.756 .02541 Mdot
.756 .02546 Mdot
.756 .02577 Mdot
.756 .0261 Mdot
.756 .02661 Mdot
.756 .02679 Mdot
.756 .02769 Mdot
.756 .02787 Mdot
.756 .02787 Mdot
.756 .02803 Mdot
.756 .02838 Mdot
.756 .02915 Mdot
.756 .02933 Mdot
.756 .02945 Mdot
.756 .02988 Mdot
.756 .0304 Mdot
.756 .03041 Mdot
.756 .03089 Mdot
.756 .03097 Mdot
.756 .03123 Mdot
.756 .03144 Mdot
.756 .03193 Mdot
.756 .03198 Mdot
.756 .0327 Mdot
.756 .03297 Mdot
.756 .03433 Mdot
.756 .03461 Mdot
.756 .03461 Mdot
.756 .03484 Mdot
.756 .03538 Mdot
.756 .03655 Mdot
.756 .03671 Mdot
.756 .03682 Mdot
.756 .037 Mdot
.756 .03764 Mdot
.756 .03796 Mdot
.756 .03843 Mdot
.756 .03845 Mdot
.756 .03916 Mdot
.756 .03929 Mdot
.756 .0393 Mdot
.756 .03941 Mdot
.756 .03969 Mdot
.756 .04 Mdot
.756 .04075 Mdot
.756 .04082 Mdot
.756 .04191 Mdot
.756 .04232 Mdot
.756 .04293 Mdot
.756 .04386 Mdot
.756 .04414 Mdot
.756 .04424 Mdot
.756 .04438 Mdot
.756 .04451 Mdot
.756 .04472 Mdot
.756 .04479 Mdot
.756 .0448 Mdot
.756 .04515 Mdot
.756 .04523 Mdot
.756 .04597 Mdot
.756 .04723 Mdot
.756 .04772 Mdot
.756 .04798 Mdot
.756 .04813 Mdot
.756 .04841 Mdot
.756 .04866 Mdot
.756 .04866 Mdot
.756 .04938 Mdot
.756 .04979 Mdot
.756 .04986 Mdot
.756 .0503 Mdot
.756 .05057 Mdot
.756 .0506 Mdot
.756 .05168 Mdot
.756 .05187 Mdot
.756 .05188 Mdot
.756 .05205 Mdot
.756 .05248 Mdot
.756 .05249 Mdot
.756 .05252 Mdot
.756 .05294 Mdot
.756 .05328 Mdot
.756 .05408 Mdot
.756 .05419 Mdot
.756 .05464 Mdot
.756 .05469 Mdot
.756 .05507 Mdot
.756 .05547 Mdot
.756 .05583 Mdot
.756 .05605 Mdot
.756 .05645 Mdot
.756 .05737 Mdot
.756 .05845 Mdot
.756 .05878 Mdot
.756 .05895 Mdot
.756 .0592 Mdot
.756 .05935 Mdot
.756 .05943 Mdot
.756 .05957 Mdot
.756 .05976 Mdot
.756 .06008 Mdot
.756 .06019 Mdot
.756 .0602 Mdot
.756 .06073 Mdot
.756 .06085 Mdot
.756 .06088 Mdot
.756 .06091 Mdot
.756 .06158 Mdot
.756 .06191 Mdot
.756 .06197 Mdot
.756 .06241 Mdot
.756 .06325 Mdot
.756 .06387 Mdot
.756 .06413 Mdot
.756 .06416 Mdot
.756 .06445 Mdot
.756 .06462 Mdot
.756 .06501 Mdot
.756 .06524 Mdot
.756 .06566 Mdot
.756 .06603 Mdot
.756 .06604 Mdot
.756 .0663 Mdot
.756 .06712 Mdot
.756 .06774 Mdot
.756 .06786 Mdot
.756 .06851 Mdot
.756 .06893 Mdot
.756 .06898 Mdot
.756 .0691 Mdot
.756 .07061 Mdot
.756 .07089 Mdot
.756 .07091 Mdot
.756 .07108 Mdot
.756 .07112 Mdot
.756 .07116 Mdot
.756 .07117 Mdot
.756 .07166 Mdot
.756 .07182 Mdot
.756 .07183 Mdot
.756 .07188 Mdot
.756 .0724 Mdot
.756 .07251 Mdot
.756 .07302 Mdot
.756 .07423 Mdot
.756 .0744 Mdot
.756 .07509 Mdot
.756 .07515 Mdot
.756 .07558 Mdot
.756 .07573 Mdot
.756 .07617 Mdot
.756 .07634 Mdot
.756 .0764 Mdot
.756 .07652 Mdot
.756 .07689 Mdot
.756 .07722 Mdot
.756 .07732 Mdot
.756 .07782 Mdot
.756 .07843 Mdot
.756 .07921 Mdot
.756 .07951 Mdot
.756 .0797 Mdot
.756 .0801 Mdot
.756 .08069 Mdot
.756 .08084 Mdot
.756 .08086 Mdot
.756 .08117 Mdot
.756 .08134 Mdot
.756 .08159 Mdot
.756 .08198 Mdot
.756 .0822 Mdot
.756 .08232 Mdot
.756 .08253 Mdot
.756 .08283 Mdot
.756 .08317 Mdot
.756 .0832 Mdot
.756 .08331 Mdot
.756 .08348 Mdot
.756 .08349 Mdot
.756 .08361 Mdot
.756 .08429 Mdot
.756 .08437 Mdot
.756 .08447 Mdot
.756 .08451 Mdot
.756 .08456 Mdot
.756 .08468 Mdot
.756 .08492 Mdot
.756 .08516 Mdot
.756 .08545 Mdot
.756 .08558 Mdot
.756 .08608 Mdot
.756 .08616 Mdot
.756 .08637 Mdot
.756 .08682 Mdot
.756 .08734 Mdot
.756 .08755 Mdot
.756 .08757 Mdot
.756 .0881 Mdot
.756 .08904 Mdot
.756 .08904 Mdot
.756 .08943 Mdot
.756 .08948 Mdot
.756 .08991 Mdot
.756 .09018 Mdot
.756 .09022 Mdot
.756 .09031 Mdot
.756 .09076 Mdot
.756 .09111 Mdot
.756 .09175 Mdot
.756 .09231 Mdot
.756 .09232 Mdot
.756 .09271 Mdot
.756 .09281 Mdot
.756 .09396 Mdot
.756 .09418 Mdot
.756 .09489 Mdot
.756 .09507 Mdot
.756 .09591 Mdot
.756 .09606 Mdot
.756 .09615 Mdot
.756 .09669 Mdot
.756 .09676 Mdot
.756 .09695 Mdot
.756 .09916 Mdot
.756 .09923 Mdot
.756 .09944 Mdot
.756 .09965 Mdot
.756 .09969 Mdot
.756 .09993 Mdot
.756 .1 Mdot
.756 .10007 Mdot
.756 .10007 Mdot
.756 .10081 Mdot
.756 .10097 Mdot
.756 .10105 Mdot
.756 .10107 Mdot
.756 .10115 Mdot
.756 .10192 Mdot
.756 .10194 Mdot
.756 .1021 Mdot
.756 .10287 Mdot
.756 .10356 Mdot
.756 .10446 Mdot
.756 .1047 Mdot
.756 .10496 Mdot
.756 .10588 Mdot
.756 .106 Mdot
.756 .10609 Mdot
.756 .10675 Mdot
.756 .10697 Mdot
.756 .10763 Mdot
.756 .10789 Mdot
.756 .10798 Mdot
.756 .10805 Mdot
.756 .10816 Mdot
.756 .10862 Mdot
.756 .10872 Mdot
.756 .10881 Mdot
.756 .10909 Mdot
.756 .10922 Mdot
.756 .10938 Mdot
.756 .10972 Mdot
.756 .11012 Mdot
.756 .11104 Mdot
.756 .11105 Mdot
.756 .11115 Mdot
.756 .1119 Mdot
.756 .11208 Mdot
.756 .11223 Mdot
.756 .11269 Mdot
.756 .11297 Mdot
.756 .11358 Mdot
.756 .11369 Mdot
.756 .11379 Mdot
.756 .11448 Mdot
.756 .1147 Mdot
.756 .11472 Mdot
.756 .1152 Mdot
.756 .11546 Mdot
.756 .11579 Mdot
.756 .11584 Mdot
.756 .11641 Mdot
.756 .11676 Mdot
.756 .11694 Mdot
.756 .11725 Mdot
.756 .11743 Mdot
.756 .1177 Mdot
.756 .11811 Mdot
.756 .11822 Mdot
.756 .11826 Mdot
.756 .11843 Mdot
.756 .11868 Mdot
.756 .11871 Mdot
.756 .11885 Mdot
.756 .11888 Mdot
.756 .11919 Mdot
.756 .11959 Mdot
.756 .11991 Mdot
.756 .12004 Mdot
.756 .12018 Mdot
.756 .12024 Mdot
.756 .12032 Mdot
.756 .1205 Mdot
.756 .1205 Mdot
.756 .12054 Mdot
.756 .12073 Mdot
.756 .12086 Mdot
.756 .12122 Mdot
.756 .12167 Mdot
.756 .12172 Mdot
.756 .12186 Mdot
.756 .12241 Mdot
.756 .12262 Mdot
.756 .12274 Mdot
.756 .12306 Mdot
.756 .12374 Mdot
.756 .1243 Mdot
.756 .12452 Mdot
.756 .12482 Mdot
.756 .12484 Mdot
.756 .12488 Mdot
.756 .12567 Mdot
.756 .12656 Mdot
.756 .12661 Mdot
.756 .12664 Mdot
.756 .12688 Mdot
.756 .12709 Mdot
.756 .12709 Mdot
.756 .12761 Mdot
.756 .12769 Mdot
.756 .12775 Mdot
.756 .12842 Mdot
.756 .12881 Mdot
.756 .12887 Mdot
.756 .12902 Mdot
.756 .12969 Mdot
.756 .13023 Mdot
.756 .13049 Mdot
.756 .13119 Mdot
.756 .1316 Mdot
.756 .13204 Mdot
.756 .13206 Mdot
.756 .13221 Mdot
.756 .13264 Mdot
.756 .1328 Mdot
.756 .13392 Mdot
.756 .13395 Mdot
.756 .13453 Mdot
.756 .13486 Mdot
.756 .13594 Mdot
.756 .13621 Mdot
.756 .13748 Mdot
.756 .13771 Mdot
.756 .13784 Mdot
.756 .13867 Mdot
.756 .13877 Mdot
.756 .13905 Mdot
.756 .14039 Mdot
.756 .14153 Mdot
.756 .14181 Mdot
.756 .14222 Mdot
.756 .1424 Mdot
.756 .1425 Mdot
.756 .14281 Mdot
.756 .14309 Mdot
.756 .14314 Mdot
.756 .14319 Mdot
.756 .14321 Mdot
.756 .1434 Mdot
.756 .14357 Mdot
.756 .14367 Mdot
.756 .14377 Mdot
.756 .14377 Mdot
.756 .14489 Mdot
.756 .14492 Mdot
.756 .14514 Mdot
.756 .14526 Mdot
.756 .14528 Mdot
.756 .1454 Mdot
.756 .14657 Mdot
.756 .1466 Mdot
.756 .14685 Mdot
.756 .14754 Mdot
.756 .14801 Mdot
.756 .14905 Mdot
.756 .15042 Mdot
.756 .15078 Mdot
.756 .15116 Mdot
.756 .15119 Mdot
.756 .15221 Mdot
.756 .15248 Mdot
.756 .15256 Mdot
.756 .15259 Mdot
.756 .15267 Mdot
.756 .15273 Mdot
.756 .15288 Mdot
.756 .15387 Mdot
.756 .15387 Mdot
.756 .1542 Mdot
.756 .15498 Mdot
.756 .15499 Mdot
.756 .15521 Mdot
.756 .1556 Mdot
.756 .15561 Mdot
.756 .15572 Mdot
.756 .15584 Mdot
.756 .15601 Mdot
.756 .1567 Mdot
.756 .15685 Mdot
.756 .15699 Mdot
.756 .15742 Mdot
.756 .15761 Mdot
.756 .15771 Mdot
.756 .15785 Mdot
.756 .15809 Mdot
.756 .15836 Mdot
.756 .15844 Mdot
.756 .15897 Mdot
.756 .16036 Mdot
.756 .16037 Mdot
.756 .16052 Mdot
.756 .16166 Mdot
.756 .1619 Mdot
.756 .16193 Mdot
.756 .16216 Mdot
.756 .16248 Mdot
.756 .16285 Mdot
.756 .16328 Mdot
.756 .16398 Mdot
.756 .1642 Mdot
.756 .16429 Mdot
.756 .16436 Mdot
.756 .16452 Mdot
.756 .16506 Mdot
.756 .16555 Mdot
.756 .16589 Mdot
.756 .16592 Mdot
.756 .16665 Mdot
.756 .16704 Mdot
.756 .16754 Mdot
.756 .16761 Mdot
.756 .16848 Mdot
.756 .16856 Mdot
.756 .16901 Mdot
.756 .16928 Mdot
.756 .16975 Mdot
.756 .17002 Mdot
.756 .17043 Mdot
.756 .17105 Mdot
.756 .17122 Mdot
.756 .17127 Mdot
.756 .17135 Mdot
.756 .17153 Mdot
.756 .17192 Mdot
.756 .17195 Mdot
.756 .17217 Mdot
.756 .17222 Mdot
.756 .17268 Mdot
.756 .17271 Mdot
.756 .17329 Mdot
.756 .17377 Mdot
.756 .17396 Mdot
.756 .17418 Mdot
.756 .17428 Mdot
.756 .17439 Mdot
.756 .17466 Mdot
.756 .17467 Mdot
.756 .17472 Mdot
.756 .17501 Mdot
.756 .17521 Mdot
.756 .17575 Mdot
.756 .1759 Mdot
.756 .17641 Mdot
.756 .17642 Mdot
.756 .17643 Mdot
.756 .1765 Mdot
.756 .17671 Mdot
.756 .17754 Mdot
.756 .17787 Mdot
.756 .17804 Mdot
.756 .17854 Mdot
.756 .17855 Mdot
.756 .17957 Mdot
.756 .18041 Mdot
.756 .18074 Mdot
.756 .18082 Mdot
.756 .18094 Mdot
.756 .18119 Mdot
.756 .18122 Mdot
.756 .18128 Mdot
.756 .18172 Mdot
.756 .18248 Mdot
.756 .18353 Mdot
.756 .18383 Mdot
.756 .18391 Mdot
.756 .18394 Mdot
.756 .18396 Mdot
.756 .18431 Mdot
.756 .18463 Mdot
.756 .18463 Mdot
.756 .18481 Mdot
.756 .18542 Mdot
.756 .18553 Mdot
.756 .18563 Mdot
.756 .18663 Mdot
.756 .1868 Mdot
.756 .18723 Mdot
.756 .18732 Mdot
.756 .18755 Mdot
.756 .18856 Mdot
.756 .18937 Mdot
.756 .18976 Mdot
.756 .19068 Mdot
.756 .19083 Mdot
.756 .19083 Mdot
.756 .19145 Mdot
.756 .1921 Mdot
.756 .19214 Mdot
.756 .19237 Mdot
.756 .19289 Mdot
.756 .19301 Mdot
.756 .19326 Mdot
.756 .19383 Mdot
.756 .19496 Mdot
.756 .195 Mdot
.756 .1956 Mdot
.756 .19587 Mdot
.756 .19638 Mdot
.756 .19801 Mdot
.756 .19841 Mdot
.756 .20034 Mdot
.756 .20068 Mdot
.756 .20089 Mdot
.756 .20124 Mdot
.756 .20213 Mdot
.756 .20229 Mdot
.756 .20261 Mdot
.756 .20272 Mdot
.756 .20474 Mdot
.756 .20647 Mdot
.756 .20688 Mdot
.756 .20751 Mdot
.756 .20777 Mdot
.756 .20793 Mdot
.756 .2084 Mdot
.756 .20882 Mdot
.756 .2089 Mdot
.756 .20897 Mdot
.756 .20899 Mdot
.756 .20929 Mdot
.756 .20929 Mdot
.756 .20954 Mdot
.756 .20969 Mdot
.756 .20984 Mdot
.756 .20984 Mdot
.756 .21045 Mdot
.756 .21117 Mdot
.756 .21154 Mdot
.756 .21159 Mdot
.756 .21191 Mdot
.756 .2121 Mdot
.756 .21214 Mdot
.756 .21232 Mdot
.756 .21239 Mdot
.756 .21408 Mdot
.756 .21412 Mdot
.756 .2145 Mdot
.756 .21547 Mdot
.756 .21555 Mdot
.756 .21603 Mdot
.756 .21625 Mdot
.756 .21713 Mdot
.756 .2175 Mdot
.756 .21782 Mdot
.756 .21989 Mdot
.756 .22044 Mdot
.756 .22102 Mdot
.756 .22107 Mdot
.756 .22261 Mdot
.756 .22302 Mdot
.756 .22314 Mdot
.756 .22318 Mdot
.756 .2233 Mdot
.756 .2234 Mdot
.756 .22362 Mdot
.756 .22449 Mdot
.756 .22512 Mdot
.756 .22512 Mdot
.756 .22561 Mdot
.756 .22679 Mdot
.756 .22681 Mdot
.756 .22714 Mdot
.756 .22774 Mdot
.756 .22775 Mdot
.756 .22792 Mdot
.756 .2281 Mdot
.756 .22835 Mdot
.756 .2294 Mdot
.756 .22962 Mdot
.756 .22983 Mdot
.756 .23046 Mdot
.756 .23048 Mdot
.756 .23077 Mdot
.756 .23092 Mdot
.756 .23113 Mdot
.756 .2315 Mdot
.756 .23189 Mdot
.756 .2319 Mdot
.756 .23203 Mdot
.756 .23283 Mdot
.756 .23406 Mdot
.756 .23493 Mdot
.756 .23494 Mdot
.756 .23496 Mdot
.756 .23518 Mdot
.756 .23551 Mdot
.756 .2369 Mdot
.756 .23715 Mdot
.756 .23725 Mdot
.756 .23731 Mdot
.756 .23766 Mdot
.756 .23814 Mdot
.756 .23861 Mdot
.756 .2387 Mdot
.756 .23887 Mdot
.756 .23913 Mdot
.756 .2392 Mdot
.756 .23934 Mdot
.756 .24022 Mdot
.756 .24023 Mdot
.756 .24041 Mdot
.756 .24074 Mdot
.756 .24087 Mdot
.756 .24098 Mdot
.756 .24108 Mdot
.756 .24121 Mdot
.756 .24162 Mdot
.756 .24204 Mdot
.756 .24213 Mdot
.756 .24214 Mdot
.756 .24278 Mdot
.756 .2433 Mdot
.756 .24334 Mdot
.756 .24443 Mdot
.756 .24503 Mdot
.756 .24579 Mdot
.756 .24589 Mdot
.756 .24721 Mdot
.756 .24733 Mdot
.756 .248 Mdot
.756 .24842 Mdot
.756 .24913 Mdot
.756 .24953 Mdot
.756 .25015 Mdot
.756 .2511 Mdot
.756 .25135 Mdot
.756 .25143 Mdot
.756 .25155 Mdot
.756 .25183 Mdot
.756 .25241 Mdot
.756 .25245 Mdot
.756 .25278 Mdot
.756 .25286 Mdot
.756 .25356 Mdot
.756 .25361 Mdot
.756 .25448 Mdot
.756 .2552 Mdot
.756 .2555 Mdot
.756 .25582 Mdot
.756 .25597 Mdot
.756 .25615 Mdot
.756 .25654 Mdot
.756 .25656 Mdot
.756 .25664 Mdot
.756 .25708 Mdot
.756 .25738 Mdot
.756 .25821 Mdot
.756 .25843 Mdot
.756 .2592 Mdot
.756 .25922 Mdot
.756 .25923 Mdot
.756 .25933 Mdot
.756 .25966 Mdot
.756 .26091 Mdot
.756 .2614 Mdot
.756 .26167 Mdot
.756 .26242 Mdot
.756 .26243 Mdot
.756 .26524 Mdot
.756 .26574 Mdot
.756 .26586 Mdot
.756 .26605 Mdot
.756 .26643 Mdot
.756 .26648 Mdot
.756 .26656 Mdot
.756 .26723 Mdot
.756 .26837 Mdot
.756 .26997 Mdot
.756 .27042 Mdot
.756 .27053 Mdot
.756 .27058 Mdot
.756 .27062 Mdot
.756 .27114 Mdot
.756 .27163 Mdot
.756 .27163 Mdot
.756 .2719 Mdot
.756 .27282 Mdot
.756 .27299 Mdot
.756 .27314 Mdot
.756 .27465 Mdot
.756 .27491 Mdot
.756 .27556 Mdot
.756 .2757 Mdot
.756 .27604 Mdot
.756 .27757 Mdot
.756 .27879 Mdot
.756 .27938 Mdot
.756 .28078 Mdot
.756 .281 Mdot
.756 .28101 Mdot
.756 .28193 Mdot
.756 .28293 Mdot
.756 .28298 Mdot
.756 .28332 Mdot
.756 .28412 Mdot
.756 .2843 Mdot
.756 .28468 Mdot
.756 .28554 Mdot
.756 .28724 Mdot
.756 .28731 Mdot
.756 .28821 Mdot
.756 .28862 Mdot
.756 .28939 Mdot
.756 .29186 Mdot
.756 .29246 Mdot
.756 .29538 Mdot
.756 .29589 Mdot
.756 .2962 Mdot
.756 .29674 Mdot
.756 .29809 Mdot
.756 .29833 Mdot
.756 .29881 Mdot
.756 .29897 Mdot
.756 .30203 Mdot
.756 .30464 Mdot
.756 .30527 Mdot
.756 .30622 Mdot
.756 .30661 Mdot
.756 .30685 Mdot
.756 .30757 Mdot
.756 .30821 Mdot
.756 .30832 Mdot
.756 .30844 Mdot
.756 .30847 Mdot
.756 .30891 Mdot
.756 .30891 Mdot
.756 .30929 Mdot
.756 .30952 Mdot
.756 .30975 Mdot
.756 .30975 Mdot
.756 .31067 Mdot
.756 .31176 Mdot
.756 .31231 Mdot
.756 .31238 Mdot
.756 .31288 Mdot
.756 .31316 Mdot
.756 .31322 Mdot
.756 .31349 Mdot
.756 .3136 Mdot
.756 .31615 Mdot
.756 .31622 Mdot
.756 .31679 Mdot
.756 .31826 Mdot
.756 .31838 Mdot
.756 .3191 Mdot
.756 .31944 Mdot
.756 .32077 Mdot
.756 .32132 Mdot
.756 .32182 Mdot
.756 .32495 Mdot
.756 .32577 Mdot
.756 .32665 Mdot
.756 .32673 Mdot
.756 .32905 Mdot
.756 .32967 Mdot
.756 .32985 Mdot
.756 .32992 Mdot
.756 .3301 Mdot
.756 .33024 Mdot
.756 .33058 Mdot
.756 .3319 Mdot
.756 .33284 Mdot
.756 .33285 Mdot
.756 .33359 Mdot
.756 .33538 Mdot
.756 .3354 Mdot
.756 .3359 Mdot
.756 .3368 Mdot
.756 .33683 Mdot
.756 .33708 Mdot
.756 .33735 Mdot
.756 .33774 Mdot
.756 .33932 Mdot
.756 .33965 Mdot
.756 .33997 Mdot
.756 .34093 Mdot
.756 .34095 Mdot
.756 .34139 Mdot
.756 .34161 Mdot
.756 .34194 Mdot
.756 .3425 Mdot
.756 .34308 Mdot
.756 .3431 Mdot
.756 .34329 Mdot
.756 .34451 Mdot
.756 .34637 Mdot
.756 .34767 Mdot
.756 .3477 Mdot
.756 .34773 Mdot
.756 .34806 Mdot
.756 .34855 Mdot
.756 .35065 Mdot
.756 .35104 Mdot
.756 .35119 Mdot
.756 .35127 Mdot
.756 .3518 Mdot
.756 .35253 Mdot
.756 .35325 Mdot
.756 .35337 Mdot
.756 .35364 Mdot
.756 .35403 Mdot
.756 .35414 Mdot
.756 .35435 Mdot
.756 .35567 Mdot
.756 .35569 Mdot
.756 .35596 Mdot
.756 .35647 Mdot
.756 .35667 Mdot
.756 .35683 Mdot
.756 .35698 Mdot
.756 .35718 Mdot
.756 .35779 Mdot
.756 .35843 Mdot
.756 .35857 Mdot
.756 .35858 Mdot
.756 .35955 Mdot
.756 .36033 Mdot
.756 .3604 Mdot
.756 .36205 Mdot
.756 .36295 Mdot
.756 .3641 Mdot
.756 .36425 Mdot
.756 .36625 Mdot
.756 .36643 Mdot
.756 .36745 Mdot
.756 .36807 Mdot
.756 .36916 Mdot
.756 .36975 Mdot
.756 .37069 Mdot
.756 .37213 Mdot
.756 .3725 Mdot
.756 .37263 Mdot
.756 .37282 Mdot
.756 .37323 Mdot
.756 .3741 Mdot
.756 .37418 Mdot
.756 .37467 Mdot
.756 .37479 Mdot
.756 .37585 Mdot
.756 .37592 Mdot
.756 .37724 Mdot
.756 .37833 Mdot
.756 .37878 Mdot
.756 .37927 Mdot
.756 .37949 Mdot
.756 .37976 Mdot
.756 .38036 Mdot
.756 .38039 Mdot
.756 .38051 Mdot
.756 .38116 Mdot
.756 .38162 Mdot
.756 .38287 Mdot
.756 .38322 Mdot
.756 .38437 Mdot
.756 .3844 Mdot
.756 .38442 Mdot
.756 .38458 Mdot
.756 .38506 Mdot
.756 .38696 Mdot
.756 .3877 Mdot
.756 .3881 Mdot
.756 .38924 Mdot
.756 .38926 Mdot
.756 .39352 Mdot
.756 .39427 Mdot
.756 .39445 Mdot
.756 .39473 Mdot
.756 .3953 Mdot
.756 .39538 Mdot
.756 .39551 Mdot
.756 .39651 Mdot
.756 .39825 Mdot
.756 .40066 Mdot
.756 .40133 Mdot
.756 .40151 Mdot
.756 .40158 Mdot
.756 .40164 Mdot
.756 .40243 Mdot
.756 .40316 Mdot
.756 .40317 Mdot
.756 .40358 Mdot
.756 .40497 Mdot
.756 .40522 Mdot
.756 .40545 Mdot
.756 .40774 Mdot
.756 .40813 Mdot
.756 .40912 Mdot
.756 .40932 Mdot
.756 .40983 Mdot
.756 .41215 Mdot
.756 .41399 Mdot
.756 .41489 Mdot
.756 .417 Mdot
.756 .41734 Mdot
.756 .41735 Mdot
.756 .41875 Mdot
.756 .42025 Mdot
.756 .42033 Mdot
.756 .42085 Mdot
.756 .42205 Mdot
.756 .42233 Mdot
.756 .42289 Mdot
.756 .42421 Mdot
.756 .42678 Mdot
.756 .42688 Mdot
.756 .42824 Mdot
.756 .42886 Mdot
.756 .43003 Mdot
.756 .43376 Mdot
.756 .43467 Mdot
.756 .43908 Mdot
.756 .43985 Mdot
.756 .44033 Mdot
.756 .44113 Mdot
.756 .44317 Mdot
.756 .44354 Mdot
.756 .44427 Mdot
.756 .44451 Mdot
.756 .44914 Mdot
.756 .45309 Mdot
.756 .45403 Mdot
.756 .45547 Mdot
.756 .45606 Mdot
.756 .45642 Mdot
.756 .45751 Mdot
.756 .45848 Mdot
.756 .45865 Mdot
.756 .45882 Mdot
.756 .45887 Mdot
.756 .45954 Mdot
.756 .45954 Mdot
.756 .46011 Mdot
.756 .46046 Mdot
.756 .4608 Mdot
.756 .46081 Mdot
.758 .01566 Mdot
.758 .01615 Mdot
.758 .01625 Mdot
.758 .01689 Mdot
.758 .01704 Mdot
.758 .0171 Mdot
.758 .01716 Mdot
.758 .01768 Mdot
.758 .01801 Mdot
.758 .01824 Mdot
.758 .01834 Mdot
.758 .01842 Mdot
.758 .0192 Mdot
.758 .01971 Mdot
.758 .02006 Mdot
.758 .0202 Mdot
.758 .02034 Mdot
.758 .02057 Mdot
.758 .02082 Mdot
.758 .02152 Mdot
.758 .02202 Mdot
.758 .02228 Mdot
.758 .02282 Mdot
.758 .02304 Mdot
.758 .02324 Mdot
.758 .0236 Mdot
.758 .02397 Mdot
.758 .02487 Mdot
.758 .02503 Mdot
.758 .02514 Mdot
.758 .02561 Mdot
.758 .02579 Mdot
.758 .02594 Mdot
.758 .02619 Mdot
.758 .02701 Mdot
.758 .02733 Mdot
.758 .02746 Mdot
.758 .02764 Mdot
.758 .02818 Mdot
.758 .02828 Mdot
.758 .02875 Mdot
.758 .02888 Mdot
.758 .03011 Mdot
.758 .03035 Mdot
.758 .03052 Mdot
.758 .03124 Mdot
.758 .03151 Mdot
.758 .03173 Mdot
.758 .03183 Mdot
.758 .0321 Mdot
.758 .03263 Mdot
.758 .0328 Mdot
.758 .03327 Mdot
.758 .03335 Mdot
.758 .03384 Mdot
.758 .03398 Mdot
.758 .03403 Mdot
.758 .0343 Mdot
.758 .03489 Mdot
.758 .035 Mdot
.758 .03513 Mdot
.758 .03528 Mdot
.758 .03551 Mdot
.758 .036 Mdot
.758 .03604 Mdot
.758 .03619 Mdot
.758 .03706 Mdot
.758 .03738 Mdot
.758 .03762 Mdot
.758 .03805 Mdot
.758 .03842 Mdot
.758 .03868 Mdot
.758 .03976 Mdot
.758 .04012 Mdot
.758 .04017 Mdot
.758 .04052 Mdot
.758 .04067 Mdot
.758 .04108 Mdot
.758 .04111 Mdot
.758 .04128 Mdot
.758 .0417 Mdot
.758 .04187 Mdot
.758 .04212 Mdot
.758 .04241 Mdot
.758 .04284 Mdot
.758 .04296 Mdot
.758 .04371 Mdot
.758 .04391 Mdot
.758 .044 Mdot
.758 .04407 Mdot
.758 .04441 Mdot
.758 .0453 Mdot
.758 .04547 Mdot
.758 .04567 Mdot
.758 .04584 Mdot
.758 .0459 Mdot
.758 .04623 Mdot
.758 .04698 Mdot
.758 .04705 Mdot
.758 .04726 Mdot
.758 .04775 Mdot
.758 .04826 Mdot
.758 .04859 Mdot
.758 .04892 Mdot
.758 .04908 Mdot
.758 .04944 Mdot
.758 .04994 Mdot
.758 .05009 Mdot
.758 .05045 Mdot
.758 .05065 Mdot
.758 .05104 Mdot
.758 .05122 Mdot
.758 .0516 Mdot
.758 .05172 Mdot
.758 .05188 Mdot
.758 .05214 Mdot
.758 .05269 Mdot
.758 .05323 Mdot
.758 .0533 Mdot
.758 .05383 Mdot
.758 .05406 Mdot
.758 .05468 Mdot
.758 .05472 Mdot
.758 .05499 Mdot
.758 .05539 Mdot
.758 .05562 Mdot
.758 .05588 Mdot
.758 .05589 Mdot
.758 .05627 Mdot
.758 .05631 Mdot
.758 .05668 Mdot
.758 .0567 Mdot
.758 .05673 Mdot
.758 .05735 Mdot
.758 .05754 Mdot
.758 .05797 Mdot
.758 .05867 Mdot
.758 .05879 Mdot
.758 .05879 Mdot
.758 .05898 Mdot
.758 .05899 Mdot
.758 .05912 Mdot
.758 .05921 Mdot
.758 .05973 Mdot
.758 .06027 Mdot
.758 .06059 Mdot
.758 .06109 Mdot
.758 .0611 Mdot
.758 .06134 Mdot
.758 .06162 Mdot
.758 .06164 Mdot
.758 .06169 Mdot
.758 .0619 Mdot
.758 .06198 Mdot
.758 .0625 Mdot
.758 .06307 Mdot
.758 .06363 Mdot
.758 .06373 Mdot
.758 .06406 Mdot
.758 .0648 Mdot
.758 .06481 Mdot
.758 .06557 Mdot
.758 .06579 Mdot
.758 .06607 Mdot
.758 .06622 Mdot
.758 .06624 Mdot
.758 .06658 Mdot
.758 .06682 Mdot
.758 .06737 Mdot
.758 .06811 Mdot
.758 .06835 Mdot
.758 .06889 Mdot
.758 .0692 Mdot
.758 .06979 Mdot
.758 .07005 Mdot
.758 .07064 Mdot
.758 .07081 Mdot
.758 .07089 Mdot
.758 .07106 Mdot
.758 .07143 Mdot
.758 .07146 Mdot
.758 .07229 Mdot
.758 .07239 Mdot
.758 .07283 Mdot
.758 .07295 Mdot
.758 .0731 Mdot
.758 .07321 Mdot
.758 .07323 Mdot
.758 .07336 Mdot
.758 .07401 Mdot
.758 .07415 Mdot
.758 .07436 Mdot
.758 .0753 Mdot
.758 .07537 Mdot
.758 .07577 Mdot
.758 .07584 Mdot
.758 .0761 Mdot
.758 .07638 Mdot
.758 .07649 Mdot
.758 .07673 Mdot
.758 .07713 Mdot
.758 .07713 Mdot
.758 .07771 Mdot
.758 .07778 Mdot
.758 .0779 Mdot
.758 .07833 Mdot
.758 .07836 Mdot
.758 .07841 Mdot
.758 .07936 Mdot
.758 .07961 Mdot
.758 .07964 Mdot
.758 .08004 Mdot
.758 .08018 Mdot
.758 .08029 Mdot
.758 .08135 Mdot
.758 .08153 Mdot
.758 .08154 Mdot
.758 .08182 Mdot
.758 .08183 Mdot
.758 .08203 Mdot
.758 .08217 Mdot
.758 .08296 Mdot
.758 .08377 Mdot
.758 .08408 Mdot
.758 .08426 Mdot
.758 .08502 Mdot
.758 .08504 Mdot
.758 .08523 Mdot
.758 .0854 Mdot
.758 .08583 Mdot
.758 .08585 Mdot
.758 .08593 Mdot
.758 .08614 Mdot
.758 .08625 Mdot
.758 .08634 Mdot
.758 .08638 Mdot
.758 .08652 Mdot
.758 .08715 Mdot
.758 .08802 Mdot
.758 .08886 Mdot
.758 .08903 Mdot
.758 .08952 Mdot
.758 .08956 Mdot
.758 .09039 Mdot
.758 .09064 Mdot
.758 .09066 Mdot
.758 .09066 Mdot
.758 .09159 Mdot
.758 .09174 Mdot
.758 .0918 Mdot
.758 .09215 Mdot
.758 .09257 Mdot
.758 .09267 Mdot
.758 .0928 Mdot
.758 .09283 Mdot
.758 .09334 Mdot
.758 .0937 Mdot
.758 .09453 Mdot
.758 .09566 Mdot
.758 .09602 Mdot
.758 .09649 Mdot
.758 .09685 Mdot
.758 .09704 Mdot
.758 .09731 Mdot
.758 .09745 Mdot
.758 .09821 Mdot
.758 .09861 Mdot
.758 .09949 Mdot
.758 .09976 Mdot
.758 .09987 Mdot
.758 .10004 Mdot
.758 .10014 Mdot
.758 .10069 Mdot
.758 .10074 Mdot
.758 .1015 Mdot
.758 .10155 Mdot
.758 .10199 Mdot
.758 .10215 Mdot
.758 .10282 Mdot
.758 .103 Mdot
.758 .10323 Mdot
.758 .1034 Mdot
.758 .10342 Mdot
.758 .10362 Mdot
.758 .10381 Mdot
.758 .10392 Mdot
.758 .10461 Mdot
.758 .10469 Mdot
.758 .10482 Mdot
.758 .10514 Mdot
.758 .10547 Mdot
.758 .10656 Mdot
.758 .10662 Mdot
.758 .10667 Mdot
.758 .10728 Mdot
.758 .10737 Mdot
.758 .10777 Mdot
.758 .1082 Mdot
.758 .10836 Mdot
.758 .10873 Mdot
.758 .10933 Mdot
.758 .10933 Mdot
.758 .11021 Mdot
.758 .11032 Mdot
.758 .1105 Mdot
.758 .11115 Mdot
.758 .1112 Mdot
.758 .11127 Mdot
.758 .11195 Mdot
.758 .11271 Mdot
.758 .11293 Mdot
.758 .1131 Mdot
.758 .11314 Mdot
.758 .11375 Mdot
.758 .11396 Mdot
.758 .11413 Mdot
.758 .11516 Mdot
.758 .11524 Mdot
.758 .11573 Mdot
.758 .11601 Mdot
.758 .11602 Mdot
.758 .11645 Mdot
.758 .11647 Mdot
.758 .11661 Mdot
.758 .11676 Mdot
.758 .11698 Mdot
.758 .11817 Mdot
.758 .11861 Mdot
.758 .1194 Mdot
.758 .11942 Mdot
.758 .11954 Mdot
.758 .11987 Mdot
.758 .12012 Mdot
.758 .12014 Mdot
.758 .12129 Mdot
.758 .12133 Mdot
.758 .12162 Mdot
.758 .12187 Mdot
.758 .12188 Mdot
.758 .12252 Mdot
.758 .12255 Mdot
.758 .12267 Mdot
.758 .12299 Mdot
.758 .12303 Mdot
.758 .12316 Mdot
.758 .12321 Mdot
.758 .12329 Mdot
.758 .12332 Mdot
.758 .12335 Mdot
.758 .12337 Mdot
.758 .12355 Mdot
.758 .12356 Mdot
.758 .12453 Mdot
.758 .12585 Mdot
.758 .12712 Mdot
.758 .12737 Mdot
.758 .12812 Mdot
.758 .12817 Mdot
.758 .1294 Mdot
.758 .12958 Mdot
.758 .12982 Mdot
.758 .12984 Mdot
.758 .12985 Mdot
.758 .13115 Mdot
.758 .13122 Mdot
.758 .13125 Mdot
.758 .13149 Mdot
.758 .13158 Mdot
.758 .13211 Mdot
.758 .13244 Mdot
.758 .13252 Mdot
.758 .13274 Mdot
.758 .13289 Mdot
.758 .13309 Mdot
.758 .13313 Mdot
.758 .13391 Mdot
.758 .13446 Mdot
.758 .13572 Mdot
.758 .13591 Mdot
.758 .13607 Mdot
.758 .1367 Mdot
.758 .13711 Mdot
.758 .13743 Mdot
.758 .13798 Mdot
.758 .13837 Mdot
.758 .1386 Mdot
.758 .13868 Mdot
.758 .13923 Mdot
.758 .13927 Mdot
.758 .13951 Mdot
.758 .13955 Mdot
.758 .13993 Mdot
.758 .13996 Mdot
.758 .14014 Mdot
.758 .14014 Mdot
.758 .14028 Mdot
.758 .14037 Mdot
.758 .14037 Mdot
.758 .14129 Mdot
.758 .14133 Mdot
.758 .1414 Mdot
.758 .1419 Mdot
.758 .14324 Mdot
.758 .14364 Mdot
.758 .14381 Mdot
.758 .14407 Mdot
.758 .14422 Mdot
.758 .14505 Mdot
.758 .14512 Mdot
.758 .14628 Mdot
.758 .14636 Mdot
.758 .1465 Mdot
.758 .14703 Mdot
.758 .14726 Mdot
.758 .14743 Mdot
.758 .14828 Mdot
.758 .14856 Mdot
.758 .14869 Mdot
.758 .1489 Mdot
.758 .14916 Mdot
.758 .14919 Mdot
.758 .14934 Mdot
.758 .14949 Mdot
.758 .14978 Mdot
.758 .14994 Mdot
.758 .15099 Mdot
.758 .15111 Mdot
.758 .15132 Mdot
.758 .15179 Mdot
.758 .1523 Mdot
.758 .15319 Mdot
.758 .15348 Mdot
.758 .15363 Mdot
.758 .15396 Mdot
.758 .15404 Mdot
.758 .15411 Mdot
.758 .15504 Mdot
.758 .15519 Mdot
.758 .15543 Mdot
.758 .15579 Mdot
.758 .15608 Mdot
.758 .15644 Mdot
.758 .15668 Mdot
.758 .15725 Mdot
.758 .15815 Mdot
.758 .15816 Mdot
.758 .15949 Mdot
.758 .15965 Mdot
.758 .15992 Mdot
.758 .1602 Mdot
.758 .16091 Mdot
.758 .16099 Mdot
.758 .1611 Mdot
.758 .1615 Mdot
.758 .16212 Mdot
.758 .16328 Mdot
.758 .16361 Mdot
.758 .16387 Mdot
.758 .16393 Mdot
.758 .16485 Mdot
.758 .16509 Mdot
.758 .16517 Mdot
.758 .16543 Mdot
.758 .16548 Mdot
.758 .16574 Mdot
.758 .167 Mdot
.758 .16711 Mdot
.758 .16786 Mdot
.758 .16828 Mdot
.758 .16829 Mdot
.758 .16894 Mdot
.758 .16897 Mdot
.758 .16919 Mdot
.758 .16942 Mdot
.758 .16975 Mdot
.758 .17128 Mdot
.758 .17156 Mdot
.758 .1722 Mdot
.758 .17222 Mdot
.758 .17262 Mdot
.758 .17319 Mdot
.758 .17342 Mdot
.758 .17345 Mdot
.758 .17362 Mdot
.758 .17413 Mdot
.758 .17446 Mdot
.758 .17451 Mdot
.758 .17454 Mdot
.758 .17455 Mdot
.758 .17461 Mdot
.758 .17628 Mdot
.758 .17634 Mdot
.758 .17679 Mdot
.758 .17681 Mdot
.758 .17716 Mdot
.758 .17718 Mdot
.758 .17815 Mdot
.758 .1782 Mdot
.758 .17838 Mdot
.758 .17886 Mdot
.758 .17893 Mdot
.758 .17912 Mdot
.758 .1792 Mdot
.758 .17932 Mdot
.758 .17937 Mdot
.758 .17941 Mdot
.758 .17943 Mdot
.758 .17944 Mdot
.758 .17971 Mdot
.758 .17973 Mdot
.758 .18119 Mdot
.758 .18146 Mdot
.758 .18182 Mdot
.758 .18201 Mdot
.758 .18311 Mdot
.758 .1832 Mdot
.758 .18324 Mdot
.758 .18376 Mdot
.758 .18394 Mdot
.758 .18513 Mdot
.758 .1855 Mdot
.758 .18653 Mdot
.758 .18664 Mdot
.758 .18672 Mdot
.758 .1883 Mdot
.758 .18857 Mdot
.758 .18869 Mdot
.758 .18885 Mdot
.758 .18922 Mdot
.758 .18925 Mdot
.758 .18926 Mdot
.758 .18989 Mdot
.758 .19065 Mdot
.758 .19123 Mdot
.758 .19133 Mdot
.758 .19138 Mdot
.758 .1917 Mdot
.758 .19174 Mdot
.758 .19189 Mdot
.758 .19194 Mdot
.758 .19268 Mdot
.758 .19319 Mdot
.758 .1933 Mdot
.758 .19365 Mdot
.758 .19386 Mdot
.758 .19417 Mdot
.758 .19424 Mdot
.758 .19541 Mdot
.758 .19603 Mdot
.758 .19624 Mdot
.758 .19816 Mdot
.758 .19819 Mdot
.758 .19845 Mdot
.758 .19869 Mdot
.758 .19894 Mdot
.758 .19965 Mdot
.758 .20026 Mdot
.758 .20075 Mdot
.758 .20159 Mdot
.758 .20218 Mdot
.758 .20252 Mdot
.758 .20264 Mdot
.758 .20347 Mdot
.758 .20354 Mdot
.758 .20391 Mdot
.758 .20397 Mdot
.758 .20454 Mdot
.758 .20459 Mdot
.758 .20485 Mdot
.758 .20485 Mdot
.758 .20508 Mdot
.758 .20521 Mdot
.758 .20522 Mdot
.758 .2056 Mdot
.758 .20573 Mdot
.758 .20661 Mdot
.758 .20662 Mdot
.758 .20666 Mdot
.758 .20677 Mdot
.758 .20745 Mdot
.758 .20752 Mdot
.758 .20832 Mdot
.758 .20956 Mdot
.758 .21017 Mdot
.758 .21042 Mdot
.758 .21079 Mdot
.758 .21082 Mdot
.758 .21104 Mdot
.758 .21231 Mdot
.758 .21241 Mdot
.758 .21293 Mdot
.758 .21417 Mdot
.758 .21429 Mdot
.758 .2145 Mdot
.758 .21464 Mdot
.758 .2153 Mdot
.758 .21566 Mdot
.758 .21592 Mdot
.758 .2172 Mdot
.758 .21755 Mdot
.758 .21762 Mdot
.758 .21783 Mdot
.758 .21814 Mdot
.758 .21853 Mdot
.758 .21858 Mdot
.758 .2188 Mdot
.758 .21904 Mdot
.758 .21948 Mdot
.758 .21962 Mdot
.758 .21972 Mdot
.758 .22081 Mdot
.758 .22124 Mdot
.758 .22132 Mdot
.758 .2215 Mdot
.758 .2218 Mdot
.758 .22253 Mdot
.758 .2233 Mdot
.758 .22413 Mdot
.758 .22435 Mdot
.758 .22464 Mdot
.758 .22508 Mdot
.758 .2253 Mdot
.758 .22564 Mdot
.758 .22581 Mdot
.758 .22586 Mdot
.758 .22593 Mdot
.758 .22604 Mdot
.758 .22745 Mdot
.758 .22767 Mdot
.758 .22785 Mdot
.758 .22801 Mdot
.758 .22804 Mdot
.758 .22858 Mdot
.758 .22893 Mdot
.758 .22893 Mdot
.758 .22902 Mdot
.758 .22958 Mdot
.758 .22972 Mdot
.758 .22994 Mdot
.758 .23017 Mdot
.758 .23019 Mdot
.758 .2308 Mdot
.758 .23155 Mdot
.758 .23198 Mdot
.758 .23217 Mdot
.758 .23217 Mdot
.758 .2342 Mdot
.758 .23443 Mdot
.758 .23485 Mdot
.758 .23504 Mdot
.758 .2351 Mdot
.758 .23521 Mdot
.758 .23527 Mdot
.758 .23562 Mdot
.758 .23635 Mdot
.758 .23646 Mdot
.758 .23663 Mdot
.758 .23725 Mdot
.758 .23799 Mdot
.758 .23818 Mdot
.758 .23824 Mdot
.758 .23994 Mdot
.758 .24044 Mdot
.758 .24083 Mdot
.758 .24092 Mdot
.758 .241 Mdot
.758 .24232 Mdot
.758 .24268 Mdot
.758 .2428 Mdot
.758 .2432 Mdot
.758 .24327 Mdot
.758 .24367 Mdot
.758 .24533 Mdot
.758 .24557 Mdot
.758 .24575 Mdot
.758 .24688 Mdot
.758 .24752 Mdot
.758 .24754 Mdot
.758 .24852 Mdot
.758 .24857 Mdot
.758 .2489 Mdot
.758 .24924 Mdot
.758 .24974 Mdot
.758 .25206 Mdot
.758 .25249 Mdot
.758 .25346 Mdot
.758 .2535 Mdot
.758 .25409 Mdot
.758 .25496 Mdot
.758 .25532 Mdot
.758 .25536 Mdot
.758 .25562 Mdot
.758 .25639 Mdot
.758 .25689 Mdot
.758 .25696 Mdot
.758 .25701 Mdot
.758 .25703 Mdot
.758 .25711 Mdot
.758 .25965 Mdot
.758 .25974 Mdot
.758 .26042 Mdot
.758 .26045 Mdot
.758 .26098 Mdot
.758 .26101 Mdot
.758 .26249 Mdot
.758 .26256 Mdot
.758 .26283 Mdot
.758 .26301 Mdot
.758 .26356 Mdot
.758 .26366 Mdot
.758 .26395 Mdot
.758 .26407 Mdot
.758 .26425 Mdot
.758 .26433 Mdot
.758 .26439 Mdot
.758 .26443 Mdot
.758 .26443 Mdot
.758 .26485 Mdot
.758 .26488 Mdot
.758 .2671 Mdot
.758 .2675 Mdot
.758 .26805 Mdot
.758 .26833 Mdot
.758 .27001 Mdot
.758 .27013 Mdot
.758 .2702 Mdot
.758 .27098 Mdot
.758 .27126 Mdot
.758 .27306 Mdot
.758 .27362 Mdot
.758 .27518 Mdot
.758 .27535 Mdot
.758 .27547 Mdot
.758 .27788 Mdot
.758 .27828 Mdot
.758 .27846 Mdot
.758 .27871 Mdot
.758 .27926 Mdot
.758 .2793 Mdot
.758 .27933 Mdot
.758 .28028 Mdot
.758 .28143 Mdot
.758 .28231 Mdot
.758 .28247 Mdot
.758 .28255 Mdot
.758 .28303 Mdot
.758 .28308 Mdot
.758 .28331 Mdot
.758 .28339 Mdot
.758 .28451 Mdot
.758 .28529 Mdot
.758 .28545 Mdot
.758 .28598 Mdot
.758 .28631 Mdot
.758 .28676 Mdot
.758 .28687 Mdot
.758 .28865 Mdot
.758 .28959 Mdot
.758 .28991 Mdot
.758 .29281 Mdot
.758 .29287 Mdot
.758 .29326 Mdot
.758 .29362 Mdot
.758 .29399 Mdot
.758 .29507 Mdot
.758 .296 Mdot
.758 .29675 Mdot
.758 .29801 Mdot
.758 .29891 Mdot
.758 .29943 Mdot
.758 .29962 Mdot
.758 .30087 Mdot
.758 .30097 Mdot
.758 .30153 Mdot
.758 .30163 Mdot
.758 .3025 Mdot
.758 .30256 Mdot
.758 .30296 Mdot
.758 .30297 Mdot
.758 .3033 Mdot
.758 .3035 Mdot
.758 .30351 Mdot
.758 .3041 Mdot
.758 .30429 Mdot
.758 .30562 Mdot
.758 .30565 Mdot
.758 .3057 Mdot
.758 .30587 Mdot
.758 .30691 Mdot
.758 .30701 Mdot
.758 .30821 Mdot
.758 .3101 Mdot
.758 .31102 Mdot
.758 .31141 Mdot
.758 .31197 Mdot
.758 .31201 Mdot
.758 .31235 Mdot
.758 .31426 Mdot
.758 .31443 Mdot
.758 .31522 Mdot
.758 .31709 Mdot
.758 .31727 Mdot
.758 .31759 Mdot
.758 .3178 Mdot
.758 .3188 Mdot
.758 .31935 Mdot
.758 .31974 Mdot
.758 .32169 Mdot
.758 .32221 Mdot
.758 .32232 Mdot
.758 .32263 Mdot
.758 .3231 Mdot
.758 .32371 Mdot
.758 .32378 Mdot
.758 .32411 Mdot
.758 .32446 Mdot
.758 .32514 Mdot
.758 .32535 Mdot
.758 .32551 Mdot
.758 .32715 Mdot
.758 .3278 Mdot
.758 .32792 Mdot
.758 .3282 Mdot
.758 .32866 Mdot
.758 .32976 Mdot
.758 .33093 Mdot
.758 .33219 Mdot
.758 .33252 Mdot
.758 .33296 Mdot
.758 .33363 Mdot
.758 .33397 Mdot
.758 .33447 Mdot
.758 .33473 Mdot
.758 .3348 Mdot
.758 .33491 Mdot
.758 .33509 Mdot
.758 .33723 Mdot
.758 .33755 Mdot
.758 .33783 Mdot
.758 .33807 Mdot
.758 .33811 Mdot
.758 .33893 Mdot
.758 .33947 Mdot
.758 .33947 Mdot
.758 .3396 Mdot
.758 .34044 Mdot
.758 .34066 Mdot
.758 .341 Mdot
.758 .34134 Mdot
.758 .34138 Mdot
.758 .34229 Mdot
.758 .34344 Mdot
.758 .34409 Mdot
.758 .34437 Mdot
.758 .34438 Mdot
.758 .34745 Mdot
.758 .3478 Mdot
.758 .34844 Mdot
.758 .34873 Mdot
.758 .34881 Mdot
.758 .34899 Mdot
.758 .34908 Mdot
.758 .3496 Mdot
.758 .35071 Mdot
.758 .35089 Mdot
.758 .35114 Mdot
.758 .35207 Mdot
.758 .35321 Mdot
.758 .35349 Mdot
.758 .35358 Mdot
.758 .35615 Mdot
.758 .35691 Mdot
.758 .35751 Mdot
.758 .35764 Mdot
.758 .35776 Mdot
.758 .35976 Mdot
.758 .36031 Mdot
.758 .36049 Mdot
.758 .3611 Mdot
.758 .3612 Mdot
.758 .36181 Mdot
.758 .36433 Mdot
.758 .3647 Mdot
.758 .36497 Mdot
.758 .36668 Mdot
.758 .36764 Mdot
.758 .36768 Mdot
.758 .36917 Mdot
.758 .36924 Mdot
.758 .36975 Mdot
.758 .37026 Mdot
.758 .37102 Mdot
.758 .37453 Mdot
.758 .37518 Mdot
.758 .37666 Mdot
.758 .37671 Mdot
.758 .37761 Mdot
.758 .37893 Mdot
.758 .37947 Mdot
.758 .37954 Mdot
.758 .37993 Mdot
.758 .38109 Mdot
.758 .38185 Mdot
.758 .38197 Mdot
.758 .38204 Mdot
.758 .38207 Mdot
.758 .38219 Mdot
.758 .38604 Mdot
.758 .38617 Mdot
.758 .3872 Mdot
.758 .38724 Mdot
.758 .38805 Mdot
.758 .3881 Mdot
.758 .39034 Mdot
.758 .39045 Mdot
.758 .39086 Mdot
.758 .39113 Mdot
.758 .39196 Mdot
.758 .39211 Mdot
.758 .39256 Mdot
.758 .39274 Mdot
.758 .39301 Mdot
.758 .39313 Mdot
.758 .39323 Mdot
.758 .39328 Mdot
.758 .39329 Mdot
.758 .39391 Mdot
.758 .39396 Mdot
.758 .39732 Mdot
.758 .39794 Mdot
.758 .39877 Mdot
.758 .3992 Mdot
.758 .40174 Mdot
.758 .40193 Mdot
.758 .40203 Mdot
.758 .40321 Mdot
.758 .40364 Mdot
.758 .40636 Mdot
.758 .40722 Mdot
.758 .40959 Mdot
.758 .40984 Mdot
.758 .41002 Mdot
.758 .41367 Mdot
.758 .41428 Mdot
.758 .41455 Mdot
.758 .41493 Mdot
.758 .41577 Mdot
.758 .41583 Mdot
.758 .41587 Mdot
.758 .41732 Mdot
.758 .41905 Mdot
.758 .42039 Mdot
.758 .42063 Mdot
.758 .42075 Mdot
.758 .42148 Mdot
.758 .42156 Mdot
.758 .4219 Mdot
.758 .42202 Mdot
.758 .42373 Mdot
.758 .4249 Mdot
.758 .42515 Mdot
.758 .42595 Mdot
.758 .42645 Mdot
.758 .42714 Mdot
.758 .4273 Mdot
.758 .43 Mdot
.758 .43142 Mdot
.758 .43191 Mdot
.758 .43631 Mdot
.758 .43639 Mdot
.758 .43698 Mdot
.758 .43753 Mdot
.758 .4381 Mdot
.758 .43974 Mdot
.758 .44115 Mdot
.758 .44227 Mdot
.758 .44419 Mdot
.758 .44556 Mdot
.758 .44634 Mdot
.758 .44663 Mdot
.758 .44853 Mdot
.758 .44868 Mdot
.758 .44953 Mdot
.758 .44967 Mdot
.758 .45099 Mdot
.758 .45109 Mdot
.758 .4517 Mdot
.758 .4517 Mdot
.758 .45222 Mdot
.758 .45251 Mdot
.758 .45253 Mdot
.758 .45343 Mdot
.758 .45371 Mdot
.758 .45573 Mdot
.758 .45577 Mdot
.758 .45584 Mdot
.758 .45611 Mdot
.758 .45768 Mdot
.758 .45784 Mdot
.758 .45966 Mdot
.758 .46252 Mdot
.76 .01498 Mdot
.76 .01512 Mdot
.76 .01515 Mdot
.76 .01533 Mdot
.76 .01537 Mdot
.76 .01565 Mdot
.76 .01571 Mdot
.76 .01584 Mdot
.76 .01613 Mdot
.76 .01623 Mdot
.76 .01623 Mdot
.76 .01642 Mdot
.76 .01687 Mdot
.76 .01701 Mdot
.76 .01701 Mdot
.76 .0173 Mdot
.76 .01799 Mdot
.76 .0182 Mdot
.76 .01821 Mdot
.76 .01865 Mdot
.76 .01969 Mdot
.76 .02002 Mdot
.76 .02003 Mdot
.76 .02057 Mdot
.76 .02069 Mdot
.76 .02219 Mdot
.76 .02228 Mdot
.76 .02278 Mdot
.76 .02278 Mdot
.76 .02279 Mdot
.76 .02311 Mdot
.76 .02311 Mdot
.76 .02362 Mdot
.76 .0238 Mdot
.76 .02487 Mdot
.76 .02529 Mdot
.76 .02601 Mdot
.76 .02607 Mdot
.76 .02621 Mdot
.76 .0266 Mdot
.76 .02697 Mdot
.76 .02698 Mdot
.76 .02698 Mdot
.76 .02715 Mdot
.76 .02748 Mdot
.76 .02748 Mdot
.76 .02761 Mdot
.76 .02777 Mdot
.76 .02825 Mdot
.76 .02838 Mdot
.76 .02853 Mdot
.76 .02944 Mdot
.76 .02985 Mdot
.76 .03015 Mdot
.76 .03038 Mdot
.76 .03054 Mdot
.76 .03078 Mdot
.76 .03189 Mdot
.76 .03198 Mdot
.76 .03218 Mdot
.76 .0325 Mdot
.76 .03274 Mdot
.76 .03279 Mdot
.76 .03334 Mdot
.76 .03336 Mdot
.76 .03336 Mdot
.76 .03362 Mdot
.76 .0341 Mdot
.76 .03411 Mdot
.76 .03412 Mdot
.76 .03432 Mdot
.76 .03433 Mdot
.76 .03455 Mdot
.76 .03513 Mdot
.76 .03528 Mdot
.76 .03548 Mdot
.76 .03571 Mdot
.76 .0371 Mdot
.76 .03772 Mdot
.76 .03818 Mdot
.76 .03853 Mdot
.76 .03877 Mdot
.76 .039 Mdot
.76 .03914 Mdot
.76 .04081 Mdot
.76 .04096 Mdot
.76 .041 Mdot
.76 .04116 Mdot
.76 .04127 Mdot
.76 .04146 Mdot
.76 .04174 Mdot
.76 .04207 Mdot
.76 .04211 Mdot
.76 .04218 Mdot
.76 .04243 Mdot
.76 .04302 Mdot
.76 .04305 Mdot
.76 .04306 Mdot
.76 .04344 Mdot
.76 .04366 Mdot
.76 .04418 Mdot
.76 .0442 Mdot
.76 .04421 Mdot
.76 .04452 Mdot
.76 .04453 Mdot
.76 .04487 Mdot
.76 .04496 Mdot
.76 .04497 Mdot
.76 .04575 Mdot
.76 .04598 Mdot
.76 .04628 Mdot
.76 .04663 Mdot
.76 .04873 Mdot
.76 .04888 Mdot
.76 .04937 Mdot
.76 .04968 Mdot
.76 .04971 Mdot
.76 .04986 Mdot
.76 .05038 Mdot
.76 .05091 Mdot
.76 .05128 Mdot
.76 .05163 Mdot
.76 .05184 Mdot
.76 .05275 Mdot
.76 .05438 Mdot
.76 .05452 Mdot
.76 .05461 Mdot
.76 .05466 Mdot
.76 .05466 Mdot
.76 .05491 Mdot
.76 .05507 Mdot
.76 .05536 Mdot
.76 .0558 Mdot
.76 .05616 Mdot
.76 .05629 Mdot
.76 .05635 Mdot
.76 .05647 Mdot
.76 .05671 Mdot
.76 .05684 Mdot
.76 .05725 Mdot
.76 .05774 Mdot
.76 .05778 Mdot
.76 .0578 Mdot
.76 .0579 Mdot
.76 .05795 Mdot
.76 .05838 Mdot
.76 .05862 Mdot
.76 .05871 Mdot
.76 .05878 Mdot
.76 .05951 Mdot
.76 .05953 Mdot
.76 .05955 Mdot
.76 .06001 Mdot
.76 .06003 Mdot
.76 .06055 Mdot
.76 .06069 Mdot
.76 .0607 Mdot
.76 .06071 Mdot
.76 .06106 Mdot
.76 .06185 Mdot
.76 .06188 Mdot
.76 .06223 Mdot
.76 .06234 Mdot
.76 .06241 Mdot
.76 .06269 Mdot
.76 .06298 Mdot
.76 .06322 Mdot
.76 .06356 Mdot
.76 .06469 Mdot
.76 .06573 Mdot
.76 .06623 Mdot
.76 .06643 Mdot
.76 .06655 Mdot
.76 .06665 Mdot
.76 .06682 Mdot
.76 .06695 Mdot
.76 .06739 Mdot
.76 .06786 Mdot
.76 .0679 Mdot
.76 .06813 Mdot
.76 .06858 Mdot
.76 .06893 Mdot
.76 .06974 Mdot
.76 .07025 Mdot
.76 .07029 Mdot
.76 .07083 Mdot
.76 .07114 Mdot
.76 .07114 Mdot
.76 .07157 Mdot
.76 .0717 Mdot
.76 .07192 Mdot
.76 .07252 Mdot
.76 .0734 Mdot
.76 .07438 Mdot
.76 .07501 Mdot
.76 .07522 Mdot
.76 .07535 Mdot
.76 .07543 Mdot
.76 .07544 Mdot
.76 .07582 Mdot
.76 .07606 Mdot
.76 .07646 Mdot
.76 .0765 Mdot
.76 .07675 Mdot
.76 .07716 Mdot
.76 .07734 Mdot
.76 .07772 Mdot
.76 .07791 Mdot
.76 .078 Mdot
.76 .07806 Mdot
.76 .07818 Mdot
.76 .07855 Mdot
.76 .07874 Mdot
.76 .07878 Mdot
.76 .07921 Mdot
.76 .07936 Mdot
.76 .08012 Mdot
.76 .08018 Mdot
.76 .08018 Mdot
.76 .0802 Mdot
.76 .08036 Mdot
.76 .08043 Mdot
.76 .08049 Mdot
.76 .08109 Mdot
.76 .08145 Mdot
.76 .08158 Mdot
.76 .08158 Mdot
.76 .08169 Mdot
.76 .08186 Mdot
.76 .0828 Mdot
.76 .08283 Mdot
.76 .08286 Mdot
.76 .08324 Mdot
.76 .08357 Mdot
.76 .0836 Mdot
.76 .08439 Mdot
.76 .0846 Mdot
.76 .08461 Mdot
.76 .08463 Mdot
.76 .08476 Mdot
.76 .08505 Mdot
.76 .08515 Mdot
.76 .08585 Mdot
.76 .08636 Mdot
.76 .08641 Mdot
.76 .08694 Mdot
.76 .08711 Mdot
.76 .08722 Mdot
.76 .08763 Mdot
.76 .08788 Mdot
.76 .08808 Mdot
.76 .08845 Mdot
.76 .08855 Mdot
.76 .08895 Mdot
.76 .0898 Mdot
.76 .09067 Mdot
.76 .09086 Mdot
.76 .09093 Mdot
.76 .09226 Mdot
.76 .09302 Mdot
.76 .09331 Mdot
.76 .0935 Mdot
.76 .09365 Mdot
.76 .09392 Mdot
.76 .09411 Mdot
.76 .09465 Mdot
.76 .09469 Mdot
.76 .09478 Mdot
.76 .09549 Mdot
.76 .09556 Mdot
.76 .09591 Mdot
.76 .09596 Mdot
.76 .09642 Mdot
.76 .09643 Mdot
.76 .0966 Mdot
.76 .09663 Mdot
.76 .09712 Mdot
.76 .09766 Mdot
.76 .09788 Mdot
.76 .09835 Mdot
.76 .09851 Mdot
.76 .09865 Mdot
.76 .09896 Mdot
.76 .09912 Mdot
.76 .09919 Mdot
.76 .10001 Mdot
.76 .10042 Mdot
.76 .10048 Mdot
.76 .10048 Mdot
.76 .10081 Mdot
.76 .10114 Mdot
.76 .10133 Mdot
.76 .10167 Mdot
.76 .10188 Mdot
.76 .10229 Mdot
.76 .10259 Mdot
.76 .10383 Mdot
.76 .10392 Mdot
.76 .1054 Mdot
.76 .10637 Mdot
.76 .10668 Mdot
.76 .10678 Mdot
.76 .10688 Mdot
.76 .107 Mdot
.76 .10701 Mdot
.76 .10759 Mdot
.76 .10783 Mdot
.76 .10795 Mdot
.76 .10847 Mdot
.76 .10856 Mdot
.76 .10862 Mdot
.76 .1087 Mdot
.76 .109 Mdot
.76 .10963 Mdot
.76 .10991 Mdot
.76 .11009 Mdot
.76 .11048 Mdot
.76 .11078 Mdot
.76 .11091 Mdot
.76 .11099 Mdot
.76 .11118 Mdot
.76 .11175 Mdot
.76 .11203 Mdot
.76 .11209 Mdot
.76 .11274 Mdot
.76 .11298 Mdot
.76 .11413 Mdot
.76 .11422 Mdot
.76 .11422 Mdot
.76 .11426 Mdot
.76 .11449 Mdot
.76 .11461 Mdot
.76 .11464 Mdot
.76 .11469 Mdot
.76 .11504 Mdot
.76 .11561 Mdot
.76 .11616 Mdot
.76 .11635 Mdot
.76 .11636 Mdot
.76 .11647 Mdot
.76 .11652 Mdot
.76 .11678 Mdot
.76 .11763 Mdot
.76 .11771 Mdot
.76 .11797 Mdot
.76 .11819 Mdot
.76 .11821 Mdot
.76 .11826 Mdot
.76 .1183 Mdot
.76 .11887 Mdot
.76 .11937 Mdot
.76 .11942 Mdot
.76 .12062 Mdot
.76 .12094 Mdot
.76 .12096 Mdot
.76 .12099 Mdot
.76 .12119 Mdot
.76 .12124 Mdot
.76 .12163 Mdot
.76 .12178 Mdot
.76 .12284 Mdot
.76 .12362 Mdot
.76 .12369 Mdot
.76 .12392 Mdot
.76 .12418 Mdot
.76 .1245 Mdot
.76 .12475 Mdot
.76 .12492 Mdot
.76 .12555 Mdot
.76 .12593 Mdot
.76 .12623 Mdot
.76 .1264 Mdot
.76 .12679 Mdot
.76 .12695 Mdot
.76 .12695 Mdot
.76 .12756 Mdot
.76 .12884 Mdot
.76 .13017 Mdot
.76 .13046 Mdot
.76 .13056 Mdot
.76 .13057 Mdot
.76 .13229 Mdot
.76 .13241 Mdot
.76 .13255 Mdot
.76 .13259 Mdot
.76 .13363 Mdot
.76 .13373 Mdot
.76 .1339 Mdot
.76 .13419 Mdot
.76 .13447 Mdot
.76 .1347 Mdot
.76 .13511 Mdot
.76 .13539 Mdot
.76 .13596 Mdot
.76 .13621 Mdot
.76 .13627 Mdot
.76 .13641 Mdot
.76 .1368 Mdot
.76 .1375 Mdot
.76 .1376 Mdot
.76 .13812 Mdot
.76 .1382 Mdot
.76 .13891 Mdot
.76 .13893 Mdot
.76 .13918 Mdot
.76 .13922 Mdot
.76 .13996 Mdot
.76 .1408 Mdot
.76 .14112 Mdot
.76 .14184 Mdot
.76 .14208 Mdot
.76 .1423 Mdot
.76 .14242 Mdot
.76 .14277 Mdot
.76 .14301 Mdot
.76 .14312 Mdot
.76 .14436 Mdot
.76 .14499 Mdot
.76 .14508 Mdot
.76 .14508 Mdot
.76 .14559 Mdot
.76 .14608 Mdot
.76 .14637 Mdot
.76 .14658 Mdot
.76 .14689 Mdot
.76 .147 Mdot
.76 .1472 Mdot
.76 .14783 Mdot
.76 .14821 Mdot
.76 .14828 Mdot
.76 .14961 Mdot
.76 .15018 Mdot
.76 .15031 Mdot
.76 .15131 Mdot
.76 .15131 Mdot
.76 .15256 Mdot
.76 .15266 Mdot
.76 .15352 Mdot
.76 .15403 Mdot
.76 .1545 Mdot
.76 .15465 Mdot
.76 .1548 Mdot
.76 .15499 Mdot
.76 .15501 Mdot
.76 .15589 Mdot
.76 .15626 Mdot
.76 .15644 Mdot
.76 .1566 Mdot
.76 .15692 Mdot
.76 .15722 Mdot
.76 .15736 Mdot
.76 .15745 Mdot
.76 .15757 Mdot
.76 .15803 Mdot
.76 .15851 Mdot
.76 .15876 Mdot
.76 .15892 Mdot
.76 .15898 Mdot
.76 .1594 Mdot
.76 .15968 Mdot
.76 .16027 Mdot
.76 .16053 Mdot
.76 .16073 Mdot
.76 .16093 Mdot
.76 .16106 Mdot
.76 .16133 Mdot
.76 .16142 Mdot
.76 .16173 Mdot
.76 .16221 Mdot
.76 .16264 Mdot
.76 .16272 Mdot
.76 .16353 Mdot
.76 .16372 Mdot
.76 .16407 Mdot
.76 .16438 Mdot
.76 .16439 Mdot
.76 .16583 Mdot
.76 .16596 Mdot
.76 .16596 Mdot
.76 .16602 Mdot
.76 .16637 Mdot
.76 .16655 Mdot
.76 .1666 Mdot
.76 .16668 Mdot
.76 .16721 Mdot
.76 .16763 Mdot
.76 .16807 Mdot
.76 .16891 Mdot
.76 .16921 Mdot
.76 .16939 Mdot
.76 .16945 Mdot
.76 .16985 Mdot
.76 .17115 Mdot
.76 .17126 Mdot
.76 .17167 Mdot
.76 .172 Mdot
.76 .17202 Mdot
.76 .1721 Mdot
.76 .17216 Mdot
.76 .17303 Mdot
.76 .17379 Mdot
.76 .17386 Mdot
.76 .17449 Mdot
.76 .17465 Mdot
.76 .17568 Mdot
.76 .17617 Mdot
.76 .17621 Mdot
.76 .17625 Mdot
.76 .17655 Mdot
.76 .17663 Mdot
.76 .17722 Mdot
.76 .17746 Mdot
.76 .17906 Mdot
.76 .18024 Mdot
.76 .18036 Mdot
.76 .18071 Mdot
.76 .18111 Mdot
.76 .18159 Mdot
.76 .18159 Mdot
.76 .18197 Mdot
.76 .18222 Mdot
.76 .1831 Mdot
.76 .18319 Mdot
.76 .18364 Mdot
.76 .18371 Mdot
.76 .18376 Mdot
.76 .18421 Mdot
.76 .18447 Mdot
.76 .18456 Mdot
.76 .18507 Mdot
.76 .18531 Mdot
.76 .18532 Mdot
.76 .18624 Mdot
.76 .18819 Mdot
.76 .18824 Mdot
.76 .19021 Mdot
.76 .19064 Mdot
.76 .19079 Mdot
.76 .19082 Mdot
.76 .19106 Mdot
.76 .1921 Mdot
.76 .19291 Mdot
.76 .19321 Mdot
.76 .19343 Mdot
.76 .19352 Mdot
.76 .19361 Mdot
.76 .19383 Mdot
.76 .19388 Mdot
.76 .19429 Mdot
.76 .19446 Mdot
.76 .19546 Mdot
.76 .19563 Mdot
.76 .19587 Mdot
.76 .19592 Mdot
.76 .19631 Mdot
.76 .19652 Mdot
.76 .19674 Mdot
.76 .19709 Mdot
.76 .19771 Mdot
.76 .19814 Mdot
.76 .19901 Mdot
.76 .19939 Mdot
.76 .19948 Mdot
.76 .19969 Mdot
.76 .20002 Mdot
.76 .20028 Mdot
.76 .2006 Mdot
.76 .20135 Mdot
.76 .20146 Mdot
.76 .2015 Mdot
.76 .20165 Mdot
.76 .2023 Mdot
.76 .20242 Mdot
.76 .20301 Mdot
.76 .2035 Mdot
.76 .20352 Mdot
.76 .20375 Mdot
.76 .20389 Mdot
.76 .20396 Mdot
.76 .20451 Mdot
.76 .20509 Mdot
.76 .20573 Mdot
.76 .20636 Mdot
.76 .20685 Mdot
.76 .20794 Mdot
.76 .20794 Mdot
.76 .20831 Mdot
.76 .20865 Mdot
.76 .20883 Mdot
.76 .20936 Mdot
.76 .20943 Mdot
.76 .20973 Mdot
.76 .2099 Mdot
.76 .21178 Mdot
.76 .21248 Mdot
.76 .21273 Mdot
.76 .21288 Mdot
.76 .21288 Mdot
.76 .21364 Mdot
.76 .21382 Mdot
.76 .21413 Mdot
.76 .21439 Mdot
.76 .21482 Mdot
.76 .21489 Mdot
.76 .21515 Mdot
.76 .21562 Mdot
.76 .21579 Mdot
.76 .21602 Mdot
.76 .21609 Mdot
.76 .21694 Mdot
.76 .21704 Mdot
.76 .21763 Mdot
.76 .21773 Mdot
.76 .21808 Mdot
.76 .21975 Mdot
.76 .22062 Mdot
.76 .22069 Mdot
.76 .22082 Mdot
.76 .22108 Mdot
.76 .22124 Mdot
.76 .22177 Mdot
.76 .22233 Mdot
.76 .22234 Mdot
.76 .22403 Mdot
.76 .22424 Mdot
.76 .22439 Mdot
.76 .22445 Mdot
.76 .2257 Mdot
.76 .22647 Mdot
.76 .22653 Mdot
.76 .22718 Mdot
.76 .22742 Mdot
.76 .22765 Mdot
.76 .22793 Mdot
.76 .22796 Mdot
.76 .22825 Mdot
.76 .22831 Mdot
.76 .22915 Mdot
.76 .2293 Mdot
.76 .22964 Mdot
.76 .22986 Mdot
.76 .22989 Mdot
.76 .23013 Mdot
.76 .23038 Mdot
.76 .23087 Mdot
.76 .23132 Mdot
.76 .23154 Mdot
.76 .23168 Mdot
.76 .2318 Mdot
.76 .23185 Mdot
.76 .23256 Mdot
.76 .23328 Mdot
.76 .23367 Mdot
.76 .23385 Mdot
.76 .23391 Mdot
.76 .234 Mdot
.76 .23464 Mdot
.76 .23507 Mdot
.76 .23597 Mdot
.76 .23609 Mdot
.76 .23635 Mdot
.76 .23666 Mdot
.76 .23697 Mdot
.76 .23716 Mdot
.76 .23758 Mdot
.76 .23771 Mdot
.76 .23818 Mdot
.76 .2383 Mdot
.76 .2389 Mdot
.76 .23956 Mdot
.76 .23969 Mdot
.76 .24003 Mdot
.76 .24091 Mdot
.76 .2412 Mdot
.76 .24174 Mdot
.76 .2422 Mdot
.76 .24223 Mdot
.76 .24384 Mdot
.76 .24386 Mdot
.76 .24441 Mdot
.76 .24461 Mdot
.76 .24461 Mdot
.76 .2447 Mdot
.76 .24514 Mdot
.76 .24524 Mdot
.76 .24551 Mdot
.76 .24557 Mdot
.76 .24571 Mdot
.76 .24634 Mdot
.76 .24651 Mdot
.76 .24697 Mdot
.76 .24715 Mdot
.76 .24782 Mdot
.76 .24909 Mdot
.76 .24955 Mdot
.76 .24982 Mdot
.76 .24992 Mdot
.76 .25052 Mdot
.76 .25249 Mdot
.76 .25267 Mdot
.76 .25329 Mdot
.76 .25379 Mdot
.76 .25382 Mdot
.76 .25394 Mdot
.76 .25403 Mdot
.76 .25535 Mdot
.76 .25651 Mdot
.76 .25662 Mdot
.76 .25758 Mdot
.76 .25782 Mdot
.76 .25939 Mdot
.76 .26013 Mdot
.76 .26018 Mdot
.76 .26025 Mdot
.76 .26071 Mdot
.76 .26083 Mdot
.76 .26172 Mdot
.76 .26208 Mdot
.76 .26452 Mdot
.76 .26632 Mdot
.76 .2665 Mdot
.76 .26702 Mdot
.76 .26763 Mdot
.76 .26836 Mdot
.76 .26836 Mdot
.76 .26895 Mdot
.76 .26932 Mdot
.76 .27065 Mdot
.76 .27079 Mdot
.76 .27148 Mdot
.76 .27159 Mdot
.76 .27166 Mdot
.76 .27235 Mdot
.76 .27274 Mdot
.76 .27288 Mdot
.76 .27365 Mdot
.76 .27402 Mdot
.76 .27403 Mdot
.76 .27543 Mdot
.76 .2784 Mdot
.76 .27847 Mdot
.76 .28147 Mdot
.76 .28212 Mdot
.76 .28236 Mdot
.76 .28239 Mdot
.76 .28275 Mdot
.76 .28435 Mdot
.76 .28557 Mdot
.76 .28602 Mdot
.76 .28637 Mdot
.76 .2865 Mdot
.76 .28663 Mdot
.76 .28697 Mdot
.76 .28704 Mdot
.76 .28767 Mdot
.76 .28793 Mdot
.76 .28945 Mdot
.76 .2897 Mdot
.76 .29007 Mdot
.76 .29015 Mdot
.76 .29074 Mdot
.76 .29106 Mdot
.76 .29139 Mdot
.76 .29192 Mdot
.76 .29287 Mdot
.76 .29352 Mdot
.76 .29484 Mdot
.76 .29542 Mdot
.76 .29555 Mdot
.76 .29588 Mdot
.76 .29637 Mdot
.76 .29677 Mdot
.76 .29726 Mdot
.76 .29839 Mdot
.76 .29856 Mdot
.76 .29863 Mdot
.76 .29886 Mdot
.76 .29984 Mdot
.76 .30002 Mdot
.76 .30092 Mdot
.76 .30166 Mdot
.76 .30169 Mdot
.76 .30206 Mdot
.76 .30227 Mdot
.76 .30237 Mdot
.76 .3032 Mdot
.76 .30409 Mdot
.76 .30506 Mdot
.76 .30602 Mdot
.76 .30676 Mdot
.76 .30841 Mdot
.76 .30842 Mdot
.76 .30898 Mdot
.76 .30949 Mdot
.76 .30977 Mdot
.76 .31057 Mdot
.76 .31068 Mdot
.76 .31113 Mdot
.76 .31139 Mdot
.76 .31425 Mdot
.76 .31531 Mdot
.76 .3157 Mdot
.76 .31592 Mdot
.76 .31592 Mdot
.76 .31708 Mdot
.76 .31735 Mdot
.76 .31783 Mdot
.76 .31822 Mdot
.76 .31888 Mdot
.76 .31898 Mdot
.76 .31938 Mdot
.76 .32008 Mdot
.76 .32035 Mdot
.76 .3207 Mdot
.76 .32081 Mdot
.76 .32209 Mdot
.76 .32225 Mdot
.76 .32315 Mdot
.76 .3233 Mdot
.76 .32383 Mdot
.76 .32637 Mdot
.76 .32769 Mdot
.76 .3278 Mdot
.76 .32799 Mdot
.76 .32839 Mdot
.76 .32863 Mdot
.76 .32944 Mdot
.76 .3303 Mdot
.76 .3303 Mdot
.76 .33287 Mdot
.76 .33319 Mdot
.76 .33342 Mdot
.76 .33352 Mdot
.76 .33542 Mdot
.76 .33658 Mdot
.76 .33668 Mdot
.76 .33766 Mdot
.76 .33803 Mdot
.76 .33838 Mdot
.76 .33881 Mdot
.76 .33884 Mdot
.76 .33928 Mdot
.76 .33938 Mdot
.76 .34066 Mdot
.76 .34088 Mdot
.76 .34141 Mdot
.76 .34173 Mdot
.76 .34178 Mdot
.76 .34215 Mdot
.76 .34253 Mdot
.76 .34327 Mdot
.76 .34396 Mdot
.76 .34429 Mdot
.76 .3445 Mdot
.76 .34468 Mdot
.76 .34476 Mdot
.76 .34584 Mdot
.76 .34693 Mdot
.76 .34752 Mdot
.76 .3478 Mdot
.76 .34788 Mdot
.76 .34803 Mdot
.76 .34901 Mdot
.76 .34965 Mdot
.76 .35102 Mdot
.76 .35121 Mdot
.76 .3516 Mdot
.76 .35207 Mdot
.76 .35254 Mdot
.76 .35283 Mdot
.76 .35346 Mdot
.76 .35367 Mdot
.76 .35438 Mdot
.76 .35457 Mdot
.76 .35548 Mdot
.76 .35648 Mdot
.76 .35667 Mdot
.76 .35719 Mdot
.76 .35853 Mdot
.76 .35897 Mdot
.76 .35979 Mdot
.76 .36049 Mdot
.76 .36054 Mdot
.76 .36298 Mdot
.76 .36301 Mdot
.76 .36384 Mdot
.76 .36415 Mdot
.76 .36416 Mdot
.76 .36429 Mdot
.76 .36497 Mdot
.76 .36511 Mdot
.76 .36552 Mdot
.76 .36562 Mdot
.76 .36582 Mdot
.76 .36678 Mdot
.76 .36704 Mdot
.76 .36774 Mdot
.76 .36801 Mdot
.76 .36903 Mdot
.76 .37096 Mdot
.76 .37166 Mdot
.76 .37208 Mdot
.76 .37223 Mdot
.76 .37314 Mdot
.76 .37613 Mdot
.76 .3764 Mdot
.76 .37734 Mdot
.76 .3781 Mdot
.76 .37815 Mdot
.76 .37833 Mdot
.76 .37847 Mdot
.76 .38048 Mdot
.76 .38224 Mdot
.76 .38241 Mdot
.76 .38387 Mdot
.76 .38424 Mdot
.76 .38662 Mdot
.76 .38775 Mdot
.76 .38783 Mdot
.76 .38792 Mdot
.76 .38863 Mdot
.76 .3888 Mdot
.76 .39016 Mdot
.76 .39071 Mdot
.76 .39441 Mdot
.76 .39715 Mdot
.76 .39743 Mdot
.76 .39822 Mdot
.76 .39914 Mdot
.76 .40026 Mdot
.76 .40026 Mdot
.76 .40115 Mdot
.76 .40172 Mdot
.76 .40374 Mdot
.76 .40395 Mdot
.76 .405 Mdot
.76 .40516 Mdot
.76 .40527 Mdot
.76 .40632 Mdot
.76 .40691 Mdot
.76 .40712 Mdot
.76 .4083 Mdot
.76 .40886 Mdot
.76 .40887 Mdot
.76 .411 Mdot
.76 .41551 Mdot
.76 .41562 Mdot
.76 .42018 Mdot
.76 .42117 Mdot
.76 .42153 Mdot
.76 .42158 Mdot
.76 .42213 Mdot
.76 .42455 Mdot
.76 .42641 Mdot
.76 .4271 Mdot
.76 .42763 Mdot
.76 .42782 Mdot
.76 .42803 Mdot
.76 .42854 Mdot
.76 .42865 Mdot
.76 .42961 Mdot
.76 .43001 Mdot
.76 .43231 Mdot
.76 .43269 Mdot
.76 .43325 Mdot
.76 .43338 Mdot
.76 .43427 Mdot
.76 .43476 Mdot
.76 .43526 Mdot
.76 .43606 Mdot
.76 .43752 Mdot
.76 .4385 Mdot
.76 .4405 Mdot
.76 .44138 Mdot
.76 .44159 Mdot
.76 .44209 Mdot
.76 .44284 Mdot
.76 .44344 Mdot
.76 .44419 Mdot
.76 .44591 Mdot
.76 .44616 Mdot
.76 .44627 Mdot
.76 .44662 Mdot
.76 .4481 Mdot
.76 .44838 Mdot
.76 .44975 Mdot
.76 .45088 Mdot
.76 .45092 Mdot
.76 .45147 Mdot
.76 .4518 Mdot
.76 .45196 Mdot
.76 .45321 Mdot
.76 .45456 Mdot
.76 .45604 Mdot
.76 .45749 Mdot
.76 .45863 Mdot
.76 .46114 Mdot
.76 .46115 Mdot
.76 .46199 Mdot
.76 .46278 Mdot
.76 .46319 Mdot
.762 .01649 Mdot
.762 .01699 Mdot
.762 .01729 Mdot
.762 .01738 Mdot
.762 .01742 Mdot
.762 .01819 Mdot
.762 .01839 Mdot
.762 .01864 Mdot
.762 .01877 Mdot
.762 .01884 Mdot
.762 .01907 Mdot
.762 .01927 Mdot
.762 .01955 Mdot
.762 .02001 Mdot
.762 .02032 Mdot
.762 .0207 Mdot
.762 .0209 Mdot
.762 .021 Mdot
.762 .02135 Mdot
.762 .02166 Mdot
.762 .022 Mdot
.762 .02207 Mdot
.762 .02209 Mdot
.762 .02215 Mdot
.762 .02229 Mdot
.762 .02278 Mdot
.762 .02306 Mdot
.762 .02326 Mdot
.762 .02384 Mdot
.762 .02414 Mdot
.762 .0243 Mdot
.762 .02464 Mdot
.762 .02482 Mdot
.762 .02529 Mdot
.762 .02582 Mdot
.762 .02593 Mdot
.762 .02595 Mdot
.762 .02604 Mdot
.762 .02605 Mdot
.762 .02626 Mdot
.762 .02701 Mdot
.762 .02725 Mdot
.762 .02743 Mdot
.762 .02774 Mdot
.762 .02862 Mdot
.762 .02908 Mdot
.762 .02932 Mdot
.762 .02984 Mdot
.762 .03012 Mdot
.762 .03026 Mdot
.762 .03028 Mdot
.762 .03084 Mdot
.762 .03107 Mdot
.762 .03156 Mdot
.762 .03164 Mdot
.762 .0318 Mdot
.762 .03184 Mdot
.762 .03198 Mdot
.762 .03199 Mdot
.762 .03231 Mdot
.762 .0332 Mdot
.762 .03346 Mdot
.762 .03381 Mdot
.762 .03389 Mdot
.762 .03409 Mdot
.762 .03456 Mdot
.762 .03474 Mdot
.762 .0355 Mdot
.762 .03591 Mdot
.762 .03661 Mdot
.762 .03686 Mdot
.762 .03698 Mdot
.762 .03705 Mdot
.762 .03777 Mdot
.762 .03819 Mdot
.762 .03826 Mdot
.762 .03841 Mdot
.762 .03843 Mdot
.762 .03928 Mdot
.762 .03963 Mdot
.762 .0399 Mdot
.762 .04032 Mdot
.762 .04038 Mdot
.762 .0405 Mdot
.762 .04076 Mdot
.762 .04082 Mdot
.762 .04102 Mdot
.762 .04104 Mdot
.762 .04152 Mdot
.762 .04279 Mdot
.762 .0428 Mdot
.762 .04288 Mdot
.762 .04305 Mdot
.762 .04305 Mdot
.762 .04328 Mdot
.762 .04334 Mdot
.762 .04382 Mdot
.762 .04393 Mdot
.762 .04424 Mdot
.762 .04474 Mdot
.762 .04496 Mdot
.762 .04502 Mdot
.762 .04505 Mdot
.762 .04523 Mdot
.762 .0454 Mdot
.762 .04563 Mdot
.762 .04571 Mdot
.762 .04639 Mdot
.762 .04701 Mdot
.762 .04809 Mdot
.762 .04847 Mdot
.762 .04864 Mdot
.762 .04876 Mdot
.762 .04956 Mdot
.762 .04985 Mdot
.762 .05015 Mdot
.762 .05049 Mdot
.762 .0506 Mdot
.762 .05082 Mdot
.762 .05086 Mdot
.762 .05098 Mdot
.762 .05126 Mdot
.762 .05129 Mdot
.762 .05192 Mdot
.762 .05216 Mdot
.762 .05221 Mdot
.762 .05269 Mdot
.762 .05292 Mdot
.762 .0531 Mdot
.762 .05351 Mdot
.762 .05373 Mdot
.762 .05384 Mdot
.762 .05399 Mdot
.762 .05402 Mdot
.762 .05423 Mdot
.762 .0544 Mdot
.762 .05449 Mdot
.762 .05481 Mdot
.762 .05483 Mdot
.762 .05557 Mdot
.762 .05621 Mdot
.762 .05651 Mdot
.762 .05696 Mdot
.762 .0575 Mdot
.762 .05752 Mdot
.762 .05765 Mdot
.762 .0579 Mdot
.762 .0579 Mdot
.762 .05824 Mdot
.762 .05834 Mdot
.762 .05848 Mdot
.762 .05907 Mdot
.762 .05915 Mdot
.762 .05924 Mdot
.762 .05936 Mdot
.762 .0597 Mdot
.762 .06047 Mdot
.762 .06081 Mdot
.762 .0609 Mdot
.762 .06095 Mdot
.762 .06095 Mdot
.762 .06122 Mdot
.762 .06131 Mdot
.762 .06148 Mdot
.762 .06183 Mdot
.762 .06196 Mdot
.762 .06246 Mdot
.762 .06265 Mdot
.762 .06268 Mdot
.762 .06298 Mdot
.762 .06394 Mdot
.762 .06411 Mdot
.762 .06519 Mdot
.762 .06557 Mdot
.762 .06615 Mdot
.762 .06642 Mdot
.762 .06645 Mdot
.762 .0666 Mdot
.762 .06673 Mdot
.762 .06693 Mdot
.762 .06721 Mdot
.762 .06742 Mdot
.762 .06762 Mdot
.762 .06781 Mdot
.762 .06826 Mdot
.762 .06872 Mdot
.762 .06892 Mdot
.762 .06923 Mdot
.762 .06941 Mdot
.762 .06974 Mdot
.762 .06981 Mdot
.762 .06998 Mdot
.762 .07041 Mdot
.762 .07043 Mdot
.762 .07045 Mdot
.762 .07142 Mdot
.762 .07178 Mdot
.762 .07186 Mdot
.762 .07259 Mdot
.762 .07294 Mdot
.762 .07294 Mdot
.762 .07322 Mdot
.762 .07384 Mdot
.762 .07394 Mdot
.762 .07418 Mdot
.762 .07433 Mdot
.762 .07458 Mdot
.762 .07461 Mdot
.762 .07493 Mdot
.762 .07496 Mdot
.762 .07515 Mdot
.762 .0752 Mdot
.762 .07534 Mdot
.762 .07567 Mdot
.762 .07582 Mdot
.762 .07586 Mdot
.762 .07591 Mdot
.762 .07594 Mdot
.762 .07596 Mdot
.762 .07686 Mdot
.762 .07698 Mdot
.762 .07762 Mdot
.762 .07795 Mdot
.762 .0784 Mdot
.762 .07909 Mdot
.762 .07991 Mdot
.762 .07994 Mdot
.762 .08014 Mdot
.762 .08053 Mdot
.762 .08053 Mdot
.762 .08105 Mdot
.762 .0812 Mdot
.762 .08127 Mdot
.762 .08141 Mdot
.762 .08183 Mdot
.762 .08231 Mdot
.762 .08244 Mdot
.762 .08258 Mdot
.762 .08276 Mdot
.762 .08291 Mdot
.762 .08328 Mdot
.762 .08397 Mdot
.762 .08428 Mdot
.762 .08444 Mdot
.762 .0849 Mdot
.762 .08496 Mdot
.762 .08511 Mdot
.762 .08517 Mdot
.762 .08518 Mdot
.762 .08559 Mdot
.762 .08573 Mdot
.762 .08599 Mdot
.762 .08636 Mdot
.762 .08652 Mdot
.762 .08671 Mdot
.762 .08748 Mdot
.762 .08768 Mdot
.762 .08776 Mdot
.762 .08781 Mdot
.762 .08827 Mdot
.762 .08909 Mdot
.762 .08973 Mdot
.762 .09 Mdot
.762 .09116 Mdot
.762 .09164 Mdot
.762 .09222 Mdot
.762 .09241 Mdot
.762 .0931 Mdot
.762 .09336 Mdot
.762 .09351 Mdot
.762 .09356 Mdot
.762 .09378 Mdot
.762 .09398 Mdot
.762 .0943 Mdot
.762 .0947 Mdot
.762 .09472 Mdot
.762 .09475 Mdot
.762 .09504 Mdot
.762 .09534 Mdot
.762 .09564 Mdot
.762 .09605 Mdot
.762 .09632 Mdot
.762 .09702 Mdot
.762 .09732 Mdot
.762 .0978 Mdot
.762 .09807 Mdot
.762 .09858 Mdot
.762 .09867 Mdot
.762 .09893 Mdot
.762 .0996 Mdot
.762 .09963 Mdot
.762 .09965 Mdot
.762 .10009 Mdot
.762 .10035 Mdot
.762 .10113 Mdot
.762 .10114 Mdot
.762 .10168 Mdot
.762 .1018 Mdot
.762 .10196 Mdot
.762 .10262 Mdot
.762 .10292 Mdot
.762 .10345 Mdot
.762 .10346 Mdot
.762 .10387 Mdot
.762 .10398 Mdot
.762 .10482 Mdot
.762 .10497 Mdot
.762 .10515 Mdot
.762 .1052 Mdot
.762 .10533 Mdot
.762 .10558 Mdot
.762 .10594 Mdot
.762 .106 Mdot
.762 .10649 Mdot
.762 .10653 Mdot
.762 .10682 Mdot
.762 .10689 Mdot
.762 .1071 Mdot
.762 .10714 Mdot
.762 .10761 Mdot
.762 .10784 Mdot
.762 .10789 Mdot
.762 .10793 Mdot
.762 .10798 Mdot
.762 .10802 Mdot
.762 .10806 Mdot
.762 .10904 Mdot
.762 .10942 Mdot
.762 .10945 Mdot
.762 .10959 Mdot
.762 .1096 Mdot
.762 .1096 Mdot
.762 .11059 Mdot
.762 .11069 Mdot
.762 .11089 Mdot
.762 .11109 Mdot
.762 .11126 Mdot
.762 .11178 Mdot
.762 .11242 Mdot
.762 .11283 Mdot
.762 .11408 Mdot
.762 .11413 Mdot
.762 .11442 Mdot
.762 .11501 Mdot
.762 .11502 Mdot
.762 .11581 Mdot
.762 .11584 Mdot
.762 .11604 Mdot
.762 .11615 Mdot
.762 .11636 Mdot
.762 .117 Mdot
.762 .11773 Mdot
.762 .11792 Mdot
.762 .11814 Mdot
.762 .11841 Mdot
.762 .11864 Mdot
.762 .1192 Mdot
.762 .11982 Mdot
.762 .12025 Mdot
.762 .12073 Mdot
.762 .12082 Mdot
.762 .12083 Mdot
.762 .12098 Mdot
.762 .12168 Mdot
.762 .12177 Mdot
.762 .12199 Mdot
.762 .12199 Mdot
.762 .12209 Mdot
.762 .1221 Mdot
.762 .12273 Mdot
.762 .12294 Mdot
.762 .12333 Mdot
.762 .12346 Mdot
.762 .12391 Mdot
.762 .12414 Mdot
.762 .12444 Mdot
.762 .12469 Mdot
.762 .12549 Mdot
.762 .1256 Mdot
.762 .12592 Mdot
.762 .12604 Mdot
.762 .12611 Mdot
.762 .12682 Mdot
.762 .12741 Mdot
.762 .12775 Mdot
.762 .12806 Mdot
.762 .12903 Mdot
.762 .12945 Mdot
.762 .13106 Mdot
.762 .13121 Mdot
.762 .13195 Mdot
.762 .13284 Mdot
.762 .13313 Mdot
.762 .13335 Mdot
.762 .13341 Mdot
.762 .13418 Mdot
.762 .13456 Mdot
.762 .1348 Mdot
.762 .13488 Mdot
.762 .13522 Mdot
.762 .13552 Mdot
.762 .13598 Mdot
.762 .136 Mdot
.762 .13648 Mdot
.762 .1365 Mdot
.762 .13661 Mdot
.762 .13664 Mdot
.762 .13669 Mdot
.762 .13713 Mdot
.762 .13731 Mdot
.762 .13759 Mdot
.762 .13804 Mdot
.762 .13866 Mdot
.762 .13908 Mdot
.762 .14015 Mdot
.762 .1406 Mdot
.762 .14111 Mdot
.762 .14134 Mdot
.762 .14159 Mdot
.762 .14175 Mdot
.762 .14252 Mdot
.762 .14267 Mdot
.762 .14275 Mdot
.762 .14277 Mdot
.762 .14306 Mdot
.762 .14331 Mdot
.762 .14339 Mdot
.762 .14408 Mdot
.762 .14412 Mdot
.762 .14416 Mdot
.762 .14483 Mdot
.762 .14522 Mdot
.762 .14641 Mdot
.762 .14642 Mdot
.762 .14678 Mdot
.762 .14724 Mdot
.762 .14744 Mdot
.762 .14768 Mdot
.762 .14789 Mdot
.762 .14868 Mdot
.762 .14914 Mdot
.762 .14995 Mdot
.762 .14996 Mdot
.762 .15003 Mdot
.762 .15059 Mdot
.762 .15069 Mdot
.762 .15076 Mdot
.762 .15187 Mdot
.762 .15203 Mdot
.762 .15227 Mdot
.762 .15253 Mdot
.762 .15262 Mdot
.762 .15282 Mdot
.762 .15312 Mdot
.762 .15319 Mdot
.762 .15375 Mdot
.762 .15383 Mdot
.762 .15439 Mdot
.762 .15458 Mdot
.762 .15464 Mdot
.762 .15508 Mdot
.762 .15519 Mdot
.762 .15551 Mdot
.762 .15557 Mdot
.762 .15598 Mdot
.762 .15628 Mdot
.762 .15664 Mdot
.762 .15672 Mdot
.762 .15678 Mdot
.762 .15685 Mdot
.762 .15691 Mdot
.762 .15697 Mdot
.762 .15734 Mdot
.762 .15847 Mdot
.762 .15904 Mdot
.762 .1591 Mdot
.762 .15931 Mdot
.762 .15932 Mdot
.762 .15933 Mdot
.762 .1598 Mdot
.762 .16083 Mdot
.762 .16098 Mdot
.762 .16129 Mdot
.762 .16159 Mdot
.762 .16168 Mdot
.762 .16185 Mdot
.762 .16226 Mdot
.762 .16264 Mdot
.762 .16362 Mdot
.762 .16397 Mdot
.762 .16424 Mdot
.762 .16463 Mdot
.762 .165 Mdot
.762 .16614 Mdot
.762 .16622 Mdot
.762 .16667 Mdot
.762 .16757 Mdot
.762 .16759 Mdot
.762 .16879 Mdot
.762 .16883 Mdot
.762 .16883 Mdot
.762 .16914 Mdot
.762 .1693 Mdot
.762 .16963 Mdot
.762 .17059 Mdot
.762 .17172 Mdot
.762 .172 Mdot
.762 .172 Mdot
.762 .17233 Mdot
.762 .17274 Mdot
.762 .17309 Mdot
.762 .17332 Mdot
.762 .17386 Mdot
.762 .17396 Mdot
.762 .17489 Mdot
.762 .17554 Mdot
.762 .17556 Mdot
.762 .17628 Mdot
.762 .17642 Mdot
.762 .17643 Mdot
.762 .17666 Mdot
.762 .17773 Mdot
.762 .17787 Mdot
.762 .17819 Mdot
.762 .1782 Mdot
.762 .17835 Mdot
.762 .17838 Mdot
.762 .17933 Mdot
.762 .17965 Mdot
.762 .18025 Mdot
.762 .18044 Mdot
.762 .18077 Mdot
.762 .18112 Mdot
.762 .18148 Mdot
.762 .18193 Mdot
.762 .18232 Mdot
.762 .18301 Mdot
.762 .18354 Mdot
.762 .18371 Mdot
.762 .18419 Mdot
.762 .18438 Mdot
.762 .18448 Mdot
.762 .18556 Mdot
.762 .18646 Mdot
.762 .18683 Mdot
.762 .18698 Mdot
.762 .18746 Mdot
.762 .18894 Mdot
.762 .18957 Mdot
.762 .19065 Mdot
.762 .19173 Mdot
.762 .19203 Mdot
.762 .19225 Mdot
.762 .19251 Mdot
.762 .19338 Mdot
.762 .19343 Mdot
.762 .19473 Mdot
.762 .19518 Mdot
.762 .19551 Mdot
.762 .19561 Mdot
.762 .1965 Mdot
.762 .19668 Mdot
.762 .19678 Mdot
.762 .19736 Mdot
.762 .19773 Mdot
.762 .19785 Mdot
.762 .19836 Mdot
.762 .19882 Mdot
.762 .19953 Mdot
.762 .19955 Mdot
.762 .20028 Mdot
.762 .20032 Mdot
.762 .20049 Mdot
.762 .20052 Mdot
.762 .20061 Mdot
.762 .20128 Mdot
.762 .20128 Mdot
.762 .20155 Mdot
.762 .20197 Mdot
.762 .20267 Mdot
.762 .20286 Mdot
.762 .20361 Mdot
.762 .20404 Mdot
.762 .20425 Mdot
.762 .20439 Mdot
.762 .20588 Mdot
.762 .20656 Mdot
.762 .20735 Mdot
.762 .20753 Mdot
.762 .20769 Mdot
.762 .20808 Mdot
.762 .20817 Mdot
.762 .20831 Mdot
.762 .20853 Mdot
.762 .2095 Mdot
.762 .20971 Mdot
.762 .20984 Mdot
.762 .20988 Mdot
.762 .21032 Mdot
.762 .21061 Mdot
.762 .21069 Mdot
.762 .21081 Mdot
.762 .21187 Mdot
.762 .2119 Mdot
.762 .21193 Mdot
.762 .21199 Mdot
.762 .21232 Mdot
.762 .21301 Mdot
.762 .21361 Mdot
.762 .21413 Mdot
.762 .21543 Mdot
.762 .21543 Mdot
.762 .21577 Mdot
.762 .21598 Mdot
.762 .21669 Mdot
.762 .21699 Mdot
.762 .21735 Mdot
.762 .21768 Mdot
.762 .21827 Mdot
.762 .21835 Mdot
.762 .21887 Mdot
.762 .21958 Mdot
.762 .22082 Mdot
.762 .22082 Mdot
.762 .22093 Mdot
.762 .22093 Mdot
.762 .22106 Mdot
.762 .22166 Mdot
.762 .22178 Mdot
.762 .22179 Mdot
.762 .22194 Mdot
.762 .22204 Mdot
.762 .22208 Mdot
.762 .22373 Mdot
.762 .22399 Mdot
.762 .22434 Mdot
.762 .22447 Mdot
.762 .22448 Mdot
.762 .22475 Mdot
.762 .22488 Mdot
.762 .22518 Mdot
.762 .22544 Mdot
.762 .22564 Mdot
.762 .22574 Mdot
.762 .2266 Mdot
.762 .22672 Mdot
.762 .22692 Mdot
.762 .22757 Mdot
.762 .22786 Mdot
.762 .22795 Mdot
.762 .22864 Mdot
.762 .22879 Mdot
.762 .22929 Mdot
.762 .22937 Mdot
.762 .22938 Mdot
.762 .23 Mdot
.762 .23046 Mdot
.762 .23101 Mdot
.762 .23113 Mdot
.762 .23122 Mdot
.762 .23133 Mdot
.762 .23143 Mdot
.762 .23151 Mdot
.762 .23207 Mdot
.762 .23272 Mdot
.762 .2338 Mdot
.762 .23423 Mdot
.762 .23467 Mdot
.762 .23475 Mdot
.762 .23498 Mdot
.762 .23508 Mdot
.762 .23509 Mdot
.762 .2351 Mdot
.762 .23549 Mdot
.762 .23582 Mdot
.762 .23739 Mdot
.762 .23763 Mdot
.762 .23809 Mdot
.762 .23855 Mdot
.762 .23868 Mdot
.762 .23895 Mdot
.762 .23958 Mdot
.762 .24015 Mdot
.762 .24075 Mdot
.762 .24164 Mdot
.762 .24219 Mdot
.762 .24259 Mdot
.762 .24317 Mdot
.762 .24319 Mdot
.762 .24375 Mdot
.762 .24549 Mdot
.762 .2456 Mdot
.762 .24594 Mdot
.762 .2463 Mdot
.762 .24658 Mdot
.762 .24717 Mdot
.762 .24767 Mdot
.762 .24769 Mdot
.762 .24853 Mdot
.762 .24887 Mdot
.762 .24935 Mdot
.762 .24952 Mdot
.762 .24958 Mdot
.762 .24958 Mdot
.762 .25005 Mdot
.762 .25014 Mdot
.762 .2503 Mdot
.762 .2508 Mdot
.762 .25227 Mdot
.762 .25398 Mdot
.762 .25442 Mdot
.762 .25442 Mdot
.762 .25492 Mdot
.762 .25555 Mdot
.762 .25608 Mdot
.762 .25643 Mdot
.762 .25725 Mdot
.762 .2574 Mdot
.762 .25883 Mdot
.762 .25981 Mdot
.762 .25984 Mdot
.762 .26094 Mdot
.762 .26116 Mdot
.762 .26117 Mdot
.762 .26152 Mdot
.762 .26315 Mdot
.762 .26336 Mdot
.762 .26386 Mdot
.762 .26387 Mdot
.762 .2641 Mdot
.762 .26413 Mdot
.762 .26559 Mdot
.762 .26607 Mdot
.762 .26699 Mdot
.762 .26728 Mdot
.762 .26778 Mdot
.762 .26832 Mdot
.762 .26887 Mdot
.762 .26955 Mdot
.762 .27014 Mdot
.762 .2712 Mdot
.762 .27201 Mdot
.762 .27226 Mdot
.762 .273 Mdot
.762 .27328 Mdot
.762 .27344 Mdot
.762 .27509 Mdot
.762 .27645 Mdot
.762 .27702 Mdot
.762 .27725 Mdot
.762 .27797 Mdot
.762 .28023 Mdot
.762 .28119 Mdot
.762 .28284 Mdot
.762 .28448 Mdot
.762 .28494 Mdot
.762 .28528 Mdot
.762 .28568 Mdot
.762 .287 Mdot
.762 .28708 Mdot
.762 .28906 Mdot
.762 .28974 Mdot
.762 .29025 Mdot
.762 .2904 Mdot
.762 .29175 Mdot
.762 .29203 Mdot
.762 .29218 Mdot
.762 .29307 Mdot
.762 .29363 Mdot
.762 .29381 Mdot
.762 .29459 Mdot
.762 .2953 Mdot
.762 .29637 Mdot
.762 .29641 Mdot
.762 .29752 Mdot
.762 .29757 Mdot
.762 .29783 Mdot
.762 .29788 Mdot
.762 .29801 Mdot
.762 .29904 Mdot
.762 .29905 Mdot
.762 .29946 Mdot
.762 .3001 Mdot
.762 .30115 Mdot
.762 .3026 Mdot
.762 .30325 Mdot
.762 .30357 Mdot
.762 .30379 Mdot
.762 .30605 Mdot
.762 .30709 Mdot
.762 .30829 Mdot
.762 .30856 Mdot
.762 .30881 Mdot
.762 .3094 Mdot
.762 .30955 Mdot
.762 .30975 Mdot
.762 .3101 Mdot
.762 .31156 Mdot
.762 .31189 Mdot
.762 .31209 Mdot
.762 .31214 Mdot
.762 .31281 Mdot
.762 .31325 Mdot
.762 .31338 Mdot
.762 .31357 Mdot
.762 .31518 Mdot
.762 .31522 Mdot
.762 .31528 Mdot
.762 .31537 Mdot
.762 .31587 Mdot
.762 .31691 Mdot
.762 .31783 Mdot
.762 .31862 Mdot
.762 .3206 Mdot
.762 .32061 Mdot
.762 .32113 Mdot
.762 .32145 Mdot
.762 .32252 Mdot
.762 .32298 Mdot
.762 .32354 Mdot
.762 .32403 Mdot
.762 .32493 Mdot
.762 .32505 Mdot
.762 .32585 Mdot
.762 .32692 Mdot
.762 .32719 Mdot
.762 .32882 Mdot
.762 .32882 Mdot
.762 .32899 Mdot
.762 .32899 Mdot
.762 .32918 Mdot
.762 .33009 Mdot
.762 .33028 Mdot
.762 .3303 Mdot
.762 .33053 Mdot
.762 .33068 Mdot
.762 .33074 Mdot
.762 .33326 Mdot
.762 .33365 Mdot
.762 .33419 Mdot
.762 .33438 Mdot
.762 .33439 Mdot
.762 .33481 Mdot
.762 .335 Mdot
.762 .33547 Mdot
.762 .33585 Mdot
.762 .33617 Mdot
.762 .33632 Mdot
.762 .33762 Mdot
.762 .33782 Mdot
.762 .33811 Mdot
.762 .33911 Mdot
.762 .33955 Mdot
.762 .33969 Mdot
.762 .34073 Mdot
.762 .34097 Mdot
.762 .34172 Mdot
.762 .34185 Mdot
.762 .34187 Mdot
.762 .34281 Mdot
.762 .34352 Mdot
.762 .34435 Mdot
.762 .34453 Mdot
.762 .34466 Mdot
.762 .34484 Mdot
.762 .34498 Mdot
.762 .34511 Mdot
.762 .34596 Mdot
.762 .34696 Mdot
.762 .3486 Mdot
.762 .34926 Mdot
.762 .34993 Mdot
.762 .35005 Mdot
.762 .35039 Mdot
.762 .35055 Mdot
.762 .35057 Mdot
.762 .35059 Mdot
.762 .35117 Mdot
.762 .35167 Mdot
.762 .35407 Mdot
.762 .35443 Mdot
.762 .35514 Mdot
.762 .35584 Mdot
.762 .35604 Mdot
.762 .35645 Mdot
.762 .35741 Mdot
.762 .35828 Mdot
.762 .3592 Mdot
.762 .36055 Mdot
.762 .36138 Mdot
.762 .362 Mdot
.762 .36288 Mdot
.762 .36291 Mdot
.762 .36376 Mdot
.762 .36642 Mdot
.762 .36659 Mdot
.762 .3671 Mdot
.762 .36764 Mdot
.762 .36807 Mdot
.762 .36897 Mdot
.762 .36974 Mdot
.762 .36977 Mdot
.762 .37104 Mdot
.762 .37156 Mdot
.762 .37229 Mdot
.762 .37256 Mdot
.762 .37265 Mdot
.762 .37266 Mdot
.762 .37337 Mdot
.762 .3735 Mdot
.762 .37375 Mdot
.762 .37451 Mdot
.762 .37675 Mdot
.762 .37936 Mdot
.762 .38002 Mdot
.762 .38002 Mdot
.762 .38078 Mdot
.762 .38175 Mdot
.762 .38256 Mdot
.762 .38309 Mdot
.762 .38434 Mdot
.762 .38457 Mdot
.762 .38674 Mdot
.762 .38824 Mdot
.762 .38828 Mdot
.762 .38997 Mdot
.762 .39029 Mdot
.762 .39031 Mdot
.762 .39084 Mdot
.762 .39334 Mdot
.762 .39365 Mdot
.762 .39441 Mdot
.762 .39442 Mdot
.762 .39478 Mdot
.762 .39483 Mdot
.762 .39705 Mdot
.762 .39778 Mdot
.762 .39918 Mdot
.762 .39962 Mdot
.762 .40039 Mdot
.762 .40121 Mdot
.762 .40204 Mdot
.762 .40309 Mdot
.762 .40398 Mdot
.762 .40559 Mdot
.762 .40683 Mdot
.762 .40721 Mdot
.762 .40833 Mdot
.762 .40877 Mdot
.762 .40901 Mdot
.762 .41152 Mdot
.762 .4136 Mdot
.762 .41447 Mdot
.762 .41482 Mdot
.762 .41592 Mdot
.762 .41936 Mdot
.762 .42083 Mdot
.762 .42333 Mdot
.762 .42584 Mdot
.762 .42655 Mdot
.762 .42706 Mdot
.762 .42766 Mdot
.762 .42967 Mdot
.762 .42979 Mdot
.762 .43282 Mdot
.762 .43385 Mdot
.762 .43462 Mdot
.762 .43486 Mdot
.762 .43691 Mdot
.762 .43734 Mdot
.762 .43757 Mdot
.762 .43893 Mdot
.762 .43978 Mdot
.762 .44006 Mdot
.762 .44124 Mdot
.762 .44232 Mdot
.762 .44396 Mdot
.762 .44401 Mdot
.762 .44571 Mdot
.762 .44579 Mdot
.762 .44618 Mdot
.762 .44627 Mdot
.762 .44646 Mdot
.762 .44803 Mdot
.762 .44804 Mdot
.762 .44866 Mdot
.762 .44964 Mdot
.762 .45125 Mdot
.762 .45344 Mdot
.762 .45444 Mdot
.762 .45492 Mdot
.762 .45526 Mdot
.762 .45872 Mdot
.762 .4603 Mdot
.762 .46212 Mdot
.762 .46254 Mdot
.762 .46292 Mdot
.762 .46382 Mdot
.762 .46404 Mdot
.762 .46435 Mdot
.762 .46487 Mdot
.764 .01516 Mdot
.764 .0154 Mdot
.764 .01575 Mdot
.764 .0163 Mdot
.764 .01714 Mdot
.764 .01788 Mdot
.764 .01842 Mdot
.764 .01852 Mdot
.764 .01901 Mdot
.764 .01954 Mdot
.764 .02014 Mdot
.764 .02038 Mdot
.764 .02053 Mdot
.764 .02127 Mdot
.764 .0216 Mdot
.764 .0218 Mdot
.764 .02209 Mdot
.764 .02212 Mdot
.764 .02278 Mdot
.764 .023 Mdot
.764 .02322 Mdot
.764 .02337 Mdot
.764 .0236 Mdot
.764 .02474 Mdot
.764 .02475 Mdot
.764 .02524 Mdot
.764 .02555 Mdot
.764 .02599 Mdot
.764 .02604 Mdot
.764 .02703 Mdot
.764 .02738 Mdot
.764 .02771 Mdot
.764 .02794 Mdot
.764 .02829 Mdot
.764 .03003 Mdot
.764 .03005 Mdot
.764 .03073 Mdot
.764 .0308 Mdot
.764 .03105 Mdot
.764 .03116 Mdot
.764 .03126 Mdot
.764 .03186 Mdot
.764 .03193 Mdot
.764 .03194 Mdot
.764 .03201 Mdot
.764 .03202 Mdot
.764 .03354 Mdot
.764 .03406 Mdot
.764 .03408 Mdot
.764 .03457 Mdot
.764 .03474 Mdot
.764 .03481 Mdot
.764 .03492 Mdot
.764 .03546 Mdot
.764 .03557 Mdot
.764 .03613 Mdot
.764 .03658 Mdot
.764 .03679 Mdot
.764 .03811 Mdot
.764 .03814 Mdot
.764 .03884 Mdot
.764 .03919 Mdot
.764 .03929 Mdot
.764 .0395 Mdot
.764 .03968 Mdot
.764 .03984 Mdot
.764 .04 Mdot
.764 .04079 Mdot
.764 .04091 Mdot
.764 .04102 Mdot
.764 .04104 Mdot
.764 .04115 Mdot
.764 .04116 Mdot
.764 .04126 Mdot
.764 .04155 Mdot
.764 .0425 Mdot
.764 .04264 Mdot
.764 .04266 Mdot
.764 .04278 Mdot
.764 .04347 Mdot
.764 .04395 Mdot
.764 .04427 Mdot
.764 .04431 Mdot
.764 .04432 Mdot
.764 .04486 Mdot
.764 .04505 Mdot
.764 .04505 Mdot
.764 .04531 Mdot
.764 .04539 Mdot
.764 .04542 Mdot
.764 .04559 Mdot
.764 .04573 Mdot
.764 .04618 Mdot
.764 .04642 Mdot
.764 .04658 Mdot
.764 .04743 Mdot
.764 .04802 Mdot
.764 .04812 Mdot
.764 .04837 Mdot
.764 .04844 Mdot
.764 .04942 Mdot
.764 .05046 Mdot
.764 .05051 Mdot
.764 .05157 Mdot
.764 .05157 Mdot
.764 .05211 Mdot
.764 .05226 Mdot
.764 .05258 Mdot
.764 .05286 Mdot
.764 .05311 Mdot
.764 .05335 Mdot
.764 .05353 Mdot
.764 .05367 Mdot
.764 .05426 Mdot
.764 .05455 Mdot
.764 .05466 Mdot
.764 .05474 Mdot
.764 .0549 Mdot
.764 .05494 Mdot
.764 .05511 Mdot
.764 .05513 Mdot
.764 .05527 Mdot
.764 .05558 Mdot
.764 .05572 Mdot
.764 .05579 Mdot
.764 .05598 Mdot
.764 .05669 Mdot
.764 .05697 Mdot
.764 .05717 Mdot
.764 .05718 Mdot
.764 .05728 Mdot
.764 .05739 Mdot
.764 .05741 Mdot
.764 .05761 Mdot
.764 .05866 Mdot
.764 .05877 Mdot
.764 .05938 Mdot
.764 .05943 Mdot
.764 .05988 Mdot
.764 .05993 Mdot
.764 .05995 Mdot
.764 .05999 Mdot
.764 .06078 Mdot
.764 .06078 Mdot
.764 .06106 Mdot
.764 .06107 Mdot
.764 .06109 Mdot
.764 .06118 Mdot
.764 .06147 Mdot
.764 .06159 Mdot
.764 .06164 Mdot
.764 .06189 Mdot
.764 .06211 Mdot
.764 .06222 Mdot
.764 .0628 Mdot
.764 .06316 Mdot
.764 .06341 Mdot
.764 .06388 Mdot
.764 .0647 Mdot
.764 .0656 Mdot
.764 .06576 Mdot
.764 .06614 Mdot
.764 .06616 Mdot
.764 .06625 Mdot
.764 .06775 Mdot
.764 .06789 Mdot
.764 .06806 Mdot
.764 .06934 Mdot
.764 .06941 Mdot
.764 .06992 Mdot
.764 .07093 Mdot
.764 .07102 Mdot
.764 .07103 Mdot
.764 .07128 Mdot
.764 .07136 Mdot
.764 .07158 Mdot
.764 .07185 Mdot
.764 .07209 Mdot
.764 .07231 Mdot
.764 .07258 Mdot
.764 .07271 Mdot
.764 .073 Mdot
.764 .07338 Mdot
.764 .07375 Mdot
.764 .07389 Mdot
.764 .07403 Mdot
.764 .07407 Mdot
.764 .07424 Mdot
.764 .07432 Mdot
.764 .07439 Mdot
.764 .07486 Mdot
.764 .07513 Mdot
.764 .07558 Mdot
.764 .07576 Mdot
.764 .07578 Mdot
.764 .07587 Mdot
.764 .07592 Mdot
.764 .07612 Mdot
.764 .07618 Mdot
.764 .07643 Mdot
.764 .07647 Mdot
.764 .07669 Mdot
.764 .07698 Mdot
.764 .07716 Mdot
.764 .07728 Mdot
.764 .07737 Mdot
.764 .07748 Mdot
.764 .07777 Mdot
.764 .07885 Mdot
.764 .07909 Mdot
.764 .07928 Mdot
.764 .07957 Mdot
.764 .07958 Mdot
.764 .0796 Mdot
.764 .07976 Mdot
.764 .07992 Mdot
.764 .07995 Mdot
.764 .08025 Mdot
.764 .08153 Mdot
.764 .08156 Mdot
.764 .08186 Mdot
.764 .08203 Mdot
.764 .08207 Mdot
.764 .08296 Mdot
.764 .08303 Mdot
.764 .08304 Mdot
.764 .08324 Mdot
.764 .08373 Mdot
.764 .0838 Mdot
.764 .08383 Mdot
.764 .0839 Mdot
.764 .08402 Mdot
.764 .08407 Mdot
.764 .08484 Mdot
.764 .0851 Mdot
.764 .08511 Mdot
.764 .0852 Mdot
.764 .08547 Mdot
.764 .08554 Mdot
.764 .08555 Mdot
.764 .08557 Mdot
.764 .08559 Mdot
.764 .08572 Mdot
.764 .08572 Mdot
.764 .08615 Mdot
.764 .08634 Mdot
.764 .08641 Mdot
.764 .0868 Mdot
.764 .08713 Mdot
.764 .0873 Mdot
.764 .08812 Mdot
.764 .08816 Mdot
.764 .08819 Mdot
.764 .0883 Mdot
.764 .08874 Mdot
.764 .08912 Mdot
.764 .08984 Mdot
.764 .0911 Mdot
.764 .09247 Mdot
.764 .09254 Mdot
.764 .0927 Mdot
.764 .09303 Mdot
.764 .09326 Mdot
.764 .09329 Mdot
.764 .09332 Mdot
.764 .09346 Mdot
.764 .09575 Mdot
.764 .09596 Mdot
.764 .09623 Mdot
.764 .09712 Mdot
.764 .09723 Mdot
.764 .09768 Mdot
.764 .09818 Mdot
.764 .09829 Mdot
.764 .09907 Mdot
.764 .09916 Mdot
.764 .10061 Mdot
.764 .10074 Mdot
.764 .10075 Mdot
.764 .10077 Mdot
.764 .10115 Mdot
.764 .10127 Mdot
.764 .10161 Mdot
.764 .10202 Mdot
.764 .10238 Mdot
.764 .10272 Mdot
.764 .10296 Mdot
.764 .10313 Mdot
.764 .10316 Mdot
.764 .10322 Mdot
.764 .10337 Mdot
.764 .10377 Mdot
.764 .10436 Mdot
.764 .10472 Mdot
.764 .10485 Mdot
.764 .10492 Mdot
.764 .10513 Mdot
.764 .10535 Mdot
.764 .10541 Mdot
.764 .10568 Mdot
.764 .1058 Mdot
.764 .1059 Mdot
.764 .10605 Mdot
.764 .10631 Mdot
.764 .10661 Mdot
.764 .10703 Mdot
.764 .10772 Mdot
.764 .10797 Mdot
.764 .10799 Mdot
.764 .10803 Mdot
.764 .10816 Mdot
.764 .10823 Mdot
.764 .10854 Mdot
.764 .10863 Mdot
.764 .1088 Mdot
.764 .10902 Mdot
.764 .10907 Mdot
.764 .10941 Mdot
.764 .10986 Mdot
.764 .11013 Mdot
.764 .11031 Mdot
.764 .11046 Mdot
.764 .11058 Mdot
.764 .1106 Mdot
.764 .11062 Mdot
.764 .11106 Mdot
.764 .11271 Mdot
.764 .11281 Mdot
.764 .11309 Mdot
.764 .11338 Mdot
.764 .11382 Mdot
.764 .11383 Mdot
.764 .11386 Mdot
.764 .11411 Mdot
.764 .11435 Mdot
.764 .1144 Mdot
.764 .11485 Mdot
.764 .1168 Mdot
.764 .11685 Mdot
.764 .11731 Mdot
.764 .11756 Mdot
.764 .11764 Mdot
.764 .119 Mdot
.764 .1191 Mdot
.764 .11911 Mdot
.764 .11941 Mdot
.764 .11942 Mdot
.764 .1197 Mdot
.764 .12017 Mdot
.764 .12028 Mdot
.764 .12033 Mdot
.764 .12043 Mdot
.764 .12061 Mdot
.764 .12069 Mdot
.764 .12186 Mdot
.764 .12219 Mdot
.764 .12226 Mdot
.764 .12227 Mdot
.764 .12242 Mdot
.764 .12283 Mdot
.764 .12293 Mdot
.764 .12295 Mdot
.764 .12299 Mdot
.764 .12301 Mdot
.764 .12321 Mdot
.764 .12322 Mdot
.764 .12357 Mdot
.764 .12387 Mdot
.764 .12397 Mdot
.764 .12416 Mdot
.764 .12426 Mdot
.764 .12485 Mdot
.764 .12537 Mdot
.764 .12562 Mdot
.764 .12687 Mdot
.764 .12693 Mdot
.764 .12698 Mdot
.764 .12715 Mdot
.764 .12782 Mdot
.764 .1284 Mdot
.764 .1295 Mdot
.764 .13139 Mdot
.764 .13143 Mdot
.764 .13195 Mdot
.764 .13202 Mdot
.764 .13229 Mdot
.764 .13343 Mdot
.764 .13352 Mdot
.764 .13364 Mdot
.764 .13365 Mdot
.764 .13368 Mdot
.764 .13388 Mdot
.764 .13435 Mdot
.764 .13438 Mdot
.764 .13473 Mdot
.764 .13478 Mdot
.764 .13483 Mdot
.764 .13504 Mdot
.764 .1352 Mdot
.764 .13776 Mdot
.764 .13778 Mdot
.764 .13839 Mdot
.764 .13854 Mdot
.764 .13863 Mdot
.764 .13886 Mdot
.764 .13921 Mdot
.764 .13927 Mdot
.764 .14018 Mdot
.764 .14063 Mdot
.764 .14063 Mdot
.764 .1408 Mdot
.764 .14148 Mdot
.764 .14224 Mdot
.764 .14242 Mdot
.764 .14362 Mdot
.764 .14374 Mdot
.764 .14597 Mdot
.764 .14616 Mdot
.764 .14618 Mdot
.764 .14621 Mdot
.764 .14679 Mdot
.764 .14697 Mdot
.764 .14699 Mdot
.764 .14748 Mdot
.764 .14812 Mdot
.764 .14866 Mdot
.764 .1488 Mdot
.764 .14914 Mdot
.764 .14919 Mdot
.764 .14922 Mdot
.764 .14955 Mdot
.764 .14981 Mdot
.764 .14986 Mdot
.764 .14996 Mdot
.764 .15005 Mdot
.764 .15018 Mdot
.764 .15069 Mdot
.764 .15079 Mdot
.764 .15169 Mdot
.764 .15224 Mdot
.764 .15228 Mdot
.764 .15244 Mdot
.764 .15255 Mdot
.764 .15281 Mdot
.764 .15287 Mdot
.764 .15292 Mdot
.764 .15312 Mdot
.764 .1532 Mdot
.764 .15326 Mdot
.764 .15329 Mdot
.764 .1537 Mdot
.764 .15389 Mdot
.764 .15405 Mdot
.764 .15427 Mdot
.764 .15436 Mdot
.764 .15438 Mdot
.764 .15467 Mdot
.764 .15514 Mdot
.764 .15578 Mdot
.764 .15631 Mdot
.764 .15683 Mdot
.764 .15721 Mdot
.764 .15723 Mdot
.764 .1573 Mdot
.764 .1575 Mdot
.764 .15761 Mdot
.764 .15794 Mdot
.764 .15808 Mdot
.764 .15822 Mdot
.764 .15847 Mdot
.764 .15851 Mdot
.764 .15881 Mdot
.764 .15889 Mdot
.764 .1594 Mdot
.764 .15954 Mdot
.764 .16008 Mdot
.764 .16009 Mdot
.764 .16051 Mdot
.764 .16078 Mdot
.764 .16101 Mdot
.764 .16119 Mdot
.764 .16122 Mdot
.764 .16126 Mdot
.764 .16193 Mdot
.764 .16198 Mdot
.764 .16331 Mdot
.764 .16445 Mdot
.764 .16449 Mdot
.764 .16461 Mdot
.764 .16503 Mdot
.764 .16547 Mdot
.764 .16609 Mdot
.764 .16615 Mdot
.764 .16617 Mdot
.764 .16621 Mdot
.764 .16658 Mdot
.764 .16696 Mdot
.764 .16703 Mdot
.764 .1675 Mdot
.764 .16773 Mdot
.764 .1707 Mdot
.764 .17078 Mdot
.764 .17148 Mdot
.764 .17187 Mdot
.764 .17198 Mdot
.764 .17406 Mdot
.764 .17422 Mdot
.764 .17424 Mdot
.764 .17431 Mdot
.764 .17463 Mdot
.764 .1747 Mdot
.764 .1747 Mdot
.764 .17489 Mdot
.764 .17513 Mdot
.764 .17585 Mdot
.764 .17585 Mdot
.764 .17602 Mdot
.764 .17609 Mdot
.764 .17625 Mdot
.764 .17652 Mdot
.764 .17665 Mdot
.764 .17843 Mdot
.764 .17894 Mdot
.764 .17904 Mdot
.764 .17906 Mdot
.764 .17929 Mdot
.764 .17947 Mdot
.764 .17992 Mdot
.764 .18007 Mdot
.764 .1801 Mdot
.764 .18015 Mdot
.764 .18019 Mdot
.764 .1805 Mdot
.764 .18051 Mdot
.764 .18105 Mdot
.764 .1815 Mdot
.764 .18166 Mdot
.764 .18195 Mdot
.764 .1821 Mdot
.764 .18264 Mdot
.764 .18301 Mdot
.764 .18334 Mdot
.764 .18379 Mdot
.764 .18418 Mdot
.764 .18609 Mdot
.764 .18618 Mdot
.764 .18626 Mdot
.764 .18652 Mdot
.764 .18754 Mdot
.764 .18843 Mdot
.764 .18862 Mdot
.764 .1901 Mdot
.764 .193 Mdot
.764 .19306 Mdot
.764 .19385 Mdot
.764 .19395 Mdot
.764 .19437 Mdot
.764 .19611 Mdot
.764 .19625 Mdot
.764 .19643 Mdot
.764 .19645 Mdot
.764 .19649 Mdot
.764 .1968 Mdot
.764 .19752 Mdot
.764 .19756 Mdot
.764 .1981 Mdot
.764 .19817 Mdot
.764 .19825 Mdot
.764 .19857 Mdot
.764 .19882 Mdot
.764 .19895 Mdot
.764 .19915 Mdot
.764 .20198 Mdot
.764 .20235 Mdot
.764 .20272 Mdot
.764 .20275 Mdot
.764 .20368 Mdot
.764 .20382 Mdot
.764 .20392 Mdot
.764 .20406 Mdot
.764 .20442 Mdot
.764 .20494 Mdot
.764 .20503 Mdot
.764 .20642 Mdot
.764 .20711 Mdot
.764 .20711 Mdot
.764 .20738 Mdot
.764 .20841 Mdot
.764 .20958 Mdot
.764 .20985 Mdot
.764 .21006 Mdot
.764 .21055 Mdot
.764 .21117 Mdot
.764 .21126 Mdot
.764 .2114 Mdot
.764 .21168 Mdot
.764 .21187 Mdot
.764 .21252 Mdot
.764 .21508 Mdot
.764 .21522 Mdot
.764 .21527 Mdot
.764 .21557 Mdot
.764 .2156 Mdot
.764 .21564 Mdot
.764 .21652 Mdot
.764 .2168 Mdot
.764 .21683 Mdot
.764 .21716 Mdot
.764 .21739 Mdot
.764 .21759 Mdot
.764 .21768 Mdot
.764 .21856 Mdot
.764 .21884 Mdot
.764 .21939 Mdot
.764 .21959 Mdot
.764 .21972 Mdot
.764 .22012 Mdot
.764 .22019 Mdot
.764 .22019 Mdot
.764 .22025 Mdot
.764 .22074 Mdot
.764 .2209 Mdot
.764 .22113 Mdot
.764 .22122 Mdot
.764 .22136 Mdot
.764 .22151 Mdot
.764 .2217 Mdot
.764 .22249 Mdot
.764 .22264 Mdot
.764 .22309 Mdot
.764 .22401 Mdot
.764 .22485 Mdot
.764 .22491 Mdot
.764 .22516 Mdot
.764 .22533 Mdot
.764 .22573 Mdot
.764 .22582 Mdot
.764 .2259 Mdot
.764 .2262 Mdot
.764 .22632 Mdot
.764 .22641 Mdot
.764 .22646 Mdot
.764 .22709 Mdot
.764 .22738 Mdot
.764 .22762 Mdot
.764 .22795 Mdot
.764 .22809 Mdot
.764 .22813 Mdot
.764 .22857 Mdot
.764 .22928 Mdot
.764 .23026 Mdot
.764 .231 Mdot
.764 .23107 Mdot
.764 .23187 Mdot
.764 .2323 Mdot
.764 .23245 Mdot
.764 .23249 Mdot
.764 .23258 Mdot
.764 .23289 Mdot
.764 .23306 Mdot
.764 .23357 Mdot
.764 .23364 Mdot
.764 .23375 Mdot
.764 .23378 Mdot
.764 .23398 Mdot
.764 .23438 Mdot
.764 .23444 Mdot
.764 .23489 Mdot
.764 .23502 Mdot
.764 .2358 Mdot
.764 .236 Mdot
.764 .23684 Mdot
.764 .23685 Mdot
.764 .23707 Mdot
.764 .23748 Mdot
.764 .23757 Mdot
.764 .23791 Mdot
.764 .23793 Mdot
.764 .23826 Mdot
.764 .23841 Mdot
.764 .23853 Mdot
.764 .23858 Mdot
.764 .23864 Mdot
.764 .23966 Mdot
.764 .23968 Mdot
.764 .23974 Mdot
.764 .24156 Mdot
.764 .24177 Mdot
.764 .24187 Mdot
.764 .24352 Mdot
.764 .24357 Mdot
.764 .24376 Mdot
.764 .24439 Mdot
.764 .24507 Mdot
.764 .24602 Mdot
.764 .24611 Mdot
.764 .24613 Mdot
.764 .24619 Mdot
.764 .24677 Mdot
.764 .24683 Mdot
.764 .24734 Mdot
.764 .24745 Mdot
.764 .24817 Mdot
.764 .24852 Mdot
.764 .24928 Mdot
.764 .24929 Mdot
.764 .25024 Mdot
.764 .25307 Mdot
.764 .25319 Mdot
.764 .25426 Mdot
.764 .25485 Mdot
.764 .25502 Mdot
.764 .2582 Mdot
.764 .25844 Mdot
.764 .25846 Mdot
.764 .25858 Mdot
.764 .25907 Mdot
.764 .25916 Mdot
.764 .25918 Mdot
.764 .25946 Mdot
.764 .25983 Mdot
.764 .26092 Mdot
.764 .26093 Mdot
.764 .26119 Mdot
.764 .2613 Mdot
.764 .26154 Mdot
.764 .26196 Mdot
.764 .26215 Mdot
.764 .26488 Mdot
.764 .26565 Mdot
.764 .2658 Mdot
.764 .26583 Mdot
.764 .26619 Mdot
.764 .26646 Mdot
.764 .26714 Mdot
.764 .26737 Mdot
.764 .26742 Mdot
.764 .2675 Mdot
.764 .26756 Mdot
.764 .26803 Mdot
.764 .26804 Mdot
.764 .26887 Mdot
.764 .26957 Mdot
.764 .26981 Mdot
.764 .27025 Mdot
.764 .27049 Mdot
.764 .2713 Mdot
.764 .27187 Mdot
.764 .27237 Mdot
.764 .27306 Mdot
.764 .27366 Mdot
.764 .27658 Mdot
.764 .27672 Mdot
.764 .27683 Mdot
.764 .27724 Mdot
.764 .27879 Mdot
.764 .28015 Mdot
.764 .28045 Mdot
.764 .28271 Mdot
.764 .28713 Mdot
.764 .28722 Mdot
.764 .28843 Mdot
.764 .28859 Mdot
.764 .28922 Mdot
.764 .29189 Mdot
.764 .2921 Mdot
.764 .29237 Mdot
.764 .2924 Mdot
.764 .29246 Mdot
.764 .29295 Mdot
.764 .29404 Mdot
.764 .2941 Mdot
.764 .29493 Mdot
.764 .29503 Mdot
.764 .29515 Mdot
.764 .29565 Mdot
.764 .29603 Mdot
.764 .29623 Mdot
.764 .29654 Mdot
.764 .30086 Mdot
.764 .30142 Mdot
.764 .30199 Mdot
.764 .30204 Mdot
.764 .30346 Mdot
.764 .30367 Mdot
.764 .30383 Mdot
.764 .30404 Mdot
.764 .30458 Mdot
.764 .30538 Mdot
.764 .30551 Mdot
.764 .30764 Mdot
.764 .30869 Mdot
.764 .30869 Mdot
.764 .3091 Mdot
.764 .31069 Mdot
.764 .31246 Mdot
.764 .31289 Mdot
.764 .3132 Mdot
.764 .31394 Mdot
.764 .3149 Mdot
.764 .31503 Mdot
.764 .31525 Mdot
.764 .31567 Mdot
.764 .31596 Mdot
.764 .31696 Mdot
.764 .32088 Mdot
.764 .32109 Mdot
.764 .32116 Mdot
.764 .32161 Mdot
.764 .32166 Mdot
.764 .32172 Mdot
.764 .32307 Mdot
.764 .3235 Mdot
.764 .32355 Mdot
.764 .32404 Mdot
.764 .32441 Mdot
.764 .3247 Mdot
.764 .32484 Mdot
.764 .32618 Mdot
.764 .32661 Mdot
.764 .32746 Mdot
.764 .32777 Mdot
.764 .32796 Mdot
.764 .32858 Mdot
.764 .32867 Mdot
.764 .32868 Mdot
.764 .32877 Mdot
.764 .32953 Mdot
.764 .32977 Mdot
.764 .33012 Mdot
.764 .33025 Mdot
.764 .33047 Mdot
.764 .33069 Mdot
.764 .33099 Mdot
.764 .33219 Mdot
.764 .33242 Mdot
.764 .33311 Mdot
.764 .33451 Mdot
.764 .3358 Mdot
.764 .33589 Mdot
.764 .33627 Mdot
.764 .33654 Mdot
.764 .33714 Mdot
.764 .33728 Mdot
.764 .3374 Mdot
.764 .33787 Mdot
.764 .33805 Mdot
.764 .33819 Mdot
.764 .33826 Mdot
.764 .33923 Mdot
.764 .33966 Mdot
.764 .34003 Mdot
.764 .34054 Mdot
.764 .34074 Mdot
.764 .34081 Mdot
.764 .34148 Mdot
.764 .34257 Mdot
.764 .34406 Mdot
.764 .3452 Mdot
.764 .34531 Mdot
.764 .34653 Mdot
.764 .34719 Mdot
.764 .34742 Mdot
.764 .34747 Mdot
.764 .34761 Mdot
.764 .34809 Mdot
.764 .34835 Mdot
.764 .34912 Mdot
.764 .34924 Mdot
.764 .34941 Mdot
.764 .34945 Mdot
.764 .34976 Mdot
.764 .35036 Mdot
.764 .35045 Mdot
.764 .35115 Mdot
.764 .35134 Mdot
.764 .35253 Mdot
.764 .35284 Mdot
.764 .35412 Mdot
.764 .35414 Mdot
.764 .35448 Mdot
.764 .35511 Mdot
.764 .35524 Mdot
.764 .35575 Mdot
.764 .35579 Mdot
.764 .35629 Mdot
.764 .35653 Mdot
.764 .3567 Mdot
.764 .35678 Mdot
.764 .35687 Mdot
.764 .35843 Mdot
.764 .35846 Mdot
.764 .35855 Mdot
.764 .36133 Mdot
.764 .36165 Mdot
.764 .3618 Mdot
.764 .36432 Mdot
.764 .3644 Mdot
.764 .36469 Mdot
.764 .36566 Mdot
.764 .3667 Mdot
.764 .36815 Mdot
.764 .36828 Mdot
.764 .36832 Mdot
.764 .36842 Mdot
.764 .3693 Mdot
.764 .36938 Mdot
.764 .37017 Mdot
.764 .37034 Mdot
.764 .37143 Mdot
.764 .37197 Mdot
.764 .37313 Mdot
.764 .37315 Mdot
.764 .3746 Mdot
.764 .37892 Mdot
.764 .3791 Mdot
.764 .38073 Mdot
.764 .38164 Mdot
.764 .3819 Mdot
.764 .38676 Mdot
.764 .38712 Mdot
.764 .38716 Mdot
.764 .38734 Mdot
.764 .38809 Mdot
.764 .38823 Mdot
.764 .38825 Mdot
.764 .38869 Mdot
.764 .38925 Mdot
.764 .39092 Mdot
.764 .39093 Mdot
.764 .39133 Mdot
.764 .39149 Mdot
.764 .39187 Mdot
.764 .3925 Mdot
.764 .3928 Mdot
.764 .39696 Mdot
.764 .39815 Mdot
.764 .39837 Mdot
.764 .39843 Mdot
.764 .39897 Mdot
.764 .39939 Mdot
.764 .40042 Mdot
.764 .40077 Mdot
.764 .40085 Mdot
.764 .40098 Mdot
.764 .40107 Mdot
.764 .40178 Mdot
.764 .4018 Mdot
.764 .40306 Mdot
.764 .40413 Mdot
.764 .4045 Mdot
.764 .40518 Mdot
.764 .40553 Mdot
.764 .40678 Mdot
.764 .40764 Mdot
.764 .40841 Mdot
.764 .40946 Mdot
.764 .41038 Mdot
.764 .41484 Mdot
.764 .41505 Mdot
.764 .41522 Mdot
.764 .41585 Mdot
.764 .41822 Mdot
.764 .42029 Mdot
.764 .42075 Mdot
.764 .42421 Mdot
.764 .43097 Mdot
.764 .4311 Mdot
.764 .43295 Mdot
.764 .43319 Mdot
.764 .43416 Mdot
.764 .43824 Mdot
.764 .43856 Mdot
.764 .43897 Mdot
.764 .43902 Mdot
.764 .43911 Mdot
.764 .43985 Mdot
.764 .44153 Mdot
.764 .44162 Mdot
.764 .44288 Mdot
.764 .44304 Mdot
.764 .44323 Mdot
.764 .44398 Mdot
.764 .44456 Mdot
.764 .44487 Mdot
.764 .44534 Mdot
.764 .45194 Mdot
.764 .4528 Mdot
.764 .45367 Mdot
.764 .45375 Mdot
.764 .45592 Mdot
.764 .45625 Mdot
.764 .45648 Mdot
.764 .4568 Mdot
.764 .45762 Mdot
.764 .45885 Mdot
.764 .45905 Mdot
.764 .4623 Mdot
.764 .46391 Mdot
.764 .46391 Mdot
.764 .46454 Mdot
.766 .0151 Mdot
.766 .01513 Mdot
.766 .0153 Mdot
.766 .01534 Mdot
.766 .01562 Mdot
.766 .01565 Mdot
.766 .01568 Mdot
.766 .0158 Mdot
.766 .01609 Mdot
.766 .01615 Mdot
.766 .01619 Mdot
.766 .01638 Mdot
.766 .01683 Mdot
.766 .01691 Mdot
.766 .01697 Mdot
.766 .01727 Mdot
.766 .01734 Mdot
.766 .01795 Mdot
.766 .01808 Mdot
.766 .01818 Mdot
.766 .01828 Mdot
.766 .01854 Mdot
.766 .01863 Mdot
.766 .01874 Mdot
.766 .01933 Mdot
.766 .01967 Mdot
.766 .01986 Mdot
.766 .02002 Mdot
.766 .02018 Mdot
.766 .02057 Mdot
.766 .02072 Mdot
.766 .02078 Mdot
.766 .02088 Mdot
.766 .02108 Mdot
.766 .0213 Mdot
.766 .02147 Mdot
.766 .02179 Mdot
.766 .02231 Mdot
.766 .0226 Mdot
.766 .02284 Mdot
.766 .02309 Mdot
.766 .02347 Mdot
.766 .02369 Mdot
.766 .02391 Mdot
.766 .02399 Mdot
.766 .02401 Mdot
.766 .02416 Mdot
.766 .02447 Mdot
.766 .0248 Mdot
.766 .02506 Mdot
.766 .02556 Mdot
.766 .02635 Mdot
.766 .0268 Mdot
.766 .02716 Mdot
.766 .02755 Mdot
.766 .02812 Mdot
.766 .02847 Mdot
.766 .0288 Mdot
.766 .02892 Mdot
.766 .02895 Mdot
.766 .02919 Mdot
.766 .02966 Mdot
.766 .03016 Mdot
.766 .03038 Mdot
.766 .03045 Mdot
.766 .03057 Mdot
.766 .03115 Mdot
.766 .03118 Mdot
.766 .03132 Mdot
.766 .0322 Mdot
.766 .03254 Mdot
.766 .03323 Mdot
.766 .03338 Mdot
.766 .03378 Mdot
.766 .03407 Mdot
.766 .03437 Mdot
.766 .03517 Mdot
.766 .03526 Mdot
.766 .03578 Mdot
.766 .03629 Mdot
.766 .03653 Mdot
.766 .03689 Mdot
.766 .03699 Mdot
.766 .0371 Mdot
.766 .03735 Mdot
.766 .0376 Mdot
.766 .03793 Mdot
.766 .03838 Mdot
.766 .03871 Mdot
.766 .03881 Mdot
.766 .039 Mdot
.766 .03902 Mdot
.766 .03906 Mdot
.766 .03981 Mdot
.766 .03989 Mdot
.766 .03994 Mdot
.766 .04016 Mdot
.766 .04151 Mdot
.766 .04202 Mdot
.766 .04234 Mdot
.766 .04234 Mdot
.766 .04278 Mdot
.766 .04305 Mdot
.766 .04308 Mdot
.766 .0433 Mdot
.766 .04392 Mdot
.766 .04393 Mdot
.766 .04436 Mdot
.766 .04439 Mdot
.766 .04456 Mdot
.766 .04483 Mdot
.766 .04568 Mdot
.766 .04578 Mdot
.766 .04605 Mdot
.766 .04612 Mdot
.766 .04614 Mdot
.766 .04619 Mdot
.766 .04684 Mdot
.766 .04699 Mdot
.766 .04735 Mdot
.766 .04777 Mdot
.766 .04813 Mdot
.766 .04868 Mdot
.766 .04884 Mdot
.766 .04901 Mdot
.766 .0494 Mdot
.766 .04978 Mdot
.766 .05027 Mdot
.766 .05043 Mdot
.766 .05096 Mdot
.766 .05148 Mdot
.766 .05148 Mdot
.766 .05164 Mdot
.766 .05192 Mdot
.766 .05194 Mdot
.766 .05201 Mdot
.766 .05205 Mdot
.766 .05317 Mdot
.766 .05328 Mdot
.766 .05335 Mdot
.766 .0537 Mdot
.766 .05445 Mdot
.766 .05576 Mdot
.766 .05655 Mdot
.766 .05703 Mdot
.766 .05704 Mdot
.766 .05771 Mdot
.766 .05813 Mdot
.766 .05817 Mdot
.766 .05837 Mdot
.766 .05851 Mdot
.766 .05872 Mdot
.766 .05885 Mdot
.766 .05945 Mdot
.766 .05947 Mdot
.766 .05991 Mdot
.766 .06014 Mdot
.766 .06017 Mdot
.766 .0602 Mdot
.766 .06035 Mdot
.766 .06044 Mdot
.766 .06086 Mdot
.766 .06127 Mdot
.766 .06161 Mdot
.766 .06215 Mdot
.766 .0623 Mdot
.766 .06272 Mdot
.766 .06282 Mdot
.766 .06283 Mdot
.766 .06286 Mdot
.766 .06293 Mdot
.766 .06393 Mdot
.766 .06407 Mdot
.766 .06416 Mdot
.766 .06471 Mdot
.766 .06535 Mdot
.766 .0657 Mdot
.766 .06591 Mdot
.766 .06675 Mdot
.766 .06686 Mdot
.766 .06699 Mdot
.766 .06725 Mdot
.766 .06785 Mdot
.766 .06844 Mdot
.766 .06911 Mdot
.766 .06919 Mdot
.766 .06943 Mdot
.766 .07025 Mdot
.766 .07034 Mdot
.766 .07103 Mdot
.766 .07104 Mdot
.766 .07128 Mdot
.766 .07172 Mdot
.766 .07175 Mdot
.766 .07185 Mdot
.766 .07191 Mdot
.766 .07362 Mdot
.766 .07375 Mdot
.766 .0738 Mdot
.766 .07391 Mdot
.766 .07443 Mdot
.766 .07539 Mdot
.766 .07558 Mdot
.766 .07638 Mdot
.766 .07748 Mdot
.766 .0776 Mdot
.766 .07761 Mdot
.766 .07793 Mdot
.766 .07851 Mdot
.766 .07881 Mdot
.766 .07954 Mdot
.766 .07955 Mdot
.766 .08012 Mdot
.766 .08042 Mdot
.766 .08058 Mdot
.766 .08087 Mdot
.766 .08123 Mdot
.766 .08129 Mdot
.766 .08159 Mdot
.766 .08181 Mdot
.766 .08209 Mdot
.766 .08213 Mdot
.766 .08232 Mdot
.766 .08326 Mdot
.766 .08327 Mdot
.766 .08396 Mdot
.766 .0843 Mdot
.766 .08436 Mdot
.766 .0844 Mdot
.766 .08463 Mdot
.766 .08476 Mdot
.766 .08477 Mdot
.766 .08487 Mdot
.766 .0854 Mdot
.766 .08604 Mdot
.766 .08656 Mdot
.766 .08664 Mdot
.766 .08739 Mdot
.766 .08762 Mdot
.766 .08825 Mdot
.766 .08841 Mdot
.766 .08841 Mdot
.766 .08842 Mdot
.766 .08847 Mdot
.766 .08856 Mdot
.766 .08858 Mdot
.766 .09012 Mdot
.766 .09032 Mdot
.766 .09046 Mdot
.766 .09131 Mdot
.766 .0914 Mdot
.766 .09159 Mdot
.766 .09229 Mdot
.766 .09243 Mdot
.766 .09249 Mdot
.766 .09266 Mdot
.766 .09283 Mdot
.766 .09288 Mdot
.766 .09315 Mdot
.766 .09443 Mdot
.766 .09444 Mdot
.766 .0946 Mdot
.766 .0948 Mdot
.766 .0948 Mdot
.766 .0952 Mdot
.766 .09521 Mdot
.766 .09612 Mdot
.766 .09702 Mdot
.766 .09715 Mdot
.766 .09805 Mdot
.766 .0981 Mdot
.766 .09817 Mdot
.766 .09854 Mdot
.766 .09979 Mdot
.766 .09993 Mdot
.766 .09994 Mdot
.766 .10012 Mdot
.766 .10099 Mdot
.766 .10101 Mdot
.766 .10106 Mdot
.766 .10137 Mdot
.766 .10204 Mdot
.766 .10209 Mdot
.766 .10225 Mdot
.766 .10233 Mdot
.766 .10265 Mdot
.766 .10343 Mdot
.766 .10496 Mdot
.766 .10515 Mdot
.766 .10523 Mdot
.766 .1054 Mdot
.766 .1062 Mdot
.766 .10682 Mdot
.766 .10766 Mdot
.766 .10796 Mdot
.766 .10882 Mdot
.766 .10888 Mdot
.766 .10918 Mdot
.766 .11087 Mdot
.766 .1109 Mdot
.766 .11106 Mdot
.766 .11107 Mdot
.766 .11149 Mdot
.766 .11156 Mdot
.766 .11245 Mdot
.766 .11262 Mdot
.766 .11291 Mdot
.766 .11305 Mdot
.766 .11367 Mdot
.766 .11403 Mdot
.766 .11404 Mdot
.766 .11491 Mdot
.766 .11538 Mdot
.766 .1155 Mdot
.766 .11563 Mdot
.766 .11607 Mdot
.766 .11626 Mdot
.766 .11661 Mdot
.766 .1167 Mdot
.766 .11671 Mdot
.766 .11679 Mdot
.766 .11693 Mdot
.766 .11717 Mdot
.766 .1175 Mdot
.766 .11761 Mdot
.766 .11794 Mdot
.766 .118 Mdot
.766 .11829 Mdot
.766 .11863 Mdot
.766 .11972 Mdot
.766 .11975 Mdot
.766 .12005 Mdot
.766 .12029 Mdot
.766 .1208 Mdot
.766 .12109 Mdot
.766 .12133 Mdot
.766 .12141 Mdot
.766 .12147 Mdot
.766 .12182 Mdot
.766 .12202 Mdot
.766 .12204 Mdot
.766 .12219 Mdot
.766 .12231 Mdot
.766 .12301 Mdot
.766 .12304 Mdot
.766 .12345 Mdot
.766 .12354 Mdot
.766 .12355 Mdot
.766 .12398 Mdot
.766 .12403 Mdot
.766 .12476 Mdot
.766 .12478 Mdot
.766 .12491 Mdot
.766 .12605 Mdot
.766 .12612 Mdot
.766 .1264 Mdot
.766 .12738 Mdot
.766 .12761 Mdot
.766 .12761 Mdot
.766 .12764 Mdot
.766 .12771 Mdot
.766 .12785 Mdot
.766 .12788 Mdot
.766 .12795 Mdot
.766 .12851 Mdot
.766 .13023 Mdot
.766 .13035 Mdot
.766 .13054 Mdot
.766 .13068 Mdot
.766 .13076 Mdot
.766 .13206 Mdot
.766 .13219 Mdot
.766 .13228 Mdot
.766 .13249 Mdot
.766 .13343 Mdot
.766 .13357 Mdot
.766 .13378 Mdot
.766 .13387 Mdot
.766 .13412 Mdot
.766 .13412 Mdot
.766 .13439 Mdot
.766 .13447 Mdot
.766 .13487 Mdot
.766 .13571 Mdot
.766 .13684 Mdot
.766 .13685 Mdot
.766 .1371 Mdot
.766 .1374 Mdot
.766 .13741 Mdot
.766 .13801 Mdot
.766 .13803 Mdot
.766 .13815 Mdot
.766 .13943 Mdot
.766 .13947 Mdot
.766 .14015 Mdot
.766 .14031 Mdot
.766 .1408 Mdot
.766 .14081 Mdot
.766 .141 Mdot
.766 .14198 Mdot
.766 .14238 Mdot
.766 .14247 Mdot
.766 .14257 Mdot
.766 .14313 Mdot
.766 .14327 Mdot
.766 .14505 Mdot
.766 .14507 Mdot
.766 .14527 Mdot
.766 .14527 Mdot
.766 .14556 Mdot
.766 .14608 Mdot
.766 .14689 Mdot
.766 .14692 Mdot
.766 .14699 Mdot
.766 .14747 Mdot
.766 .14768 Mdot
.766 .1485 Mdot
.766 .14858 Mdot
.766 .14882 Mdot
.766 .14895 Mdot
.766 .149 Mdot
.766 .14943 Mdot
.766 .14944 Mdot
.766 .14977 Mdot
.766 .15063 Mdot
.766 .15175 Mdot
.766 .15284 Mdot
.766 .15294 Mdot
.766 .15297 Mdot
.766 .15327 Mdot
.766 .15339 Mdot
.766 .15364 Mdot
.766 .15374 Mdot
.766 .15442 Mdot
.766 .15488 Mdot
.766 .15582 Mdot
.766 .15711 Mdot
.766 .15757 Mdot
.766 .15785 Mdot
.766 .15828 Mdot
.766 .15844 Mdot
.766 .15889 Mdot
.766 .15897 Mdot
.766 .15944 Mdot
.766 .1607 Mdot
.766 .16119 Mdot
.766 .16123 Mdot
.766 .16202 Mdot
.766 .16208 Mdot
.766 .16231 Mdot
.766 .16233 Mdot
.766 .16297 Mdot
.766 .16308 Mdot
.766 .16362 Mdot
.766 .16389 Mdot
.766 .1644 Mdot
.766 .16445 Mdot
.766 .16471 Mdot
.766 .16515 Mdot
.766 .16537 Mdot
.766 .16631 Mdot
.766 .16687 Mdot
.766 .16688 Mdot
.766 .16793 Mdot
.766 .16805 Mdot
.766 .16822 Mdot
.766 .16873 Mdot
.766 .16894 Mdot
.766 .16906 Mdot
.766 .16909 Mdot
.766 .16912 Mdot
.766 .16931 Mdot
.766 .1696 Mdot
.766 .16999 Mdot
.766 .17028 Mdot
.766 .17082 Mdot
.766 .17094 Mdot
.766 .17096 Mdot
.766 .17096 Mdot
.766 .1711 Mdot
.766 .1713 Mdot
.766 .17168 Mdot
.766 .17219 Mdot
.766 .17234 Mdot
.766 .17286 Mdot
.766 .17295 Mdot
.766 .17339 Mdot
.766 .17371 Mdot
.766 .17391 Mdot
.766 .17435 Mdot
.766 .17503 Mdot
.766 .17539 Mdot
.766 .17558 Mdot
.766 .17563 Mdot
.766 .17577 Mdot
.766 .17609 Mdot
.766 .17645 Mdot
.766 .17695 Mdot
.766 .17723 Mdot
.766 .17767 Mdot
.766 .17804 Mdot
.766 .17816 Mdot
.766 .17826 Mdot
.766 .17881 Mdot
.766 .17911 Mdot
.766 .17914 Mdot
.766 .17936 Mdot
.766 .17955 Mdot
.766 .1805 Mdot
.766 .18062 Mdot
.766 .18067 Mdot
.766 .1813 Mdot
.766 .18143 Mdot
.766 .18145 Mdot
.766 .18211 Mdot
.766 .18218 Mdot
.766 .18232 Mdot
.766 .18331 Mdot
.766 .18334 Mdot
.766 .18353 Mdot
.766 .18362 Mdot
.766 .18363 Mdot
.766 .18377 Mdot
.766 .18414 Mdot
.766 .18492 Mdot
.766 .18509 Mdot
.766 .18528 Mdot
.766 .18538 Mdot
.766 .18549 Mdot
.766 .18582 Mdot
.766 .1868 Mdot
.766 .18731 Mdot
.766 .18767 Mdot
.766 .18767 Mdot
.766 .18771 Mdot
.766 .18782 Mdot
.766 .18803 Mdot
.766 .18808 Mdot
.766 .18819 Mdot
.766 .18856 Mdot
.766 .18904 Mdot
.766 .19168 Mdot
.766 .19187 Mdot
.766 .19216 Mdot
.766 .19238 Mdot
.766 .1925 Mdot
.766 .19448 Mdot
.766 .19468 Mdot
.766 .19483 Mdot
.766 .19515 Mdot
.766 .19658 Mdot
.766 .1968 Mdot
.766 .19712 Mdot
.766 .19725 Mdot
.766 .19765 Mdot
.766 .19765 Mdot
.766 .19804 Mdot
.766 .19805 Mdot
.766 .19818 Mdot
.766 .19873 Mdot
.766 .1988 Mdot
.766 .19976 Mdot
.766 .20007 Mdot
.766 .20055 Mdot
.766 .20097 Mdot
.766 .20181 Mdot
.766 .20183 Mdot
.766 .20221 Mdot
.766 .20267 Mdot
.766 .20269 Mdot
.766 .20361 Mdot
.766 .20364 Mdot
.766 .20382 Mdot
.766 .20577 Mdot
.766 .20584 Mdot
.766 .20688 Mdot
.766 .20712 Mdot
.766 .20788 Mdot
.766 .20789 Mdot
.766 .20812 Mdot
.766 .20818 Mdot
.766 .20884 Mdot
.766 .20935 Mdot
.766 .20969 Mdot
.766 .2103 Mdot
.766 .21043 Mdot
.766 .21052 Mdot
.766 .2106 Mdot
.766 .21145 Mdot
.766 .21167 Mdot
.766 .21439 Mdot
.766 .21442 Mdot
.766 .21472 Mdot
.766 .21473 Mdot
.766 .21517 Mdot
.766 .21567 Mdot
.766 .21596 Mdot
.766 .21643 Mdot
.766 .21721 Mdot
.766 .21726 Mdot
.766 .21736 Mdot
.766 .21761 Mdot
.766 .21807 Mdot
.766 .21809 Mdot
.766 .21841 Mdot
.766 .21949 Mdot
.766 .21949 Mdot
.766 .21968 Mdot
.766 .21979 Mdot
.766 .22016 Mdot
.766 .22036 Mdot
.766 .22043 Mdot
.766 .22091 Mdot
.766 .22095 Mdot
.766 .2211 Mdot
.766 .22111 Mdot
.766 .22141 Mdot
.766 .22162 Mdot
.766 .22294 Mdot
.766 .22338 Mdot
.766 .22362 Mdot
.766 .22465 Mdot
.766 .22632 Mdot
.766 .22647 Mdot
.766 .22652 Mdot
.766 .22698 Mdot
.766 .2271 Mdot
.766 .22716 Mdot
.766 .22755 Mdot
.766 .2277 Mdot
.766 .22821 Mdot
.766 .22875 Mdot
.766 .22944 Mdot
.766 .22994 Mdot
.766 .23089 Mdot
.766 .23142 Mdot
.766 .23287 Mdot
.766 .23357 Mdot
.766 .23399 Mdot
.766 .23446 Mdot
.766 .23452 Mdot
.766 .23465 Mdot
.766 .2349 Mdot
.766 .23558 Mdot
.766 .23572 Mdot
.766 .23591 Mdot
.766 .23643 Mdot
.766 .23757 Mdot
.766 .23761 Mdot
.766 .23836 Mdot
.766 .23912 Mdot
.766 .23918 Mdot
.766 .24039 Mdot
.766 .24047 Mdot
.766 .24083 Mdot
.766 .24086 Mdot
.766 .24093 Mdot
.766 .24102 Mdot
.766 .24168 Mdot
.766 .24184 Mdot
.766 .24201 Mdot
.766 .24284 Mdot
.766 .24325 Mdot
.766 .24403 Mdot
.766 .24411 Mdot
.766 .24451 Mdot
.766 .24518 Mdot
.766 .24552 Mdot
.766 .24696 Mdot
.766 .24781 Mdot
.766 .24784 Mdot
.766 .2487 Mdot
.766 .24895 Mdot
.766 .24943 Mdot
.766 .24962 Mdot
.766 .24988 Mdot
.766 .25066 Mdot
.766 .25098 Mdot
.766 .25117 Mdot
.766 .25121 Mdot
.766 .25127 Mdot
.766 .25156 Mdot
.766 .25199 Mdot
.766 .2526 Mdot
.766 .2527 Mdot
.766 .25304 Mdot
.766 .25356 Mdot
.766 .25387 Mdot
.766 .25405 Mdot
.766 .25409 Mdot
.766 .25409 Mdot
.766 .25429 Mdot
.766 .25461 Mdot
.766 .25518 Mdot
.766 .25596 Mdot
.766 .2562 Mdot
.766 .25699 Mdot
.766 .25713 Mdot
.766 .25781 Mdot
.766 .2583 Mdot
.766 .25859 Mdot
.766 .25927 Mdot
.766 .26031 Mdot
.766 .26087 Mdot
.766 .26116 Mdot
.766 .26123 Mdot
.766 .26144 Mdot
.766 .26194 Mdot
.766 .26249 Mdot
.766 .26326 Mdot
.766 .26369 Mdot
.766 .26437 Mdot
.766 .26493 Mdot
.766 .26512 Mdot
.766 .26526 Mdot
.766 .2661 Mdot
.766 .26657 Mdot
.766 .26661 Mdot
.766 .26695 Mdot
.766 .26724 Mdot
.766 .2687 Mdot
.766 .26889 Mdot
.766 .26896 Mdot
.766 .26992 Mdot
.766 .27013 Mdot
.766 .27015 Mdot
.766 .27116 Mdot
.766 .27128 Mdot
.766 .27149 Mdot
.766 .273 Mdot
.766 .27305 Mdot
.766 .27334 Mdot
.766 .27348 Mdot
.766 .27349 Mdot
.766 .27371 Mdot
.766 .27428 Mdot
.766 .27546 Mdot
.766 .27573 Mdot
.766 .27602 Mdot
.766 .27618 Mdot
.766 .27634 Mdot
.766 .27684 Mdot
.766 .27836 Mdot
.766 .27913 Mdot
.766 .27968 Mdot
.766 .27969 Mdot
.766 .27975 Mdot
.766 .27991 Mdot
.766 .28024 Mdot
.766 .28031 Mdot
.766 .28048 Mdot
.766 .28104 Mdot
.766 .28179 Mdot
.766 .28583 Mdot
.766 .28612 Mdot
.766 .28656 Mdot
.766 .2869 Mdot
.766 .28707 Mdot
.766 .29012 Mdot
.766 .29043 Mdot
.766 .29065 Mdot
.766 .29115 Mdot
.766 .29334 Mdot
.766 .29366 Mdot
.766 .29417 Mdot
.766 .29436 Mdot
.766 .29497 Mdot
.766 .29497 Mdot
.766 .29557 Mdot
.766 .29559 Mdot
.766 .29578 Mdot
.766 .29663 Mdot
.766 .29673 Mdot
.766 .29821 Mdot
.766 .29868 Mdot
.766 .29942 Mdot
.766 .30005 Mdot
.766 .30135 Mdot
.766 .30137 Mdot
.766 .30196 Mdot
.766 .30267 Mdot
.766 .30269 Mdot
.766 .3041 Mdot
.766 .30414 Mdot
.766 .30442 Mdot
.766 .30741 Mdot
.766 .30752 Mdot
.766 .30912 Mdot
.766 .30948 Mdot
.766 .31065 Mdot
.766 .31066 Mdot
.766 .31101 Mdot
.766 .31111 Mdot
.766 .31211 Mdot
.766 .31289 Mdot
.766 .31341 Mdot
.766 .31436 Mdot
.766 .31455 Mdot
.766 .31469 Mdot
.766 .31481 Mdot
.766 .31611 Mdot
.766 .31645 Mdot
.766 .32062 Mdot
.766 .32066 Mdot
.766 .32112 Mdot
.766 .32114 Mdot
.766 .32181 Mdot
.766 .32258 Mdot
.766 .32303 Mdot
.766 .32375 Mdot
.766 .32493 Mdot
.766 .32501 Mdot
.766 .32517 Mdot
.766 .32555 Mdot
.766 .32626 Mdot
.766 .32629 Mdot
.766 .32678 Mdot
.766 .32843 Mdot
.766 .32843 Mdot
.766 .32872 Mdot
.766 .32889 Mdot
.766 .32946 Mdot
.766 .32976 Mdot
.766 .32988 Mdot
.766 .33061 Mdot
.766 .33067 Mdot
.766 .3309 Mdot
.766 .33091 Mdot
.766 .33137 Mdot
.766 .3317 Mdot
.766 .33371 Mdot
.766 .3344 Mdot
.766 .33476 Mdot
.766 .33633 Mdot
.766 .33889 Mdot
.766 .33912 Mdot
.766 .3392 Mdot
.766 .3399 Mdot
.766 .34009 Mdot
.766 .34018 Mdot
.766 .34078 Mdot
.766 .34101 Mdot
.766 .34179 Mdot
.766 .34261 Mdot
.766 .34368 Mdot
.766 .34443 Mdot
.766 .3459 Mdot
.766 .34671 Mdot
.766 .34893 Mdot
.766 .35 Mdot
.766 .35065 Mdot
.766 .35136 Mdot
.766 .35145 Mdot
.766 .35166 Mdot
.766 .35204 Mdot
.766 .35309 Mdot
.766 .35329 Mdot
.766 .35358 Mdot
.766 .35438 Mdot
.766 .35612 Mdot
.766 .35619 Mdot
.766 .35735 Mdot
.766 .3585 Mdot
.766 .3586 Mdot
.766 .36045 Mdot
.766 .36058 Mdot
.766 .36113 Mdot
.766 .36116 Mdot
.766 .36127 Mdot
.766 .36142 Mdot
.766 .36243 Mdot
.766 .36267 Mdot
.766 .36294 Mdot
.766 .3642 Mdot
.766 .36483 Mdot
.766 .36602 Mdot
.766 .36615 Mdot
.766 .36676 Mdot
.766 .36779 Mdot
.766 .36831 Mdot
.766 .37052 Mdot
.766 .37182 Mdot
.766 .37186 Mdot
.766 .37318 Mdot
.766 .37356 Mdot
.766 .3743 Mdot
.766 .37459 Mdot
.766 .37499 Mdot
.766 .37618 Mdot
.766 .37668 Mdot
.766 .37697 Mdot
.766 .37703 Mdot
.766 .37711 Mdot
.766 .37756 Mdot
.766 .37822 Mdot
.766 .37915 Mdot
.766 .37931 Mdot
.766 .37983 Mdot
.766 .38063 Mdot
.766 .3811 Mdot
.766 .38137 Mdot
.766 .38143 Mdot
.766 .38144 Mdot
.766 .38175 Mdot
.766 .38223 Mdot
.766 .38311 Mdot
.766 .38431 Mdot
.766 .38467 Mdot
.766 .38588 Mdot
.766 .38609 Mdot
.766 .38714 Mdot
.766 .38789 Mdot
.766 .38834 Mdot
.766 .38937 Mdot
.766 .39097 Mdot
.766 .39183 Mdot
.766 .39227 Mdot
.766 .39238 Mdot
.766 .3927 Mdot
.766 .39347 Mdot
.766 .39431 Mdot
.766 .39549 Mdot
.766 .39614 Mdot
.766 .39719 Mdot
.766 .39805 Mdot
.766 .39833 Mdot
.766 .39855 Mdot
.766 .39984 Mdot
.766 .40055 Mdot
.766 .40062 Mdot
.766 .40114 Mdot
.766 .40159 Mdot
.766 .40382 Mdot
.766 .40411 Mdot
.766 .40421 Mdot
.766 .40569 Mdot
.766 .40601 Mdot
.766 .40603 Mdot
.766 .40759 Mdot
.766 .40777 Mdot
.766 .4081 Mdot
.766 .4104 Mdot
.766 .41048 Mdot
.766 .41093 Mdot
.766 .41114 Mdot
.766 .41116 Mdot
.766 .41149 Mdot
.766 .41237 Mdot
.766 .41418 Mdot
.766 .41459 Mdot
.766 .41504 Mdot
.766 .41528 Mdot
.766 .41552 Mdot
.766 .41629 Mdot
.766 .41861 Mdot
.766 .4198 Mdot
.766 .42065 Mdot
.766 .42065 Mdot
.766 .42075 Mdot
.766 .42099 Mdot
.766 .42149 Mdot
.766 .42161 Mdot
.766 .42187 Mdot
.766 .42273 Mdot
.766 .42387 Mdot
.766 .43006 Mdot
.766 .43051 Mdot
.766 .43118 Mdot
.766 .4317 Mdot
.766 .43197 Mdot
.766 .43664 Mdot
.766 .43711 Mdot
.766 .43744 Mdot
.766 .43821 Mdot
.766 .44157 Mdot
.766 .44207 Mdot
.766 .44283 Mdot
.766 .44314 Mdot
.766 .44406 Mdot
.766 .44406 Mdot
.766 .44499 Mdot
.766 .44502 Mdot
.766 .44531 Mdot
.766 .4466 Mdot
.766 .44676 Mdot
.766 .44903 Mdot
.766 .44976 Mdot
.766 .45088 Mdot
.766 .45185 Mdot
.766 .45383 Mdot
.766 .45387 Mdot
.766 .45478 Mdot
.766 .45586 Mdot
.766 .45589 Mdot
.766 .45805 Mdot
.766 .45812 Mdot
.766 .45855 Mdot
.766 .46313 Mdot
.766 .46329 Mdot
.766 .46574 Mdot
.766 .4663 Mdot
.768 .01517 Mdot
.768 .01542 Mdot
.768 .01574 Mdot
.768 .01578 Mdot
.768 .01579 Mdot
.768 .01629 Mdot
.768 .01635 Mdot
.768 .01637 Mdot
.768 .01713 Mdot
.768 .01723 Mdot
.768 .01725 Mdot
.768 .01757 Mdot
.768 .01842 Mdot
.768 .01858 Mdot
.768 .01861 Mdot
.768 .0191 Mdot
.768 .02041 Mdot
.768 .02042 Mdot
.768 .02057 Mdot
.768 .02065 Mdot
.768 .0207 Mdot
.768 .02074 Mdot
.768 .02146 Mdot
.768 .02149 Mdot
.768 .02319 Mdot
.768 .02346 Mdot
.768 .02348 Mdot
.768 .02371 Mdot
.768 .0238 Mdot
.768 .02384 Mdot
.768 .02391 Mdot
.768 .02397 Mdot
.768 .02507 Mdot
.768 .02512 Mdot
.768 .02515 Mdot
.768 .02557 Mdot
.768 .02708 Mdot
.768 .02773 Mdot
.768 .02814 Mdot
.768 .02818 Mdot
.768 .02836 Mdot
.768 .02847 Mdot
.768 .02853 Mdot
.768 .02866 Mdot
.768 .02873 Mdot
.768 .02884 Mdot
.768 .02893 Mdot
.768 .02981 Mdot
.768 .02986 Mdot
.768 .03043 Mdot
.768 .03062 Mdot
.768 .03069 Mdot
.768 .03074 Mdot
.768 .03139 Mdot
.768 .03172 Mdot
.768 .03291 Mdot
.768 .0337 Mdot
.768 .03386 Mdot
.768 .03421 Mdot
.768 .03471 Mdot
.768 .03507 Mdot
.768 .03534 Mdot
.768 .0354 Mdot
.768 .03567 Mdot
.768 .03585 Mdot
.768 .03585 Mdot
.768 .03593 Mdot
.768 .03614 Mdot
.768 .03624 Mdot
.768 .03641 Mdot
.768 .03655 Mdot
.768 .03791 Mdot
.768 .03798 Mdot
.768 .03851 Mdot
.768 .03886 Mdot
.768 .03915 Mdot
.768 .03926 Mdot
.768 .03933 Mdot
.768 .03978 Mdot
.768 .04033 Mdot
.768 .0405 Mdot
.768 .04052 Mdot
.768 .04083 Mdot
.768 .04086 Mdot
.768 .0413 Mdot
.768 .04245 Mdot
.768 .04266 Mdot
.768 .04388 Mdot
.768 .04413 Mdot
.768 .04466 Mdot
.768 .04543 Mdot
.768 .04598 Mdot
.768 .04637 Mdot
.768 .04639 Mdot
.768 .04648 Mdot
.768 .0469 Mdot
.768 .04692 Mdot
.768 .04718 Mdot
.768 .04718 Mdot
.768 .0473 Mdot
.768 .04751 Mdot
.768 .04762 Mdot
.768 .04778 Mdot
.768 .04804 Mdot
.768 .04825 Mdot
.768 .04876 Mdot
.768 .04923 Mdot
.768 .04933 Mdot
.768 .04973 Mdot
.768 .05034 Mdot
.768 .05045 Mdot
.768 .05126 Mdot
.768 .0518 Mdot
.768 .05189 Mdot
.768 .05225 Mdot
.768 .05242 Mdot
.768 .05252 Mdot
.768 .05321 Mdot
.768 .05342 Mdot
.768 .05406 Mdot
.768 .05431 Mdot
.768 .05435 Mdot
.768 .05483 Mdot
.768 .05488 Mdot
.768 .05516 Mdot
.768 .05555 Mdot
.768 .05565 Mdot
.768 .05697 Mdot
.768 .05732 Mdot
.768 .05742 Mdot
.768 .0575 Mdot
.768 .05763 Mdot
.768 .05874 Mdot
.768 .05951 Mdot
.768 .05989 Mdot
.768 .06072 Mdot
.768 .06189 Mdot
.768 .06213 Mdot
.768 .06241 Mdot
.768 .06274 Mdot
.768 .06281 Mdot
.768 .06307 Mdot
.768 .06333 Mdot
.768 .06337 Mdot
.768 .06351 Mdot
.768 .06415 Mdot
.768 .06418 Mdot
.768 .06454 Mdot
.768 .06457 Mdot
.768 .06459 Mdot
.768 .06477 Mdot
.768 .0648 Mdot
.768 .06509 Mdot
.768 .06526 Mdot
.768 .06538 Mdot
.768 .0655 Mdot
.768 .06551 Mdot
.768 .06591 Mdot
.768 .06607 Mdot
.768 .06622 Mdot
.768 .067 Mdot
.768 .06765 Mdot
.768 .06774 Mdot
.768 .06789 Mdot
.768 .0685 Mdot
.768 .06883 Mdot
.768 .0689 Mdot
.768 .06943 Mdot
.768 .0696 Mdot
.768 .07085 Mdot
.768 .07167 Mdot
.768 .07182 Mdot
.768 .07236 Mdot
.768 .07262 Mdot
.768 .07278 Mdot
.768 .07349 Mdot
.768 .07384 Mdot
.768 .07416 Mdot
.768 .07515 Mdot
.768 .07517 Mdot
.768 .07554 Mdot
.768 .07559 Mdot
.768 .07632 Mdot
.768 .07641 Mdot
.768 .07655 Mdot
.768 .07665 Mdot
.768 .07684 Mdot
.768 .07729 Mdot
.768 .0774 Mdot
.768 .07744 Mdot
.768 .0776 Mdot
.768 .07903 Mdot
.768 .07962 Mdot
.768 .08009 Mdot
.768 .08016 Mdot
.768 .08031 Mdot
.768 .08044 Mdot
.768 .08059 Mdot
.768 .08064 Mdot
.768 .08071 Mdot
.768 .08104 Mdot
.768 .08234 Mdot
.768 .08352 Mdot
.768 .08411 Mdot
.768 .08457 Mdot
.768 .08462 Mdot
.768 .0848 Mdot
.768 .08538 Mdot
.768 .08579 Mdot
.768 .08609 Mdot
.768 .08652 Mdot
.768 .08718 Mdot
.768 .08729 Mdot
.768 .08754 Mdot
.768 .08798 Mdot
.768 .08802 Mdot
.768 .08845 Mdot
.768 .08849 Mdot
.768 .08858 Mdot
.768 .089 Mdot
.768 .08922 Mdot
.768 .08939 Mdot
.768 .08945 Mdot
.768 .08966 Mdot
.768 .09008 Mdot
.768 .09064 Mdot
.768 .09069 Mdot
.768 .09125 Mdot
.768 .0913 Mdot
.768 .09132 Mdot
.768 .09159 Mdot
.768 .09165 Mdot
.768 .09173 Mdot
.768 .09195 Mdot
.768 .09209 Mdot
.768 .09236 Mdot
.768 .09253 Mdot
.768 .09271 Mdot
.768 .09273 Mdot
.768 .09335 Mdot
.768 .09342 Mdot
.768 .09359 Mdot
.768 .09382 Mdot
.768 .09503 Mdot
.768 .09555 Mdot
.768 .09603 Mdot
.768 .09616 Mdot
.768 .09639 Mdot
.768 .09649 Mdot
.768 .0965 Mdot
.768 .09682 Mdot
.768 .09733 Mdot
.768 .09739 Mdot
.768 .09783 Mdot
.768 .09794 Mdot
.768 .09818 Mdot
.768 .09876 Mdot
.768 .09902 Mdot
.768 .09913 Mdot
.768 .09936 Mdot
.768 .10094 Mdot
.768 .1022 Mdot
.768 .10242 Mdot
.768 .10253 Mdot
.768 .10326 Mdot
.768 .10366 Mdot
.768 .1039 Mdot
.768 .10399 Mdot
.768 .105 Mdot
.768 .10553 Mdot
.768 .10603 Mdot
.768 .10755 Mdot
.768 .10757 Mdot
.768 .10814 Mdot
.768 .10822 Mdot
.768 .10908 Mdot
.768 .10935 Mdot
.768 .10948 Mdot
.768 .10969 Mdot
.768 .10985 Mdot
.768 .11014 Mdot
.768 .11045 Mdot
.768 .11083 Mdot
.768 .111 Mdot
.768 .11106 Mdot
.768 .11116 Mdot
.768 .1113 Mdot
.768 .11351 Mdot
.768 .11363 Mdot
.768 .11441 Mdot
.768 .11513 Mdot
.768 .11524 Mdot
.768 .11543 Mdot
.768 .11546 Mdot
.768 .11546 Mdot
.768 .11567 Mdot
.768 .11589 Mdot
.768 .11597 Mdot
.768 .11609 Mdot
.768 .11659 Mdot
.768 .11683 Mdot
.768 .11765 Mdot
.768 .11859 Mdot
.768 .1195 Mdot
.768 .11957 Mdot
.768 .1201 Mdot
.768 .12039 Mdot
.768 .12117 Mdot
.768 .12131 Mdot
.768 .12133 Mdot
.768 .12134 Mdot
.768 .12201 Mdot
.768 .12209 Mdot
.768 .12236 Mdot
.768 .12248 Mdot
.768 .12288 Mdot
.768 .12325 Mdot
.768 .12373 Mdot
.768 .12388 Mdot
.768 .12418 Mdot
.768 .12435 Mdot
.768 .1248 Mdot
.768 .12501 Mdot
.768 .12602 Mdot
.768 .12619 Mdot
.768 .1262 Mdot
.768 .12658 Mdot
.768 .12724 Mdot
.768 .12731 Mdot
.768 .12746 Mdot
.768 .12759 Mdot
.768 .12798 Mdot
.768 .12803 Mdot
.768 .12818 Mdot
.768 .12881 Mdot
.768 .12887 Mdot
.768 .12892 Mdot
.768 .12915 Mdot
.768 .12926 Mdot
.768 .12941 Mdot
.768 .1295 Mdot
.768 .12983 Mdot
.768 .13048 Mdot
.768 .13134 Mdot
.768 .13141 Mdot
.768 .13172 Mdot
.768 .13183 Mdot
.768 .13228 Mdot
.768 .13235 Mdot
.768 .13238 Mdot
.768 .1328 Mdot
.768 .13288 Mdot
.768 .133 Mdot
.768 .13334 Mdot
.768 .13352 Mdot
.768 .13356 Mdot
.768 .13397 Mdot
.768 .13424 Mdot
.768 .13452 Mdot
.768 .13455 Mdot
.768 .13537 Mdot
.768 .13549 Mdot
.768 .13561 Mdot
.768 .13587 Mdot
.768 .13623 Mdot
.768 .13808 Mdot
.768 .13873 Mdot
.768 .13888 Mdot
.768 .13958 Mdot
.768 .13961 Mdot
.768 .13981 Mdot
.768 .14017 Mdot
.768 .14032 Mdot
.768 .14034 Mdot
.768 .14083 Mdot
.768 .14162 Mdot
.768 .1417 Mdot
.768 .14238 Mdot
.768 .14255 Mdot
.768 .14292 Mdot
.768 .14381 Mdot
.768 .14384 Mdot
.768 .14421 Mdot
.768 .14422 Mdot
.768 .14438 Mdot
.768 .14473 Mdot
.768 .14566 Mdot
.768 .14716 Mdot
.768 .14716 Mdot
.768 .14877 Mdot
.768 .14909 Mdot
.768 .14943 Mdot
.768 .14959 Mdot
.768 .15072 Mdot
.768 .15134 Mdot
.768 .1517 Mdot
.768 .15185 Mdot
.768 .15312 Mdot
.768 .15339 Mdot
.768 .15386 Mdot
.768 .15402 Mdot
.768 .15406 Mdot
.768 .15421 Mdot
.768 .15497 Mdot
.768 .15731 Mdot
.768 .15734 Mdot
.768 .15779 Mdot
.768 .15822 Mdot
.768 .15825 Mdot
.768 .15834 Mdot
.768 .15965 Mdot
.768 .15974 Mdot
.768 .15986 Mdot
.768 .16007 Mdot
.768 .16027 Mdot
.768 .16039 Mdot
.768 .1606 Mdot
.768 .16084 Mdot
.768 .16129 Mdot
.768 .16176 Mdot
.768 .16235 Mdot
.768 .16261 Mdot
.768 .16261 Mdot
.768 .1627 Mdot
.768 .16285 Mdot
.768 .16307 Mdot
.768 .16334 Mdot
.768 .1634 Mdot
.768 .16468 Mdot
.768 .16646 Mdot
.768 .16665 Mdot
.768 .16734 Mdot
.768 .16784 Mdot
.768 .16822 Mdot
.768 .16896 Mdot
.768 .16912 Mdot
.768 .16942 Mdot
.768 .16946 Mdot
.768 .16946 Mdot
.768 .16978 Mdot
.768 .16989 Mdot
.768 .17012 Mdot
.768 .17025 Mdot
.768 .17042 Mdot
.768 .1708 Mdot
.768 .17115 Mdot
.768 .17119 Mdot
.768 .17156 Mdot
.768 .17233 Mdot
.768 .17282 Mdot
.768 .17333 Mdot
.768 .17426 Mdot
.768 .1745 Mdot
.768 .17567 Mdot
.768 .17578 Mdot
.768 .17617 Mdot
.768 .17659 Mdot
.768 .17703 Mdot
.768 .17823 Mdot
.768 .17844 Mdot
.768 .17848 Mdot
.768 .17849 Mdot
.768 .17952 Mdot
.768 .17965 Mdot
.768 .18006 Mdot
.768 .18009 Mdot
.768 .18024 Mdot
.768 .18085 Mdot
.768 .18105 Mdot
.768 .18107 Mdot
.768 .18109 Mdot
.768 .18142 Mdot
.768 .18216 Mdot
.768 .1824 Mdot
.768 .18286 Mdot
.768 .18311 Mdot
.768 .18321 Mdot
.768 .18381 Mdot
.768 .18413 Mdot
.768 .1846 Mdot
.768 .18568 Mdot
.768 .18594 Mdot
.768 .18595 Mdot
.768 .18595 Mdot
.768 .18654 Mdot
.768 .18692 Mdot
.768 .18729 Mdot
.768 .18756 Mdot
.768 .18766 Mdot
.768 .18789 Mdot
.768 .18809 Mdot
.768 .18811 Mdot
.768 .18868 Mdot
.768 .18876 Mdot
.768 .18883 Mdot
.768 .1889 Mdot
.768 .18899 Mdot
.768 .18997 Mdot
.768 .19005 Mdot
.768 .19014 Mdot
.768 .19048 Mdot
.768 .19066 Mdot
.768 .19089 Mdot
.768 .19099 Mdot
.768 .19103 Mdot
.768 .19128 Mdot
.768 .19154 Mdot
.768 .19154 Mdot
.768 .19178 Mdot
.768 .19212 Mdot
.768 .19253 Mdot
.768 .19385 Mdot
.768 .19395 Mdot
.768 .19443 Mdot
.768 .19461 Mdot
.768 .19529 Mdot
.768 .1954 Mdot
.768 .19544 Mdot
.768 .19563 Mdot
.768 .19594 Mdot
.768 .19609 Mdot
.768 .19622 Mdot
.768 .19627 Mdot
.768 .19641 Mdot
.768 .19693 Mdot
.768 .1972 Mdot
.768 .19726 Mdot
.768 .19751 Mdot
.768 .19789 Mdot
.768 .19816 Mdot
.768 .19831 Mdot
.768 .19874 Mdot
.768 .19879 Mdot
.768 .19899 Mdot
.768 .19935 Mdot
.768 .1995 Mdot
.768 .20004 Mdot
.768 .20023 Mdot
.768 .20039 Mdot
.768 .20041 Mdot
.768 .20081 Mdot
.768 .20133 Mdot
.768 .20134 Mdot
.768 .20136 Mdot
.768 .20219 Mdot
.768 .20343 Mdot
.768 .2042 Mdot
.768 .20494 Mdot
.768 .2052 Mdot
.768 .20543 Mdot
.768 .20651 Mdot
.768 .20656 Mdot
.768 .20686 Mdot
.768 .20741 Mdot
.768 .20765 Mdot
.768 .20767 Mdot
.768 .20843 Mdot
.768 .20963 Mdot
.768 .2097 Mdot
.768 .20977 Mdot
.768 .21009 Mdot
.768 .21081 Mdot
.768 .21106 Mdot
.768 .21164 Mdot
.768 .21182 Mdot
.768 .21245 Mdot
.768 .213 Mdot
.768 .21305 Mdot
.768 .21362 Mdot
.768 .21364 Mdot
.768 .21388 Mdot
.768 .21442 Mdot
.768 .21493 Mdot
.768 .21533 Mdot
.768 .21548 Mdot
.768 .21584 Mdot
.768 .21618 Mdot
.768 .2173 Mdot
.768 .21784 Mdot
.768 .21814 Mdot
.768 .21815 Mdot
.768 .2183 Mdot
.768 .21848 Mdot
.768 .21897 Mdot
.768 .22063 Mdot
.768 .22086 Mdot
.768 .22112 Mdot
.768 .22164 Mdot
.768 .22185 Mdot
.768 .22189 Mdot
.768 .22206 Mdot
.768 .22297 Mdot
.768 .22362 Mdot
.768 .22436 Mdot
.768 .22457 Mdot
.768 .22513 Mdot
.768 .22532 Mdot
.768 .22535 Mdot
.768 .22588 Mdot
.768 .22731 Mdot
.768 .22743 Mdot
.768 .2276 Mdot
.768 .22771 Mdot
.768 .22834 Mdot
.768 .22844 Mdot
.768 .22869 Mdot
.768 .22875 Mdot
.768 .22898 Mdot
.768 .22965 Mdot
.768 .23015 Mdot
.768 .23018 Mdot
.768 .23213 Mdot
.768 .23284 Mdot
.768 .23342 Mdot
.768 .23347 Mdot
.768 .23374 Mdot
.768 .23379 Mdot
.768 .23448 Mdot
.768 .23493 Mdot
.768 .23514 Mdot
.768 .23519 Mdot
.768 .23533 Mdot
.768 .23682 Mdot
.768 .23685 Mdot
.768 .23692 Mdot
.768 .23734 Mdot
.768 .23747 Mdot
.768 .23765 Mdot
.768 .23798 Mdot
.768 .23829 Mdot
.768 .23847 Mdot
.768 .23879 Mdot
.768 .23916 Mdot
.768 .23986 Mdot
.768 .23995 Mdot
.768 .24058 Mdot
.768 .24148 Mdot
.768 .24188 Mdot
.768 .24188 Mdot
.768 .24202 Mdot
.768 .24226 Mdot
.768 .24259 Mdot
.768 .243 Mdot
.768 .24309 Mdot
.768 .24444 Mdot
.768 .24506 Mdot
.768 .24721 Mdot
.768 .24779 Mdot
.768 .24809 Mdot
.768 .24914 Mdot
.768 .24991 Mdot
.768 .24992 Mdot
.768 .2505 Mdot
.768 .25085 Mdot
.768 .25163 Mdot
.768 .25166 Mdot
.768 .25188 Mdot
.768 .25234 Mdot
.768 .25241 Mdot
.768 .25241 Mdot
.768 .25289 Mdot
.768 .25306 Mdot
.768 .25342 Mdot
.768 .25362 Mdot
.768 .25388 Mdot
.768 .25447 Mdot
.768 .255 Mdot
.768 .25506 Mdot
.768 .2556 Mdot
.768 .25562 Mdot
.768 .25577 Mdot
.768 .25681 Mdot
.768 .25686 Mdot
.768 .25757 Mdot
.768 .25835 Mdot
.768 .25978 Mdot
.768 .26014 Mdot
.768 .26195 Mdot
.768 .26211 Mdot
.768 .26272 Mdot
.768 .26335 Mdot
.768 .26404 Mdot
.768 .26588 Mdot
.768 .26619 Mdot
.768 .26626 Mdot
.768 .26628 Mdot
.768 .26786 Mdot
.768 .26805 Mdot
.768 .26868 Mdot
.768 .26873 Mdot
.768 .26896 Mdot
.768 .2699 Mdot
.768 .27021 Mdot
.768 .27024 Mdot
.768 .27027 Mdot
.768 .27078 Mdot
.768 .27191 Mdot
.768 .27228 Mdot
.768 .27299 Mdot
.768 .27337 Mdot
.768 .27352 Mdot
.768 .27445 Mdot
.768 .27494 Mdot
.768 .27565 Mdot
.768 .27731 Mdot
.768 .27772 Mdot
.768 .27773 Mdot
.768 .27774 Mdot
.768 .27863 Mdot
.768 .27922 Mdot
.768 .27979 Mdot
.768 .28021 Mdot
.768 .28036 Mdot
.768 .28071 Mdot
.768 .28102 Mdot
.768 .28105 Mdot
.768 .28193 Mdot
.768 .28205 Mdot
.768 .28216 Mdot
.768 .28226 Mdot
.768 .28241 Mdot
.768 .2839 Mdot
.768 .28403 Mdot
.768 .28417 Mdot
.768 .28469 Mdot
.768 .28497 Mdot
.768 .28532 Mdot
.768 .28548 Mdot
.768 .28554 Mdot
.768 .28592 Mdot
.768 .28631 Mdot
.768 .28632 Mdot
.768 .28668 Mdot
.768 .2872 Mdot
.768 .28784 Mdot
.768 .28986 Mdot
.768 .29003 Mdot
.768 .29076 Mdot
.768 .29103 Mdot
.768 .29208 Mdot
.768 .29225 Mdot
.768 .29231 Mdot
.768 .29261 Mdot
.768 .29308 Mdot
.768 .29331 Mdot
.768 .29351 Mdot
.768 .29358 Mdot
.768 .29379 Mdot
.768 .29459 Mdot
.768 .29501 Mdot
.768 .2951 Mdot
.768 .29549 Mdot
.768 .29607 Mdot
.768 .29648 Mdot
.768 .29672 Mdot
.768 .29738 Mdot
.768 .29745 Mdot
.768 .29776 Mdot
.768 .29832 Mdot
.768 .29854 Mdot
.768 .29937 Mdot
.768 .29967 Mdot
.768 .29992 Mdot
.768 .29994 Mdot
.768 .30055 Mdot
.768 .30136 Mdot
.768 .30137 Mdot
.768 .3014 Mdot
.768 .30268 Mdot
.768 .30458 Mdot
.768 .30576 Mdot
.768 .3069 Mdot
.768 .3073 Mdot
.768 .30765 Mdot
.768 .30932 Mdot
.768 .30939 Mdot
.768 .30985 Mdot
.768 .31069 Mdot
.768 .31106 Mdot
.768 .31109 Mdot
.768 .31226 Mdot
.768 .31411 Mdot
.768 .31421 Mdot
.768 .31432 Mdot
.768 .31481 Mdot
.768 .31591 Mdot
.768 .31631 Mdot
.768 .31719 Mdot
.768 .31747 Mdot
.768 .31844 Mdot
.768 .31928 Mdot
.768 .31935 Mdot
.768 .32023 Mdot
.768 .32026 Mdot
.768 .32063 Mdot
.768 .32146 Mdot
.768 .32224 Mdot
.768 .32286 Mdot
.768 .32309 Mdot
.768 .32365 Mdot
.768 .32416 Mdot
.768 .32589 Mdot
.768 .32671 Mdot
.768 .32718 Mdot
.768 .3272 Mdot
.768 .32742 Mdot
.768 .3277 Mdot
.768 .32846 Mdot
.768 .331 Mdot
.768 .33136 Mdot
.768 .33175 Mdot
.768 .33256 Mdot
.768 .33287 Mdot
.768 .33293 Mdot
.768 .33319 Mdot
.768 .3346 Mdot
.768 .33559 Mdot
.768 .33673 Mdot
.768 .33705 Mdot
.768 .33791 Mdot
.768 .3382 Mdot
.768 .33825 Mdot
.768 .33906 Mdot
.768 .34126 Mdot
.768 .34145 Mdot
.768 .34171 Mdot
.768 .34188 Mdot
.768 .34284 Mdot
.768 .343 Mdot
.768 .34338 Mdot
.768 .34347 Mdot
.768 .34383 Mdot
.768 .34486 Mdot
.768 .34562 Mdot
.768 .34567 Mdot
.768 .34866 Mdot
.768 .34975 Mdot
.768 .35065 Mdot
.768 .35072 Mdot
.768 .35113 Mdot
.768 .35121 Mdot
.768 .35227 Mdot
.768 .35296 Mdot
.768 .35328 Mdot
.768 .35336 Mdot
.768 .35357 Mdot
.768 .35587 Mdot
.768 .35591 Mdot
.768 .35602 Mdot
.768 .35667 Mdot
.768 .35687 Mdot
.768 .35715 Mdot
.768 .35765 Mdot
.768 .35812 Mdot
.768 .3584 Mdot
.768 .3589 Mdot
.768 .35946 Mdot
.768 .36053 Mdot
.768 .36068 Mdot
.768 .36164 Mdot
.768 .36302 Mdot
.768 .36364 Mdot
.768 .36364 Mdot
.768 .36385 Mdot
.768 .36422 Mdot
.768 .36474 Mdot
.768 .36535 Mdot
.768 .3655 Mdot
.768 .36757 Mdot
.768 .36852 Mdot
.768 .37183 Mdot
.768 .37272 Mdot
.768 .37319 Mdot
.768 .3748 Mdot
.768 .37597 Mdot
.768 .37599 Mdot
.768 .37687 Mdot
.768 .37741 Mdot
.768 .37862 Mdot
.768 .37866 Mdot
.768 .37901 Mdot
.768 .3797 Mdot
.768 .37981 Mdot
.768 .37981 Mdot
.768 .38055 Mdot
.768 .38081 Mdot
.768 .38137 Mdot
.768 .38167 Mdot
.768 .38207 Mdot
.768 .38297 Mdot
.768 .3838 Mdot
.768 .38388 Mdot
.768 .38471 Mdot
.768 .38475 Mdot
.768 .38497 Mdot
.768 .38657 Mdot
.768 .38664 Mdot
.768 .38774 Mdot
.768 .38895 Mdot
.768 .39113 Mdot
.768 .39169 Mdot
.768 .39446 Mdot
.768 .39471 Mdot
.768 .39565 Mdot
.768 .39662 Mdot
.768 .39767 Mdot
.768 .40051 Mdot
.768 .40099 Mdot
.768 .40109 Mdot
.768 .40111 Mdot
.768 .40354 Mdot
.768 .40385 Mdot
.768 .40481 Mdot
.768 .40489 Mdot
.768 .40524 Mdot
.768 .40668 Mdot
.768 .40715 Mdot
.768 .4072 Mdot
.768 .40725 Mdot
.768 .40803 Mdot
.768 .40976 Mdot
.768 .41033 Mdot
.768 .41142 Mdot
.768 .41202 Mdot
.768 .41224 Mdot
.768 .41366 Mdot
.768 .41442 Mdot
.768 .41551 Mdot
.768 .41806 Mdot
.768 .41869 Mdot
.768 .4187 Mdot
.768 .41871 Mdot
.768 .42009 Mdot
.768 .421 Mdot
.768 .42187 Mdot
.768 .42251 Mdot
.768 .42275 Mdot
.768 .42328 Mdot
.768 .42376 Mdot
.768 .4238 Mdot
.768 .42516 Mdot
.768 .42535 Mdot
.768 .42551 Mdot
.768 .42567 Mdot
.768 .42589 Mdot
.768 .42818 Mdot
.768 .42838 Mdot
.768 .4286 Mdot
.768 .4294 Mdot
.768 .42982 Mdot
.768 .43037 Mdot
.768 .4306 Mdot
.768 .4307 Mdot
.768 .43128 Mdot
.768 .43189 Mdot
.768 .4319 Mdot
.768 .43245 Mdot
.768 .43326 Mdot
.768 .43424 Mdot
.768 .43734 Mdot
.768 .43759 Mdot
.768 .43872 Mdot
.768 .43913 Mdot
.768 .44074 Mdot
.768 .44101 Mdot
.768 .4411 Mdot
.768 .44156 Mdot
.768 .44229 Mdot
.768 .44264 Mdot
.768 .44294 Mdot
.768 .44306 Mdot
.768 .44338 Mdot
.768 .44461 Mdot
.768 .44525 Mdot
.768 .44539 Mdot
.768 .44598 Mdot
.768 .44688 Mdot
.768 .44751 Mdot
.768 .44787 Mdot
.768 .44888 Mdot
.768 .44899 Mdot
.768 .44947 Mdot
.768 .45033 Mdot
.768 .45067 Mdot
.768 .45194 Mdot
.768 .4524 Mdot
.768 .45278 Mdot
.768 .45281 Mdot
.768 .45376 Mdot
.768 .455 Mdot
.768 .45501 Mdot
.768 .45506 Mdot
.768 .45703 Mdot
.768 .45995 Mdot
.768 .46176 Mdot
.768 .46351 Mdot
.768 .46413 Mdot
.768 .46466 Mdot
.768 .46722 Mdot
.768 .46733 Mdot
.768 .46804 Mdot
.77 .01737 Mdot
.77 .01765 Mdot
.77 .0188 Mdot
.77 .01906 Mdot
.77 .01916 Mdot
.77 .01923 Mdot
.77 .0194 Mdot
.77 .01959 Mdot
.77 .02013 Mdot
.77 .02015 Mdot
.77 .02101 Mdot
.77 .0214 Mdot
.77 .02156 Mdot
.77 .02167 Mdot
.77 .02193 Mdot
.77 .02223 Mdot
.77 .02305 Mdot
.77 .02308 Mdot
.77 .02349 Mdot
.77 .02441 Mdot
.77 .02463 Mdot
.77 .02502 Mdot
.77 .02526 Mdot
.77 .02538 Mdot
.77 .02543 Mdot
.77 .02544 Mdot
.77 .02551 Mdot
.77 .02583 Mdot
.77 .02628 Mdot
.77 .02756 Mdot
.77 .0276 Mdot
.77 .02805 Mdot
.77 .02824 Mdot
.77 .02828 Mdot
.77 .02831 Mdot
.77 .02841 Mdot
.77 .02964 Mdot
.77 .02998 Mdot
.77 .03058 Mdot
.77 .03095 Mdot
.77 .03113 Mdot
.77 .03121 Mdot
.77 .03123 Mdot
.77 .03126 Mdot
.77 .0313 Mdot
.77 .03134 Mdot
.77 .03158 Mdot
.77 .03169 Mdot
.77 .03183 Mdot
.77 .03253 Mdot
.77 .03314 Mdot
.77 .034 Mdot
.77 .03449 Mdot
.77 .03456 Mdot
.77 .03525 Mdot
.77 .03554 Mdot
.77 .03561 Mdot
.77 .03565 Mdot
.77 .03581 Mdot
.77 .03731 Mdot
.77 .0374 Mdot
.77 .03755 Mdot
.77 .0377 Mdot
.77 .03771 Mdot
.77 .03823 Mdot
.77 .03915 Mdot
.77 .03925 Mdot
.77 .03972 Mdot
.77 .04 Mdot
.77 .04002 Mdot
.77 .04012 Mdot
.77 .04015 Mdot
.77 .0402 Mdot
.77 .04026 Mdot
.77 .04032 Mdot
.77 .04068 Mdot
.77 .04086 Mdot
.77 .04107 Mdot
.77 .04166 Mdot
.77 .04187 Mdot
.77 .04196 Mdot
.77 .042 Mdot
.77 .04215 Mdot
.77 .04232 Mdot
.77 .04309 Mdot
.77 .0436 Mdot
.77 .04441 Mdot
.77 .04453 Mdot
.77 .04456 Mdot
.77 .04506 Mdot
.77 .04517 Mdot
.77 .04527 Mdot
.77 .04634 Mdot
.77 .04673 Mdot
.77 .04678 Mdot
.77 .04689 Mdot
.77 .04696 Mdot
.77 .0472 Mdot
.77 .04951 Mdot
.77 .04966 Mdot
.77 .04988 Mdot
.77 .05012 Mdot
.77 .05012 Mdot
.77 .0503 Mdot
.77 .05089 Mdot
.77 .05092 Mdot
.77 .05234 Mdot
.77 .0525 Mdot
.77 .05267 Mdot
.77 .05322 Mdot
.77 .05366 Mdot
.77 .05369 Mdot
.77 .05385 Mdot
.77 .05388 Mdot
.77 .05396 Mdot
.77 .05406 Mdot
.77 .05414 Mdot
.77 .0547 Mdot
.77 .05498 Mdot
.77 .05531 Mdot
.77 .05604 Mdot
.77 .05621 Mdot
.77 .05653 Mdot
.77 .05668 Mdot
.77 .05674 Mdot
.77 .05683 Mdot
.77 .05696 Mdot
.77 .05721 Mdot
.77 .05723 Mdot
.77 .05727 Mdot
.77 .05842 Mdot
.77 .05842 Mdot
.77 .0592 Mdot
.77 .06021 Mdot
.77 .06045 Mdot
.77 .06063 Mdot
.77 .06067 Mdot
.77 .06124 Mdot
.77 .06135 Mdot
.77 .06145 Mdot
.77 .0615 Mdot
.77 .06161 Mdot
.77 .06177 Mdot
.77 .06216 Mdot
.77 .06342 Mdot
.77 .06342 Mdot
.77 .06356 Mdot
.77 .06368 Mdot
.77 .06402 Mdot
.77 .0641 Mdot
.77 .06426 Mdot
.77 .06437 Mdot
.77 .06475 Mdot
.77 .06567 Mdot
.77 .0683 Mdot
.77 .06852 Mdot
.77 .06887 Mdot
.77 .06923 Mdot
.77 .06925 Mdot
.77 .06933 Mdot
.77 .06951 Mdot
.77 .0699 Mdot
.77 .06994 Mdot
.77 .07043 Mdot
.77 .07047 Mdot
.77 .07073 Mdot
.77 .07266 Mdot
.77 .07291 Mdot
.77 .07294 Mdot
.77 .07317 Mdot
.77 .07401 Mdot
.77 .07439 Mdot
.77 .07468 Mdot
.77 .07474 Mdot
.77 .07498 Mdot
.77 .07503 Mdot
.77 .07515 Mdot
.77 .0753 Mdot
.77 .07543 Mdot
.77 .07622 Mdot
.77 .0763 Mdot
.77 .07673 Mdot
.77 .07719 Mdot
.77 .07723 Mdot
.77 .07836 Mdot
.77 .07862 Mdot
.77 .0788 Mdot
.77 .0791 Mdot
.77 .07928 Mdot
.77 .07933 Mdot
.77 .07943 Mdot
.77 .07958 Mdot
.77 .07977 Mdot
.77 .08015 Mdot
.77 .08019 Mdot
.77 .08026 Mdot
.77 .08133 Mdot
.77 .08182 Mdot
.77 .08202 Mdot
.77 .08202 Mdot
.77 .08288 Mdot
.77 .08302 Mdot
.77 .08316 Mdot
.77 .08322 Mdot
.77 .08413 Mdot
.77 .08426 Mdot
.77 .08478 Mdot
.77 .08481 Mdot
.77 .08515 Mdot
.77 .08528 Mdot
.77 .08542 Mdot
.77 .08549 Mdot
.77 .08588 Mdot
.77 .08636 Mdot
.77 .08645 Mdot
.77 .08653 Mdot
.77 .08668 Mdot
.77 .08677 Mdot
.77 .08693 Mdot
.77 .08718 Mdot
.77 .08778 Mdot
.77 .08868 Mdot
.77 .08972 Mdot
.77 .08972 Mdot
.77 .08993 Mdot
.77 .09011 Mdot
.77 .09065 Mdot
.77 .09076 Mdot
.77 .09101 Mdot
.77 .09118 Mdot
.77 .0915 Mdot
.77 .09176 Mdot
.77 .09214 Mdot
.77 .09218 Mdot
.77 .09278 Mdot
.77 .09319 Mdot
.77 .09401 Mdot
.77 .09645 Mdot
.77 .09651 Mdot
.77 .09723 Mdot
.77 .09758 Mdot
.77 .09811 Mdot
.77 .09862 Mdot
.77 .09867 Mdot
.77 .09869 Mdot
.77 .09883 Mdot
.77 .09895 Mdot
.77 .0991 Mdot
.77 .09971 Mdot
.77 .09973 Mdot
.77 .09976 Mdot
.77 .1005 Mdot
.77 .10052 Mdot
.77 .10052 Mdot
.77 .10058 Mdot
.77 .10081 Mdot
.77 .10097 Mdot
.77 .10211 Mdot
.77 .10395 Mdot
.77 .10433 Mdot
.77 .10438 Mdot
.77 .10473 Mdot
.77 .10538 Mdot
.77 .10603 Mdot
.77 .10661 Mdot
.77 .10678 Mdot
.77 .10707 Mdot
.77 .10715 Mdot
.77 .10752 Mdot
.77 .1076 Mdot
.77 .10779 Mdot
.77 .10801 Mdot
.77 .10822 Mdot
.77 .10843 Mdot
.77 .10944 Mdot
.77 .10955 Mdot
.77 .11022 Mdot
.77 .11059 Mdot
.77 .11065 Mdot
.77 .11079 Mdot
.77 .11093 Mdot
.77 .11098 Mdot
.77 .11179 Mdot
.77 .11272 Mdot
.77 .11273 Mdot
.77 .11293 Mdot
.77 .11314 Mdot
.77 .11341 Mdot
.77 .1136 Mdot
.77 .11387 Mdot
.77 .11389 Mdot
.77 .11415 Mdot
.77 .11423 Mdot
.77 .11438 Mdot
.77 .11449 Mdot
.77 .1146 Mdot
.77 .1149 Mdot
.77 .11549 Mdot
.77 .11552 Mdot
.77 .11555 Mdot
.77 .11565 Mdot
.77 .11709 Mdot
.77 .11719 Mdot
.77 .1173 Mdot
.77 .11798 Mdot
.77 .11806 Mdot
.77 .11836 Mdot
.77 .11837 Mdot
.77 .1185 Mdot
.77 .11865 Mdot
.77 .11907 Mdot
.77 .11969 Mdot
.77 .11985 Mdot
.77 .11991 Mdot
.77 .11991 Mdot
.77 .12012 Mdot
.77 .12022 Mdot
.77 .12053 Mdot
.77 .12117 Mdot
.77 .12161 Mdot
.77 .12182 Mdot
.77 .12232 Mdot
.77 .12261 Mdot
.77 .12267 Mdot
.77 .12287 Mdot
.77 .12319 Mdot
.77 .12338 Mdot
.77 .1236 Mdot
.77 .12371 Mdot
.77 .12431 Mdot
.77 .12452 Mdot
.77 .12505 Mdot
.77 .12519 Mdot
.77 .12531 Mdot
.77 .12555 Mdot
.77 .12568 Mdot
.77 .12593 Mdot
.77 .12618 Mdot
.77 .12631 Mdot
.77 .12636 Mdot
.77 .1265 Mdot
.77 .12707 Mdot
.77 .12724 Mdot
.77 .12746 Mdot
.77 .12861 Mdot
.77 .12863 Mdot
.77 .13022 Mdot
.77 .13022 Mdot
.77 .13055 Mdot
.77 .13083 Mdot
.77 .13165 Mdot
.77 .13183 Mdot
.77 .13221 Mdot
.77 .13248 Mdot
.77 .13297 Mdot
.77 .13309 Mdot
.77 .13337 Mdot
.77 .13395 Mdot
.77 .13401 Mdot
.77 .13494 Mdot
.77 .13514 Mdot
.77 .13536 Mdot
.77 .13557 Mdot
.77 .13575 Mdot
.77 .13636 Mdot
.77 .13684 Mdot
.77 .13759 Mdot
.77 .14019 Mdot
.77 .14058 Mdot
.77 .14061 Mdot
.77 .14067 Mdot
.77 .14179 Mdot
.77 .14231 Mdot
.77 .14233 Mdot
.77 .14235 Mdot
.77 .1431 Mdot
.77 .14314 Mdot
.77 .14392 Mdot
.77 .14393 Mdot
.77 .14401 Mdot
.77 .14404 Mdot
.77 .14444 Mdot
.77 .14467 Mdot
.77 .1456 Mdot
.77 .14564 Mdot
.77 .14569 Mdot
.77 .14632 Mdot
.77 .14682 Mdot
.77 .14685 Mdot
.77 .14686 Mdot
.77 .14695 Mdot
.77 .1473 Mdot
.77 .14755 Mdot
.77 .14756 Mdot
.77 .1477 Mdot
.77 .1493 Mdot
.77 .14978 Mdot
.77 .15071 Mdot
.77 .15103 Mdot
.77 .15104 Mdot
.77 .15185 Mdot
.77 .15213 Mdot
.77 .1522 Mdot
.77 .15273 Mdot
.77 .15276 Mdot
.77 .1528 Mdot
.77 .15334 Mdot
.77 .15435 Mdot
.77 .1545 Mdot
.77 .15533 Mdot
.77 .15623 Mdot
.77 .1565 Mdot
.77 .15694 Mdot
.77 .15707 Mdot
.77 .15763 Mdot
.77 .15776 Mdot
.77 .15805 Mdot
.77 .15809 Mdot
.77 .1584 Mdot
.77 .15871 Mdot
.77 .15903 Mdot
.77 .16059 Mdot
.77 .1606 Mdot
.77 .16077 Mdot
.77 .16177 Mdot
.77 .16179 Mdot
.77 .16236 Mdot
.77 .16245 Mdot
.77 .16267 Mdot
.77 .16288 Mdot
.77 .16289 Mdot
.77 .16296 Mdot
.77 .16422 Mdot
.77 .1646 Mdot
.77 .16564 Mdot
.77 .16566 Mdot
.77 .1657 Mdot
.77 .16597 Mdot
.77 .16622 Mdot
.77 .16628 Mdot
.77 .16646 Mdot
.77 .16655 Mdot
.77 .16671 Mdot
.77 .16699 Mdot
.77 .16742 Mdot
.77 .16745 Mdot
.77 .16767 Mdot
.77 .16785 Mdot
.77 .16796 Mdot
.77 .16818 Mdot
.77 .16819 Mdot
.77 .16836 Mdot
.77 .16854 Mdot
.77 .169 Mdot
.77 .16945 Mdot
.77 .16991 Mdot
.77 .16996 Mdot
.77 .17 Mdot
.77 .17015 Mdot
.77 .17026 Mdot
.77 .17058 Mdot
.77 .1718 Mdot
.77 .17236 Mdot
.77 .17242 Mdot
.77 .17253 Mdot
.77 .1727 Mdot
.77 .17303 Mdot
.77 .17375 Mdot
.77 .17386 Mdot
.77 .17433 Mdot
.77 .17434 Mdot
.77 .17454 Mdot
.77 .17477 Mdot
.77 .17542 Mdot
.77 .17576 Mdot
.77 .1758 Mdot
.77 .17637 Mdot
.77 .17663 Mdot
.77 .17671 Mdot
.77 .17672 Mdot
.77 .17694 Mdot
.77 .17704 Mdot
.77 .17719 Mdot
.77 .17766 Mdot
.77 .17865 Mdot
.77 .17933 Mdot
.77 .17965 Mdot
.77 .17996 Mdot
.77 .18043 Mdot
.77 .18073 Mdot
.77 .18087 Mdot
.77 .18094 Mdot
.77 .18096 Mdot
.77 .18127 Mdot
.77 .18141 Mdot
.77 .18176 Mdot
.77 .18198 Mdot
.77 .18207 Mdot
.77 .1824 Mdot
.77 .18257 Mdot
.77 .18274 Mdot
.77 .18349 Mdot
.77 .1835 Mdot
.77 .18381 Mdot
.77 .18463 Mdot
.77 .18485 Mdot
.77 .1849 Mdot
.77 .18503 Mdot
.77 .18519 Mdot
.77 .1854 Mdot
.77 .1856 Mdot
.77 .18599 Mdot
.77 .18607 Mdot
.77 .18631 Mdot
.77 .18637 Mdot
.77 .18657 Mdot
.77 .18665 Mdot
.77 .18686 Mdot
.77 .18701 Mdot
.77 .18733 Mdot
.77 .18775 Mdot
.77 .18801 Mdot
.77 .18808 Mdot
.77 .18834 Mdot
.77 .18864 Mdot
.77 .18981 Mdot
.77 .19012 Mdot
.77 .19014 Mdot
.77 .19132 Mdot
.77 .19227 Mdot
.77 .19252 Mdot
.77 .19259 Mdot
.77 .19259 Mdot
.77 .19311 Mdot
.77 .1935 Mdot
.77 .19353 Mdot
.77 .19457 Mdot
.77 .19479 Mdot
.77 .19507 Mdot
.77 .19566 Mdot
.77 .19607 Mdot
.77 .19682 Mdot
.77 .19701 Mdot
.77 .19744 Mdot
.77 .19834 Mdot
.77 .19843 Mdot
.77 .19885 Mdot
.77 .19986 Mdot
.77 .19999 Mdot
.77 .20005 Mdot
.77 .20018 Mdot
.77 .2005 Mdot
.77 .20083 Mdot
.77 .20112 Mdot
.77 .20205 Mdot
.77 .20278 Mdot
.77 .20394 Mdot
.77 .20438 Mdot
.77 .20783 Mdot
.77 .20795 Mdot
.77 .20855 Mdot
.77 .20859 Mdot
.77 .20869 Mdot
.77 .20877 Mdot
.77 .209 Mdot
.77 .20901 Mdot
.77 .21042 Mdot
.77 .2109 Mdot
.77 .21121 Mdot
.77 .21124 Mdot
.77 .21127 Mdot
.77 .21234 Mdot
.77 .21244 Mdot
.77 .21245 Mdot
.77 .21249 Mdot
.77 .21369 Mdot
.77 .21371 Mdot
.77 .21383 Mdot
.77 .21388 Mdot
.77 .21449 Mdot
.77 .21485 Mdot
.77 .21624 Mdot
.77 .21628 Mdot
.77 .21634 Mdot
.77 .21641 Mdot
.77 .21706 Mdot
.77 .21739 Mdot
.77 .21808 Mdot
.77 .21816 Mdot
.77 .2182 Mdot
.77 .21822 Mdot
.77 .21836 Mdot
.77 .2189 Mdot
.77 .21929 Mdot
.77 .2193 Mdot
.77 .21951 Mdot
.77 .22022 Mdot
.77 .22172 Mdot
.77 .22197 Mdot
.77 .22272 Mdot
.77 .22414 Mdot
.77 .22447 Mdot
.77 .22463 Mdot
.77 .22466 Mdot
.77 .22514 Mdot
.77 .2259 Mdot
.77 .22633 Mdot
.77 .22638 Mdot
.77 .22644 Mdot
.77 .22672 Mdot
.77 .22725 Mdot
.77 .22731 Mdot
.77 .22736 Mdot
.77 .2282 Mdot
.77 .22975 Mdot
.77 .22999 Mdot
.77 .23 Mdot
.77 .23033 Mdot
.77 .23127 Mdot
.77 .23188 Mdot
.77 .23265 Mdot
.77 .23306 Mdot
.77 .23374 Mdot
.77 .23394 Mdot
.77 .2348 Mdot
.77 .23501 Mdot
.77 .23546 Mdot
.77 .23552 Mdot
.77 .23558 Mdot
.77 .23598 Mdot
.77 .23604 Mdot
.77 .23627 Mdot
.77 .23647 Mdot
.77 .23672 Mdot
.77 .23696 Mdot
.77 .2379 Mdot
.77 .23909 Mdot
.77 .23936 Mdot
.77 .23938 Mdot
.77 .23963 Mdot
.77 .24015 Mdot
.77 .24118 Mdot
.77 .2412 Mdot
.77 .24209 Mdot
.77 .24223 Mdot
.77 .24256 Mdot
.77 .24289 Mdot
.77 .2429 Mdot
.77 .24302 Mdot
.77 .24356 Mdot
.77 .24495 Mdot
.77 .24554 Mdot
.77 .24623 Mdot
.77 .24714 Mdot
.77 .24717 Mdot
.77 .24723 Mdot
.77 .24765 Mdot
.77 .24804 Mdot
.77 .24813 Mdot
.77 .24841 Mdot
.77 .24853 Mdot
.77 .24878 Mdot
.77 .24922 Mdot
.77 .24988 Mdot
.77 .24993 Mdot
.77 .25026 Mdot
.77 .25048 Mdot
.77 .25054 Mdot
.77 .25072 Mdot
.77 .25105 Mdot
.77 .25107 Mdot
.77 .25133 Mdot
.77 .2516 Mdot
.77 .25209 Mdot
.77 .25232 Mdot
.77 .25301 Mdot
.77 .25372 Mdot
.77 .25379 Mdot
.77 .25385 Mdot
.77 .25409 Mdot
.77 .25426 Mdot
.77 .25474 Mdot
.77 .25663 Mdot
.77 .2575 Mdot
.77 .25758 Mdot
.77 .25775 Mdot
.77 .25801 Mdot
.77 .25853 Mdot
.77 .25962 Mdot
.77 .2598 Mdot
.77 .26052 Mdot
.77 .26053 Mdot
.77 .26085 Mdot
.77 .2612 Mdot
.77 .26221 Mdot
.77 .26273 Mdot
.77 .26279 Mdot
.77 .26367 Mdot
.77 .26406 Mdot
.77 .26419 Mdot
.77 .2642 Mdot
.77 .26454 Mdot
.77 .26469 Mdot
.77 .26493 Mdot
.77 .26566 Mdot
.77 .26717 Mdot
.77 .26823 Mdot
.77 .26872 Mdot
.77 .26919 Mdot
.77 .26992 Mdot
.77 .27038 Mdot
.77 .2706 Mdot
.77 .2707 Mdot
.77 .27074 Mdot
.77 .27121 Mdot
.77 .27142 Mdot
.77 .27196 Mdot
.77 .2723 Mdot
.77 .27244 Mdot
.77 .27295 Mdot
.77 .27321 Mdot
.77 .27347 Mdot
.77 .27462 Mdot
.77 .27464 Mdot
.77 .27512 Mdot
.77 .27639 Mdot
.77 .27672 Mdot
.77 .27681 Mdot
.77 .277 Mdot
.77 .27724 Mdot
.77 .27756 Mdot
.77 .27788 Mdot
.77 .27848 Mdot
.77 .2786 Mdot
.77 .27897 Mdot
.77 .27907 Mdot
.77 .27937 Mdot
.77 .2795 Mdot
.77 .27981 Mdot
.77 .28005 Mdot
.77 .28054 Mdot
.77 .28118 Mdot
.77 .28158 Mdot
.77 .28169 Mdot
.77 .2821 Mdot
.77 .28255 Mdot
.77 .28436 Mdot
.77 .28484 Mdot
.77 .28487 Mdot
.77 .28669 Mdot
.77 .28815 Mdot
.77 .28854 Mdot
.77 .28864 Mdot
.77 .28864 Mdot
.77 .28944 Mdot
.77 .29004 Mdot
.77 .29009 Mdot
.77 .29169 Mdot
.77 .29204 Mdot
.77 .29247 Mdot
.77 .29337 Mdot
.77 .294 Mdot
.77 .29516 Mdot
.77 .29544 Mdot
.77 .29611 Mdot
.77 .29749 Mdot
.77 .29763 Mdot
.77 .29828 Mdot
.77 .29984 Mdot
.77 .30004 Mdot
.77 .30014 Mdot
.77 .30033 Mdot
.77 .30083 Mdot
.77 .30133 Mdot
.77 .30177 Mdot
.77 .30321 Mdot
.77 .30434 Mdot
.77 .30613 Mdot
.77 .30681 Mdot
.77 .31212 Mdot
.77 .3123 Mdot
.77 .31322 Mdot
.77 .31328 Mdot
.77 .31344 Mdot
.77 .31356 Mdot
.77 .31391 Mdot
.77 .31392 Mdot
.77 .3161 Mdot
.77 .31683 Mdot
.77 .31732 Mdot
.77 .31736 Mdot
.77 .31741 Mdot
.77 .31905 Mdot
.77 .3192 Mdot
.77 .31922 Mdot
.77 .31929 Mdot
.77 .32114 Mdot
.77 .32117 Mdot
.77 .32135 Mdot
.77 .32142 Mdot
.77 .32236 Mdot
.77 .32292 Mdot
.77 .32507 Mdot
.77 .32513 Mdot
.77 .32522 Mdot
.77 .32533 Mdot
.77 .32633 Mdot
.77 .32683 Mdot
.77 .32789 Mdot
.77 .32803 Mdot
.77 .32809 Mdot
.77 .32812 Mdot
.77 .32832 Mdot
.77 .32915 Mdot
.77 .32976 Mdot
.77 .32978 Mdot
.77 .3301 Mdot
.77 .33119 Mdot
.77 .3335 Mdot
.77 .33389 Mdot
.77 .33504 Mdot
.77 .33723 Mdot
.77 .33774 Mdot
.77 .33799 Mdot
.77 .33803 Mdot
.77 .33878 Mdot
.77 .33994 Mdot
.77 .34061 Mdot
.77 .34068 Mdot
.77 .34078 Mdot
.77 .34121 Mdot
.77 .34202 Mdot
.77 .34211 Mdot
.77 .34219 Mdot
.77 .34349 Mdot
.77 .34586 Mdot
.77 .34623 Mdot
.77 .34626 Mdot
.77 .34677 Mdot
.77 .3482 Mdot
.77 .34914 Mdot
.77 .35034 Mdot
.77 .35097 Mdot
.77 .35201 Mdot
.77 .35232 Mdot
.77 .35365 Mdot
.77 .35397 Mdot
.77 .35466 Mdot
.77 .35475 Mdot
.77 .35484 Mdot
.77 .35547 Mdot
.77 .35556 Mdot
.77 .35592 Mdot
.77 .35622 Mdot
.77 .35661 Mdot
.77 .35698 Mdot
.77 .35843 Mdot
.77 .36026 Mdot
.77 .36067 Mdot
.77 .3607 Mdot
.77 .36109 Mdot
.77 .36189 Mdot
.77 .36347 Mdot
.77 .36351 Mdot
.77 .36488 Mdot
.77 .36509 Mdot
.77 .3656 Mdot
.77 .3661 Mdot
.77 .36612 Mdot
.77 .3663 Mdot
.77 .36714 Mdot
.77 .36927 Mdot
.77 .37018 Mdot
.77 .37125 Mdot
.77 .37265 Mdot
.77 .37269 Mdot
.77 .37278 Mdot
.77 .37343 Mdot
.77 .37404 Mdot
.77 .37417 Mdot
.77 .3746 Mdot
.77 .3748 Mdot
.77 .37518 Mdot
.77 .37586 Mdot
.77 .37687 Mdot
.77 .37694 Mdot
.77 .37745 Mdot
.77 .37779 Mdot
.77 .37788 Mdot
.77 .37816 Mdot
.77 .37867 Mdot
.77 .3787 Mdot
.77 .3791 Mdot
.77 .37952 Mdot
.77 .38027 Mdot
.77 .38062 Mdot
.77 .3817 Mdot
.77 .38278 Mdot
.77 .3829 Mdot
.77 .38298 Mdot
.77 .38336 Mdot
.77 .38361 Mdot
.77 .38436 Mdot
.77 .38726 Mdot
.77 .3886 Mdot
.77 .38873 Mdot
.77 .38899 Mdot
.77 .38939 Mdot
.77 .39019 Mdot
.77 .39188 Mdot
.77 .39214 Mdot
.77 .39325 Mdot
.77 .39327 Mdot
.77 .39377 Mdot
.77 .3943 Mdot
.77 .39585 Mdot
.77 .39666 Mdot
.77 .39675 Mdot
.77 .3981 Mdot
.77 .3987 Mdot
.77 .39891 Mdot
.77 .39892 Mdot
.77 .39944 Mdot
.77 .39967 Mdot
.77 .40004 Mdot
.77 .40117 Mdot
.77 .4035 Mdot
.77 .40513 Mdot
.77 .40589 Mdot
.77 .40661 Mdot
.77 .40772 Mdot
.77 .40844 Mdot
.77 .40878 Mdot
.77 .40893 Mdot
.77 .40899 Mdot
.77 .40971 Mdot
.77 .41005 Mdot
.77 .41088 Mdot
.77 .4114 Mdot
.77 .41161 Mdot
.77 .4124 Mdot
.77 .4128 Mdot
.77 .4132 Mdot
.77 .41497 Mdot
.77 .415 Mdot
.77 .41574 Mdot
.77 .4177 Mdot
.77 .4182 Mdot
.77 .41833 Mdot
.77 .41864 Mdot
.77 .41901 Mdot
.77 .4195 Mdot
.77 .41999 Mdot
.77 .42091 Mdot
.77 .42109 Mdot
.77 .42166 Mdot
.77 .42182 Mdot
.77 .42228 Mdot
.77 .42248 Mdot
.77 .42297 Mdot
.77 .42333 Mdot
.77 .42409 Mdot
.77 .42508 Mdot
.77 .42569 Mdot
.77 .42586 Mdot
.77 .42649 Mdot
.77 .42718 Mdot
.77 .42996 Mdot
.77 .4307 Mdot
.77 .43075 Mdot
.77 .43356 Mdot
.77 .4358 Mdot
.77 .43641 Mdot
.77 .43655 Mdot
.77 .43656 Mdot
.77 .43779 Mdot
.77 .43872 Mdot
.77 .43879 Mdot
.77 .44126 Mdot
.77 .44179 Mdot
.77 .44245 Mdot
.77 .44384 Mdot
.77 .44481 Mdot
.77 .4466 Mdot
.77 .44704 Mdot
.77 .44784 Mdot
.77 .44806 Mdot
.77 .45019 Mdot
.77 .45041 Mdot
.77 .45141 Mdot
.77 .45381 Mdot
.77 .45411 Mdot
.77 .45427 Mdot
.77 .45456 Mdot
.77 .45532 Mdot
.77 .4561 Mdot
.77 .45678 Mdot
.77 .459 Mdot
.77 .46073 Mdot
.77 .46349 Mdot
.77 .46453 Mdot
.772 .01485 Mdot
.772 .0149 Mdot
.772 .01492 Mdot
.772 .015 Mdot
.772 .01504 Mdot
.772 .01515 Mdot
.772 .01521 Mdot
.772 .01539 Mdot
.772 .01548 Mdot
.772 .01576 Mdot
.772 .0159 Mdot
.772 .01633 Mdot
.772 .01655 Mdot
.772 .01673 Mdot
.772 .01693 Mdot
.772 .01721 Mdot
.772 .01755 Mdot
.772 .01782 Mdot
.772 .01813 Mdot
.772 .01857 Mdot
.772 .01899 Mdot
.772 .01909 Mdot
.772 .01951 Mdot
.772 .01999 Mdot
.772 .02006 Mdot
.772 .0204 Mdot
.772 .02067 Mdot
.772 .02132 Mdot
.772 .02147 Mdot
.772 .02161 Mdot
.772 .02212 Mdot
.772 .02285 Mdot
.772 .02297 Mdot
.772 .02349 Mdot
.772 .02373 Mdot
.772 .02391 Mdot
.772 .02416 Mdot
.772 .02491 Mdot
.772 .02513 Mdot
.772 .02514 Mdot
.772 .02534 Mdot
.772 .02536 Mdot
.772 .02598 Mdot
.772 .02614 Mdot
.772 .02652 Mdot
.772 .0268 Mdot
.772 .02728 Mdot
.772 .02746 Mdot
.772 .02748 Mdot
.772 .02827 Mdot
.772 .02838 Mdot
.772 .02864 Mdot
.772 .02891 Mdot
.772 .02917 Mdot
.772 .02922 Mdot
.772 .0293 Mdot
.772 .02931 Mdot
.772 .02944 Mdot
.772 .03046 Mdot
.772 .03079 Mdot
.772 .03082 Mdot
.772 .03112 Mdot
.772 .03116 Mdot
.772 .03173 Mdot
.772 .0321 Mdot
.772 .03236 Mdot
.772 .03295 Mdot
.772 .03337 Mdot
.772 .03388 Mdot
.772 .03412 Mdot
.772 .03421 Mdot
.772 .03439 Mdot
.772 .03443 Mdot
.772 .03564 Mdot
.772 .03579 Mdot
.772 .03582 Mdot
.772 .03621 Mdot
.772 .03664 Mdot
.772 .03704 Mdot
.772 .03705 Mdot
.772 .0371 Mdot
.772 .03723 Mdot
.772 .03724 Mdot
.772 .03746 Mdot
.772 .03842 Mdot
.772 .03902 Mdot
.772 .03954 Mdot
.772 .03958 Mdot
.772 .04004 Mdot
.772 .0401 Mdot
.772 .04012 Mdot
.772 .04036 Mdot
.772 .04085 Mdot
.772 .04099 Mdot
.772 .04156 Mdot
.772 .04196 Mdot
.772 .04287 Mdot
.772 .04294 Mdot
.772 .04352 Mdot
.772 .04352 Mdot
.772 .04431 Mdot
.772 .04467 Mdot
.772 .04482 Mdot
.772 .04496 Mdot
.772 .0451 Mdot
.772 .04515 Mdot
.772 .04546 Mdot
.772 .0462 Mdot
.772 .04702 Mdot
.772 .04725 Mdot
.772 .0473 Mdot
.772 .0477 Mdot
.772 .04791 Mdot
.772 .04796 Mdot
.772 .04856 Mdot
.772 .04857 Mdot
.772 .04883 Mdot
.772 .04918 Mdot
.772 .0492 Mdot
.772 .04928 Mdot
.772 .0493 Mdot
.772 .04948 Mdot
.772 .0495 Mdot
.772 .04983 Mdot
.772 .05054 Mdot
.772 .05091 Mdot
.772 .05131 Mdot
.772 .05224 Mdot
.772 .05304 Mdot
.772 .0531 Mdot
.772 .05382 Mdot
.772 .05391 Mdot
.772 .05395 Mdot
.772 .05398 Mdot
.772 .05431 Mdot
.772 .05506 Mdot
.772 .05528 Mdot
.772 .056 Mdot
.772 .05616 Mdot
.772 .05678 Mdot
.772 .05757 Mdot
.772 .05818 Mdot
.772 .05829 Mdot
.772 .0589 Mdot
.772 .05919 Mdot
.772 .0592 Mdot
.772 .05929 Mdot
.772 .06023 Mdot
.772 .06041 Mdot
.772 .06097 Mdot
.772 .0612 Mdot
.772 .06141 Mdot
.772 .06155 Mdot
.772 .06162 Mdot
.772 .06171 Mdot
.772 .06219 Mdot
.772 .06333 Mdot
.772 .06459 Mdot
.772 .06495 Mdot
.772 .06502 Mdot
.772 .06563 Mdot
.772 .06564 Mdot
.772 .06597 Mdot
.772 .06605 Mdot
.772 .06657 Mdot
.772 .06697 Mdot
.772 .06699 Mdot
.772 .06739 Mdot
.772 .06793 Mdot
.772 .06795 Mdot
.772 .06809 Mdot
.772 .06812 Mdot
.772 .0683 Mdot
.772 .0684 Mdot
.772 .06842 Mdot
.772 .06893 Mdot
.772 .07003 Mdot
.772 .07019 Mdot
.772 .0706 Mdot
.772 .07122 Mdot
.772 .07265 Mdot
.772 .07388 Mdot
.772 .07389 Mdot
.772 .07398 Mdot
.772 .07405 Mdot
.772 .0751 Mdot
.772 .07523 Mdot
.772 .07529 Mdot
.772 .07535 Mdot
.772 .07585 Mdot
.772 .07585 Mdot
.772 .07701 Mdot
.772 .07734 Mdot
.772 .07735 Mdot
.772 .07746 Mdot
.772 .07826 Mdot
.772 .07846 Mdot
.772 .07871 Mdot
.772 .0788 Mdot
.772 .07938 Mdot
.772 .07967 Mdot
.772 .07967 Mdot
.772 .08072 Mdot
.772 .08076 Mdot
.772 .08088 Mdot
.772 .08183 Mdot
.772 .082 Mdot
.772 .08339 Mdot
.772 .08339 Mdot
.772 .08355 Mdot
.772 .08406 Mdot
.772 .08496 Mdot
.772 .08498 Mdot
.772 .08527 Mdot
.772 .08614 Mdot
.772 .08649 Mdot
.772 .08667 Mdot
.772 .08681 Mdot
.772 .08703 Mdot
.772 .08706 Mdot
.772 .08714 Mdot
.772 .08727 Mdot
.772 .08772 Mdot
.772 .08801 Mdot
.772 .08802 Mdot
.772 .08918 Mdot
.772 .0897 Mdot
.772 .08978 Mdot
.772 .09022 Mdot
.772 .09081 Mdot
.772 .09172 Mdot
.772 .09228 Mdot
.772 .09239 Mdot
.772 .09248 Mdot
.772 .09278 Mdot
.772 .09333 Mdot
.772 .09334 Mdot
.772 .09366 Mdot
.772 .09385 Mdot
.772 .09397 Mdot
.772 .09409 Mdot
.772 .09459 Mdot
.772 .09462 Mdot
.772 .09464 Mdot
.772 .09479 Mdot
.772 .0954 Mdot
.772 .09543 Mdot
.772 .0958 Mdot
.772 .09599 Mdot
.772 .09605 Mdot
.772 .09663 Mdot
.772 .09688 Mdot
.772 .09692 Mdot
.772 .09712 Mdot
.772 .09717 Mdot
.772 .09745 Mdot
.772 .0976 Mdot
.772 .09764 Mdot
.772 .09842 Mdot
.772 .09964 Mdot
.772 .10011 Mdot
.772 .10037 Mdot
.772 .10085 Mdot
.772 .1009 Mdot
.772 .101 Mdot
.772 .10196 Mdot
.772 .10282 Mdot
.772 .10289 Mdot
.772 .10417 Mdot
.772 .10481 Mdot
.772 .10546 Mdot
.772 .10607 Mdot
.772 .10609 Mdot
.772 .10623 Mdot
.772 .10632 Mdot
.772 .10647 Mdot
.772 .10725 Mdot
.772 .10771 Mdot
.772 .10778 Mdot
.772 .10789 Mdot
.772 .10794 Mdot
.772 .10815 Mdot
.772 .10824 Mdot
.772 .10833 Mdot
.772 .10878 Mdot
.772 .10894 Mdot
.772 .10901 Mdot
.772 .10911 Mdot
.772 .10911 Mdot
.772 .1102 Mdot
.772 .1109 Mdot
.772 .11141 Mdot
.772 .11142 Mdot
.772 .1116 Mdot
.772 .11283 Mdot
.772 .11314 Mdot
.772 .11352 Mdot
.772 .11366 Mdot
.772 .11434 Mdot
.772 .11453 Mdot
.772 .11455 Mdot
.772 .115 Mdot
.772 .115 Mdot
.772 .11581 Mdot
.772 .11663 Mdot
.772 .11668 Mdot
.772 .11688 Mdot
.772 .11756 Mdot
.772 .11757 Mdot
.772 .11834 Mdot
.772 .1186 Mdot
.772 .11892 Mdot
.772 .11971 Mdot
.772 .11996 Mdot
.772 .12051 Mdot
.772 .12075 Mdot
.772 .12076 Mdot
.772 .12099 Mdot
.772 .12121 Mdot
.772 .12179 Mdot
.772 .12265 Mdot
.772 .12317 Mdot
.772 .12321 Mdot
.772 .12366 Mdot
.772 .12438 Mdot
.772 .12499 Mdot
.772 .12526 Mdot
.772 .12547 Mdot
.772 .12553 Mdot
.772 .12556 Mdot
.772 .12581 Mdot
.772 .12603 Mdot
.772 .12637 Mdot
.772 .12642 Mdot
.772 .12654 Mdot
.772 .12674 Mdot
.772 .12743 Mdot
.772 .12773 Mdot
.772 .12788 Mdot
.772 .12789 Mdot
.772 .12811 Mdot
.772 .12814 Mdot
.772 .12968 Mdot
.772 .1303 Mdot
.772 .13049 Mdot
.772 .13062 Mdot
.772 .1313 Mdot
.772 .13179 Mdot
.772 .1322 Mdot
.772 .1327 Mdot
.772 .13325 Mdot
.772 .13361 Mdot
.772 .13448 Mdot
.772 .13464 Mdot
.772 .13479 Mdot
.772 .13525 Mdot
.772 .1357 Mdot
.772 .1357 Mdot
.772 .1361 Mdot
.772 .13611 Mdot
.772 .1366 Mdot
.772 .13671 Mdot
.772 .1369 Mdot
.772 .13708 Mdot
.772 .13727 Mdot
.772 .13738 Mdot
.772 .13767 Mdot
.772 .13804 Mdot
.772 .13809 Mdot
.772 .13812 Mdot
.772 .13835 Mdot
.772 .13878 Mdot
.772 .13929 Mdot
.772 .13935 Mdot
.772 .13991 Mdot
.772 .1402 Mdot
.772 .14029 Mdot
.772 .14062 Mdot
.772 .1412 Mdot
.772 .14131 Mdot
.772 .14157 Mdot
.772 .14163 Mdot
.772 .1418 Mdot
.772 .14195 Mdot
.772 .14203 Mdot
.772 .14246 Mdot
.772 .14267 Mdot
.772 .14269 Mdot
.772 .14271 Mdot
.772 .14275 Mdot
.772 .14395 Mdot
.772 .14481 Mdot
.772 .14585 Mdot
.772 .14641 Mdot
.772 .14657 Mdot
.772 .14696 Mdot
.772 .1471 Mdot
.772 .1473 Mdot
.772 .14771 Mdot
.772 .14778 Mdot
.772 .14794 Mdot
.772 .14858 Mdot
.772 .14941 Mdot
.772 .15039 Mdot
.772 .15075 Mdot
.772 .15086 Mdot
.772 .15283 Mdot
.772 .15382 Mdot
.772 .15482 Mdot
.772 .15486 Mdot
.772 .15576 Mdot
.772 .15579 Mdot
.772 .15601 Mdot
.772 .15616 Mdot
.772 .15631 Mdot
.772 .15639 Mdot
.772 .15669 Mdot
.772 .15759 Mdot
.772 .15829 Mdot
.772 .1584 Mdot
.772 .15858 Mdot
.772 .15866 Mdot
.772 .15898 Mdot
.772 .15912 Mdot
.772 .15926 Mdot
.772 .15942 Mdot
.772 .15995 Mdot
.772 .16019 Mdot
.772 .16031 Mdot
.772 .16045 Mdot
.772 .16046 Mdot
.772 .16077 Mdot
.772 .16083 Mdot
.772 .16215 Mdot
.772 .16216 Mdot
.772 .16268 Mdot
.772 .16322 Mdot
.772 .1634 Mdot
.772 .16401 Mdot
.772 .16403 Mdot
.772 .1643 Mdot
.772 .16621 Mdot
.772 .16669 Mdot
.772 .16669 Mdot
.772 .16727 Mdot
.772 .16749 Mdot
.772 .16854 Mdot
.772 .16884 Mdot
.772 .16886 Mdot
.772 .16955 Mdot
.772 .16956 Mdot
.772 .1708 Mdot
.772 .17161 Mdot
.772 .17189 Mdot
.772 .17207 Mdot
.772 .17215 Mdot
.772 .17245 Mdot
.772 .17351 Mdot
.772 .17352 Mdot
.772 .17453 Mdot
.772 .17471 Mdot
.772 .17477 Mdot
.772 .17511 Mdot
.772 .17561 Mdot
.772 .17682 Mdot
.772 .17721 Mdot
.772 .17732 Mdot
.772 .17806 Mdot
.772 .17843 Mdot
.772 .17844 Mdot
.772 .1788 Mdot
.772 .17895 Mdot
.772 .17914 Mdot
.772 .18003 Mdot
.772 .18137 Mdot
.772 .18145 Mdot
.772 .18216 Mdot
.772 .18223 Mdot
.772 .18292 Mdot
.772 .18336 Mdot
.772 .18404 Mdot
.772 .18456 Mdot
.772 .18489 Mdot
.772 .18498 Mdot
.772 .1854 Mdot
.772 .18572 Mdot
.772 .18582 Mdot
.772 .18587 Mdot
.772 .18624 Mdot
.772 .18643 Mdot
.772 .18658 Mdot
.772 .1871 Mdot
.772 .18718 Mdot
.772 .18737 Mdot
.772 .18763 Mdot
.772 .18769 Mdot
.772 .18799 Mdot
.772 .18815 Mdot
.772 .18875 Mdot
.772 .18921 Mdot
.772 .18944 Mdot
.772 .18946 Mdot
.772 .18953 Mdot
.772 .1898 Mdot
.772 .18984 Mdot
.772 .19025 Mdot
.772 .19079 Mdot
.772 .19223 Mdot
.772 .19271 Mdot
.772 .193 Mdot
.772 .19318 Mdot
.772 .19347 Mdot
.772 .19367 Mdot
.772 .1937 Mdot
.772 .19466 Mdot
.772 .19472 Mdot
.772 .19486 Mdot
.772 .19548 Mdot
.772 .19596 Mdot
.772 .19611 Mdot
.772 .19658 Mdot
.772 .19688 Mdot
.772 .19774 Mdot
.772 .1983 Mdot
.772 .19878 Mdot
.772 .19964 Mdot
.772 .19988 Mdot
.772 .20011 Mdot
.772 .20045 Mdot
.772 .20082 Mdot
.772 .20132 Mdot
.772 .20139 Mdot
.772 .20151 Mdot
.772 .20152 Mdot
.772 .20166 Mdot
.772 .20213 Mdot
.772 .20215 Mdot
.772 .20265 Mdot
.772 .20277 Mdot
.772 .20291 Mdot
.772 .20307 Mdot
.772 .20337 Mdot
.772 .20365 Mdot
.772 .20395 Mdot
.772 .20412 Mdot
.772 .20428 Mdot
.772 .20456 Mdot
.772 .20512 Mdot
.772 .2052 Mdot
.772 .20526 Mdot
.772 .2056 Mdot
.772 .20628 Mdot
.772 .2063 Mdot
.772 .20706 Mdot
.772 .20715 Mdot
.772 .20801 Mdot
.772 .20846 Mdot
.772 .2086 Mdot
.772 .20911 Mdot
.772 .21 Mdot
.772 .21018 Mdot
.772 .21059 Mdot
.772 .21068 Mdot
.772 .21094 Mdot
.772 .21117 Mdot
.772 .21129 Mdot
.772 .21157 Mdot
.772 .21195 Mdot
.772 .21228 Mdot
.772 .2123 Mdot
.772 .21234 Mdot
.772 .2124 Mdot
.772 .21336 Mdot
.772 .21426 Mdot
.772 .2144 Mdot
.772 .21506 Mdot
.772 .21559 Mdot
.772 .21616 Mdot
.772 .21688 Mdot
.772 .21698 Mdot
.772 .21718 Mdot
.772 .21806 Mdot
.772 .2183 Mdot
.772 .2189 Mdot
.772 .21912 Mdot
.772 .21943 Mdot
.772 .22005 Mdot
.772 .22016 Mdot
.772 .22042 Mdot
.772 .22053 Mdot
.772 .22073 Mdot
.772 .22125 Mdot
.772 .2214 Mdot
.772 .22269 Mdot
.772 .22354 Mdot
.772 .22419 Mdot
.772 .22475 Mdot
.772 .22492 Mdot
.772 .22531 Mdot
.772 .22586 Mdot
.772 .22758 Mdot
.772 .22797 Mdot
.772 .2287 Mdot
.772 .22949 Mdot
.772 .23104 Mdot
.772 .23111 Mdot
.772 .23186 Mdot
.772 .23249 Mdot
.772 .23254 Mdot
.772 .23288 Mdot
.772 .2331 Mdot
.772 .23334 Mdot
.772 .23346 Mdot
.772 .23391 Mdot
.772 .23392 Mdot
.772 .23531 Mdot
.772 .23568 Mdot
.772 .2364 Mdot
.772 .23657 Mdot
.772 .23684 Mdot
.772 .23696 Mdot
.772 .23745 Mdot
.772 .23767 Mdot
.772 .23789 Mdot
.772 .23814 Mdot
.772 .23884 Mdot
.772 .23897 Mdot
.772 .23933 Mdot
.772 .23952 Mdot
.772 .23972 Mdot
.772 .23974 Mdot
.772 .23975 Mdot
.772 .24023 Mdot
.772 .24031 Mdot
.772 .24058 Mdot
.772 .24184 Mdot
.772 .24235 Mdot
.772 .24237 Mdot
.772 .24318 Mdot
.772 .24321 Mdot
.772 .24401 Mdot
.772 .24428 Mdot
.772 .24503 Mdot
.772 .24523 Mdot
.772 .24525 Mdot
.772 .2453 Mdot
.772 .24568 Mdot
.772 .24574 Mdot
.772 .24577 Mdot
.772 .24627 Mdot
.772 .24801 Mdot
.772 .24809 Mdot
.772 .24862 Mdot
.772 .24936 Mdot
.772 .24936 Mdot
.772 .24993 Mdot
.772 .25026 Mdot
.772 .25037 Mdot
.772 .2506 Mdot
.772 .25089 Mdot
.772 .2515 Mdot
.772 .25222 Mdot
.772 .25259 Mdot
.772 .25268 Mdot
.772 .25272 Mdot
.772 .25362 Mdot
.772 .25379 Mdot
.772 .2538 Mdot
.772 .2547 Mdot
.772 .25533 Mdot
.772 .25571 Mdot
.772 .25594 Mdot
.772 .25697 Mdot
.772 .25697 Mdot
.772 .25739 Mdot
.772 .25767 Mdot
.772 .2578 Mdot
.772 .25826 Mdot
.772 .25903 Mdot
.772 .25932 Mdot
.772 .25953 Mdot
.772 .25989 Mdot
.772 .25991 Mdot
.772 .26079 Mdot
.772 .26146 Mdot
.772 .26175 Mdot
.772 .26183 Mdot
.772 .26237 Mdot
.772 .26313 Mdot
.772 .26501 Mdot
.772 .26561 Mdot
.772 .26577 Mdot
.772 .26692 Mdot
.772 .26749 Mdot
.772 .26751 Mdot
.772 .26807 Mdot
.772 .26829 Mdot
.772 .26859 Mdot
.772 .26997 Mdot
.772 .27203 Mdot
.772 .27215 Mdot
.772 .27325 Mdot
.772 .27336 Mdot
.772 .27443 Mdot
.772 .27511 Mdot
.772 .27616 Mdot
.772 .27696 Mdot
.772 .27747 Mdot
.772 .2776 Mdot
.772 .27825 Mdot
.772 .27875 Mdot
.772 .2789 Mdot
.772 .27897 Mdot
.772 .27955 Mdot
.772 .27985 Mdot
.772 .28008 Mdot
.772 .28088 Mdot
.772 .281 Mdot
.772 .2813 Mdot
.772 .2817 Mdot
.772 .28178 Mdot
.772 .28225 Mdot
.772 .2825 Mdot
.772 .28343 Mdot
.772 .28413 Mdot
.772 .28449 Mdot
.772 .28452 Mdot
.772 .28463 Mdot
.772 .28505 Mdot
.772 .2851 Mdot
.772 .28574 Mdot
.772 .28658 Mdot
.772 .2888 Mdot
.772 .28954 Mdot
.772 .28998 Mdot
.772 .29026 Mdot
.772 .29072 Mdot
.772 .29102 Mdot
.772 .29106 Mdot
.772 .29255 Mdot
.772 .29264 Mdot
.772 .29285 Mdot
.772 .29381 Mdot
.772 .29456 Mdot
.772 .29479 Mdot
.772 .29551 Mdot
.772 .29598 Mdot
.772 .29731 Mdot
.772 .29816 Mdot
.772 .29891 Mdot
.772 .30023 Mdot
.772 .3006 Mdot
.772 .30096 Mdot
.772 .30149 Mdot
.772 .30206 Mdot
.772 .30283 Mdot
.772 .30294 Mdot
.772 .30313 Mdot
.772 .30314 Mdot
.772 .30335 Mdot
.772 .30408 Mdot
.772 .30411 Mdot
.772 .30488 Mdot
.772 .30507 Mdot
.772 .30529 Mdot
.772 .30554 Mdot
.772 .306 Mdot
.772 .30643 Mdot
.772 .30689 Mdot
.772 .30715 Mdot
.772 .30741 Mdot
.772 .30784 Mdot
.772 .3087 Mdot
.772 .30882 Mdot
.772 .30891 Mdot
.772 .30944 Mdot
.772 .31048 Mdot
.772 .31052 Mdot
.772 .3117 Mdot
.772 .31183 Mdot
.772 .31317 Mdot
.772 .31386 Mdot
.772 .31408 Mdot
.772 .31486 Mdot
.772 .31624 Mdot
.772 .31651 Mdot
.772 .31714 Mdot
.772 .31728 Mdot
.772 .31769 Mdot
.772 .31804 Mdot
.772 .31822 Mdot
.772 .31866 Mdot
.772 .31925 Mdot
.772 .31976 Mdot
.772 .31979 Mdot
.772 .31985 Mdot
.772 .31994 Mdot
.772 .32142 Mdot
.772 .32281 Mdot
.772 .32303 Mdot
.772 .32405 Mdot
.772 .32486 Mdot
.772 .32575 Mdot
.772 .32685 Mdot
.772 .327 Mdot
.772 .32732 Mdot
.772 .32868 Mdot
.772 .32905 Mdot
.772 .32998 Mdot
.772 .33031 Mdot
.772 .33079 Mdot
.772 .33176 Mdot
.772 .33193 Mdot
.772 .33233 Mdot
.772 .33249 Mdot
.772 .3328 Mdot
.772 .3336 Mdot
.772 .33384 Mdot
.772 .33583 Mdot
.772 .33714 Mdot
.772 .33815 Mdot
.772 .33901 Mdot
.772 .33927 Mdot
.772 .33987 Mdot
.772 .34073 Mdot
.772 .34337 Mdot
.772 .34398 Mdot
.772 .3451 Mdot
.772 .34632 Mdot
.772 .34872 Mdot
.772 .34882 Mdot
.772 .34999 Mdot
.772 .35096 Mdot
.772 .35104 Mdot
.772 .35155 Mdot
.772 .3519 Mdot
.772 .35227 Mdot
.772 .35246 Mdot
.772 .35315 Mdot
.772 .35317 Mdot
.772 .35531 Mdot
.772 .35589 Mdot
.772 .357 Mdot
.772 .35725 Mdot
.772 .35768 Mdot
.772 .35787 Mdot
.772 .35862 Mdot
.772 .35896 Mdot
.772 .3593 Mdot
.772 .35968 Mdot
.772 .36076 Mdot
.772 .36096 Mdot
.772 .36152 Mdot
.772 .36181 Mdot
.772 .36213 Mdot
.772 .36215 Mdot
.772 .36216 Mdot
.772 .36291 Mdot
.772 .36303 Mdot
.772 .36345 Mdot
.772 .3654 Mdot
.772 .36618 Mdot
.772 .36621 Mdot
.772 .36746 Mdot
.772 .3675 Mdot
.772 .36875 Mdot
.772 .36917 Mdot
.772 .37033 Mdot
.772 .37062 Mdot
.772 .37067 Mdot
.772 .37074 Mdot
.772 .37132 Mdot
.772 .37142 Mdot
.772 .37147 Mdot
.772 .37224 Mdot
.772 .37492 Mdot
.772 .37505 Mdot
.772 .37587 Mdot
.772 .37701 Mdot
.772 .37701 Mdot
.772 .37789 Mdot
.772 .3784 Mdot
.772 .37856 Mdot
.772 .37891 Mdot
.772 .37937 Mdot
.772 .3803 Mdot
.772 .38143 Mdot
.772 .38199 Mdot
.772 .38213 Mdot
.772 .38219 Mdot
.772 .38359 Mdot
.772 .38384 Mdot
.772 .38385 Mdot
.772 .38526 Mdot
.772 .38622 Mdot
.772 .38681 Mdot
.772 .38717 Mdot
.772 .38875 Mdot
.772 .38876 Mdot
.772 .38941 Mdot
.772 .38984 Mdot
.772 .39003 Mdot
.772 .39075 Mdot
.772 .39194 Mdot
.772 .39239 Mdot
.772 .39271 Mdot
.772 .39327 Mdot
.772 .39329 Mdot
.772 .39466 Mdot
.772 .39569 Mdot
.772 .39614 Mdot
.772 .39627 Mdot
.772 .3971 Mdot
.772 .39827 Mdot
.772 .40117 Mdot
.772 .4021 Mdot
.772 .40235 Mdot
.772 .40412 Mdot
.772 .40499 Mdot
.772 .40503 Mdot
.772 .40589 Mdot
.772 .40623 Mdot
.772 .40669 Mdot
.772 .40882 Mdot
.772 .41201 Mdot
.772 .41219 Mdot
.772 .4139 Mdot
.772 .41406 Mdot
.772 .41571 Mdot
.772 .41676 Mdot
.772 .41838 Mdot
.772 .41962 Mdot
.772 .4204 Mdot
.772 .42061 Mdot
.772 .42161 Mdot
.772 .42239 Mdot
.772 .42262 Mdot
.772 .42273 Mdot
.772 .42362 Mdot
.772 .42408 Mdot
.772 .42444 Mdot
.772 .42568 Mdot
.772 .42586 Mdot
.772 .42632 Mdot
.772 .42694 Mdot
.772 .42707 Mdot
.772 .42778 Mdot
.772 .42818 Mdot
.772 .42961 Mdot
.772 .43069 Mdot
.772 .43125 Mdot
.772 .4313 Mdot
.772 .43147 Mdot
.772 .43211 Mdot
.772 .43219 Mdot
.772 .43317 Mdot
.772 .43448 Mdot
.772 .4379 Mdot
.772 .43905 Mdot
.772 .43972 Mdot
.772 .44015 Mdot
.772 .44087 Mdot
.772 .44133 Mdot
.772 .44139 Mdot
.772 .4437 Mdot
.772 .44382 Mdot
.772 .44416 Mdot
.772 .44564 Mdot
.772 .44679 Mdot
.772 .44715 Mdot
.772 .44826 Mdot
.772 .44898 Mdot
.772 .45104 Mdot
.772 .45236 Mdot
.772 .45351 Mdot
.772 .45555 Mdot
.772 .45613 Mdot
.772 .45668 Mdot
.772 .4575 Mdot
.772 .45838 Mdot
.772 .45957 Mdot
.772 .45974 Mdot
.772 .46002 Mdot
.772 .46005 Mdot
.772 .46037 Mdot
.772 .46149 Mdot
.772 .46155 Mdot
.772 .46274 Mdot
.772 .46302 Mdot
.772 .46336 Mdot
.772 .46375 Mdot
.772 .46446 Mdot
.772 .46513 Mdot
.772 .46583 Mdot
.772 .46623 Mdot
.772 .46663 Mdot
.772 .4673 Mdot
.772 .46863 Mdot
.772 .46882 Mdot
.772 .46895 Mdot
.772 .46977 Mdot
.774 .01479 Mdot
.774 .01483 Mdot
.774 .01489 Mdot
.774 .01499 Mdot
.774 .015 Mdot
.774 .01515 Mdot
.774 .01515 Mdot
.774 .01538 Mdot
.774 .01539 Mdot
.774 .01575 Mdot
.774 .01577 Mdot
.774 .01597 Mdot
.774 .01631 Mdot
.774 .01634 Mdot
.774 .01666 Mdot
.774 .01674 Mdot
.774 .01717 Mdot
.774 .01719 Mdot
.774 .01724 Mdot
.774 .01734 Mdot
.774 .01755 Mdot
.774 .01773 Mdot
.774 .01785 Mdot
.774 .01851 Mdot
.774 .01854 Mdot
.774 .01862 Mdot
.774 .01878 Mdot
.774 .01911 Mdot
.774 .01938 Mdot
.774 .01957 Mdot
.774 .01983 Mdot
.774 .02059 Mdot
.774 .02059 Mdot
.774 .02064 Mdot
.774 .02076 Mdot
.774 .021 Mdot
.774 .02111 Mdot
.774 .02148 Mdot
.774 .02149 Mdot
.774 .02152 Mdot
.774 .0216 Mdot
.774 .02194 Mdot
.774 .02222 Mdot
.774 .02263 Mdot
.774 .02321 Mdot
.774 .02381 Mdot
.774 .02382 Mdot
.774 .02389 Mdot
.774 .02406 Mdot
.774 .02445 Mdot
.774 .02461 Mdot
.774 .02519 Mdot
.774 .02521 Mdot
.774 .02524 Mdot
.774 .02525 Mdot
.774 .02537 Mdot
.774 .02575 Mdot
.774 .0259 Mdot
.774 .02599 Mdot
.774 .02634 Mdot
.774 .02697 Mdot
.774 .02698 Mdot
.774 .02745 Mdot
.774 .02787 Mdot
.774 .02788 Mdot
.774 .02808 Mdot
.774 .02846 Mdot
.774 .0288 Mdot
.774 .02881 Mdot
.774 .02892 Mdot
.774 .02919 Mdot
.774 .02978 Mdot
.774 .03003 Mdot
.774 .03093 Mdot
.774 .03096 Mdot
.774 .03101 Mdot
.774 .03103 Mdot
.774 .0312 Mdot
.774 .03121 Mdot
.774 .03179 Mdot
.774 .03203 Mdot
.774 .03217 Mdot
.774 .03227 Mdot
.774 .03271 Mdot
.774 .03302 Mdot
.774 .03315 Mdot
.774 .03316 Mdot
.774 .03369 Mdot
.774 .0337 Mdot
.774 .03424 Mdot
.774 .03442 Mdot
.774 .03462 Mdot
.774 .03474 Mdot
.774 .03508 Mdot
.774 .03509 Mdot
.774 .0354 Mdot
.774 .036 Mdot
.774 .03652 Mdot
.774 .03653 Mdot
.774 .0367 Mdot
.774 .03712 Mdot
.774 .03803 Mdot
.774 .03809 Mdot
.774 .03815 Mdot
.774 .03842 Mdot
.774 .03981 Mdot
.774 .03986 Mdot
.774 .03995 Mdot
.774 .03997 Mdot
.774 .04023 Mdot
.774 .04026 Mdot
.774 .04083 Mdot
.774 .04115 Mdot
.774 .04152 Mdot
.774 .04173 Mdot
.774 .04189 Mdot
.774 .04222 Mdot
.774 .04257 Mdot
.774 .04305 Mdot
.774 .04325 Mdot
.774 .04327 Mdot
.774 .04409 Mdot
.774 .04411 Mdot
.774 .04455 Mdot
.774 .04495 Mdot
.774 .04523 Mdot
.774 .04543 Mdot
.774 .04553 Mdot
.774 .04571 Mdot
.774 .04575 Mdot
.774 .046 Mdot
.774 .04624 Mdot
.774 .04626 Mdot
.774 .04674 Mdot
.774 .04676 Mdot
.774 .04766 Mdot
.774 .04777 Mdot
.774 .04847 Mdot
.774 .04848 Mdot
.774 .04874 Mdot
.774 .0488 Mdot
.774 .04887 Mdot
.774 .04932 Mdot
.774 .0494 Mdot
.774 .04968 Mdot
.774 .05031 Mdot
.774 .05081 Mdot
.774 .0509 Mdot
.774 .05099 Mdot
.774 .05134 Mdot
.774 .05142 Mdot
.774 .05263 Mdot
.774 .05356 Mdot
.774 .05363 Mdot
.774 .05373 Mdot
.774 .05377 Mdot
.774 .0538 Mdot
.774 .05421 Mdot
.774 .05425 Mdot
.774 .05496 Mdot
.774 .05514 Mdot
.774 .05555 Mdot
.774 .05564 Mdot
.774 .05615 Mdot
.774 .05622 Mdot
.774 .05654 Mdot
.774 .05662 Mdot
.774 .05678 Mdot
.774 .05729 Mdot
.774 .0573 Mdot
.774 .05783 Mdot
.774 .05807 Mdot
.774 .05858 Mdot
.774 .05873 Mdot
.774 .05889 Mdot
.774 .05892 Mdot
.774 .05987 Mdot
.774 .06018 Mdot
.774 .06021 Mdot
.774 .06078 Mdot
.774 .0609 Mdot
.774 .06097 Mdot
.774 .06151 Mdot
.774 .06195 Mdot
.774 .06204 Mdot
.774 .06227 Mdot
.774 .06242 Mdot
.774 .06269 Mdot
.774 .06276 Mdot
.774 .06315 Mdot
.774 .06352 Mdot
.774 .06354 Mdot
.774 .06429 Mdot
.774 .06431 Mdot
.774 .06547 Mdot
.774 .06571 Mdot
.774 .06589 Mdot
.774 .06635 Mdot
.774 .06643 Mdot
.774 .06697 Mdot
.774 .06698 Mdot
.774 .06739 Mdot
.774 .06748 Mdot
.774 .06759 Mdot
.774 .06775 Mdot
.774 .06828 Mdot
.774 .0684 Mdot
.774 .06884 Mdot
.774 .06981 Mdot
.774 .06993 Mdot
.774 .07021 Mdot
.774 .0706 Mdot
.774 .07073 Mdot
.774 .07087 Mdot
.774 .07141 Mdot
.774 .07153 Mdot
.774 .07192 Mdot
.774 .07217 Mdot
.774 .0734 Mdot
.774 .07485 Mdot
.774 .07496 Mdot
.774 .07511 Mdot
.774 .07518 Mdot
.774 .07523 Mdot
.774 .07585 Mdot
.774 .07592 Mdot
.774 .07701 Mdot
.774 .0772 Mdot
.774 .0773 Mdot
.774 .07793 Mdot
.774 .07806 Mdot
.774 .07869 Mdot
.774 .07886 Mdot
.774 .07896 Mdot
.774 .07946 Mdot
.774 .07948 Mdot
.774 .07958 Mdot
.774 .07983 Mdot
.774 .0801 Mdot
.774 .08062 Mdot
.774 .08064 Mdot
.774 .0808 Mdot
.774 .08103 Mdot
.774 .08146 Mdot
.774 .08149 Mdot
.774 .08183 Mdot
.774 .08261 Mdot
.774 .08285 Mdot
.774 .0831 Mdot
.774 .08314 Mdot
.774 .08411 Mdot
.774 .08462 Mdot
.774 .0851 Mdot
.774 .08515 Mdot
.774 .08596 Mdot
.774 .08602 Mdot
.774 .08621 Mdot
.774 .08631 Mdot
.774 .08667 Mdot
.774 .08716 Mdot
.774 .08783 Mdot
.774 .08797 Mdot
.774 .08832 Mdot
.774 .08856 Mdot
.774 .08899 Mdot
.774 .0891 Mdot
.774 .08969 Mdot
.774 .09027 Mdot
.774 .0903 Mdot
.774 .09146 Mdot
.774 .09149 Mdot
.774 .09157 Mdot
.774 .09254 Mdot
.774 .09329 Mdot
.774 .09365 Mdot
.774 .09388 Mdot
.774 .09393 Mdot
.774 .0944 Mdot
.774 .09444 Mdot
.774 .09464 Mdot
.774 .09478 Mdot
.774 .09485 Mdot
.774 .09488 Mdot
.774 .0956 Mdot
.774 .0956 Mdot
.774 .09562 Mdot
.774 .0959 Mdot
.774 .09626 Mdot
.774 .09639 Mdot
.774 .09656 Mdot
.774 .09664 Mdot
.774 .09682 Mdot
.774 .09729 Mdot
.774 .09764 Mdot
.774 .09783 Mdot
.774 .09789 Mdot
.774 .09791 Mdot
.774 .0985 Mdot
.774 .09987 Mdot
.774 .1 Mdot
.774 .10018 Mdot
.774 .10045 Mdot
.774 .10062 Mdot
.774 .10103 Mdot
.774 .10122 Mdot
.774 .10143 Mdot
.774 .10164 Mdot
.774 .10248 Mdot
.774 .10267 Mdot
.774 .10326 Mdot
.774 .10342 Mdot
.774 .10366 Mdot
.774 .10404 Mdot
.774 .10557 Mdot
.774 .10593 Mdot
.774 .10683 Mdot
.774 .10781 Mdot
.774 .10798 Mdot
.774 .10821 Mdot
.774 .1083 Mdot
.774 .10831 Mdot
.774 .10839 Mdot
.774 .10869 Mdot
.774 .10936 Mdot
.774 .10946 Mdot
.774 .10987 Mdot
.774 .11072 Mdot
.774 .111 Mdot
.774 .11114 Mdot
.774 .11145 Mdot
.774 .1116 Mdot
.774 .11247 Mdot
.774 .11258 Mdot
.774 .11278 Mdot
.774 .11332 Mdot
.774 .11375 Mdot
.774 .11401 Mdot
.774 .11409 Mdot
.774 .11416 Mdot
.774 .11494 Mdot
.774 .11498 Mdot
.774 .11513 Mdot
.774 .11526 Mdot
.774 .11552 Mdot
.774 .11579 Mdot
.774 .11593 Mdot
.774 .11674 Mdot
.774 .11677 Mdot
.774 .11701 Mdot
.774 .11737 Mdot
.774 .11783 Mdot
.774 .11803 Mdot
.774 .11808 Mdot
.774 .11834 Mdot
.774 .11861 Mdot
.774 .11895 Mdot
.774 .11982 Mdot
.774 .12011 Mdot
.774 .1202 Mdot
.774 .12058 Mdot
.774 .12063 Mdot
.774 .12214 Mdot
.774 .12292 Mdot
.774 .12321 Mdot
.774 .12367 Mdot
.774 .12374 Mdot
.774 .12501 Mdot
.774 .1251 Mdot
.774 .12539 Mdot
.774 .12555 Mdot
.774 .1257 Mdot
.774 .1261 Mdot
.774 .12672 Mdot
.774 .12686 Mdot
.774 .12715 Mdot
.774 .12765 Mdot
.774 .12789 Mdot
.774 .12806 Mdot
.774 .12812 Mdot
.774 .12866 Mdot
.774 .12903 Mdot
.774 .12969 Mdot
.774 .12986 Mdot
.774 .13078 Mdot
.774 .13084 Mdot
.774 .13167 Mdot
.774 .13172 Mdot
.774 .13244 Mdot
.774 .13251 Mdot
.774 .13273 Mdot
.774 .13351 Mdot
.774 .13357 Mdot
.774 .13359 Mdot
.774 .13369 Mdot
.774 .13373 Mdot
.774 .13388 Mdot
.774 .13438 Mdot
.774 .13518 Mdot
.774 .13583 Mdot
.774 .13635 Mdot
.774 .13691 Mdot
.774 .13726 Mdot
.774 .13734 Mdot
.774 .13737 Mdot
.774 .13807 Mdot
.774 .13813 Mdot
.774 .13818 Mdot
.774 .13844 Mdot
.774 .13865 Mdot
.774 .13877 Mdot
.774 .13881 Mdot
.774 .13993 Mdot
.774 .13993 Mdot
.774 .13996 Mdot
.774 .1404 Mdot
.774 .14095 Mdot
.774 .14115 Mdot
.774 .14141 Mdot
.774 .14154 Mdot
.774 .14165 Mdot
.774 .14181 Mdot
.774 .14255 Mdot
.774 .14284 Mdot
.774 .14304 Mdot
.774 .14308 Mdot
.774 .14337 Mdot
.774 .14347 Mdot
.774 .1435 Mdot
.774 .14441 Mdot
.774 .14442 Mdot
.774 .14639 Mdot
.774 .14647 Mdot
.774 .14654 Mdot
.774 .14674 Mdot
.774 .14702 Mdot
.774 .14731 Mdot
.774 .14743 Mdot
.774 .14753 Mdot
.774 .1477 Mdot
.774 .14798 Mdot
.774 .14833 Mdot
.774 .14862 Mdot
.774 .14895 Mdot
.774 .14911 Mdot
.774 .14928 Mdot
.774 .14997 Mdot
.774 .15028 Mdot
.774 .15052 Mdot
.774 .15057 Mdot
.774 .15086 Mdot
.774 .15179 Mdot
.774 .15202 Mdot
.774 .15205 Mdot
.774 .1524 Mdot
.774 .15299 Mdot
.774 .15353 Mdot
.774 .1536 Mdot
.774 .15535 Mdot
.774 .15557 Mdot
.774 .15592 Mdot
.774 .15611 Mdot
.774 .15731 Mdot
.774 .1575 Mdot
.774 .15882 Mdot
.774 .15908 Mdot
.774 .15945 Mdot
.774 .15959 Mdot
.774 .1596 Mdot
.774 .15972 Mdot
.774 .16019 Mdot
.774 .16053 Mdot
.774 .16122 Mdot
.774 .16137 Mdot
.774 .16202 Mdot
.774 .16219 Mdot
.774 .1627 Mdot
.774 .16333 Mdot
.774 .16376 Mdot
.774 .16399 Mdot
.774 .16406 Mdot
.774 .16446 Mdot
.774 .16469 Mdot
.774 .1649 Mdot
.774 .16521 Mdot
.774 .16604 Mdot
.774 .16621 Mdot
.774 .16652 Mdot
.774 .16735 Mdot
.774 .16803 Mdot
.774 .16842 Mdot
.774 .16855 Mdot
.774 .16866 Mdot
.774 .16984 Mdot
.774 .16986 Mdot
.774 .16992 Mdot
.774 .17015 Mdot
.774 .17019 Mdot
.774 .17037 Mdot
.774 .17076 Mdot
.774 .17117 Mdot
.774 .17139 Mdot
.774 .17264 Mdot
.774 .1727 Mdot
.774 .17307 Mdot
.774 .17362 Mdot
.774 .17385 Mdot
.774 .17434 Mdot
.774 .17465 Mdot
.774 .17472 Mdot
.774 .17513 Mdot
.774 .17553 Mdot
.774 .17554 Mdot
.774 .17608 Mdot
.774 .17742 Mdot
.774 .17786 Mdot
.774 .178 Mdot
.774 .17837 Mdot
.774 .17859 Mdot
.774 .17868 Mdot
.774 .17992 Mdot
.774 .18002 Mdot
.774 .18101 Mdot
.774 .18146 Mdot
.774 .18222 Mdot
.774 .18264 Mdot
.774 .18267 Mdot
.774 .18306 Mdot
.774 .18338 Mdot
.774 .18349 Mdot
.774 .18544 Mdot
.774 .18558 Mdot
.774 .18604 Mdot
.774 .18628 Mdot
.774 .18652 Mdot
.774 .18715 Mdot
.774 .1881 Mdot
.774 .18832 Mdot
.774 .18877 Mdot
.774 .18954 Mdot
.774 .18992 Mdot
.774 .19017 Mdot
.774 .19026 Mdot
.774 .19032 Mdot
.774 .19084 Mdot
.774 .1911 Mdot
.774 .19167 Mdot
.774 .19254 Mdot
.774 .19269 Mdot
.774 .19295 Mdot
.774 .19343 Mdot
.774 .19431 Mdot
.774 .19439 Mdot
.774 .19448 Mdot
.774 .19576 Mdot
.774 .19584 Mdot
.774 .19663 Mdot
.774 .19695 Mdot
.774 .19706 Mdot
.774 .1974 Mdot
.774 .19861 Mdot
.774 .1987 Mdot
.774 .19873 Mdot
.774 .19889 Mdot
.774 .19895 Mdot
.774 .19918 Mdot
.774 .19996 Mdot
.774 .20017 Mdot
.774 .20097 Mdot
.774 .2012 Mdot
.774 .2022 Mdot
.774 .20266 Mdot
.774 .203 Mdot
.774 .20388 Mdot
.774 .20441 Mdot
.774 .20454 Mdot
.774 .20459 Mdot
.774 .2055 Mdot
.774 .20566 Mdot
.774 .20575 Mdot
.774 .20584 Mdot
.774 .20625 Mdot
.774 .20657 Mdot
.774 .20675 Mdot
.774 .20682 Mdot
.774 .20691 Mdot
.774 .20786 Mdot
.774 .20818 Mdot
.774 .20839 Mdot
.774 .20855 Mdot
.774 .20855 Mdot
.774 .2086 Mdot
.774 .20927 Mdot
.774 .21012 Mdot
.774 .21033 Mdot
.774 .21043 Mdot
.774 .21084 Mdot
.774 .21104 Mdot
.774 .21122 Mdot
.774 .2113 Mdot
.774 .21146 Mdot
.774 .2126 Mdot
.774 .21305 Mdot
.774 .21336 Mdot
.774 .21342 Mdot
.774 .21342 Mdot
.774 .21387 Mdot
.774 .21403 Mdot
.774 .21408 Mdot
.774 .21548 Mdot
.774 .2155 Mdot
.774 .21662 Mdot
.774 .2172 Mdot
.774 .21817 Mdot
.774 .21854 Mdot
.774 .21868 Mdot
.774 .21878 Mdot
.774 .21909 Mdot
.774 .21952 Mdot
.774 .21995 Mdot
.774 .21998 Mdot
.774 .22016 Mdot
.774 .22031 Mdot
.774 .22058 Mdot
.774 .22101 Mdot
.774 .22154 Mdot
.774 .22201 Mdot
.774 .22252 Mdot
.774 .22277 Mdot
.774 .22301 Mdot
.774 .22321 Mdot
.774 .2235 Mdot
.774 .22382 Mdot
.774 .22409 Mdot
.774 .22457 Mdot
.774 .22495 Mdot
.774 .22502 Mdot
.774 .22547 Mdot
.774 .22691 Mdot
.774 .22727 Mdot
.774 .22731 Mdot
.774 .22786 Mdot
.774 .22876 Mdot
.774 .22888 Mdot
.774 .22959 Mdot
.774 .2297 Mdot
.774 .2318 Mdot
.774 .23242 Mdot
.774 .23275 Mdot
.774 .23301 Mdot
.774 .2333 Mdot
.774 .2334 Mdot
.774 .23359 Mdot
.774 .23468 Mdot
.774 .23546 Mdot
.774 .23575 Mdot
.774 .2378 Mdot
.774 .2382 Mdot
.774 .23876 Mdot
.774 .23898 Mdot
.774 .23899 Mdot
.774 .23917 Mdot
.774 .23918 Mdot
.774 .23948 Mdot
.774 .2396 Mdot
.774 .23991 Mdot
.774 .24018 Mdot
.774 .24043 Mdot
.774 .24044 Mdot
.774 .24126 Mdot
.774 .2415 Mdot
.774 .24174 Mdot
.774 .24274 Mdot
.774 .243 Mdot
.774 .24379 Mdot
.774 .24416 Mdot
.774 .24478 Mdot
.774 .24494 Mdot
.774 .24543 Mdot
.774 .24579 Mdot
.774 .2459 Mdot
.774 .24652 Mdot
.774 .24687 Mdot
.774 .24719 Mdot
.774 .24768 Mdot
.774 .2479 Mdot
.774 .24875 Mdot
.774 .24897 Mdot
.774 .24922 Mdot
.774 .2497 Mdot
.774 .251 Mdot
.774 .25204 Mdot
.774 .25246 Mdot
.774 .25265 Mdot
.774 .25285 Mdot
.774 .25302 Mdot
.774 .25418 Mdot
.774 .25485 Mdot
.774 .25488 Mdot
.774 .25497 Mdot
.774 .25533 Mdot
.774 .25539 Mdot
.774 .25545 Mdot
.774 .25566 Mdot
.774 .25627 Mdot
.774 .25691 Mdot
.774 .25725 Mdot
.774 .2587 Mdot
.774 .25919 Mdot
.774 .25927 Mdot
.774 .25985 Mdot
.774 .26067 Mdot
.774 .26071 Mdot
.774 .26106 Mdot
.774 .26115 Mdot
.774 .26134 Mdot
.774 .26181 Mdot
.774 .26217 Mdot
.774 .2623 Mdot
.774 .2624 Mdot
.774 .26303 Mdot
.774 .26365 Mdot
.774 .26368 Mdot
.774 .2645 Mdot
.774 .26473 Mdot
.774 .26531 Mdot
.774 .26657 Mdot
.774 .26726 Mdot
.774 .26748 Mdot
.774 .26805 Mdot
.774 .2684 Mdot
.774 .26853 Mdot
.774 .27046 Mdot
.774 .2706 Mdot
.774 .27213 Mdot
.774 .27283 Mdot
.774 .27402 Mdot
.774 .27467 Mdot
.774 .27471 Mdot
.774 .27531 Mdot
.774 .2758 Mdot
.774 .27597 Mdot
.774 .279 Mdot
.774 .27922 Mdot
.774 .27993 Mdot
.774 .2803 Mdot
.774 .28067 Mdot
.774 .28164 Mdot
.774 .28312 Mdot
.774 .28345 Mdot
.774 .28416 Mdot
.774 .28534 Mdot
.774 .28593 Mdot
.774 .28632 Mdot
.774 .28646 Mdot
.774 .28655 Mdot
.774 .28735 Mdot
.774 .28776 Mdot
.774 .28865 Mdot
.774 .28998 Mdot
.774 .29022 Mdot
.774 .29063 Mdot
.774 .29137 Mdot
.774 .29273 Mdot
.774 .29285 Mdot
.774 .29298 Mdot
.774 .29498 Mdot
.774 .2951 Mdot
.774 .29632 Mdot
.774 .29682 Mdot
.774 .29698 Mdot
.774 .29752 Mdot
.774 .29939 Mdot
.774 .29952 Mdot
.774 .29957 Mdot
.774 .29981 Mdot
.774 .29992 Mdot
.774 .30026 Mdot
.774 .30148 Mdot
.774 .3018 Mdot
.774 .30303 Mdot
.774 .30339 Mdot
.774 .30494 Mdot
.774 .30566 Mdot
.774 .30618 Mdot
.774 .30754 Mdot
.774 .30836 Mdot
.774 .30856 Mdot
.774 .30864 Mdot
.774 .31006 Mdot
.774 .3103 Mdot
.774 .31044 Mdot
.774 .31058 Mdot
.774 .31121 Mdot
.774 .3117 Mdot
.774 .31198 Mdot
.774 .31209 Mdot
.774 .31223 Mdot
.774 .3137 Mdot
.774 .31419 Mdot
.774 .31453 Mdot
.774 .31477 Mdot
.774 .31477 Mdot
.774 .31484 Mdot
.774 .31589 Mdot
.774 .3172 Mdot
.774 .31752 Mdot
.774 .31768 Mdot
.774 .31832 Mdot
.774 .31862 Mdot
.774 .3189 Mdot
.774 .31903 Mdot
.774 .31928 Mdot
.774 .32104 Mdot
.774 .32174 Mdot
.774 .32222 Mdot
.774 .32231 Mdot
.774 .32231 Mdot
.774 .32301 Mdot
.774 .32326 Mdot
.774 .32333 Mdot
.774 .3255 Mdot
.774 .32553 Mdot
.774 .32727 Mdot
.774 .32816 Mdot
.774 .32967 Mdot
.774 .33024 Mdot
.774 .33045 Mdot
.774 .33061 Mdot
.774 .33109 Mdot
.774 .33175 Mdot
.774 .33241 Mdot
.774 .33246 Mdot
.774 .33275 Mdot
.774 .33298 Mdot
.774 .33339 Mdot
.774 .33406 Mdot
.774 .33489 Mdot
.774 .3356 Mdot
.774 .33639 Mdot
.774 .33678 Mdot
.774 .33716 Mdot
.774 .33746 Mdot
.774 .33791 Mdot
.774 .3384 Mdot
.774 .33883 Mdot
.774 .33957 Mdot
.774 .34015 Mdot
.774 .34027 Mdot
.774 .34097 Mdot
.774 .34319 Mdot
.774 .34375 Mdot
.774 .34381 Mdot
.774 .34466 Mdot
.774 .34606 Mdot
.774 .34625 Mdot
.774 .34735 Mdot
.774 .34751 Mdot
.774 .35076 Mdot
.774 .35173 Mdot
.774 .35224 Mdot
.774 .35263 Mdot
.774 .35309 Mdot
.774 .35323 Mdot
.774 .35353 Mdot
.774 .35522 Mdot
.774 .35642 Mdot
.774 .35688 Mdot
.774 .36005 Mdot
.774 .36067 Mdot
.774 .36153 Mdot
.774 .36187 Mdot
.774 .3619 Mdot
.774 .36216 Mdot
.774 .36218 Mdot
.774 .36265 Mdot
.774 .36284 Mdot
.774 .36332 Mdot
.774 .36374 Mdot
.774 .36413 Mdot
.774 .36414 Mdot
.774 .36541 Mdot
.774 .36578 Mdot
.774 .36615 Mdot
.774 .3677 Mdot
.774 .3681 Mdot
.774 .36932 Mdot
.774 .3699 Mdot
.774 .37085 Mdot
.774 .3711 Mdot
.774 .37187 Mdot
.774 .37242 Mdot
.774 .37259 Mdot
.774 .37355 Mdot
.774 .37409 Mdot
.774 .37459 Mdot
.774 .37535 Mdot
.774 .37569 Mdot
.774 .37701 Mdot
.774 .37734 Mdot
.774 .37773 Mdot
.774 .37848 Mdot
.774 .38048 Mdot
.774 .38209 Mdot
.774 .38275 Mdot
.774 .38303 Mdot
.774 .38335 Mdot
.774 .38362 Mdot
.774 .38541 Mdot
.774 .38645 Mdot
.774 .38649 Mdot
.774 .38663 Mdot
.774 .38719 Mdot
.774 .38728 Mdot
.774 .38737 Mdot
.774 .3877 Mdot
.774 .38863 Mdot
.774 .38963 Mdot
.774 .39016 Mdot
.774 .3924 Mdot
.774 .39316 Mdot
.774 .39329 Mdot
.774 .39419 Mdot
.774 .39546 Mdot
.774 .39551 Mdot
.774 .39605 Mdot
.774 .39619 Mdot
.774 .39648 Mdot
.774 .39722 Mdot
.774 .39777 Mdot
.774 .39797 Mdot
.774 .39813 Mdot
.774 .39911 Mdot
.774 .40007 Mdot
.774 .40011 Mdot
.774 .40139 Mdot
.774 .40173 Mdot
.774 .40264 Mdot
.774 .40459 Mdot
.774 .40566 Mdot
.774 .40599 Mdot
.774 .40687 Mdot
.774 .40741 Mdot
.774 .40762 Mdot
.774 .41061 Mdot
.774 .41083 Mdot
.774 .4132 Mdot
.774 .41428 Mdot
.774 .41611 Mdot
.774 .41712 Mdot
.774 .41718 Mdot
.774 .41811 Mdot
.774 .41888 Mdot
.774 .41914 Mdot
.774 .42383 Mdot
.774 .42417 Mdot
.774 .42527 Mdot
.774 .42585 Mdot
.774 .42641 Mdot
.774 .42791 Mdot
.774 .4302 Mdot
.774 .43071 Mdot
.774 .43181 Mdot
.774 .43364 Mdot
.774 .43455 Mdot
.774 .43517 Mdot
.774 .43537 Mdot
.774 .43551 Mdot
.774 .43676 Mdot
.774 .43739 Mdot
.774 .43876 Mdot
.774 .44083 Mdot
.774 .4412 Mdot
.774 .44183 Mdot
.774 .44297 Mdot
.774 .44508 Mdot
.774 .44527 Mdot
.774 .44547 Mdot
.774 .44875 Mdot
.774 .45063 Mdot
.774 .45141 Mdot
.774 .45166 Mdot
.774 .45249 Mdot
.774 .45539 Mdot
.774 .45559 Mdot
.774 .45567 Mdot
.774 .45605 Mdot
.774 .45621 Mdot
.774 .45674 Mdot
.774 .45862 Mdot
.774 .45912 Mdot
.774 .46103 Mdot
.774 .46158 Mdot
.774 .46398 Mdot
.774 .46509 Mdot
.774 .46591 Mdot
.774 .46801 Mdot
.774 .46928 Mdot
.774 .46959 Mdot
.774 .46971 Mdot
.774 .4719 Mdot
.774 .47228 Mdot
.776 .01547 Mdot
.776 .01555 Mdot
.776 .01583 Mdot
.776 .01587 Mdot
.776 .01589 Mdot
.776 .01601 Mdot
.776 .0163 Mdot
.776 .01645 Mdot
.776 .0165 Mdot
.776 .01654 Mdot
.776 .01673 Mdot
.776 .01717 Mdot
.776 .0174 Mdot
.776 .01749 Mdot
.776 .01754 Mdot
.776 .01784 Mdot
.776 .01853 Mdot
.776 .01888 Mdot
.776 .01902 Mdot
.776 .0191 Mdot
.776 .01956 Mdot
.776 .01972 Mdot
.776 .02058 Mdot
.776 .02064 Mdot
.776 .02107 Mdot
.776 .02118 Mdot
.776 .0212 Mdot
.776 .0214 Mdot
.776 .02152 Mdot
.776 .02223 Mdot
.776 .02248 Mdot
.776 .02276 Mdot
.776 .02382 Mdot
.776 .02391 Mdot
.776 .02437 Mdot
.776 .02458 Mdot
.776 .02475 Mdot
.776 .02478 Mdot
.776 .02479 Mdot
.776 .02509 Mdot
.776 .02528 Mdot
.776 .02638 Mdot
.776 .02676 Mdot
.776 .0272 Mdot
.776 .02884 Mdot
.776 .02898 Mdot
.776 .02928 Mdot
.776 .02953 Mdot
.776 .0297 Mdot
.776 .03003 Mdot
.776 .0302 Mdot
.776 .03029 Mdot
.776 .03033 Mdot
.776 .03035 Mdot
.776 .03067 Mdot
.776 .03081 Mdot
.776 .03112 Mdot
.776 .03124 Mdot
.776 .03189 Mdot
.776 .03235 Mdot
.776 .03282 Mdot
.776 .03341 Mdot
.776 .03409 Mdot
.776 .03557 Mdot
.776 .03592 Mdot
.776 .03664 Mdot
.776 .03669 Mdot
.776 .03685 Mdot
.776 .03732 Mdot
.776 .0377 Mdot
.776 .03797 Mdot
.776 .03811 Mdot
.776 .03849 Mdot
.776 .03875 Mdot
.776 .03889 Mdot
.776 .03895 Mdot
.776 .03898 Mdot
.776 .03948 Mdot
.776 .03969 Mdot
.776 .04017 Mdot
.776 .04037 Mdot
.776 .04079 Mdot
.776 .04096 Mdot
.776 .041 Mdot
.776 .04107 Mdot
.776 .04136 Mdot
.776 .04174 Mdot
.776 .04186 Mdot
.776 .04209 Mdot
.776 .04281 Mdot
.776 .04373 Mdot
.776 .04424 Mdot
.776 .04456 Mdot
.776 .04478 Mdot
.776 .04556 Mdot
.776 .04602 Mdot
.776 .04678 Mdot
.776 .04705 Mdot
.776 .04708 Mdot
.776 .04761 Mdot
.776 .04763 Mdot
.776 .04866 Mdot
.776 .04873 Mdot
.776 .04881 Mdot
.776 .04907 Mdot
.776 .04979 Mdot
.776 .04987 Mdot
.776 .0504 Mdot
.776 .05081 Mdot
.776 .05102 Mdot
.776 .05115 Mdot
.776 .05161 Mdot
.776 .05201 Mdot
.776 .05224 Mdot
.776 .05233 Mdot
.776 .05238 Mdot
.776 .05267 Mdot
.776 .05296 Mdot
.776 .05315 Mdot
.776 .05348 Mdot
.776 .05422 Mdot
.776 .05445 Mdot
.776 .05453 Mdot
.776 .05518 Mdot
.776 .05544 Mdot
.776 .05551 Mdot
.776 .05557 Mdot
.776 .05561 Mdot
.776 .05608 Mdot
.776 .05666 Mdot
.776 .05684 Mdot
.776 .05718 Mdot
.776 .0572 Mdot
.776 .05832 Mdot
.776 .05868 Mdot
.776 .05882 Mdot
.776 .05974 Mdot
.776 .06002 Mdot
.776 .06024 Mdot
.776 .06054 Mdot
.776 .06103 Mdot
.776 .06138 Mdot
.776 .06162 Mdot
.776 .06196 Mdot
.776 .06259 Mdot
.776 .06324 Mdot
.776 .0633 Mdot
.776 .06448 Mdot
.776 .0649 Mdot
.776 .06495 Mdot
.776 .065 Mdot
.776 .06577 Mdot
.776 .0658 Mdot
.776 .06633 Mdot
.776 .0674 Mdot
.776 .06751 Mdot
.776 .06764 Mdot
.776 .06803 Mdot
.776 .0686 Mdot
.776 .06916 Mdot
.776 .06927 Mdot
.776 .06945 Mdot
.776 .07009 Mdot
.776 .07039 Mdot
.776 .07073 Mdot
.776 .07107 Mdot
.776 .07126 Mdot
.776 .07141 Mdot
.776 .07197 Mdot
.776 .0726 Mdot
.776 .07295 Mdot
.776 .07309 Mdot
.776 .07317 Mdot
.776 .07333 Mdot
.776 .07362 Mdot
.776 .07408 Mdot
.776 .07436 Mdot
.776 .07488 Mdot
.776 .07551 Mdot
.776 .07563 Mdot
.776 .07603 Mdot
.776 .07638 Mdot
.776 .07651 Mdot
.776 .07705 Mdot
.776 .07714 Mdot
.776 .07728 Mdot
.776 .07751 Mdot
.776 .07792 Mdot
.776 .07803 Mdot
.776 .07812 Mdot
.776 .07819 Mdot
.776 .07891 Mdot
.776 .07903 Mdot
.776 .07982 Mdot
.776 .08009 Mdot
.776 .0802 Mdot
.776 .08062 Mdot
.776 .08066 Mdot
.776 .0815 Mdot
.776 .08215 Mdot
.776 .08239 Mdot
.776 .08295 Mdot
.776 .08317 Mdot
.776 .0836 Mdot
.776 .08389 Mdot
.776 .08437 Mdot
.776 .0846 Mdot
.776 .08503 Mdot
.776 .08537 Mdot
.776 .08583 Mdot
.776 .08602 Mdot
.776 .08623 Mdot
.776 .08648 Mdot
.776 .08659 Mdot
.776 .08713 Mdot
.776 .08714 Mdot
.776 .08751 Mdot
.776 .08751 Mdot
.776 .08791 Mdot
.776 .08804 Mdot
.776 .08805 Mdot
.776 .08826 Mdot
.776 .08901 Mdot
.776 .09003 Mdot
.776 .09012 Mdot
.776 .09022 Mdot
.776 .09033 Mdot
.776 .09041 Mdot
.776 .09095 Mdot
.776 .09195 Mdot
.776 .0922 Mdot
.776 .0926 Mdot
.776 .09268 Mdot
.776 .09275 Mdot
.776 .09293 Mdot
.776 .09394 Mdot
.776 .09395 Mdot
.776 .094 Mdot
.776 .09482 Mdot
.776 .09547 Mdot
.776 .09648 Mdot
.776 .09656 Mdot
.776 .09666 Mdot
.776 .09685 Mdot
.776 .09747 Mdot
.776 .0976 Mdot
.776 .09834 Mdot
.776 .09921 Mdot
.776 .09938 Mdot
.776 .09966 Mdot
.776 .10009 Mdot
.776 .1004 Mdot
.776 .10066 Mdot
.776 .10113 Mdot
.776 .10166 Mdot
.776 .10217 Mdot
.776 .10248 Mdot
.776 .10271 Mdot
.776 .10324 Mdot
.776 .10358 Mdot
.776 .10391 Mdot
.776 .10429 Mdot
.776 .10455 Mdot
.776 .1051 Mdot
.776 .10532 Mdot
.776 .10543 Mdot
.776 .10568 Mdot
.776 .10614 Mdot
.776 .10629 Mdot
.776 .10684 Mdot
.776 .10695 Mdot
.776 .10729 Mdot
.776 .10792 Mdot
.776 .1081 Mdot
.776 .10907 Mdot
.776 .10925 Mdot
.776 .10959 Mdot
.776 .10987 Mdot
.776 .11036 Mdot
.776 .11042 Mdot
.776 .11062 Mdot
.776 .11076 Mdot
.776 .11108 Mdot
.776 .11146 Mdot
.776 .1116 Mdot
.776 .11182 Mdot
.776 .11218 Mdot
.776 .11222 Mdot
.776 .11281 Mdot
.776 .11298 Mdot
.776 .11306 Mdot
.776 .11312 Mdot
.776 .11323 Mdot
.776 .11434 Mdot
.776 .11453 Mdot
.776 .11493 Mdot
.776 .11504 Mdot
.776 .11576 Mdot
.776 .11618 Mdot
.776 .11634 Mdot
.776 .11699 Mdot
.776 .117 Mdot
.776 .11706 Mdot
.776 .11713 Mdot
.776 .11793 Mdot
.776 .11828 Mdot
.776 .11834 Mdot
.776 .11836 Mdot
.776 .11922 Mdot
.776 .11938 Mdot
.776 .11974 Mdot
.776 .12061 Mdot
.776 .12096 Mdot
.776 .12096 Mdot
.776 .12129 Mdot
.776 .12153 Mdot
.776 .12162 Mdot
.776 .12208 Mdot
.776 .12283 Mdot
.776 .12317 Mdot
.776 .12385 Mdot
.776 .12437 Mdot
.776 .12495 Mdot
.776 .12509 Mdot
.776 .12539 Mdot
.776 .12571 Mdot
.776 .12574 Mdot
.776 .12593 Mdot
.776 .12609 Mdot
.776 .12627 Mdot
.776 .12641 Mdot
.776 .12673 Mdot
.776 .1271 Mdot
.776 .12711 Mdot
.776 .12737 Mdot
.776 .12769 Mdot
.776 .12769 Mdot
.776 .12832 Mdot
.776 .12851 Mdot
.776 .12853 Mdot
.776 .12876 Mdot
.776 .12885 Mdot
.776 .13003 Mdot
.776 .13063 Mdot
.776 .13112 Mdot
.776 .1316 Mdot
.776 .13175 Mdot
.776 .13189 Mdot
.776 .13206 Mdot
.776 .13219 Mdot
.776 .13232 Mdot
.776 .13303 Mdot
.776 .13383 Mdot
.776 .13459 Mdot
.776 .13494 Mdot
.776 .13498 Mdot
.776 .13558 Mdot
.776 .13571 Mdot
.776 .13583 Mdot
.776 .1361 Mdot
.776 .13688 Mdot
.776 .13707 Mdot
.776 .13725 Mdot
.776 .13767 Mdot
.776 .13769 Mdot
.776 .13777 Mdot
.776 .13789 Mdot
.776 .13904 Mdot
.776 .13962 Mdot
.776 .14005 Mdot
.776 .14143 Mdot
.776 .14161 Mdot
.776 .14174 Mdot
.776 .14189 Mdot
.776 .14206 Mdot
.776 .14219 Mdot
.776 .14305 Mdot
.776 .14314 Mdot
.776 .14335 Mdot
.776 .14449 Mdot
.776 .1445 Mdot
.776 .1447 Mdot
.776 .14473 Mdot
.776 .14545 Mdot
.776 .14584 Mdot
.776 .14612 Mdot
.776 .14627 Mdot
.776 .14655 Mdot
.776 .14687 Mdot
.776 .14722 Mdot
.776 .1477 Mdot
.776 .1481 Mdot
.776 .14883 Mdot
.776 .14923 Mdot
.776 .14927 Mdot
.776 .14959 Mdot
.776 .14965 Mdot
.776 .15002 Mdot
.776 .15045 Mdot
.776 .15092 Mdot
.776 .15128 Mdot
.776 .15188 Mdot
.776 .15211 Mdot
.776 .15264 Mdot
.776 .15315 Mdot
.776 .15373 Mdot
.776 .15376 Mdot
.776 .15415 Mdot
.776 .15467 Mdot
.776 .15499 Mdot
.776 .15533 Mdot
.776 .15551 Mdot
.776 .1559 Mdot
.776 .1566 Mdot
.776 .15667 Mdot
.776 .15684 Mdot
.776 .15694 Mdot
.776 .15705 Mdot
.776 .15714 Mdot
.776 .15767 Mdot
.776 .1577 Mdot
.776 .15786 Mdot
.776 .15839 Mdot
.776 .15907 Mdot
.776 .15936 Mdot
.776 .15964 Mdot
.776 .16039 Mdot
.776 .16115 Mdot
.776 .16143 Mdot
.776 .16197 Mdot
.776 .16214 Mdot
.776 .1624 Mdot
.776 .16285 Mdot
.776 .16306 Mdot
.776 .16316 Mdot
.776 .16325 Mdot
.776 .16355 Mdot
.776 .16378 Mdot
.776 .16428 Mdot
.776 .16487 Mdot
.776 .16508 Mdot
.776 .16517 Mdot
.776 .16543 Mdot
.776 .16598 Mdot
.776 .16604 Mdot
.776 .16696 Mdot
.776 .16722 Mdot
.776 .16735 Mdot
.776 .16743 Mdot
.776 .16761 Mdot
.776 .16893 Mdot
.776 .16933 Mdot
.776 .16963 Mdot
.776 .1702 Mdot
.776 .17025 Mdot
.776 .17042 Mdot
.776 .17154 Mdot
.776 .17219 Mdot
.776 .17224 Mdot
.776 .17225 Mdot
.776 .17244 Mdot
.776 .17345 Mdot
.776 .17346 Mdot
.776 .17355 Mdot
.776 .17366 Mdot
.776 .17416 Mdot
.776 .17491 Mdot
.776 .17544 Mdot
.776 .17552 Mdot
.776 .17555 Mdot
.776 .17557 Mdot
.776 .17609 Mdot
.776 .17691 Mdot
.776 .17715 Mdot
.776 .17772 Mdot
.776 .17872 Mdot
.776 .17906 Mdot
.776 .17961 Mdot
.776 .17961 Mdot
.776 .18012 Mdot
.776 .18048 Mdot
.776 .18064 Mdot
.776 .18134 Mdot
.776 .1825 Mdot
.776 .18304 Mdot
.776 .18306 Mdot
.776 .18409 Mdot
.776 .18489 Mdot
.776 .18507 Mdot
.776 .18515 Mdot
.776 .18579 Mdot
.776 .18601 Mdot
.776 .18648 Mdot
.776 .18698 Mdot
.776 .18702 Mdot
.776 .1871 Mdot
.776 .18733 Mdot
.776 .18757 Mdot
.776 .18785 Mdot
.776 .18807 Mdot
.776 .18856 Mdot
.776 .18899 Mdot
.776 .18914 Mdot
.776 .18915 Mdot
.776 .18955 Mdot
.776 .19005 Mdot
.776 .19005 Mdot
.776 .19103 Mdot
.776 .19133 Mdot
.776 .19136 Mdot
.776 .19171 Mdot
.776 .19186 Mdot
.776 .19199 Mdot
.776 .19265 Mdot
.776 .19297 Mdot
.776 .19368 Mdot
.776 .19462 Mdot
.776 .19537 Mdot
.776 .19538 Mdot
.776 .19612 Mdot
.776 .19617 Mdot
.776 .19635 Mdot
.776 .19658 Mdot
.776 .19684 Mdot
.776 .19704 Mdot
.776 .19723 Mdot
.776 .19791 Mdot
.776 .19834 Mdot
.776 .19958 Mdot
.776 .19979 Mdot
.776 .19994 Mdot
.776 .20023 Mdot
.776 .20076 Mdot
.776 .2011 Mdot
.776 .20131 Mdot
.776 .20136 Mdot
.776 .202 Mdot
.776 .20231 Mdot
.776 .20251 Mdot
.776 .20269 Mdot
.776 .20304 Mdot
.776 .20311 Mdot
.776 .20388 Mdot
.776 .20431 Mdot
.776 .20461 Mdot
.776 .20488 Mdot
.776 .20555 Mdot
.776 .20558 Mdot
.776 .20569 Mdot
.776 .20571 Mdot
.776 .20589 Mdot
.776 .20731 Mdot
.776 .20767 Mdot
.776 .20787 Mdot
.776 .20792 Mdot
.776 .20857 Mdot
.776 .20924 Mdot
.776 .20941 Mdot
.776 .21128 Mdot
.776 .21138 Mdot
.776 .21166 Mdot
.776 .21186 Mdot
.776 .21209 Mdot
.776 .21236 Mdot
.776 .21255 Mdot
.776 .21389 Mdot
.776 .21404 Mdot
.776 .21435 Mdot
.776 .21494 Mdot
.776 .21606 Mdot
.776 .21613 Mdot
.776 .21614 Mdot
.776 .21617 Mdot
.776 .21645 Mdot
.776 .2165 Mdot
.776 .21749 Mdot
.776 .21762 Mdot
.776 .21804 Mdot
.776 .21823 Mdot
.776 .21854 Mdot
.776 .21865 Mdot
.776 .21889 Mdot
.776 .21932 Mdot
.776 .21982 Mdot
.776 .22036 Mdot
.776 .22099 Mdot
.776 .22111 Mdot
.776 .22173 Mdot
.776 .22219 Mdot
.776 .22286 Mdot
.776 .22348 Mdot
.776 .22354 Mdot
.776 .22404 Mdot
.776 .22413 Mdot
.776 .2247 Mdot
.776 .22485 Mdot
.776 .22538 Mdot
.776 .22611 Mdot
.776 .22666 Mdot
.776 .2276 Mdot
.776 .22795 Mdot
.776 .22835 Mdot
.776 .22877 Mdot
.776 .22957 Mdot
.776 .23047 Mdot
.776 .23052 Mdot
.776 .23111 Mdot
.776 .23115 Mdot
.776 .23121 Mdot
.776 .23193 Mdot
.776 .23242 Mdot
.776 .23296 Mdot
.776 .23323 Mdot
.776 .23383 Mdot
.776 .23395 Mdot
.776 .23415 Mdot
.776 .23484 Mdot
.776 .23492 Mdot
.776 .23502 Mdot
.776 .23529 Mdot
.776 .23545 Mdot
.776 .23562 Mdot
.776 .23568 Mdot
.776 .23576 Mdot
.776 .23658 Mdot
.776 .23662 Mdot
.776 .23666 Mdot
.776 .23688 Mdot
.776 .2374 Mdot
.776 .2377 Mdot
.776 .23812 Mdot
.776 .23876 Mdot
.776 .23921 Mdot
.776 .23964 Mdot
.776 .24068 Mdot
.776 .24081 Mdot
.776 .24198 Mdot
.776 .24226 Mdot
.776 .24242 Mdot
.776 .24325 Mdot
.776 .24352 Mdot
.776 .24392 Mdot
.776 .24462 Mdot
.776 .24494 Mdot
.776 .24511 Mdot
.776 .24524 Mdot
.776 .24571 Mdot
.776 .24606 Mdot
.776 .24684 Mdot
.776 .24688 Mdot
.776 .2477 Mdot
.776 .24775 Mdot
.776 .24808 Mdot
.776 .24823 Mdot
.776 .24825 Mdot
.776 .24862 Mdot
.776 .24934 Mdot
.776 .24948 Mdot
.776 .24957 Mdot
.776 .251 Mdot
.776 .25132 Mdot
.776 .25141 Mdot
.776 .2516 Mdot
.776 .25174 Mdot
.776 .252 Mdot
.776 .25258 Mdot
.776 .25336 Mdot
.776 .25356 Mdot
.776 .25405 Mdot
.776 .25468 Mdot
.776 .25514 Mdot
.776 .25595 Mdot
.776 .25603 Mdot
.776 .2561 Mdot
.776 .25637 Mdot
.776 .25709 Mdot
.776 .25784 Mdot
.776 .2581 Mdot
.776 .25851 Mdot
.776 .25911 Mdot
.776 .2592 Mdot
.776 .25921 Mdot
.776 .25951 Mdot
.776 .25985 Mdot
.776 .2601 Mdot
.776 .26108 Mdot
.776 .26109 Mdot
.776 .26123 Mdot
.776 .2614 Mdot
.776 .26218 Mdot
.776 .26296 Mdot
.776 .26334 Mdot
.776 .26416 Mdot
.776 .26428 Mdot
.776 .26432 Mdot
.776 .26436 Mdot
.776 .26458 Mdot
.776 .26516 Mdot
.776 .26571 Mdot
.776 .26644 Mdot
.776 .26673 Mdot
.776 .26682 Mdot
.776 .2677 Mdot
.776 .26925 Mdot
.776 .26978 Mdot
.776 .27063 Mdot
.776 .27063 Mdot
.776 .27143 Mdot
.776 .27199 Mdot
.776 .27223 Mdot
.776 .27332 Mdot
.776 .27512 Mdot
.776 .27595 Mdot
.776 .27599 Mdot
.776 .27758 Mdot
.776 .27883 Mdot
.776 .2791 Mdot
.776 .27924 Mdot
.776 .28023 Mdot
.776 .28056 Mdot
.776 .28129 Mdot
.776 .28207 Mdot
.776 .28213 Mdot
.776 .28225 Mdot
.776 .28261 Mdot
.776 .28298 Mdot
.776 .28342 Mdot
.776 .28376 Mdot
.776 .28452 Mdot
.776 .28519 Mdot
.776 .28542 Mdot
.776 .28544 Mdot
.776 .28606 Mdot
.776 .28684 Mdot
.776 .28684 Mdot
.776 .28836 Mdot
.776 .28882 Mdot
.776 .28887 Mdot
.776 .28941 Mdot
.776 .28964 Mdot
.776 .28985 Mdot
.776 .29087 Mdot
.776 .29137 Mdot
.776 .29247 Mdot
.776 .29392 Mdot
.776 .29509 Mdot
.776 .29511 Mdot
.776 .29625 Mdot
.776 .29633 Mdot
.776 .29662 Mdot
.776 .29697 Mdot
.776 .29737 Mdot
.776 .29768 Mdot
.776 .29798 Mdot
.776 .29904 Mdot
.776 .2997 Mdot
.776 .30162 Mdot
.776 .30196 Mdot
.776 .30219 Mdot
.776 .30264 Mdot
.776 .30346 Mdot
.776 .30398 Mdot
.776 .30431 Mdot
.776 .30439 Mdot
.776 .30538 Mdot
.776 .30585 Mdot
.776 .30617 Mdot
.776 .30645 Mdot
.776 .307 Mdot
.776 .3071 Mdot
.776 .30829 Mdot
.776 .30897 Mdot
.776 .30943 Mdot
.776 .30986 Mdot
.776 .31088 Mdot
.776 .31093 Mdot
.776 .31111 Mdot
.776 .31114 Mdot
.776 .31142 Mdot
.776 .31362 Mdot
.776 .31417 Mdot
.776 .31449 Mdot
.776 .31457 Mdot
.776 .31558 Mdot
.776 .31662 Mdot
.776 .31689 Mdot
.776 .31978 Mdot
.776 .31994 Mdot
.776 .32037 Mdot
.776 .32068 Mdot
.776 .32105 Mdot
.776 .32146 Mdot
.776 .32176 Mdot
.776 .32383 Mdot
.776 .32406 Mdot
.776 .32455 Mdot
.776 .32547 Mdot
.776 .32719 Mdot
.776 .3273 Mdot
.776 .32733 Mdot
.776 .32738 Mdot
.776 .32781 Mdot
.776 .32788 Mdot
.776 .32942 Mdot
.776 .32962 Mdot
.776 .33027 Mdot
.776 .33057 Mdot
.776 .33106 Mdot
.776 .33123 Mdot
.776 .33159 Mdot
.776 .33227 Mdot
.776 .33304 Mdot
.776 .33387 Mdot
.776 .33485 Mdot
.776 .33504 Mdot
.776 .336 Mdot
.776 .33672 Mdot
.776 .33776 Mdot
.776 .33872 Mdot
.776 .33882 Mdot
.776 .33959 Mdot
.776 .33973 Mdot
.776 .34062 Mdot
.776 .34084 Mdot
.776 .34166 Mdot
.776 .34279 Mdot
.776 .34365 Mdot
.776 .34511 Mdot
.776 .34566 Mdot
.776 .34627 Mdot
.776 .34693 Mdot
.776 .34816 Mdot
.776 .34957 Mdot
.776 .34964 Mdot
.776 .35056 Mdot
.776 .35062 Mdot
.776 .35071 Mdot
.776 .35184 Mdot
.776 .35259 Mdot
.776 .35342 Mdot
.776 .35385 Mdot
.776 .35478 Mdot
.776 .35497 Mdot
.776 .35528 Mdot
.776 .35634 Mdot
.776 .35648 Mdot
.776 .35663 Mdot
.776 .35705 Mdot
.776 .3573 Mdot
.776 .35756 Mdot
.776 .35765 Mdot
.776 .35778 Mdot
.776 .35904 Mdot
.776 .35911 Mdot
.776 .35917 Mdot
.776 .35952 Mdot
.776 .36032 Mdot
.776 .36079 Mdot
.776 .36144 Mdot
.776 .36243 Mdot
.776 .36313 Mdot
.776 .3638 Mdot
.776 .36541 Mdot
.776 .36561 Mdot
.776 .36744 Mdot
.776 .36787 Mdot
.776 .36811 Mdot
.776 .3694 Mdot
.776 .36983 Mdot
.776 .37045 Mdot
.776 .37153 Mdot
.776 .37203 Mdot
.776 .37228 Mdot
.776 .37249 Mdot
.776 .37322 Mdot
.776 .37376 Mdot
.776 .37497 Mdot
.776 .37504 Mdot
.776 .3763 Mdot
.776 .37639 Mdot
.776 .3769 Mdot
.776 .37712 Mdot
.776 .37717 Mdot
.776 .37773 Mdot
.776 .37885 Mdot
.776 .37907 Mdot
.776 .37922 Mdot
.776 .38142 Mdot
.776 .38193 Mdot
.776 .38206 Mdot
.776 .38237 Mdot
.776 .38257 Mdot
.776 .38298 Mdot
.776 .38388 Mdot
.776 .38508 Mdot
.776 .3854 Mdot
.776 .38617 Mdot
.776 .38714 Mdot
.776 .38786 Mdot
.776 .38911 Mdot
.776 .38923 Mdot
.776 .38935 Mdot
.776 .38976 Mdot
.776 .39088 Mdot
.776 .39204 Mdot
.776 .39245 Mdot
.776 .39309 Mdot
.776 .39401 Mdot
.776 .39415 Mdot
.776 .39417 Mdot
.776 .39463 Mdot
.776 .39516 Mdot
.776 .39555 Mdot
.776 .39707 Mdot
.776 .39709 Mdot
.776 .3973 Mdot
.776 .39758 Mdot
.776 .39878 Mdot
.776 .39999 Mdot
.776 .40058 Mdot
.776 .40186 Mdot
.776 .40204 Mdot
.776 .40211 Mdot
.776 .40217 Mdot
.776 .4025 Mdot
.776 .40341 Mdot
.776 .40426 Mdot
.776 .40539 Mdot
.776 .40584 Mdot
.776 .40598 Mdot
.776 .40734 Mdot
.776 .40976 Mdot
.776 .41058 Mdot
.776 .4119 Mdot
.776 .4119 Mdot
.776 .41313 Mdot
.776 .41401 Mdot
.776 .41437 Mdot
.776 .41607 Mdot
.776 .41887 Mdot
.776 .42016 Mdot
.776 .42021 Mdot
.776 .42269 Mdot
.776 .42462 Mdot
.776 .42504 Mdot
.776 .42525 Mdot
.776 .4268 Mdot
.776 .42731 Mdot
.776 .42844 Mdot
.776 .42965 Mdot
.776 .42974 Mdot
.776 .42993 Mdot
.776 .43049 Mdot
.776 .43107 Mdot
.776 .43174 Mdot
.776 .43228 Mdot
.776 .43346 Mdot
.776 .43449 Mdot
.776 .43485 Mdot
.776 .43489 Mdot
.776 .43585 Mdot
.776 .43705 Mdot
.776 .43941 Mdot
.776 .44013 Mdot
.776 .4402 Mdot
.776 .44105 Mdot
.776 .4414 Mdot
.776 .44173 Mdot
.776 .4433 Mdot
.776 .44408 Mdot
.776 .44579 Mdot
.776 .44805 Mdot
.776 .44985 Mdot
.776 .44989 Mdot
.776 .45166 Mdot
.776 .45179 Mdot
.776 .45223 Mdot
.776 .45277 Mdot
.776 .4534 Mdot
.776 .45388 Mdot
.776 .45434 Mdot
.776 .45599 Mdot
.776 .45701 Mdot
.776 .45999 Mdot
.776 .46051 Mdot
.776 .46087 Mdot
.776 .46157 Mdot
.776 .46285 Mdot
.776 .46366 Mdot
.776 .46416 Mdot
.776 .46429 Mdot
.776 .46583 Mdot
.776 .46656 Mdot
.776 .46705 Mdot
.776 .46748 Mdot
.776 .46834 Mdot
.776 .4685 Mdot
.776 .47035 Mdot
.776 .47139 Mdot
.776 .47212 Mdot
.776 .47278 Mdot
.778 .01554 Mdot
.778 .01593 Mdot
.778 .01599 Mdot
.778 .0162 Mdot
.778 .0166 Mdot
.778 .01668 Mdot
.778 .01671 Mdot
.778 .01702 Mdot
.778 .01765 Mdot
.778 .01778 Mdot
.778 .01781 Mdot
.778 .0182 Mdot
.778 .0183 Mdot
.778 .01846 Mdot
.778 .01925 Mdot
.778 .01928 Mdot
.778 .01948 Mdot
.778 .01953 Mdot
.778 .01978 Mdot
.778 .02009 Mdot
.778 .02014 Mdot
.778 .0203 Mdot
.778 .02052 Mdot
.778 .02055 Mdot
.778 .02177 Mdot
.778 .02182 Mdot
.778 .02214 Mdot
.778 .02221 Mdot
.778 .0226 Mdot
.778 .02267 Mdot
.778 .02297 Mdot
.778 .02308 Mdot
.778 .02316 Mdot
.778 .0234 Mdot
.778 .02375 Mdot
.778 .02379 Mdot
.778 .02533 Mdot
.778 .02554 Mdot
.778 .02569 Mdot
.778 .02577 Mdot
.778 .02626 Mdot
.778 .02638 Mdot
.778 .02698 Mdot
.778 .02709 Mdot
.778 .02709 Mdot
.778 .02755 Mdot
.778 .02773 Mdot
.778 .02786 Mdot
.778 .02824 Mdot
.778 .02827 Mdot
.778 .02846 Mdot
.778 .02859 Mdot
.778 .02875 Mdot
.778 .02878 Mdot
.778 .02884 Mdot
.778 .02901 Mdot
.778 .02944 Mdot
.778 .03115 Mdot
.778 .03123 Mdot
.778 .03135 Mdot
.778 .03155 Mdot
.778 .03179 Mdot
.778 .03192 Mdot
.778 .03192 Mdot
.778 .03268 Mdot
.778 .03287 Mdot
.778 .03324 Mdot
.778 .0338 Mdot
.778 .03396 Mdot
.778 .03397 Mdot
.778 .03469 Mdot
.778 .03497 Mdot
.778 .03517 Mdot
.778 .03549 Mdot
.778 .03575 Mdot
.778 .03578 Mdot
.778 .03581 Mdot
.778 .03611 Mdot
.778 .0363 Mdot
.778 .03655 Mdot
.778 .0366 Mdot
.778 .03669 Mdot
.778 .03676 Mdot
.778 .03691 Mdot
.778 .03692 Mdot
.778 .03695 Mdot
.778 .03763 Mdot
.778 .03771 Mdot
.778 .03783 Mdot
.778 .03831 Mdot
.778 .04 Mdot
.778 .04028 Mdot
.778 .04041 Mdot
.778 .04044 Mdot
.778 .04061 Mdot
.778 .04092 Mdot
.778 .04128 Mdot
.778 .04142 Mdot
.778 .04148 Mdot
.778 .04149 Mdot
.778 .04202 Mdot
.778 .04248 Mdot
.778 .04267 Mdot
.778 .04296 Mdot
.778 .04317 Mdot
.778 .04354 Mdot
.778 .04373 Mdot
.778 .04442 Mdot
.778 .04466 Mdot
.778 .04467 Mdot
.778 .04488 Mdot
.778 .04489 Mdot
.778 .04489 Mdot
.778 .04569 Mdot
.778 .0458 Mdot
.778 .04595 Mdot
.778 .04623 Mdot
.778 .04648 Mdot
.778 .04654 Mdot
.778 .04704 Mdot
.778 .04745 Mdot
.778 .04749 Mdot
.778 .04754 Mdot
.778 .048 Mdot
.778 .0483 Mdot
.778 .04834 Mdot
.778 .0486 Mdot
.778 .0487 Mdot
.778 .04876 Mdot
.778 .04891 Mdot
.778 .04901 Mdot
.778 .04918 Mdot
.778 .04926 Mdot
.778 .04926 Mdot
.778 .04931 Mdot
.778 .05003 Mdot
.778 .05037 Mdot
.778 .0505 Mdot
.778 .05068 Mdot
.778 .05069 Mdot
.778 .05125 Mdot
.778 .05143 Mdot
.778 .05279 Mdot
.778 .05356 Mdot
.778 .05376 Mdot
.778 .05404 Mdot
.778 .05406 Mdot
.778 .05408 Mdot
.778 .0545 Mdot
.778 .05469 Mdot
.778 .05475 Mdot
.778 .05495 Mdot
.778 .055 Mdot
.778 .05548 Mdot
.778 .05577 Mdot
.778 .05604 Mdot
.778 .05627 Mdot
.778 .05637 Mdot
.778 .05638 Mdot
.778 .0572 Mdot
.778 .05792 Mdot
.778 .05818 Mdot
.778 .05821 Mdot
.778 .05866 Mdot
.778 .05899 Mdot
.778 .05956 Mdot
.778 .05986 Mdot
.778 .06063 Mdot
.778 .06093 Mdot
.778 .06132 Mdot
.778 .06133 Mdot
.778 .06165 Mdot
.778 .06167 Mdot
.778 .06167 Mdot
.778 .0625 Mdot
.778 .06292 Mdot
.778 .06308 Mdot
.778 .06331 Mdot
.778 .06375 Mdot
.778 .06381 Mdot
.778 .06414 Mdot
.778 .06424 Mdot
.778 .06501 Mdot
.778 .06505 Mdot
.778 .06514 Mdot
.778 .06515 Mdot
.778 .06525 Mdot
.778 .06565 Mdot
.778 .06571 Mdot
.778 .06579 Mdot
.778 .06651 Mdot
.778 .06698 Mdot
.778 .06704 Mdot
.778 .06743 Mdot
.778 .06759 Mdot
.778 .06769 Mdot
.778 .06793 Mdot
.778 .06808 Mdot
.778 .06834 Mdot
.778 .06846 Mdot
.778 .06846 Mdot
.778 .06855 Mdot
.778 .06957 Mdot
.778 .06966 Mdot
.778 .07019 Mdot
.778 .0704 Mdot
.778 .07067 Mdot
.778 .0707 Mdot
.778 .07156 Mdot
.778 .07185 Mdot
.778 .07314 Mdot
.778 .07359 Mdot
.778 .07396 Mdot
.778 .07436 Mdot
.778 .07515 Mdot
.778 .07542 Mdot
.778 .07546 Mdot
.778 .07574 Mdot
.778 .0759 Mdot
.778 .07594 Mdot
.778 .07597 Mdot
.778 .07662 Mdot
.778 .07692 Mdot
.778 .07701 Mdot
.778 .07732 Mdot
.778 .0774 Mdot
.778 .07809 Mdot
.778 .07815 Mdot
.778 .0786 Mdot
.778 .07902 Mdot
.778 .07937 Mdot
.778 .07952 Mdot
.778 .07955 Mdot
.778 .08082 Mdot
.778 .0809 Mdot
.778 .08195 Mdot
.778 .08234 Mdot
.778 .08239 Mdot
.778 .08281 Mdot
.778 .0831 Mdot
.778 .08361 Mdot
.778 .0845 Mdot
.778 .08468 Mdot
.778 .08497 Mdot
.778 .08616 Mdot
.778 .08663 Mdot
.778 .08719 Mdot
.778 .08723 Mdot
.778 .08725 Mdot
.778 .08752 Mdot
.778 .08762 Mdot
.778 .08775 Mdot
.778 .08777 Mdot
.778 .08777 Mdot
.778 .08886 Mdot
.778 .08907 Mdot
.778 .08916 Mdot
.778 .08972 Mdot
.778 .08997 Mdot
.778 .09033 Mdot
.778 .09102 Mdot
.778 .09111 Mdot
.778 .09162 Mdot
.778 .09168 Mdot
.778 .09177 Mdot
.778 .09286 Mdot
.778 .09297 Mdot
.778 .09303 Mdot
.778 .09318 Mdot
.778 .0932 Mdot
.778 .09334 Mdot
.778 .0938 Mdot
.778 .09397 Mdot
.778 .09407 Mdot
.778 .09419 Mdot
.778 .09501 Mdot
.778 .09531 Mdot
.778 .09571 Mdot
.778 .09604 Mdot
.778 .09614 Mdot
.778 .09675 Mdot
.778 .09696 Mdot
.778 .09699 Mdot
.778 .09699 Mdot
.778 .09714 Mdot
.778 .09752 Mdot
.778 .09776 Mdot
.778 .09815 Mdot
.778 .09835 Mdot
.778 .09835 Mdot
.778 .09849 Mdot
.778 .09862 Mdot
.778 .09943 Mdot
.778 .10007 Mdot
.778 .10021 Mdot
.778 .10103 Mdot
.778 .10135 Mdot
.778 .10179 Mdot
.778 .10182 Mdot
.778 .10256 Mdot
.778 .10317 Mdot
.778 .10338 Mdot
.778 .10361 Mdot
.778 .10562 Mdot
.778 .10564 Mdot
.778 .1059 Mdot
.778 .10633 Mdot
.778 .1069 Mdot
.778 .10723 Mdot
.778 .10752 Mdot
.778 .10833 Mdot
.778 .10871 Mdot
.778 .10876 Mdot
.778 .10917 Mdot
.778 .10924 Mdot
.778 .10968 Mdot
.778 .10992 Mdot
.778 .10998 Mdot
.778 .11002 Mdot
.778 .11052 Mdot
.778 .11103 Mdot
.778 .11129 Mdot
.778 .11151 Mdot
.778 .11164 Mdot
.778 .11214 Mdot
.778 .11225 Mdot
.778 .11273 Mdot
.778 .11307 Mdot
.778 .11332 Mdot
.778 .11333 Mdot
.778 .11342 Mdot
.778 .11412 Mdot
.778 .11466 Mdot
.778 .11478 Mdot
.778 .11508 Mdot
.778 .1151 Mdot
.778 .11532 Mdot
.778 .11556 Mdot
.778 .1156 Mdot
.778 .11626 Mdot
.778 .11757 Mdot
.778 .1177 Mdot
.778 .11925 Mdot
.778 .11933 Mdot
.778 .11994 Mdot
.778 .12002 Mdot
.778 .12068 Mdot
.778 .12077 Mdot
.778 .12112 Mdot
.778 .12192 Mdot
.778 .12204 Mdot
.778 .12279 Mdot
.778 .12299 Mdot
.778 .1233 Mdot
.778 .12358 Mdot
.778 .12403 Mdot
.778 .1257 Mdot
.778 .12572 Mdot
.778 .12588 Mdot
.778 .126 Mdot
.778 .12638 Mdot
.778 .12661 Mdot
.778 .12749 Mdot
.778 .12754 Mdot
.778 .12758 Mdot
.778 .12774 Mdot
.778 .12801 Mdot
.778 .12815 Mdot
.778 .12836 Mdot
.778 .12839 Mdot
.778 .12839 Mdot
.778 .12917 Mdot
.778 .12977 Mdot
.778 .13008 Mdot
.778 .13042 Mdot
.778 .13055 Mdot
.778 .13119 Mdot
.778 .13142 Mdot
.778 .13159 Mdot
.778 .13181 Mdot
.778 .13237 Mdot
.778 .13266 Mdot
.778 .13269 Mdot
.778 .13325 Mdot
.778 .13344 Mdot
.778 .13358 Mdot
.778 .13438 Mdot
.778 .13448 Mdot
.778 .13462 Mdot
.778 .13558 Mdot
.778 .1363 Mdot
.778 .13648 Mdot
.778 .13658 Mdot
.778 .13681 Mdot
.778 .13684 Mdot
.778 .13706 Mdot
.778 .13736 Mdot
.778 .13777 Mdot
.778 .13804 Mdot
.778 .13818 Mdot
.778 .13838 Mdot
.778 .13903 Mdot
.778 .13966 Mdot
.778 .14012 Mdot
.778 .14044 Mdot
.778 .14049 Mdot
.778 .14052 Mdot
.778 .14075 Mdot
.778 .1412 Mdot
.778 .14126 Mdot
.778 .14141 Mdot
.778 .14235 Mdot
.778 .14243 Mdot
.778 .14269 Mdot
.778 .14273 Mdot
.778 .14273 Mdot
.778 .14294 Mdot
.778 .14298 Mdot
.778 .1431 Mdot
.778 .14355 Mdot
.778 .14367 Mdot
.778 .14393 Mdot
.778 .14439 Mdot
.778 .14454 Mdot
.778 .14485 Mdot
.778 .14485 Mdot
.778 .14506 Mdot
.778 .14513 Mdot
.778 .14527 Mdot
.778 .14577 Mdot
.778 .14599 Mdot
.778 .14654 Mdot
.778 .14695 Mdot
.778 .14752 Mdot
.778 .14774 Mdot
.778 .14838 Mdot
.778 .14903 Mdot
.778 .14953 Mdot
.778 .14987 Mdot
.778 .1502 Mdot
.778 .15025 Mdot
.778 .1514 Mdot
.778 .15235 Mdot
.778 .15267 Mdot
.778 .15295 Mdot
.778 .15304 Mdot
.778 .15441 Mdot
.778 .15608 Mdot
.778 .15617 Mdot
.778 .15619 Mdot
.778 .1566 Mdot
.778 .15727 Mdot
.778 .15758 Mdot
.778 .15815 Mdot
.778 .15834 Mdot
.778 .15867 Mdot
.778 .15911 Mdot
.778 .16037 Mdot
.778 .16097 Mdot
.778 .16104 Mdot
.778 .1614 Mdot
.778 .16169 Mdot
.778 .16179 Mdot
.778 .16248 Mdot
.778 .16286 Mdot
.778 .16295 Mdot
.778 .16302 Mdot
.778 .16348 Mdot
.778 .16379 Mdot
.778 .16459 Mdot
.778 .16499 Mdot
.778 .16533 Mdot
.778 .16553 Mdot
.778 .1663 Mdot
.778 .16638 Mdot
.778 .16648 Mdot
.778 .16722 Mdot
.778 .16738 Mdot
.778 .16776 Mdot
.778 .16786 Mdot
.778 .16815 Mdot
.778 .16816 Mdot
.778 .1683 Mdot
.778 .16892 Mdot
.778 .1694 Mdot
.778 .17023 Mdot
.778 .17023 Mdot
.778 .17041 Mdot
.778 .17088 Mdot
.778 .17092 Mdot
.778 .17107 Mdot
.778 .17126 Mdot
.778 .17146 Mdot
.778 .17163 Mdot
.778 .17169 Mdot
.778 .17194 Mdot
.778 .17272 Mdot
.778 .17353 Mdot
.778 .17392 Mdot
.778 .17476 Mdot
.778 .17496 Mdot
.778 .17578 Mdot
.778 .17633 Mdot
.778 .17736 Mdot
.778 .17749 Mdot
.778 .17834 Mdot
.778 .17845 Mdot
.778 .17857 Mdot
.778 .17959 Mdot
.778 .17974 Mdot
.778 .18027 Mdot
.778 .18153 Mdot
.778 .18172 Mdot
.778 .18288 Mdot
.778 .18306 Mdot
.778 .18319 Mdot
.778 .18367 Mdot
.778 .18378 Mdot
.778 .18411 Mdot
.778 .1848 Mdot
.778 .18741 Mdot
.778 .18744 Mdot
.778 .18769 Mdot
.778 .18787 Mdot
.778 .18815 Mdot
.778 .18847 Mdot
.778 .18882 Mdot
.778 .18885 Mdot
.778 .18931 Mdot
.778 .19019 Mdot
.778 .19027 Mdot
.778 .19033 Mdot
.778 .19059 Mdot
.778 .191 Mdot
.778 .19115 Mdot
.778 .19123 Mdot
.778 .19154 Mdot
.778 .19156 Mdot
.778 .19159 Mdot
.778 .1916 Mdot
.778 .19281 Mdot
.778 .19281 Mdot
.778 .19374 Mdot
.778 .19423 Mdot
.778 .19475 Mdot
.778 .19495 Mdot
.778 .19541 Mdot
.778 .19595 Mdot
.778 .1963 Mdot
.778 .19657 Mdot
.778 .19691 Mdot
.778 .19779 Mdot
.778 .19824 Mdot
.778 .19829 Mdot
.778 .19915 Mdot
.778 .19945 Mdot
.778 .19967 Mdot
.778 .20091 Mdot
.778 .20107 Mdot
.778 .20128 Mdot
.778 .20278 Mdot
.778 .20391 Mdot
.778 .20419 Mdot
.778 .20433 Mdot
.778 .20469 Mdot
.778 .20474 Mdot
.778 .20508 Mdot
.778 .20524 Mdot
.778 .20535 Mdot
.778 .20555 Mdot
.778 .20618 Mdot
.778 .20629 Mdot
.778 .20661 Mdot
.778 .20683 Mdot
.778 .20696 Mdot
.778 .20714 Mdot
.778 .20803 Mdot
.778 .20815 Mdot
.778 .20912 Mdot
.778 .20921 Mdot
.778 .20985 Mdot
.778 .21034 Mdot
.778 .21042 Mdot
.778 .21047 Mdot
.778 .21054 Mdot
.778 .21064 Mdot
.778 .21082 Mdot
.778 .21153 Mdot
.778 .21161 Mdot
.778 .21185 Mdot
.778 .21239 Mdot
.778 .21332 Mdot
.778 .21344 Mdot
.778 .21385 Mdot
.778 .21391 Mdot
.778 .21391 Mdot
.778 .21424 Mdot
.778 .21429 Mdot
.778 .21449 Mdot
.778 .21519 Mdot
.778 .21537 Mdot
.778 .21577 Mdot
.778 .21602 Mdot
.778 .21621 Mdot
.778 .2165 Mdot
.778 .21673 Mdot
.778 .2172 Mdot
.778 .2172 Mdot
.778 .2172 Mdot
.778 .21754 Mdot
.778 .21764 Mdot
.778 .21786 Mdot
.778 .21863 Mdot
.778 .21874 Mdot
.778 .21898 Mdot
.778 .21933 Mdot
.778 .2196 Mdot
.778 .21983 Mdot
.778 .22047 Mdot
.778 .22078 Mdot
.778 .22087 Mdot
.778 .22098 Mdot
.778 .221 Mdot
.778 .22136 Mdot
.778 .2217 Mdot
.778 .22269 Mdot
.778 .22371 Mdot
.778 .22448 Mdot
.778 .22502 Mdot
.778 .22553 Mdot
.778 .22557 Mdot
.778 .22557 Mdot
.778 .22561 Mdot
.778 .2274 Mdot
.778 .22887 Mdot
.778 .22906 Mdot
.778 .22937 Mdot
.778 .22981 Mdot
.778 .22995 Mdot
.778 .23092 Mdot
.778 .23208 Mdot
.778 .23287 Mdot
.778 .23364 Mdot
.778 .23468 Mdot
.778 .23481 Mdot
.778 .23485 Mdot
.778 .23537 Mdot
.778 .23549 Mdot
.778 .23653 Mdot
.778 .23702 Mdot
.778 .2374 Mdot
.778 .23791 Mdot
.778 .2382 Mdot
.778 .23871 Mdot
.778 .23872 Mdot
.778 .2394 Mdot
.778 .23973 Mdot
.778 .24102 Mdot
.778 .24136 Mdot
.778 .2423 Mdot
.778 .2424 Mdot
.778 .24295 Mdot
.778 .24341 Mdot
.778 .24357 Mdot
.778 .24431 Mdot
.778 .24463 Mdot
.778 .24522 Mdot
.778 .24537 Mdot
.778 .24547 Mdot
.778 .24602 Mdot
.778 .24619 Mdot
.778 .2462 Mdot
.778 .24668 Mdot
.778 .24792 Mdot
.778 .24855 Mdot
.778 .24907 Mdot
.778 .24938 Mdot
.778 .24946 Mdot
.778 .25058 Mdot
.778 .25059 Mdot
.778 .2507 Mdot
.778 .25086 Mdot
.778 .25143 Mdot
.778 .25202 Mdot
.778 .25226 Mdot
.778 .25285 Mdot
.778 .25301 Mdot
.778 .25346 Mdot
.778 .25347 Mdot
.778 .2537 Mdot
.778 .25466 Mdot
.778 .2554 Mdot
.778 .25609 Mdot
.778 .25667 Mdot
.778 .25669 Mdot
.778 .2567 Mdot
.778 .25698 Mdot
.778 .25749 Mdot
.778 .2577 Mdot
.778 .25777 Mdot
.778 .258 Mdot
.778 .2583 Mdot
.778 .25861 Mdot
.778 .25887 Mdot
.778 .25896 Mdot
.778 .25936 Mdot
.778 .25995 Mdot
.778 .26057 Mdot
.778 .26184 Mdot
.778 .26244 Mdot
.778 .26313 Mdot
.778 .26375 Mdot
.778 .26406 Mdot
.778 .26533 Mdot
.778 .26619 Mdot
.778 .26738 Mdot
.778 .2678 Mdot
.778 .268 Mdot
.778 .26843 Mdot
.778 .26898 Mdot
.778 .26932 Mdot
.778 .26948 Mdot
.778 .26968 Mdot
.778 .27034 Mdot
.778 .2705 Mdot
.778 .27126 Mdot
.778 .27149 Mdot
.778 .27232 Mdot
.778 .27427 Mdot
.778 .27457 Mdot
.778 .27638 Mdot
.778 .27666 Mdot
.778 .27686 Mdot
.778 .27762 Mdot
.778 .27778 Mdot
.778 .2783 Mdot
.778 .27937 Mdot
.778 .28343 Mdot
.778 .28348 Mdot
.778 .28387 Mdot
.778 .28415 Mdot
.778 .28458 Mdot
.778 .28507 Mdot
.778 .28562 Mdot
.778 .28567 Mdot
.778 .28639 Mdot
.778 .28775 Mdot
.778 .28789 Mdot
.778 .28797 Mdot
.778 .28838 Mdot
.778 .28901 Mdot
.778 .28925 Mdot
.778 .28937 Mdot
.778 .28985 Mdot
.778 .28989 Mdot
.778 .28994 Mdot
.778 .28994 Mdot
.778 .29183 Mdot
.778 .29183 Mdot
.778 .29327 Mdot
.778 .29404 Mdot
.778 .29485 Mdot
.778 .29516 Mdot
.778 .29588 Mdot
.778 .29672 Mdot
.778 .29726 Mdot
.778 .29768 Mdot
.778 .29821 Mdot
.778 .29957 Mdot
.778 .30028 Mdot
.778 .30035 Mdot
.778 .3017 Mdot
.778 .30217 Mdot
.778 .30251 Mdot
.778 .30444 Mdot
.778 .30468 Mdot
.778 .30502 Mdot
.778 .30603 Mdot
.778 .30734 Mdot
.778 .3091 Mdot
.778 .30953 Mdot
.778 .30976 Mdot
.778 .31032 Mdot
.778 .31039 Mdot
.778 .31092 Mdot
.778 .31118 Mdot
.778 .31135 Mdot
.778 .31166 Mdot
.778 .31264 Mdot
.778 .31281 Mdot
.778 .31331 Mdot
.778 .31365 Mdot
.778 .31385 Mdot
.778 .31413 Mdot
.778 .31551 Mdot
.778 .3157 Mdot
.778 .31722 Mdot
.778 .31735 Mdot
.778 .31835 Mdot
.778 .31911 Mdot
.778 .31923 Mdot
.778 .31931 Mdot
.778 .31942 Mdot
.778 .31958 Mdot
.778 .31986 Mdot
.778 .32096 Mdot
.778 .32109 Mdot
.778 .32146 Mdot
.778 .3223 Mdot
.778 .32375 Mdot
.778 .32393 Mdot
.778 .32456 Mdot
.778 .32466 Mdot
.778 .32466 Mdot
.778 .32518 Mdot
.778 .32525 Mdot
.778 .32556 Mdot
.778 .32665 Mdot
.778 .32693 Mdot
.778 .32756 Mdot
.778 .32794 Mdot
.778 .32824 Mdot
.778 .32868 Mdot
.778 .32904 Mdot
.778 .32978 Mdot
.778 .32979 Mdot
.778 .32979 Mdot
.778 .3303 Mdot
.778 .33047 Mdot
.778 .33081 Mdot
.778 .33201 Mdot
.778 .33217 Mdot
.778 .33254 Mdot
.778 .33309 Mdot
.778 .33352 Mdot
.778 .33388 Mdot
.778 .33487 Mdot
.778 .33536 Mdot
.778 .33549 Mdot
.778 .33567 Mdot
.778 .3357 Mdot
.778 .33626 Mdot
.778 .33678 Mdot
.778 .33833 Mdot
.778 .3399 Mdot
.778 .34111 Mdot
.778 .34195 Mdot
.778 .34274 Mdot
.778 .34281 Mdot
.778 .34281 Mdot
.778 .34287 Mdot
.778 .34565 Mdot
.778 .34794 Mdot
.778 .34824 Mdot
.778 .34873 Mdot
.778 .34941 Mdot
.778 .34962 Mdot
.778 .35112 Mdot
.778 .35293 Mdot
.778 .35416 Mdot
.778 .35536 Mdot
.778 .35697 Mdot
.778 .35719 Mdot
.778 .35725 Mdot
.778 .35805 Mdot
.778 .35824 Mdot
.778 .35986 Mdot
.778 .36062 Mdot
.778 .36122 Mdot
.778 .362 Mdot
.778 .36245 Mdot
.778 .36325 Mdot
.778 .36327 Mdot
.778 .36432 Mdot
.778 .36484 Mdot
.778 .36685 Mdot
.778 .36738 Mdot
.778 .36883 Mdot
.778 .369 Mdot
.778 .36985 Mdot
.778 .37056 Mdot
.778 .37081 Mdot
.778 .37197 Mdot
.778 .37246 Mdot
.778 .37339 Mdot
.778 .37361 Mdot
.778 .37377 Mdot
.778 .37463 Mdot
.778 .3749 Mdot
.778 .37491 Mdot
.778 .37566 Mdot
.778 .37757 Mdot
.778 .37856 Mdot
.778 .37937 Mdot
.778 .37985 Mdot
.778 .37998 Mdot
.778 .38173 Mdot
.778 .38174 Mdot
.778 .38191 Mdot
.778 .38216 Mdot
.778 .38304 Mdot
.778 .38396 Mdot
.778 .38434 Mdot
.778 .38525 Mdot
.778 .38551 Mdot
.778 .3862 Mdot
.778 .38622 Mdot
.778 .38657 Mdot
.778 .38807 Mdot
.778 .38922 Mdot
.778 .39029 Mdot
.778 .3912 Mdot
.778 .39123 Mdot
.778 .39125 Mdot
.778 .39169 Mdot
.778 .39248 Mdot
.778 .39281 Mdot
.778 .39291 Mdot
.778 .39327 Mdot
.778 .39374 Mdot
.778 .39421 Mdot
.778 .39462 Mdot
.778 .39476 Mdot
.778 .39538 Mdot
.778 .3963 Mdot
.778 .39726 Mdot
.778 .39924 Mdot
.778 .40017 Mdot
.778 .40125 Mdot
.778 .40221 Mdot
.778 .4027 Mdot
.778 .40467 Mdot
.778 .406 Mdot
.778 .40787 Mdot
.778 .40851 Mdot
.778 .40882 Mdot
.778 .4095 Mdot
.778 .41034 Mdot
.778 .41088 Mdot
.778 .41113 Mdot
.778 .41144 Mdot
.778 .41247 Mdot
.778 .41271 Mdot
.778 .41391 Mdot
.778 .41426 Mdot
.778 .41556 Mdot
.778 .41859 Mdot
.778 .41905 Mdot
.778 .42186 Mdot
.778 .42231 Mdot
.778 .4226 Mdot
.778 .42379 Mdot
.778 .42405 Mdot
.778 .42485 Mdot
.778 .42652 Mdot
.778 .43284 Mdot
.778 .43291 Mdot
.778 .43352 Mdot
.778 .43395 Mdot
.778 .43463 Mdot
.778 .43539 Mdot
.778 .43625 Mdot
.778 .43631 Mdot
.778 .43744 Mdot
.778 .43977 Mdot
.778 .43989 Mdot
.778 .44053 Mdot
.778 .44151 Mdot
.778 .44189 Mdot
.778 .44207 Mdot
.778 .44283 Mdot
.778 .44288 Mdot
.778 .44296 Mdot
.778 .44297 Mdot
.778 .44591 Mdot
.778 .44591 Mdot
.778 .44815 Mdot
.778 .44934 Mdot
.778 .4506 Mdot
.778 .45109 Mdot
.778 .4522 Mdot
.778 .45351 Mdot
.778 .45436 Mdot
.778 .45501 Mdot
.778 .45584 Mdot
.778 .45795 Mdot
.778 .45905 Mdot
.778 .45917 Mdot
.778 .46126 Mdot
.778 .46199 Mdot
.778 .46252 Mdot
.778 .46552 Mdot
.778 .46589 Mdot
.778 .46642 Mdot
.778 .468 Mdot
.778 .47004 Mdot
.778 .47278 Mdot
.778 .47345 Mdot
.778 .4738 Mdot
.778 .47468 Mdot
.778 .47478 Mdot
.78 .01478 Mdot
.78 .01482 Mdot
.78 .01488 Mdot
.78 .01498 Mdot
.78 .01513 Mdot
.78 .01536 Mdot
.78 .01572 Mdot
.78 .01628 Mdot
.78 .01688 Mdot
.78 .01715 Mdot
.78 .01809 Mdot
.78 .01817 Mdot
.78 .01852 Mdot
.78 .01917 Mdot
.78 .01938 Mdot
.78 .01999 Mdot
.78 .02011 Mdot
.78 .02065 Mdot
.78 .02094 Mdot
.78 .02166 Mdot
.78 .02199 Mdot
.78 .02294 Mdot
.78 .02313 Mdot
.78 .02397 Mdot
.78 .02433 Mdot
.78 .02443 Mdot
.78 .02457 Mdot
.78 .02555 Mdot
.78 .02606 Mdot
.78 .02741 Mdot
.78 .02754 Mdot
.78 .02785 Mdot
.78 .02793 Mdot
.78 .02915 Mdot
.78 .02941 Mdot
.78 .02971 Mdot
.78 .02986 Mdot
.78 .03009 Mdot
.78 .03103 Mdot
.78 .03158 Mdot
.78 .03162 Mdot
.78 .03235 Mdot
.78 .03241 Mdot
.78 .03257 Mdot
.78 .03452 Mdot
.78 .03472 Mdot
.78 .03508 Mdot
.78 .0352 Mdot
.78 .03533 Mdot
.78 .03543 Mdot
.78 .03632 Mdot
.78 .03662 Mdot
.78 .03724 Mdot
.78 .03763 Mdot
.78 .03764 Mdot
.78 .03811 Mdot
.78 .03835 Mdot
.78 .03869 Mdot
.78 .03921 Mdot
.78 .03982 Mdot
.78 .04016 Mdot
.78 .04058 Mdot
.78 .04084 Mdot
.78 .04103 Mdot
.78 .04108 Mdot
.78 .04222 Mdot
.78 .04225 Mdot
.78 .04232 Mdot
.78 .04249 Mdot
.78 .04257 Mdot
.78 .04271 Mdot
.78 .0456 Mdot
.78 .04591 Mdot
.78 .04593 Mdot
.78 .04649 Mdot
.78 .04662 Mdot
.78 .04668 Mdot
.78 .04687 Mdot
.78 .04703 Mdot
.78 .0476 Mdot
.78 .04842 Mdot
.78 .04846 Mdot
.78 .04888 Mdot
.78 .049 Mdot
.78 .04985 Mdot
.78 .05046 Mdot
.78 .05048 Mdot
.78 .05111 Mdot
.78 .05121 Mdot
.78 .05158 Mdot
.78 .05212 Mdot
.78 .05293 Mdot
.78 .05303 Mdot
.78 .05313 Mdot
.78 .05327 Mdot
.78 .05387 Mdot
.78 .05441 Mdot
.78 .05458 Mdot
.78 .05507 Mdot
.78 .05548 Mdot
.78 .05577 Mdot
.78 .05585 Mdot
.78 .05585 Mdot
.78 .05637 Mdot
.78 .05762 Mdot
.78 .05767 Mdot
.78 .05778 Mdot
.78 .05804 Mdot
.78 .05816 Mdot
.78 .05839 Mdot
.78 .05864 Mdot
.78 .05986 Mdot
.78 .06104 Mdot
.78 .0629 Mdot
.78 .06299 Mdot
.78 .06308 Mdot
.78 .06338 Mdot
.78 .06341 Mdot
.78 .06395 Mdot
.78 .06406 Mdot
.78 .06412 Mdot
.78 .06428 Mdot
.78 .06448 Mdot
.78 .06458 Mdot
.78 .06488 Mdot
.78 .06512 Mdot
.78 .06601 Mdot
.78 .06729 Mdot
.78 .06736 Mdot
.78 .06744 Mdot
.78 .06765 Mdot
.78 .06802 Mdot
.78 .0682 Mdot
.78 .06835 Mdot
.78 .06858 Mdot
.78 .06896 Mdot
.78 .06953 Mdot
.78 .07047 Mdot
.78 .07051 Mdot
.78 .07161 Mdot
.78 .07165 Mdot
.78 .07222 Mdot
.78 .07255 Mdot
.78 .07307 Mdot
.78 .07316 Mdot
.78 .07357 Mdot
.78 .07433 Mdot
.78 .07434 Mdot
.78 .07449 Mdot
.78 .07465 Mdot
.78 .07487 Mdot
.78 .0758 Mdot
.78 .07665 Mdot
.78 .0769 Mdot
.78 .07757 Mdot
.78 .07766 Mdot
.78 .0783 Mdot
.78 .07842 Mdot
.78 .07875 Mdot
.78 .07888 Mdot
.78 .07889 Mdot
.78 .07911 Mdot
.78 .07947 Mdot
.78 .0797 Mdot
.78 .07976 Mdot
.78 .08038 Mdot
.78 .08055 Mdot
.78 .08165 Mdot
.78 .08173 Mdot
.78 .08179 Mdot
.78 .0819 Mdot
.78 .0823 Mdot
.78 .0825 Mdot
.78 .08284 Mdot
.78 .08324 Mdot
.78 .08386 Mdot
.78 .08387 Mdot
.78 .08388 Mdot
.78 .08396 Mdot
.78 .08475 Mdot
.78 .08509 Mdot
.78 .08514 Mdot
.78 .08594 Mdot
.78 .08699 Mdot
.78 .08781 Mdot
.78 .08872 Mdot
.78 .08989 Mdot
.78 .09003 Mdot
.78 .09017 Mdot
.78 .09051 Mdot
.78 .09063 Mdot
.78 .09067 Mdot
.78 .09152 Mdot
.78 .09169 Mdot
.78 .09179 Mdot
.78 .09204 Mdot
.78 .09235 Mdot
.78 .0925 Mdot
.78 .09259 Mdot
.78 .09261 Mdot
.78 .09297 Mdot
.78 .09335 Mdot
.78 .09339 Mdot
.78 .09474 Mdot
.78 .09483 Mdot
.78 .09625 Mdot
.78 .09674 Mdot
.78 .09684 Mdot
.78 .09697 Mdot
.78 .09725 Mdot
.78 .09729 Mdot
.78 .09787 Mdot
.78 .09815 Mdot
.78 .09839 Mdot
.78 .09875 Mdot
.78 .09933 Mdot
.78 .10022 Mdot
.78 .10091 Mdot
.78 .10094 Mdot
.78 .10169 Mdot
.78 .10176 Mdot
.78 .10347 Mdot
.78 .10353 Mdot
.78 .10428 Mdot
.78 .10429 Mdot
.78 .10443 Mdot
.78 .10494 Mdot
.78 .1054 Mdot
.78 .10575 Mdot
.78 .10575 Mdot
.78 .10588 Mdot
.78 .10654 Mdot
.78 .10716 Mdot
.78 .10772 Mdot
.78 .10772 Mdot
.78 .10797 Mdot
.78 .10821 Mdot
.78 .10855 Mdot
.78 .10879 Mdot
.78 .10919 Mdot
.78 .10937 Mdot
.78 .11001 Mdot
.78 .11062 Mdot
.78 .11079 Mdot
.78 .11133 Mdot
.78 .1116 Mdot
.78 .11172 Mdot
.78 .11277 Mdot
.78 .11291 Mdot
.78 .11295 Mdot
.78 .11391 Mdot
.78 .11402 Mdot
.78 .11409 Mdot
.78 .11462 Mdot
.78 .11482 Mdot
.78 .11483 Mdot
.78 .11518 Mdot
.78 .11573 Mdot
.78 .1161 Mdot
.78 .11619 Mdot
.78 .11715 Mdot
.78 .11742 Mdot
.78 .11785 Mdot
.78 .11914 Mdot
.78 .11925 Mdot
.78 .11935 Mdot
.78 .11953 Mdot
.78 .11983 Mdot
.78 .12014 Mdot
.78 .12045 Mdot
.78 .12099 Mdot
.78 .12106 Mdot
.78 .12119 Mdot
.78 .12141 Mdot
.78 .12161 Mdot
.78 .12243 Mdot
.78 .12258 Mdot
.78 .1226 Mdot
.78 .12261 Mdot
.78 .12273 Mdot
.78 .1229 Mdot
.78 .12398 Mdot
.78 .12422 Mdot
.78 .12451 Mdot
.78 .12457 Mdot
.78 .12562 Mdot
.78 .12583 Mdot
.78 .12604 Mdot
.78 .12655 Mdot
.78 .12727 Mdot
.78 .12746 Mdot
.78 .12749 Mdot
.78 .12795 Mdot
.78 .12832 Mdot
.78 .12874 Mdot
.78 .13016 Mdot
.78 .13198 Mdot
.78 .1322 Mdot
.78 .13243 Mdot
.78 .13249 Mdot
.78 .13295 Mdot
.78 .13315 Mdot
.78 .13321 Mdot
.78 .1342 Mdot
.78 .13432 Mdot
.78 .13452 Mdot
.78 .13479 Mdot
.78 .13495 Mdot
.78 .13501 Mdot
.78 .13507 Mdot
.78 .13522 Mdot
.78 .13533 Mdot
.78 .13582 Mdot
.78 .13606 Mdot
.78 .1362 Mdot
.78 .13623 Mdot
.78 .13678 Mdot
.78 .13739 Mdot
.78 .13744 Mdot
.78 .13785 Mdot
.78 .13875 Mdot
.78 .13881 Mdot
.78 .13956 Mdot
.78 .13969 Mdot
.78 .14066 Mdot
.78 .14092 Mdot
.78 .14158 Mdot
.78 .14191 Mdot
.78 .14198 Mdot
.78 .14267 Mdot
.78 .14283 Mdot
.78 .14303 Mdot
.78 .14347 Mdot
.78 .14353 Mdot
.78 .14443 Mdot
.78 .14488 Mdot
.78 .1451 Mdot
.78 .14525 Mdot
.78 .1458 Mdot
.78 .14631 Mdot
.78 .14637 Mdot
.78 .14671 Mdot
.78 .14778 Mdot
.78 .1481 Mdot
.78 .14842 Mdot
.78 .14918 Mdot
.78 .14923 Mdot
.78 .15016 Mdot
.78 .1504 Mdot
.78 .1505 Mdot
.78 .15172 Mdot
.78 .15277 Mdot
.78 .15299 Mdot
.78 .15318 Mdot
.78 .15327 Mdot
.78 .15356 Mdot
.78 .15388 Mdot
.78 .15443 Mdot
.78 .15443 Mdot
.78 .15443 Mdot
.78 .15445 Mdot
.78 .15466 Mdot
.78 .15475 Mdot
.78 .15498 Mdot
.78 .15547 Mdot
.78 .15618 Mdot
.78 .15673 Mdot
.78 .15673 Mdot
.78 .15694 Mdot
.78 .15769 Mdot
.78 .15795 Mdot
.78 .15892 Mdot
.78 .15893 Mdot
.78 .15981 Mdot
.78 .15981 Mdot
.78 .1601 Mdot
.78 .16019 Mdot
.78 .16056 Mdot
.78 .1611 Mdot
.78 .16115 Mdot
.78 .16148 Mdot
.78 .16152 Mdot
.78 .16174 Mdot
.78 .16209 Mdot
.78 .16237 Mdot
.78 .16338 Mdot
.78 .1639 Mdot
.78 .16426 Mdot
.78 .16432 Mdot
.78 .16459 Mdot
.78 .16471 Mdot
.78 .16543 Mdot
.78 .16554 Mdot
.78 .16567 Mdot
.78 .16586 Mdot
.78 .16604 Mdot
.78 .16724 Mdot
.78 .16769 Mdot
.78 .16772 Mdot
.78 .1679 Mdot
.78 .16796 Mdot
.78 .1689 Mdot
.78 .16939 Mdot
.78 .16946 Mdot
.78 .16963 Mdot
.78 .16974 Mdot
.78 .17056 Mdot
.78 .17088 Mdot
.78 .17089 Mdot
.78 .17143 Mdot
.78 .17189 Mdot
.78 .1723 Mdot
.78 .17258 Mdot
.78 .17279 Mdot
.78 .17287 Mdot
.78 .17302 Mdot
.78 .17316 Mdot
.78 .1742 Mdot
.78 .17451 Mdot
.78 .17494 Mdot
.78 .17561 Mdot
.78 .17598 Mdot
.78 .17639 Mdot
.78 .17683 Mdot
.78 .17762 Mdot
.78 .1778 Mdot
.78 .17785 Mdot
.78 .17795 Mdot
.78 .17822 Mdot
.78 .17869 Mdot
.78 .17919 Mdot
.78 .17967 Mdot
.78 .17968 Mdot
.78 .17972 Mdot
.78 .17984 Mdot
.78 .17988 Mdot
.78 .18028 Mdot
.78 .18035 Mdot
.78 .18048 Mdot
.78 .18051 Mdot
.78 .18061 Mdot
.78 .18082 Mdot
.78 .18116 Mdot
.78 .18147 Mdot
.78 .18183 Mdot
.78 .18202 Mdot
.78 .18228 Mdot
.78 .18275 Mdot
.78 .18278 Mdot
.78 .18287 Mdot
.78 .18299 Mdot
.78 .18302 Mdot
.78 .18304 Mdot
.78 .18322 Mdot
.78 .18324 Mdot
.78 .18348 Mdot
.78 .18405 Mdot
.78 .18516 Mdot
.78 .18535 Mdot
.78 .18554 Mdot
.78 .18599 Mdot
.78 .18609 Mdot
.78 .18651 Mdot
.78 .18773 Mdot
.78 .18791 Mdot
.78 .18805 Mdot
.78 .18838 Mdot
.78 .18862 Mdot
.78 .18917 Mdot
.78 .18959 Mdot
.78 .1903 Mdot
.78 .19059 Mdot
.78 .19065 Mdot
.78 .19137 Mdot
.78 .19138 Mdot
.78 .19148 Mdot
.78 .19185 Mdot
.78 .19195 Mdot
.78 .1923 Mdot
.78 .1924 Mdot
.78 .19247 Mdot
.78 .19259 Mdot
.78 .19318 Mdot
.78 .19325 Mdot
.78 .19415 Mdot
.78 .19481 Mdot
.78 .19632 Mdot
.78 .19765 Mdot
.78 .19799 Mdot
.78 .19835 Mdot
.78 .19844 Mdot
.78 .19917 Mdot
.78 .19947 Mdot
.78 .19957 Mdot
.78 .20054 Mdot
.78 .20111 Mdot
.78 .20126 Mdot
.78 .2013 Mdot
.78 .20162 Mdot
.78 .20199 Mdot
.78 .20203 Mdot
.78 .20229 Mdot
.78 .20238 Mdot
.78 .20247 Mdot
.78 .2027 Mdot
.78 .20288 Mdot
.78 .20364 Mdot
.78 .20369 Mdot
.78 .20401 Mdot
.78 .20406 Mdot
.78 .20423 Mdot
.78 .20428 Mdot
.78 .20514 Mdot
.78 .20568 Mdot
.78 .20608 Mdot
.78 .20617 Mdot
.78 .20681 Mdot
.78 .2082 Mdot
.78 .2083 Mdot
.78 .20947 Mdot
.78 .20968 Mdot
.78 .21029 Mdot
.78 .21096 Mdot
.78 .21119 Mdot
.78 .2115 Mdot
.78 .21159 Mdot
.78 .21262 Mdot
.78 .21277 Mdot
.78 .21313 Mdot
.78 .21325 Mdot
.78 .21367 Mdot
.78 .21432 Mdot
.78 .21457 Mdot
.78 .21488 Mdot
.78 .21557 Mdot
.78 .21567 Mdot
.78 .21576 Mdot
.78 .21707 Mdot
.78 .21736 Mdot
.78 .21777 Mdot
.78 .21812 Mdot
.78 .21834 Mdot
.78 .21921 Mdot
.78 .22 Mdot
.78 .22004 Mdot
.78 .2201 Mdot
.78 .22063 Mdot
.78 .22116 Mdot
.78 .22137 Mdot
.78 .2223 Mdot
.78 .2228 Mdot
.78 .22329 Mdot
.78 .22409 Mdot
.78 .22413 Mdot
.78 .22448 Mdot
.78 .22453 Mdot
.78 .22456 Mdot
.78 .22592 Mdot
.78 .226 Mdot
.78 .22629 Mdot
.78 .22639 Mdot
.78 .22654 Mdot
.78 .22763 Mdot
.78 .22802 Mdot
.78 .22827 Mdot
.78 .22844 Mdot
.78 .22875 Mdot
.78 .23008 Mdot
.78 .23043 Mdot
.78 .23072 Mdot
.78 .23086 Mdot
.78 .23098 Mdot
.78 .23124 Mdot
.78 .23131 Mdot
.78 .23182 Mdot
.78 .23267 Mdot
.78 .23267 Mdot
.78 .23268 Mdot
.78 .23271 Mdot
.78 .23303 Mdot
.78 .23317 Mdot
.78 .23352 Mdot
.78 .23429 Mdot
.78 .23466 Mdot
.78 .2354 Mdot
.78 .23625 Mdot
.78 .23626 Mdot
.78 .23658 Mdot
.78 .23717 Mdot
.78 .23776 Mdot
.78 .23817 Mdot
.78 .23967 Mdot
.78 .23969 Mdot
.78 .24106 Mdot
.78 .24106 Mdot
.78 .24152 Mdot
.78 .24166 Mdot
.78 .24224 Mdot
.78 .24291 Mdot
.78 .24307 Mdot
.78 .24315 Mdot
.78 .24366 Mdot
.78 .24373 Mdot
.78 .24407 Mdot
.78 .24462 Mdot
.78 .24506 Mdot
.78 .24663 Mdot
.78 .24745 Mdot
.78 .24795 Mdot
.78 .24801 Mdot
.78 .2481 Mdot
.78 .24852 Mdot
.78 .24871 Mdot
.78 .24925 Mdot
.78 .24983 Mdot
.78 .25 Mdot
.78 .25021 Mdot
.78 .2505 Mdot
.78 .2506 Mdot
.78 .25079 Mdot
.78 .25094 Mdot
.78 .25265 Mdot
.78 .25335 Mdot
.78 .2534 Mdot
.78 .25369 Mdot
.78 .25371 Mdot
.78 .25377 Mdot
.78 .25485 Mdot
.78 .25522 Mdot
.78 .25525 Mdot
.78 .25601 Mdot
.78 .25611 Mdot
.78 .25638 Mdot
.78 .25655 Mdot
.78 .25783 Mdot
.78 .25833 Mdot
.78 .25835 Mdot
.78 .25893 Mdot
.78 .25919 Mdot
.78 .25991 Mdot
.78 .26055 Mdot
.78 .26098 Mdot
.78 .26107 Mdot
.78 .26131 Mdot
.78 .26144 Mdot
.78 .26166 Mdot
.78 .26167 Mdot
.78 .2618 Mdot
.78 .26189 Mdot
.78 .263 Mdot
.78 .26351 Mdot
.78 .264 Mdot
.78 .26442 Mdot
.78 .26458 Mdot
.78 .26467 Mdot
.78 .26556 Mdot
.78 .2657 Mdot
.78 .26589 Mdot
.78 .26623 Mdot
.78 .26628 Mdot
.78 .26693 Mdot
.78 .26713 Mdot
.78 .26761 Mdot
.78 .26781 Mdot
.78 .26884 Mdot
.78 .26912 Mdot
.78 .26921 Mdot
.78 .26936 Mdot
.78 .26979 Mdot
.78 .27052 Mdot
.78 .27069 Mdot
.78 .27087 Mdot
.78 .27129 Mdot
.78 .27204 Mdot
.78 .27206 Mdot
.78 .27211 Mdot
.78 .27212 Mdot
.78 .27229 Mdot
.78 .27232 Mdot
.78 .27237 Mdot
.78 .27293 Mdot
.78 .273 Mdot
.78 .27311 Mdot
.78 .27331 Mdot
.78 .27335 Mdot
.78 .2735 Mdot
.78 .27384 Mdot
.78 .27437 Mdot
.78 .27485 Mdot
.78 .27542 Mdot
.78 .27571 Mdot
.78 .27611 Mdot
.78 .27685 Mdot
.78 .27689 Mdot
.78 .27704 Mdot
.78 .27723 Mdot
.78 .27727 Mdot
.78 .27729 Mdot
.78 .27759 Mdot
.78 .27762 Mdot
.78 .27799 Mdot
.78 .27888 Mdot
.78 .28061 Mdot
.78 .28091 Mdot
.78 .28121 Mdot
.78 .28191 Mdot
.78 .28206 Mdot
.78 .28272 Mdot
.78 .28462 Mdot
.78 .28489 Mdot
.78 .28512 Mdot
.78 .28564 Mdot
.78 .28601 Mdot
.78 .28687 Mdot
.78 .28752 Mdot
.78 .28863 Mdot
.78 .28908 Mdot
.78 .28917 Mdot
.78 .29029 Mdot
.78 .29031 Mdot
.78 .29047 Mdot
.78 .29104 Mdot
.78 .2912 Mdot
.78 .29175 Mdot
.78 .2919 Mdot
.78 .29201 Mdot
.78 .29221 Mdot
.78 .29312 Mdot
.78 .29323 Mdot
.78 .29463 Mdot
.78 .29567 Mdot
.78 .29802 Mdot
.78 .30009 Mdot
.78 .30063 Mdot
.78 .30118 Mdot
.78 .30132 Mdot
.78 .30246 Mdot
.78 .30293 Mdot
.78 .30308 Mdot
.78 .30461 Mdot
.78 .30549 Mdot
.78 .30573 Mdot
.78 .30578 Mdot
.78 .30628 Mdot
.78 .30686 Mdot
.78 .30693 Mdot
.78 .30733 Mdot
.78 .30747 Mdot
.78 .30761 Mdot
.78 .30797 Mdot
.78 .30826 Mdot
.78 .30944 Mdot
.78 .30951 Mdot
.78 .31002 Mdot
.78 .31009 Mdot
.78 .31036 Mdot
.78 .31044 Mdot
.78 .31178 Mdot
.78 .31261 Mdot
.78 .31325 Mdot
.78 .31338 Mdot
.78 .31439 Mdot
.78 .31656 Mdot
.78 .31671 Mdot
.78 .31853 Mdot
.78 .31887 Mdot
.78 .31982 Mdot
.78 .32085 Mdot
.78 .32121 Mdot
.78 .3217 Mdot
.78 .32184 Mdot
.78 .32345 Mdot
.78 .32367 Mdot
.78 .32425 Mdot
.78 .32444 Mdot
.78 .32508 Mdot
.78 .3261 Mdot
.78 .32649 Mdot
.78 .32698 Mdot
.78 .32805 Mdot
.78 .3282 Mdot
.78 .32834 Mdot
.78 .33039 Mdot
.78 .33084 Mdot
.78 .33148 Mdot
.78 .33203 Mdot
.78 .33237 Mdot
.78 .33373 Mdot
.78 .33496 Mdot
.78 .33502 Mdot
.78 .33511 Mdot
.78 .33595 Mdot
.78 .33677 Mdot
.78 .3371 Mdot
.78 .33855 Mdot
.78 .33933 Mdot
.78 .34009 Mdot
.78 .34134 Mdot
.78 .3414 Mdot
.78 .34195 Mdot
.78 .34202 Mdot
.78 .34207 Mdot
.78 .34419 Mdot
.78 .34433 Mdot
.78 .34478 Mdot
.78 .34493 Mdot
.78 .34517 Mdot
.78 .34687 Mdot
.78 .34747 Mdot
.78 .34786 Mdot
.78 .34813 Mdot
.78 .34861 Mdot
.78 .35069 Mdot
.78 .35123 Mdot
.78 .35168 Mdot
.78 .35191 Mdot
.78 .35209 Mdot
.78 .35249 Mdot
.78 .3526 Mdot
.78 .35339 Mdot
.78 .35472 Mdot
.78 .35473 Mdot
.78 .35473 Mdot
.78 .35478 Mdot
.78 .35529 Mdot
.78 .35551 Mdot
.78 .35605 Mdot
.78 .35725 Mdot
.78 .35783 Mdot
.78 .35898 Mdot
.78 .36032 Mdot
.78 .36033 Mdot
.78 .36083 Mdot
.78 .36175 Mdot
.78 .36266 Mdot
.78 .3633 Mdot
.78 .36565 Mdot
.78 .36567 Mdot
.78 .36781 Mdot
.78 .36782 Mdot
.78 .36853 Mdot
.78 .36875 Mdot
.78 .36965 Mdot
.78 .3707 Mdot
.78 .37095 Mdot
.78 .37107 Mdot
.78 .37187 Mdot
.78 .37198 Mdot
.78 .3725 Mdot
.78 .37336 Mdot
.78 .37405 Mdot
.78 .37651 Mdot
.78 .37778 Mdot
.78 .37856 Mdot
.78 .37865 Mdot
.78 .37879 Mdot
.78 .37944 Mdot
.78 .37974 Mdot
.78 .38059 Mdot
.78 .38149 Mdot
.78 .38176 Mdot
.78 .38208 Mdot
.78 .38255 Mdot
.78 .38269 Mdot
.78 .38298 Mdot
.78 .38322 Mdot
.78 .38589 Mdot
.78 .38699 Mdot
.78 .38707 Mdot
.78 .38751 Mdot
.78 .38755 Mdot
.78 .38764 Mdot
.78 .38933 Mdot
.78 .3899 Mdot
.78 .38994 Mdot
.78 .39113 Mdot
.78 .3913 Mdot
.78 .39172 Mdot
.78 .39198 Mdot
.78 .39398 Mdot
.78 .39475 Mdot
.78 .39479 Mdot
.78 .3957 Mdot
.78 .3961 Mdot
.78 .39722 Mdot
.78 .39822 Mdot
.78 .39889 Mdot
.78 .39904 Mdot
.78 .3994 Mdot
.78 .39961 Mdot
.78 .39996 Mdot
.78 .39996 Mdot
.78 .40016 Mdot
.78 .40031 Mdot
.78 .40205 Mdot
.78 .40283 Mdot
.78 .40359 Mdot
.78 .40426 Mdot
.78 .4045 Mdot
.78 .40464 Mdot
.78 .40603 Mdot
.78 .40626 Mdot
.78 .40655 Mdot
.78 .40708 Mdot
.78 .40716 Mdot
.78 .40817 Mdot
.78 .40848 Mdot
.78 .40923 Mdot
.78 .40955 Mdot
.78 .41115 Mdot
.78 .41159 Mdot
.78 .41172 Mdot
.78 .41196 Mdot
.78 .41263 Mdot
.78 .41377 Mdot
.78 .41403 Mdot
.78 .41431 Mdot
.78 .41497 Mdot
.78 .41614 Mdot
.78 .41617 Mdot
.78 .41625 Mdot
.78 .41627 Mdot
.78 .41653 Mdot
.78 .41657 Mdot
.78 .41666 Mdot
.78 .41752 Mdot
.78 .41764 Mdot
.78 .41781 Mdot
.78 .41813 Mdot
.78 .41819 Mdot
.78 .41843 Mdot
.78 .41894 Mdot
.78 .41978 Mdot
.78 .42052 Mdot
.78 .42142 Mdot
.78 .42187 Mdot
.78 .4225 Mdot
.78 .42364 Mdot
.78 .42371 Mdot
.78 .42394 Mdot
.78 .42423 Mdot
.78 .4243 Mdot
.78 .42434 Mdot
.78 .4248 Mdot
.78 .42484 Mdot
.78 .42542 Mdot
.78 .42681 Mdot
.78 .42952 Mdot
.78 .42998 Mdot
.78 .43044 Mdot
.78 .43153 Mdot
.78 .43177 Mdot
.78 .43281 Mdot
.78 .43577 Mdot
.78 .43619 Mdot
.78 .43654 Mdot
.78 .43735 Mdot
.78 .43793 Mdot
.78 .43927 Mdot
.78 .4403 Mdot
.78 .44202 Mdot
.78 .44273 Mdot
.78 .44287 Mdot
.78 .44461 Mdot
.78 .44464 Mdot
.78 .44489 Mdot
.78 .44578 Mdot
.78 .44602 Mdot
.78 .44688 Mdot
.78 .44713 Mdot
.78 .44729 Mdot
.78 .4476 Mdot
.78 .44903 Mdot
.78 .44919 Mdot
.78 .45139 Mdot
.78 .453 Mdot
.78 .45668 Mdot
.78 .45991 Mdot
.78 .46074 Mdot
.78 .4616 Mdot
.78 .46182 Mdot
.78 .4636 Mdot
.78 .46433 Mdot
.78 .46457 Mdot
.78 .46695 Mdot
.78 .46832 Mdot
.78 .4687 Mdot
.78 .46878 Mdot
.78 .46956 Mdot
.78 .47047 Mdot
.78 .47057 Mdot
.78 .47119 Mdot
.78 .47141 Mdot
.78 .47162 Mdot
.78 .4722 Mdot
.78 .47264 Mdot
.78 .47448 Mdot
.78 .4746 Mdot
.78 .47539 Mdot
.78 .47551 Mdot
.78 .47592 Mdot
.782 .01475 Mdot
.782 .01477 Mdot
.782 .0148 Mdot
.782 .01484 Mdot
.782 .01491 Mdot
.782 .01502 Mdot
.782 .0152 Mdot
.782 .01537 Mdot
.782 .01543 Mdot
.782 .01547 Mdot
.782 .01573 Mdot
.782 .01584 Mdot
.782 .01589 Mdot
.782 .01631 Mdot
.782 .01647 Mdot
.782 .01649 Mdot
.782 .01656 Mdot
.782 .0172 Mdot
.782 .01746 Mdot
.782 .01749 Mdot
.782 .01756 Mdot
.782 .0176 Mdot
.782 .01861 Mdot
.782 .01901 Mdot
.782 .01906 Mdot
.782 .01917 Mdot
.782 .01922 Mdot
.782 .0195 Mdot
.782 .02044 Mdot
.782 .02044 Mdot
.782 .0208 Mdot
.782 .02144 Mdot
.782 .0215 Mdot
.782 .02168 Mdot
.782 .02176 Mdot
.782 .0222 Mdot
.782 .02226 Mdot
.782 .02277 Mdot
.782 .02366 Mdot
.782 .02367 Mdot
.782 .02424 Mdot
.782 .02523 Mdot
.782 .02533 Mdot
.782 .02534 Mdot
.782 .0256 Mdot
.782 .02573 Mdot
.782 .02599 Mdot
.782 .02643 Mdot
.782 .02652 Mdot
.782 .02661 Mdot
.782 .02731 Mdot
.782 .02784 Mdot
.782 .02871 Mdot
.782 .02872 Mdot
.782 .02913 Mdot
.782 .02961 Mdot
.782 .02996 Mdot
.782 .03007 Mdot
.782 .03029 Mdot
.782 .03032 Mdot
.782 .03053 Mdot
.782 .03116 Mdot
.782 .03132 Mdot
.782 .03133 Mdot
.782 .03157 Mdot
.782 .03174 Mdot
.782 .03185 Mdot
.782 .03195 Mdot
.782 .03236 Mdot
.782 .03303 Mdot
.782 .03318 Mdot
.782 .03331 Mdot
.782 .03354 Mdot
.782 .03397 Mdot
.782 .03441 Mdot
.782 .03525 Mdot
.782 .03561 Mdot
.782 .0366 Mdot
.782 .03662 Mdot
.782 .03702 Mdot
.782 .03726 Mdot
.782 .038 Mdot
.782 .03828 Mdot
.782 .03853 Mdot
.782 .03855 Mdot
.782 .03874 Mdot
.782 .03908 Mdot
.782 .03913 Mdot
.782 .03945 Mdot
.782 .04026 Mdot
.782 .04044 Mdot
.782 .04069 Mdot
.782 .04071 Mdot
.782 .04103 Mdot
.782 .04108 Mdot
.782 .04134 Mdot
.782 .04152 Mdot
.782 .04167 Mdot
.782 .0423 Mdot
.782 .04337 Mdot
.782 .0436 Mdot
.782 .0438 Mdot
.782 .04395 Mdot
.782 .04415 Mdot
.782 .04482 Mdot
.782 .04552 Mdot
.782 .04631 Mdot
.782 .04683 Mdot
.782 .04686 Mdot
.782 .0473 Mdot
.782 .04739 Mdot
.782 .04894 Mdot
.782 .04897 Mdot
.782 .04959 Mdot
.782 .04977 Mdot
.782 .04997 Mdot
.782 .05028 Mdot
.782 .05114 Mdot
.782 .05158 Mdot
.782 .05197 Mdot
.782 .052 Mdot
.782 .05226 Mdot
.782 .05228 Mdot
.782 .05256 Mdot
.782 .05281 Mdot
.782 .05289 Mdot
.782 .05324 Mdot
.782 .0534 Mdot
.782 .05341 Mdot
.782 .05366 Mdot
.782 .05467 Mdot
.782 .05494 Mdot
.782 .05515 Mdot
.782 .05534 Mdot
.782 .05537 Mdot
.782 .05588 Mdot
.782 .05595 Mdot
.782 .05636 Mdot
.782 .05664 Mdot
.782 .05687 Mdot
.782 .05782 Mdot
.782 .05787 Mdot
.782 .05803 Mdot
.782 .05822 Mdot
.782 .05892 Mdot
.782 .05922 Mdot
.782 .05953 Mdot
.782 .05965 Mdot
.782 .0597 Mdot
.782 .05989 Mdot
.782 .06021 Mdot
.782 .06044 Mdot
.782 .06061 Mdot
.782 .06067 Mdot
.782 .06076 Mdot
.782 .06181 Mdot
.782 .06274 Mdot
.782 .0629 Mdot
.782 .06414 Mdot
.782 .06421 Mdot
.782 .06474 Mdot
.782 .06494 Mdot
.782 .06499 Mdot
.782 .06534 Mdot
.782 .06567 Mdot
.782 .06582 Mdot
.782 .06619 Mdot
.782 .06825 Mdot
.782 .06827 Mdot
.782 .06829 Mdot
.782 .06926 Mdot
.782 .06948 Mdot
.782 .06954 Mdot
.782 .06985 Mdot
.782 .07034 Mdot
.782 .07168 Mdot
.782 .07237 Mdot
.782 .07279 Mdot
.782 .07297 Mdot
.782 .07303 Mdot
.782 .07344 Mdot
.782 .07347 Mdot
.782 .07355 Mdot
.782 .07391 Mdot
.782 .07406 Mdot
.782 .0743 Mdot
.782 .07443 Mdot
.782 .07451 Mdot
.782 .07497 Mdot
.782 .07522 Mdot
.782 .07524 Mdot
.782 .07532 Mdot
.782 .07563 Mdot
.782 .07643 Mdot
.782 .07721 Mdot
.782 .07753 Mdot
.782 .07763 Mdot
.782 .07778 Mdot
.782 .07796 Mdot
.782 .07825 Mdot
.782 .07829 Mdot
.782 .07901 Mdot
.782 .07909 Mdot
.782 .07921 Mdot
.782 .07941 Mdot
.782 .0795 Mdot
.782 .07985 Mdot
.782 .08028 Mdot
.782 .08064 Mdot
.782 .08213 Mdot
.782 .0822 Mdot
.782 .08247 Mdot
.782 .08276 Mdot
.782 .08384 Mdot
.782 .08433 Mdot
.782 .08454 Mdot
.782 .0848 Mdot
.782 .085 Mdot
.782 .08501 Mdot
.782 .08507 Mdot
.782 .08536 Mdot
.782 .08537 Mdot
.782 .08587 Mdot
.782 .08624 Mdot
.782 .0865 Mdot
.782 .08658 Mdot
.782 .08673 Mdot
.782 .08716 Mdot
.782 .08794 Mdot
.782 .08822 Mdot
.782 .08836 Mdot
.782 .08846 Mdot
.782 .08983 Mdot
.782 .09008 Mdot
.782 .0903 Mdot
.782 .09176 Mdot
.782 .09201 Mdot
.782 .09211 Mdot
.782 .09212 Mdot
.782 .09248 Mdot
.782 .09296 Mdot
.782 .09327 Mdot
.782 .09335 Mdot
.782 .09389 Mdot
.782 .09441 Mdot
.782 .09465 Mdot
.782 .09522 Mdot
.782 .09573 Mdot
.782 .09728 Mdot
.782 .09795 Mdot
.782 .09828 Mdot
.782 .09844 Mdot
.782 .09847 Mdot
.782 .09851 Mdot
.782 .09939 Mdot
.782 .09968 Mdot
.782 .10003 Mdot
.782 .10036 Mdot
.782 .10046 Mdot
.782 .10095 Mdot
.782 .10171 Mdot
.782 .10184 Mdot
.782 .10192 Mdot
.782 .10213 Mdot
.782 .10232 Mdot
.782 .10275 Mdot
.782 .10282 Mdot
.782 .10367 Mdot
.782 .10381 Mdot
.782 .10411 Mdot
.782 .10429 Mdot
.782 .10488 Mdot
.782 .105 Mdot
.782 .10554 Mdot
.782 .10583 Mdot
.782 .10591 Mdot
.782 .10597 Mdot
.782 .1062 Mdot
.782 .10656 Mdot
.782 .10658 Mdot
.782 .10661 Mdot
.782 .10673 Mdot
.782 .10697 Mdot
.782 .10729 Mdot
.782 .10754 Mdot
.782 .10766 Mdot
.782 .10791 Mdot
.782 .10811 Mdot
.782 .10824 Mdot
.782 .10841 Mdot
.782 .10876 Mdot
.782 .10896 Mdot
.782 .10924 Mdot
.782 .10935 Mdot
.782 .10938 Mdot
.782 .1095 Mdot
.782 .1099 Mdot
.782 .10999 Mdot
.782 .11106 Mdot
.782 .11124 Mdot
.782 .11186 Mdot
.782 .11246 Mdot
.782 .11289 Mdot
.782 .11295 Mdot
.782 .11312 Mdot
.782 .11336 Mdot
.782 .11363 Mdot
.782 .11409 Mdot
.782 .11415 Mdot
.782 .11417 Mdot
.782 .11495 Mdot
.782 .11496 Mdot
.782 .11528 Mdot
.782 .1154 Mdot
.782 .11559 Mdot
.782 .1159 Mdot
.782 .11603 Mdot
.782 .11615 Mdot
.782 .11658 Mdot
.782 .11726 Mdot
.782 .11782 Mdot
.782 .11785 Mdot
.782 .11849 Mdot
.782 .11851 Mdot
.782 .11867 Mdot
.782 .11938 Mdot
.782 .11957 Mdot
.782 .12016 Mdot
.782 .12027 Mdot
.782 .12068 Mdot
.782 .12114 Mdot
.782 .12178 Mdot
.782 .12234 Mdot
.782 .12283 Mdot
.782 .12359 Mdot
.782 .12393 Mdot
.782 .12433 Mdot
.782 .1245 Mdot
.782 .12464 Mdot
.782 .12465 Mdot
.782 .12466 Mdot
.782 .12475 Mdot
.782 .12521 Mdot
.782 .12523 Mdot
.782 .126 Mdot
.782 .12657 Mdot
.782 .12698 Mdot
.782 .12712 Mdot
.782 .12734 Mdot
.782 .12803 Mdot
.782 .12876 Mdot
.782 .12924 Mdot
.782 .12968 Mdot
.782 .12983 Mdot
.782 .1299 Mdot
.782 .13006 Mdot
.782 .1304 Mdot
.782 .1322 Mdot
.782 .13258 Mdot
.782 .13293 Mdot
.782 .13354 Mdot
.782 .13522 Mdot
.782 .1356 Mdot
.782 .13576 Mdot
.782 .13578 Mdot
.782 .13634 Mdot
.782 .13709 Mdot
.782 .13709 Mdot
.782 .13757 Mdot
.782 .1377 Mdot
.782 .13854 Mdot
.782 .13936 Mdot
.782 .13967 Mdot
.782 .13973 Mdot
.782 .14007 Mdot
.782 .14051 Mdot
.782 .14063 Mdot
.782 .14106 Mdot
.782 .14142 Mdot
.782 .14247 Mdot
.782 .14324 Mdot
.782 .14385 Mdot
.782 .144 Mdot
.782 .14411 Mdot
.782 .14489 Mdot
.782 .14541 Mdot
.782 .14566 Mdot
.782 .14571 Mdot
.782 .14577 Mdot
.782 .14616 Mdot
.782 .14686 Mdot
.782 .14715 Mdot
.782 .14723 Mdot
.782 .14734 Mdot
.782 .14735 Mdot
.782 .14759 Mdot
.782 .14761 Mdot
.782 .14815 Mdot
.782 .14867 Mdot
.782 .14883 Mdot
.782 .14959 Mdot
.782 .15077 Mdot
.782 .15097 Mdot
.782 .15111 Mdot
.782 .15122 Mdot
.782 .15143 Mdot
.782 .15173 Mdot
.782 .15201 Mdot
.782 .15208 Mdot
.782 .1524 Mdot
.782 .15251 Mdot
.782 .15385 Mdot
.782 .15397 Mdot
.782 .15406 Mdot
.782 .15453 Mdot
.782 .15473 Mdot
.782 .15481 Mdot
.782 .15573 Mdot
.782 .15582 Mdot
.782 .15592 Mdot
.782 .15677 Mdot
.782 .15722 Mdot
.782 .15735 Mdot
.782 .15744 Mdot
.782 .15773 Mdot
.782 .1578 Mdot
.782 .15837 Mdot
.782 .15839 Mdot
.782 .15844 Mdot
.782 .15849 Mdot
.782 .15861 Mdot
.782 .15862 Mdot
.782 .15896 Mdot
.782 .15901 Mdot
.782 .15919 Mdot
.782 .15951 Mdot
.782 .15961 Mdot
.782 .15989 Mdot
.782 .16009 Mdot
.782 .16018 Mdot
.782 .16047 Mdot
.782 .16078 Mdot
.782 .16099 Mdot
.782 .16126 Mdot
.782 .16179 Mdot
.782 .1618 Mdot
.782 .16211 Mdot
.782 .16255 Mdot
.782 .16272 Mdot
.782 .16272 Mdot
.782 .16277 Mdot
.782 .16295 Mdot
.782 .16358 Mdot
.782 .16373 Mdot
.782 .16541 Mdot
.782 .16569 Mdot
.782 .16583 Mdot
.782 .16665 Mdot
.782 .16758 Mdot
.782 .16826 Mdot
.782 .16836 Mdot
.782 .16862 Mdot
.782 .16899 Mdot
.782 .16919 Mdot
.782 .16939 Mdot
.782 .16942 Mdot
.782 .17014 Mdot
.782 .17023 Mdot
.782 .17026 Mdot
.782 .17148 Mdot
.782 .1715 Mdot
.782 .17199 Mdot
.782 .17219 Mdot
.782 .17248 Mdot
.782 .17298 Mdot
.782 .17318 Mdot
.782 .17321 Mdot
.782 .1733 Mdot
.782 .17336 Mdot
.782 .17347 Mdot
.782 .17404 Mdot
.782 .17428 Mdot
.782 .17509 Mdot
.782 .17597 Mdot
.782 .17602 Mdot
.782 .17702 Mdot
.782 .17705 Mdot
.782 .1773 Mdot
.782 .17842 Mdot
.782 .17854 Mdot
.782 .1787 Mdot
.782 .17901 Mdot
.782 .17963 Mdot
.782 .17963 Mdot
.782 .1798 Mdot
.782 .17998 Mdot
.782 .18044 Mdot
.782 .18082 Mdot
.782 .18116 Mdot
.782 .18217 Mdot
.782 .18304 Mdot
.782 .18317 Mdot
.782 .18318 Mdot
.782 .18381 Mdot
.782 .18382 Mdot
.782 .18454 Mdot
.782 .18472 Mdot
.782 .18499 Mdot
.782 .18552 Mdot
.782 .18615 Mdot
.782 .18628 Mdot
.782 .18641 Mdot
.782 .18664 Mdot
.782 .18665 Mdot
.782 .18668 Mdot
.782 .18681 Mdot
.782 .18753 Mdot
.782 .18756 Mdot
.782 .18774 Mdot
.782 .18876 Mdot
.782 .18906 Mdot
.782 .18964 Mdot
.782 .18966 Mdot
.782 .1903 Mdot
.782 .19051 Mdot
.782 .19086 Mdot
.782 .19193 Mdot
.782 .19289 Mdot
.782 .19309 Mdot
.782 .19383 Mdot
.782 .19452 Mdot
.782 .19476 Mdot
.782 .19487 Mdot
.782 .19511 Mdot
.782 .19564 Mdot
.782 .19622 Mdot
.782 .19674 Mdot
.782 .19676 Mdot
.782 .19845 Mdot
.782 .19906 Mdot
.782 .19918 Mdot
.782 .19921 Mdot
.782 .1996 Mdot
.782 .20055 Mdot
.782 .20198 Mdot
.782 .20267 Mdot
.782 .20318 Mdot
.782 .2037 Mdot
.782 .20378 Mdot
.782 .20404 Mdot
.782 .20406 Mdot
.782 .2045 Mdot
.782 .20493 Mdot
.782 .20573 Mdot
.782 .20611 Mdot
.782 .20611 Mdot
.782 .20686 Mdot
.782 .20706 Mdot
.782 .20811 Mdot
.782 .20838 Mdot
.782 .20863 Mdot
.782 .20914 Mdot
.782 .20966 Mdot
.782 .21 Mdot
.782 .21005 Mdot
.782 .21014 Mdot
.782 .21015 Mdot
.782 .21024 Mdot
.782 .21066 Mdot
.782 .21078 Mdot
.782 .21146 Mdot
.782 .21164 Mdot
.782 .21231 Mdot
.782 .21289 Mdot
.782 .2134 Mdot
.782 .21351 Mdot
.782 .21421 Mdot
.782 .21453 Mdot
.782 .21572 Mdot
.782 .21669 Mdot
.782 .21691 Mdot
.782 .21709 Mdot
.782 .2181 Mdot
.782 .21831 Mdot
.782 .21912 Mdot
.782 .21924 Mdot
.782 .21952 Mdot
.782 .21959 Mdot
.782 .21969 Mdot
.782 .2203 Mdot
.782 .22139 Mdot
.782 .22148 Mdot
.782 .22156 Mdot
.782 .22184 Mdot
.782 .22197 Mdot
.782 .22214 Mdot
.782 .22216 Mdot
.782 .22253 Mdot
.782 .22256 Mdot
.782 .2234 Mdot
.782 .224 Mdot
.782 .22422 Mdot
.782 .22446 Mdot
.782 .22481 Mdot
.782 .22566 Mdot
.782 .22616 Mdot
.782 .22751 Mdot
.782 .22782 Mdot
.782 .22803 Mdot
.782 .22822 Mdot
.782 .22854 Mdot
.782 .229 Mdot
.782 .22945 Mdot
.782 .22955 Mdot
.782 .23006 Mdot
.782 .23022 Mdot
.782 .23025 Mdot
.782 .23232 Mdot
.782 .23251 Mdot
.782 .23266 Mdot
.782 .23339 Mdot
.782 .23371 Mdot
.782 .23382 Mdot
.782 .23392 Mdot
.782 .23467 Mdot
.782 .23527 Mdot
.782 .23541 Mdot
.782 .23556 Mdot
.782 .23689 Mdot
.782 .23753 Mdot
.782 .2376 Mdot
.782 .2378 Mdot
.782 .23793 Mdot
.782 .23839 Mdot
.782 .23851 Mdot
.782 .23939 Mdot
.782 .23942 Mdot
.782 .23951 Mdot
.782 .23958 Mdot
.782 .23976 Mdot
.782 .23979 Mdot
.782 .24014 Mdot
.782 .24032 Mdot
.782 .24039 Mdot
.782 .24068 Mdot
.782 .24108 Mdot
.782 .24117 Mdot
.782 .24132 Mdot
.782 .24149 Mdot
.782 .24177 Mdot
.782 .24207 Mdot
.782 .24222 Mdot
.782 .24241 Mdot
.782 .24268 Mdot
.782 .24316 Mdot
.782 .24348 Mdot
.782 .2439 Mdot
.782 .24443 Mdot
.782 .24475 Mdot
.782 .24475 Mdot
.782 .24524 Mdot
.782 .24593 Mdot
.782 .24619 Mdot
.782 .2462 Mdot
.782 .24627 Mdot
.782 .24656 Mdot
.782 .24663 Mdot
.782 .24754 Mdot
.782 .24777 Mdot
.782 .24865 Mdot
.782 .24871 Mdot
.782 .25039 Mdot
.782 .25083 Mdot
.782 .25106 Mdot
.782 .25235 Mdot
.782 .2538 Mdot
.782 .25485 Mdot
.782 .25502 Mdot
.782 .2552 Mdot
.782 .25542 Mdot
.782 .256 Mdot
.782 .25631 Mdot
.782 .25662 Mdot
.782 .25667 Mdot
.782 .25751 Mdot
.782 .25779 Mdot
.782 .25794 Mdot
.782 .25799 Mdot
.782 .25799 Mdot
.782 .25809 Mdot
.782 .25958 Mdot
.782 .2599 Mdot
.782 .25993 Mdot
.782 .2607 Mdot
.782 .26101 Mdot
.782 .26146 Mdot
.782 .26223 Mdot
.782 .26255 Mdot
.782 .26259 Mdot
.782 .26274 Mdot
.782 .26283 Mdot
.782 .263 Mdot
.782 .26324 Mdot
.782 .2639 Mdot
.782 .26428 Mdot
.782 .26555 Mdot
.782 .26692 Mdot
.782 .267 Mdot
.782 .26856 Mdot
.782 .2686 Mdot
.782 .26867 Mdot
.782 .269 Mdot
.782 .27074 Mdot
.782 .27094 Mdot
.782 .27119 Mdot
.782 .27133 Mdot
.782 .27168 Mdot
.782 .27264 Mdot
.782 .27264 Mdot
.782 .2729 Mdot
.782 .2732 Mdot
.782 .27327 Mdot
.782 .27391 Mdot
.782 .2745 Mdot
.782 .27504 Mdot
.782 .27528 Mdot
.782 .27661 Mdot
.782 .27797 Mdot
.782 .27818 Mdot
.782 .27819 Mdot
.782 .27918 Mdot
.782 .27919 Mdot
.782 .28032 Mdot
.782 .28061 Mdot
.782 .28103 Mdot
.782 .28186 Mdot
.782 .28283 Mdot
.782 .28305 Mdot
.782 .28325 Mdot
.782 .28361 Mdot
.782 .28362 Mdot
.782 .28366 Mdot
.782 .28388 Mdot
.782 .285 Mdot
.782 .28504 Mdot
.782 .28533 Mdot
.782 .28692 Mdot
.782 .28738 Mdot
.782 .2883 Mdot
.782 .28833 Mdot
.782 .28933 Mdot
.782 .28966 Mdot
.782 .29021 Mdot
.782 .29188 Mdot
.782 .29338 Mdot
.782 .29369 Mdot
.782 .29486 Mdot
.782 .29593 Mdot
.782 .29631 Mdot
.782 .29648 Mdot
.782 .29686 Mdot
.782 .29768 Mdot
.782 .29858 Mdot
.782 .29941 Mdot
.782 .29943 Mdot
.782 .30208 Mdot
.782 .30303 Mdot
.782 .30322 Mdot
.782 .30327 Mdot
.782 .30387 Mdot
.782 .30537 Mdot
.782 .30759 Mdot
.782 .30868 Mdot
.782 .30947 Mdot
.782 .31029 Mdot
.782 .31042 Mdot
.782 .31081 Mdot
.782 .31086 Mdot
.782 .31153 Mdot
.782 .31222 Mdot
.782 .31346 Mdot
.782 .31405 Mdot
.782 .31406 Mdot
.782 .31522 Mdot
.782 .31555 Mdot
.782 .31719 Mdot
.782 .31761 Mdot
.782 .318 Mdot
.782 .31879 Mdot
.782 .31961 Mdot
.782 .32014 Mdot
.782 .32022 Mdot
.782 .32036 Mdot
.782 .32038 Mdot
.782 .32051 Mdot
.782 .32118 Mdot
.782 .32135 Mdot
.782 .32243 Mdot
.782 .32271 Mdot
.782 .32376 Mdot
.782 .32465 Mdot
.782 .32547 Mdot
.782 .32562 Mdot
.782 .32673 Mdot
.782 .32722 Mdot
.782 .32909 Mdot
.782 .3306 Mdot
.782 .33095 Mdot
.782 .33123 Mdot
.782 .33281 Mdot
.782 .33314 Mdot
.782 .3344 Mdot
.782 .3346 Mdot
.782 .33503 Mdot
.782 .33514 Mdot
.782 .3353 Mdot
.782 .33625 Mdot
.782 .33796 Mdot
.782 .33809 Mdot
.782 .33821 Mdot
.782 .33866 Mdot
.782 .33885 Mdot
.782 .33913 Mdot
.782 .33916 Mdot
.782 .33974 Mdot
.782 .33978 Mdot
.782 .3411 Mdot
.782 .34204 Mdot
.782 .34238 Mdot
.782 .34276 Mdot
.782 .34331 Mdot
.782 .34464 Mdot
.782 .34541 Mdot
.782 .34753 Mdot
.782 .34801 Mdot
.782 .34834 Mdot
.782 .34863 Mdot
.782 .34914 Mdot
.782 .34986 Mdot
.782 .35056 Mdot
.782 .35072 Mdot
.782 .35151 Mdot
.782 .35176 Mdot
.782 .35182 Mdot
.782 .35504 Mdot
.782 .35534 Mdot
.782 .35558 Mdot
.782 .35672 Mdot
.782 .35722 Mdot
.782 .35739 Mdot
.782 .35755 Mdot
.782 .35872 Mdot
.782 .35966 Mdot
.782 .35988 Mdot
.782 .36012 Mdot
.782 .3622 Mdot
.782 .36319 Mdot
.782 .36361 Mdot
.782 .36383 Mdot
.782 .36454 Mdot
.782 .36472 Mdot
.782 .3661 Mdot
.782 .36616 Mdot
.782 .36629 Mdot
.782 .36641 Mdot
.782 .36668 Mdot
.782 .36673 Mdot
.782 .36728 Mdot
.782 .36756 Mdot
.782 .36767 Mdot
.782 .36812 Mdot
.782 .36874 Mdot
.782 .36889 Mdot
.782 .36913 Mdot
.782 .36938 Mdot
.782 .36983 Mdot
.782 .3703 Mdot
.782 .37053 Mdot
.782 .37083 Mdot
.782 .37125 Mdot
.782 .372 Mdot
.782 .37251 Mdot
.782 .37317 Mdot
.782 .37399 Mdot
.782 .37448 Mdot
.782 .37449 Mdot
.782 .37525 Mdot
.782 .37634 Mdot
.782 .37675 Mdot
.782 .37676 Mdot
.782 .37686 Mdot
.782 .37732 Mdot
.782 .37744 Mdot
.782 .37885 Mdot
.782 .37921 Mdot
.782 .38059 Mdot
.782 .38069 Mdot
.782 .38332 Mdot
.782 .384 Mdot
.782 .38436 Mdot
.782 .38637 Mdot
.782 .38864 Mdot
.782 .39029 Mdot
.782 .39055 Mdot
.782 .39083 Mdot
.782 .39118 Mdot
.782 .39208 Mdot
.782 .39257 Mdot
.782 .39306 Mdot
.782 .39313 Mdot
.782 .39444 Mdot
.782 .39489 Mdot
.782 .39512 Mdot
.782 .3952 Mdot
.782 .3952 Mdot
.782 .39535 Mdot
.782 .39768 Mdot
.782 .39818 Mdot
.782 .39823 Mdot
.782 .39943 Mdot
.782 .39992 Mdot
.782 .40062 Mdot
.782 .40184 Mdot
.782 .40233 Mdot
.782 .4024 Mdot
.782 .40263 Mdot
.782 .40277 Mdot
.782 .40304 Mdot
.782 .4034 Mdot
.782 .40444 Mdot
.782 .40503 Mdot
.782 .40702 Mdot
.782 .40916 Mdot
.782 .40929 Mdot
.782 .41173 Mdot
.782 .41179 Mdot
.782 .4119 Mdot
.782 .41242 Mdot
.782 .41514 Mdot
.782 .41545 Mdot
.782 .41584 Mdot
.782 .41607 Mdot
.782 .4166 Mdot
.782 .41811 Mdot
.782 .41811 Mdot
.782 .41852 Mdot
.782 .41898 Mdot
.782 .4191 Mdot
.782 .42009 Mdot
.782 .42103 Mdot
.782 .42187 Mdot
.782 .42224 Mdot
.782 .42432 Mdot
.782 .42644 Mdot
.782 .42678 Mdot
.782 .42679 Mdot
.782 .42834 Mdot
.782 .42836 Mdot
.782 .43013 Mdot
.782 .43057 Mdot
.782 .43123 Mdot
.782 .43253 Mdot
.782 .43405 Mdot
.782 .43438 Mdot
.782 .43471 Mdot
.782 .43526 Mdot
.782 .43529 Mdot
.782 .43535 Mdot
.782 .43568 Mdot
.782 .43744 Mdot
.782 .4375 Mdot
.782 .43795 Mdot
.782 .44044 Mdot
.782 .44117 Mdot
.782 .4426 Mdot
.782 .44265 Mdot
.782 .44421 Mdot
.782 .44473 Mdot
.782 .44559 Mdot
.782 .44821 Mdot
.782 .45055 Mdot
.782 .45103 Mdot
.782 .45286 Mdot
.782 .45453 Mdot
.782 .45513 Mdot
.782 .45539 Mdot
.782 .45598 Mdot
.782 .45727 Mdot
.782 .45868 Mdot
.782 .45997 Mdot
.782 .46001 Mdot
.782 .46416 Mdot
.782 .46563 Mdot
.782 .46594 Mdot
.782 .46601 Mdot
.782 .46696 Mdot
.782 .4693 Mdot
.782 .47277 Mdot
.782 .47447 Mdot
.782 .47571 Mdot
.782 .477 Mdot
.784 .01491 Mdot
.784 .01501 Mdot
.784 .01518 Mdot
.784 .01545 Mdot
.784 .01587 Mdot
.784 .01592 Mdot
.784 .01652 Mdot
.784 .0166 Mdot
.784 .01744 Mdot
.784 .01755 Mdot
.784 .01767 Mdot
.784 .01812 Mdot
.784 .01822 Mdot
.784 .01898 Mdot
.784 .01916 Mdot
.784 .01934 Mdot
.784 .02005 Mdot
.784 .02021 Mdot
.784 .0213 Mdot
.784 .02139 Mdot
.784 .0214 Mdot
.784 .02168 Mdot
.784 .02197 Mdot
.784 .02226 Mdot
.784 .02283 Mdot
.784 .02309 Mdot
.784 .02333 Mdot
.784 .02362 Mdot
.784 .02387 Mdot
.784 .02505 Mdot
.784 .02519 Mdot
.784 .0252 Mdot
.784 .02564 Mdot
.784 .0259 Mdot
.784 .02598 Mdot
.784 .0261 Mdot
.784 .02655 Mdot
.784 .02744 Mdot
.784 .02784 Mdot
.784 .02823 Mdot
.784 .02868 Mdot
.784 .02906 Mdot
.784 .02939 Mdot
.784 .03046 Mdot
.784 .03075 Mdot
.784 .03092 Mdot
.784 .03113 Mdot
.784 .03116 Mdot
.784 .03184 Mdot
.784 .03221 Mdot
.784 .03225 Mdot
.784 .03238 Mdot
.784 .03256 Mdot
.784 .03327 Mdot
.784 .03409 Mdot
.784 .03466 Mdot
.784 .0353 Mdot
.784 .03559 Mdot
.784 .0359 Mdot
.784 .03662 Mdot
.784 .03722 Mdot
.784 .03726 Mdot
.784 .03758 Mdot
.784 .03773 Mdot
.784 .0394 Mdot
.784 .0395 Mdot
.784 .03986 Mdot
.784 .04012 Mdot
.784 .04042 Mdot
.784 .04046 Mdot
.784 .0405 Mdot
.784 .04078 Mdot
.784 .04156 Mdot
.784 .04215 Mdot
.784 .04221 Mdot
.784 .04241 Mdot
.784 .04252 Mdot
.784 .0427 Mdot
.784 .04286 Mdot
.784 .0438 Mdot
.784 .044 Mdot
.784 .04487 Mdot
.784 .04509 Mdot
.784 .04554 Mdot
.784 .04585 Mdot
.784 .04599 Mdot
.784 .04699 Mdot
.784 .04745 Mdot
.784 .04794 Mdot
.784 .04906 Mdot
.784 .05 Mdot
.784 .05006 Mdot
.784 .05047 Mdot
.784 .05056 Mdot
.784 .0508 Mdot
.784 .05311 Mdot
.784 .05343 Mdot
.784 .05357 Mdot
.784 .05414 Mdot
.784 .05455 Mdot
.784 .05502 Mdot
.784 .05508 Mdot
.784 .05515 Mdot
.784 .05559 Mdot
.784 .05681 Mdot
.784 .057 Mdot
.784 .05774 Mdot
.784 .05783 Mdot
.784 .05814 Mdot
.784 .05832 Mdot
.784 .05859 Mdot
.784 .05885 Mdot
.784 .06033 Mdot
.784 .06063 Mdot
.784 .06084 Mdot
.784 .06127 Mdot
.784 .06152 Mdot
.784 .062 Mdot
.784 .06226 Mdot
.784 .06234 Mdot
.784 .06305 Mdot
.784 .06353 Mdot
.784 .06357 Mdot
.784 .06376 Mdot
.784 .06432 Mdot
.784 .06532 Mdot
.784 .06604 Mdot
.784 .0666 Mdot
.784 .06681 Mdot
.784 .06854 Mdot
.784 .06857 Mdot
.784 .06865 Mdot
.784 .06931 Mdot
.784 .07004 Mdot
.784 .07014 Mdot
.784 .07077 Mdot
.784 .07092 Mdot
.784 .0713 Mdot
.784 .07141 Mdot
.784 .07317 Mdot
.784 .07368 Mdot
.784 .07432 Mdot
.784 .07492 Mdot
.784 .07542 Mdot
.784 .07543 Mdot
.784 .07565 Mdot
.784 .07632 Mdot
.784 .07639 Mdot
.784 .07654 Mdot
.784 .07662 Mdot
.784 .07717 Mdot
.784 .0773 Mdot
.784 .07779 Mdot
.784 .07792 Mdot
.784 .078 Mdot
.784 .07811 Mdot
.784 .07813 Mdot
.784 .0788 Mdot
.784 .07973 Mdot
.784 .08028 Mdot
.784 .08073 Mdot
.784 .0809 Mdot
.784 .08102 Mdot
.784 .08218 Mdot
.784 .08225 Mdot
.784 .08231 Mdot
.784 .08242 Mdot
.784 .0828 Mdot
.784 .08308 Mdot
.784 .08351 Mdot
.784 .08368 Mdot
.784 .08381 Mdot
.784 .08392 Mdot
.784 .08623 Mdot
.784 .08671 Mdot
.784 .08704 Mdot
.784 .08739 Mdot
.784 .08772 Mdot
.784 .0881 Mdot
.784 .08842 Mdot
.784 .08847 Mdot
.784 .08886 Mdot
.784 .0889 Mdot
.784 .08926 Mdot
.784 .08939 Mdot
.784 .08958 Mdot
.784 .08968 Mdot
.784 .08979 Mdot
.784 .09051 Mdot
.784 .09073 Mdot
.784 .09126 Mdot
.784 .09132 Mdot
.784 .09136 Mdot
.784 .09161 Mdot
.784 .0925 Mdot
.784 .09407 Mdot
.784 .09487 Mdot
.784 .0952 Mdot
.784 .09567 Mdot
.784 .09607 Mdot
.784 .0964 Mdot
.784 .09651 Mdot
.784 .09777 Mdot
.784 .09904 Mdot
.784 .09912 Mdot
.784 .09916 Mdot
.784 .09928 Mdot
.784 .0995 Mdot
.784 .09962 Mdot
.784 .10032 Mdot
.784 .10127 Mdot
.784 .10146 Mdot
.784 .10162 Mdot
.784 .10261 Mdot
.784 .10284 Mdot
.784 .10344 Mdot
.784 .10361 Mdot
.784 .10383 Mdot
.784 .10399 Mdot
.784 .10481 Mdot
.784 .10515 Mdot
.784 .10544 Mdot
.784 .10546 Mdot
.784 .10637 Mdot
.784 .10717 Mdot
.784 .10734 Mdot
.784 .10817 Mdot
.784 .10853 Mdot
.784 .10912 Mdot
.784 .1093 Mdot
.784 .10989 Mdot
.784 .10992 Mdot
.784 .10999 Mdot
.784 .11026 Mdot
.784 .111 Mdot
.784 .11132 Mdot
.784 .11143 Mdot
.784 .11166 Mdot
.784 .11179 Mdot
.784 .11243 Mdot
.784 .11264 Mdot
.784 .11284 Mdot
.784 .11362 Mdot
.784 .11365 Mdot
.784 .11382 Mdot
.784 .11395 Mdot
.784 .11412 Mdot
.784 .11415 Mdot
.784 .1152 Mdot
.784 .11602 Mdot
.784 .11666 Mdot
.784 .11752 Mdot
.784 .11817 Mdot
.784 .1182 Mdot
.784 .11822 Mdot
.784 .1185 Mdot
.784 .11868 Mdot
.784 .11909 Mdot
.784 .12049 Mdot
.784 .1206 Mdot
.784 .12071 Mdot
.784 .12087 Mdot
.784 .12141 Mdot
.784 .12148 Mdot
.784 .12192 Mdot
.784 .12255 Mdot
.784 .12258 Mdot
.784 .12284 Mdot
.784 .12284 Mdot
.784 .12306 Mdot
.784 .12312 Mdot
.784 .12322 Mdot
.784 .12448 Mdot
.784 .12545 Mdot
.784 .12642 Mdot
.784 .12658 Mdot
.784 .12685 Mdot
.784 .12698 Mdot
.784 .1276 Mdot
.784 .12811 Mdot
.784 .12862 Mdot
.784 .12867 Mdot
.784 .12871 Mdot
.784 .12918 Mdot
.784 .12957 Mdot
.784 .12979 Mdot
.784 .12986 Mdot
.784 .13006 Mdot
.784 .13028 Mdot
.784 .13037 Mdot
.784 .13098 Mdot
.784 .13104 Mdot
.784 .13161 Mdot
.784 .13181 Mdot
.784 .13199 Mdot
.784 .1321 Mdot
.784 .13226 Mdot
.784 .13243 Mdot
.784 .13314 Mdot
.784 .13315 Mdot
.784 .13355 Mdot
.784 .13364 Mdot
.784 .13391 Mdot
.784 .13473 Mdot
.784 .13483 Mdot
.784 .1349 Mdot
.784 .13503 Mdot
.784 .13529 Mdot
.784 .13568 Mdot
.784 .13669 Mdot
.784 .13708 Mdot
.784 .13729 Mdot
.784 .13788 Mdot
.784 .1379 Mdot
.784 .13879 Mdot
.784 .13906 Mdot
.784 .13914 Mdot
.784 .13952 Mdot
.784 .14 Mdot
.784 .14039 Mdot
.784 .14083 Mdot
.784 .14091 Mdot
.784 .14165 Mdot
.784 .14174 Mdot
.784 .14228 Mdot
.784 .14257 Mdot
.784 .1428 Mdot
.784 .14297 Mdot
.784 .14305 Mdot
.784 .14425 Mdot
.784 .14494 Mdot
.784 .14694 Mdot
.784 .14705 Mdot
.784 .14712 Mdot
.784 .14731 Mdot
.784 .14765 Mdot
.784 .14785 Mdot
.784 .14844 Mdot
.784 .14894 Mdot
.784 .14897 Mdot
.784 .14914 Mdot
.784 .15014 Mdot
.784 .15044 Mdot
.784 .15073 Mdot
.784 .15096 Mdot
.784 .15098 Mdot
.784 .15104 Mdot
.784 .15143 Mdot
.784 .15199 Mdot
.784 .15215 Mdot
.784 .1525 Mdot
.784 .15254 Mdot
.784 .1529 Mdot
.784 .15383 Mdot
.784 .1541 Mdot
.784 .15411 Mdot
.784 .15442 Mdot
.784 .15445 Mdot
.784 .1547 Mdot
.784 .15486 Mdot
.784 .15577 Mdot
.784 .15598 Mdot
.784 .15652 Mdot
.784 .15697 Mdot
.784 .157 Mdot
.784 .15743 Mdot
.784 .15809 Mdot
.784 .15844 Mdot
.784 .15852 Mdot
.784 .15901 Mdot
.784 .15951 Mdot
.784 .15969 Mdot
.784 .15995 Mdot
.784 .16064 Mdot
.784 .16126 Mdot
.784 .16182 Mdot
.784 .16273 Mdot
.784 .16302 Mdot
.784 .16345 Mdot
.784 .16395 Mdot
.784 .16399 Mdot
.784 .1641 Mdot
.784 .16452 Mdot
.784 .1657 Mdot
.784 .16619 Mdot
.784 .16636 Mdot
.784 .16672 Mdot
.784 .16677 Mdot
.784 .16693 Mdot
.784 .16735 Mdot
.784 .16769 Mdot
.784 .16793 Mdot
.784 .16827 Mdot
.784 .16858 Mdot
.784 .1698 Mdot
.784 .16985 Mdot
.784 .17011 Mdot
.784 .17032 Mdot
.784 .17034 Mdot
.784 .17059 Mdot
.784 .17063 Mdot
.784 .17122 Mdot
.784 .17133 Mdot
.784 .172 Mdot
.784 .17228 Mdot
.784 .17254 Mdot
.784 .17356 Mdot
.784 .17457 Mdot
.784 .17466 Mdot
.784 .17535 Mdot
.784 .17578 Mdot
.784 .17592 Mdot
.784 .17647 Mdot
.784 .17664 Mdot
.784 .17676 Mdot
.784 .17694 Mdot
.784 .17698 Mdot
.784 .17701 Mdot
.784 .17739 Mdot
.784 .17745 Mdot
.784 .17773 Mdot
.784 .17822 Mdot
.784 .17837 Mdot
.784 .17843 Mdot
.784 .17864 Mdot
.784 .17954 Mdot
.784 .18057 Mdot
.784 .18075 Mdot
.784 .18091 Mdot
.784 .18117 Mdot
.784 .18143 Mdot
.784 .18201 Mdot
.784 .18201 Mdot
.784 .18212 Mdot
.784 .18223 Mdot
.784 .18263 Mdot
.784 .18281 Mdot
.784 .18302 Mdot
.784 .1838 Mdot
.784 .18385 Mdot
.784 .18425 Mdot
.784 .18426 Mdot
.784 .1846 Mdot
.784 .18469 Mdot
.784 .18486 Mdot
.784 .18651 Mdot
.784 .18683 Mdot
.784 .18835 Mdot
.784 .18987 Mdot
.784 .19011 Mdot
.784 .1905 Mdot
.784 .19055 Mdot
.784 .19075 Mdot
.784 .19117 Mdot
.784 .19172 Mdot
.784 .19179 Mdot
.784 .19252 Mdot
.784 .19279 Mdot
.784 .19331 Mdot
.784 .1934 Mdot
.784 .19346 Mdot
.784 .19379 Mdot
.784 .1942 Mdot
.784 .19481 Mdot
.784 .1949 Mdot
.784 .19515 Mdot
.784 .19527 Mdot
.784 .19533 Mdot
.784 .19558 Mdot
.784 .19592 Mdot
.784 .19601 Mdot
.784 .19604 Mdot
.784 .19606 Mdot
.784 .19639 Mdot
.784 .19644 Mdot
.784 .19689 Mdot
.784 .19698 Mdot
.784 .19701 Mdot
.784 .19711 Mdot
.784 .19738 Mdot
.784 .198 Mdot
.784 .19832 Mdot
.784 .19843 Mdot
.784 .1986 Mdot
.784 .19877 Mdot
.784 .19902 Mdot
.784 .19912 Mdot
.784 .19929 Mdot
.784 .19994 Mdot
.784 .2004 Mdot
.784 .20042 Mdot
.784 .20106 Mdot
.784 .20119 Mdot
.784 .20161 Mdot
.784 .2029 Mdot
.784 .20295 Mdot
.784 .20306 Mdot
.784 .20312 Mdot
.784 .20316 Mdot
.784 .20336 Mdot
.784 .20378 Mdot
.784 .20439 Mdot
.784 .20467 Mdot
.784 .20471 Mdot
.784 .20597 Mdot
.784 .206 Mdot
.784 .20636 Mdot
.784 .20659 Mdot
.784 .20691 Mdot
.784 .20701 Mdot
.784 .20784 Mdot
.784 .20787 Mdot
.784 .20926 Mdot
.784 .20969 Mdot
.784 .20981 Mdot
.784 .2104 Mdot
.784 .21117 Mdot
.784 .21178 Mdot
.784 .21246 Mdot
.784 .21259 Mdot
.784 .21337 Mdot
.784 .21374 Mdot
.784 .21389 Mdot
.784 .2146 Mdot
.784 .21474 Mdot
.784 .2152 Mdot
.784 .21555 Mdot
.784 .21583 Mdot
.784 .21595 Mdot
.784 .21783 Mdot
.784 .2189 Mdot
.784 .22049 Mdot
.784 .22205 Mdot
.784 .22222 Mdot
.784 .22232 Mdot
.784 .22262 Mdot
.784 .22316 Mdot
.784 .22347 Mdot
.784 .22439 Mdot
.784 .22518 Mdot
.784 .22522 Mdot
.784 .22549 Mdot
.784 .22635 Mdot
.784 .22706 Mdot
.784 .22727 Mdot
.784 .22753 Mdot
.784 .22798 Mdot
.784 .22835 Mdot
.784 .22837 Mdot
.784 .22847 Mdot
.784 .22874 Mdot
.784 .22894 Mdot
.784 .22908 Mdot
.784 .22973 Mdot
.784 .22995 Mdot
.784 .23021 Mdot
.784 .23075 Mdot
.784 .23082 Mdot
.784 .23134 Mdot
.784 .23139 Mdot
.784 .23285 Mdot
.784 .23326 Mdot
.784 .23329 Mdot
.784 .23346 Mdot
.784 .23374 Mdot
.784 .23378 Mdot
.784 .23382 Mdot
.784 .23421 Mdot
.784 .23446 Mdot
.784 .23589 Mdot
.784 .23621 Mdot
.784 .23656 Mdot
.784 .23707 Mdot
.784 .23759 Mdot
.784 .23777 Mdot
.784 .23782 Mdot
.784 .23849 Mdot
.784 .23953 Mdot
.784 .2396 Mdot
.784 .23993 Mdot
.784 .24007 Mdot
.784 .24019 Mdot
.784 .2402 Mdot
.784 .24096 Mdot
.784 .24145 Mdot
.784 .24176 Mdot
.784 .24204 Mdot
.784 .24245 Mdot
.784 .24303 Mdot
.784 .24353 Mdot
.784 .24449 Mdot
.784 .24537 Mdot
.784 .24538 Mdot
.784 .24574 Mdot
.784 .24668 Mdot
.784 .24715 Mdot
.784 .24726 Mdot
.784 .24738 Mdot
.784 .24793 Mdot
.784 .24833 Mdot
.784 .24872 Mdot
.784 .24878 Mdot
.784 .24895 Mdot
.784 .24961 Mdot
.784 .24965 Mdot
.784 .25 Mdot
.784 .25012 Mdot
.784 .2502 Mdot
.784 .25145 Mdot
.784 .25146 Mdot
.784 .25166 Mdot
.784 .25222 Mdot
.784 .25249 Mdot
.784 .25306 Mdot
.784 .25314 Mdot
.784 .25338 Mdot
.784 .25339 Mdot
.784 .25375 Mdot
.784 .25386 Mdot
.784 .25405 Mdot
.784 .25425 Mdot
.784 .25458 Mdot
.784 .25495 Mdot
.784 .25529 Mdot
.784 .25549 Mdot
.784 .25597 Mdot
.784 .25768 Mdot
.784 .25789 Mdot
.784 .25796 Mdot
.784 .25837 Mdot
.784 .2587 Mdot
.784 .25873 Mdot
.784 .25889 Mdot
.784 .25912 Mdot
.784 .25918 Mdot
.784 .25933 Mdot
.784 .25998 Mdot
.784 .26011 Mdot
.784 .26029 Mdot
.784 .26066 Mdot
.784 .26133 Mdot
.784 .2616 Mdot
.784 .26178 Mdot
.784 .26197 Mdot
.784 .26218 Mdot
.784 .26264 Mdot
.784 .26378 Mdot
.784 .26513 Mdot
.784 .26537 Mdot
.784 .26551 Mdot
.784 .26658 Mdot
.784 .26694 Mdot
.784 .26699 Mdot
.784 .26726 Mdot
.784 .26748 Mdot
.784 .26834 Mdot
.784 .26862 Mdot
.784 .2688 Mdot
.784 .26908 Mdot
.784 .26915 Mdot
.784 .26919 Mdot
.784 .26945 Mdot
.784 .26979 Mdot
.784 .26988 Mdot
.784 .26996 Mdot
.784 .27033 Mdot
.784 .2711 Mdot
.784 .27133 Mdot
.784 .27142 Mdot
.784 .27158 Mdot
.784 .27174 Mdot
.784 .27316 Mdot
.784 .27478 Mdot
.784 .27506 Mdot
.784 .27531 Mdot
.784 .27572 Mdot
.784 .27612 Mdot
.784 .27658 Mdot
.784 .27675 Mdot
.784 .27703 Mdot
.784 .27704 Mdot
.784 .27718 Mdot
.784 .2772 Mdot
.784 .27738 Mdot
.784 .27742 Mdot
.784 .27758 Mdot
.784 .27801 Mdot
.784 .27829 Mdot
.784 .27862 Mdot
.784 .27985 Mdot
.784 .27992 Mdot
.784 .28055 Mdot
.784 .28057 Mdot
.784 .28109 Mdot
.784 .28123 Mdot
.784 .2815 Mdot
.784 .28409 Mdot
.784 .28459 Mdot
.784 .28698 Mdot
.784 .28936 Mdot
.784 .28974 Mdot
.784 .29034 Mdot
.784 .29042 Mdot
.784 .29074 Mdot
.784 .29139 Mdot
.784 .29226 Mdot
.784 .29237 Mdot
.784 .29352 Mdot
.784 .29394 Mdot
.784 .29475 Mdot
.784 .29489 Mdot
.784 .29499 Mdot
.784 .29551 Mdot
.784 .29615 Mdot
.784 .2971 Mdot
.784 .29725 Mdot
.784 .29764 Mdot
.784 .29783 Mdot
.784 .29792 Mdot
.784 .29831 Mdot
.784 .29884 Mdot
.784 .29899 Mdot
.784 .29903 Mdot
.784 .29907 Mdot
.784 .29958 Mdot
.784 .29966 Mdot
.784 .30036 Mdot
.784 .30051 Mdot
.784 .30056 Mdot
.784 .30071 Mdot
.784 .30114 Mdot
.784 .30211 Mdot
.784 .3026 Mdot
.784 .30278 Mdot
.784 .30305 Mdot
.784 .30332 Mdot
.784 .3037 Mdot
.784 .30386 Mdot
.784 .30413 Mdot
.784 .30514 Mdot
.784 .30588 Mdot
.784 .30589 Mdot
.784 .3069 Mdot
.784 .3071 Mdot
.784 .30776 Mdot
.784 .30979 Mdot
.784 .30986 Mdot
.784 .31004 Mdot
.784 .31014 Mdot
.784 .3102 Mdot
.784 .31052 Mdot
.784 .31116 Mdot
.784 .31213 Mdot
.784 .31257 Mdot
.784 .31263 Mdot
.784 .3146 Mdot
.784 .31465 Mdot
.784 .31521 Mdot
.784 .31557 Mdot
.784 .31608 Mdot
.784 .31623 Mdot
.784 .31753 Mdot
.784 .31758 Mdot
.784 .31976 Mdot
.784 .32044 Mdot
.784 .32062 Mdot
.784 .32156 Mdot
.784 .32275 Mdot
.784 .32371 Mdot
.784 .32477 Mdot
.784 .32498 Mdot
.784 .3262 Mdot
.784 .32679 Mdot
.784 .32702 Mdot
.784 .32813 Mdot
.784 .32835 Mdot
.784 .32907 Mdot
.784 .32963 Mdot
.784 .33006 Mdot
.784 .33025 Mdot
.784 .3332 Mdot
.784 .33488 Mdot
.784 .33736 Mdot
.784 .33981 Mdot
.784 .34009 Mdot
.784 .34025 Mdot
.784 .34072 Mdot
.784 .34155 Mdot
.784 .34204 Mdot
.784 .34349 Mdot
.784 .34472 Mdot
.784 .34479 Mdot
.784 .34521 Mdot
.784 .34655 Mdot
.784 .34768 Mdot
.784 .348 Mdot
.784 .34841 Mdot
.784 .34912 Mdot
.784 .34969 Mdot
.784 .34973 Mdot
.784 .34988 Mdot
.784 .35031 Mdot
.784 .35063 Mdot
.784 .35084 Mdot
.784 .35186 Mdot
.784 .35221 Mdot
.784 .35261 Mdot
.784 .35346 Mdot
.784 .35357 Mdot
.784 .35438 Mdot
.784 .35446 Mdot
.784 .35675 Mdot
.784 .3574 Mdot
.784 .35744 Mdot
.784 .35771 Mdot
.784 .35814 Mdot
.784 .3582 Mdot
.784 .35827 Mdot
.784 .35888 Mdot
.784 .35928 Mdot
.784 .36151 Mdot
.784 .36202 Mdot
.784 .36256 Mdot
.784 .36336 Mdot
.784 .36418 Mdot
.784 .36447 Mdot
.784 .36454 Mdot
.784 .3656 Mdot
.784 .36723 Mdot
.784 .36733 Mdot
.784 .36785 Mdot
.784 .36807 Mdot
.784 .36826 Mdot
.784 .36827 Mdot
.784 .36947 Mdot
.784 .37023 Mdot
.784 .37072 Mdot
.784 .37116 Mdot
.784 .37181 Mdot
.784 .37271 Mdot
.784 .37349 Mdot
.784 .375 Mdot
.784 .37638 Mdot
.784 .3764 Mdot
.784 .37696 Mdot
.784 .37844 Mdot
.784 .37917 Mdot
.784 .37935 Mdot
.784 .37953 Mdot
.784 .3804 Mdot
.784 .38102 Mdot
.784 .38164 Mdot
.784 .38174 Mdot
.784 .382 Mdot
.784 .38304 Mdot
.784 .3831 Mdot
.784 .38365 Mdot
.784 .38383 Mdot
.784 .38396 Mdot
.784 .38592 Mdot
.784 .38593 Mdot
.784 .38624 Mdot
.784 .38713 Mdot
.784 .38754 Mdot
.784 .38844 Mdot
.784 .38857 Mdot
.784 .38894 Mdot
.784 .38896 Mdot
.784 .38952 Mdot
.784 .3897 Mdot
.784 .38999 Mdot
.784 .3903 Mdot
.784 .39082 Mdot
.784 .39141 Mdot
.784 .39194 Mdot
.784 .39224 Mdot
.784 .39301 Mdot
.784 .39568 Mdot
.784 .39602 Mdot
.784 .39613 Mdot
.784 .39676 Mdot
.784 .39729 Mdot
.784 .39734 Mdot
.784 .39759 Mdot
.784 .39794 Mdot
.784 .39804 Mdot
.784 .39827 Mdot
.784 .3993 Mdot
.784 .3995 Mdot
.784 .39977 Mdot
.784 .40035 Mdot
.784 .40141 Mdot
.784 .40184 Mdot
.784 .40211 Mdot
.784 .40242 Mdot
.784 .40274 Mdot
.784 .40346 Mdot
.784 .40525 Mdot
.784 .40737 Mdot
.784 .40774 Mdot
.784 .40796 Mdot
.784 .40965 Mdot
.784 .41021 Mdot
.784 .41028 Mdot
.784 .4107 Mdot
.784 .41105 Mdot
.784 .4124 Mdot
.784 .41284 Mdot
.784 .41311 Mdot
.784 .41355 Mdot
.784 .41367 Mdot
.784 .41374 Mdot
.784 .41414 Mdot
.784 .41467 Mdot
.784 .41481 Mdot
.784 .41494 Mdot
.784 .41551 Mdot
.784 .41672 Mdot
.784 .41709 Mdot
.784 .41723 Mdot
.784 .41749 Mdot
.784 .41774 Mdot
.784 .41996 Mdot
.784 .4225 Mdot
.784 .42293 Mdot
.784 .42333 Mdot
.784 .42396 Mdot
.784 .4246 Mdot
.784 .42531 Mdot
.784 .42558 Mdot
.784 .42602 Mdot
.784 .42604 Mdot
.784 .42626 Mdot
.784 .42629 Mdot
.784 .42658 Mdot
.784 .42664 Mdot
.784 .42689 Mdot
.784 .42756 Mdot
.784 .428 Mdot
.784 .42852 Mdot
.784 .43044 Mdot
.784 .43055 Mdot
.784 .43154 Mdot
.784 .43157 Mdot
.784 .43239 Mdot
.784 .43262 Mdot
.784 .43303 Mdot
.784 .43709 Mdot
.784 .43787 Mdot
.784 .44163 Mdot
.784 .44536 Mdot
.784 .44595 Mdot
.784 .44689 Mdot
.784 .44702 Mdot
.784 .44752 Mdot
.784 .44855 Mdot
.784 .4499 Mdot
.784 .45008 Mdot
.784 .45188 Mdot
.784 .45253 Mdot
.784 .45382 Mdot
.784 .45403 Mdot
.784 .45419 Mdot
.784 .45499 Mdot
.784 .456 Mdot
.784 .4575 Mdot
.784 .45773 Mdot
.784 .45834 Mdot
.784 .45863 Mdot
.784 .45878 Mdot
.784 .45938 Mdot
.784 .46023 Mdot
.784 .46045 Mdot
.784 .46053 Mdot
.784 .46058 Mdot
.784 .46138 Mdot
.784 .46151 Mdot
.784 .46261 Mdot
.784 .46284 Mdot
.784 .46291 Mdot
.784 .46316 Mdot
.784 .46382 Mdot
.784 .46535 Mdot
.784 .46612 Mdot
.784 .4664 Mdot
.784 .46682 Mdot
.784 .46725 Mdot
.784 .46785 Mdot
.784 .46809 Mdot
.784 .46851 Mdot
.784 .4701 Mdot
.784 .47125 Mdot
.784 .47128 Mdot
.784 .47286 Mdot
.784 .47318 Mdot
.784 .47422 Mdot
.784 .4774 Mdot
.784 .47751 Mdot
.784 .47778 Mdot
.784 .47794 Mdot
.784 .47804 Mdot
.786 .01499 Mdot
.786 .01514 Mdot
.786 .01539 Mdot
.786 .01577 Mdot
.786 .01638 Mdot
.786 .01733 Mdot
.786 .01857 Mdot
.786 .01882 Mdot
.786 .01899 Mdot
.786 .01909 Mdot
.786 .02043 Mdot
.786 .02077 Mdot
.786 .02079 Mdot
.786 .02117 Mdot
.786 .02144 Mdot
.786 .0216 Mdot
.786 .02162 Mdot
.786 .02192 Mdot
.786 .02242 Mdot
.786 .02333 Mdot
.786 .0237 Mdot
.786 .02405 Mdot
.786 .02409 Mdot
.786 .02423 Mdot
.786 .02427 Mdot
.786 .02477 Mdot
.786 .02485 Mdot
.786 .02486 Mdot
.786 .02528 Mdot
.786 .02554 Mdot
.786 .02557 Mdot
.786 .02596 Mdot
.786 .02604 Mdot
.786 .02683 Mdot
.786 .02799 Mdot
.786 .02826 Mdot
.786 .02884 Mdot
.786 .0294 Mdot
.786 .02946 Mdot
.786 .02968 Mdot
.786 .02973 Mdot
.786 .02984 Mdot
.786 .03052 Mdot
.786 .03065 Mdot
.786 .03066 Mdot
.786 .03076 Mdot
.786 .03103 Mdot
.786 .03133 Mdot
.786 .03173 Mdot
.786 .03178 Mdot
.786 .0324 Mdot
.786 .03252 Mdot
.786 .03363 Mdot
.786 .03376 Mdot
.786 .03558 Mdot
.786 .036 Mdot
.786 .03653 Mdot
.786 .03692 Mdot
.786 .03696 Mdot
.786 .03767 Mdot
.786 .03779 Mdot
.786 .03789 Mdot
.786 .03824 Mdot
.786 .03833 Mdot
.786 .0385 Mdot
.786 .03956 Mdot
.786 .03977 Mdot
.786 .03979 Mdot
.786 .03995 Mdot
.786 .04019 Mdot
.786 .04037 Mdot
.786 .04083 Mdot
.786 .04146 Mdot
.786 .04154 Mdot
.786 .04189 Mdot
.786 .04233 Mdot
.786 .04251 Mdot
.786 .04271 Mdot
.786 .04345 Mdot
.786 .04445 Mdot
.786 .04465 Mdot
.786 .04484 Mdot
.786 .04553 Mdot
.786 .04581 Mdot
.786 .04603 Mdot
.786 .04609 Mdot
.786 .04704 Mdot
.786 .04732 Mdot
.786 .04751 Mdot
.786 .04818 Mdot
.786 .04867 Mdot
.786 .049 Mdot
.786 .04962 Mdot
.786 .04968 Mdot
.786 .0508 Mdot
.786 .05099 Mdot
.786 .05114 Mdot
.786 .05169 Mdot
.786 .05183 Mdot
.786 .0521 Mdot
.786 .05211 Mdot
.786 .05233 Mdot
.786 .05287 Mdot
.786 .05328 Mdot
.786 .05364 Mdot
.786 .05377 Mdot
.786 .0541 Mdot
.786 .05413 Mdot
.786 .05438 Mdot
.786 .05473 Mdot
.786 .05474 Mdot
.786 .05477 Mdot
.786 .05485 Mdot
.786 .05498 Mdot
.786 .05504 Mdot
.786 .05507 Mdot
.786 .05531 Mdot
.786 .05553 Mdot
.786 .05578 Mdot
.786 .05641 Mdot
.786 .05676 Mdot
.786 .05688 Mdot
.786 .05743 Mdot
.786 .05813 Mdot
.786 .05841 Mdot
.786 .05872 Mdot
.786 .05898 Mdot
.786 .05988 Mdot
.786 .06147 Mdot
.786 .06178 Mdot
.786 .06207 Mdot
.786 .06237 Mdot
.786 .06316 Mdot
.786 .06358 Mdot
.786 .06359 Mdot
.786 .06394 Mdot
.786 .06403 Mdot
.786 .06411 Mdot
.786 .06545 Mdot
.786 .06552 Mdot
.786 .06596 Mdot
.786 .06627 Mdot
.786 .06731 Mdot
.786 .06736 Mdot
.786 .0681 Mdot
.786 .06822 Mdot
.786 .06862 Mdot
.786 .06939 Mdot
.786 .06959 Mdot
.786 .06968 Mdot
.786 .06978 Mdot
.786 .07012 Mdot
.786 .07091 Mdot
.786 .07143 Mdot
.786 .07175 Mdot
.786 .07176 Mdot
.786 .07198 Mdot
.786 .07284 Mdot
.786 .07306 Mdot
.786 .07349 Mdot
.786 .0735 Mdot
.786 .07385 Mdot
.786 .0747 Mdot
.786 .07479 Mdot
.786 .07533 Mdot
.786 .0759 Mdot
.786 .07611 Mdot
.786 .07646 Mdot
.786 .07663 Mdot
.786 .07667 Mdot
.786 .07672 Mdot
.786 .07678 Mdot
.786 .07706 Mdot
.786 .07751 Mdot
.786 .07761 Mdot
.786 .07764 Mdot
.786 .07768 Mdot
.786 .0778 Mdot
.786 .07802 Mdot
.786 .07811 Mdot
.786 .07816 Mdot
.786 .07854 Mdot
.786 .07856 Mdot
.786 .07866 Mdot
.786 .07878 Mdot
.786 .07888 Mdot
.786 .07926 Mdot
.786 .08002 Mdot
.786 .08026 Mdot
.786 .08075 Mdot
.786 .08081 Mdot
.786 .08098 Mdot
.786 .081 Mdot
.786 .08156 Mdot
.786 .08174 Mdot
.786 .08186 Mdot
.786 .08297 Mdot
.786 .0834 Mdot
.786 .08389 Mdot
.786 .0843 Mdot
.786 .08533 Mdot
.786 .08554 Mdot
.786 .08571 Mdot
.786 .08613 Mdot
.786 .08617 Mdot
.786 .08821 Mdot
.786 .08869 Mdot
.786 .08916 Mdot
.786 .08938 Mdot
.786 .08963 Mdot
.786 .08981 Mdot
.786 .09032 Mdot
.786 .09072 Mdot
.786 .09087 Mdot
.786 .09153 Mdot
.786 .09155 Mdot
.786 .09196 Mdot
.786 .09209 Mdot
.786 .09224 Mdot
.786 .09236 Mdot
.786 .09236 Mdot
.786 .0944 Mdot
.786 .09447 Mdot
.786 .09459 Mdot
.786 .09528 Mdot
.786 .09553 Mdot
.786 .09576 Mdot
.786 .09639 Mdot
.786 .09699 Mdot
.786 .09708 Mdot
.786 .09738 Mdot
.786 .0974 Mdot
.786 .09748 Mdot
.786 .09751 Mdot
.786 .09863 Mdot
.786 .09883 Mdot
.786 .09892 Mdot
.786 .09945 Mdot
.786 .09959 Mdot
.786 .09985 Mdot
.786 .10067 Mdot
.786 .10098 Mdot
.786 .10111 Mdot
.786 .10128 Mdot
.786 .1013 Mdot
.786 .1018 Mdot
.786 .10253 Mdot
.786 .10306 Mdot
.786 .10388 Mdot
.786 .10437 Mdot
.786 .10439 Mdot
.786 .10473 Mdot
.786 .10501 Mdot
.786 .10609 Mdot
.786 .10644 Mdot
.786 .10711 Mdot
.786 .10768 Mdot
.786 .10791 Mdot
.786 .10825 Mdot
.786 .10901 Mdot
.786 .10916 Mdot
.786 .11001 Mdot
.786 .11002 Mdot
.786 .11014 Mdot
.786 .1109 Mdot
.786 .11122 Mdot
.786 .11179 Mdot
.786 .11205 Mdot
.786 .11211 Mdot
.786 .11218 Mdot
.786 .11229 Mdot
.786 .11273 Mdot
.786 .11343 Mdot
.786 .11359 Mdot
.786 .11363 Mdot
.786 .1137 Mdot
.786 .11389 Mdot
.786 .11412 Mdot
.786 .11423 Mdot
.786 .11437 Mdot
.786 .11445 Mdot
.786 .11504 Mdot
.786 .11509 Mdot
.786 .11523 Mdot
.786 .11543 Mdot
.786 .11558 Mdot
.786 .11581 Mdot
.786 .11618 Mdot
.786 .11738 Mdot
.786 .11762 Mdot
.786 .11775 Mdot
.786 .11852 Mdot
.786 .11861 Mdot
.786 .11888 Mdot
.786 .11891 Mdot
.786 .11902 Mdot
.786 .11979 Mdot
.786 .12008 Mdot
.786 .12027 Mdot
.786 .12113 Mdot
.786 .12201 Mdot
.786 .12251 Mdot
.786 .12269 Mdot
.786 .12271 Mdot
.786 .12346 Mdot
.786 .12411 Mdot
.786 .1243 Mdot
.786 .12535 Mdot
.786 .12572 Mdot
.786 .12574 Mdot
.786 .12606 Mdot
.786 .12631 Mdot
.786 .12632 Mdot
.786 .12664 Mdot
.786 .12699 Mdot
.786 .12704 Mdot
.786 .12709 Mdot
.786 .12877 Mdot
.786 .13025 Mdot
.786 .13067 Mdot
.786 .13101 Mdot
.786 .13174 Mdot
.786 .13182 Mdot
.786 .13188 Mdot
.786 .13209 Mdot
.786 .13248 Mdot
.786 .13266 Mdot
.786 .13277 Mdot
.786 .13351 Mdot
.786 .13357 Mdot
.786 .1342 Mdot
.786 .13444 Mdot
.786 .13547 Mdot
.786 .13549 Mdot
.786 .13593 Mdot
.786 .13614 Mdot
.786 .13635 Mdot
.786 .13658 Mdot
.786 .13677 Mdot
.786 .13678 Mdot
.786 .13698 Mdot
.786 .13726 Mdot
.786 .13924 Mdot
.786 .13998 Mdot
.786 .14009 Mdot
.786 .14028 Mdot
.786 .14136 Mdot
.786 .14176 Mdot
.786 .14212 Mdot
.786 .1423 Mdot
.786 .14244 Mdot
.786 .14269 Mdot
.786 .14311 Mdot
.786 .14405 Mdot
.786 .14419 Mdot
.786 .14429 Mdot
.786 .14467 Mdot
.786 .14467 Mdot
.786 .1447 Mdot
.786 .14473 Mdot
.786 .14482 Mdot
.786 .14487 Mdot
.786 .1451 Mdot
.786 .14576 Mdot
.786 .14663 Mdot
.786 .14695 Mdot
.786 .14708 Mdot
.786 .14743 Mdot
.786 .14792 Mdot
.786 .14814 Mdot
.786 .14844 Mdot
.786 .14854 Mdot
.786 .14905 Mdot
.786 .14983 Mdot
.786 .15033 Mdot
.786 .15053 Mdot
.786 .1508 Mdot
.786 .15083 Mdot
.786 .15086 Mdot
.786 .15118 Mdot
.786 .15137 Mdot
.786 .15142 Mdot
.786 .15162 Mdot
.786 .15275 Mdot
.786 .15276 Mdot
.786 .15359 Mdot
.786 .1537 Mdot
.786 .15393 Mdot
.786 .15436 Mdot
.786 .15488 Mdot
.786 .15555 Mdot
.786 .15565 Mdot
.786 .15568 Mdot
.786 .15622 Mdot
.786 .15628 Mdot
.786 .15666 Mdot
.786 .15697 Mdot
.786 .15761 Mdot
.786 .15836 Mdot
.786 .15845 Mdot
.786 .1589 Mdot
.786 .15893 Mdot
.786 .15996 Mdot
.786 .16086 Mdot
.786 .16122 Mdot
.786 .16176 Mdot
.786 .16258 Mdot
.786 .16285 Mdot
.786 .16295 Mdot
.786 .16309 Mdot
.786 .16318 Mdot
.786 .16373 Mdot
.786 .16451 Mdot
.786 .16453 Mdot
.786 .16473 Mdot
.786 .16495 Mdot
.786 .16584 Mdot
.786 .16591 Mdot
.786 .16642 Mdot
.786 .16721 Mdot
.786 .16725 Mdot
.786 .16731 Mdot
.786 .16772 Mdot
.786 .16782 Mdot
.786 .16793 Mdot
.786 .1681 Mdot
.786 .16853 Mdot
.786 .16879 Mdot
.786 .16941 Mdot
.786 .16954 Mdot
.786 .16956 Mdot
.786 .1699 Mdot
.786 .17014 Mdot
.786 .1702 Mdot
.786 .17031 Mdot
.786 .17062 Mdot
.786 .17099 Mdot
.786 .17115 Mdot
.786 .17137 Mdot
.786 .17149 Mdot
.786 .17243 Mdot
.786 .1725 Mdot
.786 .17256 Mdot
.786 .17273 Mdot
.786 .17304 Mdot
.786 .17327 Mdot
.786 .17363 Mdot
.786 .17422 Mdot
.786 .17423 Mdot
.786 .1761 Mdot
.786 .17648 Mdot
.786 .17669 Mdot
.786 .17684 Mdot
.786 .17741 Mdot
.786 .1779 Mdot
.786 .17804 Mdot
.786 .17831 Mdot
.786 .17847 Mdot
.786 .17847 Mdot
.786 .17851 Mdot
.786 .17868 Mdot
.786 .17912 Mdot
.786 .1797 Mdot
.786 .17989 Mdot
.786 .18034 Mdot
.786 .18064 Mdot
.786 .18123 Mdot
.786 .18191 Mdot
.786 .18199 Mdot
.786 .18275 Mdot
.786 .18338 Mdot
.786 .18383 Mdot
.786 .18417 Mdot
.786 .18436 Mdot
.786 .18446 Mdot
.786 .18449 Mdot
.786 .18544 Mdot
.786 .18566 Mdot
.786 .18602 Mdot
.786 .18605 Mdot
.786 .18618 Mdot
.786 .18668 Mdot
.786 .18684 Mdot
.786 .18699 Mdot
.786 .18856 Mdot
.786 .18864 Mdot
.786 .18922 Mdot
.786 .18925 Mdot
.786 .18975 Mdot
.786 .19014 Mdot
.786 .19016 Mdot
.786 .19066 Mdot
.786 .19083 Mdot
.786 .1912 Mdot
.786 .19129 Mdot
.786 .19137 Mdot
.786 .19156 Mdot
.786 .19332 Mdot
.786 .19401 Mdot
.786 .19404 Mdot
.786 .19449 Mdot
.786 .19486 Mdot
.786 .19633 Mdot
.786 .19678 Mdot
.786 .197 Mdot
.786 .19753 Mdot
.786 .19867 Mdot
.786 .19881 Mdot
.786 .1989 Mdot
.786 .19923 Mdot
.786 .1994 Mdot
.786 .19973 Mdot
.786 .19984 Mdot
.786 .20013 Mdot
.786 .20029 Mdot
.786 .20146 Mdot
.786 .20155 Mdot
.786 .20254 Mdot
.786 .20268 Mdot
.786 .20292 Mdot
.786 .20437 Mdot
.786 .20454 Mdot
.786 .20458 Mdot
.786 .20512 Mdot
.786 .20527 Mdot
.786 .2056 Mdot
.786 .20572 Mdot
.786 .20593 Mdot
.786 .20629 Mdot
.786 .20659 Mdot
.786 .2066 Mdot
.786 .20688 Mdot
.786 .20691 Mdot
.786 .20736 Mdot
.786 .20818 Mdot
.786 .20893 Mdot
.786 .2093 Mdot
.786 .20941 Mdot
.786 .21046 Mdot
.786 .21163 Mdot
.786 .21181 Mdot
.786 .2121 Mdot
.786 .21312 Mdot
.786 .2138 Mdot
.786 .21398 Mdot
.786 .21443 Mdot
.786 .215 Mdot
.786 .21528 Mdot
.786 .21539 Mdot
.786 .21548 Mdot
.786 .2155 Mdot
.786 .21589 Mdot
.786 .216 Mdot
.786 .21655 Mdot
.786 .21794 Mdot
.786 .21803 Mdot
.786 .21825 Mdot
.786 .21841 Mdot
.786 .21856 Mdot
.786 .219 Mdot
.786 .219 Mdot
.786 .21905 Mdot
.786 .2191 Mdot
.786 .21914 Mdot
.786 .21924 Mdot
.786 .21932 Mdot
.786 .21968 Mdot
.786 .22072 Mdot
.786 .22209 Mdot
.786 .22258 Mdot
.786 .22279 Mdot
.786 .22334 Mdot
.786 .22411 Mdot
.786 .22446 Mdot
.786 .22493 Mdot
.786 .22509 Mdot
.786 .22523 Mdot
.786 .22555 Mdot
.786 .22589 Mdot
.786 .22712 Mdot
.786 .2278 Mdot
.786 .2279 Mdot
.786 .22792 Mdot
.786 .22822 Mdot
.786 .22864 Mdot
.786 .22868 Mdot
.786 .22873 Mdot
.786 .22923 Mdot
.786 .22953 Mdot
.786 .22962 Mdot
.786 .22986 Mdot
.786 .22993 Mdot
.786 .23138 Mdot
.786 .23147 Mdot
.786 .23171 Mdot
.786 .23172 Mdot
.786 .23302 Mdot
.786 .2332 Mdot
.786 .2334 Mdot
.786 .23356 Mdot
.786 .23407 Mdot
.786 .23423 Mdot
.786 .23505 Mdot
.786 .23551 Mdot
.786 .23586 Mdot
.786 .2361 Mdot
.786 .23614 Mdot
.786 .23626 Mdot
.786 .23631 Mdot
.786 .23688 Mdot
.786 .23715 Mdot
.786 .23726 Mdot
.786 .23785 Mdot
.786 .23834 Mdot
.786 .23935 Mdot
.786 .24052 Mdot
.786 .24066 Mdot
.786 .24137 Mdot
.786 .24142 Mdot
.786 .24303 Mdot
.786 .24372 Mdot
.786 .24445 Mdot
.786 .24501 Mdot
.786 .24587 Mdot
.786 .24643 Mdot
.786 .24651 Mdot
.786 .24715 Mdot
.786 .24758 Mdot
.786 .24774 Mdot
.786 .24797 Mdot
.786 .2481 Mdot
.786 .24828 Mdot
.786 .24896 Mdot
.786 .24973 Mdot
.786 .2502 Mdot
.786 .25022 Mdot
.786 .25054 Mdot
.786 .25088 Mdot
.786 .25186 Mdot
.786 .25228 Mdot
.786 .2524 Mdot
.786 .2532 Mdot
.786 .25444 Mdot
.786 .25449 Mdot
.786 .25459 Mdot
.786 .25524 Mdot
.786 .2554 Mdot
.786 .25542 Mdot
.786 .25557 Mdot
.786 .25584 Mdot
.786 .25651 Mdot
.786 .25692 Mdot
.786 .25717 Mdot
.786 .2579 Mdot
.786 .25803 Mdot
.786 .2581 Mdot
.786 .25813 Mdot
.786 .25867 Mdot
.786 .25905 Mdot
.786 .25914 Mdot
.786 .25931 Mdot
.786 .2598 Mdot
.786 .26009 Mdot
.786 .26037 Mdot
.786 .26063 Mdot
.786 .26097 Mdot
.786 .26117 Mdot
.786 .26264 Mdot
.786 .26275 Mdot
.786 .26285 Mdot
.786 .26311 Mdot
.786 .2636 Mdot
.786 .26396 Mdot
.786 .26452 Mdot
.786 .26453 Mdot
.786 .26505 Mdot
.786 .26541 Mdot
.786 .26546 Mdot
.786 .26547 Mdot
.786 .26668 Mdot
.786 .26736 Mdot
.786 .26841 Mdot
.786 .26864 Mdot
.786 .26901 Mdot
.786 .26907 Mdot
.786 .26933 Mdot
.786 .26957 Mdot
.786 .27019 Mdot
.786 .27046 Mdot
.786 .27081 Mdot
.786 .27124 Mdot
.786 .27146 Mdot
.786 .27189 Mdot
.786 .27213 Mdot
.786 .27214 Mdot
.786 .27219 Mdot
.786 .27246 Mdot
.786 .27315 Mdot
.786 .27408 Mdot
.786 .27437 Mdot
.786 .27508 Mdot
.786 .27537 Mdot
.786 .27556 Mdot
.786 .27571 Mdot
.786 .27648 Mdot
.786 .27754 Mdot
.786 .27768 Mdot
.786 .27887 Mdot
.786 .27955 Mdot
.786 .27986 Mdot
.786 .2801 Mdot
.786 .28057 Mdot
.786 .28109 Mdot
.786 .2814 Mdot
.786 .28155 Mdot
.786 .28159 Mdot
.786 .28309 Mdot
.786 .28344 Mdot
.786 .28401 Mdot
.786 .28405 Mdot
.786 .28426 Mdot
.786 .28504 Mdot
.786 .2853 Mdot
.786 .28553 Mdot
.786 .28799 Mdot
.786 .28812 Mdot
.786 .28903 Mdot
.786 .28909 Mdot
.786 .28987 Mdot
.786 .29049 Mdot
.786 .29052 Mdot
.786 .2913 Mdot
.786 .29157 Mdot
.786 .29216 Mdot
.786 .2923 Mdot
.786 .29241 Mdot
.786 .29271 Mdot
.786 .29548 Mdot
.786 .29657 Mdot
.786 .29661 Mdot
.786 .29732 Mdot
.786 .29791 Mdot
.786 .29877 Mdot
.786 .30021 Mdot
.786 .30092 Mdot
.786 .30127 Mdot
.786 .3021 Mdot
.786 .30389 Mdot
.786 .30411 Mdot
.786 .30425 Mdot
.786 .30477 Mdot
.786 .30504 Mdot
.786 .30556 Mdot
.786 .30574 Mdot
.786 .30619 Mdot
.786 .30644 Mdot
.786 .30829 Mdot
.786 .30842 Mdot
.786 .30998 Mdot
.786 .3102 Mdot
.786 .31057 Mdot
.786 .31285 Mdot
.786 .31312 Mdot
.786 .31318 Mdot
.786 .31403 Mdot
.786 .31426 Mdot
.786 .31479 Mdot
.786 .31498 Mdot
.786 .3153 Mdot
.786 .31588 Mdot
.786 .31634 Mdot
.786 .31636 Mdot
.786 .31679 Mdot
.786 .31685 Mdot
.786 .31755 Mdot
.786 .31884 Mdot
.786 .32002 Mdot
.786 .32061 Mdot
.786 .32078 Mdot
.786 .32243 Mdot
.786 .32427 Mdot
.786 .32454 Mdot
.786 .325 Mdot
.786 .3266 Mdot
.786 .32768 Mdot
.786 .32797 Mdot
.786 .32867 Mdot
.786 .32956 Mdot
.786 .33 Mdot
.786 .33017 Mdot
.786 .33031 Mdot
.786 .33035 Mdot
.786 .33096 Mdot
.786 .33113 Mdot
.786 .332 Mdot
.786 .33418 Mdot
.786 .33433 Mdot
.786 .33467 Mdot
.786 .33493 Mdot
.786 .33516 Mdot
.786 .33585 Mdot
.786 .33586 Mdot
.786 .33593 Mdot
.786 .33601 Mdot
.786 .33607 Mdot
.786 .33622 Mdot
.786 .33636 Mdot
.786 .33692 Mdot
.786 .33856 Mdot
.786 .34071 Mdot
.786 .34148 Mdot
.786 .34182 Mdot
.786 .34267 Mdot
.786 .34389 Mdot
.786 .34443 Mdot
.786 .34518 Mdot
.786 .34543 Mdot
.786 .34564 Mdot
.786 .34614 Mdot
.786 .34668 Mdot
.786 .34861 Mdot
.786 .34968 Mdot
.786 .34984 Mdot
.786 .34988 Mdot
.786 .35034 Mdot
.786 .35101 Mdot
.786 .35107 Mdot
.786 .35115 Mdot
.786 .35194 Mdot
.786 .3524 Mdot
.786 .35255 Mdot
.786 .35292 Mdot
.786 .35303 Mdot
.786 .35532 Mdot
.786 .35545 Mdot
.786 .35583 Mdot
.786 .35585 Mdot
.786 .35789 Mdot
.786 .35817 Mdot
.786 .35849 Mdot
.786 .35875 Mdot
.786 .35953 Mdot
.786 .35979 Mdot
.786 .36109 Mdot
.786 .36181 Mdot
.786 .36235 Mdot
.786 .36273 Mdot
.786 .36279 Mdot
.786 .36298 Mdot
.786 .36307 Mdot
.786 .36396 Mdot
.786 .36439 Mdot
.786 .36455 Mdot
.786 .36548 Mdot
.786 .36626 Mdot
.786 .36783 Mdot
.786 .36968 Mdot
.786 .3699 Mdot
.786 .37102 Mdot
.786 .3711 Mdot
.786 .37363 Mdot
.786 .3747 Mdot
.786 .37586 Mdot
.786 .37674 Mdot
.786 .37809 Mdot
.786 .37897 Mdot
.786 .3791 Mdot
.786 .38011 Mdot
.786 .38078 Mdot
.786 .38102 Mdot
.786 .38138 Mdot
.786 .3816 Mdot
.786 .38188 Mdot
.786 .38295 Mdot
.786 .38416 Mdot
.786 .38489 Mdot
.786 .38493 Mdot
.786 .38543 Mdot
.786 .38597 Mdot
.786 .38751 Mdot
.786 .38817 Mdot
.786 .38835 Mdot
.786 .38961 Mdot
.786 .39156 Mdot
.786 .39165 Mdot
.786 .3918 Mdot
.786 .39282 Mdot
.786 .39306 Mdot
.786 .3931 Mdot
.786 .39334 Mdot
.786 .39376 Mdot
.786 .39482 Mdot
.786 .39546 Mdot
.786 .39585 Mdot
.786 .397 Mdot
.786 .3972 Mdot
.786 .39732 Mdot
.786 .39736 Mdot
.786 .39821 Mdot
.786 .39881 Mdot
.786 .39896 Mdot
.786 .39923 Mdot
.786 .39998 Mdot
.786 .40045 Mdot
.786 .40089 Mdot
.786 .4013 Mdot
.786 .40183 Mdot
.786 .40214 Mdot
.786 .40446 Mdot
.786 .40463 Mdot
.786 .40478 Mdot
.786 .40519 Mdot
.786 .40596 Mdot
.786 .40653 Mdot
.786 .4074 Mdot
.786 .40743 Mdot
.786 .40824 Mdot
.786 .4088 Mdot
.786 .40889 Mdot
.786 .4089 Mdot
.786 .41081 Mdot
.786 .41187 Mdot
.786 .41353 Mdot
.786 .41389 Mdot
.786 .41447 Mdot
.786 .41457 Mdot
.786 .41498 Mdot
.786 .41535 Mdot
.786 .41632 Mdot
.786 .41675 Mdot
.786 .41729 Mdot
.786 .41798 Mdot
.786 .41831 Mdot
.786 .419 Mdot
.786 .41937 Mdot
.786 .41939 Mdot
.786 .41947 Mdot
.786 .41989 Mdot
.786 .42098 Mdot
.786 .42243 Mdot
.786 .42289 Mdot
.786 .42401 Mdot
.786 .42447 Mdot
.786 .42476 Mdot
.786 .425 Mdot
.786 .42621 Mdot
.786 .42788 Mdot
.786 .42809 Mdot
.786 .42997 Mdot
.786 .43104 Mdot
.786 .43152 Mdot
.786 .4319 Mdot
.786 .43264 Mdot
.786 .43346 Mdot
.786 .43394 Mdot
.786 .43418 Mdot
.786 .43425 Mdot
.786 .43661 Mdot
.786 .43716 Mdot
.786 .43805 Mdot
.786 .43811 Mdot
.786 .43844 Mdot
.786 .43967 Mdot
.786 .44007 Mdot
.786 .44044 Mdot
.786 .44431 Mdot
.786 .44451 Mdot
.786 .44594 Mdot
.786 .44603 Mdot
.786 .44725 Mdot
.786 .44823 Mdot
.786 .44828 Mdot
.786 .44951 Mdot
.786 .44993 Mdot
.786 .45085 Mdot
.786 .45107 Mdot
.786 .45125 Mdot
.786 .45172 Mdot
.786 .45607 Mdot
.786 .4578 Mdot
.786 .45785 Mdot
.786 .45897 Mdot
.786 .4599 Mdot
.786 .46125 Mdot
.786 .46352 Mdot
.786 .46463 Mdot
.786 .46518 Mdot
.786 .46649 Mdot
.786 .4693 Mdot
.786 .46964 Mdot
.786 .46987 Mdot
.786 .47068 Mdot
.786 .47111 Mdot
.786 .47193 Mdot
.786 .4722 Mdot
.786 .47291 Mdot
.786 .4733 Mdot
.786 .47621 Mdot
.786 .47642 Mdot
.786 .47887 Mdot
.786 .47922 Mdot
.788 .01476 Mdot
.788 .01478 Mdot
.788 .01482 Mdot
.788 .01488 Mdot
.788 .0149 Mdot
.788 .01497 Mdot
.788 .01501 Mdot
.788 .01512 Mdot
.788 .01518 Mdot
.788 .01535 Mdot
.788 .01545 Mdot
.788 .01572 Mdot
.788 .01587 Mdot
.788 .01629 Mdot
.788 .01654 Mdot
.788 .01657 Mdot
.788 .0172 Mdot
.788 .0173 Mdot
.788 .01759 Mdot
.788 .01765 Mdot
.788 .01861 Mdot
.788 .01863 Mdot
.788 .01863 Mdot
.788 .01878 Mdot
.788 .01879 Mdot
.788 .01908 Mdot
.788 .01924 Mdot
.788 .01933 Mdot
.788 .02065 Mdot
.788 .02085 Mdot
.788 .02088 Mdot
.788 .02089 Mdot
.788 .02111 Mdot
.788 .02114 Mdot
.788 .02159 Mdot
.788 .02163 Mdot
.788 .02185 Mdot
.788 .02195 Mdot
.788 .02199 Mdot
.788 .02407 Mdot
.788 .02439 Mdot
.788 .02444 Mdot
.788 .02444 Mdot
.788 .0248 Mdot
.788 .02484 Mdot
.788 .02502 Mdot
.788 .02555 Mdot
.788 .02561 Mdot
.788 .02596 Mdot
.788 .02612 Mdot
.788 .02619 Mdot
.788 .02701 Mdot
.788 .02865 Mdot
.788 .02946 Mdot
.788 .02996 Mdot
.788 .03004 Mdot
.788 .03005 Mdot
.788 .0305 Mdot
.788 .03061 Mdot
.788 .03068 Mdot
.788 .03095 Mdot
.788 .03096 Mdot
.788 .03179 Mdot
.788 .03189 Mdot
.788 .03243 Mdot
.788 .0327 Mdot
.788 .0328 Mdot
.788 .03357 Mdot
.788 .03409 Mdot
.788 .03512 Mdot
.788 .03524 Mdot
.788 .03567 Mdot
.788 .03608 Mdot
.788 .03668 Mdot
.788 .03762 Mdot
.788 .03791 Mdot
.788 .03795 Mdot
.788 .03874 Mdot
.788 .03886 Mdot
.788 .03888 Mdot
.788 .03959 Mdot
.788 .03976 Mdot
.788 .03987 Mdot
.788 .0403 Mdot
.788 .04032 Mdot
.788 .04153 Mdot
.788 .04162 Mdot
.788 .04178 Mdot
.788 .04182 Mdot
.788 .04263 Mdot
.788 .04305 Mdot
.788 .04321 Mdot
.788 .04428 Mdot
.788 .04444 Mdot
.788 .04525 Mdot
.788 .04619 Mdot
.788 .04662 Mdot
.788 .04688 Mdot
.788 .04706 Mdot
.788 .04774 Mdot
.788 .04817 Mdot
.788 .04838 Mdot
.788 .04895 Mdot
.788 .04913 Mdot
.788 .04933 Mdot
.788 .05062 Mdot
.788 .05082 Mdot
.788 .05127 Mdot
.788 .05133 Mdot
.788 .05228 Mdot
.788 .05257 Mdot
.788 .05277 Mdot
.788 .05279 Mdot
.788 .05288 Mdot
.788 .05392 Mdot
.788 .05419 Mdot
.788 .05436 Mdot
.788 .05476 Mdot
.788 .05478 Mdot
.788 .05504 Mdot
.788 .05508 Mdot
.788 .05671 Mdot
.788 .05698 Mdot
.788 .05711 Mdot
.788 .05737 Mdot
.788 .05743 Mdot
.788 .05872 Mdot
.788 .05889 Mdot
.788 .05937 Mdot
.788 .05963 Mdot
.788 .06043 Mdot
.788 .06052 Mdot
.788 .06116 Mdot
.788 .06122 Mdot
.788 .06131 Mdot
.788 .06131 Mdot
.788 .06156 Mdot
.788 .06284 Mdot
.788 .06305 Mdot
.788 .06432 Mdot
.788 .06458 Mdot
.788 .065 Mdot
.788 .0654 Mdot
.788 .06568 Mdot
.788 .06593 Mdot
.788 .06608 Mdot
.788 .06676 Mdot
.788 .06744 Mdot
.788 .06777 Mdot
.788 .06793 Mdot
.788 .06867 Mdot
.788 .06895 Mdot
.788 .06927 Mdot
.788 .06993 Mdot
.788 .0713 Mdot
.788 .07162 Mdot
.788 .07215 Mdot
.788 .07232 Mdot
.788 .07241 Mdot
.788 .07255 Mdot
.788 .07334 Mdot
.788 .07391 Mdot
.788 .07438 Mdot
.788 .07469 Mdot
.788 .07472 Mdot
.788 .07486 Mdot
.788 .07599 Mdot
.788 .0764 Mdot
.788 .07651 Mdot
.788 .07693 Mdot
.788 .07719 Mdot
.788 .07783 Mdot
.788 .07786 Mdot
.788 .07801 Mdot
.788 .07827 Mdot
.788 .07832 Mdot
.788 .07911 Mdot
.788 .07975 Mdot
.788 .0809 Mdot
.788 .0809 Mdot
.788 .08133 Mdot
.788 .08154 Mdot
.788 .08194 Mdot
.788 .08203 Mdot
.788 .08406 Mdot
.788 .08434 Mdot
.788 .08468 Mdot
.788 .0851 Mdot
.788 .08549 Mdot
.788 .08554 Mdot
.788 .08676 Mdot
.788 .08681 Mdot
.788 .0869 Mdot
.788 .08695 Mdot
.788 .08792 Mdot
.788 .088 Mdot
.788 .08814 Mdot
.788 .08815 Mdot
.788 .08854 Mdot
.788 .0897 Mdot
.788 .08994 Mdot
.788 .09028 Mdot
.788 .09055 Mdot
.788 .09089 Mdot
.788 .09096 Mdot
.788 .09224 Mdot
.788 .09289 Mdot
.788 .09331 Mdot
.788 .09396 Mdot
.788 .0946 Mdot
.788 .09504 Mdot
.788 .09542 Mdot
.788 .09567 Mdot
.788 .09674 Mdot
.788 .0978 Mdot
.788 .09809 Mdot
.788 .09833 Mdot
.788 .09858 Mdot
.788 .09888 Mdot
.788 .09975 Mdot
.788 .10018 Mdot
.788 .10051 Mdot
.788 .10069 Mdot
.788 .10079 Mdot
.788 .10159 Mdot
.788 .10173 Mdot
.788 .10194 Mdot
.788 .10241 Mdot
.788 .1025 Mdot
.788 .10389 Mdot
.788 .1042 Mdot
.788 .10439 Mdot
.788 .10448 Mdot
.788 .1048 Mdot
.788 .10485 Mdot
.788 .10517 Mdot
.788 .10523 Mdot
.788 .1055 Mdot
.788 .10565 Mdot
.788 .10586 Mdot
.788 .10677 Mdot
.788 .10711 Mdot
.788 .10714 Mdot
.788 .1075 Mdot
.788 .10801 Mdot
.788 .10838 Mdot
.788 .10871 Mdot
.788 .10874 Mdot
.788 .10881 Mdot
.788 .10924 Mdot
.788 .10929 Mdot
.788 .1095 Mdot
.788 .10971 Mdot
.788 .11042 Mdot
.788 .11103 Mdot
.788 .11113 Mdot
.788 .11129 Mdot
.788 .11193 Mdot
.788 .1121 Mdot
.788 .11276 Mdot
.788 .11318 Mdot
.788 .11351 Mdot
.788 .11418 Mdot
.788 .11423 Mdot
.788 .11447 Mdot
.788 .11488 Mdot
.788 .11496 Mdot
.788 .1162 Mdot
.788 .11663 Mdot
.788 .11696 Mdot
.788 .11705 Mdot
.788 .11709 Mdot
.788 .11721 Mdot
.788 .11871 Mdot
.788 .11892 Mdot
.788 .11902 Mdot
.788 .11902 Mdot
.788 .1197 Mdot
.788 .12003 Mdot
.788 .12067 Mdot
.788 .1208 Mdot
.788 .12111 Mdot
.788 .12169 Mdot
.788 .1229 Mdot
.788 .12369 Mdot
.788 .12401 Mdot
.788 .12427 Mdot
.788 .12444 Mdot
.788 .12498 Mdot
.788 .12564 Mdot
.788 .12626 Mdot
.788 .12633 Mdot
.788 .1265 Mdot
.788 .12657 Mdot
.788 .12772 Mdot
.788 .12825 Mdot
.788 .12834 Mdot
.788 .12848 Mdot
.788 .12855 Mdot
.788 .1286 Mdot
.788 .12877 Mdot
.788 .12901 Mdot
.788 .1292 Mdot
.788 .12969 Mdot
.788 .13008 Mdot
.788 .13022 Mdot
.788 .13043 Mdot
.788 .13044 Mdot
.788 .13103 Mdot
.788 .13106 Mdot
.788 .13108 Mdot
.788 .13187 Mdot
.788 .13217 Mdot
.788 .13233 Mdot
.788 .13289 Mdot
.788 .13327 Mdot
.788 .13347 Mdot
.788 .13352 Mdot
.788 .13381 Mdot
.788 .13424 Mdot
.788 .13442 Mdot
.788 .13475 Mdot
.788 .13476 Mdot
.788 .1348 Mdot
.788 .13487 Mdot
.788 .13528 Mdot
.788 .13561 Mdot
.788 .13639 Mdot
.788 .1369 Mdot
.788 .13791 Mdot
.788 .13858 Mdot
.788 .13897 Mdot
.788 .139 Mdot
.788 .13911 Mdot
.788 .13961 Mdot
.788 .14061 Mdot
.788 .14131 Mdot
.788 .14191 Mdot
.788 .14231 Mdot
.788 .14255 Mdot
.788 .14293 Mdot
.788 .14336 Mdot
.788 .14351 Mdot
.788 .14399 Mdot
.788 .14449 Mdot
.788 .14544 Mdot
.788 .14546 Mdot
.788 .14566 Mdot
.788 .14611 Mdot
.788 .1465 Mdot
.788 .14688 Mdot
.788 .14735 Mdot
.788 .14843 Mdot
.788 .14874 Mdot
.788 .14941 Mdot
.788 .14952 Mdot
.788 .14993 Mdot
.788 .15021 Mdot
.788 .15037 Mdot
.788 .15163 Mdot
.788 .15185 Mdot
.788 .15218 Mdot
.788 .15221 Mdot
.788 .15292 Mdot
.788 .15298 Mdot
.788 .15306 Mdot
.788 .15357 Mdot
.788 .15526 Mdot
.788 .15575 Mdot
.788 .15604 Mdot
.788 .15616 Mdot
.788 .15619 Mdot
.788 .15669 Mdot
.788 .15677 Mdot
.788 .15728 Mdot
.788 .15737 Mdot
.788 .15746 Mdot
.788 .15769 Mdot
.788 .1578 Mdot
.788 .15803 Mdot
.788 .15821 Mdot
.788 .15837 Mdot
.788 .159 Mdot
.788 .1598 Mdot
.788 .15991 Mdot
.788 .16033 Mdot
.788 .16038 Mdot
.788 .16094 Mdot
.788 .16109 Mdot
.788 .16175 Mdot
.788 .16232 Mdot
.788 .16233 Mdot
.788 .16263 Mdot
.788 .16285 Mdot
.788 .1629 Mdot
.788 .16296 Mdot
.788 .16301 Mdot
.788 .16369 Mdot
.788 .16376 Mdot
.788 .1641 Mdot
.788 .16411 Mdot
.788 .16443 Mdot
.788 .16444 Mdot
.788 .16456 Mdot
.788 .16551 Mdot
.788 .16554 Mdot
.788 .16652 Mdot
.788 .16662 Mdot
.788 .16666 Mdot
.788 .16691 Mdot
.788 .16716 Mdot
.788 .16792 Mdot
.788 .1682 Mdot
.788 .16923 Mdot
.788 .16989 Mdot
.788 .17028 Mdot
.788 .17042 Mdot
.788 .17085 Mdot
.788 .17147 Mdot
.788 .17155 Mdot
.788 .17193 Mdot
.788 .17228 Mdot
.788 .17257 Mdot
.788 .1727 Mdot
.788 .1735 Mdot
.788 .17365 Mdot
.788 .17401 Mdot
.788 .17436 Mdot
.788 .17466 Mdot
.788 .1748 Mdot
.788 .17534 Mdot
.788 .17537 Mdot
.788 .17585 Mdot
.788 .17599 Mdot
.788 .17606 Mdot
.788 .17625 Mdot
.788 .17724 Mdot
.788 .17747 Mdot
.788 .17758 Mdot
.788 .17861 Mdot
.788 .17895 Mdot
.788 .1791 Mdot
.788 .1791 Mdot
.788 .17947 Mdot
.788 .18003 Mdot
.788 .18017 Mdot
.788 .18031 Mdot
.788 .18069 Mdot
.788 .18106 Mdot
.788 .18169 Mdot
.788 .1819 Mdot
.788 .1824 Mdot
.788 .18331 Mdot
.788 .18493 Mdot
.788 .18521 Mdot
.788 .18581 Mdot
.788 .18623 Mdot
.788 .18647 Mdot
.788 .18647 Mdot
.788 .18696 Mdot
.788 .18737 Mdot
.788 .18764 Mdot
.788 .1885 Mdot
.788 .18953 Mdot
.788 .19026 Mdot
.788 .19051 Mdot
.788 .19062 Mdot
.788 .19089 Mdot
.788 .19096 Mdot
.788 .19099 Mdot
.788 .19136 Mdot
.788 .19161 Mdot
.788 .19221 Mdot
.788 .19221 Mdot
.788 .19282 Mdot
.788 .19351 Mdot
.788 .19365 Mdot
.788 .19366 Mdot
.788 .19379 Mdot
.788 .194 Mdot
.788 .19412 Mdot
.788 .1942 Mdot
.788 .19447 Mdot
.788 .19484 Mdot
.788 .19514 Mdot
.788 .19583 Mdot
.788 .19591 Mdot
.788 .19637 Mdot
.788 .19653 Mdot
.788 .19674 Mdot
.788 .19694 Mdot
.788 .19709 Mdot
.788 .1971 Mdot
.788 .19802 Mdot
.788 .19807 Mdot
.788 .19811 Mdot
.788 .19841 Mdot
.788 .19935 Mdot
.788 .19982 Mdot
.788 .19986 Mdot
.788 .20008 Mdot
.788 .20096 Mdot
.788 .20156 Mdot
.788 .20187 Mdot
.788 .20195 Mdot
.788 .20211 Mdot
.788 .20235 Mdot
.788 .20241 Mdot
.788 .20308 Mdot
.788 .20337 Mdot
.788 .2039 Mdot
.788 .20391 Mdot
.788 .20396 Mdot
.788 .20409 Mdot
.788 .20472 Mdot
.788 .20511 Mdot
.788 .20524 Mdot
.788 .20648 Mdot
.788 .20728 Mdot
.788 .20794 Mdot
.788 .20869 Mdot
.788 .20887 Mdot
.788 .20992 Mdot
.788 .21055 Mdot
.788 .21059 Mdot
.788 .21077 Mdot
.788 .21093 Mdot
.788 .21155 Mdot
.788 .21167 Mdot
.788 .21313 Mdot
.788 .21324 Mdot
.788 .21423 Mdot
.788 .215 Mdot
.788 .21518 Mdot
.788 .2158 Mdot
.788 .21611 Mdot
.788 .21618 Mdot
.788 .21679 Mdot
.788 .21745 Mdot
.788 .21769 Mdot
.788 .21845 Mdot
.788 .21846 Mdot
.788 .21924 Mdot
.788 .22012 Mdot
.788 .22073 Mdot
.788 .22077 Mdot
.788 .22103 Mdot
.788 .22105 Mdot
.788 .22109 Mdot
.788 .22179 Mdot
.788 .22241 Mdot
.788 .22295 Mdot
.788 .22301 Mdot
.788 .22375 Mdot
.788 .22456 Mdot
.788 .22545 Mdot
.788 .22562 Mdot
.788 .22593 Mdot
.788 .227 Mdot
.788 .22716 Mdot
.788 .22781 Mdot
.788 .22826 Mdot
.788 .22852 Mdot
.788 .22898 Mdot
.788 .2305 Mdot
.788 .23084 Mdot
.788 .23136 Mdot
.788 .23141 Mdot
.788 .23252 Mdot
.788 .23262 Mdot
.788 .23275 Mdot
.788 .23303 Mdot
.788 .23354 Mdot
.788 .2359 Mdot
.788 .23621 Mdot
.788 .23687 Mdot
.788 .23699 Mdot
.788 .23731 Mdot
.788 .23745 Mdot
.788 .23764 Mdot
.788 .23767 Mdot
.788 .23836 Mdot
.788 .23847 Mdot
.788 .2386 Mdot
.788 .23862 Mdot
.788 .23875 Mdot
.788 .23939 Mdot
.788 .23954 Mdot
.788 .23969 Mdot
.788 .24004 Mdot
.788 .24017 Mdot
.788 .24021 Mdot
.788 .24058 Mdot
.788 .24086 Mdot
.788 .24111 Mdot
.788 .24115 Mdot
.788 .24211 Mdot
.788 .24336 Mdot
.788 .24349 Mdot
.788 .24353 Mdot
.788 .24355 Mdot
.788 .2442 Mdot
.788 .24429 Mdot
.788 .24517 Mdot
.788 .2454 Mdot
.788 .24589 Mdot
.788 .24644 Mdot
.788 .24734 Mdot
.788 .24736 Mdot
.788 .24783 Mdot
.788 .24818 Mdot
.788 .24825 Mdot
.788 .24834 Mdot
.788 .24842 Mdot
.788 .24862 Mdot
.788 .24916 Mdot
.788 .24918 Mdot
.788 .2495 Mdot
.788 .24962 Mdot
.788 .24968 Mdot
.788 .25014 Mdot
.788 .25016 Mdot
.788 .25053 Mdot
.788 .25066 Mdot
.788 .25068 Mdot
.788 .25087 Mdot
.788 .251 Mdot
.788 .25132 Mdot
.788 .25236 Mdot
.788 .25237 Mdot
.788 .25241 Mdot
.788 .2538 Mdot
.788 .25395 Mdot
.788 .25412 Mdot
.788 .25418 Mdot
.788 .25458 Mdot
.788 .25496 Mdot
.788 .25497 Mdot
.788 .25617 Mdot
.788 .2566 Mdot
.788 .25769 Mdot
.788 .258 Mdot
.788 .25823 Mdot
.788 .25928 Mdot
.788 .2598 Mdot
.788 .25989 Mdot
.788 .2601 Mdot
.788 .26042 Mdot
.788 .26079 Mdot
.788 .26126 Mdot
.788 .26176 Mdot
.788 .26188 Mdot
.788 .26201 Mdot
.788 .26248 Mdot
.788 .26261 Mdot
.788 .26266 Mdot
.788 .26304 Mdot
.788 .26349 Mdot
.788 .2637 Mdot
.788 .26496 Mdot
.788 .26519 Mdot
.788 .26577 Mdot
.788 .26626 Mdot
.788 .26632 Mdot
.788 .26647 Mdot
.788 .26661 Mdot
.788 .26678 Mdot
.788 .26701 Mdot
.788 .26777 Mdot
.788 .26786 Mdot
.788 .2679 Mdot
.788 .26866 Mdot
.788 .26889 Mdot
.788 .269 Mdot
.788 .2693 Mdot
.788 .27086 Mdot
.788 .27121 Mdot
.788 .27139 Mdot
.788 .27148 Mdot
.788 .27301 Mdot
.788 .27329 Mdot
.788 .27345 Mdot
.788 .27355 Mdot
.788 .27379 Mdot
.788 .27379 Mdot
.788 .27432 Mdot
.788 .27437 Mdot
.788 .27525 Mdot
.788 .27547 Mdot
.788 .27569 Mdot
.788 .27629 Mdot
.788 .27687 Mdot
.788 .27778 Mdot
.788 .27787 Mdot
.788 .27821 Mdot
.788 .27899 Mdot
.788 .28013 Mdot
.788 .28043 Mdot
.788 .28133 Mdot
.788 .28163 Mdot
.788 .28226 Mdot
.788 .28297 Mdot
.788 .28342 Mdot
.788 .28436 Mdot
.788 .28503 Mdot
.788 .2854 Mdot
.788 .2854 Mdot
.788 .28617 Mdot
.788 .28682 Mdot
.788 .28724 Mdot
.788 .28859 Mdot
.788 .29022 Mdot
.788 .29138 Mdot
.788 .29177 Mdot
.788 .29195 Mdot
.788 .29237 Mdot
.788 .29248 Mdot
.788 .29253 Mdot
.788 .2931 Mdot
.788 .29349 Mdot
.788 .29444 Mdot
.788 .29445 Mdot
.788 .2954 Mdot
.788 .2965 Mdot
.788 .29672 Mdot
.788 .29673 Mdot
.788 .29693 Mdot
.788 .29727 Mdot
.788 .29746 Mdot
.788 .29759 Mdot
.788 .29801 Mdot
.788 .29859 Mdot
.788 .29906 Mdot
.788 .30015 Mdot
.788 .30028 Mdot
.788 .30101 Mdot
.788 .30125 Mdot
.788 .30159 Mdot
.788 .3019 Mdot
.788 .30214 Mdot
.788 .30216 Mdot
.788 .30361 Mdot
.788 .30369 Mdot
.788 .30374 Mdot
.788 .30421 Mdot
.788 .30571 Mdot
.788 .30643 Mdot
.788 .3065 Mdot
.788 .30685 Mdot
.788 .30824 Mdot
.788 .30919 Mdot
.788 .30967 Mdot
.788 .30979 Mdot
.788 .31005 Mdot
.788 .31042 Mdot
.788 .31052 Mdot
.788 .31158 Mdot
.788 .31204 Mdot
.788 .31287 Mdot
.788 .31288 Mdot
.788 .31297 Mdot
.788 .31316 Mdot
.788 .31416 Mdot
.788 .31478 Mdot
.788 .31499 Mdot
.788 .31693 Mdot
.788 .3182 Mdot
.788 .31924 Mdot
.788 .32041 Mdot
.788 .32071 Mdot
.788 .32236 Mdot
.788 .32335 Mdot
.788 .32342 Mdot
.788 .32369 Mdot
.788 .32395 Mdot
.788 .32493 Mdot
.788 .32511 Mdot
.788 .32741 Mdot
.788 .32759 Mdot
.788 .32916 Mdot
.788 .33037 Mdot
.788 .33064 Mdot
.788 .33162 Mdot
.788 .33212 Mdot
.788 .33223 Mdot
.788 .33318 Mdot
.788 .33423 Mdot
.788 .33461 Mdot
.788 .33581 Mdot
.788 .33582 Mdot
.788 .33704 Mdot
.788 .33843 Mdot
.788 .3394 Mdot
.788 .33946 Mdot
.788 .33987 Mdot
.788 .3399 Mdot
.788 .33996 Mdot
.788 .34106 Mdot
.788 .34204 Mdot
.788 .34289 Mdot
.788 .34299 Mdot
.788 .34416 Mdot
.788 .34543 Mdot
.788 .34684 Mdot
.788 .34709 Mdot
.788 .34759 Mdot
.788 .34928 Mdot
.788 .34953 Mdot
.788 .35056 Mdot
.788 .35126 Mdot
.788 .35166 Mdot
.788 .35239 Mdot
.788 .35479 Mdot
.788 .35533 Mdot
.788 .35614 Mdot
.788 .35623 Mdot
.788 .35798 Mdot
.788 .35813 Mdot
.788 .35834 Mdot
.788 .35877 Mdot
.788 .35959 Mdot
.788 .3633 Mdot
.788 .3638 Mdot
.788 .36484 Mdot
.788 .36501 Mdot
.788 .36552 Mdot
.788 .36574 Mdot
.788 .36604 Mdot
.788 .3661 Mdot
.788 .36718 Mdot
.788 .36735 Mdot
.788 .36756 Mdot
.788 .36759 Mdot
.788 .36779 Mdot
.788 .36881 Mdot
.788 .36904 Mdot
.788 .36927 Mdot
.788 .36983 Mdot
.788 .37004 Mdot
.788 .3701 Mdot
.788 .37067 Mdot
.788 .37112 Mdot
.788 .37151 Mdot
.788 .37157 Mdot
.788 .37308 Mdot
.788 .37506 Mdot
.788 .37527 Mdot
.788 .37533 Mdot
.788 .37536 Mdot
.788 .37638 Mdot
.788 .37652 Mdot
.788 .37791 Mdot
.788 .37828 Mdot
.788 .37904 Mdot
.788 .37991 Mdot
.788 .38133 Mdot
.788 .38137 Mdot
.788 .3821 Mdot
.788 .38266 Mdot
.788 .38277 Mdot
.788 .38292 Mdot
.788 .38304 Mdot
.788 .38335 Mdot
.788 .3842 Mdot
.788 .38423 Mdot
.788 .38473 Mdot
.788 .38492 Mdot
.788 .38503 Mdot
.788 .38575 Mdot
.788 .38578 Mdot
.788 .38635 Mdot
.788 .38656 Mdot
.788 .38659 Mdot
.788 .38689 Mdot
.788 .38711 Mdot
.788 .3876 Mdot
.788 .38924 Mdot
.788 .38926 Mdot
.788 .38933 Mdot
.788 .39151 Mdot
.788 .39175 Mdot
.788 .39202 Mdot
.788 .39212 Mdot
.788 .39274 Mdot
.788 .39334 Mdot
.788 .39336 Mdot
.788 .39524 Mdot
.788 .39593 Mdot
.788 .39764 Mdot
.788 .39813 Mdot
.788 .3985 Mdot
.788 .40015 Mdot
.788 .40097 Mdot
.788 .40112 Mdot
.788 .40145 Mdot
.788 .40195 Mdot
.788 .40253 Mdot
.788 .40327 Mdot
.788 .40405 Mdot
.788 .40425 Mdot
.788 .40446 Mdot
.788 .40519 Mdot
.788 .4054 Mdot
.788 .40547 Mdot
.788 .40608 Mdot
.788 .40678 Mdot
.788 .40712 Mdot
.788 .40911 Mdot
.788 .40947 Mdot
.788 .41038 Mdot
.788 .41115 Mdot
.788 .41124 Mdot
.788 .41147 Mdot
.788 .41169 Mdot
.788 .41197 Mdot
.788 .41233 Mdot
.788 .41352 Mdot
.788 .41367 Mdot
.788 .41373 Mdot
.788 .41494 Mdot
.788 .41529 Mdot
.788 .41547 Mdot
.788 .41594 Mdot
.788 .4184 Mdot
.788 .41896 Mdot
.788 .41923 Mdot
.788 .41938 Mdot
.788 .42179 Mdot
.788 .42223 Mdot
.788 .42248 Mdot
.788 .42264 Mdot
.788 .42302 Mdot
.788 .42302 Mdot
.788 .42385 Mdot
.788 .42394 Mdot
.788 .42532 Mdot
.788 .42566 Mdot
.788 .42602 Mdot
.788 .42695 Mdot
.788 .42787 Mdot
.788 .4293 Mdot
.788 .42945 Mdot
.788 .43121 Mdot
.788 .433 Mdot
.788 .43347 Mdot
.788 .4349 Mdot
.788 .43537 Mdot
.788 .43636 Mdot
.788 .43748 Mdot
.788 .43819 Mdot
.788 .43968 Mdot
.788 .44073 Mdot
.788 .44131 Mdot
.788 .44132 Mdot
.788 .44252 Mdot
.788 .44355 Mdot
.788 .44422 Mdot
.788 .44635 Mdot
.788 .44892 Mdot
.788 .45074 Mdot
.788 .45136 Mdot
.788 .45164 Mdot
.788 .4523 Mdot
.788 .45247 Mdot
.788 .45255 Mdot
.788 .45345 Mdot
.788 .45407 Mdot
.788 .45556 Mdot
.788 .45558 Mdot
.788 .45708 Mdot
.788 .45881 Mdot
.788 .45915 Mdot
.788 .45917 Mdot
.788 .45949 Mdot
.788 .46002 Mdot
.788 .46033 Mdot
.788 .46053 Mdot
.788 .46118 Mdot
.788 .4621 Mdot
.788 .46284 Mdot
.788 .46457 Mdot
.788 .46476 Mdot
.788 .46591 Mdot
.788 .4663 Mdot
.788 .46683 Mdot
.788 .46731 Mdot
.788 .46769 Mdot
.788 .46772 Mdot
.788 .47001 Mdot
.788 .47014 Mdot
.788 .47023 Mdot
.788 .47096 Mdot
.788 .47332 Mdot
.788 .47447 Mdot
.788 .47457 Mdot
.788 .47512 Mdot
.788 .47731 Mdot
.788 .4788 Mdot
.788 .47957 Mdot
.788 .47976 Mdot
.788 .48016 Mdot
.79 .01527 Mdot
.79 .01558 Mdot
.79 .01596 Mdot
.79 .01609 Mdot
.79 .01668 Mdot
.79 .01688 Mdot
.79 .01726 Mdot
.79 .01783 Mdot
.79 .01814 Mdot
.79 .01873 Mdot
.79 .01963 Mdot
.79 .01983 Mdot
.79 .02013 Mdot
.79 .02106 Mdot
.79 .0211 Mdot
.79 .02158 Mdot
.79 .02175 Mdot
.79 .02202 Mdot
.79 .02248 Mdot
.79 .02279 Mdot
.79 .02303 Mdot
.79 .02327 Mdot
.79 .02417 Mdot
.79 .02473 Mdot
.79 .02475 Mdot
.79 .02481 Mdot
.79 .02556 Mdot
.79 .02583 Mdot
.79 .0261 Mdot
.79 .02617 Mdot
.79 .02625 Mdot
.79 .02627 Mdot
.79 .02699 Mdot
.79 .02704 Mdot
.79 .02734 Mdot
.79 .02747 Mdot
.79 .02784 Mdot
.79 .028 Mdot
.79 .02823 Mdot
.79 .02915 Mdot
.79 .02966 Mdot
.79 .03053 Mdot
.79 .03056 Mdot
.79 .03062 Mdot
.79 .03066 Mdot
.79 .03185 Mdot
.79 .03228 Mdot
.79 .0327 Mdot
.79 .03282 Mdot
.79 .03295 Mdot
.79 .03298 Mdot
.79 .03354 Mdot
.79 .03411 Mdot
.79 .03419 Mdot
.79 .03466 Mdot
.79 .03485 Mdot
.79 .03487 Mdot
.79 .03546 Mdot
.79 .0357 Mdot
.79 .03586 Mdot
.79 .03608 Mdot
.79 .03623 Mdot
.79 .03629 Mdot
.79 .03753 Mdot
.79 .0378 Mdot
.79 .03832 Mdot
.79 .03971 Mdot
.79 .03976 Mdot
.79 .03984 Mdot
.79 .03991 Mdot
.79 .04112 Mdot
.79 .04179 Mdot
.79 .04182 Mdot
.79 .04247 Mdot
.79 .04249 Mdot
.79 .04283 Mdot
.79 .04306 Mdot
.79 .04313 Mdot
.79 .04331 Mdot
.79 .04352 Mdot
.79 .04355 Mdot
.79 .04357 Mdot
.79 .04433 Mdot
.79 .04446 Mdot
.79 .04462 Mdot
.79 .04535 Mdot
.79 .04549 Mdot
.79 .04623 Mdot
.79 .04653 Mdot
.79 .04657 Mdot
.79 .0466 Mdot
.79 .04749 Mdot
.79 .04787 Mdot
.79 .04793 Mdot
.79 .04813 Mdot
.79 .04846 Mdot
.79 .04871 Mdot
.79 .04881 Mdot
.79 .04897 Mdot
.79 .05065 Mdot
.79 .05075 Mdot
.79 .05118 Mdot
.79 .05145 Mdot
.79 .05201 Mdot
.79 .05244 Mdot
.79 .05259 Mdot
.79 .05421 Mdot
.79 .05428 Mdot
.79 .05442 Mdot
.79 .05453 Mdot
.79 .05532 Mdot
.79 .05643 Mdot
.79 .05694 Mdot
.79 .05747 Mdot
.79 .0575 Mdot
.79 .05754 Mdot
.79 .05857 Mdot
.79 .0586 Mdot
.79 .05914 Mdot
.79 .0595 Mdot
.79 .05961 Mdot
.79 .0599 Mdot
.79 .06023 Mdot
.79 .06028 Mdot
.79 .06031 Mdot
.79 .0615 Mdot
.79 .06171 Mdot
.79 .06197 Mdot
.79 .06312 Mdot
.79 .06332 Mdot
.79 .06333 Mdot
.79 .06435 Mdot
.79 .0645 Mdot
.79 .06498 Mdot
.79 .06504 Mdot
.79 .06509 Mdot
.79 .06553 Mdot
.79 .06645 Mdot
.79 .0665 Mdot
.79 .0671 Mdot
.79 .0672 Mdot
.79 .06732 Mdot
.79 .06741 Mdot
.79 .06751 Mdot
.79 .068 Mdot
.79 .06804 Mdot
.79 .06842 Mdot
.79 .06858 Mdot
.79 .06884 Mdot
.79 .06902 Mdot
.79 .0715 Mdot
.79 .07166 Mdot
.79 .07209 Mdot
.79 .07219 Mdot
.79 .07227 Mdot
.79 .07233 Mdot
.79 .0726 Mdot
.79 .07276 Mdot
.79 .07365 Mdot
.79 .07383 Mdot
.79 .07432 Mdot
.79 .07456 Mdot
.79 .07473 Mdot
.79 .07638 Mdot
.79 .07668 Mdot
.79 .07684 Mdot
.79 .07711 Mdot
.79 .07723 Mdot
.79 .07729 Mdot
.79 .07745 Mdot
.79 .07761 Mdot
.79 .0779 Mdot
.79 .07885 Mdot
.79 .07886 Mdot
.79 .08052 Mdot
.79 .08063 Mdot
.79 .08143 Mdot
.79 .08146 Mdot
.79 .08224 Mdot
.79 .08227 Mdot
.79 .08231 Mdot
.79 .08238 Mdot
.79 .08357 Mdot
.79 .084 Mdot
.79 .08406 Mdot
.79 .08436 Mdot
.79 .08484 Mdot
.79 .08491 Mdot
.79 .08548 Mdot
.79 .08565 Mdot
.79 .08587 Mdot
.79 .08611 Mdot
.79 .08663 Mdot
.79 .08671 Mdot
.79 .08675 Mdot
.79 .08736 Mdot
.79 .08864 Mdot
.79 .08896 Mdot
.79 .08938 Mdot
.79 .0894 Mdot
.79 .08988 Mdot
.79 .0912 Mdot
.79 .09152 Mdot
.79 .09153 Mdot
.79 .09313 Mdot
.79 .09314 Mdot
.79 .09338 Mdot
.79 .09414 Mdot
.79 .09423 Mdot
.79 .09431 Mdot
.79 .09501 Mdot
.79 .09545 Mdot
.79 .09573 Mdot
.79 .09645 Mdot
.79 .09654 Mdot
.79 .09748 Mdot
.79 .09764 Mdot
.79 .09783 Mdot
.79 .09798 Mdot
.79 .09814 Mdot
.79 .09889 Mdot
.79 .0989 Mdot
.79 .09897 Mdot
.79 .09957 Mdot
.79 .09962 Mdot
.79 .09982 Mdot
.79 .09997 Mdot
.79 .10024 Mdot
.79 .10051 Mdot
.79 .10263 Mdot
.79 .10443 Mdot
.79 .10464 Mdot
.79 .10468 Mdot
.79 .10496 Mdot
.79 .10531 Mdot
.79 .10537 Mdot
.79 .10552 Mdot
.79 .10566 Mdot
.79 .10575 Mdot
.79 .10617 Mdot
.79 .10642 Mdot
.79 .10666 Mdot
.79 .10666 Mdot
.79 .10775 Mdot
.79 .10783 Mdot
.79 .10798 Mdot
.79 .10812 Mdot
.79 .10823 Mdot
.79 .10879 Mdot
.79 .10889 Mdot
.79 .10927 Mdot
.79 .10954 Mdot
.79 .10994 Mdot
.79 .11034 Mdot
.79 .1114 Mdot
.79 .11211 Mdot
.79 .11215 Mdot
.79 .11251 Mdot
.79 .11262 Mdot
.79 .11279 Mdot
.79 .11288 Mdot
.79 .1133 Mdot
.79 .11345 Mdot
.79 .11348 Mdot
.79 .11359 Mdot
.79 .11383 Mdot
.79 .1141 Mdot
.79 .11428 Mdot
.79 .11454 Mdot
.79 .11487 Mdot
.79 .11551 Mdot
.79 .11569 Mdot
.79 .11604 Mdot
.79 .11607 Mdot
.79 .11748 Mdot
.79 .11781 Mdot
.79 .11868 Mdot
.79 .11886 Mdot
.79 .11903 Mdot
.79 .12012 Mdot
.79 .12018 Mdot
.79 .12052 Mdot
.79 .12056 Mdot
.79 .12073 Mdot
.79 .1214 Mdot
.79 .12145 Mdot
.79 .12152 Mdot
.79 .12163 Mdot
.79 .12351 Mdot
.79 .12413 Mdot
.79 .12418 Mdot
.79 .12428 Mdot
.79 .12475 Mdot
.79 .12492 Mdot
.79 .12551 Mdot
.79 .12562 Mdot
.79 .12652 Mdot
.79 .12679 Mdot
.79 .12714 Mdot
.79 .12733 Mdot
.79 .12752 Mdot
.79 .1278 Mdot
.79 .12819 Mdot
.79 .12834 Mdot
.79 .12846 Mdot
.79 .12854 Mdot
.79 .12875 Mdot
.79 .12892 Mdot
.79 .1295 Mdot
.79 .12962 Mdot
.79 .13027 Mdot
.79 .13034 Mdot
.79 .13151 Mdot
.79 .13192 Mdot
.79 .13203 Mdot
.79 .13262 Mdot
.79 .13268 Mdot
.79 .13271 Mdot
.79 .1333 Mdot
.79 .13347 Mdot
.79 .1338 Mdot
.79 .13445 Mdot
.79 .1349 Mdot
.79 .13526 Mdot
.79 .13556 Mdot
.79 .13606 Mdot
.79 .13609 Mdot
.79 .13628 Mdot
.79 .13682 Mdot
.79 .13852 Mdot
.79 .13861 Mdot
.79 .13863 Mdot
.79 .13901 Mdot
.79 .1402 Mdot
.79 .14034 Mdot
.79 .14047 Mdot
.79 .14067 Mdot
.79 .141 Mdot
.79 .14124 Mdot
.79 .14158 Mdot
.79 .14227 Mdot
.79 .14272 Mdot
.79 .14345 Mdot
.79 .14386 Mdot
.79 .144 Mdot
.79 .14548 Mdot
.79 .14574 Mdot
.79 .14604 Mdot
.79 .14627 Mdot
.79 .1465 Mdot
.79 .14652 Mdot
.79 .14667 Mdot
.79 .14693 Mdot
.79 .1477 Mdot
.79 .14773 Mdot
.79 .14775 Mdot
.79 .14783 Mdot
.79 .14837 Mdot
.79 .14879 Mdot
.79 .14887 Mdot
.79 .14902 Mdot
.79 .14918 Mdot
.79 .14942 Mdot
.79 .14984 Mdot
.79 .15008 Mdot
.79 .15028 Mdot
.79 .15094 Mdot
.79 .15209 Mdot
.79 .15221 Mdot
.79 .15363 Mdot
.79 .1545 Mdot
.79 .15477 Mdot
.79 .15545 Mdot
.79 .15596 Mdot
.79 .15613 Mdot
.79 .15647 Mdot
.79 .1568 Mdot
.79 .15687 Mdot
.79 .15701 Mdot
.79 .1573 Mdot
.79 .15767 Mdot
.79 .15785 Mdot
.79 .15795 Mdot
.79 .15802 Mdot
.79 .15819 Mdot
.79 .1584 Mdot
.79 .15855 Mdot
.79 .15871 Mdot
.79 .15876 Mdot
.79 .15921 Mdot
.79 .1593 Mdot
.79 .15961 Mdot
.79 .15998 Mdot
.79 .15999 Mdot
.79 .1609 Mdot
.79 .16171 Mdot
.79 .16183 Mdot
.79 .16193 Mdot
.79 .16207 Mdot
.79 .16211 Mdot
.79 .16229 Mdot
.79 .16247 Mdot
.79 .16287 Mdot
.79 .16305 Mdot
.79 .16335 Mdot
.79 .16352 Mdot
.79 .16363 Mdot
.79 .16372 Mdot
.79 .16411 Mdot
.79 .16455 Mdot
.79 .16518 Mdot
.79 .16524 Mdot
.79 .1658 Mdot
.79 .16657 Mdot
.79 .16668 Mdot
.79 .16689 Mdot
.79 .16704 Mdot
.79 .16748 Mdot
.79 .16802 Mdot
.79 .1686 Mdot
.79 .16867 Mdot
.79 .16897 Mdot
.79 .16901 Mdot
.79 .16923 Mdot
.79 .1694 Mdot
.79 .16967 Mdot
.79 .16968 Mdot
.79 .16981 Mdot
.79 .17048 Mdot
.79 .17072 Mdot
.79 .17077 Mdot
.79 .17094 Mdot
.79 .17132 Mdot
.79 .17166 Mdot
.79 .17169 Mdot
.79 .17174 Mdot
.79 .17202 Mdot
.79 .17245 Mdot
.79 .17295 Mdot
.79 .17397 Mdot
.79 .17426 Mdot
.79 .17481 Mdot
.79 .17486 Mdot
.79 .1757 Mdot
.79 .17682 Mdot
.79 .17709 Mdot
.79 .17761 Mdot
.79 .17898 Mdot
.79 .17901 Mdot
.79 .17905 Mdot
.79 .17919 Mdot
.79 .17926 Mdot
.79 .17954 Mdot
.79 .18014 Mdot
.79 .18125 Mdot
.79 .18135 Mdot
.79 .18189 Mdot
.79 .18195 Mdot
.79 .18222 Mdot
.79 .18252 Mdot
.79 .18265 Mdot
.79 .18328 Mdot
.79 .18336 Mdot
.79 .18346 Mdot
.79 .18364 Mdot
.79 .18661 Mdot
.79 .18691 Mdot
.79 .1876 Mdot
.79 .18768 Mdot
.79 .18783 Mdot
.79 .18798 Mdot
.79 .18857 Mdot
.79 .18883 Mdot
.79 .18923 Mdot
.79 .18977 Mdot
.79 .18994 Mdot
.79 .19005 Mdot
.79 .19137 Mdot
.79 .1918 Mdot
.79 .19234 Mdot
.79 .19265 Mdot
.79 .19295 Mdot
.79 .19339 Mdot
.79 .194 Mdot
.79 .19424 Mdot
.79 .19444 Mdot
.79 .19456 Mdot
.79 .1949 Mdot
.79 .19516 Mdot
.79 .19545 Mdot
.79 .19557 Mdot
.79 .19573 Mdot
.79 .19607 Mdot
.79 .19627 Mdot
.79 .19627 Mdot
.79 .19654 Mdot
.79 .19729 Mdot
.79 .1974 Mdot
.79 .19766 Mdot
.79 .19833 Mdot
.79 .19925 Mdot
.79 .1999 Mdot
.79 .20002 Mdot
.79 .20007 Mdot
.79 .201 Mdot
.79 .2011 Mdot
.79 .20115 Mdot
.79 .20208 Mdot
.79 .20235 Mdot
.79 .20287 Mdot
.79 .2039 Mdot
.79 .20441 Mdot
.79 .2046 Mdot
.79 .20467 Mdot
.79 .20478 Mdot
.79 .20518 Mdot
.79 .20564 Mdot
.79 .20587 Mdot
.79 .20641 Mdot
.79 .20644 Mdot
.79 .20649 Mdot
.79 .20679 Mdot
.79 .20691 Mdot
.79 .20717 Mdot
.79 .20764 Mdot
.79 .20823 Mdot
.79 .2094 Mdot
.79 .20992 Mdot
.79 .21033 Mdot
.79 .21047 Mdot
.79 .2105 Mdot
.79 .2111 Mdot
.79 .21243 Mdot
.79 .21271 Mdot
.79 .21298 Mdot
.79 .21312 Mdot
.79 .21321 Mdot
.79 .21341 Mdot
.79 .21372 Mdot
.79 .21384 Mdot
.79 .21463 Mdot
.79 .21516 Mdot
.79 .21558 Mdot
.79 .21625 Mdot
.79 .21657 Mdot
.79 .21697 Mdot
.79 .21703 Mdot
.79 .21812 Mdot
.79 .21877 Mdot
.79 .21898 Mdot
.79 .22133 Mdot
.79 .22174 Mdot
.79 .22221 Mdot
.79 .22258 Mdot
.79 .22293 Mdot
.79 .22297 Mdot
.79 .2232 Mdot
.79 .22361 Mdot
.79 .22484 Mdot
.79 .22488 Mdot
.79 .22491 Mdot
.79 .22504 Mdot
.79 .22554 Mdot
.79 .2259 Mdot
.79 .22656 Mdot
.79 .22668 Mdot
.79 .22674 Mdot
.79 .22692 Mdot
.79 .22716 Mdot
.79 .22754 Mdot
.79 .22821 Mdot
.79 .22859 Mdot
.79 .2289 Mdot
.79 .22944 Mdot
.79 .22975 Mdot
.79 .22994 Mdot
.79 .23036 Mdot
.79 .23096 Mdot
.79 .23177 Mdot
.79 .23196 Mdot
.79 .23327 Mdot
.79 .23419 Mdot
.79 .23431 Mdot
.79 .23557 Mdot
.79 .23587 Mdot
.79 .23601 Mdot
.79 .23707 Mdot
.79 .23788 Mdot
.79 .238 Mdot
.79 .23814 Mdot
.79 .23868 Mdot
.79 .23869 Mdot
.79 .23912 Mdot
.79 .23921 Mdot
.79 .23932 Mdot
.79 .23954 Mdot
.79 .24 Mdot
.79 .24058 Mdot
.79 .24087 Mdot
.79 .24103 Mdot
.79 .24114 Mdot
.79 .24141 Mdot
.79 .24174 Mdot
.79 .24197 Mdot
.79 .24223 Mdot
.79 .2423 Mdot
.79 .24302 Mdot
.79 .24315 Mdot
.79 .24364 Mdot
.79 .24424 Mdot
.79 .24425 Mdot
.79 .24432 Mdot
.79 .24569 Mdot
.79 .246 Mdot
.79 .24697 Mdot
.79 .24716 Mdot
.79 .24731 Mdot
.79 .24754 Mdot
.79 .2476 Mdot
.79 .24788 Mdot
.79 .24814 Mdot
.79 .24817 Mdot
.79 .2488 Mdot
.79 .24908 Mdot
.79 .24936 Mdot
.79 .24956 Mdot
.79 .24982 Mdot
.79 .25 Mdot
.79 .25014 Mdot
.79 .25055 Mdot
.79 .25077 Mdot
.79 .25145 Mdot
.79 .25231 Mdot
.79 .25244 Mdot
.79 .25254 Mdot
.79 .25342 Mdot
.79 .25464 Mdot
.79 .25471 Mdot
.79 .25482 Mdot
.79 .25515 Mdot
.79 .2554 Mdot
.79 .25566 Mdot
.79 .25608 Mdot
.79 .25642 Mdot
.79 .25689 Mdot
.79 .25693 Mdot
.79 .25785 Mdot
.79 .25796 Mdot
.79 .25823 Mdot
.79 .25843 Mdot
.79 .2585 Mdot
.79 .25885 Mdot
.79 .25912 Mdot
.79 .25926 Mdot
.79 .25954 Mdot
.79 .25956 Mdot
.79 .25977 Mdot
.79 .26041 Mdot
.79 .26082 Mdot
.79 .2609 Mdot
.79 .2612 Mdot
.79 .26127 Mdot
.79 .26151 Mdot
.79 .26154 Mdot
.79 .26215 Mdot
.79 .26268 Mdot
.79 .26273 Mdot
.79 .26281 Mdot
.79 .26287 Mdot
.79 .26326 Mdot
.79 .26364 Mdot
.79 .26366 Mdot
.79 .26393 Mdot
.79 .26472 Mdot
.79 .26473 Mdot
.79 .26634 Mdot
.79 .26679 Mdot
.79 .26767 Mdot
.79 .26768 Mdot
.79 .26774 Mdot
.79 .26812 Mdot
.79 .26907 Mdot
.79 .26913 Mdot
.79 .27083 Mdot
.79 .27126 Mdot
.79 .27176 Mdot
.79 .27209 Mdot
.79 .27425 Mdot
.79 .2743 Mdot
.79 .27436 Mdot
.79 .27458 Mdot
.79 .27469 Mdot
.79 .27514 Mdot
.79 .27541 Mdot
.79 .27608 Mdot
.79 .27784 Mdot
.79 .27795 Mdot
.79 .27799 Mdot
.79 .27843 Mdot
.79 .27865 Mdot
.79 .27884 Mdot
.79 .27895 Mdot
.79 .27937 Mdot
.79 .27984 Mdot
.79 .28005 Mdot
.79 .28106 Mdot
.79 .28117 Mdot
.79 .28133 Mdot
.79 .28162 Mdot
.79 .28232 Mdot
.79 .28271 Mdot
.79 .2829 Mdot
.79 .2863 Mdot
.79 .28679 Mdot
.79 .28787 Mdot
.79 .28799 Mdot
.79 .28824 Mdot
.79 .28848 Mdot
.79 .2894 Mdot
.79 .28982 Mdot
.79 .29044 Mdot
.79 .2913 Mdot
.79 .29157 Mdot
.79 .29175 Mdot
.79 .29383 Mdot
.79 .2945 Mdot
.79 .29536 Mdot
.79 .29585 Mdot
.79 .29633 Mdot
.79 .29703 Mdot
.79 .29799 Mdot
.79 .29837 Mdot
.79 .29868 Mdot
.79 .29886 Mdot
.79 .2994 Mdot
.79 .29981 Mdot
.79 .30028 Mdot
.79 .30047 Mdot
.79 .30071 Mdot
.79 .30126 Mdot
.79 .30157 Mdot
.79 .30158 Mdot
.79 .302 Mdot
.79 .30319 Mdot
.79 .30336 Mdot
.79 .30377 Mdot
.79 .30482 Mdot
.79 .30628 Mdot
.79 .3073 Mdot
.79 .30749 Mdot
.79 .30758 Mdot
.79 .30905 Mdot
.79 .30921 Mdot
.79 .30928 Mdot
.79 .31074 Mdot
.79 .31118 Mdot
.79 .31201 Mdot
.79 .31363 Mdot
.79 .31444 Mdot
.79 .31474 Mdot
.79 .31485 Mdot
.79 .31502 Mdot
.79 .31566 Mdot
.79 .31638 Mdot
.79 .31673 Mdot
.79 .3176 Mdot
.79 .31765 Mdot
.79 .31771 Mdot
.79 .3182 Mdot
.79 .31839 Mdot
.79 .3188 Mdot
.79 .31953 Mdot
.79 .32046 Mdot
.79 .32231 Mdot
.79 .32314 Mdot
.79 .32378 Mdot
.79 .32401 Mdot
.79 .32405 Mdot
.79 .325 Mdot
.79 .32711 Mdot
.79 .32755 Mdot
.79 .32798 Mdot
.79 .32819 Mdot
.79 .32834 Mdot
.79 .32865 Mdot
.79 .32914 Mdot
.79 .32933 Mdot
.79 .33057 Mdot
.79 .33142 Mdot
.79 .33208 Mdot
.79 .33314 Mdot
.79 .33365 Mdot
.79 .33427 Mdot
.79 .33437 Mdot
.79 .33609 Mdot
.79 .33712 Mdot
.79 .33746 Mdot
.79 .34116 Mdot
.79 .34181 Mdot
.79 .34256 Mdot
.79 .34314 Mdot
.79 .34369 Mdot
.79 .34375 Mdot
.79 .34412 Mdot
.79 .34477 Mdot
.79 .34671 Mdot
.79 .34677 Mdot
.79 .34682 Mdot
.79 .34703 Mdot
.79 .34781 Mdot
.79 .34838 Mdot
.79 .34943 Mdot
.79 .34961 Mdot
.79 .34972 Mdot
.79 .35 Mdot
.79 .35039 Mdot
.79 .35099 Mdot
.79 .35204 Mdot
.79 .35264 Mdot
.79 .35313 Mdot
.79 .35398 Mdot
.79 .35447 Mdot
.79 .35478 Mdot
.79 .35543 Mdot
.79 .35638 Mdot
.79 .35766 Mdot
.79 .35797 Mdot
.79 .36003 Mdot
.79 .36149 Mdot
.79 .36167 Mdot
.79 .36367 Mdot
.79 .36413 Mdot
.79 .36435 Mdot
.79 .36604 Mdot
.79 .36731 Mdot
.79 .36751 Mdot
.79 .36773 Mdot
.79 .36859 Mdot
.79 .36859 Mdot
.79 .36928 Mdot
.79 .36942 Mdot
.79 .36958 Mdot
.79 .36994 Mdot
.79 .37067 Mdot
.79 .37159 Mdot
.79 .37204 Mdot
.79 .37229 Mdot
.79 .37247 Mdot
.79 .37289 Mdot
.79 .37341 Mdot
.79 .37378 Mdot
.79 .37419 Mdot
.79 .3743 Mdot
.79 .37544 Mdot
.79 .37565 Mdot
.79 .37642 Mdot
.79 .37736 Mdot
.79 .37739 Mdot
.79 .37749 Mdot
.79 .37965 Mdot
.79 .38014 Mdot
.79 .38167 Mdot
.79 .38197 Mdot
.79 .38222 Mdot
.79 .38257 Mdot
.79 .38268 Mdot
.79 .38312 Mdot
.79 .38353 Mdot
.79 .38358 Mdot
.79 .38458 Mdot
.79 .38502 Mdot
.79 .38545 Mdot
.79 .38577 Mdot
.79 .38618 Mdot
.79 .38646 Mdot
.79 .38669 Mdot
.79 .38734 Mdot
.79 .38768 Mdot
.79 .38875 Mdot
.79 .39011 Mdot
.79 .39032 Mdot
.79 .39048 Mdot
.79 .39187 Mdot
.79 .3938 Mdot
.79 .39391 Mdot
.79 .39407 Mdot
.79 .3946 Mdot
.79 .39499 Mdot
.79 .3954 Mdot
.79 .39607 Mdot
.79 .39661 Mdot
.79 .39734 Mdot
.79 .39742 Mdot
.79 .39887 Mdot
.79 .39904 Mdot
.79 .39947 Mdot
.79 .39979 Mdot
.79 .3999 Mdot
.79 .40046 Mdot
.79 .40087 Mdot
.79 .4011 Mdot
.79 .40153 Mdot
.79 .40156 Mdot
.79 .4019 Mdot
.79 .40292 Mdot
.79 .40357 Mdot
.79 .40369 Mdot
.79 .40417 Mdot
.79 .40428 Mdot
.79 .40464 Mdot
.79 .4047 Mdot
.79 .40566 Mdot
.79 .40651 Mdot
.79 .40657 Mdot
.79 .40671 Mdot
.79 .40681 Mdot
.79 .40742 Mdot
.79 .40802 Mdot
.79 .40805 Mdot
.79 .40847 Mdot
.79 .40973 Mdot
.79 .40974 Mdot
.79 .41229 Mdot
.79 .41299 Mdot
.79 .41438 Mdot
.79 .41441 Mdot
.79 .41449 Mdot
.79 .41509 Mdot
.79 .4166 Mdot
.79 .41668 Mdot
.79 .41938 Mdot
.79 .42006 Mdot
.79 .42085 Mdot
.79 .42137 Mdot
.79 .42479 Mdot
.79 .42486 Mdot
.79 .42496 Mdot
.79 .42531 Mdot
.79 .42548 Mdot
.79 .42618 Mdot
.79 .42661 Mdot
.79 .42768 Mdot
.79 .43046 Mdot
.79 .43062 Mdot
.79 .43069 Mdot
.79 .43138 Mdot
.79 .43172 Mdot
.79 .43204 Mdot
.79 .43221 Mdot
.79 .43287 Mdot
.79 .43361 Mdot
.79 .43394 Mdot
.79 .43553 Mdot
.79 .43571 Mdot
.79 .43597 Mdot
.79 .43642 Mdot
.79 .43752 Mdot
.79 .43815 Mdot
.79 .43844 Mdot
.79 .44383 Mdot
.79 .44459 Mdot
.79 .4463 Mdot
.79 .4465 Mdot
.79 .44688 Mdot
.79 .44726 Mdot
.79 .44872 Mdot
.79 .44938 Mdot
.79 .45037 Mdot
.79 .45172 Mdot
.79 .45215 Mdot
.79 .45243 Mdot
.79 .45572 Mdot
.79 .45678 Mdot
.79 .45814 Mdot
.79 .4589 Mdot
.79 .45966 Mdot
.79 .46077 Mdot
.79 .46229 Mdot
.79 .46289 Mdot
.79 .46338 Mdot
.79 .46367 Mdot
.79 .46452 Mdot
.79 .46517 Mdot
.79 .4659 Mdot
.79 .46621 Mdot
.79 .46659 Mdot
.79 .46746 Mdot
.79 .46795 Mdot
.79 .46796 Mdot
.79 .46863 Mdot
.79 .4705 Mdot
.79 .47078 Mdot
.79 .47142 Mdot
.79 .47308 Mdot
.79 .47539 Mdot
.79 .477 Mdot
.79 .4773 Mdot
.79 .47744 Mdot
.79 .47976 Mdot
.79 .48002 Mdot
.79 .48013 Mdot
.792 .01657 Mdot
.792 .01682 Mdot
.792 .01765 Mdot
.792 .01786 Mdot
.792 .01805 Mdot
.792 .01936 Mdot
.792 .01969 Mdot
.792 .02 Mdot
.792 .02014 Mdot
.792 .02043 Mdot
.792 .02184 Mdot
.792 .02207 Mdot
.792 .02232 Mdot
.792 .02259 Mdot
.792 .02308 Mdot
.792 .02331 Mdot
.792 .02375 Mdot
.792 .02376 Mdot
.792 .02377 Mdot
.792 .02576 Mdot
.792 .02585 Mdot
.792 .026 Mdot
.792 .02616 Mdot
.792 .02636 Mdot
.792 .02676 Mdot
.792 .02716 Mdot
.792 .02719 Mdot
.792 .02797 Mdot
.792 .02833 Mdot
.792 .02838 Mdot
.792 .02879 Mdot
.792 .02902 Mdot
.792 .02905 Mdot
.792 .02906 Mdot
.792 .02941 Mdot
.792 .03042 Mdot
.792 .03057 Mdot
.792 .03097 Mdot
.792 .03133 Mdot
.792 .03183 Mdot
.792 .03221 Mdot
.792 .03236 Mdot
.792 .03259 Mdot
.792 .03264 Mdot
.792 .03284 Mdot
.792 .03317 Mdot
.792 .0338 Mdot
.792 .03408 Mdot
.792 .03443 Mdot
.792 .03448 Mdot
.792 .03571 Mdot
.792 .03573 Mdot
.792 .03596 Mdot
.792 .03629 Mdot
.792 .03637 Mdot
.792 .03701 Mdot
.792 .03737 Mdot
.792 .03742 Mdot
.792 .03744 Mdot
.792 .038 Mdot
.792 .03864 Mdot
.792 .03959 Mdot
.792 .03973 Mdot
.792 .03983 Mdot
.792 .04031 Mdot
.792 .04037 Mdot
.792 .04047 Mdot
.792 .04061 Mdot
.792 .04093 Mdot
.792 .04104 Mdot
.792 .04183 Mdot
.792 .04243 Mdot
.792 .04251 Mdot
.792 .04266 Mdot
.792 .04303 Mdot
.792 .04311 Mdot
.792 .04343 Mdot
.792 .04394 Mdot
.792 .04394 Mdot
.792 .04494 Mdot
.792 .0454 Mdot
.792 .0455 Mdot
.792 .04595 Mdot
.792 .04603 Mdot
.792 .04613 Mdot
.792 .04778 Mdot
.792 .04797 Mdot
.792 .048 Mdot
.792 .04836 Mdot
.792 .04889 Mdot
.792 .04901 Mdot
.792 .05003 Mdot
.792 .05061 Mdot
.792 .05068 Mdot
.792 .0507 Mdot
.792 .05159 Mdot
.792 .05261 Mdot
.792 .05412 Mdot
.792 .05435 Mdot
.792 .05449 Mdot
.792 .05516 Mdot
.792 .05526 Mdot
.792 .05535 Mdot
.792 .05551 Mdot
.792 .05573 Mdot
.792 .05624 Mdot
.792 .05641 Mdot
.792 .0566 Mdot
.792 .05766 Mdot
.792 .05862 Mdot
.792 .05875 Mdot
.792 .05898 Mdot
.792 .05906 Mdot
.792 .05957 Mdot
.792 .05969 Mdot
.792 .0602 Mdot
.792 .06101 Mdot
.792 .06101 Mdot
.792 .06259 Mdot
.792 .06331 Mdot
.792 .0634 Mdot
.792 .06348 Mdot
.792 .06381 Mdot
.792 .06419 Mdot
.792 .06431 Mdot
.792 .06447 Mdot
.792 .065 Mdot
.792 .0671 Mdot
.792 .06739 Mdot
.792 .06744 Mdot
.792 .06801 Mdot
.792 .0687 Mdot
.792 .06884 Mdot
.792 .06904 Mdot
.792 .07038 Mdot
.792 .07066 Mdot
.792 .07083 Mdot
.792 .07157 Mdot
.792 .07159 Mdot
.792 .07169 Mdot
.792 .07172 Mdot
.792 .07174 Mdot
.792 .07213 Mdot
.792 .07313 Mdot
.792 .07329 Mdot
.792 .07474 Mdot
.792 .07708 Mdot
.792 .07713 Mdot
.792 .07749 Mdot
.792 .07773 Mdot
.792 .07785 Mdot
.792 .0781 Mdot
.792 .07878 Mdot
.792 .07893 Mdot
.792 .07907 Mdot
.792 .07915 Mdot
.792 .07933 Mdot
.792 .07969 Mdot
.792 .08049 Mdot
.792 .08076 Mdot
.792 .08107 Mdot
.792 .08274 Mdot
.792 .08317 Mdot
.792 .08385 Mdot
.792 .08397 Mdot
.792 .08424 Mdot
.792 .08425 Mdot
.792 .08447 Mdot
.792 .08464 Mdot
.792 .08483 Mdot
.792 .08495 Mdot
.792 .08568 Mdot
.792 .08575 Mdot
.792 .08576 Mdot
.792 .08595 Mdot
.792 .08612 Mdot
.792 .08615 Mdot
.792 .08638 Mdot
.792 .0864 Mdot
.792 .08676 Mdot
.792 .08804 Mdot
.792 .08805 Mdot
.792 .08812 Mdot
.792 .08961 Mdot
.792 .09024 Mdot
.792 .09055 Mdot
.792 .09161 Mdot
.792 .0917 Mdot
.792 .09183 Mdot
.792 .09196 Mdot
.792 .09219 Mdot
.792 .09249 Mdot
.792 .09309 Mdot
.792 .09328 Mdot
.792 .09353 Mdot
.792 .09437 Mdot
.792 .09577 Mdot
.792 .09769 Mdot
.792 .09795 Mdot
.792 .09815 Mdot
.792 .09823 Mdot
.792 .09914 Mdot
.792 .10009 Mdot
.792 .10022 Mdot
.792 .10046 Mdot
.792 .1005 Mdot
.792 .10077 Mdot
.792 .10101 Mdot
.792 .10142 Mdot
.792 .10289 Mdot
.792 .10332 Mdot
.792 .10359 Mdot
.792 .10394 Mdot
.792 .10419 Mdot
.792 .10477 Mdot
.792 .10481 Mdot
.792 .10496 Mdot
.792 .10501 Mdot
.792 .10504 Mdot
.792 .10566 Mdot
.792 .10588 Mdot
.792 .10724 Mdot
.792 .10749 Mdot
.792 .10806 Mdot
.792 .10833 Mdot
.792 .1096 Mdot
.792 .10979 Mdot
.792 .10984 Mdot
.792 .11067 Mdot
.792 .11067 Mdot
.792 .11085 Mdot
.792 .11107 Mdot
.792 .11196 Mdot
.792 .11326 Mdot
.792 .11351 Mdot
.792 .11351 Mdot
.792 .11358 Mdot
.792 .11415 Mdot
.792 .11448 Mdot
.792 .11452 Mdot
.792 .11473 Mdot
.792 .11481 Mdot
.792 .11495 Mdot
.792 .11511 Mdot
.792 .11521 Mdot
.792 .11553 Mdot
.792 .1162 Mdot
.792 .11638 Mdot
.792 .11643 Mdot
.792 .11666 Mdot
.792 .11678 Mdot
.792 .11707 Mdot
.792 .11763 Mdot
.792 .11766 Mdot
.792 .11774 Mdot
.792 .11807 Mdot
.792 .11888 Mdot
.792 .1189 Mdot
.792 .11934 Mdot
.792 .11982 Mdot
.792 .12009 Mdot
.792 .12028 Mdot
.792 .12038 Mdot
.792 .12075 Mdot
.792 .12247 Mdot
.792 .12315 Mdot
.792 .12344 Mdot
.792 .12423 Mdot
.792 .12441 Mdot
.792 .12485 Mdot
.792 .12486 Mdot
.792 .1252 Mdot
.792 .12545 Mdot
.792 .12548 Mdot
.792 .12577 Mdot
.792 .12597 Mdot
.792 .12631 Mdot
.792 .12712 Mdot
.792 .12723 Mdot
.792 .12725 Mdot
.792 .12755 Mdot
.792 .12783 Mdot
.792 .12786 Mdot
.792 .12823 Mdot
.792 .12826 Mdot
.792 .12854 Mdot
.792 .12884 Mdot
.792 .12884 Mdot
.792 .12964 Mdot
.792 .13041 Mdot
.792 .13086 Mdot
.792 .13087 Mdot
.792 .13098 Mdot
.792 .13335 Mdot
.792 .13393 Mdot
.792 .134 Mdot
.792 .13435 Mdot
.792 .13483 Mdot
.792 .13569 Mdot
.792 .136 Mdot
.792 .13651 Mdot
.792 .13665 Mdot
.792 .13687 Mdot
.792 .13707 Mdot
.792 .13743 Mdot
.792 .13791 Mdot
.792 .13886 Mdot
.792 .13916 Mdot
.792 .13956 Mdot
.792 .14031 Mdot
.792 .14088 Mdot
.792 .14274 Mdot
.792 .1431 Mdot
.792 .14372 Mdot
.792 .14481 Mdot
.792 .14491 Mdot
.792 .14521 Mdot
.792 .14614 Mdot
.792 .14657 Mdot
.792 .14668 Mdot
.792 .14687 Mdot
.792 .14701 Mdot
.792 .14825 Mdot
.792 .14845 Mdot
.792 .14851 Mdot
.792 .14877 Mdot
.792 .14996 Mdot
.792 .15015 Mdot
.792 .15042 Mdot
.792 .15043 Mdot
.792 .15053 Mdot
.792 .15053 Mdot
.792 .15059 Mdot
.792 .15103 Mdot
.792 .15141 Mdot
.792 .15156 Mdot
.792 .15205 Mdot
.792 .15295 Mdot
.792 .1535 Mdot
.792 .15438 Mdot
.792 .15507 Mdot
.792 .1555 Mdot
.792 .15605 Mdot
.792 .15644 Mdot
.792 .1567 Mdot
.792 .1567 Mdot
.792 .15736 Mdot
.792 .15742 Mdot
.792 .15766 Mdot
.792 .15775 Mdot
.792 .15778 Mdot
.792 .15785 Mdot
.792 .15793 Mdot
.792 .15846 Mdot
.792 .15848 Mdot
.792 .15857 Mdot
.792 .15877 Mdot
.792 .15908 Mdot
.792 .15912 Mdot
.792 .15992 Mdot
.792 .16128 Mdot
.792 .16148 Mdot
.792 .16167 Mdot
.792 .16257 Mdot
.792 .163 Mdot
.792 .16308 Mdot
.792 .16416 Mdot
.792 .16477 Mdot
.792 .16502 Mdot
.792 .16532 Mdot
.792 .1654 Mdot
.792 .1667 Mdot
.792 .16671 Mdot
.792 .16673 Mdot
.792 .16699 Mdot
.792 .16734 Mdot
.792 .16829 Mdot
.792 .16829 Mdot
.792 .16859 Mdot
.792 .16873 Mdot
.792 .16876 Mdot
.792 .1691 Mdot
.792 .17081 Mdot
.792 .1712 Mdot
.792 .1712 Mdot
.792 .17131 Mdot
.792 .17222 Mdot
.792 .17234 Mdot
.792 .17274 Mdot
.792 .17281 Mdot
.792 .17281 Mdot
.792 .17313 Mdot
.792 .17326 Mdot
.792 .17349 Mdot
.792 .17375 Mdot
.792 .17381 Mdot
.792 .17385 Mdot
.792 .17391 Mdot
.792 .17439 Mdot
.792 .1744 Mdot
.792 .17468 Mdot
.792 .17468 Mdot
.792 .17547 Mdot
.792 .17576 Mdot
.792 .17584 Mdot
.792 .17597 Mdot
.792 .17619 Mdot
.792 .17639 Mdot
.792 .17648 Mdot
.792 .17685 Mdot
.792 .1774 Mdot
.792 .17773 Mdot
.792 .17777 Mdot
.792 .17791 Mdot
.792 .1784 Mdot
.792 .17843 Mdot
.792 .17864 Mdot
.792 .17882 Mdot
.792 .17903 Mdot
.792 .17971 Mdot
.792 .17974 Mdot
.792 .18044 Mdot
.792 .18094 Mdot
.792 .181 Mdot
.792 .1812 Mdot
.792 .18164 Mdot
.792 .18193 Mdot
.792 .1821 Mdot
.792 .1821 Mdot
.792 .18213 Mdot
.792 .18268 Mdot
.792 .18525 Mdot
.792 .1854 Mdot
.792 .18639 Mdot
.792 .18647 Mdot
.792 .1865 Mdot
.792 .18672 Mdot
.792 .18693 Mdot
.792 .18724 Mdot
.792 .18809 Mdot
.792 .18813 Mdot
.792 .18818 Mdot
.792 .18848 Mdot
.792 .18892 Mdot
.792 .18907 Mdot
.792 .18917 Mdot
.792 .18919 Mdot
.792 .18928 Mdot
.792 .18972 Mdot
.792 .19013 Mdot
.792 .19016 Mdot
.792 .19063 Mdot
.792 .19072 Mdot
.792 .19094 Mdot
.792 .19148 Mdot
.792 .19257 Mdot
.792 .19276 Mdot
.792 .19292 Mdot
.792 .19295 Mdot
.792 .19297 Mdot
.792 .19345 Mdot
.792 .19388 Mdot
.792 .19394 Mdot
.792 .19425 Mdot
.792 .19441 Mdot
.792 .19452 Mdot
.792 .19458 Mdot
.792 .19496 Mdot
.792 .19501 Mdot
.792 .19548 Mdot
.792 .19549 Mdot
.792 .19676 Mdot
.792 .19692 Mdot
.792 .19701 Mdot
.792 .19736 Mdot
.792 .19785 Mdot
.792 .19798 Mdot
.792 .19855 Mdot
.792 .19869 Mdot
.792 .19869 Mdot
.792 .19871 Mdot
.792 .19888 Mdot
.792 .19942 Mdot
.792 .20212 Mdot
.792 .20222 Mdot
.792 .20263 Mdot
.792 .20355 Mdot
.792 .20366 Mdot
.792 .20422 Mdot
.792 .20441 Mdot
.792 .20498 Mdot
.792 .20499 Mdot
.792 .20578 Mdot
.792 .20582 Mdot
.792 .20594 Mdot
.792 .20634 Mdot
.792 .20683 Mdot
.792 .20699 Mdot
.792 .20724 Mdot
.792 .20764 Mdot
.792 .2077 Mdot
.792 .20786 Mdot
.792 .20801 Mdot
.792 .2082 Mdot
.792 .20853 Mdot
.792 .2091 Mdot
.792 .20976 Mdot
.792 .20985 Mdot
.792 .21092 Mdot
.792 .21135 Mdot
.792 .21158 Mdot
.792 .21161 Mdot
.792 .2117 Mdot
.792 .21183 Mdot
.792 .21246 Mdot
.792 .21303 Mdot
.792 .21365 Mdot
.792 .2139 Mdot
.792 .21456 Mdot
.792 .2175 Mdot
.792 .21808 Mdot
.792 .21905 Mdot
.792 .22079 Mdot
.792 .22095 Mdot
.792 .22142 Mdot
.792 .2229 Mdot
.792 .22357 Mdot
.792 .22375 Mdot
.792 .22405 Mdot
.792 .22411 Mdot
.792 .22427 Mdot
.792 .22473 Mdot
.792 .22624 Mdot
.792 .22655 Mdot
.792 .22664 Mdot
.792 .22706 Mdot
.792 .22867 Mdot
.792 .22894 Mdot
.792 .22898 Mdot
.792 .22909 Mdot
.792 .22925 Mdot
.792 .22966 Mdot
.792 .22969 Mdot
.792 .22984 Mdot
.792 .22985 Mdot
.792 .22994 Mdot
.792 .22995 Mdot
.792 .23064 Mdot
.792 .23123 Mdot
.792 .23149 Mdot
.792 .23203 Mdot
.792 .23226 Mdot
.792 .23369 Mdot
.792 .23456 Mdot
.792 .23541 Mdot
.792 .23557 Mdot
.792 .23578 Mdot
.792 .23594 Mdot
.792 .23694 Mdot
.792 .23704 Mdot
.792 .23772 Mdot
.792 .23859 Mdot
.792 .23869 Mdot
.792 .2392 Mdot
.792 .2393 Mdot
.792 .23963 Mdot
.792 .23963 Mdot
.792 .2397 Mdot
.792 .23979 Mdot
.792 .24014 Mdot
.792 .24066 Mdot
.792 .24076 Mdot
.792 .24114 Mdot
.792 .24128 Mdot
.792 .24133 Mdot
.792 .24144 Mdot
.792 .24156 Mdot
.792 .2419 Mdot
.792 .24241 Mdot
.792 .24245 Mdot
.792 .24258 Mdot
.792 .2429 Mdot
.792 .24338 Mdot
.792 .24346 Mdot
.792 .2435 Mdot
.792 .24364 Mdot
.792 .24472 Mdot
.792 .24552 Mdot
.792 .24586 Mdot
.792 .24675 Mdot
.792 .24687 Mdot
.792 .24719 Mdot
.792 .24749 Mdot
.792 .24889 Mdot
.792 .24892 Mdot
.792 .2496 Mdot
.792 .24972 Mdot
.792 .25144 Mdot
.792 .25241 Mdot
.792 .2528 Mdot
.792 .25323 Mdot
.792 .25327 Mdot
.792 .25339 Mdot
.792 .25398 Mdot
.792 .2546 Mdot
.792 .25471 Mdot
.792 .25481 Mdot
.792 .25547 Mdot
.792 .25547 Mdot
.792 .25551 Mdot
.792 .25592 Mdot
.792 .25648 Mdot
.792 .2567 Mdot
.792 .25797 Mdot
.792 .25797 Mdot
.792 .25843 Mdot
.792 .25846 Mdot
.792 .25867 Mdot
.792 .25868 Mdot
.792 .25872 Mdot
.792 .25925 Mdot
.792 .25988 Mdot
.792 .26051 Mdot
.792 .26095 Mdot
.792 .26119 Mdot
.792 .26197 Mdot
.792 .26259 Mdot
.792 .26259 Mdot
.792 .26271 Mdot
.792 .26277 Mdot
.792 .26291 Mdot
.792 .2642 Mdot
.792 .26439 Mdot
.792 .26479 Mdot
.792 .26481 Mdot
.792 .26502 Mdot
.792 .26514 Mdot
.792 .26514 Mdot
.792 .26565 Mdot
.792 .26586 Mdot
.792 .26622 Mdot
.792 .26662 Mdot
.792 .26672 Mdot
.792 .26679 Mdot
.792 .26687 Mdot
.792 .26763 Mdot
.792 .26766 Mdot
.792 .2681 Mdot
.792 .2681 Mdot
.792 .26935 Mdot
.792 .26981 Mdot
.792 .26985 Mdot
.792 .26994 Mdot
.792 .27014 Mdot
.792 .27048 Mdot
.792 .2705 Mdot
.792 .27081 Mdot
.792 .27087 Mdot
.792 .27096 Mdot
.792 .27153 Mdot
.792 .27227 Mdot
.792 .27241 Mdot
.792 .27294 Mdot
.792 .273 Mdot
.792 .27322 Mdot
.792 .274 Mdot
.792 .27404 Mdot
.792 .27418 Mdot
.792 .27437 Mdot
.792 .27465 Mdot
.792 .27471 Mdot
.792 .275 Mdot
.792 .27607 Mdot
.792 .27611 Mdot
.792 .27699 Mdot
.792 .27722 Mdot
.792 .27753 Mdot
.792 .27755 Mdot
.792 .2776 Mdot
.792 .27802 Mdot
.792 .27811 Mdot
.792 .2783 Mdot
.792 .27842 Mdot
.792 .27912 Mdot
.792 .27958 Mdot
.792 .27985 Mdot
.792 .27985 Mdot
.792 .27989 Mdot
.792 .28042 Mdot
.792 .28077 Mdot
.792 .28484 Mdot
.792 .28508 Mdot
.792 .28665 Mdot
.792 .28678 Mdot
.792 .28682 Mdot
.792 .28717 Mdot
.792 .28751 Mdot
.792 .28799 Mdot
.792 .28934 Mdot
.792 .28941 Mdot
.792 .28949 Mdot
.792 .28995 Mdot
.792 .29065 Mdot
.792 .29089 Mdot
.792 .29105 Mdot
.792 .29109 Mdot
.792 .29123 Mdot
.792 .29193 Mdot
.792 .29257 Mdot
.792 .29262 Mdot
.792 .29337 Mdot
.792 .29351 Mdot
.792 .29386 Mdot
.792 .29472 Mdot
.792 .29645 Mdot
.792 .29674 Mdot
.792 .29699 Mdot
.792 .29703 Mdot
.792 .29707 Mdot
.792 .29783 Mdot
.792 .29852 Mdot
.792 .29861 Mdot
.792 .29909 Mdot
.792 .29935 Mdot
.792 .29952 Mdot
.792 .29962 Mdot
.792 .30022 Mdot
.792 .3003 Mdot
.792 .30105 Mdot
.792 .30106 Mdot
.792 .30307 Mdot
.792 .30332 Mdot
.792 .30348 Mdot
.792 .30403 Mdot
.792 .30479 Mdot
.792 .305 Mdot
.792 .30591 Mdot
.792 .30613 Mdot
.792 .30614 Mdot
.792 .30616 Mdot
.792 .30644 Mdot
.792 .30728 Mdot
.792 .31156 Mdot
.792 .31173 Mdot
.792 .31238 Mdot
.792 .31382 Mdot
.792 .314 Mdot
.792 .31489 Mdot
.792 .3152 Mdot
.792 .3161 Mdot
.792 .31611 Mdot
.792 .31737 Mdot
.792 .31743 Mdot
.792 .31762 Mdot
.792 .31826 Mdot
.792 .31903 Mdot
.792 .31928 Mdot
.792 .31967 Mdot
.792 .32031 Mdot
.792 .32041 Mdot
.792 .32066 Mdot
.792 .32089 Mdot
.792 .3212 Mdot
.792 .32171 Mdot
.792 .32262 Mdot
.792 .32366 Mdot
.792 .32381 Mdot
.792 .3255 Mdot
.792 .32619 Mdot
.792 .32655 Mdot
.792 .32659 Mdot
.792 .32674 Mdot
.792 .32695 Mdot
.792 .32795 Mdot
.792 .32885 Mdot
.792 .32983 Mdot
.792 .33023 Mdot
.792 .33127 Mdot
.792 .33593 Mdot
.792 .33684 Mdot
.792 .33839 Mdot
.792 .34113 Mdot
.792 .34139 Mdot
.792 .34214 Mdot
.792 .34447 Mdot
.792 .34554 Mdot
.792 .34582 Mdot
.792 .3463 Mdot
.792 .34639 Mdot
.792 .34664 Mdot
.792 .34737 Mdot
.792 .34977 Mdot
.792 .35026 Mdot
.792 .35041 Mdot
.792 .35108 Mdot
.792 .35361 Mdot
.792 .35404 Mdot
.792 .35412 Mdot
.792 .35429 Mdot
.792 .35454 Mdot
.792 .3552 Mdot
.792 .35524 Mdot
.792 .35548 Mdot
.792 .35549 Mdot
.792 .35564 Mdot
.792 .35565 Mdot
.792 .35674 Mdot
.792 .35768 Mdot
.792 .35808 Mdot
.792 .35894 Mdot
.792 .35931 Mdot
.792 .36156 Mdot
.792 .36295 Mdot
.792 .3643 Mdot
.792 .36455 Mdot
.792 .36487 Mdot
.792 .36513 Mdot
.792 .36673 Mdot
.792 .36688 Mdot
.792 .36795 Mdot
.792 .36933 Mdot
.792 .3695 Mdot
.792 .3703 Mdot
.792 .37045 Mdot
.792 .37097 Mdot
.792 .37097 Mdot
.792 .37109 Mdot
.792 .37123 Mdot
.792 .37179 Mdot
.792 .37261 Mdot
.792 .37276 Mdot
.792 .37338 Mdot
.792 .37359 Mdot
.792 .37368 Mdot
.792 .37384 Mdot
.792 .37404 Mdot
.792 .37458 Mdot
.792 .37538 Mdot
.792 .37544 Mdot
.792 .37565 Mdot
.792 .37616 Mdot
.792 .37692 Mdot
.792 .37704 Mdot
.792 .37711 Mdot
.792 .37734 Mdot
.792 .37904 Mdot
.792 .38031 Mdot
.792 .38085 Mdot
.792 .38225 Mdot
.792 .38244 Mdot
.792 .38295 Mdot
.792 .38344 Mdot
.792 .38566 Mdot
.792 .3857 Mdot
.792 .38677 Mdot
.792 .38697 Mdot
.792 .38968 Mdot
.792 .39122 Mdot
.792 .39184 Mdot
.792 .39253 Mdot
.792 .39259 Mdot
.792 .39278 Mdot
.792 .39371 Mdot
.792 .3947 Mdot
.792 .39486 Mdot
.792 .39503 Mdot
.792 .39607 Mdot
.792 .39608 Mdot
.792 .39614 Mdot
.792 .39679 Mdot
.792 .39767 Mdot
.792 .39802 Mdot
.792 .40004 Mdot
.792 .40004 Mdot
.792 .40076 Mdot
.792 .40081 Mdot
.792 .40115 Mdot
.792 .40116 Mdot
.792 .40121 Mdot
.792 .40206 Mdot
.792 .40305 Mdot
.792 .40406 Mdot
.792 .40474 Mdot
.792 .40513 Mdot
.792 .40637 Mdot
.792 .40735 Mdot
.792 .40735 Mdot
.792 .40754 Mdot
.792 .40763 Mdot
.792 .40786 Mdot
.792 .40991 Mdot
.792 .4102 Mdot
.792 .41083 Mdot
.792 .41086 Mdot
.792 .4112 Mdot
.792 .41138 Mdot
.792 .41139 Mdot
.792 .4122 Mdot
.792 .41252 Mdot
.792 .4131 Mdot
.792 .41374 Mdot
.792 .41388 Mdot
.792 .414 Mdot
.792 .41413 Mdot
.792 .41534 Mdot
.792 .41538 Mdot
.792 .41607 Mdot
.792 .41608 Mdot
.792 .41806 Mdot
.792 .41878 Mdot
.792 .41885 Mdot
.792 .41898 Mdot
.792 .41931 Mdot
.792 .41985 Mdot
.792 .41988 Mdot
.792 .42037 Mdot
.792 .42047 Mdot
.792 .4206 Mdot
.792 .42151 Mdot
.792 .42268 Mdot
.792 .4229 Mdot
.792 .42374 Mdot
.792 .42384 Mdot
.792 .42419 Mdot
.792 .42542 Mdot
.792 .42548 Mdot
.792 .42571 Mdot
.792 .42601 Mdot
.792 .42645 Mdot
.792 .42654 Mdot
.792 .427 Mdot
.792 .42871 Mdot
.792 .42877 Mdot
.792 .43016 Mdot
.792 .43052 Mdot
.792 .43102 Mdot
.792 .43104 Mdot
.792 .43112 Mdot
.792 .43178 Mdot
.792 .43194 Mdot
.792 .43223 Mdot
.792 .43242 Mdot
.792 .43353 Mdot
.792 .43426 Mdot
.792 .43468 Mdot
.792 .4347 Mdot
.792 .43476 Mdot
.792 .43559 Mdot
.792 .43615 Mdot
.792 .44259 Mdot
.792 .44298 Mdot
.792 .44547 Mdot
.792 .44567 Mdot
.792 .44574 Mdot
.792 .44628 Mdot
.792 .44682 Mdot
.792 .44759 Mdot
.792 .44972 Mdot
.792 .44983 Mdot
.792 .44995 Mdot
.792 .45069 Mdot
.792 .4518 Mdot
.792 .45218 Mdot
.792 .45243 Mdot
.792 .45249 Mdot
.792 .45271 Mdot
.792 .45382 Mdot
.792 .45483 Mdot
.792 .45492 Mdot
.792 .45611 Mdot
.792 .45632 Mdot
.792 .45688 Mdot
.792 .45824 Mdot
.792 .46098 Mdot
.792 .46145 Mdot
.792 .46184 Mdot
.792 .46191 Mdot
.792 .46197 Mdot
.792 .46316 Mdot
.792 .46426 Mdot
.792 .46441 Mdot
.792 .46517 Mdot
.792 .46557 Mdot
.792 .46584 Mdot
.792 .466 Mdot
.792 .46696 Mdot
.792 .46709 Mdot
.792 .46827 Mdot
.792 .46828 Mdot
.792 .47147 Mdot
.792 .47187 Mdot
.792 .47211 Mdot
.792 .47299 Mdot
.792 .4742 Mdot
.792 .47453 Mdot
.792 .47597 Mdot
.792 .47632 Mdot
.792 .47633 Mdot
.792 .47636 Mdot
.792 .4768 Mdot
.792 .47814 Mdot
.794 .01519 Mdot
.794 .01547 Mdot
.794 .01592 Mdot
.794 .01662 Mdot
.794 .01775 Mdot
.794 .01816 Mdot
.794 .01875 Mdot
.794 .01953 Mdot
.794 .02018 Mdot
.794 .02112 Mdot
.794 .02236 Mdot
.794 .02246 Mdot
.794 .02259 Mdot
.794 .0234 Mdot
.794 .02488 Mdot
.794 .02506 Mdot
.794 .02511 Mdot
.794 .0254 Mdot
.794 .02607 Mdot
.794 .02685 Mdot
.794 .02701 Mdot
.794 .02722 Mdot
.794 .02726 Mdot
.794 .02765 Mdot
.794 .02782 Mdot
.794 .02792 Mdot
.794 .02845 Mdot
.794 .0285 Mdot
.794 .02852 Mdot
.794 .02992 Mdot
.794 .03072 Mdot
.794 .03086 Mdot
.794 .03114 Mdot
.794 .03122 Mdot
.794 .03167 Mdot
.794 .03275 Mdot
.794 .03329 Mdot
.794 .03399 Mdot
.794 .03411 Mdot
.794 .03424 Mdot
.794 .03457 Mdot
.794 .03463 Mdot
.794 .03526 Mdot
.794 .03552 Mdot
.794 .03565 Mdot
.794 .03566 Mdot
.794 .03568 Mdot
.794 .03602 Mdot
.794 .03652 Mdot
.794 .03654 Mdot
.794 .0366 Mdot
.794 .03664 Mdot
.794 .03886 Mdot
.794 .03909 Mdot
.794 .04014 Mdot
.794 .0402 Mdot
.794 .04035 Mdot
.794 .04079 Mdot
.794 .04093 Mdot
.794 .04165 Mdot
.794 .04184 Mdot
.794 .04219 Mdot
.794 .04228 Mdot
.794 .04336 Mdot
.794 .04421 Mdot
.794 .04448 Mdot
.794 .04464 Mdot
.794 .04481 Mdot
.794 .0453 Mdot
.794 .04532 Mdot
.794 .04551 Mdot
.794 .04571 Mdot
.794 .04624 Mdot
.794 .04634 Mdot
.794 .04734 Mdot
.794 .04752 Mdot
.794 .04775 Mdot
.794 .04796 Mdot
.794 .04797 Mdot
.794 .04801 Mdot
.794 .0483 Mdot
.794 .04838 Mdot
.794 .04855 Mdot
.794 .04935 Mdot
.794 .04937 Mdot
.794 .04948 Mdot
.794 .04954 Mdot
.794 .05021 Mdot
.794 .05076 Mdot
.794 .05229 Mdot
.794 .05306 Mdot
.794 .05342 Mdot
.794 .05427 Mdot
.794 .05509 Mdot
.794 .05519 Mdot
.794 .05533 Mdot
.794 .05542 Mdot
.794 .05612 Mdot
.794 .05628 Mdot
.794 .05634 Mdot
.794 .05642 Mdot
.794 .05748 Mdot
.794 .05779 Mdot
.794 .05834 Mdot
.794 .05849 Mdot
.794 .0602 Mdot
.794 .06155 Mdot
.794 .06198 Mdot
.794 .06224 Mdot
.794 .06251 Mdot
.794 .06328 Mdot
.794 .06332 Mdot
.794 .06363 Mdot
.794 .06394 Mdot
.794 .06478 Mdot
.794 .06493 Mdot
.794 .06634 Mdot
.794 .06653 Mdot
.794 .06653 Mdot
.794 .06682 Mdot
.794 .06718 Mdot
.794 .06751 Mdot
.794 .06753 Mdot
.794 .06758 Mdot
.794 .06804 Mdot
.794 .06817 Mdot
.794 .06839 Mdot
.794 .06839 Mdot
.794 .06845 Mdot
.794 .06874 Mdot
.794 .0695 Mdot
.794 .06971 Mdot
.794 .06975 Mdot
.794 .06991 Mdot
.794 .07001 Mdot
.794 .07108 Mdot
.794 .07132 Mdot
.794 .07196 Mdot
.794 .07439 Mdot
.794 .07496 Mdot
.794 .07542 Mdot
.794 .0756 Mdot
.794 .07618 Mdot
.794 .07634 Mdot
.794 .07753 Mdot
.794 .07762 Mdot
.794 .07803 Mdot
.794 .07833 Mdot
.794 .07851 Mdot
.794 .07882 Mdot
.794 .07898 Mdot
.794 .07907 Mdot
.794 .07921 Mdot
.794 .07935 Mdot
.794 .08047 Mdot
.794 .08072 Mdot
.794 .08082 Mdot
.794 .08094 Mdot
.794 .08129 Mdot
.794 .08263 Mdot
.794 .08311 Mdot
.794 .0835 Mdot
.794 .08367 Mdot
.794 .084 Mdot
.794 .08422 Mdot
.794 .08496 Mdot
.794 .08515 Mdot
.794 .08579 Mdot
.794 .08642 Mdot
.794 .08655 Mdot
.794 .08673 Mdot
.794 .08695 Mdot
.794 .08718 Mdot
.794 .08725 Mdot
.794 .08777 Mdot
.794 .08834 Mdot
.794 .08909 Mdot
.794 .08977 Mdot
.794 .09018 Mdot
.794 .09061 Mdot
.794 .09063 Mdot
.794 .09071 Mdot
.794 .09094 Mdot
.794 .09184 Mdot
.794 .0919 Mdot
.794 .09238 Mdot
.794 .09289 Mdot
.794 .09336 Mdot
.794 .09384 Mdot
.794 .09422 Mdot
.794 .09446 Mdot
.794 .0967 Mdot
.794 .09699 Mdot
.794 .09699 Mdot
.794 .09717 Mdot
.794 .09745 Mdot
.794 .09802 Mdot
.794 .09844 Mdot
.794 .09856 Mdot
.794 .09858 Mdot
.794 .09867 Mdot
.794 .0994 Mdot
.794 .0996 Mdot
.794 .09963 Mdot
.794 .09995 Mdot
.794 .09996 Mdot
.794 .10004 Mdot
.794 .1005 Mdot
.794 .10054 Mdot
.794 .10092 Mdot
.794 .101 Mdot
.794 .10152 Mdot
.794 .10172 Mdot
.794 .10205 Mdot
.794 .10211 Mdot
.794 .10237 Mdot
.794 .10253 Mdot
.794 .1026 Mdot
.794 .1029 Mdot
.794 .10351 Mdot
.794 .10359 Mdot
.794 .10402 Mdot
.794 .10422 Mdot
.794 .1046 Mdot
.794 .10562 Mdot
.794 .10594 Mdot
.794 .10594 Mdot
.794 .10598 Mdot
.794 .10685 Mdot
.794 .10698 Mdot
.794 .10948 Mdot
.794 .10969 Mdot
.794 .10982 Mdot
.794 .11032 Mdot
.794 .11038 Mdot
.794 .11057 Mdot
.794 .11112 Mdot
.794 .1114 Mdot
.794 .11232 Mdot
.794 .11258 Mdot
.794 .11269 Mdot
.794 .1131 Mdot
.794 .11436 Mdot
.794 .11447 Mdot
.794 .1146 Mdot
.794 .11477 Mdot
.794 .11525 Mdot
.794 .11526 Mdot
.794 .11574 Mdot
.794 .11579 Mdot
.794 .11602 Mdot
.794 .11652 Mdot
.794 .11676 Mdot
.794 .11677 Mdot
.794 .11692 Mdot
.794 .11713 Mdot
.794 .1172 Mdot
.794 .11736 Mdot
.794 .11777 Mdot
.794 .11914 Mdot
.794 .11952 Mdot
.794 .11969 Mdot
.794 .11988 Mdot
.794 .11993 Mdot
.794 .12043 Mdot
.794 .12257 Mdot
.794 .12324 Mdot
.794 .12333 Mdot
.794 .12394 Mdot
.794 .12422 Mdot
.794 .12473 Mdot
.794 .1251 Mdot
.794 .12527 Mdot
.794 .12531 Mdot
.794 .12534 Mdot
.794 .12539 Mdot
.794 .12557 Mdot
.794 .12626 Mdot
.794 .12626 Mdot
.794 .12656 Mdot
.794 .12713 Mdot
.794 .12758 Mdot
.794 .12858 Mdot
.794 .12879 Mdot
.794 .12908 Mdot
.794 .12943 Mdot
.794 .12978 Mdot
.794 .1299 Mdot
.794 .13019 Mdot
.794 .13072 Mdot
.794 .13109 Mdot
.794 .1312 Mdot
.794 .13164 Mdot
.794 .13192 Mdot
.794 .13283 Mdot
.794 .1339 Mdot
.794 .13393 Mdot
.794 .13455 Mdot
.794 .13456 Mdot
.794 .1348 Mdot
.794 .1351 Mdot
.794 .1352 Mdot
.794 .13524 Mdot
.794 .13526 Mdot
.794 .1354 Mdot
.794 .13576 Mdot
.794 .13597 Mdot
.794 .1372 Mdot
.794 .13729 Mdot
.794 .13805 Mdot
.794 .13883 Mdot
.794 .13885 Mdot
.794 .13961 Mdot
.794 .14037 Mdot
.794 .14097 Mdot
.794 .14135 Mdot
.794 .14211 Mdot
.794 .14491 Mdot
.794 .14537 Mdot
.794 .14537 Mdot
.794 .14546 Mdot
.794 .14565 Mdot
.794 .1461 Mdot
.794 .14701 Mdot
.794 .14768 Mdot
.794 .14778 Mdot
.794 .14785 Mdot
.794 .1479 Mdot
.794 .14804 Mdot
.794 .14914 Mdot
.794 .14919 Mdot
.794 .14951 Mdot
.794 .14956 Mdot
.794 .14987 Mdot
.794 .14991 Mdot
.794 .14995 Mdot
.794 .15006 Mdot
.794 .15008 Mdot
.794 .15021 Mdot
.794 .15035 Mdot
.794 .15095 Mdot
.794 .151 Mdot
.794 .15161 Mdot
.794 .15173 Mdot
.794 .15256 Mdot
.794 .15288 Mdot
.794 .15317 Mdot
.794 .1534 Mdot
.794 .15349 Mdot
.794 .15351 Mdot
.794 .15391 Mdot
.794 .15416 Mdot
.794 .15427 Mdot
.794 .15475 Mdot
.794 .15475 Mdot
.794 .15476 Mdot
.794 .15572 Mdot
.794 .15584 Mdot
.794 .15654 Mdot
.794 .15685 Mdot
.794 .15707 Mdot
.794 .15721 Mdot
.794 .15745 Mdot
.794 .15824 Mdot
.794 .15907 Mdot
.794 .15957 Mdot
.794 .15958 Mdot
.794 .15965 Mdot
.794 .15982 Mdot
.794 .16004 Mdot
.794 .16103 Mdot
.794 .16124 Mdot
.794 .16196 Mdot
.794 .16378 Mdot
.794 .1652 Mdot
.794 .16554 Mdot
.794 .16574 Mdot
.794 .16584 Mdot
.794 .16654 Mdot
.794 .16663 Mdot
.794 .16694 Mdot
.794 .16752 Mdot
.794 .16781 Mdot
.794 .1682 Mdot
.794 .16826 Mdot
.794 .16874 Mdot
.794 .16971 Mdot
.794 .17012 Mdot
.794 .1703 Mdot
.794 .17043 Mdot
.794 .17085 Mdot
.794 .17096 Mdot
.794 .17106 Mdot
.794 .17127 Mdot
.794 .1721 Mdot
.794 .17227 Mdot
.794 .17296 Mdot
.794 .17312 Mdot
.794 .17334 Mdot
.794 .1734 Mdot
.794 .1736 Mdot
.794 .17436 Mdot
.794 .17438 Mdot
.794 .17514 Mdot
.794 .17523 Mdot
.794 .17541 Mdot
.794 .17559 Mdot
.794 .17609 Mdot
.794 .17638 Mdot
.794 .17675 Mdot
.794 .17678 Mdot
.794 .17701 Mdot
.794 .17735 Mdot
.794 .17747 Mdot
.794 .17771 Mdot
.794 .17837 Mdot
.794 .17886 Mdot
.794 .17952 Mdot
.794 .18038 Mdot
.794 .18054 Mdot
.794 .18063 Mdot
.794 .18115 Mdot
.794 .18141 Mdot
.794 .18143 Mdot
.794 .18171 Mdot
.794 .18179 Mdot
.794 .18238 Mdot
.794 .18258 Mdot
.794 .18259 Mdot
.794 .18448 Mdot
.794 .18457 Mdot
.794 .18598 Mdot
.794 .18705 Mdot
.794 .18706 Mdot
.794 .1872 Mdot
.794 .18759 Mdot
.794 .18796 Mdot
.794 .18817 Mdot
.794 .18861 Mdot
.794 .18867 Mdot
.794 .18942 Mdot
.794 .18942 Mdot
.794 .1899 Mdot
.794 .19 Mdot
.794 .19027 Mdot
.794 .19033 Mdot
.794 .19039 Mdot
.794 .1904 Mdot
.794 .19047 Mdot
.794 .19075 Mdot
.794 .19141 Mdot
.794 .19185 Mdot
.794 .19185 Mdot
.794 .19233 Mdot
.794 .19257 Mdot
.794 .19323 Mdot
.794 .19395 Mdot
.794 .19407 Mdot
.794 .19418 Mdot
.794 .19507 Mdot
.794 .19509 Mdot
.794 .19553 Mdot
.794 .19581 Mdot
.794 .19586 Mdot
.794 .19632 Mdot
.794 .1964 Mdot
.794 .19646 Mdot
.794 .19687 Mdot
.794 .19692 Mdot
.794 .19744 Mdot
.794 .19763 Mdot
.794 .1979 Mdot
.794 .19808 Mdot
.794 .19893 Mdot
.794 .19952 Mdot
.794 .19969 Mdot
.794 .20039 Mdot
.794 .20053 Mdot
.794 .20063 Mdot
.794 .20083 Mdot
.794 .2011 Mdot
.794 .20228 Mdot
.794 .20251 Mdot
.794 .20398 Mdot
.794 .20403 Mdot
.794 .20501 Mdot
.794 .20503 Mdot
.794 .20515 Mdot
.794 .20542 Mdot
.794 .20589 Mdot
.794 .20604 Mdot
.794 .20611 Mdot
.794 .20615 Mdot
.794 .20636 Mdot
.794 .20639 Mdot
.794 .20694 Mdot
.794 .20726 Mdot
.794 .20828 Mdot
.794 .2086 Mdot
.794 .20921 Mdot
.794 .20922 Mdot
.794 .20936 Mdot
.794 .20957 Mdot
.794 .21058 Mdot
.794 .21102 Mdot
.794 .21167 Mdot
.794 .21181 Mdot
.794 .21184 Mdot
.794 .21271 Mdot
.794 .21278 Mdot
.794 .21285 Mdot
.794 .21304 Mdot
.794 .21392 Mdot
.794 .21423 Mdot
.794 .21426 Mdot
.794 .21521 Mdot
.794 .21581 Mdot
.794 .2166 Mdot
.794 .21702 Mdot
.794 .21739 Mdot
.794 .21745 Mdot
.794 .22139 Mdot
.794 .22146 Mdot
.794 .2222 Mdot
.794 .2222 Mdot
.794 .22233 Mdot
.794 .22264 Mdot
.794 .22336 Mdot
.794 .2248 Mdot
.794 .22499 Mdot
.794 .22535 Mdot
.794 .22586 Mdot
.794 .22602 Mdot
.794 .22614 Mdot
.794 .22621 Mdot
.794 .22643 Mdot
.794 .22731 Mdot
.794 .22819 Mdot
.794 .22826 Mdot
.794 .22877 Mdot
.794 .22884 Mdot
.794 .2291 Mdot
.794 .22935 Mdot
.794 .2294 Mdot
.794 .22947 Mdot
.794 .22965 Mdot
.794 .22968 Mdot
.794 .22988 Mdot
.794 .23011 Mdot
.794 .23102 Mdot
.794 .23105 Mdot
.794 .23114 Mdot
.794 .2321 Mdot
.794 .23229 Mdot
.794 .23361 Mdot
.794 .23411 Mdot
.794 .23458 Mdot
.794 .23495 Mdot
.794 .2351 Mdot
.794 .23513 Mdot
.794 .23533 Mdot
.794 .23576 Mdot
.794 .23588 Mdot
.794 .23612 Mdot
.794 .23615 Mdot
.794 .23633 Mdot
.794 .23709 Mdot
.794 .23709 Mdot
.794 .23711 Mdot
.794 .23745 Mdot
.794 .2375 Mdot
.794 .23858 Mdot
.794 .23863 Mdot
.794 .23883 Mdot
.794 .23892 Mdot
.794 .23976 Mdot
.794 .23993 Mdot
.794 .24043 Mdot
.794 .24059 Mdot
.794 .24078 Mdot
.794 .241 Mdot
.794 .24138 Mdot
.794 .24155 Mdot
.794 .24178 Mdot
.794 .24263 Mdot
.794 .24395 Mdot
.794 .24475 Mdot
.794 .24477 Mdot
.794 .24478 Mdot
.794 .2448 Mdot
.794 .24487 Mdot
.794 .24515 Mdot
.794 .24549 Mdot
.794 .2467 Mdot
.794 .24706 Mdot
.794 .2471 Mdot
.794 .24739 Mdot
.794 .24819 Mdot
.794 .24844 Mdot
.794 .24853 Mdot
.794 .24865 Mdot
.794 .24869 Mdot
.794 .24899 Mdot
.794 .25013 Mdot
.794 .25143 Mdot
.794 .25276 Mdot
.794 .25368 Mdot
.794 .25422 Mdot
.794 .25451 Mdot
.794 .25452 Mdot
.794 .25454 Mdot
.794 .2547 Mdot
.794 .25582 Mdot
.794 .25595 Mdot
.794 .25644 Mdot
.794 .25644 Mdot
.794 .25736 Mdot
.794 .25742 Mdot
.794 .25783 Mdot
.794 .25845 Mdot
.794 .25854 Mdot
.794 .2593 Mdot
.794 .26002 Mdot
.794 .26084 Mdot
.794 .26151 Mdot
.794 .26178 Mdot
.794 .26199 Mdot
.794 .26266 Mdot
.794 .26283 Mdot
.794 .26291 Mdot
.794 .26299 Mdot
.794 .26332 Mdot
.794 .26339 Mdot
.794 .26384 Mdot
.794 .26463 Mdot
.794 .26491 Mdot
.794 .26601 Mdot
.794 .26627 Mdot
.794 .26661 Mdot
.794 .2667 Mdot
.794 .26702 Mdot
.794 .2674 Mdot
.794 .26748 Mdot
.794 .26823 Mdot
.794 .26827 Mdot
.794 .26925 Mdot
.794 .26947 Mdot
.794 .26961 Mdot
.794 .26989 Mdot
.794 .27019 Mdot
.794 .27038 Mdot
.794 .27058 Mdot
.794 .27098 Mdot
.794 .27144 Mdot
.794 .27203 Mdot
.794 .27208 Mdot
.794 .27243 Mdot
.794 .27244 Mdot
.794 .27273 Mdot
.794 .27296 Mdot
.794 .27298 Mdot
.794 .27317 Mdot
.794 .27356 Mdot
.794 .2746 Mdot
.794 .27464 Mdot
.794 .27482 Mdot
.794 .27538 Mdot
.794 .27643 Mdot
.794 .27692 Mdot
.794 .27767 Mdot
.794 .2778 Mdot
.794 .27804 Mdot
.794 .27818 Mdot
.794 .27876 Mdot
.794 .27901 Mdot
.794 .27943 Mdot
.794 .27945 Mdot
.794 .27948 Mdot
.794 .27991 Mdot
.794 .28003 Mdot
.794 .28097 Mdot
.794 .28128 Mdot
.794 .28131 Mdot
.794 .28287 Mdot
.794 .2843 Mdot
.794 .28444 Mdot
.794 .28522 Mdot
.794 .28593 Mdot
.794 .28669 Mdot
.794 .28839 Mdot
.794 .2884 Mdot
.794 .28862 Mdot
.794 .28871 Mdot
.794 .28924 Mdot
.794 .28926 Mdot
.794 .28968 Mdot
.794 .28982 Mdot
.794 .29016 Mdot
.794 .29048 Mdot
.794 .29087 Mdot
.794 .29095 Mdot
.794 .29214 Mdot
.794 .29215 Mdot
.794 .29291 Mdot
.794 .29307 Mdot
.794 .2935 Mdot
.794 .2936 Mdot
.794 .29368 Mdot
.794 .2937 Mdot
.794 .29382 Mdot
.794 .29427 Mdot
.794 .29531 Mdot
.794 .296 Mdot
.794 .29601 Mdot
.794 .29677 Mdot
.794 .29716 Mdot
.794 .29819 Mdot
.794 .29933 Mdot
.794 .29952 Mdot
.794 .2997 Mdot
.794 .30111 Mdot
.794 .30115 Mdot
.794 .30185 Mdot
.794 .3023 Mdot
.794 .30238 Mdot
.794 .30311 Mdot
.794 .30323 Mdot
.794 .30332 Mdot
.794 .30398 Mdot
.794 .30406 Mdot
.794 .30489 Mdot
.794 .30519 Mdot
.794 .30562 Mdot
.794 .30591 Mdot
.794 .30725 Mdot
.794 .30818 Mdot
.794 .30846 Mdot
.794 .30957 Mdot
.794 .30978 Mdot
.794 .30995 Mdot
.794 .31027 Mdot
.794 .3107 Mdot
.794 .31256 Mdot
.794 .31293 Mdot
.794 .31527 Mdot
.794 .31535 Mdot
.794 .31691 Mdot
.794 .31694 Mdot
.794 .31712 Mdot
.794 .31755 Mdot
.794 .31829 Mdot
.794 .31854 Mdot
.794 .31865 Mdot
.794 .31871 Mdot
.794 .31904 Mdot
.794 .31909 Mdot
.794 .31997 Mdot
.794 .32048 Mdot
.794 .32209 Mdot
.794 .32261 Mdot
.794 .32358 Mdot
.794 .32358 Mdot
.794 .32381 Mdot
.794 .32414 Mdot
.794 .32574 Mdot
.794 .32644 Mdot
.794 .32748 Mdot
.794 .3277 Mdot
.794 .32775 Mdot
.794 .32914 Mdot
.794 .32924 Mdot
.794 .32935 Mdot
.794 .32966 Mdot
.794 .33106 Mdot
.794 .33154 Mdot
.794 .33159 Mdot
.794 .3331 Mdot
.794 .33406 Mdot
.794 .33531 Mdot
.794 .33597 Mdot
.794 .33657 Mdot
.794 .33666 Mdot
.794 .34291 Mdot
.794 .34302 Mdot
.794 .34419 Mdot
.794 .3442 Mdot
.794 .34442 Mdot
.794 .3449 Mdot
.794 .34604 Mdot
.794 .34833 Mdot
.794 .34863 Mdot
.794 .3492 Mdot
.794 .35001 Mdot
.794 .35027 Mdot
.794 .35046 Mdot
.794 .35057 Mdot
.794 .35092 Mdot
.794 .35232 Mdot
.794 .35371 Mdot
.794 .35382 Mdot
.794 .35463 Mdot
.794 .35475 Mdot
.794 .35515 Mdot
.794 .35555 Mdot
.794 .35563 Mdot
.794 .35575 Mdot
.794 .35603 Mdot
.794 .35607 Mdot
.794 .3564 Mdot
.794 .35676 Mdot
.794 .3582 Mdot
.794 .35825 Mdot
.794 .3584 Mdot
.794 .35992 Mdot
.794 .36023 Mdot
.794 .36232 Mdot
.794 .36312 Mdot
.794 .36387 Mdot
.794 .36444 Mdot
.794 .36468 Mdot
.794 .36473 Mdot
.794 .36506 Mdot
.794 .36574 Mdot
.794 .36593 Mdot
.794 .36631 Mdot
.794 .36636 Mdot
.794 .36664 Mdot
.794 .36784 Mdot
.794 .36784 Mdot
.794 .36787 Mdot
.794 .36842 Mdot
.794 .3685 Mdot
.794 .3702 Mdot
.794 .37028 Mdot
.794 .3706 Mdot
.794 .37076 Mdot
.794 .37209 Mdot
.794 .37235 Mdot
.794 .37315 Mdot
.794 .3734 Mdot
.794 .3737 Mdot
.794 .37405 Mdot
.794 .37465 Mdot
.794 .37494 Mdot
.794 .37529 Mdot
.794 .37665 Mdot
.794 .37874 Mdot
.794 .38001 Mdot
.794 .38004 Mdot
.794 .38006 Mdot
.794 .38009 Mdot
.794 .3802 Mdot
.794 .38064 Mdot
.794 .38118 Mdot
.794 .38311 Mdot
.794 .38368 Mdot
.794 .38375 Mdot
.794 .3842 Mdot
.794 .38547 Mdot
.794 .38587 Mdot
.794 .38602 Mdot
.794 .3862 Mdot
.794 .38627 Mdot
.794 .38675 Mdot
.794 .38855 Mdot
.794 .39062 Mdot
.794 .39273 Mdot
.794 .39419 Mdot
.794 .39505 Mdot
.794 .39551 Mdot
.794 .39553 Mdot
.794 .39556 Mdot
.794 .39581 Mdot
.794 .39759 Mdot
.794 .3978 Mdot
.794 .39858 Mdot
.794 .39858 Mdot
.794 .40004 Mdot
.794 .40013 Mdot
.794 .40078 Mdot
.794 .40177 Mdot
.794 .40191 Mdot
.794 .40312 Mdot
.794 .40427 Mdot
.794 .40556 Mdot
.794 .40662 Mdot
.794 .40705 Mdot
.794 .40739 Mdot
.794 .40845 Mdot
.794 .40872 Mdot
.794 .40885 Mdot
.794 .40898 Mdot
.794 .4095 Mdot
.794 .40961 Mdot
.794 .41032 Mdot
.794 .41159 Mdot
.794 .41202 Mdot
.794 .41376 Mdot
.794 .41418 Mdot
.794 .41472 Mdot
.794 .41487 Mdot
.794 .41538 Mdot
.794 .41598 Mdot
.794 .4161 Mdot
.794 .4173 Mdot
.794 .41736 Mdot
.794 .41892 Mdot
.794 .41926 Mdot
.794 .41949 Mdot
.794 .41994 Mdot
.794 .42041 Mdot
.794 .42071 Mdot
.794 .42103 Mdot
.794 .42167 Mdot
.794 .4224 Mdot
.794 .42334 Mdot
.794 .42341 Mdot
.794 .42397 Mdot
.794 .42398 Mdot
.794 .42444 Mdot
.794 .42481 Mdot
.794 .42484 Mdot
.794 .42514 Mdot
.794 .42575 Mdot
.794 .42741 Mdot
.794 .42747 Mdot
.794 .42777 Mdot
.794 .42866 Mdot
.794 .43032 Mdot
.794 .4311 Mdot
.794 .43229 Mdot
.794 .43249 Mdot
.794 .43288 Mdot
.794 .4331 Mdot
.794 .43401 Mdot
.794 .43442 Mdot
.794 .43508 Mdot
.794 .43512 Mdot
.794 .43516 Mdot
.794 .43584 Mdot
.794 .43603 Mdot
.794 .43753 Mdot
.794 .43803 Mdot
.794 .43806 Mdot
.794 .44054 Mdot
.794 .44281 Mdot
.794 .44304 Mdot
.794 .44427 Mdot
.794 .4454 Mdot
.794 .44661 Mdot
.794 .44932 Mdot
.794 .44967 Mdot
.794 .44982 Mdot
.794 .45066 Mdot
.794 .45069 Mdot
.794 .45137 Mdot
.794 .45159 Mdot
.794 .45211 Mdot
.794 .45263 Mdot
.794 .45324 Mdot
.794 .45338 Mdot
.794 .45527 Mdot
.794 .45529 Mdot
.794 .45648 Mdot
.794 .45674 Mdot
.794 .45742 Mdot
.794 .45758 Mdot
.794 .45771 Mdot
.794 .45774 Mdot
.794 .45793 Mdot
.794 .45864 Mdot
.794 .4603 Mdot
.794 .4614 Mdot
.794 .46141 Mdot
.794 .46262 Mdot
.794 .46323 Mdot
.794 .46487 Mdot
.794 .46669 Mdot
.794 .46699 Mdot
.794 .46727 Mdot
.794 .46952 Mdot
.794 .46957 Mdot
.794 .47068 Mdot
.794 .4714 Mdot
.794 .47152 Mdot
.794 .47269 Mdot
.794 .47287 Mdot
.794 .47302 Mdot
.794 .47408 Mdot
.794 .47419 Mdot
.794 .47551 Mdot
.794 .47598 Mdot
.794 .47667 Mdot
.794 .47713 Mdot
.794 .47926 Mdot
.794 .48074 Mdot
.794 .48118 Mdot
.794 .48294 Mdot
.794 .48328 Mdot
.794 .48355 Mdot
.794 .48405 Mdot
.796 .01475 Mdot
.796 .01477 Mdot
.796 .0148 Mdot
.796 .01485 Mdot
.796 .01491 Mdot
.796 .01493 Mdot
.796 .015 Mdot
.796 .01503 Mdot
.796 .01505 Mdot
.796 .01516 Mdot
.796 .01521 Mdot
.796 .01525 Mdot
.796 .01542 Mdot
.796 .0155 Mdot
.796 .01557 Mdot
.796 .01584 Mdot
.796 .01597 Mdot
.796 .01607 Mdot
.796 .01651 Mdot
.796 .01671 Mdot
.796 .01679 Mdot
.796 .0168 Mdot
.796 .01687 Mdot
.796 .01758 Mdot
.796 .01789 Mdot
.796 .01801 Mdot
.796 .01804 Mdot
.796 .01815 Mdot
.796 .01927 Mdot
.796 .01977 Mdot
.796 .01996 Mdot
.796 .02001 Mdot
.796 .02019 Mdot
.796 .02062 Mdot
.796 .0208 Mdot
.796 .02105 Mdot
.796 .0211 Mdot
.796 .02197 Mdot
.796 .02276 Mdot
.796 .02307 Mdot
.796 .02314 Mdot
.796 .02343 Mdot
.796 .02401 Mdot
.796 .02411 Mdot
.796 .02441 Mdot
.796 .0248 Mdot
.796 .02488 Mdot
.796 .02627 Mdot
.796 .02712 Mdot
.796 .02727 Mdot
.796 .02749 Mdot
.796 .02752 Mdot
.796 .02801 Mdot
.796 .02812 Mdot
.796 .02834 Mdot
.796 .02858 Mdot
.796 .02875 Mdot
.796 .02951 Mdot
.796 .02968 Mdot
.796 .03015 Mdot
.796 .03063 Mdot
.796 .03078 Mdot
.796 .0309 Mdot
.796 .03122 Mdot
.796 .03124 Mdot
.796 .03179 Mdot
.796 .03288 Mdot
.796 .0331 Mdot
.796 .03446 Mdot
.796 .03471 Mdot
.796 .03505 Mdot
.796 .03511 Mdot
.796 .03515 Mdot
.796 .03515 Mdot
.796 .03588 Mdot
.796 .03606 Mdot
.796 .03641 Mdot
.796 .03679 Mdot
.796 .0368 Mdot
.796 .03706 Mdot
.796 .03827 Mdot
.796 .03853 Mdot
.796 .03923 Mdot
.796 .03925 Mdot
.796 .03928 Mdot
.796 .03928 Mdot
.796 .04005 Mdot
.796 .04025 Mdot
.796 .04029 Mdot
.796 .04048 Mdot
.796 .04091 Mdot
.796 .04099 Mdot
.796 .04102 Mdot
.796 .0419 Mdot
.796 .04217 Mdot
.796 .04224 Mdot
.796 .04232 Mdot
.796 .0427 Mdot
.796 .04288 Mdot
.796 .04326 Mdot
.796 .04363 Mdot
.796 .04399 Mdot
.796 .0444 Mdot
.796 .04514 Mdot
.796 .04615 Mdot
.796 .04654 Mdot
.796 .04708 Mdot
.796 .04718 Mdot
.796 .04725 Mdot
.796 .04725 Mdot
.796 .04794 Mdot
.796 .04837 Mdot
.796 .04841 Mdot
.796 .04846 Mdot
.796 .0487 Mdot
.796 .04925 Mdot
.796 .04931 Mdot
.796 .04964 Mdot
.796 .04986 Mdot
.796 .04987 Mdot
.796 .05028 Mdot
.796 .05126 Mdot
.796 .05221 Mdot
.796 .05248 Mdot
.796 .05263 Mdot
.796 .05343 Mdot
.796 .05349 Mdot
.796 .05375 Mdot
.796 .05377 Mdot
.796 .05382 Mdot
.796 .05383 Mdot
.796 .05386 Mdot
.796 .0542 Mdot
.796 .05467 Mdot
.796 .05504 Mdot
.796 .05537 Mdot
.796 .05542 Mdot
.796 .05572 Mdot
.796 .05573 Mdot
.796 .05584 Mdot
.796 .05642 Mdot
.796 .05655 Mdot
.796 .0566 Mdot
.796 .05799 Mdot
.796 .05843 Mdot
.796 .05854 Mdot
.796 .05867 Mdot
.796 .05926 Mdot
.796 .05956 Mdot
.796 .06015 Mdot
.796 .06075 Mdot
.796 .06132 Mdot
.796 .06197 Mdot
.796 .06212 Mdot
.796 .06315 Mdot
.796 .06343 Mdot
.796 .06476 Mdot
.796 .06538 Mdot
.796 .06624 Mdot
.796 .06639 Mdot
.796 .06651 Mdot
.796 .06651 Mdot
.796 .06761 Mdot
.796 .06829 Mdot
.796 .06836 Mdot
.796 .06844 Mdot
.796 .06882 Mdot
.796 .06912 Mdot
.796 .0697 Mdot
.796 .06979 Mdot
.796 .07031 Mdot
.796 .07067 Mdot
.796 .07069 Mdot
.796 .07094 Mdot
.796 .07134 Mdot
.796 .07185 Mdot
.796 .07246 Mdot
.796 .07289 Mdot
.796 .07364 Mdot
.796 .07366 Mdot
.796 .07441 Mdot
.796 .07448 Mdot
.796 .07484 Mdot
.796 .07508 Mdot
.796 .0754 Mdot
.796 .07609 Mdot
.796 .07635 Mdot
.796 .07644 Mdot
.796 .07666 Mdot
.796 .07685 Mdot
.796 .07689 Mdot
.796 .07698 Mdot
.796 .07699 Mdot
.796 .07703 Mdot
.796 .07712 Mdot
.796 .07758 Mdot
.796 .07833 Mdot
.796 .07892 Mdot
.796 .07914 Mdot
.796 .07915 Mdot
.796 .07943 Mdot
.796 .07952 Mdot
.796 .07997 Mdot
.796 .08 Mdot
.796 .08001 Mdot
.796 .08019 Mdot
.796 .08101 Mdot
.796 .08111 Mdot
.796 .08132 Mdot
.796 .08139 Mdot
.796 .08357 Mdot
.796 .08358 Mdot
.796 .0836 Mdot
.796 .08431 Mdot
.796 .08448 Mdot
.796 .08459 Mdot
.796 .08469 Mdot
.796 .0849 Mdot
.796 .08564 Mdot
.796 .08588 Mdot
.796 .08611 Mdot
.796 .08706 Mdot
.796 .08708 Mdot
.796 .08716 Mdot
.796 .088 Mdot
.796 .08892 Mdot
.796 .08995 Mdot
.796 .09018 Mdot
.796 .09182 Mdot
.796 .09182 Mdot
.796 .09227 Mdot
.796 .09235 Mdot
.796 .09262 Mdot
.796 .09343 Mdot
.796 .09409 Mdot
.796 .09438 Mdot
.796 .09538 Mdot
.796 .09675 Mdot
.796 .09699 Mdot
.796 .09717 Mdot
.796 .09717 Mdot
.796 .0973 Mdot
.796 .09892 Mdot
.796 .1 Mdot
.796 .10008 Mdot
.796 .10012 Mdot
.796 .10025 Mdot
.796 .10035 Mdot
.796 .10085 Mdot
.796 .10133 Mdot
.796 .10224 Mdot
.796 .1024 Mdot
.796 .10322 Mdot
.796 .10379 Mdot
.796 .10382 Mdot
.796 .10414 Mdot
.796 .10423 Mdot
.796 .10486 Mdot
.796 .10568 Mdot
.796 .10591 Mdot
.796 .10624 Mdot
.796 .10665 Mdot
.796 .10722 Mdot
.796 .10733 Mdot
.796 .1077 Mdot
.796 .10853 Mdot
.796 .10855 Mdot
.796 .10882 Mdot
.796 .10975 Mdot
.796 .10986 Mdot
.796 .11044 Mdot
.796 .11075 Mdot
.796 .11082 Mdot
.796 .11091 Mdot
.796 .11133 Mdot
.796 .11243 Mdot
.796 .11252 Mdot
.796 .11284 Mdot
.796 .11298 Mdot
.796 .11333 Mdot
.796 .11364 Mdot
.796 .1137 Mdot
.796 .11384 Mdot
.796 .11385 Mdot
.796 .11391 Mdot
.796 .11393 Mdot
.796 .11407 Mdot
.796 .11469 Mdot
.796 .11479 Mdot
.796 .11599 Mdot
.796 .11619 Mdot
.796 .11638 Mdot
.796 .11693 Mdot
.796 .11728 Mdot
.796 .1173 Mdot
.796 .11775 Mdot
.796 .11789 Mdot
.796 .11842 Mdot
.796 .1186 Mdot
.796 .11864 Mdot
.796 .11866 Mdot
.796 .11895 Mdot
.796 .11898 Mdot
.796 .11944 Mdot
.796 .12025 Mdot
.796 .12042 Mdot
.796 .12074 Mdot
.796 .12087 Mdot
.796 .12092 Mdot
.796 .12136 Mdot
.796 .12215 Mdot
.796 .12251 Mdot
.796 .12305 Mdot
.796 .12434 Mdot
.796 .12435 Mdot
.796 .12439 Mdot
.796 .12551 Mdot
.796 .12569 Mdot
.796 .12578 Mdot
.796 .12595 Mdot
.796 .12611 Mdot
.796 .12645 Mdot
.796 .12671 Mdot
.796 .12762 Mdot
.796 .12801 Mdot
.796 .12831 Mdot
.796 .12837 Mdot
.796 .12979 Mdot
.796 .12988 Mdot
.796 .12993 Mdot
.796 .13004 Mdot
.796 .13139 Mdot
.796 .13189 Mdot
.796 .13284 Mdot
.796 .13368 Mdot
.796 .13445 Mdot
.796 .13449 Mdot
.796 .13454 Mdot
.796 .13486 Mdot
.796 .13547 Mdot
.796 .13547 Mdot
.796 .13561 Mdot
.796 .13588 Mdot
.796 .13644 Mdot
.796 .13746 Mdot
.796 .13747 Mdot
.796 .13771 Mdot
.796 .13787 Mdot
.796 .13818 Mdot
.796 .13822 Mdot
.796 .13831 Mdot
.796 .13874 Mdot
.796 .13892 Mdot
.796 .14003 Mdot
.796 .14044 Mdot
.796 .14108 Mdot
.796 .14128 Mdot
.796 .14154 Mdot
.796 .14313 Mdot
.796 .14531 Mdot
.796 .14569 Mdot
.796 .14598 Mdot
.796 .14599 Mdot
.796 .14619 Mdot
.796 .14659 Mdot
.796 .14673 Mdot
.796 .14844 Mdot
.796 .14845 Mdot
.796 .1487 Mdot
.796 .14877 Mdot
.796 .15049 Mdot
.796 .15062 Mdot
.796 .15069 Mdot
.796 .15089 Mdot
.796 .15105 Mdot
.796 .15185 Mdot
.796 .1526 Mdot
.796 .15406 Mdot
.796 .15431 Mdot
.796 .15442 Mdot
.796 .1547 Mdot
.796 .15518 Mdot
.796 .15562 Mdot
.796 .15653 Mdot
.796 .15658 Mdot
.796 .15708 Mdot
.796 .15722 Mdot
.796 .1577 Mdot
.796 .1581 Mdot
.796 .15823 Mdot
.796 .15888 Mdot
.796 .15914 Mdot
.796 .15953 Mdot
.796 .1599 Mdot
.796 .16042 Mdot
.796 .16086 Mdot
.796 .16108 Mdot
.796 .16131 Mdot
.796 .16186 Mdot
.796 .1619 Mdot
.796 .16199 Mdot
.796 .16216 Mdot
.796 .16275 Mdot
.796 .16406 Mdot
.796 .1641 Mdot
.796 .16452 Mdot
.796 .16452 Mdot
.796 .16458 Mdot
.796 .166 Mdot
.796 .16619 Mdot
.796 .16711 Mdot
.796 .1676 Mdot
.796 .16771 Mdot
.796 .16786 Mdot
.796 .16852 Mdot
.796 .17004 Mdot
.796 .17027 Mdot
.796 .17042 Mdot
.796 .17072 Mdot
.796 .17093 Mdot
.796 .17115 Mdot
.796 .17165 Mdot
.796 .17171 Mdot
.796 .1722 Mdot
.796 .17224 Mdot
.796 .1723 Mdot
.796 .17252 Mdot
.796 .17254 Mdot
.796 .17264 Mdot
.796 .17266 Mdot
.796 .17288 Mdot
.796 .17346 Mdot
.796 .17387 Mdot
.796 .17403 Mdot
.796 .17429 Mdot
.796 .17431 Mdot
.796 .17518 Mdot
.796 .17594 Mdot
.796 .17626 Mdot
.796 .17656 Mdot
.796 .1772 Mdot
.796 .17743 Mdot
.796 .17744 Mdot
.796 .17801 Mdot
.796 .17803 Mdot
.796 .17874 Mdot
.796 .17897 Mdot
.796 .17941 Mdot
.796 .17957 Mdot
.796 .17981 Mdot
.796 .17981 Mdot
.796 .1801 Mdot
.796 .18016 Mdot
.796 .1802 Mdot
.796 .18066 Mdot
.796 .1807 Mdot
.796 .18071 Mdot
.796 .18079 Mdot
.796 .1812 Mdot
.796 .1812 Mdot
.796 .18127 Mdot
.796 .18143 Mdot
.796 .18217 Mdot
.796 .18273 Mdot
.796 .183 Mdot
.796 .18351 Mdot
.796 .18371 Mdot
.796 .18379 Mdot
.796 .18449 Mdot
.796 .18449 Mdot
.796 .18576 Mdot
.796 .18616 Mdot
.796 .18633 Mdot
.796 .18682 Mdot
.796 .18719 Mdot
.796 .18784 Mdot
.796 .18792 Mdot
.796 .18912 Mdot
.796 .18923 Mdot
.796 .18926 Mdot
.796 .18931 Mdot
.796 .1897 Mdot
.796 .1911 Mdot
.796 .19139 Mdot
.796 .19143 Mdot
.796 .19153 Mdot
.796 .1918 Mdot
.796 .19206 Mdot
.796 .1926 Mdot
.796 .19302 Mdot
.796 .19446 Mdot
.796 .19452 Mdot
.796 .19509 Mdot
.796 .19547 Mdot
.796 .19555 Mdot
.796 .19565 Mdot
.796 .19582 Mdot
.796 .19703 Mdot
.796 .19791 Mdot
.796 .19806 Mdot
.796 .19813 Mdot
.796 .19832 Mdot
.796 .1994 Mdot
.796 .19961 Mdot
.796 .20023 Mdot
.796 .20046 Mdot
.796 .20052 Mdot
.796 .20055 Mdot
.796 .20126 Mdot
.796 .20127 Mdot
.796 .20277 Mdot
.796 .20285 Mdot
.796 .20294 Mdot
.796 .20296 Mdot
.796 .20411 Mdot
.796 .20534 Mdot
.796 .2054 Mdot
.796 .20548 Mdot
.796 .20582 Mdot
.796 .20598 Mdot
.796 .20672 Mdot
.796 .20696 Mdot
.796 .20696 Mdot
.796 .20718 Mdot
.796 .20761 Mdot
.796 .20851 Mdot
.796 .20851 Mdot
.796 .20916 Mdot
.796 .21012 Mdot
.796 .21012 Mdot
.796 .21013 Mdot
.796 .21014 Mdot
.796 .21052 Mdot
.796 .21078 Mdot
.796 .21128 Mdot
.796 .21131 Mdot
.796 .21134 Mdot
.796 .21149 Mdot
.796 .21156 Mdot
.796 .21171 Mdot
.796 .21216 Mdot
.796 .21245 Mdot
.796 .21355 Mdot
.796 .21372 Mdot
.796 .21376 Mdot
.796 .21409 Mdot
.796 .21422 Mdot
.796 .21486 Mdot
.796 .21535 Mdot
.796 .21572 Mdot
.796 .21574 Mdot
.796 .21589 Mdot
.796 .21602 Mdot
.796 .21621 Mdot
.796 .21662 Mdot
.796 .21667 Mdot
.796 .21915 Mdot
.796 .21967 Mdot
.796 .22191 Mdot
.796 .22263 Mdot
.796 .22299 Mdot
.796 .22323 Mdot
.796 .22369 Mdot
.796 .2237 Mdot
.796 .22403 Mdot
.796 .22439 Mdot
.796 .22466 Mdot
.796 .22488 Mdot
.796 .22507 Mdot
.796 .22587 Mdot
.796 .22587 Mdot
.796 .22619 Mdot
.796 .2266 Mdot
.796 .22761 Mdot
.796 .22762 Mdot
.796 .22801 Mdot
.796 .22814 Mdot
.796 .22852 Mdot
.796 .229 Mdot
.796 .22903 Mdot
.796 .23087 Mdot
.796 .23108 Mdot
.796 .23118 Mdot
.796 .2315 Mdot
.796 .23176 Mdot
.796 .23303 Mdot
.796 .23413 Mdot
.796 .23423 Mdot
.796 .23573 Mdot
.796 .23643 Mdot
.796 .23656 Mdot
.796 .23694 Mdot
.796 .23713 Mdot
.796 .23757 Mdot
.796 .23834 Mdot
.796 .2384 Mdot
.796 .23903 Mdot
.796 .23958 Mdot
.796 .23989 Mdot
.796 .24048 Mdot
.796 .24056 Mdot
.796 .24136 Mdot
.796 .24158 Mdot
.796 .24176 Mdot
.796 .24235 Mdot
.796 .24252 Mdot
.796 .24284 Mdot
.796 .24298 Mdot
.796 .24319 Mdot
.796 .24423 Mdot
.796 .24463 Mdot
.796 .24526 Mdot
.796 .24585 Mdot
.796 .24668 Mdot
.796 .24738 Mdot
.796 .24769 Mdot
.796 .24772 Mdot
.796 .24809 Mdot
.796 .24809 Mdot
.796 .24815 Mdot
.796 .24825 Mdot
.796 .24847 Mdot
.796 .24897 Mdot
.796 .24904 Mdot
.796 .24918 Mdot
.796 .24945 Mdot
.796 .25005 Mdot
.796 .25038 Mdot
.796 .25248 Mdot
.796 .25253 Mdot
.796 .25321 Mdot
.796 .25321 Mdot
.796 .25331 Mdot
.796 .25557 Mdot
.796 .25568 Mdot
.796 .25587 Mdot
.796 .25686 Mdot
.796 .25702 Mdot
.796 .25733 Mdot
.796 .25743 Mdot
.796 .25811 Mdot
.796 .25828 Mdot
.796 .2585 Mdot
.796 .25852 Mdot
.796 .25955 Mdot
.796 .25958 Mdot
.796 .26173 Mdot
.796 .262 Mdot
.796 .26236 Mdot
.796 .2626 Mdot
.796 .26308 Mdot
.796 .2634 Mdot
.796 .26341 Mdot
.796 .26376 Mdot
.796 .26456 Mdot
.796 .26465 Mdot
.796 .26543 Mdot
.796 .26549 Mdot
.796 .26559 Mdot
.796 .26594 Mdot
.796 .26597 Mdot
.796 .26613 Mdot
.796 .26616 Mdot
.796 .26652 Mdot
.796 .26743 Mdot
.796 .26809 Mdot
.796 .26835 Mdot
.796 .26875 Mdot
.796 .26878 Mdot
.796 .26926 Mdot
.796 .26949 Mdot
.796 .27017 Mdot
.796 .27139 Mdot
.796 .27176 Mdot
.796 .2719 Mdot
.796 .27238 Mdot
.796 .27331 Mdot
.796 .2734 Mdot
.796 .27364 Mdot
.796 .27376 Mdot
.796 .27377 Mdot
.796 .27405 Mdot
.796 .27467 Mdot
.796 .27471 Mdot
.796 .27472 Mdot
.796 .27585 Mdot
.796 .2762 Mdot
.796 .27691 Mdot
.796 .27716 Mdot
.796 .27754 Mdot
.796 .27755 Mdot
.796 .27801 Mdot
.796 .27811 Mdot
.796 .27817 Mdot
.796 .2789 Mdot
.796 .27896 Mdot
.796 .27898 Mdot
.796 .27911 Mdot
.796 .27961 Mdot
.796 .27975 Mdot
.796 .27976 Mdot
.796 .27987 Mdot
.796 .28013 Mdot
.796 .28131 Mdot
.796 .2822 Mdot
.796 .28262 Mdot
.796 .28317 Mdot
.796 .28344 Mdot
.796 .28376 Mdot
.796 .28376 Mdot
.796 .28388 Mdot
.796 .28405 Mdot
.796 .28481 Mdot
.796 .28499 Mdot
.796 .285 Mdot
.796 .28702 Mdot
.796 .28765 Mdot
.796 .28792 Mdot
.796 .2887 Mdot
.796 .28917 Mdot
.796 .28929 Mdot
.796 .29003 Mdot
.796 .29033 Mdot
.796 .29045 Mdot
.796 .29237 Mdot
.796 .29252 Mdot
.796 .29255 Mdot
.796 .29259 Mdot
.796 .29268 Mdot
.796 .2933 Mdot
.796 .29552 Mdot
.796 .29599 Mdot
.796 .29605 Mdot
.796 .29621 Mdot
.796 .29663 Mdot
.796 .29705 Mdot
.796 .29791 Mdot
.796 .29857 Mdot
.796 .30088 Mdot
.796 .30097 Mdot
.796 .30187 Mdot
.796 .30248 Mdot
.796 .30261 Mdot
.796 .30277 Mdot
.796 .30303 Mdot
.796 .30496 Mdot
.796 .30637 Mdot
.796 .3066 Mdot
.796 .30671 Mdot
.796 .30701 Mdot
.796 .30873 Mdot
.796 .30907 Mdot
.796 .31006 Mdot
.796 .31042 Mdot
.796 .31052 Mdot
.796 .31057 Mdot
.796 .3117 Mdot
.796 .31171 Mdot
.796 .3141 Mdot
.796 .31422 Mdot
.796 .31438 Mdot
.796 .31441 Mdot
.796 .31623 Mdot
.796 .31819 Mdot
.796 .31828 Mdot
.796 .31842 Mdot
.796 .31896 Mdot
.796 .31921 Mdot
.796 .32039 Mdot
.796 .32076 Mdot
.796 .32078 Mdot
.796 .32112 Mdot
.796 .32181 Mdot
.796 .32323 Mdot
.796 .32323 Mdot
.796 .32427 Mdot
.796 .3258 Mdot
.796 .32581 Mdot
.796 .32582 Mdot
.796 .32583 Mdot
.796 .32644 Mdot
.796 .32685 Mdot
.796 .32764 Mdot
.796 .32769 Mdot
.796 .32774 Mdot
.796 .32797 Mdot
.796 .32809 Mdot
.796 .32832 Mdot
.796 .32904 Mdot
.796 .3295 Mdot
.796 .33127 Mdot
.796 .33153 Mdot
.796 .3316 Mdot
.796 .33213 Mdot
.796 .33233 Mdot
.796 .33335 Mdot
.796 .33412 Mdot
.796 .33471 Mdot
.796 .33475 Mdot
.796 .33498 Mdot
.796 .3352 Mdot
.796 .3355 Mdot
.796 .33615 Mdot
.796 .33623 Mdot
.796 .34017 Mdot
.796 .341 Mdot
.796 .34457 Mdot
.796 .34571 Mdot
.796 .34629 Mdot
.796 .34667 Mdot
.796 .34741 Mdot
.796 .34742 Mdot
.796 .34794 Mdot
.796 .34852 Mdot
.796 .34895 Mdot
.796 .3493 Mdot
.796 .3496 Mdot
.796 .35087 Mdot
.796 .35087 Mdot
.796 .35139 Mdot
.796 .35204 Mdot
.796 .35365 Mdot
.796 .35366 Mdot
.796 .35428 Mdot
.796 .35448 Mdot
.796 .3551 Mdot
.796 .35585 Mdot
.796 .3559 Mdot
.796 .35883 Mdot
.796 .35916 Mdot
.796 .35933 Mdot
.796 .35984 Mdot
.796 .36026 Mdot
.796 .36227 Mdot
.796 .36402 Mdot
.796 .36419 Mdot
.796 .36657 Mdot
.796 .36768 Mdot
.796 .36789 Mdot
.796 .3685 Mdot
.796 .3688 Mdot
.796 .3695 Mdot
.796 .37072 Mdot
.796 .37082 Mdot
.796 .37183 Mdot
.796 .37271 Mdot
.796 .37319 Mdot
.796 .37414 Mdot
.796 .37426 Mdot
.796 .37554 Mdot
.796 .37589 Mdot
.796 .37618 Mdot
.796 .37711 Mdot
.796 .37738 Mdot
.796 .37788 Mdot
.796 .37811 Mdot
.796 .37845 Mdot
.796 .38011 Mdot
.796 .38075 Mdot
.796 .38175 Mdot
.796 .38268 Mdot
.796 .384 Mdot
.796 .38512 Mdot
.796 .38561 Mdot
.796 .38567 Mdot
.796 .38625 Mdot
.796 .38625 Mdot
.796 .38634 Mdot
.796 .38651 Mdot
.796 .38686 Mdot
.796 .38765 Mdot
.796 .38776 Mdot
.796 .38798 Mdot
.796 .38841 Mdot
.796 .38937 Mdot
.796 .3899 Mdot
.796 .39323 Mdot
.796 .39332 Mdot
.796 .3944 Mdot
.796 .3944 Mdot
.796 .39455 Mdot
.796 .39815 Mdot
.796 .39833 Mdot
.796 .39863 Mdot
.796 .40021 Mdot
.796 .40046 Mdot
.796 .40095 Mdot
.796 .40111 Mdot
.796 .4022 Mdot
.796 .40248 Mdot
.796 .40282 Mdot
.796 .40285 Mdot
.796 .4045 Mdot
.796 .40454 Mdot
.796 .40796 Mdot
.796 .40839 Mdot
.796 .40897 Mdot
.796 .40934 Mdot
.796 .41011 Mdot
.796 .41063 Mdot
.796 .41064 Mdot
.796 .41119 Mdot
.796 .41246 Mdot
.796 .4126 Mdot
.796 .41385 Mdot
.796 .41395 Mdot
.796 .4141 Mdot
.796 .41466 Mdot
.796 .41472 Mdot
.796 .41497 Mdot
.796 .41502 Mdot
.796 .41558 Mdot
.796 .41704 Mdot
.796 .41808 Mdot
.796 .4185 Mdot
.796 .41914 Mdot
.796 .41919 Mdot
.796 .41995 Mdot
.796 .42031 Mdot
.796 .4214 Mdot
.796 .42334 Mdot
.796 .42394 Mdot
.796 .42415 Mdot
.796 .42492 Mdot
.796 .4264 Mdot
.796 .42654 Mdot
.796 .42693 Mdot
.796 .42711 Mdot
.796 .42713 Mdot
.796 .42758 Mdot
.796 .42857 Mdot
.796 .42863 Mdot
.796 .42864 Mdot
.796 .43044 Mdot
.796 .431 Mdot
.796 .43213 Mdot
.796 .43253 Mdot
.796 .43314 Mdot
.796 .43315 Mdot
.796 .43388 Mdot
.796 .43404 Mdot
.796 .43413 Mdot
.796 .43529 Mdot
.796 .4354 Mdot
.796 .43542 Mdot
.796 .43563 Mdot
.796 .43642 Mdot
.796 .43666 Mdot
.796 .43667 Mdot
.796 .43685 Mdot
.796 .43725 Mdot
.796 .43913 Mdot
.796 .44054 Mdot
.796 .44122 Mdot
.796 .4421 Mdot
.796 .44253 Mdot
.796 .44303 Mdot
.796 .44303 Mdot
.796 .44323 Mdot
.796 .44349 Mdot
.796 .4447 Mdot
.796 .445 Mdot
.796 .44501 Mdot
.796 .44822 Mdot
.796 .44922 Mdot
.796 .44966 Mdot
.796 .4509 Mdot
.796 .45165 Mdot
.796 .45184 Mdot
.796 .45301 Mdot
.796 .45349 Mdot
.796 .45369 Mdot
.796 .45674 Mdot
.796 .45699 Mdot
.796 .45702 Mdot
.796 .45709 Mdot
.796 .45723 Mdot
.796 .45822 Mdot
.796 .46175 Mdot
.796 .4625 Mdot
.796 .4626 Mdot
.796 .46285 Mdot
.796 .46353 Mdot
.796 .46419 Mdot
.796 .46556 Mdot
.796 .46661 Mdot
.796 .47028 Mdot
.796 .47043 Mdot
.796 .47186 Mdot
.796 .47283 Mdot
.796 .47304 Mdot
.796 .4733 Mdot
.796 .47372 Mdot
.796 .47678 Mdot
.796 .47903 Mdot
.796 .47939 Mdot
.796 .47957 Mdot
.796 .48005 Mdot
.796 .48279 Mdot
.796 .48333 Mdot
.796 .4849 Mdot
.798 .01574 Mdot
.798 .01635 Mdot
.798 .01732 Mdot
.798 .01845 Mdot
.798 .01888 Mdot
.798 .01925 Mdot
.798 .02027 Mdot
.798 .02068 Mdot
.798 .02136 Mdot
.798 .02195 Mdot
.798 .0229 Mdot
.798 .02359 Mdot
.798 .02361 Mdot
.798 .02423 Mdot
.798 .0243 Mdot
.798 .02462 Mdot
.798 .02516 Mdot
.798 .02532 Mdot
.798 .02626 Mdot
.798 .02628 Mdot
.798 .02773 Mdot
.798 .02778 Mdot
.798 .02859 Mdot
.798 .02865 Mdot
.798 .02887 Mdot
.798 .02891 Mdot
.798 .0295 Mdot
.798 .02989 Mdot
.798 .0299 Mdot
.798 .03001 Mdot
.798 .03053 Mdot
.798 .0308 Mdot
.798 .03139 Mdot
.798 .03164 Mdot
.798 .03203 Mdot
.798 .03313 Mdot
.798 .03317 Mdot
.798 .03477 Mdot
.798 .03488 Mdot
.798 .03548 Mdot
.798 .0355 Mdot
.798 .03554 Mdot
.798 .03557 Mdot
.798 .03583 Mdot
.798 .03662 Mdot
.798 .03686 Mdot
.798 .03696 Mdot
.798 .03731 Mdot
.798 .03738 Mdot
.798 .03831 Mdot
.798 .03857 Mdot
.798 .03894 Mdot
.798 .03896 Mdot
.798 .03898 Mdot
.798 .03913 Mdot
.798 .03996 Mdot
.798 .04039 Mdot
.798 .04133 Mdot
.798 .04172 Mdot
.798 .04184 Mdot
.798 .04235 Mdot
.798 .04411 Mdot
.798 .04416 Mdot
.798 .04551 Mdot
.798 .04602 Mdot
.798 .04672 Mdot
.798 .0469 Mdot
.798 .04704 Mdot
.798 .04715 Mdot
.798 .04786 Mdot
.798 .04789 Mdot
.798 .04796 Mdot
.798 .048 Mdot
.798 .04842 Mdot
.798 .0491 Mdot
.798 .04966 Mdot
.798 .04967 Mdot
.798 .05006 Mdot
.798 .0501 Mdot
.798 .05021 Mdot
.798 .05049 Mdot
.798 .05077 Mdot
.798 .05088 Mdot
.798 .05142 Mdot
.798 .05182 Mdot
.798 .05237 Mdot
.798 .05278 Mdot
.798 .05328 Mdot
.798 .05338 Mdot
.798 .0534 Mdot
.798 .05344 Mdot
.798 .05362 Mdot
.798 .05368 Mdot
.798 .05426 Mdot
.798 .055 Mdot
.798 .05522 Mdot
.798 .05525 Mdot
.798 .05569 Mdot
.798 .05718 Mdot
.798 .05781 Mdot
.798 .05793 Mdot
.798 .05801 Mdot
.798 .05882 Mdot
.798 .06026 Mdot
.798 .06163 Mdot
.798 .06171 Mdot
.798 .06387 Mdot
.798 .06468 Mdot
.798 .06557 Mdot
.798 .0658 Mdot
.798 .06592 Mdot
.798 .06607 Mdot
.798 .06631 Mdot
.798 .06648 Mdot
.798 .06744 Mdot
.798 .06761 Mdot
.798 .06767 Mdot
.798 .06777 Mdot
.798 .06784 Mdot
.798 .06791 Mdot
.798 .06851 Mdot
.798 .06905 Mdot
.798 .06943 Mdot
.798 .0696 Mdot
.798 .07049 Mdot
.798 .0705 Mdot
.798 .07102 Mdot
.798 .07112 Mdot
.798 .07118 Mdot
.798 .07137 Mdot
.798 .07148 Mdot
.798 .07181 Mdot
.798 .07183 Mdot
.798 .07227 Mdot
.798 .07244 Mdot
.798 .07301 Mdot
.798 .0733 Mdot
.798 .0739 Mdot
.798 .07393 Mdot
.798 .07412 Mdot
.798 .07466 Mdot
.798 .07481 Mdot
.798 .07508 Mdot
.798 .07547 Mdot
.798 .07549 Mdot
.798 .07626 Mdot
.798 .07643 Mdot
.798 .07646 Mdot
.798 .07652 Mdot
.798 .0768 Mdot
.798 .0769 Mdot
.798 .07713 Mdot
.798 .07782 Mdot
.798 .07855 Mdot
.798 .07862 Mdot
.798 .07883 Mdot
.798 .07901 Mdot
.798 .0791 Mdot
.798 .07936 Mdot
.798 .0794 Mdot
.798 .07982 Mdot
.798 .08011 Mdot
.798 .08042 Mdot
.798 .08162 Mdot
.798 .08171 Mdot
.798 .0825 Mdot
.798 .0835 Mdot
.798 .08358 Mdot
.798 .08368 Mdot
.798 .08381 Mdot
.798 .08382 Mdot
.798 .08511 Mdot
.798 .0874 Mdot
.798 .0876 Mdot
.798 .08882 Mdot
.798 .08892 Mdot
.798 .08906 Mdot
.798 .08959 Mdot
.798 .08973 Mdot
.798 .09054 Mdot
.798 .09066 Mdot
.798 .09112 Mdot
.798 .09219 Mdot
.798 .0929 Mdot
.798 .09296 Mdot
.798 .09317 Mdot
.798 .09369 Mdot
.798 .09447 Mdot
.798 .09534 Mdot
.798 .09557 Mdot
.798 .09588 Mdot
.798 .09625 Mdot
.798 .09643 Mdot
.798 .09669 Mdot
.798 .09707 Mdot
.798 .09733 Mdot
.798 .09887 Mdot
.798 .09913 Mdot
.798 .09922 Mdot
.798 .09939 Mdot
.798 .0995 Mdot
.798 .09951 Mdot
.798 .09962 Mdot
.798 .09987 Mdot
.798 .09991 Mdot
.798 .10052 Mdot
.798 .10057 Mdot
.798 .10144 Mdot
.798 .10204 Mdot
.798 .10231 Mdot
.798 .10374 Mdot
.798 .10375 Mdot
.798 .10458 Mdot
.798 .10474 Mdot
.798 .10484 Mdot
.798 .10513 Mdot
.798 .10531 Mdot
.798 .10548 Mdot
.798 .10551 Mdot
.798 .10555 Mdot
.798 .10583 Mdot
.798 .10586 Mdot
.798 .10657 Mdot
.798 .10684 Mdot
.798 .10776 Mdot
.798 .10778 Mdot
.798 .10822 Mdot
.798 .10917 Mdot
.798 .10923 Mdot
.798 .10941 Mdot
.798 .10953 Mdot
.798 .10964 Mdot
.798 .11006 Mdot
.798 .11008 Mdot
.798 .11038 Mdot
.798 .11063 Mdot
.798 .11105 Mdot
.798 .11117 Mdot
.798 .11168 Mdot
.798 .11171 Mdot
.798 .11198 Mdot
.798 .11294 Mdot
.798 .11321 Mdot
.798 .11326 Mdot
.798 .11336 Mdot
.798 .11371 Mdot
.798 .11381 Mdot
.798 .11396 Mdot
.798 .11432 Mdot
.798 .11487 Mdot
.798 .11501 Mdot
.798 .11544 Mdot
.798 .11575 Mdot
.798 .1166 Mdot
.798 .1167 Mdot
.798 .11697 Mdot
.798 .11705 Mdot
.798 .11728 Mdot
.798 .11733 Mdot
.798 .11747 Mdot
.798 .11789 Mdot
.798 .11796 Mdot
.798 .11861 Mdot
.798 .11908 Mdot
.798 .11958 Mdot
.798 .12041 Mdot
.798 .1205 Mdot
.798 .12149 Mdot
.798 .12163 Mdot
.798 .12177 Mdot
.798 .12207 Mdot
.798 .12289 Mdot
.798 .12354 Mdot
.798 .1245 Mdot
.798 .12462 Mdot
.798 .12478 Mdot
.798 .12499 Mdot
.798 .125 Mdot
.798 .12522 Mdot
.798 .1259 Mdot
.798 .12691 Mdot
.798 .12706 Mdot
.798 .12757 Mdot
.798 .12817 Mdot
.798 .12865 Mdot
.798 .12923 Mdot
.798 .12946 Mdot
.798 .13019 Mdot
.798 .13064 Mdot
.798 .13073 Mdot
.798 .13105 Mdot
.798 .13171 Mdot
.798 .13191 Mdot
.798 .13216 Mdot
.798 .13281 Mdot
.798 .13298 Mdot
.798 .13315 Mdot
.798 .13336 Mdot
.798 .134 Mdot
.798 .13421 Mdot
.798 .13422 Mdot
.798 .13443 Mdot
.798 .13573 Mdot
.798 .13592 Mdot
.798 .13666 Mdot
.798 .13837 Mdot
.798 .13877 Mdot
.798 .13925 Mdot
.798 .13939 Mdot
.798 .1395 Mdot
.798 .13959 Mdot
.798 .13982 Mdot
.798 .13992 Mdot
.798 .14028 Mdot
.798 .14052 Mdot
.798 .14077 Mdot
.798 .142 Mdot
.798 .14339 Mdot
.798 .14377 Mdot
.798 .14388 Mdot
.798 .14425 Mdot
.798 .14465 Mdot
.798 .14484 Mdot
.798 .14514 Mdot
.798 .14554 Mdot
.798 .14615 Mdot
.798 .1465 Mdot
.798 .14651 Mdot
.798 .14657 Mdot
.798 .14663 Mdot
.798 .14681 Mdot
.798 .14773 Mdot
.798 .14779 Mdot
.798 .14902 Mdot
.798 .14945 Mdot
.798 .14948 Mdot
.798 .14959 Mdot
.798 .14985 Mdot
.798 .15003 Mdot
.798 .15004 Mdot
.798 .15022 Mdot
.798 .15063 Mdot
.798 .15068 Mdot
.798 .15165 Mdot
.798 .15174 Mdot
.798 .15312 Mdot
.798 .15409 Mdot
.798 .15425 Mdot
.798 .15452 Mdot
.798 .15515 Mdot
.798 .15543 Mdot
.798 .15565 Mdot
.798 .15595 Mdot
.798 .15602 Mdot
.798 .15679 Mdot
.798 .15682 Mdot
.798 .15713 Mdot
.798 .1572 Mdot
.798 .15798 Mdot
.798 .15814 Mdot
.798 .15839 Mdot
.798 .15856 Mdot
.798 .1587 Mdot
.798 .15896 Mdot
.798 .15902 Mdot
.798 .1592 Mdot
.798 .15931 Mdot
.798 .15957 Mdot
.798 .15962 Mdot
.798 .15968 Mdot
.798 .15984 Mdot
.798 .16014 Mdot
.798 .16019 Mdot
.798 .16131 Mdot
.798 .16146 Mdot
.798 .16157 Mdot
.798 .16174 Mdot
.798 .16257 Mdot
.798 .16276 Mdot
.798 .16321 Mdot
.798 .16324 Mdot
.798 .16329 Mdot
.798 .16352 Mdot
.798 .16353 Mdot
.798 .16394 Mdot
.798 .16512 Mdot
.798 .16541 Mdot
.798 .16546 Mdot
.798 .16555 Mdot
.798 .16584 Mdot
.798 .16604 Mdot
.798 .16621 Mdot
.798 .16628 Mdot
.798 .16689 Mdot
.798 .16692 Mdot
.798 .16716 Mdot
.798 .1674 Mdot
.798 .16779 Mdot
.798 .16786 Mdot
.798 .16808 Mdot
.798 .16847 Mdot
.798 .16852 Mdot
.798 .16863 Mdot
.798 .16865 Mdot
.798 .16866 Mdot
.798 .16948 Mdot
.798 .16951 Mdot
.798 .16995 Mdot
.798 .17148 Mdot
.798 .17191 Mdot
.798 .17197 Mdot
.798 .17199 Mdot
.798 .17212 Mdot
.798 .17215 Mdot
.798 .17272 Mdot
.798 .17287 Mdot
.798 .17311 Mdot
.798 .17369 Mdot
.798 .17391 Mdot
.798 .17457 Mdot
.798 .17478 Mdot
.798 .17547 Mdot
.798 .17597 Mdot
.798 .17732 Mdot
.798 .17748 Mdot
.798 .17792 Mdot
.798 .17804 Mdot
.798 .17831 Mdot
.798 .17841 Mdot
.798 .17848 Mdot
.798 .17871 Mdot
.798 .17939 Mdot
.798 .17949 Mdot
.798 .18012 Mdot
.798 .18054 Mdot
.798 .18128 Mdot
.798 .18185 Mdot
.798 .18208 Mdot
.798 .1821 Mdot
.798 .1822 Mdot
.798 .18271 Mdot
.798 .18283 Mdot
.798 .18284 Mdot
.798 .18341 Mdot
.798 .18353 Mdot
.798 .18355 Mdot
.798 .18513 Mdot
.798 .18514 Mdot
.798 .18535 Mdot
.798 .18557 Mdot
.798 .18576 Mdot
.798 .18605 Mdot
.798 .18673 Mdot
.798 .18737 Mdot
.798 .18839 Mdot
.798 .18909 Mdot
.798 .18993 Mdot
.798 .19001 Mdot
.798 .19012 Mdot
.798 .19038 Mdot
.798 .19071 Mdot
.798 .19074 Mdot
.798 .19109 Mdot
.798 .19217 Mdot
.798 .1926 Mdot
.798 .19267 Mdot
.798 .19354 Mdot
.798 .19378 Mdot
.798 .19402 Mdot
.798 .19483 Mdot
.798 .19505 Mdot
.798 .19579 Mdot
.798 .19632 Mdot
.798 .19656 Mdot
.798 .19749 Mdot
.798 .19751 Mdot
.798 .19786 Mdot
.798 .19838 Mdot
.798 .19902 Mdot
.798 .19973 Mdot
.798 .19987 Mdot
.798 .20038 Mdot
.798 .20145 Mdot
.798 .20176 Mdot
.798 .20216 Mdot
.798 .20319 Mdot
.798 .20347 Mdot
.798 .20374 Mdot
.798 .20387 Mdot
.798 .20408 Mdot
.798 .20452 Mdot
.798 .20509 Mdot
.798 .20543 Mdot
.798 .20545 Mdot
.798 .20578 Mdot
.798 .20594 Mdot
.798 .20629 Mdot
.798 .20678 Mdot
.798 .20785 Mdot
.798 .20789 Mdot
.798 .20814 Mdot
.798 .20816 Mdot
.798 .20827 Mdot
.798 .20858 Mdot
.798 .20934 Mdot
.798 .2095 Mdot
.798 .21207 Mdot
.798 .21227 Mdot
.798 .21267 Mdot
.798 .21271 Mdot
.798 .21348 Mdot
.798 .2137 Mdot
.798 .21387 Mdot
.798 .21402 Mdot
.798 .21439 Mdot
.798 .21455 Mdot
.798 .21512 Mdot
.798 .21525 Mdot
.798 .2155 Mdot
.798 .21588 Mdot
.798 .21589 Mdot
.798 .21694 Mdot
.798 .21786 Mdot
.798 .21994 Mdot
.798 .22008 Mdot
.798 .22068 Mdot
.798 .22086 Mdot
.798 .22131 Mdot
.798 .22146 Mdot
.798 .22208 Mdot
.798 .22226 Mdot
.798 .2224 Mdot
.798 .22287 Mdot
.798 .22321 Mdot
.798 .2233 Mdot
.798 .22351 Mdot
.798 .22368 Mdot
.798 .22384 Mdot
.798 .22448 Mdot
.798 .22504 Mdot
.798 .22507 Mdot
.798 .22515 Mdot
.798 .22525 Mdot
.798 .22554 Mdot
.798 .22577 Mdot
.798 .22624 Mdot
.798 .22628 Mdot
.798 .22701 Mdot
.798 .22711 Mdot
.798 .22859 Mdot
.798 .22907 Mdot
.798 .22911 Mdot
.798 .22916 Mdot
.798 .22975 Mdot
.798 .22979 Mdot
.798 .22998 Mdot
.798 .2304 Mdot
.798 .23067 Mdot
.798 .2307 Mdot
.798 .23098 Mdot
.798 .23163 Mdot
.798 .23172 Mdot
.798 .23327 Mdot
.798 .23341 Mdot
.798 .23342 Mdot
.798 .23366 Mdot
.798 .23561 Mdot
.798 .23562 Mdot
.798 .23564 Mdot
.798 .23651 Mdot
.798 .23715 Mdot
.798 .23724 Mdot
.798 .23741 Mdot
.798 .23742 Mdot
.798 .23785 Mdot
.798 .23816 Mdot
.798 .23884 Mdot
.798 .2393 Mdot
.798 .23935 Mdot
.798 .23965 Mdot
.798 .24012 Mdot
.798 .24024 Mdot
.798 .24147 Mdot
.798 .24151 Mdot
.798 .24201 Mdot
.798 .24212 Mdot
.798 .2427 Mdot
.798 .24336 Mdot
.798 .24363 Mdot
.798 .24403 Mdot
.798 .24428 Mdot
.798 .24452 Mdot
.798 .24471 Mdot
.798 .24494 Mdot
.798 .24503 Mdot
.798 .24531 Mdot
.798 .24549 Mdot
.798 .24591 Mdot
.798 .24599 Mdot
.798 .24609 Mdot
.798 .24634 Mdot
.798 .24681 Mdot
.798 .24689 Mdot
.798 .24868 Mdot
.798 .24887 Mdot
.798 .24893 Mdot
.798 .2491 Mdot
.798 .24927 Mdot
.798 .24937 Mdot
.798 .25069 Mdot
.798 .25099 Mdot
.798 .25171 Mdot
.798 .25172 Mdot
.798 .25177 Mdot
.798 .25184 Mdot
.798 .2522 Mdot
.798 .25222 Mdot
.798 .25288 Mdot
.798 .25476 Mdot
.798 .25511 Mdot
.798 .25522 Mdot
.798 .25531 Mdot
.798 .25543 Mdot
.798 .25545 Mdot
.798 .25589 Mdot
.798 .25592 Mdot
.798 .25622 Mdot
.798 .25651 Mdot
.798 .25661 Mdot
.798 .2567 Mdot
.798 .25695 Mdot
.798 .25759 Mdot
.798 .25763 Mdot
.798 .25802 Mdot
.798 .2581 Mdot
.798 .25831 Mdot
.798 .2584 Mdot
.798 .2584 Mdot
.798 .25903 Mdot
.798 .25914 Mdot
.798 .25948 Mdot
.798 .25983 Mdot
.798 .2601 Mdot
.798 .26019 Mdot
.798 .26036 Mdot
.798 .2604 Mdot
.798 .26041 Mdot
.798 .26171 Mdot
.798 .26177 Mdot
.798 .26248 Mdot
.798 .26421 Mdot
.798 .26492 Mdot
.798 .26559 Mdot
.798 .26569 Mdot
.798 .26573 Mdot
.798 .26593 Mdot
.798 .26598 Mdot
.798 .26598 Mdot
.798 .26625 Mdot
.798 .26688 Mdot
.798 .26713 Mdot
.798 .26751 Mdot
.798 .26844 Mdot
.798 .2688 Mdot
.798 .26981 Mdot
.798 .26984 Mdot
.798 .27018 Mdot
.798 .27077 Mdot
.798 .27127 Mdot
.798 .27174 Mdot
.798 .27208 Mdot
.798 .27424 Mdot
.798 .27449 Mdot
.798 .27505 Mdot
.798 .27519 Mdot
.798 .27538 Mdot
.798 .27582 Mdot
.798 .27591 Mdot
.798 .27597 Mdot
.798 .27609 Mdot
.798 .27645 Mdot
.798 .27754 Mdot
.798 .27769 Mdot
.798 .27871 Mdot
.798 .27895 Mdot
.798 .27937 Mdot
.798 .28055 Mdot
.798 .28109 Mdot
.798 .28146 Mdot
.798 .28183 Mdot
.798 .28187 Mdot
.798 .28201 Mdot
.798 .28208 Mdot
.798 .28284 Mdot
.798 .28302 Mdot
.798 .28304 Mdot
.798 .28394 Mdot
.798 .28415 Mdot
.798 .28417 Mdot
.798 .28584 Mdot
.798 .28593 Mdot
.798 .2867 Mdot
.798 .28671 Mdot
.798 .28705 Mdot
.798 .28734 Mdot
.798 .28741 Mdot
.798 .2877 Mdot
.798 .28817 Mdot
.798 .28926 Mdot
.798 .28948 Mdot
.798 .29027 Mdot
.798 .29191 Mdot
.798 .29206 Mdot
.798 .29302 Mdot
.798 .29435 Mdot
.798 .29448 Mdot
.798 .29466 Mdot
.798 .29498 Mdot
.798 .29508 Mdot
.798 .29553 Mdot
.798 .29561 Mdot
.798 .29564 Mdot
.798 .29621 Mdot
.798 .29793 Mdot
.798 .29862 Mdot
.798 .29873 Mdot
.798 .30013 Mdot
.798 .3005 Mdot
.798 .30088 Mdot
.798 .30218 Mdot
.798 .30252 Mdot
.798 .30372 Mdot
.798 .30455 Mdot
.798 .30494 Mdot
.798 .30642 Mdot
.798 .30646 Mdot
.798 .30701 Mdot
.798 .30785 Mdot
.798 .30886 Mdot
.798 .31001 Mdot
.798 .31022 Mdot
.798 .31104 Mdot
.798 .31274 Mdot
.798 .31323 Mdot
.798 .31388 Mdot
.798 .31553 Mdot
.798 .31597 Mdot
.798 .3164 Mdot
.798 .3166 Mdot
.798 .31694 Mdot
.798 .31764 Mdot
.798 .31855 Mdot
.798 .31909 Mdot
.798 .31913 Mdot
.798 .31966 Mdot
.798 .31991 Mdot
.798 .32047 Mdot
.798 .32125 Mdot
.798 .32296 Mdot
.798 .32303 Mdot
.798 .32342 Mdot
.798 .32345 Mdot
.798 .32363 Mdot
.798 .32412 Mdot
.798 .32534 Mdot
.798 .3256 Mdot
.798 .32969 Mdot
.798 .33001 Mdot
.798 .33065 Mdot
.798 .33072 Mdot
.798 .33194 Mdot
.798 .33229 Mdot
.798 .33257 Mdot
.798 .33281 Mdot
.798 .3334 Mdot
.798 .33364 Mdot
.798 .33456 Mdot
.798 .33477 Mdot
.798 .33517 Mdot
.798 .33578 Mdot
.798 .33579 Mdot
.798 .33747 Mdot
.798 .33893 Mdot
.798 .34226 Mdot
.798 .34248 Mdot
.798 .34343 Mdot
.798 .34373 Mdot
.798 .34444 Mdot
.798 .34468 Mdot
.798 .34568 Mdot
.798 .34596 Mdot
.798 .34618 Mdot
.798 .34692 Mdot
.798 .34748 Mdot
.798 .34762 Mdot
.798 .34795 Mdot
.798 .34822 Mdot
.798 .34847 Mdot
.798 .3495 Mdot
.798 .35039 Mdot
.798 .35043 Mdot
.798 .35057 Mdot
.798 .35074 Mdot
.798 .35119 Mdot
.798 .35157 Mdot
.798 .35232 Mdot
.798 .35237 Mdot
.798 .35354 Mdot
.798 .35369 Mdot
.798 .35607 Mdot
.798 .35683 Mdot
.798 .35689 Mdot
.798 .35698 Mdot
.798 .3579 Mdot
.798 .35798 Mdot
.798 .35827 Mdot
.798 .35894 Mdot
.798 .35938 Mdot
.798 .35942 Mdot
.798 .35988 Mdot
.798 .36091 Mdot
.798 .36106 Mdot
.798 .36352 Mdot
.798 .36375 Mdot
.798 .36378 Mdot
.798 .36416 Mdot
.798 .36727 Mdot
.798 .36728 Mdot
.798 .36731 Mdot
.798 .36871 Mdot
.798 .36973 Mdot
.798 .36987 Mdot
.798 .37014 Mdot
.798 .37015 Mdot
.798 .37083 Mdot
.798 .37134 Mdot
.798 .37243 Mdot
.798 .37315 Mdot
.798 .37324 Mdot
.798 .3737 Mdot
.798 .37447 Mdot
.798 .37466 Mdot
.798 .37662 Mdot
.798 .37668 Mdot
.798 .37747 Mdot
.798 .37766 Mdot
.798 .37858 Mdot
.798 .37964 Mdot
.798 .38006 Mdot
.798 .38069 Mdot
.798 .38111 Mdot
.798 .38148 Mdot
.798 .38179 Mdot
.798 .38215 Mdot
.798 .38229 Mdot
.798 .38275 Mdot
.798 .38303 Mdot
.798 .3837 Mdot
.798 .38383 Mdot
.798 .38398 Mdot
.798 .38439 Mdot
.798 .38513 Mdot
.798 .38527 Mdot
.798 .38813 Mdot
.798 .38843 Mdot
.798 .38851 Mdot
.798 .38879 Mdot
.798 .38907 Mdot
.798 .38922 Mdot
.798 .39133 Mdot
.798 .39181 Mdot
.798 .39297 Mdot
.798 .39298 Mdot
.798 .39305 Mdot
.798 .39316 Mdot
.798 .39374 Mdot
.798 .39378 Mdot
.798 .39483 Mdot
.798 .39783 Mdot
.798 .39839 Mdot
.798 .39856 Mdot
.798 .3987 Mdot
.798 .39889 Mdot
.798 .39894 Mdot
.798 .39963 Mdot
.798 .39967 Mdot
.798 .40016 Mdot
.798 .40061 Mdot
.798 .40078 Mdot
.798 .40093 Mdot
.798 .40133 Mdot
.798 .40234 Mdot
.798 .40241 Mdot
.798 .40304 Mdot
.798 .40315 Mdot
.798 .40349 Mdot
.798 .40363 Mdot
.798 .40364 Mdot
.798 .40463 Mdot
.798 .40482 Mdot
.798 .40536 Mdot
.798 .40592 Mdot
.798 .40635 Mdot
.798 .40649 Mdot
.798 .40676 Mdot
.798 .40683 Mdot
.798 .40685 Mdot
.798 .40893 Mdot
.798 .40902 Mdot
.798 .41014 Mdot
.798 .4129 Mdot
.798 .41404 Mdot
.798 .41512 Mdot
.798 .41528 Mdot
.798 .41533 Mdot
.798 .41566 Mdot
.798 .41573 Mdot
.798 .41573 Mdot
.798 .41617 Mdot
.798 .41718 Mdot
.798 .41757 Mdot
.798 .41818 Mdot
.798 .41966 Mdot
.798 .42023 Mdot
.798 .42185 Mdot
.798 .4219 Mdot
.798 .42244 Mdot
.798 .42338 Mdot
.798 .42418 Mdot
.798 .42493 Mdot
.798 .42548 Mdot
.798 .42891 Mdot
.798 .42932 Mdot
.798 .43021 Mdot
.798 .43043 Mdot
.798 .43074 Mdot
.798 .43144 Mdot
.798 .43159 Mdot
.798 .43167 Mdot
.798 .43186 Mdot
.798 .43244 Mdot
.798 .43418 Mdot
.798 .43443 Mdot
.798 .43605 Mdot
.798 .43644 Mdot
.798 .43711 Mdot
.798 .43899 Mdot
.798 .43984 Mdot
.798 .44044 Mdot
.798 .44103 Mdot
.798 .44109 Mdot
.798 .44132 Mdot
.798 .44142 Mdot
.798 .44264 Mdot
.798 .44293 Mdot
.798 .44295 Mdot
.798 .44441 Mdot
.798 .44473 Mdot
.798 .44476 Mdot
.798 .44743 Mdot
.798 .44758 Mdot
.798 .44881 Mdot
.798 .44882 Mdot
.798 .44937 Mdot
.798 .44983 Mdot
.798 .44993 Mdot
.798 .4504 Mdot
.798 .45115 Mdot
.798 .45289 Mdot
.798 .45324 Mdot
.798 .4545 Mdot
.798 .45711 Mdot
.798 .45736 Mdot
.798 .4589 Mdot
.798 .46102 Mdot
.798 .46122 Mdot
.798 .46151 Mdot
.798 .46202 Mdot
.798 .46218 Mdot
.798 .46289 Mdot
.798 .46302 Mdot
.798 .46308 Mdot
.798 .46398 Mdot
.798 .46672 Mdot
.798 .46783 Mdot
.798 .468 Mdot
.798 .47023 Mdot
.798 .47083 Mdot
.798 .47144 Mdot
.798 .47351 Mdot
.798 .47405 Mdot
.798 .47596 Mdot
.798 .47729 Mdot
.798 .47792 Mdot
.798 .48027 Mdot
.798 .48033 Mdot
.798 .48121 Mdot
.798 .48256 Mdot
.798 .48417 Mdot
.798 .486 Mdot
.798 .48634 Mdot
.8 .01519 Mdot
.8 .01548 Mdot
.8 .01594 Mdot
.8 .01652 Mdot
.8 .01668 Mdot
.8 .01669 Mdot
.8 .0176 Mdot
.8 .01785 Mdot
.8 .01787 Mdot
.8 .01904 Mdot
.8 .01932 Mdot
.8 .01973 Mdot
.8 .01977 Mdot
.8 .02009 Mdot
.8 .021 Mdot
.8 .02163 Mdot
.8 .02209 Mdot
.8 .02275 Mdot
.8 .02275 Mdot
.8 .0228 Mdot
.8 .02286 Mdot
.8 .02312 Mdot
.8 .0233 Mdot
.8 .02332 Mdot
.8 .02353 Mdot
.8 .02478 Mdot
.8 .02548 Mdot
.8 .02577 Mdot
.8 .02578 Mdot
.8 .02651 Mdot
.8 .02757 Mdot
.8 .02757 Mdot
.8 .02765 Mdot
.8 .02775 Mdot
.8 .02817 Mdot
.8 .02828 Mdot
.8 .02844 Mdot
.8 .02848 Mdot
.8 .02882 Mdot
.8 .02967 Mdot
.8 .03061 Mdot
.8 .03063 Mdot
.8 .03081 Mdot
.8 .03127 Mdot
.8 .03194 Mdot
.8 .03233 Mdot
.8 .03241 Mdot
.8 .03241 Mdot
.8 .03266 Mdot
.8 .03293 Mdot
.8 .03329 Mdot
.8 .03359 Mdot
.8 .03474 Mdot
.8 .03515 Mdot
.8 .03528 Mdot
.8 .03529 Mdot
.8 .0354 Mdot
.8 .03557 Mdot
.8 .03624 Mdot
.8 .03635 Mdot
.8 .03642 Mdot
.8 .03668 Mdot
.8 .03674 Mdot
.8 .03728 Mdot
.8 .03745 Mdot
.8 .03865 Mdot
.8 .0397 Mdot
.8 .04015 Mdot
.8 .04018 Mdot
.8 .04026 Mdot
.8 .04047 Mdot
.8 .04121 Mdot
.8 .04227 Mdot
.8 .04247 Mdot
.8 .04282 Mdot
.8 .04288 Mdot
.8 .0429 Mdot
.8 .04302 Mdot
.8 .04303 Mdot
.8 .04342 Mdot
.8 .04372 Mdot
.8 .04386 Mdot
.8 .04444 Mdot
.8 .04464 Mdot
.8 .04492 Mdot
.8 .04519 Mdot
.8 .04675 Mdot
.8 .04691 Mdot
.8 .04736 Mdot
.8 .04741 Mdot
.8 .04761 Mdot
.8 .04763 Mdot
.8 .04782 Mdot
.8 .04809 Mdot
.8 .04833 Mdot
.8 .04915 Mdot
.8 .04932 Mdot
.8 .04944 Mdot
.8 .04986 Mdot
.8 .04996 Mdot
.8 .05083 Mdot
.8 .05101 Mdot
.8 .0511 Mdot
.8 .05289 Mdot
.8 .053 Mdot
.8 .05434 Mdot
.8 .05469 Mdot
.8 .05541 Mdot
.8 .05546 Mdot
.8 .05558 Mdot
.8 .05592 Mdot
.8 .05678 Mdot
.8 .05699 Mdot
.8 .0571 Mdot
.8 .05777 Mdot
.8 .05828 Mdot
.8 .0588 Mdot
.8 .05904 Mdot
.8 .05908 Mdot
.8 .05913 Mdot
.8 .05968 Mdot
.8 .05976 Mdot
.8 .05978 Mdot
.8 .05982 Mdot
.8 .06 Mdot
.8 .06002 Mdot
.8 .06061 Mdot
.8 .06063 Mdot
.8 .06065 Mdot
.8 .06086 Mdot
.8 .06113 Mdot
.8 .06135 Mdot
.8 .06227 Mdot
.8 .0626 Mdot
.8 .06304 Mdot
.8 .06347 Mdot
.8 .06361 Mdot
.8 .06518 Mdot
.8 .06598 Mdot
.8 .06623 Mdot
.8 .06695 Mdot
.8 .06703 Mdot
.8 .06735 Mdot
.8 .06738 Mdot
.8 .06768 Mdot
.8 .06811 Mdot
.8 .0685 Mdot
.8 .06982 Mdot
.8 .07009 Mdot
.8 .07027 Mdot
.8 .07077 Mdot
.8 .07095 Mdot
.8 .0711 Mdot
.8 .07249 Mdot
.8 .07279 Mdot
.8 .07292 Mdot
.8 .07342 Mdot
.8 .07379 Mdot
.8 .07448 Mdot
.8 .0758 Mdot
.8 .07598 Mdot
.8 .07732 Mdot
.8 .07811 Mdot
.8 .07815 Mdot
.8 .07866 Mdot
.8 .07867 Mdot
.8 .07913 Mdot
.8 .07918 Mdot
.8 .07982 Mdot
.8 .07991 Mdot
.8 .0801 Mdot
.8 .08056 Mdot
.8 .08059 Mdot
.8 .08065 Mdot
.8 .08089 Mdot
.8 .08175 Mdot
.8 .08201 Mdot
.8 .08236 Mdot
.8 .08253 Mdot
.8 .0836 Mdot
.8 .08401 Mdot
.8 .08442 Mdot
.8 .08525 Mdot
.8 .08534 Mdot
.8 .08563 Mdot
.8 .08568 Mdot
.8 .0857 Mdot
.8 .08577 Mdot
.8 .08617 Mdot
.8 .08665 Mdot
.8 .08678 Mdot
.8 .08682 Mdot
.8 .08687 Mdot
.8 .08688 Mdot
.8 .08698 Mdot
.8 .08718 Mdot
.8 .0872 Mdot
.8 .08815 Mdot
.8 .08819 Mdot
.8 .08821 Mdot
.8 .08855 Mdot
.8 .08897 Mdot
.8 .08919 Mdot
.8 .08933 Mdot
.8 .08933 Mdot
.8 .09002 Mdot
.8 .0902 Mdot
.8 .0908 Mdot
.8 .09133 Mdot
.8 .09155 Mdot
.8 .09203 Mdot
.8 .09273 Mdot
.8 .09295 Mdot
.8 .09355 Mdot
.8 .09367 Mdot
.8 .09391 Mdot
.8 .09546 Mdot
.8 .09673 Mdot
.8 .097 Mdot
.8 .09713 Mdot
.8 .09791 Mdot
.8 .09827 Mdot
.8 .09829 Mdot
.8 .09842 Mdot
.8 .09893 Mdot
.8 .09895 Mdot
.8 .09899 Mdot
.8 .09946 Mdot
.8 .09993 Mdot
.8 .1001 Mdot
.8 .10014 Mdot
.8 .10034 Mdot
.8 .10077 Mdot
.8 .10118 Mdot
.8 .10149 Mdot
.8 .10275 Mdot
.8 .10288 Mdot
.8 .10314 Mdot
.8 .10331 Mdot
.8 .10361 Mdot
.8 .10386 Mdot
.8 .1044 Mdot
.8 .10469 Mdot
.8 .10494 Mdot
.8 .10558 Mdot
.8 .10564 Mdot
.8 .10691 Mdot
.8 .10693 Mdot
.8 .10711 Mdot
.8 .10716 Mdot
.8 .10764 Mdot
.8 .10785 Mdot
.8 .10824 Mdot
.8 .10828 Mdot
.8 .10832 Mdot
.8 .10864 Mdot
.8 .10923 Mdot
.8 .11031 Mdot
.8 .11033 Mdot
.8 .11245 Mdot
.8 .11273 Mdot
.8 .11315 Mdot
.8 .11438 Mdot
.8 .11489 Mdot
.8 .11558 Mdot
.8 .11563 Mdot
.8 .11615 Mdot
.8 .11617 Mdot
.8 .11621 Mdot
.8 .11646 Mdot
.8 .11702 Mdot
.8 .11705 Mdot
.8 .11726 Mdot
.8 .11779 Mdot
.8 .11785 Mdot
.8 .1186 Mdot
.8 .11888 Mdot
.8 .11903 Mdot
.8 .11933 Mdot
.8 .11941 Mdot
.8 .11959 Mdot
.8 .12006 Mdot
.8 .12012 Mdot
.8 .1202 Mdot
.8 .1206 Mdot
.8 .12112 Mdot
.8 .12197 Mdot
.8 .12225 Mdot
.8 .12239 Mdot
.8 .12294 Mdot
.8 .12323 Mdot
.8 .12418 Mdot
.8 .12494 Mdot
.8 .12501 Mdot
.8 .12559 Mdot
.8 .12586 Mdot
.8 .12624 Mdot
.8 .12757 Mdot
.8 .12772 Mdot
.8 .12817 Mdot
.8 .12826 Mdot
.8 .12827 Mdot
.8 .12829 Mdot
.8 .12841 Mdot
.8 .12904 Mdot
.8 .12938 Mdot
.8 .12982 Mdot
.8 .1299 Mdot
.8 .13003 Mdot
.8 .13009 Mdot
.8 .13017 Mdot
.8 .13018 Mdot
.8 .13033 Mdot
.8 .13066 Mdot
.8 .1307 Mdot
.8 .13127 Mdot
.8 .1322 Mdot
.8 .13227 Mdot
.8 .13231 Mdot
.8 .13284 Mdot
.8 .13291 Mdot
.8 .13353 Mdot
.8 .13387 Mdot
.8 .1341 Mdot
.8 .1341 Mdot
.8 .13426 Mdot
.8 .13466 Mdot
.8 .1352 Mdot
.8 .1355 Mdot
.8 .13645 Mdot
.8 .13699 Mdot
.8 .13708 Mdot
.8 .13709 Mdot
.8 .1373 Mdot
.8 .13752 Mdot
.8 .13766 Mdot
.8 .13842 Mdot
.8 .13954 Mdot
.8 .13989 Mdot
.8 .14048 Mdot
.8 .14085 Mdot
.8 .14104 Mdot
.8 .14105 Mdot
.8 .14142 Mdot
.8 .1439 Mdot
.8 .14583 Mdot
.8 .14594 Mdot
.8 .14595 Mdot
.8 .1463 Mdot
.8 .14637 Mdot
.8 .14658 Mdot
.8 .14713 Mdot
.8 .14746 Mdot
.8 .14783 Mdot
.8 .1484 Mdot
.8 .14843 Mdot
.8 .14865 Mdot
.8 .14946 Mdot
.8 .14949 Mdot
.8 .14955 Mdot
.8 .1503 Mdot
.8 .15061 Mdot
.8 .15102 Mdot
.8 .15106 Mdot
.8 .15133 Mdot
.8 .1514 Mdot
.8 .15171 Mdot
.8 .15198 Mdot
.8 .1524 Mdot
.8 .15306 Mdot
.8 .15307 Mdot
.8 .15355 Mdot
.8 .15455 Mdot
.8 .15484 Mdot
.8 .15498 Mdot
.8 .15505 Mdot
.8 .15525 Mdot
.8 .15558 Mdot
.8 .15578 Mdot
.8 .15619 Mdot
.8 .15647 Mdot
.8 .15694 Mdot
.8 .15714 Mdot
.8 .15735 Mdot
.8 .15794 Mdot
.8 .15821 Mdot
.8 .15867 Mdot
.8 .15907 Mdot
.8 .16007 Mdot
.8 .16009 Mdot
.8 .1602 Mdot
.8 .16106 Mdot
.8 .16223 Mdot
.8 .16226 Mdot
.8 .16254 Mdot
.8 .16262 Mdot
.8 .16339 Mdot
.8 .16373 Mdot
.8 .16435 Mdot
.8 .16443 Mdot
.8 .16448 Mdot
.8 .16499 Mdot
.8 .16518 Mdot
.8 .16594 Mdot
.8 .16695 Mdot
.8 .16767 Mdot
.8 .16771 Mdot
.8 .16813 Mdot
.8 .16827 Mdot
.8 .17001 Mdot
.8 .1706 Mdot
.8 .17109 Mdot
.8 .17155 Mdot
.8 .17221 Mdot
.8 .17362 Mdot
.8 .17418 Mdot
.8 .17499 Mdot
.8 .17593 Mdot
.8 .1761 Mdot
.8 .17617 Mdot
.8 .17701 Mdot
.8 .17704 Mdot
.8 .1771 Mdot
.8 .17724 Mdot
.8 .1775 Mdot
.8 .17772 Mdot
.8 .1784 Mdot
.8 .17845 Mdot
.8 .17879 Mdot
.8 .17963 Mdot
.8 .17971 Mdot
.8 .17973 Mdot
.8 .18015 Mdot
.8 .18093 Mdot
.8 .18097 Mdot
.8 .18138 Mdot
.8 .18161 Mdot
.8 .1821 Mdot
.8 .18215 Mdot
.8 .18222 Mdot
.8 .18251 Mdot
.8 .18266 Mdot
.8 .18327 Mdot
.8 .18337 Mdot
.8 .1835 Mdot
.8 .184 Mdot
.8 .18413 Mdot
.8 .18496 Mdot
.8 .18533 Mdot
.8 .18632 Mdot
.8 .18673 Mdot
.8 .18677 Mdot
.8 .187 Mdot
.8 .18788 Mdot
.8 .18833 Mdot
.8 .18874 Mdot
.8 .18919 Mdot
.8 .18985 Mdot
.8 .19071 Mdot
.8 .19107 Mdot
.8 .19119 Mdot
.8 .19212 Mdot
.8 .19248 Mdot
.8 .19254 Mdot
.8 .19316 Mdot
.8 .19456 Mdot
.8 .19478 Mdot
.8 .19518 Mdot
.8 .19529 Mdot
.8 .19552 Mdot
.8 .19625 Mdot
.8 .19639 Mdot
.8 .1964 Mdot
.8 .19644 Mdot
.8 .19662 Mdot
.8 .19764 Mdot
.8 .19811 Mdot
.8 .19818 Mdot
.8 .19888 Mdot
.8 .19901 Mdot
.8 .19921 Mdot
.8 .19931 Mdot
.8 .19944 Mdot
.8 .19946 Mdot
.8 .1997 Mdot
.8 .20022 Mdot
.8 .20029 Mdot
.8 .2012 Mdot
.8 .20162 Mdot
.8 .20197 Mdot
.8 .20266 Mdot
.8 .2027 Mdot
.8 .2028 Mdot
.8 .20287 Mdot
.8 .20296 Mdot
.8 .20372 Mdot
.8 .20383 Mdot
.8 .20481 Mdot
.8 .20536 Mdot
.8 .20572 Mdot
.8 .20573 Mdot
.8 .20598 Mdot
.8 .2064 Mdot
.8 .20652 Mdot
.8 .20663 Mdot
.8 .20677 Mdot
.8 .20734 Mdot
.8 .2075 Mdot
.8 .20796 Mdot
.8 .2084 Mdot
.8 .20927 Mdot
.8 .20949 Mdot
.8 .21036 Mdot
.8 .21049 Mdot
.8 .21052 Mdot
.8 .21085 Mdot
.8 .21121 Mdot
.8 .21142 Mdot
.8 .21209 Mdot
.8 .21227 Mdot
.8 .21265 Mdot
.8 .21369 Mdot
.8 .21443 Mdot
.8 .21499 Mdot
.8 .21595 Mdot
.8 .21633 Mdot
.8 .21653 Mdot
.8 .21683 Mdot
.8 .21685 Mdot
.8 .21711 Mdot
.8 .21744 Mdot
.8 .21745 Mdot
.8 .21754 Mdot
.8 .21862 Mdot
.8 .21923 Mdot
.8 .22141 Mdot
.8 .22245 Mdot
.8 .22259 Mdot
.8 .22286 Mdot
.8 .22397 Mdot
.8 .22429 Mdot
.8 .22449 Mdot
.8 .22468 Mdot
.8 .2247 Mdot
.8 .22523 Mdot
.8 .22525 Mdot
.8 .22537 Mdot
.8 .2257 Mdot
.8 .22659 Mdot
.8 .2271 Mdot
.8 .22724 Mdot
.8 .22743 Mdot
.8 .2277 Mdot
.8 .22774 Mdot
.8 .22861 Mdot
.8 .22866 Mdot
.8 .22893 Mdot
.8 .229 Mdot
.8 .22953 Mdot
.8 .23031 Mdot
.8 .23036 Mdot
.8 .23045 Mdot
.8 .23166 Mdot
.8 .23202 Mdot
.8 .23215 Mdot
.8 .23242 Mdot
.8 .2328 Mdot
.8 .23287 Mdot
.8 .23296 Mdot
.8 .23329 Mdot
.8 .23341 Mdot
.8 .23391 Mdot
.8 .23406 Mdot
.8 .23434 Mdot
.8 .23501 Mdot
.8 .23503 Mdot
.8 .23553 Mdot
.8 .23554 Mdot
.8 .23561 Mdot
.8 .23605 Mdot
.8 .23607 Mdot
.8 .23608 Mdot
.8 .23686 Mdot
.8 .23797 Mdot
.8 .23845 Mdot
.8 .23892 Mdot
.8 .23893 Mdot
.8 .23915 Mdot
.8 .23926 Mdot
.8 .23957 Mdot
.8 .2401 Mdot
.8 .24041 Mdot
.8 .24048 Mdot
.8 .24108 Mdot
.8 .24152 Mdot
.8 .24227 Mdot
.8 .2426 Mdot
.8 .24293 Mdot
.8 .24387 Mdot
.8 .24431 Mdot
.8 .24451 Mdot
.8 .24505 Mdot
.8 .24569 Mdot
.8 .24621 Mdot
.8 .24637 Mdot
.8 .24728 Mdot
.8 .24731 Mdot
.8 .24732 Mdot
.8 .24749 Mdot
.8 .24864 Mdot
.8 .24886 Mdot
.8 .25073 Mdot
.8 .25078 Mdot
.8 .25092 Mdot
.8 .25124 Mdot
.8 .25137 Mdot
.8 .2526 Mdot
.8 .25276 Mdot
.8 .25313 Mdot
.8 .25356 Mdot
.8 .25414 Mdot
.8 .25425 Mdot
.8 .25431 Mdot
.8 .25434 Mdot
.8 .25441 Mdot
.8 .25515 Mdot
.8 .25546 Mdot
.8 .25629 Mdot
.8 .25668 Mdot
.8 .25829 Mdot
.8 .25898 Mdot
.8 .25944 Mdot
.8 .2595 Mdot
.8 .26018 Mdot
.8 .26041 Mdot
.8 .26159 Mdot
.8 .26249 Mdot
.8 .263 Mdot
.8 .26319 Mdot
.8 .26397 Mdot
.8 .26414 Mdot
.8 .26446 Mdot
.8 .26492 Mdot
.8 .26512 Mdot
.8 .26564 Mdot
.8 .26616 Mdot
.8 .26671 Mdot
.8 .26749 Mdot
.8 .26767 Mdot
.8 .26826 Mdot
.8 .26896 Mdot
.8 .26977 Mdot
.8 .26985 Mdot
.8 .27001 Mdot
.8 .27115 Mdot
.8 .27252 Mdot
.8 .27266 Mdot
.8 .27293 Mdot
.8 .27305 Mdot
.8 .27439 Mdot
.8 .27444 Mdot
.8 .27454 Mdot
.8 .27476 Mdot
.8 .27517 Mdot
.8 .27552 Mdot
.8 .27662 Mdot
.8 .27668 Mdot
.8 .27724 Mdot
.8 .27827 Mdot
.8 .27858 Mdot
.8 .27871 Mdot
.8 .27874 Mdot
.8 .27916 Mdot
.8 .2794 Mdot
.8 .28066 Mdot
.8 .28072 Mdot
.8 .28082 Mdot
.8 .28126 Mdot
.8 .28138 Mdot
.8 .28175 Mdot
.8 .28218 Mdot
.8 .28253 Mdot
.8 .28261 Mdot
.8 .28273 Mdot
.8 .28319 Mdot
.8 .28343 Mdot
.8 .2844 Mdot
.8 .28456 Mdot
.8 .28477 Mdot
.8 .2852 Mdot
.8 .28558 Mdot
.8 .28577 Mdot
.8 .28577 Mdot
.8 .2858 Mdot
.8 .28597 Mdot
.8 .28672 Mdot
.8 .2871 Mdot
.8 .28771 Mdot
.8 .28928 Mdot
.8 .28994 Mdot
.8 .29001 Mdot
.8 .29037 Mdot
.8 .29089 Mdot
.8 .29178 Mdot
.8 .2925 Mdot
.8 .29281 Mdot
.8 .29311 Mdot
.8 .29315 Mdot
.8 .29388 Mdot
.8 .29493 Mdot
.8 .29595 Mdot
.8 .2963 Mdot
.8 .2965 Mdot
.8 .29688 Mdot
.8 .29707 Mdot
.8 .29733 Mdot
.8 .29774 Mdot
.8 .29826 Mdot
.8 .29833 Mdot
.8 .29856 Mdot
.8 .29915 Mdot
.8 .29924 Mdot
.8 .30022 Mdot
.8 .30247 Mdot
.8 .30282 Mdot
.8 .30346 Mdot
.8 .30363 Mdot
.8 .304 Mdot
.8 .30517 Mdot
.8 .3054 Mdot
.8 .30541 Mdot
.8 .30548 Mdot
.8 .30577 Mdot
.8 .3074 Mdot
.8 .30815 Mdot
.8 .30826 Mdot
.8 .30937 Mdot
.8 .30959 Mdot
.8 .30991 Mdot
.8 .31007 Mdot
.8 .31027 Mdot
.8 .3103 Mdot
.8 .3107 Mdot
.8 .31152 Mdot
.8 .31163 Mdot
.8 .3131 Mdot
.8 .31376 Mdot
.8 .31433 Mdot
.8 .31542 Mdot
.8 .31549 Mdot
.8 .31565 Mdot
.8 .31576 Mdot
.8 .31591 Mdot
.8 .31712 Mdot
.8 .31731 Mdot
.8 .31887 Mdot
.8 .31974 Mdot
.8 .32033 Mdot
.8 .32034 Mdot
.8 .32074 Mdot
.8 .32141 Mdot
.8 .32161 Mdot
.8 .32178 Mdot
.8 .32201 Mdot
.8 .32291 Mdot
.8 .32317 Mdot
.8 .32391 Mdot
.8 .32461 Mdot
.8 .32601 Mdot
.8 .32636 Mdot
.8 .32774 Mdot
.8 .32796 Mdot
.8 .328 Mdot
.8 .32853 Mdot
.8 .3291 Mdot
.8 .32944 Mdot
.8 .33052 Mdot
.8 .3308 Mdot
.8 .3314 Mdot
.8 .33308 Mdot
.8 .33426 Mdot
.8 .33516 Mdot
.8 .33669 Mdot
.8 .33682 Mdot
.8 .33731 Mdot
.8 .33762 Mdot
.8 .3381 Mdot
.8 .33813 Mdot
.8 .33855 Mdot
.8 .33908 Mdot
.8 .3391 Mdot
.8 .33924 Mdot
.8 .34096 Mdot
.8 .34194 Mdot
.8 .34543 Mdot
.8 .34708 Mdot
.8 .34732 Mdot
.8 .34775 Mdot
.8 .34953 Mdot
.8 .35004 Mdot
.8 .35036 Mdot
.8 .35066 Mdot
.8 .35068 Mdot
.8 .35155 Mdot
.8 .35157 Mdot
.8 .35176 Mdot
.8 .35229 Mdot
.8 .35371 Mdot
.8 .35454 Mdot
.8 .35475 Mdot
.8 .35506 Mdot
.8 .35549 Mdot
.8 .35556 Mdot
.8 .35694 Mdot
.8 .35703 Mdot
.8 .35746 Mdot
.8 .35758 Mdot
.8 .35842 Mdot
.8 .35967 Mdot
.8 .35974 Mdot
.8 .35989 Mdot
.8 .36182 Mdot
.8 .3624 Mdot
.8 .36262 Mdot
.8 .36304 Mdot
.8 .36366 Mdot
.8 .36376 Mdot
.8 .36391 Mdot
.8 .36444 Mdot
.8 .36463 Mdot
.8 .36542 Mdot
.8 .36566 Mdot
.8 .36611 Mdot
.8 .36718 Mdot
.8 .36723 Mdot
.8 .36802 Mdot
.8 .36803 Mdot
.8 .36814 Mdot
.8 .36885 Mdot
.8 .36888 Mdot
.8 .3689 Mdot
.8 .37014 Mdot
.8 .37192 Mdot
.8 .37269 Mdot
.8 .37344 Mdot
.8 .37347 Mdot
.8 .37381 Mdot
.8 .37398 Mdot
.8 .37449 Mdot
.8 .37532 Mdot
.8 .37583 Mdot
.8 .37594 Mdot
.8 .3769 Mdot
.8 .37761 Mdot
.8 .37881 Mdot
.8 .37933 Mdot
.8 .37986 Mdot
.8 .38137 Mdot
.8 .38206 Mdot
.8 .38239 Mdot
.8 .38324 Mdot
.8 .38427 Mdot
.8 .38511 Mdot
.8 .38536 Mdot
.8 .38682 Mdot
.8 .38687 Mdot
.8 .38688 Mdot
.8 .38715 Mdot
.8 .389 Mdot
.8 .38935 Mdot
.8 .39234 Mdot
.8 .39242 Mdot
.8 .39264 Mdot
.8 .39316 Mdot
.8 .39336 Mdot
.8 .39533 Mdot
.8 .39559 Mdot
.8 .39619 Mdot
.8 .39687 Mdot
.8 .39779 Mdot
.8 .39797 Mdot
.8 .39806 Mdot
.8 .39811 Mdot
.8 .39823 Mdot
.8 .39941 Mdot
.8 .39991 Mdot
.8 .40124 Mdot
.8 .40186 Mdot
.8 .40444 Mdot
.8 .40554 Mdot
.8 .40628 Mdot
.8 .40637 Mdot
.8 .40746 Mdot
.8 .40783 Mdot
.8 .40971 Mdot
.8 .41116 Mdot
.8 .41198 Mdot
.8 .41227 Mdot
.8 .41352 Mdot
.8 .41379 Mdot
.8 .4143 Mdot
.8 .41504 Mdot
.8 .41536 Mdot
.8 .4162 Mdot
.8 .41703 Mdot
.8 .41791 Mdot
.8 .41916 Mdot
.8 .41945 Mdot
.8 .42039 Mdot
.8 .4215 Mdot
.8 .4228 Mdot
.8 .42294 Mdot
.8 .42319 Mdot
.8 .42502 Mdot
.8 .42721 Mdot
.8 .42743 Mdot
.8 .42786 Mdot
.8 .42805 Mdot
.8 .4302 Mdot
.8 .43028 Mdot
.8 .43043 Mdot
.8 .43079 Mdot
.8 .43145 Mdot
.8 .432 Mdot
.8 .43376 Mdot
.8 .43387 Mdot
.8 .43476 Mdot
.8 .43641 Mdot
.8 .43689 Mdot
.8 .43711 Mdot
.8 .43716 Mdot
.8 .43783 Mdot
.8 .43822 Mdot
.8 .44023 Mdot
.8 .44032 Mdot
.8 .44049 Mdot
.8 .44118 Mdot
.8 .44138 Mdot
.8 .44197 Mdot
.8 .44267 Mdot
.8 .44322 Mdot
.8 .44334 Mdot
.8 .44354 Mdot
.8 .44428 Mdot
.8 .44466 Mdot
.8 .44621 Mdot
.8 .44646 Mdot
.8 .4468 Mdot
.8 .44748 Mdot
.8 .4481 Mdot
.8 .4484 Mdot
.8 .44841 Mdot
.8 .44845 Mdot
.8 .44873 Mdot
.8 .44993 Mdot
.8 .45053 Mdot
.8 .4515 Mdot
.8 .45402 Mdot
.8 .45508 Mdot
.8 .45518 Mdot
.8 .45577 Mdot
.8 .4566 Mdot
.8 .45802 Mdot
.8 .45917 Mdot
.8 .45967 Mdot
.8 .46014 Mdot
.8 .46021 Mdot
.8 .46138 Mdot
.8 .46306 Mdot
.8 .46469 Mdot
.8 .46526 Mdot
.8 .46558 Mdot
.8 .46618 Mdot
.8 .46649 Mdot
.8 .4669 Mdot
.8 .46755 Mdot
.8 .46838 Mdot
.8 .46849 Mdot
.8 .46886 Mdot
.8 .4698 Mdot
.8 .46996 Mdot
.8 .47153 Mdot
.8 .47512 Mdot
.8 .47568 Mdot
.8 .47671 Mdot
.8 .47698 Mdot
.8 .47756 Mdot
.8 .47945 Mdot
.8 .47981 Mdot
.8 .47983 Mdot
.8 .47993 Mdot
.8 .4804 Mdot
.8 .48301 Mdot
.8 .48421 Mdot
.8 .48439 Mdot
.8 .48617 Mdot
.8 .48651 Mdot
.8 .48703 Mdot
.8 .48729 Mdot
.8 .48761 Mdot
.8 .48765 Mdot
.802 .01493 Mdot
.802 .01506 Mdot
.802 .01527 Mdot
.802 .0156 Mdot
.802 .01603 Mdot
.802 .01605 Mdot
.802 .01612 Mdot
.802 .01614 Mdot
.802 .01624 Mdot
.802 .01683 Mdot
.802 .01686 Mdot
.802 .01697 Mdot
.802 .017 Mdot
.802 .01716 Mdot
.802 .01784 Mdot
.802 .01787 Mdot
.802 .01811 Mdot
.802 .01815 Mdot
.802 .01818 Mdot
.802 .01833 Mdot
.802 .01837 Mdot
.802 .01863 Mdot
.802 .01888 Mdot
.802 .01903 Mdot
.802 .01905 Mdot
.802 .01972 Mdot
.802 .01978 Mdot
.802 .02016 Mdot
.802 .02023 Mdot
.802 .02027 Mdot
.802 .02051 Mdot
.802 .02058 Mdot
.802 .02099 Mdot
.802 .02103 Mdot
.802 .0214 Mdot
.802 .02152 Mdot
.802 .02164 Mdot
.802 .02167 Mdot
.802 .02204 Mdot
.802 .02275 Mdot
.802 .02284 Mdot
.802 .02338 Mdot
.802 .02344 Mdot
.802 .02356 Mdot
.802 .02363 Mdot
.802 .02402 Mdot
.802 .02412 Mdot
.802 .02416 Mdot
.802 .02473 Mdot
.802 .02479 Mdot
.802 .02484 Mdot
.802 .02544 Mdot
.802 .02564 Mdot
.802 .02581 Mdot
.802 .02587 Mdot
.802 .02608 Mdot
.802 .02634 Mdot
.802 .02646 Mdot
.802 .02679 Mdot
.802 .02701 Mdot
.802 .0276 Mdot
.802 .02775 Mdot
.802 .02842 Mdot
.802 .02861 Mdot
.802 .02872 Mdot
.802 .02891 Mdot
.802 .02901 Mdot
.802 .02926 Mdot
.802 .02963 Mdot
.802 .02981 Mdot
.802 .02987 Mdot
.802 .03011 Mdot
.802 .03079 Mdot
.802 .03087 Mdot
.802 .03096 Mdot
.802 .03116 Mdot
.802 .03166 Mdot
.802 .03192 Mdot
.802 .03213 Mdot
.802 .03213 Mdot
.802 .03223 Mdot
.802 .03252 Mdot
.802 .03261 Mdot
.802 .03295 Mdot
.802 .03336 Mdot
.802 .03355 Mdot
.802 .03409 Mdot
.802 .03444 Mdot
.802 .03539 Mdot
.802 .03557 Mdot
.802 .03562 Mdot
.802 .03659 Mdot
.802 .03669 Mdot
.802 .03701 Mdot
.802 .03717 Mdot
.802 .03732 Mdot
.802 .03748 Mdot
.802 .03765 Mdot
.802 .03805 Mdot
.802 .03856 Mdot
.802 .03864 Mdot
.802 .03882 Mdot
.802 .03892 Mdot
.802 .03902 Mdot
.802 .03941 Mdot
.802 .03999 Mdot
.802 .04049 Mdot
.802 .04062 Mdot
.802 .04077 Mdot
.802 .0411 Mdot
.802 .0419 Mdot
.802 .04232 Mdot
.802 .04264 Mdot
.802 .04265 Mdot
.802 .04275 Mdot
.802 .04282 Mdot
.802 .04282 Mdot
.802 .04327 Mdot
.802 .04342 Mdot
.802 .04396 Mdot
.802 .04461 Mdot
.802 .04493 Mdot
.802 .04569 Mdot
.802 .04579 Mdot
.802 .04635 Mdot
.802 .04787 Mdot
.802 .04817 Mdot
.802 .04825 Mdot
.802 .04902 Mdot
.802 .04963 Mdot
.802 .0498 Mdot
.802 .04997 Mdot
.802 .05047 Mdot
.802 .05074 Mdot
.802 .05098 Mdot
.802 .05119 Mdot
.802 .05123 Mdot
.802 .0515 Mdot
.802 .05214 Mdot
.802 .05247 Mdot
.802 .05296 Mdot
.802 .05309 Mdot
.802 .05338 Mdot
.802 .05354 Mdot
.802 .05362 Mdot
.802 .0537 Mdot
.802 .05432 Mdot
.802 .0544 Mdot
.802 .05504 Mdot
.802 .05526 Mdot
.802 .05571 Mdot
.802 .05573 Mdot
.802 .05606 Mdot
.802 .05627 Mdot
.802 .05651 Mdot
.802 .05703 Mdot
.802 .05832 Mdot
.802 .05853 Mdot
.802 .05894 Mdot
.802 .05899 Mdot
.802 .05909 Mdot
.802 .05951 Mdot
.802 .05953 Mdot
.802 .05968 Mdot
.802 .05979 Mdot
.802 .05979 Mdot
.802 .06052 Mdot
.802 .06075 Mdot
.802 .06083 Mdot
.802 .06163 Mdot
.802 .0623 Mdot
.802 .06267 Mdot
.802 .06318 Mdot
.802 .06415 Mdot
.802 .06441 Mdot
.802 .06456 Mdot
.802 .06531 Mdot
.802 .06546 Mdot
.802 .06597 Mdot
.802 .0679 Mdot
.802 .06804 Mdot
.802 .06837 Mdot
.802 .0685 Mdot
.802 .06919 Mdot
.802 .06946 Mdot
.802 .06969 Mdot
.802 .06974 Mdot
.802 .07072 Mdot
.802 .07099 Mdot
.802 .07126 Mdot
.802 .07207 Mdot
.802 .0725 Mdot
.802 .07287 Mdot
.802 .07288 Mdot
.802 .07323 Mdot
.802 .07328 Mdot
.802 .07372 Mdot
.802 .07474 Mdot
.802 .07528 Mdot
.802 .07606 Mdot
.802 .07628 Mdot
.802 .07674 Mdot
.802 .077 Mdot
.802 .07711 Mdot
.802 .07725 Mdot
.802 .07767 Mdot
.802 .07825 Mdot
.802 .07825 Mdot
.802 .07837 Mdot
.802 .07918 Mdot
.802 .07939 Mdot
.802 .07975 Mdot
.802 .07994 Mdot
.802 .08047 Mdot
.802 .0805 Mdot
.802 .08094 Mdot
.802 .08104 Mdot
.802 .08111 Mdot
.802 .08138 Mdot
.802 .08176 Mdot
.802 .08259 Mdot
.802 .08318 Mdot
.802 .08374 Mdot
.802 .08463 Mdot
.802 .08466 Mdot
.802 .08499 Mdot
.802 .08566 Mdot
.802 .08573 Mdot
.802 .0859 Mdot
.802 .0864 Mdot
.802 .08657 Mdot
.802 .08659 Mdot
.802 .08684 Mdot
.802 .08699 Mdot
.802 .08702 Mdot
.802 .08702 Mdot
.802 .08819 Mdot
.802 .08856 Mdot
.802 .08869 Mdot
.802 .08885 Mdot
.802 .089 Mdot
.802 .08967 Mdot
.802 .08997 Mdot
.802 .0906 Mdot
.802 .09104 Mdot
.802 .09164 Mdot
.802 .09246 Mdot
.802 .09305 Mdot
.802 .09401 Mdot
.802 .09442 Mdot
.802 .09459 Mdot
.802 .09463 Mdot
.802 .09467 Mdot
.802 .09588 Mdot
.802 .09596 Mdot
.802 .0961 Mdot
.802 .09637 Mdot
.802 .09656 Mdot
.802 .09671 Mdot
.802 .09693 Mdot
.802 .10003 Mdot
.802 .10025 Mdot
.802 .10078 Mdot
.802 .10099 Mdot
.802 .10207 Mdot
.802 .10209 Mdot
.802 .10252 Mdot
.802 .1029 Mdot
.802 .10297 Mdot
.802 .10385 Mdot
.802 .10455 Mdot
.802 .10498 Mdot
.802 .10515 Mdot
.802 .10541 Mdot
.802 .10586 Mdot
.802 .10625 Mdot
.802 .10665 Mdot
.802 .10672 Mdot
.802 .10739 Mdot
.802 .108 Mdot
.802 .10801 Mdot
.802 .10857 Mdot
.802 .10865 Mdot
.802 .10936 Mdot
.802 .11017 Mdot
.802 .11099 Mdot
.802 .11153 Mdot
.802 .11186 Mdot
.802 .11221 Mdot
.802 .11247 Mdot
.802 .1128 Mdot
.802 .11311 Mdot
.802 .11346 Mdot
.802 .1142 Mdot
.802 .11461 Mdot
.802 .1148 Mdot
.802 .11488 Mdot
.802 .11493 Mdot
.802 .11502 Mdot
.802 .1157 Mdot
.802 .11654 Mdot
.802 .11662 Mdot
.802 .11662 Mdot
.802 .11682 Mdot
.802 .11722 Mdot
.802 .11811 Mdot
.802 .11846 Mdot
.802 .11857 Mdot
.802 .11867 Mdot
.802 .11881 Mdot
.802 .11903 Mdot
.802 .11934 Mdot
.802 .11995 Mdot
.802 .12019 Mdot
.802 .12023 Mdot
.802 .12093 Mdot
.802 .1211 Mdot
.802 .12121 Mdot
.802 .12164 Mdot
.802 .12166 Mdot
.802 .12226 Mdot
.802 .12262 Mdot
.802 .12359 Mdot
.802 .12418 Mdot
.802 .12454 Mdot
.802 .12466 Mdot
.802 .12542 Mdot
.802 .12675 Mdot
.802 .12686 Mdot
.802 .1269 Mdot
.802 .12744 Mdot
.802 .12851 Mdot
.802 .12862 Mdot
.802 .12889 Mdot
.802 .12917 Mdot
.802 .12969 Mdot
.802 .12996 Mdot
.802 .12996 Mdot
.802 .13001 Mdot
.802 .1304 Mdot
.802 .13048 Mdot
.802 .13065 Mdot
.802 .13069 Mdot
.802 .13069 Mdot
.802 .13117 Mdot
.802 .13141 Mdot
.802 .13174 Mdot
.802 .13193 Mdot
.802 .13257 Mdot
.802 .13316 Mdot
.802 .13337 Mdot
.802 .13363 Mdot
.802 .13386 Mdot
.802 .13386 Mdot
.802 .13494 Mdot
.802 .13512 Mdot
.802 .13542 Mdot
.802 .13643 Mdot
.802 .13645 Mdot
.802 .13715 Mdot
.802 .13795 Mdot
.802 .1381 Mdot
.802 .13907 Mdot
.802 .13941 Mdot
.802 .14036 Mdot
.802 .14082 Mdot
.802 .14117 Mdot
.802 .14162 Mdot
.802 .1419 Mdot
.802 .14256 Mdot
.802 .14284 Mdot
.802 .14291 Mdot
.802 .14296 Mdot
.802 .14373 Mdot
.802 .1449 Mdot
.802 .14504 Mdot
.802 .14526 Mdot
.802 .14569 Mdot
.802 .146 Mdot
.802 .14623 Mdot
.802 .14637 Mdot
.802 .14658 Mdot
.802 .14701 Mdot
.802 .14901 Mdot
.802 .14933 Mdot
.802 .14943 Mdot
.802 .15124 Mdot
.802 .15155 Mdot
.802 .15173 Mdot
.802 .15182 Mdot
.802 .15192 Mdot
.802 .15277 Mdot
.802 .1531 Mdot
.802 .15341 Mdot
.802 .15393 Mdot
.802 .15481 Mdot
.802 .15483 Mdot
.802 .15486 Mdot
.802 .15556 Mdot
.802 .15617 Mdot
.802 .15628 Mdot
.802 .15757 Mdot
.802 .15769 Mdot
.802 .15786 Mdot
.802 .15792 Mdot
.802 .158 Mdot
.802 .15882 Mdot
.802 .1595 Mdot
.802 .15977 Mdot
.802 .1602 Mdot
.802 .1609 Mdot
.802 .16154 Mdot
.802 .1617 Mdot
.802 .16218 Mdot
.802 .16226 Mdot
.802 .16228 Mdot
.802 .16272 Mdot
.802 .16325 Mdot
.802 .16337 Mdot
.802 .16426 Mdot
.802 .16434 Mdot
.802 .16436 Mdot
.802 .16526 Mdot
.802 .16539 Mdot
.802 .16652 Mdot
.802 .16671 Mdot
.802 .16692 Mdot
.802 .16769 Mdot
.802 .16782 Mdot
.802 .16858 Mdot
.802 .16915 Mdot
.802 .17001 Mdot
.802 .17054 Mdot
.802 .17109 Mdot
.802 .17151 Mdot
.802 .1717 Mdot
.802 .17173 Mdot
.802 .17205 Mdot
.802 .17227 Mdot
.802 .17255 Mdot
.802 .1731 Mdot
.802 .17429 Mdot
.802 .17444 Mdot
.802 .17495 Mdot
.802 .17525 Mdot
.802 .17538 Mdot
.802 .1754 Mdot
.802 .17547 Mdot
.802 .1756 Mdot
.802 .17669 Mdot
.802 .17774 Mdot
.802 .17805 Mdot
.802 .17817 Mdot
.802 .17817 Mdot
.802 .17844 Mdot
.802 .17849 Mdot
.802 .17914 Mdot
.802 .18056 Mdot
.802 .18112 Mdot
.802 .18129 Mdot
.802 .18131 Mdot
.802 .18146 Mdot
.802 .18169 Mdot
.802 .18203 Mdot
.802 .18254 Mdot
.802 .18349 Mdot
.802 .18352 Mdot
.802 .18374 Mdot
.802 .1839 Mdot
.802 .18396 Mdot
.802 .18447 Mdot
.802 .18509 Mdot
.802 .18535 Mdot
.802 .18553 Mdot
.802 .18577 Mdot
.802 .18622 Mdot
.802 .18626 Mdot
.802 .18721 Mdot
.802 .18722 Mdot
.802 .1875 Mdot
.802 .18779 Mdot
.802 .18825 Mdot
.802 .1883 Mdot
.802 .18839 Mdot
.802 .18935 Mdot
.802 .18973 Mdot
.802 .1903 Mdot
.802 .19056 Mdot
.802 .19065 Mdot
.802 .19087 Mdot
.802 .19106 Mdot
.802 .19179 Mdot
.802 .19229 Mdot
.802 .19255 Mdot
.802 .19406 Mdot
.802 .19441 Mdot
.802 .1946 Mdot
.802 .19467 Mdot
.802 .19552 Mdot
.802 .19577 Mdot
.802 .19724 Mdot
.802 .19742 Mdot
.802 .19786 Mdot
.802 .1983 Mdot
.802 .19896 Mdot
.802 .19914 Mdot
.802 .19957 Mdot
.802 .19957 Mdot
.802 .1996 Mdot
.802 .19965 Mdot
.802 .20027 Mdot
.802 .20028 Mdot
.802 .2004 Mdot
.802 .20068 Mdot
.802 .20073 Mdot
.802 .20074 Mdot
.802 .20151 Mdot
.802 .2017 Mdot
.802 .2019 Mdot
.802 .20242 Mdot
.802 .20273 Mdot
.802 .20295 Mdot
.802 .20347 Mdot
.802 .20357 Mdot
.802 .20375 Mdot
.802 .20383 Mdot
.802 .20438 Mdot
.802 .20471 Mdot
.802 .20504 Mdot
.802 .20545 Mdot
.802 .20564 Mdot
.802 .20582 Mdot
.802 .20582 Mdot
.802 .20756 Mdot
.802 .20784 Mdot
.802 .20832 Mdot
.802 .20842 Mdot
.802 .20888 Mdot
.802 .20995 Mdot
.802 .20998 Mdot
.802 .2111 Mdot
.802 .21239 Mdot
.802 .21263 Mdot
.802 .21323 Mdot
.802 .21373 Mdot
.802 .21418 Mdot
.802 .21448 Mdot
.802 .21473 Mdot
.802 .21499 Mdot
.802 .215 Mdot
.802 .21608 Mdot
.802 .21625 Mdot
.802 .2163 Mdot
.802 .21698 Mdot
.802 .21755 Mdot
.802 .21827 Mdot
.802 .21872 Mdot
.802 .21898 Mdot
.802 .21978 Mdot
.802 .22023 Mdot
.802 .22033 Mdot
.802 .22042 Mdot
.802 .22166 Mdot
.802 .22352 Mdot
.802 .22375 Mdot
.802 .22411 Mdot
.802 .22441 Mdot
.802 .22479 Mdot
.802 .22486 Mdot
.802 .22529 Mdot
.802 .22567 Mdot
.802 .22588 Mdot
.802 .22623 Mdot
.802 .22692 Mdot
.802 .22715 Mdot
.802 .22787 Mdot
.802 .22793 Mdot
.802 .22819 Mdot
.802 .22855 Mdot
.802 .2295 Mdot
.802 .2301 Mdot
.802 .23012 Mdot
.802 .23063 Mdot
.802 .23079 Mdot
.802 .23087 Mdot
.802 .23092 Mdot
.802 .23301 Mdot
.802 .2337 Mdot
.802 .23421 Mdot
.802 .23448 Mdot
.802 .23463 Mdot
.802 .23479 Mdot
.802 .23615 Mdot
.802 .23669 Mdot
.802 .23695 Mdot
.802 .23705 Mdot
.802 .23718 Mdot
.802 .23799 Mdot
.802 .23801 Mdot
.802 .23863 Mdot
.802 .2389 Mdot
.802 .23942 Mdot
.802 .23946 Mdot
.802 .23952 Mdot
.802 .23996 Mdot
.802 .24062 Mdot
.802 .24099 Mdot
.802 .2416 Mdot
.802 .24179 Mdot
.802 .2426 Mdot
.802 .24354 Mdot
.802 .24385 Mdot
.802 .24405 Mdot
.802 .24432 Mdot
.802 .24441 Mdot
.802 .24454 Mdot
.802 .24461 Mdot
.802 .24536 Mdot
.802 .24585 Mdot
.802 .24637 Mdot
.802 .24695 Mdot
.802 .24739 Mdot
.802 .24807 Mdot
.802 .24821 Mdot
.802 .24838 Mdot
.802 .2492 Mdot
.802 .25022 Mdot
.802 .25048 Mdot
.802 .25125 Mdot
.802 .25138 Mdot
.802 .25141 Mdot
.802 .25212 Mdot
.802 .25231 Mdot
.802 .25235 Mdot
.802 .25296 Mdot
.802 .25316 Mdot
.802 .2535 Mdot
.802 .25458 Mdot
.802 .25469 Mdot
.802 .25472 Mdot
.802 .25475 Mdot
.802 .25618 Mdot
.802 .2564 Mdot
.802 .25658 Mdot
.802 .25679 Mdot
.802 .25718 Mdot
.802 .25813 Mdot
.802 .25822 Mdot
.802 .25851 Mdot
.802 .25886 Mdot
.802 .26007 Mdot
.802 .26008 Mdot
.802 .26029 Mdot
.802 .26114 Mdot
.802 .26151 Mdot
.802 .26242 Mdot
.802 .26269 Mdot
.802 .2638 Mdot
.802 .26465 Mdot
.802 .26475 Mdot
.802 .26504 Mdot
.802 .26554 Mdot
.802 .2661 Mdot
.802 .26621 Mdot
.802 .2665 Mdot
.802 .26652 Mdot
.802 .26656 Mdot
.802 .26708 Mdot
.802 .2674 Mdot
.802 .26744 Mdot
.802 .26788 Mdot
.802 .26818 Mdot
.802 .26876 Mdot
.802 .26943 Mdot
.802 .27067 Mdot
.802 .27092 Mdot
.802 .27118 Mdot
.802 .27173 Mdot
.802 .27222 Mdot
.802 .27242 Mdot
.802 .27246 Mdot
.802 .27256 Mdot
.802 .27277 Mdot
.802 .27326 Mdot
.802 .27435 Mdot
.802 .27452 Mdot
.802 .27621 Mdot
.802 .27641 Mdot
.802 .2767 Mdot
.802 .2769 Mdot
.802 .2769 Mdot
.802 .27732 Mdot
.802 .27741 Mdot
.802 .27845 Mdot
.802 .28056 Mdot
.802 .28073 Mdot
.802 .28162 Mdot
.802 .2819 Mdot
.802 .28193 Mdot
.802 .28203 Mdot
.802 .28217 Mdot
.802 .28254 Mdot
.802 .28277 Mdot
.802 .28307 Mdot
.802 .28309 Mdot
.802 .2839 Mdot
.802 .28543 Mdot
.802 .28547 Mdot
.802 .28584 Mdot
.802 .28609 Mdot
.802 .28619 Mdot
.802 .2866 Mdot
.802 .287 Mdot
.802 .28763 Mdot
.802 .28799 Mdot
.802 .28841 Mdot
.802 .2887 Mdot
.802 .28909 Mdot
.802 .28981 Mdot
.802 .28988 Mdot
.802 .2914 Mdot
.802 .29142 Mdot
.802 .29187 Mdot
.802 .29233 Mdot
.802 .29306 Mdot
.802 .29314 Mdot
.802 .2933 Mdot
.802 .29367 Mdot
.802 .29442 Mdot
.802 .29483 Mdot
.802 .29544 Mdot
.802 .29624 Mdot
.802 .29635 Mdot
.802 .29676 Mdot
.802 .29692 Mdot
.802 .29727 Mdot
.802 .29757 Mdot
.802 .29806 Mdot
.802 .29874 Mdot
.802 .29955 Mdot
.802 .29997 Mdot
.802 .30077 Mdot
.802 .30238 Mdot
.802 .30295 Mdot
.802 .30324 Mdot
.802 .30336 Mdot
.802 .30473 Mdot
.802 .30513 Mdot
.802 .30748 Mdot
.802 .30777 Mdot
.802 .30848 Mdot
.802 .30918 Mdot
.802 .31024 Mdot
.802 .31053 Mdot
.802 .31122 Mdot
.802 .31123 Mdot
.802 .31127 Mdot
.802 .31134 Mdot
.802 .31234 Mdot
.802 .31237 Mdot
.802 .31256 Mdot
.802 .313 Mdot
.802 .31309 Mdot
.802 .3131 Mdot
.802 .31433 Mdot
.802 .31464 Mdot
.802 .31496 Mdot
.802 .3158 Mdot
.802 .31629 Mdot
.802 .31664 Mdot
.802 .31748 Mdot
.802 .31764 Mdot
.802 .31793 Mdot
.802 .31806 Mdot
.802 .31894 Mdot
.802 .31946 Mdot
.802 .31999 Mdot
.802 .32065 Mdot
.802 .32096 Mdot
.802 .32125 Mdot
.802 .32125 Mdot
.802 .3234 Mdot
.802 .32403 Mdot
.802 .32449 Mdot
.802 .32526 Mdot
.802 .32543 Mdot
.802 .32615 Mdot
.802 .32787 Mdot
.802 .32792 Mdot
.802 .32971 Mdot
.802 .33178 Mdot
.802 .33217 Mdot
.802 .33314 Mdot
.802 .33394 Mdot
.802 .33465 Mdot
.802 .33514 Mdot
.802 .33553 Mdot
.802 .33596 Mdot
.802 .33596 Mdot
.802 .33771 Mdot
.802 .33797 Mdot
.802 .33806 Mdot
.802 .33915 Mdot
.802 .34006 Mdot
.802 .34122 Mdot
.802 .34194 Mdot
.802 .34235 Mdot
.802 .34364 Mdot
.802 .34436 Mdot
.802 .34452 Mdot
.802 .34467 Mdot
.802 .34665 Mdot
.802 .34965 Mdot
.802 .35 Mdot
.802 .35058 Mdot
.802 .35106 Mdot
.802 .35168 Mdot
.802 .35179 Mdot
.802 .35308 Mdot
.802 .35343 Mdot
.802 .35398 Mdot
.802 .35509 Mdot
.802 .35546 Mdot
.802 .35661 Mdot
.802 .35671 Mdot
.802 .35713 Mdot
.802 .35771 Mdot
.802 .35923 Mdot
.802 .3602 Mdot
.802 .36022 Mdot
.802 .36105 Mdot
.802 .3613 Mdot
.802 .36142 Mdot
.802 .36151 Mdot
.802 .36486 Mdot
.802 .36597 Mdot
.802 .36678 Mdot
.802 .36722 Mdot
.802 .36746 Mdot
.802 .36771 Mdot
.802 .3699 Mdot
.802 .37076 Mdot
.802 .37118 Mdot
.802 .37134 Mdot
.802 .37155 Mdot
.802 .37284 Mdot
.802 .37288 Mdot
.802 .37388 Mdot
.802 .3743 Mdot
.802 .37514 Mdot
.802 .3752 Mdot
.802 .37529 Mdot
.802 .37601 Mdot
.802 .37707 Mdot
.802 .37767 Mdot
.802 .37864 Mdot
.802 .37894 Mdot
.802 .38024 Mdot
.802 .38175 Mdot
.802 .38224 Mdot
.802 .38257 Mdot
.802 .383 Mdot
.802 .38315 Mdot
.802 .38335 Mdot
.802 .38347 Mdot
.802 .38468 Mdot
.802 .38546 Mdot
.802 .38629 Mdot
.802 .38723 Mdot
.802 .38792 Mdot
.802 .38901 Mdot
.802 .38923 Mdot
.802 .38951 Mdot
.802 .39083 Mdot
.802 .39247 Mdot
.802 .39287 Mdot
.802 .39412 Mdot
.802 .39432 Mdot
.802 .39438 Mdot
.802 .39551 Mdot
.802 .39581 Mdot
.802 .39587 Mdot
.802 .39686 Mdot
.802 .39719 Mdot
.802 .39773 Mdot
.802 .39946 Mdot
.802 .39964 Mdot
.802 .39968 Mdot
.802 .39972 Mdot
.802 .40203 Mdot
.802 .40238 Mdot
.802 .40267 Mdot
.802 .403 Mdot
.802 .40363 Mdot
.802 .40515 Mdot
.802 .40529 Mdot
.802 .40577 Mdot
.802 .40632 Mdot
.802 .40827 Mdot
.802 .40828 Mdot
.802 .40862 Mdot
.802 .40998 Mdot
.802 .41058 Mdot
.802 .41204 Mdot
.802 .41247 Mdot
.802 .41426 Mdot
.802 .41562 Mdot
.802 .41578 Mdot
.802 .41623 Mdot
.802 .41704 Mdot
.802 .41794 Mdot
.802 .41812 Mdot
.802 .41858 Mdot
.802 .41862 Mdot
.802 .41867 Mdot
.802 .41951 Mdot
.802 .42002 Mdot
.802 .42008 Mdot
.802 .42079 Mdot
.802 .42127 Mdot
.802 .42221 Mdot
.802 .42327 Mdot
.802 .42526 Mdot
.802 .42566 Mdot
.802 .42609 Mdot
.802 .42697 Mdot
.802 .42775 Mdot
.802 .42808 Mdot
.802 .42814 Mdot
.802 .4283 Mdot
.802 .42864 Mdot
.802 .42943 Mdot
.802 .43116 Mdot
.802 .43145 Mdot
.802 .43416 Mdot
.802 .43447 Mdot
.802 .43494 Mdot
.802 .43526 Mdot
.802 .43526 Mdot
.802 .43594 Mdot
.802 .43608 Mdot
.802 .43774 Mdot
.802 .44113 Mdot
.802 .44141 Mdot
.802 .44284 Mdot
.802 .44329 Mdot
.802 .44332 Mdot
.802 .44348 Mdot
.802 .44371 Mdot
.802 .4443 Mdot
.802 .44468 Mdot
.802 .44515 Mdot
.802 .44519 Mdot
.802 .44649 Mdot
.802 .44895 Mdot
.802 .44901 Mdot
.802 .44959 Mdot
.802 .45 Mdot
.802 .45016 Mdot
.802 .45082 Mdot
.802 .45147 Mdot
.802 .45247 Mdot
.802 .45306 Mdot
.802 .45372 Mdot
.802 .45419 Mdot
.802 .45482 Mdot
.802 .45596 Mdot
.802 .45607 Mdot
.802 .45852 Mdot
.802 .45854 Mdot
.802 .45927 Mdot
.802 .46001 Mdot
.802 .46119 Mdot
.802 .46131 Mdot
.802 .46156 Mdot
.802 .46215 Mdot
.802 .46336 Mdot
.802 .46403 Mdot
.802 .46499 Mdot
.802 .46628 Mdot
.802 .46646 Mdot
.802 .46712 Mdot
.802 .46737 Mdot
.802 .46793 Mdot
.802 .46841 Mdot
.802 .46919 Mdot
.802 .47029 Mdot
.802 .47159 Mdot
.802 .47226 Mdot
.802 .47355 Mdot
.802 .47613 Mdot
.802 .47705 Mdot
.802 .47751 Mdot
.802 .4777 Mdot
.802 .4799 Mdot
.802 .48054 Mdot
.802 .48431 Mdot
.802 .48478 Mdot
.802 .48591 Mdot
.802 .48704 Mdot
.802 .48873 Mdot
.804 .01526 Mdot
.804 .01559 Mdot
.804 .01612 Mdot
.804 .01636 Mdot
.804 .01662 Mdot
.804 .01698 Mdot
.804 .0171 Mdot
.804 .01736 Mdot
.804 .01777 Mdot
.804 .01835 Mdot
.804 .01856 Mdot
.804 .01897 Mdot
.804 .0191 Mdot
.804 .01963 Mdot
.804 .02016 Mdot
.804 .02056 Mdot
.804 .02089 Mdot
.804 .0209 Mdot
.804 .02156 Mdot
.804 .02177 Mdot
.804 .02244 Mdot
.804 .02262 Mdot
.804 .02283 Mdot
.804 .02347 Mdot
.804 .02393 Mdot
.804 .02412 Mdot
.804 .0245 Mdot
.804 .02465 Mdot
.804 .02466 Mdot
.804 .02503 Mdot
.804 .0251 Mdot
.804 .02572 Mdot
.804 .02606 Mdot
.804 .02613 Mdot
.804 .02621 Mdot
.804 .02653 Mdot
.804 .02714 Mdot
.804 .02714 Mdot
.804 .02743 Mdot
.804 .02777 Mdot
.804 .0288 Mdot
.804 .02954 Mdot
.804 .02984 Mdot
.804 .03045 Mdot
.804 .03069 Mdot
.804 .03069 Mdot
.804 .03071 Mdot
.804 .03084 Mdot
.804 .03115 Mdot
.804 .03131 Mdot
.804 .03141 Mdot
.804 .03241 Mdot
.804 .03296 Mdot
.804 .03307 Mdot
.804 .03319 Mdot
.804 .0336 Mdot
.804 .03372 Mdot
.804 .03469 Mdot
.804 .03469 Mdot
.804 .03516 Mdot
.804 .03571 Mdot
.804 .03602 Mdot
.804 .03736 Mdot
.804 .03855 Mdot
.804 .03893 Mdot
.804 .03903 Mdot
.804 .04001 Mdot
.804 .0404 Mdot
.804 .04041 Mdot
.804 .04043 Mdot
.804 .04064 Mdot
.804 .04069 Mdot
.804 .04085 Mdot
.804 .04114 Mdot
.804 .04132 Mdot
.804 .04139 Mdot
.804 .04156 Mdot
.804 .04176 Mdot
.804 .04275 Mdot
.804 .04282 Mdot
.804 .04317 Mdot
.804 .04406 Mdot
.804 .04423 Mdot
.804 .04443 Mdot
.804 .04509 Mdot
.804 .04528 Mdot
.804 .04543 Mdot
.804 .0465 Mdot
.804 .04683 Mdot
.804 .04683 Mdot
.804 .04722 Mdot
.804 .04758 Mdot
.804 .04847 Mdot
.804 .04897 Mdot
.804 .04941 Mdot
.804 .05038 Mdot
.804 .05112 Mdot
.804 .05128 Mdot
.804 .0529 Mdot
.804 .05291 Mdot
.804 .05304 Mdot
.804 .05365 Mdot
.804 .05382 Mdot
.804 .05539 Mdot
.804 .05587 Mdot
.804 .05601 Mdot
.804 .05603 Mdot
.804 .05607 Mdot
.804 .0564 Mdot
.804 .05648 Mdot
.804 .05673 Mdot
.804 .0572 Mdot
.804 .05721 Mdot
.804 .0575 Mdot
.804 .05761 Mdot
.804 .05769 Mdot
.804 .05789 Mdot
.804 .05821 Mdot
.804 .0598 Mdot
.804 .05991 Mdot
.804 .06047 Mdot
.804 .0619 Mdot
.804 .06217 Mdot
.804 .06249 Mdot
.804 .06355 Mdot
.804 .06358 Mdot
.804 .06386 Mdot
.804 .0641 Mdot
.804 .06428 Mdot
.804 .06459 Mdot
.804 .06489 Mdot
.804 .06582 Mdot
.804 .06636 Mdot
.804 .06636 Mdot
.804 .06666 Mdot
.804 .06674 Mdot
.804 .06698 Mdot
.804 .06755 Mdot
.804 .06757 Mdot
.804 .06818 Mdot
.804 .069 Mdot
.804 .0698 Mdot
.804 .06986 Mdot
.804 .07016 Mdot
.804 .0705 Mdot
.804 .07077 Mdot
.804 .07184 Mdot
.804 .07207 Mdot
.804 .07209 Mdot
.804 .07215 Mdot
.804 .07263 Mdot
.804 .07326 Mdot
.804 .07351 Mdot
.804 .07545 Mdot
.804 .07562 Mdot
.804 .07582 Mdot
.804 .07611 Mdot
.804 .07613 Mdot
.804 .07634 Mdot
.804 .07733 Mdot
.804 .07759 Mdot
.804 .07792 Mdot
.804 .07866 Mdot
.804 .07908 Mdot
.804 .07912 Mdot
.804 .08012 Mdot
.804 .0809 Mdot
.804 .08112 Mdot
.804 .08115 Mdot
.804 .08122 Mdot
.804 .08175 Mdot
.804 .08187 Mdot
.804 .08228 Mdot
.804 .08304 Mdot
.804 .08305 Mdot
.804 .08351 Mdot
.804 .08369 Mdot
.804 .08382 Mdot
.804 .08414 Mdot
.804 .0842 Mdot
.804 .08465 Mdot
.804 .08485 Mdot
.804 .08721 Mdot
.804 .08737 Mdot
.804 .08738 Mdot
.804 .08754 Mdot
.804 .0876 Mdot
.804 .08829 Mdot
.804 .08866 Mdot
.804 .08902 Mdot
.804 .09002 Mdot
.804 .09058 Mdot
.804 .09102 Mdot
.804 .09154 Mdot
.804 .09324 Mdot
.804 .09329 Mdot
.804 .09373 Mdot
.804 .09412 Mdot
.804 .09422 Mdot
.804 .09438 Mdot
.804 .09441 Mdot
.804 .09442 Mdot
.804 .09449 Mdot
.804 .09492 Mdot
.804 .0954 Mdot
.804 .09546 Mdot
.804 .09689 Mdot
.804 .09772 Mdot
.804 .09775 Mdot
.804 .09776 Mdot
.804 .09791 Mdot
.804 .09825 Mdot
.804 .09837 Mdot
.804 .09858 Mdot
.804 .09876 Mdot
.804 .09902 Mdot
.804 .09956 Mdot
.804 .09968 Mdot
.804 .0997 Mdot
.804 .09996 Mdot
.804 .1002 Mdot
.804 .10024 Mdot
.804 .10068 Mdot
.804 .10114 Mdot
.804 .1016 Mdot
.804 .102 Mdot
.804 .10292 Mdot
.804 .10329 Mdot
.804 .10338 Mdot
.804 .10387 Mdot
.804 .10442 Mdot
.804 .10486 Mdot
.804 .10556 Mdot
.804 .1058 Mdot
.804 .10647 Mdot
.804 .10657 Mdot
.804 .10695 Mdot
.804 .10698 Mdot
.804 .10706 Mdot
.804 .10728 Mdot
.804 .10747 Mdot
.804 .10784 Mdot
.804 .10885 Mdot
.804 .10918 Mdot
.804 .10926 Mdot
.804 .11081 Mdot
.804 .11103 Mdot
.804 .11238 Mdot
.804 .11266 Mdot
.804 .11296 Mdot
.804 .11308 Mdot
.804 .11344 Mdot
.804 .11347 Mdot
.804 .11378 Mdot
.804 .1138 Mdot
.804 .114 Mdot
.804 .11474 Mdot
.804 .1154 Mdot
.804 .11579 Mdot
.804 .11582 Mdot
.804 .11634 Mdot
.804 .11652 Mdot
.804 .11706 Mdot
.804 .11754 Mdot
.804 .11821 Mdot
.804 .11828 Mdot
.804 .11988 Mdot
.804 .12017 Mdot
.804 .12092 Mdot
.804 .12114 Mdot
.804 .12116 Mdot
.804 .12149 Mdot
.804 .12154 Mdot
.804 .12165 Mdot
.804 .1225 Mdot
.804 .1227 Mdot
.804 .12284 Mdot
.804 .12336 Mdot
.804 .12456 Mdot
.804 .12458 Mdot
.804 .1246 Mdot
.804 .12533 Mdot
.804 .1256 Mdot
.804 .12563 Mdot
.804 .12566 Mdot
.804 .12583 Mdot
.804 .12619 Mdot
.804 .12635 Mdot
.804 .12645 Mdot
.804 .12712 Mdot
.804 .12717 Mdot
.804 .1275 Mdot
.804 .12791 Mdot
.804 .12882 Mdot
.804 .12895 Mdot
.804 .1292 Mdot
.804 .12946 Mdot
.804 .13129 Mdot
.804 .13142 Mdot
.804 .13155 Mdot
.804 .13157 Mdot
.804 .13181 Mdot
.804 .13191 Mdot
.804 .13206 Mdot
.804 .13291 Mdot
.804 .13295 Mdot
.804 .13302 Mdot
.804 .13361 Mdot
.804 .13419 Mdot
.804 .13532 Mdot
.804 .13547 Mdot
.804 .13581 Mdot
.804 .13671 Mdot
.804 .13689 Mdot
.804 .13741 Mdot
.804 .13825 Mdot
.804 .13897 Mdot
.804 .14082 Mdot
.804 .14099 Mdot
.804 .14106 Mdot
.804 .14156 Mdot
.804 .14178 Mdot
.804 .14193 Mdot
.804 .1424 Mdot
.804 .14255 Mdot
.804 .14281 Mdot
.804 .14287 Mdot
.804 .14288 Mdot
.804 .143 Mdot
.804 .14368 Mdot
.804 .14445 Mdot
.804 .14456 Mdot
.804 .14578 Mdot
.804 .1466 Mdot
.804 .14685 Mdot
.804 .14819 Mdot
.804 .14823 Mdot
.804 .14824 Mdot
.804 .14826 Mdot
.804 .14849 Mdot
.804 .14903 Mdot
.804 .14924 Mdot
.804 .14957 Mdot
.804 .14964 Mdot
.804 .14986 Mdot
.804 .14997 Mdot
.804 .15028 Mdot
.804 .15098 Mdot
.804 .15114 Mdot
.804 .15133 Mdot
.804 .15138 Mdot
.804 .15179 Mdot
.804 .15218 Mdot
.804 .15223 Mdot
.804 .15273 Mdot
.804 .15295 Mdot
.804 .15338 Mdot
.804 .15368 Mdot
.804 .15443 Mdot
.804 .15507 Mdot
.804 .15549 Mdot
.804 .15574 Mdot
.804 .15588 Mdot
.804 .1561 Mdot
.804 .15651 Mdot
.804 .15654 Mdot
.804 .15667 Mdot
.804 .15714 Mdot
.804 .15729 Mdot
.804 .1575 Mdot
.804 .15808 Mdot
.804 .15811 Mdot
.804 .15845 Mdot
.804 .15895 Mdot
.804 .1594 Mdot
.804 .15967 Mdot
.804 .16079 Mdot
.804 .16118 Mdot
.804 .16184 Mdot
.804 .16226 Mdot
.804 .16242 Mdot
.804 .16302 Mdot
.804 .16308 Mdot
.804 .16321 Mdot
.804 .16356 Mdot
.804 .16387 Mdot
.804 .16446 Mdot
.804 .16457 Mdot
.804 .16511 Mdot
.804 .16609 Mdot
.804 .16662 Mdot
.804 .16675 Mdot
.804 .16862 Mdot
.804 .16924 Mdot
.804 .16959 Mdot
.804 .17084 Mdot
.804 .17138 Mdot
.804 .17176 Mdot
.804 .1722 Mdot
.804 .17242 Mdot
.804 .1727 Mdot
.804 .17272 Mdot
.804 .17289 Mdot
.804 .17315 Mdot
.804 .17347 Mdot
.804 .17352 Mdot
.804 .1738 Mdot
.804 .17401 Mdot
.804 .17405 Mdot
.804 .17436 Mdot
.804 .17555 Mdot
.804 .17615 Mdot
.804 .17661 Mdot
.804 .1767 Mdot
.804 .17685 Mdot
.804 .17725 Mdot
.804 .17729 Mdot
.804 .17813 Mdot
.804 .17842 Mdot
.804 .17898 Mdot
.804 .17917 Mdot
.804 .17928 Mdot
.804 .18005 Mdot
.804 .18114 Mdot
.804 .18125 Mdot
.804 .18175 Mdot
.804 .1832 Mdot
.804 .18382 Mdot
.804 .18429 Mdot
.804 .18549 Mdot
.804 .18585 Mdot
.804 .18588 Mdot
.804 .18641 Mdot
.804 .18649 Mdot
.804 .18667 Mdot
.804 .18799 Mdot
.804 .18803 Mdot
.804 .18836 Mdot
.804 .18838 Mdot
.804 .18857 Mdot
.804 .18941 Mdot
.804 .19056 Mdot
.804 .19062 Mdot
.804 .19134 Mdot
.804 .19137 Mdot
.804 .19141 Mdot
.804 .1922 Mdot
.804 .19259 Mdot
.804 .19302 Mdot
.804 .19307 Mdot
.804 .19311 Mdot
.804 .19339 Mdot
.804 .19396 Mdot
.804 .19406 Mdot
.804 .19422 Mdot
.804 .19439 Mdot
.804 .19496 Mdot
.804 .19546 Mdot
.804 .19554 Mdot
.804 .19581 Mdot
.804 .19607 Mdot
.804 .19612 Mdot
.804 .19621 Mdot
.804 .19673 Mdot
.804 .19691 Mdot
.804 .19799 Mdot
.804 .1982 Mdot
.804 .19841 Mdot
.804 .19881 Mdot
.804 .19923 Mdot
.804 .19933 Mdot
.804 .19952 Mdot
.804 .20029 Mdot
.804 .2007 Mdot
.804 .20099 Mdot
.804 .20158 Mdot
.804 .20174 Mdot
.804 .20216 Mdot
.804 .20238 Mdot
.804 .20259 Mdot
.804 .20261 Mdot
.804 .20301 Mdot
.804 .20304 Mdot
.804 .20317 Mdot
.804 .2034 Mdot
.804 .20478 Mdot
.804 .20483 Mdot
.804 .20495 Mdot
.804 .2059 Mdot
.804 .20684 Mdot
.804 .20796 Mdot
.804 .20864 Mdot
.804 .2087 Mdot
.804 .20889 Mdot
.804 .20906 Mdot
.804 .20944 Mdot
.804 .20947 Mdot
.804 .21047 Mdot
.804 .21089 Mdot
.804 .21117 Mdot
.804 .21201 Mdot
.804 .21239 Mdot
.804 .21274 Mdot
.804 .21336 Mdot
.804 .21337 Mdot
.804 .21451 Mdot
.804 .21503 Mdot
.804 .21522 Mdot
.804 .21749 Mdot
.804 .21776 Mdot
.804 .21789 Mdot
.804 .218 Mdot
.804 .21869 Mdot
.804 .21872 Mdot
.804 .21903 Mdot
.804 .21927 Mdot
.804 .21992 Mdot
.804 .22004 Mdot
.804 .22028 Mdot
.804 .22069 Mdot
.804 .22079 Mdot
.804 .22081 Mdot
.804 .22099 Mdot
.804 .22209 Mdot
.804 .22215 Mdot
.804 .22223 Mdot
.804 .22304 Mdot
.804 .22333 Mdot
.804 .22349 Mdot
.804 .22351 Mdot
.804 .22547 Mdot
.804 .22572 Mdot
.804 .2267 Mdot
.804 .22676 Mdot
.804 .22678 Mdot
.804 .22719 Mdot
.804 .22733 Mdot
.804 .22772 Mdot
.804 .22934 Mdot
.804 .2294 Mdot
.804 .22942 Mdot
.804 .22945 Mdot
.804 .22983 Mdot
.804 .2307 Mdot
.804 .23077 Mdot
.804 .23103 Mdot
.804 .2312 Mdot
.804 .23141 Mdot
.804 .23156 Mdot
.804 .23166 Mdot
.804 .23167 Mdot
.804 .23202 Mdot
.804 .2322 Mdot
.804 .23271 Mdot
.804 .23373 Mdot
.804 .23382 Mdot
.804 .23408 Mdot
.804 .2344 Mdot
.804 .23447 Mdot
.804 .23513 Mdot
.804 .23576 Mdot
.804 .23585 Mdot
.804 .23664 Mdot
.804 .23691 Mdot
.804 .23699 Mdot
.804 .23728 Mdot
.804 .23769 Mdot
.804 .23797 Mdot
.804 .23818 Mdot
.804 .23938 Mdot
.804 .23967 Mdot
.804 .23976 Mdot
.804 .24041 Mdot
.804 .24108 Mdot
.804 .24148 Mdot
.804 .2415 Mdot
.804 .24171 Mdot
.804 .24207 Mdot
.804 .24237 Mdot
.804 .24273 Mdot
.804 .24278 Mdot
.804 .24298 Mdot
.804 .24373 Mdot
.804 .24398 Mdot
.804 .24431 Mdot
.804 .24432 Mdot
.804 .24524 Mdot
.804 .2453 Mdot
.804 .24585 Mdot
.804 .24665 Mdot
.804 .24737 Mdot
.804 .24765 Mdot
.804 .2478 Mdot
.804 .24929 Mdot
.804 .2496 Mdot
.804 .25023 Mdot
.804 .25078 Mdot
.804 .2509 Mdot
.804 .2513 Mdot
.804 .25197 Mdot
.804 .25222 Mdot
.804 .25304 Mdot
.804 .25314 Mdot
.804 .25319 Mdot
.804 .25328 Mdot
.804 .25344 Mdot
.804 .2535 Mdot
.804 .25382 Mdot
.804 .25405 Mdot
.804 .25419 Mdot
.804 .25455 Mdot
.804 .2555 Mdot
.804 .25568 Mdot
.804 .25655 Mdot
.804 .25676 Mdot
.804 .25812 Mdot
.804 .25898 Mdot
.804 .25919 Mdot
.804 .25959 Mdot
.804 .2597 Mdot
.804 .25987 Mdot
.804 .26012 Mdot
.804 .26103 Mdot
.804 .26124 Mdot
.804 .2613 Mdot
.804 .26212 Mdot
.804 .2622 Mdot
.804 .26319 Mdot
.804 .26376 Mdot
.804 .26561 Mdot
.804 .26576 Mdot
.804 .2666 Mdot
.804 .26663 Mdot
.804 .26724 Mdot
.804 .26796 Mdot
.804 .26831 Mdot
.804 .26863 Mdot
.804 .26876 Mdot
.804 .26879 Mdot
.804 .26906 Mdot
.804 .26948 Mdot
.804 .27 Mdot
.804 .27007 Mdot
.804 .27037 Mdot
.804 .27053 Mdot
.804 .27064 Mdot
.804 .27087 Mdot
.804 .27093 Mdot
.804 .27143 Mdot
.804 .27333 Mdot
.804 .27362 Mdot
.804 .27376 Mdot
.804 .27392 Mdot
.804 .27431 Mdot
.804 .27505 Mdot
.804 .27518 Mdot
.804 .27542 Mdot
.804 .27607 Mdot
.804 .27614 Mdot
.804 .27722 Mdot
.804 .27749 Mdot
.804 .27796 Mdot
.804 .27882 Mdot
.804 .27885 Mdot
.804 .27917 Mdot
.804 .27934 Mdot
.804 .2802 Mdot
.804 .28058 Mdot
.804 .2806 Mdot
.804 .28083 Mdot
.804 .28098 Mdot
.804 .28216 Mdot
.804 .28232 Mdot
.804 .2824 Mdot
.804 .2825 Mdot
.804 .2833 Mdot
.804 .28453 Mdot
.804 .28467 Mdot
.804 .28494 Mdot
.804 .2856 Mdot
.804 .28563 Mdot
.804 .28631 Mdot
.804 .28664 Mdot
.804 .2874 Mdot
.804 .28869 Mdot
.804 .28932 Mdot
.804 .28989 Mdot
.804 .28994 Mdot
.804 .29077 Mdot
.804 .29081 Mdot
.804 .29092 Mdot
.804 .29107 Mdot
.804 .29121 Mdot
.804 .29221 Mdot
.804 .2933 Mdot
.804 .29335 Mdot
.804 .29341 Mdot
.804 .29351 Mdot
.804 .29386 Mdot
.804 .29394 Mdot
.804 .29396 Mdot
.804 .29428 Mdot
.804 .29563 Mdot
.804 .29601 Mdot
.804 .2968 Mdot
.804 .29747 Mdot
.804 .29757 Mdot
.804 .29873 Mdot
.804 .29878 Mdot
.804 .29884 Mdot
.804 .30012 Mdot
.804 .30074 Mdot
.804 .30127 Mdot
.804 .30143 Mdot
.804 .30151 Mdot
.804 .30157 Mdot
.804 .30203 Mdot
.804 .30212 Mdot
.804 .30295 Mdot
.804 .303 Mdot
.804 .30311 Mdot
.804 .30336 Mdot
.804 .30363 Mdot
.804 .30455 Mdot
.804 .30536 Mdot
.804 .30548 Mdot
.804 .30592 Mdot
.804 .30634 Mdot
.804 .30642 Mdot
.804 .30655 Mdot
.804 .30739 Mdot
.804 .30769 Mdot
.804 .30942 Mdot
.804 .30975 Mdot
.804 .31009 Mdot
.804 .31073 Mdot
.804 .31142 Mdot
.804 .31158 Mdot
.804 .31188 Mdot
.804 .31313 Mdot
.804 .31378 Mdot
.804 .31424 Mdot
.804 .3152 Mdot
.804 .31545 Mdot
.804 .31613 Mdot
.804 .31648 Mdot
.804 .31681 Mdot
.804 .31685 Mdot
.804 .31749 Mdot
.804 .31754 Mdot
.804 .31775 Mdot
.804 .31812 Mdot
.804 .32033 Mdot
.804 .32042 Mdot
.804 .32062 Mdot
.804 .32214 Mdot
.804 .32364 Mdot
.804 .32546 Mdot
.804 .32655 Mdot
.804 .32665 Mdot
.804 .32694 Mdot
.804 .32722 Mdot
.804 .32783 Mdot
.804 .32787 Mdot
.804 .3295 Mdot
.804 .33016 Mdot
.804 .33061 Mdot
.804 .33197 Mdot
.804 .33258 Mdot
.804 .33314 Mdot
.804 .33414 Mdot
.804 .33415 Mdot
.804 .33599 Mdot
.804 .33683 Mdot
.804 .33712 Mdot
.804 .34079 Mdot
.804 .34122 Mdot
.804 .34141 Mdot
.804 .3416 Mdot
.804 .3427 Mdot
.804 .34275 Mdot
.804 .34325 Mdot
.804 .34364 Mdot
.804 .34469 Mdot
.804 .34488 Mdot
.804 .34526 Mdot
.804 .34592 Mdot
.804 .34608 Mdot
.804 .34611 Mdot
.804 .34641 Mdot
.804 .34817 Mdot
.804 .34827 Mdot
.804 .34839 Mdot
.804 .3497 Mdot
.804 .35016 Mdot
.804 .35042 Mdot
.804 .35045 Mdot
.804 .35361 Mdot
.804 .35402 Mdot
.804 .35558 Mdot
.804 .35568 Mdot
.804 .35572 Mdot
.804 .35638 Mdot
.804 .3566 Mdot
.804 .35723 Mdot
.804 .35984 Mdot
.804 .35994 Mdot
.804 .35996 Mdot
.804 .36001 Mdot
.804 .36061 Mdot
.804 .36202 Mdot
.804 .36213 Mdot
.804 .36255 Mdot
.804 .36283 Mdot
.804 .36316 Mdot
.804 .36341 Mdot
.804 .36356 Mdot
.804 .36358 Mdot
.804 .36414 Mdot
.804 .36443 Mdot
.804 .36525 Mdot
.804 .36689 Mdot
.804 .36704 Mdot
.804 .36746 Mdot
.804 .36796 Mdot
.804 .36808 Mdot
.804 .36914 Mdot
.804 .37016 Mdot
.804 .37029 Mdot
.804 .37157 Mdot
.804 .372 Mdot
.804 .37214 Mdot
.804 .3726 Mdot
.804 .37326 Mdot
.804 .37371 Mdot
.804 .37404 Mdot
.804 .37598 Mdot
.804 .37644 Mdot
.804 .37659 Mdot
.804 .37764 Mdot
.804 .37871 Mdot
.804 .37935 Mdot
.804 .37939 Mdot
.804 .37972 Mdot
.804 .3803 Mdot
.804 .38079 Mdot
.804 .38136 Mdot
.804 .38144 Mdot
.804 .38176 Mdot
.804 .38298 Mdot
.804 .38337 Mdot
.804 .3839 Mdot
.804 .38392 Mdot
.804 .3854 Mdot
.804 .38549 Mdot
.804 .38637 Mdot
.804 .38767 Mdot
.804 .38882 Mdot
.804 .38928 Mdot
.804 .38951 Mdot
.804 .39191 Mdot
.804 .39241 Mdot
.804 .39343 Mdot
.804 .3943 Mdot
.804 .39451 Mdot
.804 .39514 Mdot
.804 .39623 Mdot
.804 .39663 Mdot
.804 .39794 Mdot
.804 .3981 Mdot
.804 .39819 Mdot
.804 .39832 Mdot
.804 .39858 Mdot
.804 .39868 Mdot
.804 .39919 Mdot
.804 .39957 Mdot
.804 .39979 Mdot
.804 .40037 Mdot
.804 .40189 Mdot
.804 .40359 Mdot
.804 .40393 Mdot
.804 .40611 Mdot
.804 .40749 Mdot
.804 .40782 Mdot
.804 .40847 Mdot
.804 .40866 Mdot
.804 .40893 Mdot
.804 .40933 Mdot
.804 .41079 Mdot
.804 .41113 Mdot
.804 .41123 Mdot
.804 .41255 Mdot
.804 .41267 Mdot
.804 .41427 Mdot
.804 .41517 Mdot
.804 .41816 Mdot
.804 .41839 Mdot
.804 .41975 Mdot
.804 .41979 Mdot
.804 .42078 Mdot
.804 .42193 Mdot
.804 .42249 Mdot
.804 .42302 Mdot
.804 .42321 Mdot
.804 .42326 Mdot
.804 .4237 Mdot
.804 .42437 Mdot
.804 .42521 Mdot
.804 .42532 Mdot
.804 .42581 Mdot
.804 .42606 Mdot
.804 .42624 Mdot
.804 .42661 Mdot
.804 .4267 Mdot
.804 .42751 Mdot
.804 .43057 Mdot
.804 .43103 Mdot
.804 .43126 Mdot
.804 .43151 Mdot
.804 .43214 Mdot
.804 .43333 Mdot
.804 .43354 Mdot
.804 .43394 Mdot
.804 .43497 Mdot
.804 .43509 Mdot
.804 .43682 Mdot
.804 .43726 Mdot
.804 .43801 Mdot
.804 .4394 Mdot
.804 .43945 Mdot
.804 .43995 Mdot
.804 .44023 Mdot
.804 .44162 Mdot
.804 .44223 Mdot
.804 .44227 Mdot
.804 .44262 Mdot
.804 .44286 Mdot
.804 .44476 Mdot
.804 .44503 Mdot
.804 .44516 Mdot
.804 .44531 Mdot
.804 .4466 Mdot
.804 .44858 Mdot
.804 .44881 Mdot
.804 .44924 Mdot
.804 .45029 Mdot
.804 .45035 Mdot
.804 .45143 Mdot
.804 .45197 Mdot
.804 .45319 Mdot
.804 .45526 Mdot
.804 .45627 Mdot
.804 .4572 Mdot
.804 .45728 Mdot
.804 .45861 Mdot
.804 .45867 Mdot
.804 .45885 Mdot
.804 .45909 Mdot
.804 .45932 Mdot
.804 .46092 Mdot
.804 .46268 Mdot
.804 .46275 Mdot
.804 .46286 Mdot
.804 .46301 Mdot
.804 .46358 Mdot
.804 .46371 Mdot
.804 .46375 Mdot
.804 .46426 Mdot
.804 .46643 Mdot
.804 .46704 Mdot
.804 .46831 Mdot
.804 .46938 Mdot
.804 .46955 Mdot
.804 .47141 Mdot
.804 .47149 Mdot
.804 .47159 Mdot
.804 .47364 Mdot
.804 .47464 Mdot
.804 .4755 Mdot
.804 .47575 Mdot
.804 .47589 Mdot
.804 .47598 Mdot
.804 .47671 Mdot
.804 .47687 Mdot
.804 .47819 Mdot
.804 .47828 Mdot
.804 .47845 Mdot
.804 .47886 Mdot
.804 .4793 Mdot
.804 .48078 Mdot
.804 .48207 Mdot
.804 .48226 Mdot
.804 .48297 Mdot
.804 .48365 Mdot
.804 .48377 Mdot
.804 .48399 Mdot
.804 .48533 Mdot
.804 .48582 Mdot
.804 .4886 Mdot
.804 .48913 Mdot
.804 .48968 Mdot
.806 .01477 Mdot
.806 .01481 Mdot
.806 .01486 Mdot
.806 .01495 Mdot
.806 .01506 Mdot
.806 .0151 Mdot
.806 .01527 Mdot
.806 .01533 Mdot
.806 .01562 Mdot
.806 .01571 Mdot
.806 .01617 Mdot
.806 .01632 Mdot
.806 .01706 Mdot
.806 .01729 Mdot
.806 .01849 Mdot
.806 .01887 Mdot
.806 .01926 Mdot
.806 .01967 Mdot
.806 .01978 Mdot
.806 .02044 Mdot
.806 .0206 Mdot
.806 .0208 Mdot
.806 .02142 Mdot
.806 .02143 Mdot
.806 .02199 Mdot
.806 .02205 Mdot
.806 .02271 Mdot
.806 .02288 Mdot
.806 .02394 Mdot
.806 .0242 Mdot
.806 .02449 Mdot
.806 .02452 Mdot
.806 .02529 Mdot
.806 .0254 Mdot
.806 .02552 Mdot
.806 .02554 Mdot
.806 .02604 Mdot
.806 .02644 Mdot
.806 .02654 Mdot
.806 .02679 Mdot
.806 .0276 Mdot
.806 .02783 Mdot
.806 .02788 Mdot
.806 .02958 Mdot
.806 .03001 Mdot
.806 .03047 Mdot
.806 .03052 Mdot
.806 .03078 Mdot
.806 .0314 Mdot
.806 .03152 Mdot
.806 .03156 Mdot
.806 .03177 Mdot
.806 .03194 Mdot
.806 .03213 Mdot
.806 .03216 Mdot
.806 .03297 Mdot
.806 .03361 Mdot
.806 .03377 Mdot
.806 .03418 Mdot
.806 .03549 Mdot
.806 .03586 Mdot
.806 .03594 Mdot
.806 .03697 Mdot
.806 .03868 Mdot
.806 .03884 Mdot
.806 .03917 Mdot
.806 .03937 Mdot
.806 .03948 Mdot
.806 .04011 Mdot
.806 .04019 Mdot
.806 .04024 Mdot
.806 .04062 Mdot
.806 .04086 Mdot
.806 .04094 Mdot
.806 .04159 Mdot
.806 .04161 Mdot
.806 .04181 Mdot
.806 .04186 Mdot
.806 .04221 Mdot
.806 .04248 Mdot
.806 .04249 Mdot
.806 .0428 Mdot
.806 .04284 Mdot
.806 .04412 Mdot
.806 .04415 Mdot
.806 .04518 Mdot
.806 .04544 Mdot
.806 .0458 Mdot
.806 .04588 Mdot
.806 .04609 Mdot
.806 .04663 Mdot
.806 .04717 Mdot
.806 .04821 Mdot
.806 .04837 Mdot
.806 .04876 Mdot
.806 .04881 Mdot
.806 .04893 Mdot
.806 .04938 Mdot
.806 .05059 Mdot
.806 .051 Mdot
.806 .05233 Mdot
.806 .05334 Mdot
.806 .05361 Mdot
.806 .05402 Mdot
.806 .05414 Mdot
.806 .05446 Mdot
.806 .05451 Mdot
.806 .05461 Mdot
.806 .05464 Mdot
.806 .05504 Mdot
.806 .05566 Mdot
.806 .05577 Mdot
.806 .05586 Mdot
.806 .05593 Mdot
.806 .05642 Mdot
.806 .05644 Mdot
.806 .05647 Mdot
.806 .05685 Mdot
.806 .05699 Mdot
.806 .05804 Mdot
.806 .05807 Mdot
.806 .05838 Mdot
.806 .05848 Mdot
.806 .05892 Mdot
.806 .05896 Mdot
.806 .05903 Mdot
.806 .05948 Mdot
.806 .05949 Mdot
.806 .05998 Mdot
.806 .06005 Mdot
.806 .06072 Mdot
.806 .06073 Mdot
.806 .06075 Mdot
.806 .0616 Mdot
.806 .06212 Mdot
.806 .06216 Mdot
.806 .06382 Mdot
.806 .06424 Mdot
.806 .0648 Mdot
.806 .06483 Mdot
.806 .06495 Mdot
.806 .06529 Mdot
.806 .06615 Mdot
.806 .0664 Mdot
.806 .06693 Mdot
.806 .06703 Mdot
.806 .06851 Mdot
.806 .0687 Mdot
.806 .06897 Mdot
.806 .0696 Mdot
.806 .06967 Mdot
.806 .06986 Mdot
.806 .07056 Mdot
.806 .0706 Mdot
.806 .07179 Mdot
.806 .07255 Mdot
.806 .07263 Mdot
.806 .07282 Mdot
.806 .07321 Mdot
.806 .07377 Mdot
.806 .07436 Mdot
.806 .07536 Mdot
.806 .07628 Mdot
.806 .07648 Mdot
.806 .07698 Mdot
.806 .07713 Mdot
.806 .07718 Mdot
.806 .07741 Mdot
.806 .07808 Mdot
.806 .07826 Mdot
.806 .07879 Mdot
.806 .07886 Mdot
.806 .07903 Mdot
.806 .07908 Mdot
.806 .07921 Mdot
.806 .07971 Mdot
.806 .08071 Mdot
.806 .0809 Mdot
.806 .08105 Mdot
.806 .08116 Mdot
.806 .08147 Mdot
.806 .08192 Mdot
.806 .08194 Mdot
.806 .08197 Mdot
.806 .08202 Mdot
.806 .08241 Mdot
.806 .08264 Mdot
.806 .08287 Mdot
.806 .0832 Mdot
.806 .08358 Mdot
.806 .08455 Mdot
.806 .08461 Mdot
.806 .08489 Mdot
.806 .08511 Mdot
.806 .08526 Mdot
.806 .08598 Mdot
.806 .08604 Mdot
.806 .08615 Mdot
.806 .0863 Mdot
.806 .08687 Mdot
.806 .08689 Mdot
.806 .08698 Mdot
.806 .08768 Mdot
.806 .08777 Mdot
.806 .08779 Mdot
.806 .0878 Mdot
.806 .0886 Mdot
.806 .08888 Mdot
.806 .08889 Mdot
.806 .08892 Mdot
.806 .08908 Mdot
.806 .08919 Mdot
.806 .08942 Mdot
.806 .09029 Mdot
.806 .09035 Mdot
.806 .09112 Mdot
.806 .0912 Mdot
.806 .09185 Mdot
.806 .09357 Mdot
.806 .09388 Mdot
.806 .09442 Mdot
.806 .09455 Mdot
.806 .09545 Mdot
.806 .0955 Mdot
.806 .0957 Mdot
.806 .09612 Mdot
.806 .09624 Mdot
.806 .09698 Mdot
.806 .09711 Mdot
.806 .09764 Mdot
.806 .09799 Mdot
.806 .09803 Mdot
.806 .09889 Mdot
.806 .09905 Mdot
.806 .10041 Mdot
.806 .10068 Mdot
.806 .10143 Mdot
.806 .10174 Mdot
.806 .10217 Mdot
.806 .10319 Mdot
.806 .1033 Mdot
.806 .10361 Mdot
.806 .10474 Mdot
.806 .10479 Mdot
.806 .10644 Mdot
.806 .10672 Mdot
.806 .10756 Mdot
.806 .10794 Mdot
.806 .10796 Mdot
.806 .10808 Mdot
.806 .10838 Mdot
.806 .109 Mdot
.806 .10991 Mdot
.806 .11084 Mdot
.806 .11086 Mdot
.806 .11183 Mdot
.806 .11247 Mdot
.806 .11388 Mdot
.806 .11396 Mdot
.806 .11429 Mdot
.806 .11499 Mdot
.806 .11509 Mdot
.806 .11532 Mdot
.806 .11541 Mdot
.806 .11553 Mdot
.806 .11578 Mdot
.806 .11671 Mdot
.806 .11686 Mdot
.806 .11716 Mdot
.806 .118 Mdot
.806 .11812 Mdot
.806 .11839 Mdot
.806 .11847 Mdot
.806 .11857 Mdot
.806 .11862 Mdot
.806 .11868 Mdot
.806 .11949 Mdot
.806 .11996 Mdot
.806 .12032 Mdot
.806 .1211 Mdot
.806 .12141 Mdot
.806 .12164 Mdot
.806 .1218 Mdot
.806 .12183 Mdot
.806 .12233 Mdot
.806 .12274 Mdot
.806 .12305 Mdot
.806 .12308 Mdot
.806 .12313 Mdot
.806 .12321 Mdot
.806 .1236 Mdot
.806 .1238 Mdot
.806 .12384 Mdot
.806 .12422 Mdot
.806 .12439 Mdot
.806 .12458 Mdot
.806 .12512 Mdot
.806 .12572 Mdot
.806 .12573 Mdot
.806 .1273 Mdot
.806 .12738 Mdot
.806 .12783 Mdot
.806 .12819 Mdot
.806 .12844 Mdot
.806 .12859 Mdot
.806 .12959 Mdot
.806 .12969 Mdot
.806 .12987 Mdot
.806 .13011 Mdot
.806 .13103 Mdot
.806 .13105 Mdot
.806 .13121 Mdot
.806 .13138 Mdot
.806 .13234 Mdot
.806 .13249 Mdot
.806 .13251 Mdot
.806 .13252 Mdot
.806 .13382 Mdot
.806 .13426 Mdot
.806 .13428 Mdot
.806 .13434 Mdot
.806 .1346 Mdot
.806 .13476 Mdot
.806 .13513 Mdot
.806 .13552 Mdot
.806 .13594 Mdot
.806 .13625 Mdot
.806 .13654 Mdot
.806 .13663 Mdot
.806 .13678 Mdot
.806 .13716 Mdot
.806 .13789 Mdot
.806 .138 Mdot
.806 .13803 Mdot
.806 .13834 Mdot
.806 .13906 Mdot
.806 .13969 Mdot
.806 .14183 Mdot
.806 .14213 Mdot
.806 .14233 Mdot
.806 .14274 Mdot
.806 .1432 Mdot
.806 .1434 Mdot
.806 .1439 Mdot
.806 .14485 Mdot
.806 .14494 Mdot
.806 .14525 Mdot
.806 .14594 Mdot
.806 .14595 Mdot
.806 .14614 Mdot
.806 .14626 Mdot
.806 .14634 Mdot
.806 .14733 Mdot
.806 .14753 Mdot
.806 .14794 Mdot
.806 .14838 Mdot
.806 .14896 Mdot
.806 .14903 Mdot
.806 .1504 Mdot
.806 .15067 Mdot
.806 .15257 Mdot
.806 .15285 Mdot
.806 .1533 Mdot
.806 .1545 Mdot
.806 .155 Mdot
.806 .15569 Mdot
.806 .15734 Mdot
.806 .15744 Mdot
.806 .15752 Mdot
.806 .15773 Mdot
.806 .15802 Mdot
.806 .15934 Mdot
.806 .15983 Mdot
.806 .15992 Mdot
.806 .16258 Mdot
.806 .16265 Mdot
.806 .16303 Mdot
.806 .16437 Mdot
.806 .16497 Mdot
.806 .165 Mdot
.806 .16502 Mdot
.806 .16522 Mdot
.806 .1657 Mdot
.806 .16623 Mdot
.806 .16671 Mdot
.806 .16749 Mdot
.806 .1676 Mdot
.806 .16769 Mdot
.806 .16817 Mdot
.806 .16853 Mdot
.806 .16967 Mdot
.806 .1697 Mdot
.806 .17053 Mdot
.806 .17113 Mdot
.806 .17127 Mdot
.806 .17159 Mdot
.806 .1723 Mdot
.806 .17276 Mdot
.806 .17457 Mdot
.806 .17469 Mdot
.806 .17476 Mdot
.806 .17522 Mdot
.806 .17575 Mdot
.806 .17636 Mdot
.806 .17652 Mdot
.806 .17652 Mdot
.806 .17689 Mdot
.806 .17704 Mdot
.806 .17723 Mdot
.806 .17763 Mdot
.806 .17797 Mdot
.806 .17803 Mdot
.806 .17842 Mdot
.806 .17851 Mdot
.806 .17887 Mdot
.806 .17893 Mdot
.806 .17913 Mdot
.806 .17938 Mdot
.806 .17985 Mdot
.806 .18086 Mdot
.806 .18112 Mdot
.806 .18121 Mdot
.806 .1814 Mdot
.806 .18184 Mdot
.806 .18196 Mdot
.806 .18213 Mdot
.806 .18222 Mdot
.806 .18231 Mdot
.806 .18237 Mdot
.806 .18351 Mdot
.806 .18362 Mdot
.806 .18438 Mdot
.806 .18496 Mdot
.806 .18621 Mdot
.806 .18666 Mdot
.806 .1867 Mdot
.806 .18709 Mdot
.806 .18716 Mdot
.806 .18729 Mdot
.806 .18733 Mdot
.806 .18738 Mdot
.806 .1878 Mdot
.806 .18819 Mdot
.806 .18886 Mdot
.806 .18935 Mdot
.806 .1894 Mdot
.806 .18949 Mdot
.806 .18961 Mdot
.806 .19024 Mdot
.806 .19057 Mdot
.806 .19062 Mdot
.806 .19077 Mdot
.806 .19123 Mdot
.806 .19152 Mdot
.806 .19182 Mdot
.806 .19206 Mdot
.806 .19269 Mdot
.806 .19327 Mdot
.806 .19365 Mdot
.806 .19367 Mdot
.806 .19385 Mdot
.806 .19503 Mdot
.806 .19522 Mdot
.806 .19619 Mdot
.806 .19634 Mdot
.806 .19706 Mdot
.806 .19764 Mdot
.806 .19804 Mdot
.806 .19816 Mdot
.806 .19827 Mdot
.806 .19989 Mdot
.806 .20005 Mdot
.806 .20009 Mdot
.806 .20034 Mdot
.806 .20041 Mdot
.806 .20072 Mdot
.806 .20094 Mdot
.806 .2019 Mdot
.806 .20221 Mdot
.806 .20225 Mdot
.806 .2025 Mdot
.806 .20279 Mdot
.806 .20319 Mdot
.806 .20432 Mdot
.806 .20456 Mdot
.806 .20461 Mdot
.806 .20462 Mdot
.806 .20671 Mdot
.806 .20742 Mdot
.806 .20745 Mdot
.806 .20755 Mdot
.806 .20767 Mdot
.806 .20796 Mdot
.806 .2082 Mdot
.806 .20823 Mdot
.806 .20848 Mdot
.806 .20883 Mdot
.806 .20946 Mdot
.806 .2101 Mdot
.806 .21013 Mdot
.806 .21042 Mdot
.806 .21063 Mdot
.806 .21109 Mdot
.806 .21124 Mdot
.806 .21148 Mdot
.806 .2121 Mdot
.806 .21262 Mdot
.806 .21327 Mdot
.806 .21345 Mdot
.806 .21349 Mdot
.806 .21366 Mdot
.806 .214 Mdot
.806 .21419 Mdot
.806 .2142 Mdot
.806 .21515 Mdot
.806 .21517 Mdot
.806 .21584 Mdot
.806 .21585 Mdot
.806 .21586 Mdot
.806 .21618 Mdot
.806 .21741 Mdot
.806 .21803 Mdot
.806 .21823 Mdot
.806 .21884 Mdot
.806 .21963 Mdot
.806 .2201 Mdot
.806 .22043 Mdot
.806 .2205 Mdot
.806 .22087 Mdot
.806 .22109 Mdot
.806 .22183 Mdot
.806 .22191 Mdot
.806 .22216 Mdot
.806 .22218 Mdot
.806 .22296 Mdot
.806 .22383 Mdot
.806 .224 Mdot
.806 .22419 Mdot
.806 .2245 Mdot
.806 .22464 Mdot
.806 .22515 Mdot
.806 .22569 Mdot
.806 .22595 Mdot
.806 .22626 Mdot
.806 .22626 Mdot
.806 .22657 Mdot
.806 .22676 Mdot
.806 .2268 Mdot
.806 .22689 Mdot
.806 .22724 Mdot
.806 .22782 Mdot
.806 .22849 Mdot
.806 .22881 Mdot
.806 .22947 Mdot
.806 .2298 Mdot
.806 .22985 Mdot
.806 .23019 Mdot
.806 .23112 Mdot
.806 .23122 Mdot
.806 .23344 Mdot
.806 .23387 Mdot
.806 .23402 Mdot
.806 .23513 Mdot
.806 .23551 Mdot
.806 .2363 Mdot
.806 .23673 Mdot
.806 .23694 Mdot
.806 .23739 Mdot
.806 .23811 Mdot
.806 .23813 Mdot
.806 .23864 Mdot
.806 .23878 Mdot
.806 .23935 Mdot
.806 .23971 Mdot
.806 .24004 Mdot
.806 .24012 Mdot
.806 .24035 Mdot
.806 .24086 Mdot
.806 .24196 Mdot
.806 .24304 Mdot
.806 .24463 Mdot
.806 .24479 Mdot
.806 .24491 Mdot
.806 .24511 Mdot
.806 .24526 Mdot
.806 .24559 Mdot
.806 .24572 Mdot
.806 .24624 Mdot
.806 .24717 Mdot
.806 .24741 Mdot
.806 .24785 Mdot
.806 .24864 Mdot
.806 .24876 Mdot
.806 .24879 Mdot
.806 .24941 Mdot
.806 .25119 Mdot
.806 .25307 Mdot
.806 .25318 Mdot
.806 .2538 Mdot
.806 .25507 Mdot
.806 .25596 Mdot
.806 .25645 Mdot
.806 .25693 Mdot
.806 .25698 Mdot
.806 .25701 Mdot
.806 .25733 Mdot
.806 .2581 Mdot
.806 .25833 Mdot
.806 .25851 Mdot
.806 .25896 Mdot
.806 .25973 Mdot
.806 .26011 Mdot
.806 .26041 Mdot
.806 .26096 Mdot
.806 .26099 Mdot
.806 .26114 Mdot
.806 .26117 Mdot
.806 .26131 Mdot
.806 .26134 Mdot
.806 .26208 Mdot
.806 .26218 Mdot
.806 .26266 Mdot
.806 .2631 Mdot
.806 .26431 Mdot
.806 .2645 Mdot
.806 .26455 Mdot
.806 .26475 Mdot
.806 .26589 Mdot
.806 .26639 Mdot
.806 .26685 Mdot
.806 .26708 Mdot
.806 .26753 Mdot
.806 .2676 Mdot
.806 .26874 Mdot
.806 .26948 Mdot
.806 .2696 Mdot
.806 .2698 Mdot
.806 .27018 Mdot
.806 .27067 Mdot
.806 .2724 Mdot
.806 .2726 Mdot
.806 .27271 Mdot
.806 .27333 Mdot
.806 .27345 Mdot
.806 .2743 Mdot
.806 .2747 Mdot
.806 .2749 Mdot
.806 .27491 Mdot
.806 .27528 Mdot
.806 .27554 Mdot
.806 .27554 Mdot
.806 .27555 Mdot
.806 .27614 Mdot
.806 .27638 Mdot
.806 .27646 Mdot
.806 .27669 Mdot
.806 .27733 Mdot
.806 .27747 Mdot
.806 .27788 Mdot
.806 .27798 Mdot
.806 .27861 Mdot
.806 .27868 Mdot
.806 .27875 Mdot
.806 .27933 Mdot
.806 .27943 Mdot
.806 .27976 Mdot
.806 .27993 Mdot
.806 .28015 Mdot
.806 .28091 Mdot
.806 .28093 Mdot
.806 .28254 Mdot
.806 .28296 Mdot
.806 .28311 Mdot
.806 .28341 Mdot
.806 .28358 Mdot
.806 .28412 Mdot
.806 .28431 Mdot
.806 .28437 Mdot
.806 .28459 Mdot
.806 .28473 Mdot
.806 .28488 Mdot
.806 .28497 Mdot
.806 .28601 Mdot
.806 .2868 Mdot
.806 .28699 Mdot
.806 .2876 Mdot
.806 .28769 Mdot
.806 .28821 Mdot
.806 .28846 Mdot
.806 .28914 Mdot
.806 .29064 Mdot
.806 .29117 Mdot
.806 .29189 Mdot
.806 .29196 Mdot
.806 .29258 Mdot
.806 .29269 Mdot
.806 .2929 Mdot
.806 .29297 Mdot
.806 .29305 Mdot
.806 .29337 Mdot
.806 .29372 Mdot
.806 .29419 Mdot
.806 .29436 Mdot
.806 .29499 Mdot
.806 .29543 Mdot
.806 .29623 Mdot
.806 .29631 Mdot
.806 .29645 Mdot
.806 .29664 Mdot
.806 .29766 Mdot
.806 .29819 Mdot
.806 .29827 Mdot
.806 .29827 Mdot
.806 .29852 Mdot
.806 .29887 Mdot
.806 .29926 Mdot
.806 .29972 Mdot
.806 .3002 Mdot
.806 .30059 Mdot
.806 .30161 Mdot
.806 .30191 Mdot
.806 .30254 Mdot
.806 .30315 Mdot
.806 .30319 Mdot
.806 .30348 Mdot
.806 .30432 Mdot
.806 .30538 Mdot
.806 .30569 Mdot
.806 .306 Mdot
.806 .30726 Mdot
.806 .30749 Mdot
.806 .30866 Mdot
.806 .30959 Mdot
.806 .31024 Mdot
.806 .31043 Mdot
.806 .31061 Mdot
.806 .31322 Mdot
.806 .31347 Mdot
.806 .31354 Mdot
.806 .31394 Mdot
.806 .31405 Mdot
.806 .31456 Mdot
.806 .31491 Mdot
.806 .31646 Mdot
.806 .31696 Mdot
.806 .31702 Mdot
.806 .31742 Mdot
.806 .31789 Mdot
.806 .31853 Mdot
.806 .32036 Mdot
.806 .32075 Mdot
.806 .32082 Mdot
.806 .32084 Mdot
.806 .3242 Mdot
.806 .32536 Mdot
.806 .32541 Mdot
.806 .32557 Mdot
.806 .32576 Mdot
.806 .32623 Mdot
.806 .32661 Mdot
.806 .32667 Mdot
.806 .32707 Mdot
.806 .32763 Mdot
.806 .32864 Mdot
.806 .32968 Mdot
.806 .32973 Mdot
.806 .33019 Mdot
.806 .33053 Mdot
.806 .33127 Mdot
.806 .33152 Mdot
.806 .3319 Mdot
.806 .33291 Mdot
.806 .33373 Mdot
.806 .33478 Mdot
.806 .33508 Mdot
.806 .33515 Mdot
.806 .33541 Mdot
.806 .33597 Mdot
.806 .33627 Mdot
.806 .33628 Mdot
.806 .33782 Mdot
.806 .33784 Mdot
.806 .33894 Mdot
.806 .33894 Mdot
.806 .33895 Mdot
.806 .33948 Mdot
.806 .34146 Mdot
.806 .34246 Mdot
.806 .34279 Mdot
.806 .34377 Mdot
.806 .34504 Mdot
.806 .3458 Mdot
.806 .34633 Mdot
.806 .34644 Mdot
.806 .34703 Mdot
.806 .3474 Mdot
.806 .34859 Mdot
.806 .34871 Mdot
.806 .34911 Mdot
.806 .34915 Mdot
.806 .35041 Mdot
.806 .35181 Mdot
.806 .35209 Mdot
.806 .35239 Mdot
.806 .35288 Mdot
.806 .35312 Mdot
.806 .35393 Mdot
.806 .3548 Mdot
.806 .35523 Mdot
.806 .35572 Mdot
.806 .35573 Mdot
.806 .35623 Mdot
.806 .35653 Mdot
.806 .35659 Mdot
.806 .35674 Mdot
.806 .35731 Mdot
.806 .35825 Mdot
.806 .35932 Mdot
.806 .35984 Mdot
.806 .3609 Mdot
.806 .36143 Mdot
.806 .36151 Mdot
.806 .36206 Mdot
.806 .36356 Mdot
.806 .36373 Mdot
.806 .3673 Mdot
.806 .36799 Mdot
.806 .36824 Mdot
.806 .37003 Mdot
.806 .37064 Mdot
.806 .37191 Mdot
.806 .3726 Mdot
.806 .37294 Mdot
.806 .37367 Mdot
.806 .37482 Mdot
.806 .37486 Mdot
.806 .37569 Mdot
.806 .37591 Mdot
.806 .37682 Mdot
.806 .37741 Mdot
.806 .37794 Mdot
.806 .37807 Mdot
.806 .37844 Mdot
.806 .37925 Mdot
.806 .38104 Mdot
.806 .38277 Mdot
.806 .38534 Mdot
.806 .3856 Mdot
.806 .38579 Mdot
.806 .38612 Mdot
.806 .38636 Mdot
.806 .38689 Mdot
.806 .38709 Mdot
.806 .38793 Mdot
.806 .38944 Mdot
.806 .38982 Mdot
.806 .39054 Mdot
.806 .39181 Mdot
.806 .392 Mdot
.806 .39205 Mdot
.806 .39304 Mdot
.806 .39591 Mdot
.806 .39894 Mdot
.806 .39912 Mdot
.806 .40012 Mdot
.806 .40216 Mdot
.806 .40361 Mdot
.806 .40439 Mdot
.806 .40517 Mdot
.806 .40524 Mdot
.806 .40529 Mdot
.806 .40581 Mdot
.806 .40706 Mdot
.806 .40743 Mdot
.806 .40772 Mdot
.806 .40844 Mdot
.806 .40968 Mdot
.806 .41029 Mdot
.806 .41077 Mdot
.806 .41167 Mdot
.806 .41171 Mdot
.806 .41195 Mdot
.806 .41201 Mdot
.806 .41223 Mdot
.806 .41227 Mdot
.806 .41346 Mdot
.806 .41363 Mdot
.806 .4144 Mdot
.806 .4151 Mdot
.806 .41706 Mdot
.806 .41737 Mdot
.806 .41745 Mdot
.806 .41777 Mdot
.806 .41961 Mdot
.806 .42041 Mdot
.806 .42116 Mdot
.806 .42152 Mdot
.806 .42225 Mdot
.806 .42237 Mdot
.806 .4242 Mdot
.806 .42539 Mdot
.806 .42559 Mdot
.806 .42592 Mdot
.806 .42652 Mdot
.806 .42732 Mdot
.806 .4301 Mdot
.806 .43042 Mdot
.806 .4306 Mdot
.806 .43161 Mdot
.806 .4318 Mdot
.806 .43316 Mdot
.806 .43381 Mdot
.806 .43414 Mdot
.806 .43414 Mdot
.806 .43475 Mdot
.806 .43517 Mdot
.806 .43517 Mdot
.806 .43517 Mdot
.806 .43614 Mdot
.806 .43652 Mdot
.806 .43665 Mdot
.806 .43703 Mdot
.806 .43805 Mdot
.806 .43828 Mdot
.806 .43893 Mdot
.806 .4391 Mdot
.806 .44012 Mdot
.806 .44023 Mdot
.806 .44034 Mdot
.806 .44127 Mdot
.806 .44144 Mdot
.806 .44196 Mdot
.806 .44224 Mdot
.806 .4426 Mdot
.806 .44382 Mdot
.806 .44385 Mdot
.806 .44644 Mdot
.806 .44713 Mdot
.806 .44737 Mdot
.806 .44786 Mdot
.806 .44812 Mdot
.806 .44899 Mdot
.806 .44931 Mdot
.806 .4494 Mdot
.806 .44975 Mdot
.806 .44997 Mdot
.806 .45023 Mdot
.806 .45037 Mdot
.806 .45204 Mdot
.806 .45332 Mdot
.806 .45362 Mdot
.806 .45402 Mdot
.806 .4546 Mdot
.806 .45475 Mdot
.806 .45559 Mdot
.806 .45599 Mdot
.806 .45709 Mdot
.806 .4595 Mdot
.806 .46035 Mdot
.806 .46152 Mdot
.806 .46163 Mdot
.806 .46263 Mdot
.806 .46281 Mdot
.806 .46316 Mdot
.806 .46327 Mdot
.806 .46339 Mdot
.806 .46391 Mdot
.806 .46448 Mdot
.806 .46523 Mdot
.806 .4655 Mdot
.806 .46652 Mdot
.806 .46723 Mdot
.806 .46851 Mdot
.806 .46864 Mdot
.806 .46887 Mdot
.806 .46918 Mdot
.806 .47083 Mdot
.806 .47168 Mdot
.806 .4718 Mdot
.806 .47181 Mdot
.806 .4722 Mdot
.806 .47277 Mdot
.806 .4734 Mdot
.806 .47415 Mdot
.806 .47492 Mdot
.806 .47554 Mdot
.806 .47718 Mdot
.806 .47767 Mdot
.806 .47869 Mdot
.806 .47968 Mdot
.806 .47973 Mdot
.806 .48021 Mdot
.806 .48156 Mdot
.806 .48326 Mdot
.806 .48377 Mdot
.806 .48426 Mdot
.806 .4863 Mdot
.806 .48667 Mdot
.806 .48856 Mdot
.806 .49005 Mdot
.806 .49109 Mdot
.808 .01586 Mdot
.808 .01636 Mdot
.808 .01656 Mdot
.808 .0169 Mdot
.808 .01721 Mdot
.808 .01737 Mdot
.808 .01762 Mdot
.808 .0177 Mdot
.808 .01824 Mdot
.808 .01875 Mdot
.808 .01901 Mdot
.808 .0194 Mdot
.808 .01953 Mdot
.808 .02041 Mdot
.808 .02123 Mdot
.808 .02165 Mdot
.808 .02229 Mdot
.808 .0225 Mdot
.808 .02314 Mdot
.808 .02392 Mdot
.808 .02461 Mdot
.808 .02525 Mdot
.808 .02593 Mdot
.808 .02623 Mdot
.808 .02675 Mdot
.808 .02696 Mdot
.808 .02729 Mdot
.808 .02735 Mdot
.808 .02833 Mdot
.808 .02851 Mdot
.808 .02918 Mdot
.808 .02941 Mdot
.808 .02959 Mdot
.808 .03071 Mdot
.808 .03174 Mdot
.808 .03283 Mdot
.808 .03306 Mdot
.808 .03333 Mdot
.808 .03409 Mdot
.808 .03417 Mdot
.808 .0345 Mdot
.808 .03504 Mdot
.808 .03514 Mdot
.808 .03602 Mdot
.808 .03609 Mdot
.808 .03671 Mdot
.808 .037 Mdot
.808 .03707 Mdot
.808 .03808 Mdot
.808 .03809 Mdot
.808 .03846 Mdot
.808 .03876 Mdot
.808 .03925 Mdot
.808 .03965 Mdot
.808 .04057 Mdot
.808 .04092 Mdot
.808 .04219 Mdot
.808 .04222 Mdot
.808 .04364 Mdot
.808 .04399 Mdot
.808 .04436 Mdot
.808 .04479 Mdot
.808 .04511 Mdot
.808 .0452 Mdot
.808 .04563 Mdot
.808 .04576 Mdot
.808 .04602 Mdot
.808 .04615 Mdot
.808 .04668 Mdot
.808 .04756 Mdot
.808 .04772 Mdot
.808 .04831 Mdot
.808 .04841 Mdot
.808 .04853 Mdot
.808 .04873 Mdot
.808 .04915 Mdot
.808 .04926 Mdot
.808 .04977 Mdot
.808 .04989 Mdot
.808 .05026 Mdot
.808 .05074 Mdot
.808 .05084 Mdot
.808 .05118 Mdot
.808 .05212 Mdot
.808 .05224 Mdot
.808 .05247 Mdot
.808 .05249 Mdot
.808 .05255 Mdot
.808 .05282 Mdot
.808 .05309 Mdot
.808 .05357 Mdot
.808 .05436 Mdot
.808 .05469 Mdot
.808 .05502 Mdot
.808 .05649 Mdot
.808 .05706 Mdot
.808 .05736 Mdot
.808 .05827 Mdot
.808 .05912 Mdot
.808 .05916 Mdot
.808 .05922 Mdot
.808 .06114 Mdot
.808 .06147 Mdot
.808 .06151 Mdot
.808 .0617 Mdot
.808 .06202 Mdot
.808 .06261 Mdot
.808 .06332 Mdot
.808 .06383 Mdot
.808 .06397 Mdot
.808 .06397 Mdot
.808 .06467 Mdot
.808 .06478 Mdot
.808 .06488 Mdot
.808 .0653 Mdot
.808 .06551 Mdot
.808 .06637 Mdot
.808 .06779 Mdot
.808 .06806 Mdot
.808 .069 Mdot
.808 .06917 Mdot
.808 .06935 Mdot
.808 .06968 Mdot
.808 .0702 Mdot
.808 .07022 Mdot
.808 .07036 Mdot
.808 .07055 Mdot
.808 .07136 Mdot
.808 .07155 Mdot
.808 .07167 Mdot
.808 .07176 Mdot
.808 .07216 Mdot
.808 .07257 Mdot
.808 .07289 Mdot
.808 .07292 Mdot
.808 .07309 Mdot
.808 .07364 Mdot
.808 .07402 Mdot
.808 .07515 Mdot
.808 .07535 Mdot
.808 .07573 Mdot
.808 .07575 Mdot
.808 .07585 Mdot
.808 .07586 Mdot
.808 .07598 Mdot
.808 .07629 Mdot
.808 .07674 Mdot
.808 .07686 Mdot
.808 .07704 Mdot
.808 .07751 Mdot
.808 .07752 Mdot
.808 .0782 Mdot
.808 .07878 Mdot
.808 .07932 Mdot
.808 .0797 Mdot
.808 .07976 Mdot
.808 .07984 Mdot
.808 .07993 Mdot
.808 .0803 Mdot
.808 .08223 Mdot
.808 .08277 Mdot
.808 .08315 Mdot
.808 .08362 Mdot
.808 .0851 Mdot
.808 .08647 Mdot
.808 .08654 Mdot
.808 .08663 Mdot
.808 .08747 Mdot
.808 .08821 Mdot
.808 .08838 Mdot
.808 .08844 Mdot
.808 .08862 Mdot
.808 .08971 Mdot
.808 .08974 Mdot
.808 .08992 Mdot
.808 .09026 Mdot
.808 .09033 Mdot
.808 .09064 Mdot
.808 .09103 Mdot
.808 .09117 Mdot
.808 .09131 Mdot
.808 .09212 Mdot
.808 .09292 Mdot
.808 .09292 Mdot
.808 .09326 Mdot
.808 .09374 Mdot
.808 .09376 Mdot
.808 .09409 Mdot
.808 .09431 Mdot
.808 .09432 Mdot
.808 .0944 Mdot
.808 .09545 Mdot
.808 .09562 Mdot
.808 .09578 Mdot
.808 .09597 Mdot
.808 .09601 Mdot
.808 .09625 Mdot
.808 .09637 Mdot
.808 .09646 Mdot
.808 .09669 Mdot
.808 .0967 Mdot
.808 .09675 Mdot
.808 .0968 Mdot
.808 .09819 Mdot
.808 .09841 Mdot
.808 .10028 Mdot
.808 .10048 Mdot
.808 .1005 Mdot
.808 .10091 Mdot
.808 .10094 Mdot
.808 .10189 Mdot
.808 .10244 Mdot
.808 .10271 Mdot
.808 .10301 Mdot
.808 .10354 Mdot
.808 .10355 Mdot
.808 .10438 Mdot
.808 .10441 Mdot
.808 .10447 Mdot
.808 .10464 Mdot
.808 .10494 Mdot
.808 .10619 Mdot
.808 .10625 Mdot
.808 .10656 Mdot
.808 .10675 Mdot
.808 .10689 Mdot
.808 .10755 Mdot
.808 .10767 Mdot
.808 .10821 Mdot
.808 .10861 Mdot
.808 .10872 Mdot
.808 .10878 Mdot
.808 .10905 Mdot
.808 .10994 Mdot
.808 .11056 Mdot
.808 .11177 Mdot
.808 .11208 Mdot
.808 .11238 Mdot
.808 .11242 Mdot
.808 .1127 Mdot
.808 .11323 Mdot
.808 .11332 Mdot
.808 .11335 Mdot
.808 .1135 Mdot
.808 .11352 Mdot
.808 .11372 Mdot
.808 .11422 Mdot
.808 .11494 Mdot
.808 .11514 Mdot
.808 .11543 Mdot
.808 .11605 Mdot
.808 .11619 Mdot
.808 .11621 Mdot
.808 .11706 Mdot
.808 .1173 Mdot
.808 .11825 Mdot
.808 .11911 Mdot
.808 .11973 Mdot
.808 .11983 Mdot
.808 .11996 Mdot
.808 .12011 Mdot
.808 .12041 Mdot
.808 .1207 Mdot
.808 .12094 Mdot
.808 .12124 Mdot
.808 .12176 Mdot
.808 .12194 Mdot
.808 .12381 Mdot
.808 .12469 Mdot
.808 .12474 Mdot
.808 .12489 Mdot
.808 .1253 Mdot
.808 .12566 Mdot
.808 .12607 Mdot
.808 .12686 Mdot
.808 .12709 Mdot
.808 .12821 Mdot
.808 .12846 Mdot
.808 .13067 Mdot
.808 .13079 Mdot
.808 .13093 Mdot
.808 .13142 Mdot
.808 .13229 Mdot
.808 .13299 Mdot
.808 .13348 Mdot
.808 .13375 Mdot
.808 .13385 Mdot
.808 .13415 Mdot
.808 .13514 Mdot
.808 .1359 Mdot
.808 .13595 Mdot
.808 .13625 Mdot
.808 .13658 Mdot
.808 .1368 Mdot
.808 .13691 Mdot
.808 .13697 Mdot
.808 .13741 Mdot
.808 .13804 Mdot
.808 .13826 Mdot
.808 .13849 Mdot
.808 .13903 Mdot
.808 .1398 Mdot
.808 .14109 Mdot
.808 .14109 Mdot
.808 .14143 Mdot
.808 .14165 Mdot
.808 .14243 Mdot
.808 .14246 Mdot
.808 .14266 Mdot
.808 .14271 Mdot
.808 .14298 Mdot
.808 .14334 Mdot
.808 .14335 Mdot
.808 .14348 Mdot
.808 .14518 Mdot
.808 .14535 Mdot
.808 .14545 Mdot
.808 .14571 Mdot
.808 .14602 Mdot
.808 .14609 Mdot
.808 .14647 Mdot
.808 .14667 Mdot
.808 .14682 Mdot
.808 .14719 Mdot
.808 .1472 Mdot
.808 .14729 Mdot
.808 .14737 Mdot
.808 .14738 Mdot
.808 .14777 Mdot
.808 .14827 Mdot
.808 .14837 Mdot
.808 .1486 Mdot
.808 .14899 Mdot
.808 .14962 Mdot
.808 .14997 Mdot
.808 .15019 Mdot
.808 .15219 Mdot
.808 .15299 Mdot
.808 .15311 Mdot
.808 .15331 Mdot
.808 .15335 Mdot
.808 .15401 Mdot
.808 .15405 Mdot
.808 .15451 Mdot
.808 .15457 Mdot
.808 .15483 Mdot
.808 .15559 Mdot
.808 .15648 Mdot
.808 .15691 Mdot
.808 .1574 Mdot
.808 .15826 Mdot
.808 .15827 Mdot
.808 .15938 Mdot
.808 .15961 Mdot
.808 .15966 Mdot
.808 .15976 Mdot
.808 .16004 Mdot
.808 .16052 Mdot
.808 .16073 Mdot
.808 .16108 Mdot
.808 .16114 Mdot
.808 .16254 Mdot
.808 .16264 Mdot
.808 .16314 Mdot
.808 .16328 Mdot
.808 .16339 Mdot
.808 .16344 Mdot
.808 .16368 Mdot
.808 .16385 Mdot
.808 .16433 Mdot
.808 .16454 Mdot
.808 .16466 Mdot
.808 .16473 Mdot
.808 .16493 Mdot
.808 .16552 Mdot
.808 .1658 Mdot
.808 .1661 Mdot
.808 .16627 Mdot
.808 .16645 Mdot
.808 .16663 Mdot
.808 .16672 Mdot
.808 .16716 Mdot
.808 .16827 Mdot
.808 .1686 Mdot
.808 .16896 Mdot
.808 .16915 Mdot
.808 .1696 Mdot
.808 .16968 Mdot
.808 .16998 Mdot
.808 .17083 Mdot
.808 .17145 Mdot
.808 .17156 Mdot
.808 .17206 Mdot
.808 .17219 Mdot
.808 .17255 Mdot
.808 .17261 Mdot
.808 .17305 Mdot
.808 .17332 Mdot
.808 .17379 Mdot
.808 .17392 Mdot
.808 .17406 Mdot
.808 .17411 Mdot
.808 .17435 Mdot
.808 .17438 Mdot
.808 .17449 Mdot
.808 .1747 Mdot
.808 .17551 Mdot
.808 .17577 Mdot
.808 .17647 Mdot
.808 .17658 Mdot
.808 .17668 Mdot
.808 .177 Mdot
.808 .17721 Mdot
.808 .17747 Mdot
.808 .17799 Mdot
.808 .17839 Mdot
.808 .17847 Mdot
.808 .17869 Mdot
.808 .17874 Mdot
.808 .1801 Mdot
.808 .18016 Mdot
.808 .18024 Mdot
.808 .18049 Mdot
.808 .18096 Mdot
.808 .18203 Mdot
.808 .18341 Mdot
.808 .18442 Mdot
.808 .18458 Mdot
.808 .18479 Mdot
.808 .1849 Mdot
.808 .18503 Mdot
.808 .18552 Mdot
.808 .18598 Mdot
.808 .18631 Mdot
.808 .18638 Mdot
.808 .18686 Mdot
.808 .18771 Mdot
.808 .18783 Mdot
.808 .18799 Mdot
.808 .18864 Mdot
.808 .19046 Mdot
.808 .19051 Mdot
.808 .19087 Mdot
.808 .19102 Mdot
.808 .19213 Mdot
.808 .19244 Mdot
.808 .19252 Mdot
.808 .19276 Mdot
.808 .19343 Mdot
.808 .19401 Mdot
.808 .19467 Mdot
.808 .19555 Mdot
.808 .19573 Mdot
.808 .19594 Mdot
.808 .19631 Mdot
.808 .19693 Mdot
.808 .19812 Mdot
.808 .19832 Mdot
.808 .19852 Mdot
.808 .19864 Mdot
.808 .1988 Mdot
.808 .20091 Mdot
.808 .20148 Mdot
.808 .2021 Mdot
.808 .2023 Mdot
.808 .20253 Mdot
.808 .20297 Mdot
.808 .20322 Mdot
.808 .20331 Mdot
.808 .20471 Mdot
.808 .2051 Mdot
.808 .20585 Mdot
.808 .20587 Mdot
.808 .20625 Mdot
.808 .20663 Mdot
.808 .20708 Mdot
.808 .20724 Mdot
.808 .20772 Mdot
.808 .20821 Mdot
.808 .20876 Mdot
.808 .20932 Mdot
.808 .20936 Mdot
.808 .20952 Mdot
.808 .20957 Mdot
.808 .21055 Mdot
.808 .21059 Mdot
.808 .21063 Mdot
.808 .21071 Mdot
.808 .21111 Mdot
.808 .21115 Mdot
.808 .21165 Mdot
.808 .21201 Mdot
.808 .21205 Mdot
.808 .21217 Mdot
.808 .21228 Mdot
.808 .21299 Mdot
.808 .21401 Mdot
.808 .21436 Mdot
.808 .21473 Mdot
.808 .21546 Mdot
.808 .2156 Mdot
.808 .21568 Mdot
.808 .21655 Mdot
.808 .21686 Mdot
.808 .21893 Mdot
.808 .21894 Mdot
.808 .21949 Mdot
.808 .21953 Mdot
.808 .21984 Mdot
.808 .21996 Mdot
.808 .2204 Mdot
.808 .22109 Mdot
.808 .22115 Mdot
.808 .22148 Mdot
.808 .22155 Mdot
.808 .22174 Mdot
.808 .22199 Mdot
.808 .22257 Mdot
.808 .22259 Mdot
.808 .22266 Mdot
.808 .2228 Mdot
.808 .22375 Mdot
.808 .22555 Mdot
.808 .22583 Mdot
.808 .22589 Mdot
.808 .22592 Mdot
.808 .22599 Mdot
.808 .2264 Mdot
.808 .22648 Mdot
.808 .22691 Mdot
.808 .22701 Mdot
.808 .22763 Mdot
.808 .22763 Mdot
.808 .22795 Mdot
.808 .22796 Mdot
.808 .2282 Mdot
.808 .2288 Mdot
.808 .22882 Mdot
.808 .22891 Mdot
.808 .22895 Mdot
.808 .22908 Mdot
.808 .22908 Mdot
.808 .2291 Mdot
.808 .22974 Mdot
.808 .23045 Mdot
.808 .23054 Mdot
.808 .2307 Mdot
.808 .23107 Mdot
.808 .2317 Mdot
.808 .23206 Mdot
.808 .23271 Mdot
.808 .23328 Mdot
.808 .23364 Mdot
.808 .23485 Mdot
.808 .23497 Mdot
.808 .2351 Mdot
.808 .23541 Mdot
.808 .23649 Mdot
.808 .23688 Mdot
.808 .23816 Mdot
.808 .23836 Mdot
.808 .23848 Mdot
.808 .23868 Mdot
.808 .23874 Mdot
.808 .23982 Mdot
.808 .23987 Mdot
.808 .24017 Mdot
.808 .24063 Mdot
.808 .24072 Mdot
.808 .24115 Mdot
.808 .24238 Mdot
.808 .24298 Mdot
.808 .2438 Mdot
.808 .24435 Mdot
.808 .2445 Mdot
.808 .24529 Mdot
.808 .24621 Mdot
.808 .24668 Mdot
.808 .2467 Mdot
.808 .24771 Mdot
.808 .24849 Mdot
.808 .24864 Mdot
.808 .24883 Mdot
.808 .24887 Mdot
.808 .24895 Mdot
.808 .2491 Mdot
.808 .24956 Mdot
.808 .25033 Mdot
.808 .25068 Mdot
.808 .25122 Mdot
.808 .25124 Mdot
.808 .25134 Mdot
.808 .25308 Mdot
.808 .2536 Mdot
.808 .25373 Mdot
.808 .25376 Mdot
.808 .25458 Mdot
.808 .25462 Mdot
.808 .25479 Mdot
.808 .25498 Mdot
.808 .25506 Mdot
.808 .2551 Mdot
.808 .25543 Mdot
.808 .25566 Mdot
.808 .25572 Mdot
.808 .25649 Mdot
.808 .25675 Mdot
.808 .25682 Mdot
.808 .25703 Mdot
.808 .25714 Mdot
.808 .25747 Mdot
.808 .2577 Mdot
.808 .25799 Mdot
.808 .25842 Mdot
.808 .2586 Mdot
.808 .25887 Mdot
.808 .25936 Mdot
.808 .25963 Mdot
.808 .25967 Mdot
.808 .25991 Mdot
.808 .26021 Mdot
.808 .26036 Mdot
.808 .26104 Mdot
.808 .26107 Mdot
.808 .26135 Mdot
.808 .26286 Mdot
.808 .26335 Mdot
.808 .26339 Mdot
.808 .26398 Mdot
.808 .26429 Mdot
.808 .26498 Mdot
.808 .265 Mdot
.808 .26514 Mdot
.808 .26562 Mdot
.808 .26693 Mdot
.808 .267 Mdot
.808 .26746 Mdot
.808 .26799 Mdot
.808 .26812 Mdot
.808 .26818 Mdot
.808 .26899 Mdot
.808 .2692 Mdot
.808 .26977 Mdot
.808 .26987 Mdot
.808 .27059 Mdot
.808 .27089 Mdot
.808 .27103 Mdot
.808 .27178 Mdot
.808 .27199 Mdot
.808 .27222 Mdot
.808 .27228 Mdot
.808 .2723 Mdot
.808 .27269 Mdot
.808 .27274 Mdot
.808 .27291 Mdot
.808 .27325 Mdot
.808 .27456 Mdot
.808 .27464 Mdot
.808 .27497 Mdot
.808 .27611 Mdot
.808 .27628 Mdot
.808 .27645 Mdot
.808 .27696 Mdot
.808 .27731 Mdot
.808 .27773 Mdot
.808 .27855 Mdot
.808 .27856 Mdot
.808 .27878 Mdot
.808 .27922 Mdot
.808 .27934 Mdot
.808 .27971 Mdot
.808 .27977 Mdot
.808 .2803 Mdot
.808 .28091 Mdot
.808 .28198 Mdot
.808 .28203 Mdot
.808 .28208 Mdot
.808 .2822 Mdot
.808 .28261 Mdot
.808 .28337 Mdot
.808 .28402 Mdot
.808 .28509 Mdot
.808 .28562 Mdot
.808 .28633 Mdot
.808 .28691 Mdot
.808 .28726 Mdot
.808 .28733 Mdot
.808 .28825 Mdot
.808 .28896 Mdot
.808 .28921 Mdot
.808 .28955 Mdot
.808 .28974 Mdot
.808 .28995 Mdot
.808 .29037 Mdot
.808 .29073 Mdot
.808 .29108 Mdot
.808 .29148 Mdot
.808 .29201 Mdot
.808 .29213 Mdot
.808 .2929 Mdot
.808 .29352 Mdot
.808 .29427 Mdot
.808 .29447 Mdot
.808 .29472 Mdot
.808 .29578 Mdot
.808 .29632 Mdot
.808 .29722 Mdot
.808 .29872 Mdot
.808 .2988 Mdot
.808 .29938 Mdot
.808 .29962 Mdot
.808 .30005 Mdot
.808 .30081 Mdot
.808 .30142 Mdot
.808 .3017 Mdot
.808 .30192 Mdot
.808 .30205 Mdot
.808 .30243 Mdot
.808 .30324 Mdot
.808 .30351 Mdot
.808 .30445 Mdot
.808 .30552 Mdot
.808 .30586 Mdot
.808 .30695 Mdot
.808 .30724 Mdot
.808 .30758 Mdot
.808 .30817 Mdot
.808 .30918 Mdot
.808 .3111 Mdot
.808 .31141 Mdot
.808 .31175 Mdot
.808 .31194 Mdot
.808 .31219 Mdot
.808 .31561 Mdot
.808 .31652 Mdot
.808 .31752 Mdot
.808 .31784 Mdot
.808 .31822 Mdot
.808 .31893 Mdot
.808 .31935 Mdot
.808 .31949 Mdot
.808 .32175 Mdot
.808 .32238 Mdot
.808 .32358 Mdot
.808 .32363 Mdot
.808 .32423 Mdot
.808 .32486 Mdot
.808 .32558 Mdot
.808 .32583 Mdot
.808 .32661 Mdot
.808 .3274 Mdot
.808 .3283 Mdot
.808 .3292 Mdot
.808 .32926 Mdot
.808 .32953 Mdot
.808 .3296 Mdot
.808 .33118 Mdot
.808 .33125 Mdot
.808 .33132 Mdot
.808 .33144 Mdot
.808 .33209 Mdot
.808 .33216 Mdot
.808 .33296 Mdot
.808 .33354 Mdot
.808 .33361 Mdot
.808 .33381 Mdot
.808 .33397 Mdot
.808 .33513 Mdot
.808 .33678 Mdot
.808 .33735 Mdot
.808 .33794 Mdot
.808 .33912 Mdot
.808 .33935 Mdot
.808 .33947 Mdot
.808 .34087 Mdot
.808 .34138 Mdot
.808 .34473 Mdot
.808 .34474 Mdot
.808 .34564 Mdot
.808 .34569 Mdot
.808 .3462 Mdot
.808 .34639 Mdot
.808 .3471 Mdot
.808 .34822 Mdot
.808 .34831 Mdot
.808 .34885 Mdot
.808 .34896 Mdot
.808 .34926 Mdot
.808 .34968 Mdot
.808 .35061 Mdot
.808 .35065 Mdot
.808 .35075 Mdot
.808 .35098 Mdot
.808 .35251 Mdot
.808 .35542 Mdot
.808 .35587 Mdot
.808 .35598 Mdot
.808 .35602 Mdot
.808 .35613 Mdot
.808 .3568 Mdot
.808 .35693 Mdot
.808 .35762 Mdot
.808 .35779 Mdot
.808 .35879 Mdot
.808 .35879 Mdot
.808 .3593 Mdot
.808 .35931 Mdot
.808 .3597 Mdot
.808 .36068 Mdot
.808 .3607 Mdot
.808 .36085 Mdot
.808 .36093 Mdot
.808 .36113 Mdot
.808 .36113 Mdot
.808 .36116 Mdot
.808 .36219 Mdot
.808 .36334 Mdot
.808 .36348 Mdot
.808 .36375 Mdot
.808 .36434 Mdot
.808 .36537 Mdot
.808 .36594 Mdot
.808 .367 Mdot
.808 .36792 Mdot
.808 .3685 Mdot
.808 .37046 Mdot
.808 .37065 Mdot
.808 .37086 Mdot
.808 .37136 Mdot
.808 .3731 Mdot
.808 .37373 Mdot
.808 .3758 Mdot
.808 .37613 Mdot
.808 .37631 Mdot
.808 .37664 Mdot
.808 .37675 Mdot
.808 .37848 Mdot
.808 .37857 Mdot
.808 .37905 Mdot
.808 .37979 Mdot
.808 .37993 Mdot
.808 .38063 Mdot
.808 .38262 Mdot
.808 .38359 Mdot
.808 .38492 Mdot
.808 .38581 Mdot
.808 .38605 Mdot
.808 .38732 Mdot
.808 .38881 Mdot
.808 .38957 Mdot
.808 .3896 Mdot
.808 .39124 Mdot
.808 .39249 Mdot
.808 .39273 Mdot
.808 .39304 Mdot
.808 .3931 Mdot
.808 .39324 Mdot
.808 .39349 Mdot
.808 .39423 Mdot
.808 .39547 Mdot
.808 .39604 Mdot
.808 .39691 Mdot
.808 .39694 Mdot
.808 .3971 Mdot
.808 .39991 Mdot
.808 .40075 Mdot
.808 .40097 Mdot
.808 .40101 Mdot
.808 .40233 Mdot
.808 .4024 Mdot
.808 .40268 Mdot
.808 .40298 Mdot
.808 .40311 Mdot
.808 .40318 Mdot
.808 .40372 Mdot
.808 .40408 Mdot
.808 .40418 Mdot
.808 .40542 Mdot
.808 .40585 Mdot
.808 .40596 Mdot
.808 .40629 Mdot
.808 .40648 Mdot
.808 .407 Mdot
.808 .40738 Mdot
.808 .40785 Mdot
.808 .40855 Mdot
.808 .40883 Mdot
.808 .40927 Mdot
.808 .41006 Mdot
.808 .41049 Mdot
.808 .41056 Mdot
.808 .41095 Mdot
.808 .41143 Mdot
.808 .41168 Mdot
.808 .41278 Mdot
.808 .41282 Mdot
.808 .41327 Mdot
.808 .41571 Mdot
.808 .41651 Mdot
.808 .41658 Mdot
.808 .41752 Mdot
.808 .41802 Mdot
.808 .41915 Mdot
.808 .41918 Mdot
.808 .4194 Mdot
.808 .42018 Mdot
.808 .4223 Mdot
.808 .42241 Mdot
.808 .42315 Mdot
.808 .42401 Mdot
.808 .42421 Mdot
.808 .42431 Mdot
.808 .42562 Mdot
.808 .42597 Mdot
.808 .42689 Mdot
.808 .42705 Mdot
.808 .42821 Mdot
.808 .42869 Mdot
.808 .42892 Mdot
.808 .43013 Mdot
.808 .43048 Mdot
.808 .43084 Mdot
.808 .43095 Mdot
.808 .43098 Mdot
.808 .4316 Mdot
.808 .43168 Mdot
.808 .43196 Mdot
.808 .43251 Mdot
.808 .43462 Mdot
.808 .43475 Mdot
.808 .43529 Mdot
.808 .43714 Mdot
.808 .43741 Mdot
.808 .43767 Mdot
.808 .4385 Mdot
.808 .43908 Mdot
.808 .43975 Mdot
.808 .44108 Mdot
.808 .44109 Mdot
.808 .44144 Mdot
.808 .44215 Mdot
.808 .44235 Mdot
.808 .44294 Mdot
.808 .44305 Mdot
.808 .4439 Mdot
.808 .44489 Mdot
.808 .44662 Mdot
.808 .44669 Mdot
.808 .44677 Mdot
.808 .44697 Mdot
.808 .44763 Mdot
.808 .44886 Mdot
.808 .44991 Mdot
.808 .45165 Mdot
.808 .4525 Mdot
.808 .45365 Mdot
.808 .45458 Mdot
.808 .45515 Mdot
.808 .45527 Mdot
.808 .45675 Mdot
.808 .4579 Mdot
.808 .4583 Mdot
.808 .45885 Mdot
.808 .45915 Mdot
.808 .45949 Mdot
.808 .46017 Mdot
.808 .46076 Mdot
.808 .46094 Mdot
.808 .46132 Mdot
.808 .46198 Mdot
.808 .46283 Mdot
.808 .46301 Mdot
.808 .46425 Mdot
.808 .46527 Mdot
.808 .46647 Mdot
.808 .4668 Mdot
.808 .4672 Mdot
.808 .46892 Mdot
.808 .46978 Mdot
.808 .47124 Mdot
.808 .47366 Mdot
.808 .4738 Mdot
.808 .47474 Mdot
.808 .47512 Mdot
.808 .47581 Mdot
.808 .47704 Mdot
.808 .47804 Mdot
.808 .47848 Mdot
.808 .47883 Mdot
.808 .47905 Mdot
.808 .47966 Mdot
.808 .48097 Mdot
.808 .48141 Mdot
.808 .48292 Mdot
.808 .48465 Mdot
.808 .48521 Mdot
.808 .48696 Mdot
.808 .48744 Mdot
.808 .48798 Mdot
.808 .48894 Mdot
.808 .49056 Mdot
.81 .01519 Mdot
.81 .01525 Mdot
.81 .01548 Mdot
.81 .01555 Mdot
.81 .01559 Mdot
.81 .01596 Mdot
.81 .01607 Mdot
.81 .01613 Mdot
.81 .01673 Mdot
.81 .01692 Mdot
.81 .017 Mdot
.81 .01718 Mdot
.81 .01788 Mdot
.81 .01798 Mdot
.81 .01828 Mdot
.81 .01842 Mdot
.81 .01871 Mdot
.81 .01943 Mdot
.81 .01984 Mdot
.81 .02 Mdot
.81 .0205 Mdot
.81 .02071 Mdot
.81 .02119 Mdot
.81 .02176 Mdot
.81 .02227 Mdot
.81 .02235 Mdot
.81 .02273 Mdot
.81 .02302 Mdot
.81 .02328 Mdot
.81 .02408 Mdot
.81 .02443 Mdot
.81 .02475 Mdot
.81 .02521 Mdot
.81 .02565 Mdot
.81 .02614 Mdot
.81 .02695 Mdot
.81 .02708 Mdot
.81 .0277 Mdot
.81 .02817 Mdot
.81 .0286 Mdot
.81 .02927 Mdot
.81 .02989 Mdot
.81 .03045 Mdot
.81 .03067 Mdot
.81 .03087 Mdot
.81 .03098 Mdot
.81 .03172 Mdot
.81 .03243 Mdot
.81 .03322 Mdot
.81 .03367 Mdot
.81 .03447 Mdot
.81 .03454 Mdot
.81 .03475 Mdot
.81 .03575 Mdot
.81 .03651 Mdot
.81 .03665 Mdot
.81 .03677 Mdot
.81 .03713 Mdot
.81 .0372 Mdot
.81 .03829 Mdot
.81 .03898 Mdot
.81 .03901 Mdot
.81 .03929 Mdot
.81 .04021 Mdot
.81 .04057 Mdot
.81 .04088 Mdot
.81 .04106 Mdot
.81 .04177 Mdot
.81 .04226 Mdot
.81 .04341 Mdot
.81 .04469 Mdot
.81 .04542 Mdot
.81 .04609 Mdot
.81 .04671 Mdot
.81 .04684 Mdot
.81 .04711 Mdot
.81 .04717 Mdot
.81 .04725 Mdot
.81 .04776 Mdot
.81 .0488 Mdot
.81 .04887 Mdot
.81 .05002 Mdot
.81 .05024 Mdot
.81 .05045 Mdot
.81 .05102 Mdot
.81 .05114 Mdot
.81 .05233 Mdot
.81 .05291 Mdot
.81 .05403 Mdot
.81 .05407 Mdot
.81 .05434 Mdot
.81 .05453 Mdot
.81 .0552 Mdot
.81 .05522 Mdot
.81 .05601 Mdot
.81 .0566 Mdot
.81 .0571 Mdot
.81 .05721 Mdot
.81 .0574 Mdot
.81 .05759 Mdot
.81 .05828 Mdot
.81 .05855 Mdot
.81 .05908 Mdot
.81 .05934 Mdot
.81 .06056 Mdot
.81 .06061 Mdot
.81 .0612 Mdot
.81 .0629 Mdot
.81 .06327 Mdot
.81 .06398 Mdot
.81 .06446 Mdot
.81 .06485 Mdot
.81 .06553 Mdot
.81 .06588 Mdot
.81 .06655 Mdot
.81 .06675 Mdot
.81 .06713 Mdot
.81 .0672 Mdot
.81 .0673 Mdot
.81 .06743 Mdot
.81 .06825 Mdot
.81 .06831 Mdot
.81 .06878 Mdot
.81 .06992 Mdot
.81 .07004 Mdot
.81 .07122 Mdot
.81 .07192 Mdot
.81 .07227 Mdot
.81 .07229 Mdot
.81 .0726 Mdot
.81 .07329 Mdot
.81 .07353 Mdot
.81 .07373 Mdot
.81 .07456 Mdot
.81 .07565 Mdot
.81 .07659 Mdot
.81 .07694 Mdot
.81 .07746 Mdot
.81 .07794 Mdot
.81 .07841 Mdot
.81 .07847 Mdot
.81 .0789 Mdot
.81 .07921 Mdot
.81 .08011 Mdot
.81 .0803 Mdot
.81 .08034 Mdot
.81 .08161 Mdot
.81 .08256 Mdot
.81 .08338 Mdot
.81 .08356 Mdot
.81 .08386 Mdot
.81 .08406 Mdot
.81 .08418 Mdot
.81 .08529 Mdot
.81 .08536 Mdot
.81 .08572 Mdot
.81 .08658 Mdot
.81 .08701 Mdot
.81 .08752 Mdot
.81 .08897 Mdot
.81 .08899 Mdot
.81 .08906 Mdot
.81 .08972 Mdot
.81 .09001 Mdot
.81 .09043 Mdot
.81 .0907 Mdot
.81 .09093 Mdot
.81 .09211 Mdot
.81 .09262 Mdot
.81 .09277 Mdot
.81 .09337 Mdot
.81 .09452 Mdot
.81 .09483 Mdot
.81 .09515 Mdot
.81 .09529 Mdot
.81 .09594 Mdot
.81 .09673 Mdot
.81 .09704 Mdot
.81 .0976 Mdot
.81 .09779 Mdot
.81 .09869 Mdot
.81 .09902 Mdot
.81 .09939 Mdot
.81 .09963 Mdot
.81 .09974 Mdot
.81 .0999 Mdot
.81 .10011 Mdot
.81 .10058 Mdot
.81 .10073 Mdot
.81 .10145 Mdot
.81 .10145 Mdot
.81 .10154 Mdot
.81 .1023 Mdot
.81 .10275 Mdot
.81 .10415 Mdot
.81 .10434 Mdot
.81 .10581 Mdot
.81 .10625 Mdot
.81 .10649 Mdot
.81 .10655 Mdot
.81 .10738 Mdot
.81 .1079 Mdot
.81 .10796 Mdot
.81 .10798 Mdot
.81 .10811 Mdot
.81 .10849 Mdot
.81 .10961 Mdot
.81 .11 Mdot
.81 .11032 Mdot
.81 .11157 Mdot
.81 .11166 Mdot
.81 .113 Mdot
.81 .11343 Mdot
.81 .11407 Mdot
.81 .11438 Mdot
.81 .11495 Mdot
.81 .1153 Mdot
.81 .11552 Mdot
.81 .11584 Mdot
.81 .1162 Mdot
.81 .11633 Mdot
.81 .11636 Mdot
.81 .11714 Mdot
.81 .1179 Mdot
.81 .118 Mdot
.81 .11821 Mdot
.81 .11842 Mdot
.81 .1187 Mdot
.81 .11888 Mdot
.81 .1192 Mdot
.81 .12056 Mdot
.81 .12057 Mdot
.81 .12064 Mdot
.81 .12066 Mdot
.81 .12096 Mdot
.81 .12103 Mdot
.81 .12132 Mdot
.81 .12243 Mdot
.81 .12309 Mdot
.81 .12369 Mdot
.81 .12374 Mdot
.81 .12384 Mdot
.81 .12386 Mdot
.81 .12463 Mdot
.81 .12595 Mdot
.81 .12624 Mdot
.81 .12673 Mdot
.81 .12706 Mdot
.81 .1271 Mdot
.81 .12724 Mdot
.81 .12813 Mdot
.81 .12904 Mdot
.81 .12916 Mdot
.81 .12974 Mdot
.81 .12995 Mdot
.81 .13113 Mdot
.81 .13184 Mdot
.81 .13265 Mdot
.81 .13309 Mdot
.81 .1331 Mdot
.81 .13374 Mdot
.81 .135 Mdot
.81 .13503 Mdot
.81 .13515 Mdot
.81 .13623 Mdot
.81 .1367 Mdot
.81 .13738 Mdot
.81 .13747 Mdot
.81 .13782 Mdot
.81 .13818 Mdot
.81 .13897 Mdot
.81 .13999 Mdot
.81 .1401 Mdot
.81 .14067 Mdot
.81 .14092 Mdot
.81 .14116 Mdot
.81 .14202 Mdot
.81 .14214 Mdot
.81 .14225 Mdot
.81 .14369 Mdot
.81 .144 Mdot
.81 .1445 Mdot
.81 .14502 Mdot
.81 .14525 Mdot
.81 .14559 Mdot
.81 .14571 Mdot
.81 .1463 Mdot
.81 .14692 Mdot
.81 .14758 Mdot
.81 .14809 Mdot
.81 .14881 Mdot
.81 .14898 Mdot
.81 .1493 Mdot
.81 .14935 Mdot
.81 .15075 Mdot
.81 .15125 Mdot
.81 .15128 Mdot
.81 .15172 Mdot
.81 .15188 Mdot
.81 .15228 Mdot
.81 .1523 Mdot
.81 .15246 Mdot
.81 .15272 Mdot
.81 .15301 Mdot
.81 .15302 Mdot
.81 .15305 Mdot
.81 .15305 Mdot
.81 .15382 Mdot
.81 .15406 Mdot
.81 .15522 Mdot
.81 .15523 Mdot
.81 .15538 Mdot
.81 .15625 Mdot
.81 .15661 Mdot
.81 .15685 Mdot
.81 .15732 Mdot
.81 .15738 Mdot
.81 .15819 Mdot
.81 .15961 Mdot
.81 .15974 Mdot
.81 .15991 Mdot
.81 .15991 Mdot
.81 .16094 Mdot
.81 .16153 Mdot
.81 .16229 Mdot
.81 .163 Mdot
.81 .16315 Mdot
.81 .16338 Mdot
.81 .16349 Mdot
.81 .164 Mdot
.81 .16483 Mdot
.81 .16567 Mdot
.81 .16576 Mdot
.81 .16581 Mdot
.81 .16602 Mdot
.81 .16617 Mdot
.81 .16663 Mdot
.81 .16677 Mdot
.81 .16723 Mdot
.81 .16778 Mdot
.81 .16825 Mdot
.81 .16844 Mdot
.81 .16907 Mdot
.81 .1691 Mdot
.81 .1696 Mdot
.81 .16985 Mdot
.81 .1699 Mdot
.81 .17039 Mdot
.81 .17162 Mdot
.81 .17176 Mdot
.81 .17337 Mdot
.81 .17394 Mdot
.81 .17394 Mdot
.81 .17463 Mdot
.81 .17567 Mdot
.81 .17617 Mdot
.81 .1771 Mdot
.81 .17749 Mdot
.81 .17766 Mdot
.81 .1779 Mdot
.81 .17802 Mdot
.81 .17809 Mdot
.81 .17854 Mdot
.81 .17899 Mdot
.81 .17912 Mdot
.81 .17933 Mdot
.81 .17937 Mdot
.81 .17961 Mdot
.81 .18064 Mdot
.81 .1816 Mdot
.81 .18187 Mdot
.81 .18204 Mdot
.81 .18216 Mdot
.81 .18238 Mdot
.81 .18271 Mdot
.81 .18317 Mdot
.81 .18342 Mdot
.81 .18347 Mdot
.81 .18398 Mdot
.81 .18415 Mdot
.81 .18543 Mdot
.81 .18618 Mdot
.81 .1862 Mdot
.81 .18632 Mdot
.81 .18634 Mdot
.81 .18648 Mdot
.81 .18683 Mdot
.81 .18694 Mdot
.81 .18742 Mdot
.81 .18846 Mdot
.81 .18921 Mdot
.81 .18927 Mdot
.81 .19028 Mdot
.81 .19125 Mdot
.81 .19133 Mdot
.81 .1915 Mdot
.81 .19152 Mdot
.81 .19177 Mdot
.81 .19197 Mdot
.81 .19204 Mdot
.81 .19209 Mdot
.81 .19277 Mdot
.81 .19278 Mdot
.81 .19331 Mdot
.81 .19347 Mdot
.81 .19356 Mdot
.81 .19357 Mdot
.81 .1942 Mdot
.81 .19492 Mdot
.81 .19512 Mdot
.81 .19522 Mdot
.81 .19529 Mdot
.81 .19539 Mdot
.81 .19551 Mdot
.81 .19617 Mdot
.81 .19671 Mdot
.81 .19678 Mdot
.81 .19701 Mdot
.81 .19755 Mdot
.81 .19818 Mdot
.81 .19844 Mdot
.81 .19903 Mdot
.81 .19992 Mdot
.81 .20011 Mdot
.81 .20029 Mdot
.81 .20106 Mdot
.81 .2014 Mdot
.81 .20278 Mdot
.81 .20332 Mdot
.81 .20339 Mdot
.81 .20446 Mdot
.81 .20476 Mdot
.81 .20559 Mdot
.81 .20564 Mdot
.81 .20577 Mdot
.81 .20648 Mdot
.81 .20649 Mdot
.81 .20754 Mdot
.81 .20919 Mdot
.81 .20958 Mdot
.81 .20963 Mdot
.81 .20983 Mdot
.81 .21025 Mdot
.81 .21157 Mdot
.81 .21233 Mdot
.81 .21266 Mdot
.81 .21267 Mdot
.81 .21343 Mdot
.81 .21357 Mdot
.81 .21383 Mdot
.81 .21414 Mdot
.81 .2147 Mdot
.81 .21472 Mdot
.81 .21559 Mdot
.81 .216 Mdot
.81 .21634 Mdot
.81 .21673 Mdot
.81 .21721 Mdot
.81 .21766 Mdot
.81 .21784 Mdot
.81 .21876 Mdot
.81 .21917 Mdot
.81 .21955 Mdot
.81 .22004 Mdot
.81 .22094 Mdot
.81 .22114 Mdot
.81 .22133 Mdot
.81 .22215 Mdot
.81 .22366 Mdot
.81 .22415 Mdot
.81 .22497 Mdot
.81 .22553 Mdot
.81 .22582 Mdot
.81 .22609 Mdot
.81 .22619 Mdot
.81 .22627 Mdot
.81 .22673 Mdot
.81 .22692 Mdot
.81 .22776 Mdot
.81 .22788 Mdot
.81 .22848 Mdot
.81 .22889 Mdot
.81 .2295 Mdot
.81 .22995 Mdot
.81 .23001 Mdot
.81 .23028 Mdot
.81 .23078 Mdot
.81 .23195 Mdot
.81 .2322 Mdot
.81 .23223 Mdot
.81 .23274 Mdot
.81 .23282 Mdot
.81 .23414 Mdot
.81 .23469 Mdot
.81 .23509 Mdot
.81 .23521 Mdot
.81 .23556 Mdot
.81 .23577 Mdot
.81 .2359 Mdot
.81 .23595 Mdot
.81 .23667 Mdot
.81 .23675 Mdot
.81 .23693 Mdot
.81 .23756 Mdot
.81 .23757 Mdot
.81 .2376 Mdot
.81 .23786 Mdot
.81 .23828 Mdot
.81 .23876 Mdot
.81 .23878 Mdot
.81 .23882 Mdot
.81 .23882 Mdot
.81 .24006 Mdot
.81 .24045 Mdot
.81 .24114 Mdot
.81 .24234 Mdot
.81 .24234 Mdot
.81 .24259 Mdot
.81 .24401 Mdot
.81 .24458 Mdot
.81 .24497 Mdot
.81 .24523 Mdot
.81 .24574 Mdot
.81 .24583 Mdot
.81 .24638 Mdot
.81 .2471 Mdot
.81 .24715 Mdot
.81 .24761 Mdot
.81 .24833 Mdot
.81 .24854 Mdot
.81 .24926 Mdot
.81 .24944 Mdot
.81 .24966 Mdot
.81 .24993 Mdot
.81 .24994 Mdot
.81 .24995 Mdot
.81 .25117 Mdot
.81 .25139 Mdot
.81 .25159 Mdot
.81 .2519 Mdot
.81 .2525 Mdot
.81 .25256 Mdot
.81 .25295 Mdot
.81 .25318 Mdot
.81 .25379 Mdot
.81 .25412 Mdot
.81 .25494 Mdot
.81 .25517 Mdot
.81 .25535 Mdot
.81 .25556 Mdot
.81 .25574 Mdot
.81 .25606 Mdot
.81 .25635 Mdot
.81 .25637 Mdot
.81 .25655 Mdot
.81 .25769 Mdot
.81 .25791 Mdot
.81 .25926 Mdot
.81 .25941 Mdot
.81 .25948 Mdot
.81 .25983 Mdot
.81 .26006 Mdot
.81 .26082 Mdot
.81 .26104 Mdot
.81 .26152 Mdot
.81 .26179 Mdot
.81 .26228 Mdot
.81 .26268 Mdot
.81 .26344 Mdot
.81 .26375 Mdot
.81 .2647 Mdot
.81 .26477 Mdot
.81 .2648 Mdot
.81 .26482 Mdot
.81 .26508 Mdot
.81 .26529 Mdot
.81 .26535 Mdot
.81 .26538 Mdot
.81 .26538 Mdot
.81 .26562 Mdot
.81 .26598 Mdot
.81 .26601 Mdot
.81 .26604 Mdot
.81 .26612 Mdot
.81 .2669 Mdot
.81 .26714 Mdot
.81 .26747 Mdot
.81 .26795 Mdot
.81 .26889 Mdot
.81 .26913 Mdot
.81 .26965 Mdot
.81 .26997 Mdot
.81 .26998 Mdot
.81 .27134 Mdot
.81 .27174 Mdot
.81 .27266 Mdot
.81 .27266 Mdot
.81 .27311 Mdot
.81 .27344 Mdot
.81 .27378 Mdot
.81 .27406 Mdot
.81 .27421 Mdot
.81 .27439 Mdot
.81 .27547 Mdot
.81 .27628 Mdot
.81 .27756 Mdot
.81 .27777 Mdot
.81 .27785 Mdot
.81 .27841 Mdot
.81 .27869 Mdot
.81 .27907 Mdot
.81 .27927 Mdot
.81 .27937 Mdot
.81 .28011 Mdot
.81 .28084 Mdot
.81 .28105 Mdot
.81 .28125 Mdot
.81 .28139 Mdot
.81 .28146 Mdot
.81 .28184 Mdot
.81 .28215 Mdot
.81 .28351 Mdot
.81 .28507 Mdot
.81 .28551 Mdot
.81 .28578 Mdot
.81 .28598 Mdot
.81 .28625 Mdot
.81 .28633 Mdot
.81 .28661 Mdot
.81 .28687 Mdot
.81 .28733 Mdot
.81 .28742 Mdot
.81 .28761 Mdot
.81 .28801 Mdot
.81 .2881 Mdot
.81 .28846 Mdot
.81 .28893 Mdot
.81 .2892 Mdot
.81 .28931 Mdot
.81 .28931 Mdot
.81 .28962 Mdot
.81 .28982 Mdot
.81 .29128 Mdot
.81 .29157 Mdot
.81 .29249 Mdot
.81 .29253 Mdot
.81 .29263 Mdot
.81 .29271 Mdot
.81 .29273 Mdot
.81 .29275 Mdot
.81 .29275 Mdot
.81 .29298 Mdot
.81 .29299 Mdot
.81 .29342 Mdot
.81 .29354 Mdot
.81 .29372 Mdot
.81 .29437 Mdot
.81 .29449 Mdot
.81 .2945 Mdot
.81 .29502 Mdot
.81 .29569 Mdot
.81 .29582 Mdot
.81 .29606 Mdot
.81 .29611 Mdot
.81 .29618 Mdot
.81 .29739 Mdot
.81 .2975 Mdot
.81 .2988 Mdot
.81 .29914 Mdot
.81 .3007 Mdot
.81 .30084 Mdot
.81 .30111 Mdot
.81 .30114 Mdot
.81 .30154 Mdot
.81 .30186 Mdot
.81 .30187 Mdot
.81 .30198 Mdot
.81 .30206 Mdot
.81 .30273 Mdot
.81 .30313 Mdot
.81 .30317 Mdot
.81 .30318 Mdot
.81 .30327 Mdot
.81 .30343 Mdot
.81 .3038 Mdot
.81 .30384 Mdot
.81 .30404 Mdot
.81 .3043 Mdot
.81 .30435 Mdot
.81 .30444 Mdot
.81 .30446 Mdot
.81 .30548 Mdot
.81 .30665 Mdot
.81 .30698 Mdot
.81 .30713 Mdot
.81 .30718 Mdot
.81 .30725 Mdot
.81 .30739 Mdot
.81 .3074 Mdot
.81 .30759 Mdot
.81 .30868 Mdot
.81 .30875 Mdot
.81 .30927 Mdot
.81 .30947 Mdot
.81 .30955 Mdot
.81 .30966 Mdot
.81 .30975 Mdot
.81 .31001 Mdot
.81 .31003 Mdot
.81 .31069 Mdot
.81 .31073 Mdot
.81 .31091 Mdot
.81 .31192 Mdot
.81 .31235 Mdot
.81 .31331 Mdot
.81 .31475 Mdot
.81 .31506 Mdot
.81 .31534 Mdot
.81 .31659 Mdot
.81 .31714 Mdot
.81 .31938 Mdot
.81 .32025 Mdot
.81 .32037 Mdot
.81 .3221 Mdot
.81 .32259 Mdot
.81 .32393 Mdot
.81 .32401 Mdot
.81 .32423 Mdot
.81 .32538 Mdot
.81 .32539 Mdot
.81 .3271 Mdot
.81 .32976 Mdot
.81 .3304 Mdot
.81 .33048 Mdot
.81 .3308 Mdot
.81 .33148 Mdot
.81 .33361 Mdot
.81 .33485 Mdot
.81 .33539 Mdot
.81 .3354 Mdot
.81 .33663 Mdot
.81 .33686 Mdot
.81 .33729 Mdot
.81 .33778 Mdot
.81 .3387 Mdot
.81 .33872 Mdot
.81 .34014 Mdot
.81 .3408 Mdot
.81 .34135 Mdot
.81 .34198 Mdot
.81 .34275 Mdot
.81 .34348 Mdot
.81 .34377 Mdot
.81 .34528 Mdot
.81 .34593 Mdot
.81 .34655 Mdot
.81 .34733 Mdot
.81 .34881 Mdot
.81 .34913 Mdot
.81 .34942 Mdot
.81 .35076 Mdot
.81 .3532 Mdot
.81 .354 Mdot
.81 .35533 Mdot
.81 .35623 Mdot
.81 .3567 Mdot
.81 .35714 Mdot
.81 .3573 Mdot
.81 .35744 Mdot
.81 .35817 Mdot
.81 .35849 Mdot
.81 .35985 Mdot
.81 .36005 Mdot
.81 .36102 Mdot
.81 .36168 Mdot
.81 .36266 Mdot
.81 .3634 Mdot
.81 .36349 Mdot
.81 .36394 Mdot
.81 .36474 Mdot
.81 .36663 Mdot
.81 .36704 Mdot
.81 .36709 Mdot
.81 .36792 Mdot
.81 .36805 Mdot
.81 .37018 Mdot
.81 .37107 Mdot
.81 .37173 Mdot
.81 .37192 Mdot
.81 .37249 Mdot
.81 .37282 Mdot
.81 .37304 Mdot
.81 .37312 Mdot
.81 .37428 Mdot
.81 .37441 Mdot
.81 .3747 Mdot
.81 .37573 Mdot
.81 .37574 Mdot
.81 .37578 Mdot
.81 .3762 Mdot
.81 .37688 Mdot
.81 .37766 Mdot
.81 .37769 Mdot
.81 .37776 Mdot
.81 .37777 Mdot
.81 .37977 Mdot
.81 .3804 Mdot
.81 .38153 Mdot
.81 .38347 Mdot
.81 .38347 Mdot
.81 .38387 Mdot
.81 .38617 Mdot
.81 .3871 Mdot
.81 .38773 Mdot
.81 .38815 Mdot
.81 .38898 Mdot
.81 .38912 Mdot
.81 .39001 Mdot
.81 .39118 Mdot
.81 .39125 Mdot
.81 .39201 Mdot
.81 .39317 Mdot
.81 .3935 Mdot
.81 .39468 Mdot
.81 .39497 Mdot
.81 .39532 Mdot
.81 .39576 Mdot
.81 .39577 Mdot
.81 .39579 Mdot
.81 .39777 Mdot
.81 .39813 Mdot
.81 .39846 Mdot
.81 .39896 Mdot
.81 .39992 Mdot
.81 .40002 Mdot
.81 .40066 Mdot
.81 .40102 Mdot
.81 .40202 Mdot
.81 .40255 Mdot
.81 .40388 Mdot
.81 .40425 Mdot
.81 .40454 Mdot
.81 .40488 Mdot
.81 .40517 Mdot
.81 .4057 Mdot
.81 .40616 Mdot
.81 .40619 Mdot
.81 .40649 Mdot
.81 .40833 Mdot
.81 .40868 Mdot
.81 .41088 Mdot
.81 .41113 Mdot
.81 .41124 Mdot
.81 .4118 Mdot
.81 .41218 Mdot
.81 .41341 Mdot
.81 .41376 Mdot
.81 .41453 Mdot
.81 .41498 Mdot
.81 .41578 Mdot
.81 .41642 Mdot
.81 .41765 Mdot
.81 .41815 Mdot
.81 .41969 Mdot
.81 .41981 Mdot
.81 .41986 Mdot
.81 .41989 Mdot
.81 .42031 Mdot
.81 .42064 Mdot
.81 .42074 Mdot
.81 .42079 Mdot
.81 .4208 Mdot
.81 .42119 Mdot
.81 .42176 Mdot
.81 .42182 Mdot
.81 .42186 Mdot
.81 .42199 Mdot
.81 .42326 Mdot
.81 .42364 Mdot
.81 .42417 Mdot
.81 .42495 Mdot
.81 .42649 Mdot
.81 .42686 Mdot
.81 .42771 Mdot
.81 .42822 Mdot
.81 .42825 Mdot
.81 .43044 Mdot
.81 .4311 Mdot
.81 .43258 Mdot
.81 .43259 Mdot
.81 .43331 Mdot
.81 .43385 Mdot
.81 .43439 Mdot
.81 .43486 Mdot
.81 .4351 Mdot
.81 .43539 Mdot
.81 .43714 Mdot
.81 .43844 Mdot
.81 .44053 Mdot
.81 .44087 Mdot
.81 .44099 Mdot
.81 .44191 Mdot
.81 .44235 Mdot
.81 .44298 Mdot
.81 .44329 Mdot
.81 .44346 Mdot
.81 .44465 Mdot
.81 .44584 Mdot
.81 .44618 Mdot
.81 .4465 Mdot
.81 .44672 Mdot
.81 .44685 Mdot
.81 .44745 Mdot
.81 .44796 Mdot
.81 .45017 Mdot
.81 .45269 Mdot
.81 .4534 Mdot
.81 .45384 Mdot
.81 .45416 Mdot
.81 .4546 Mdot
.81 .45473 Mdot
.81 .45518 Mdot
.81 .4556 Mdot
.81 .45635 Mdot
.81 .45649 Mdot
.81 .45681 Mdot
.81 .45746 Mdot
.81 .4576 Mdot
.81 .45817 Mdot
.81 .45894 Mdot
.81 .45938 Mdot
.81 .45955 Mdot
.81 .45956 Mdot
.81 .46038 Mdot
.81 .46274 Mdot
.81 .46322 Mdot
.81 .46471 Mdot
.81 .46477 Mdot
.81 .46494 Mdot
.81 .46507 Mdot
.81 .46511 Mdot
.81 .46513 Mdot
.81 .46513 Mdot
.81 .4655 Mdot
.81 .46552 Mdot
.81 .46621 Mdot
.81 .46641 Mdot
.81 .46671 Mdot
.81 .46776 Mdot
.81 .46796 Mdot
.81 .46797 Mdot
.81 .4688 Mdot
.81 .4699 Mdot
.81 .4701 Mdot
.81 .47049 Mdot
.81 .47058 Mdot
.81 .47069 Mdot
.81 .47265 Mdot
.81 .47282 Mdot
.81 .47492 Mdot
.81 .47548 Mdot
.81 .47801 Mdot
.81 .47823 Mdot
.81 .47868 Mdot
.81 .47873 Mdot
.81 .47937 Mdot
.81 .4799 Mdot
.81 .4799 Mdot
.81 .48009 Mdot
.81 .48021 Mdot
.81 .48129 Mdot
.81 .48195 Mdot
.81 .48201 Mdot
.81 .48202 Mdot
.81 .48217 Mdot
.81 .48243 Mdot
.81 .48303 Mdot
.81 .4831 Mdot
.81 .48342 Mdot
.81 .48384 Mdot
.81 .48392 Mdot
.81 .48406 Mdot
.81 .4841 Mdot
.81 .48575 Mdot
.81 .48765 Mdot
.81 .48818 Mdot
.81 .48843 Mdot
.81 .48851 Mdot
.81 .48862 Mdot
.81 .48884 Mdot
.81 .48887 Mdot
.81 .48918 Mdot
.81 .49093 Mdot
.81 .49106 Mdot
.81 .4919 Mdot
.81 .49222 Mdot
.81 .49235 Mdot
.81 .49252 Mdot
.81 .49268 Mdot
.81 .4931 Mdot
.81 .49312 Mdot
.812 .01543 Mdot
.812 .01587 Mdot
.812 .01631 Mdot
.812 .01636 Mdot
.812 .0166 Mdot
.812 .01726 Mdot
.812 .01731 Mdot
.812 .01739 Mdot
.812 .01761 Mdot
.812 .01777 Mdot
.812 .01804 Mdot
.812 .0186 Mdot
.812 .01884 Mdot
.812 .01893 Mdot
.812 .01905 Mdot
.812 .01941 Mdot
.812 .01959 Mdot
.812 .01961 Mdot
.812 .01967 Mdot
.812 .01992 Mdot
.812 .02011 Mdot
.812 .02081 Mdot
.812 .02103 Mdot
.812 .02142 Mdot
.812 .02157 Mdot
.812 .02176 Mdot
.812 .02234 Mdot
.812 .02262 Mdot
.812 .02266 Mdot
.812 .02277 Mdot
.812 .02303 Mdot
.812 .02317 Mdot
.812 .02348 Mdot
.812 .02462 Mdot
.812 .02497 Mdot
.812 .02544 Mdot
.812 .0256 Mdot
.812 .02584 Mdot
.812 .02589 Mdot
.812 .02616 Mdot
.812 .02687 Mdot
.812 .0271 Mdot
.812 .02731 Mdot
.812 .02756 Mdot
.812 .02762 Mdot
.812 .02779 Mdot
.812 .02822 Mdot
.812 .02844 Mdot
.812 .02895 Mdot
.812 .0307 Mdot
.812 .03076 Mdot
.812 .03079 Mdot
.812 .03137 Mdot
.812 .03213 Mdot
.812 .03232 Mdot
.812 .03239 Mdot
.812 .0324 Mdot
.812 .03279 Mdot
.812 .03286 Mdot
.812 .03293 Mdot
.812 .0333 Mdot
.812 .03438 Mdot
.812 .03445 Mdot
.812 .03484 Mdot
.812 .03516 Mdot
.812 .03557 Mdot
.812 .03568 Mdot
.812 .03595 Mdot
.812 .03665 Mdot
.812 .03684 Mdot
.812 .03701 Mdot
.812 .03783 Mdot
.812 .03852 Mdot
.812 .0399 Mdot
.812 .04067 Mdot
.812 .04077 Mdot
.812 .04083 Mdot
.812 .04155 Mdot
.812 .04177 Mdot
.812 .04185 Mdot
.812 .043 Mdot
.812 .04304 Mdot
.812 .0433 Mdot
.812 .04342 Mdot
.812 .04342 Mdot
.812 .04343 Mdot
.812 .0437 Mdot
.812 .04406 Mdot
.812 .04418 Mdot
.812 .04425 Mdot
.812 .04429 Mdot
.812 .04489 Mdot
.812 .0453 Mdot
.812 .04548 Mdot
.812 .04665 Mdot
.812 .04671 Mdot
.812 .04676 Mdot
.812 .04702 Mdot
.812 .04739 Mdot
.812 .04792 Mdot
.812 .04859 Mdot
.812 .04875 Mdot
.812 .04921 Mdot
.812 .04924 Mdot
.812 .05033 Mdot
.812 .05041 Mdot
.812 .05065 Mdot
.812 .05092 Mdot
.812 .05115 Mdot
.812 .05226 Mdot
.812 .0531 Mdot
.812 .05337 Mdot
.812 .05344 Mdot
.812 .05419 Mdot
.812 .05561 Mdot
.812 .05687 Mdot
.812 .05703 Mdot
.812 .05712 Mdot
.812 .05768 Mdot
.812 .0583 Mdot
.812 .05864 Mdot
.812 .05879 Mdot
.812 .05896 Mdot
.812 .05945 Mdot
.812 .06008 Mdot
.812 .06065 Mdot
.812 .06072 Mdot
.812 .06114 Mdot
.812 .06118 Mdot
.812 .06124 Mdot
.812 .06132 Mdot
.812 .06134 Mdot
.812 .06134 Mdot
.812 .06135 Mdot
.812 .06135 Mdot
.812 .06179 Mdot
.812 .06238 Mdot
.812 .06257 Mdot
.812 .06269 Mdot
.812 .06275 Mdot
.812 .06344 Mdot
.812 .06348 Mdot
.812 .06356 Mdot
.812 .06373 Mdot
.812 .06438 Mdot
.812 .06468 Mdot
.812 .06629 Mdot
.812 .06631 Mdot
.812 .0665 Mdot
.812 .06658 Mdot
.812 .06668 Mdot
.812 .06676 Mdot
.812 .06718 Mdot
.812 .06771 Mdot
.812 .06778 Mdot
.812 .06864 Mdot
.812 .0688 Mdot
.812 .06904 Mdot
.812 .06973 Mdot
.812 .06999 Mdot
.812 .07073 Mdot
.812 .07078 Mdot
.812 .07087 Mdot
.812 .07158 Mdot
.812 .07256 Mdot
.812 .07268 Mdot
.812 .07292 Mdot
.812 .07307 Mdot
.812 .07351 Mdot
.812 .07388 Mdot
.812 .07508 Mdot
.812 .07568 Mdot
.812 .07623 Mdot
.812 .07642 Mdot
.812 .07706 Mdot
.812 .07709 Mdot
.812 .07749 Mdot
.812 .07761 Mdot
.812 .07882 Mdot
.812 .07947 Mdot
.812 .08113 Mdot
.812 .08238 Mdot
.812 .08318 Mdot
.812 .08344 Mdot
.812 .08358 Mdot
.812 .08445 Mdot
.812 .0845 Mdot
.812 .08494 Mdot
.812 .08536 Mdot
.812 .0855 Mdot
.812 .08606 Mdot
.812 .08628 Mdot
.812 .08629 Mdot
.812 .08658 Mdot
.812 .08693 Mdot
.812 .08737 Mdot
.812 .088 Mdot
.812 .08817 Mdot
.812 .08839 Mdot
.812 .08899 Mdot
.812 .08932 Mdot
.812 .08942 Mdot
.812 .09011 Mdot
.812 .09018 Mdot
.812 .09027 Mdot
.812 .09041 Mdot
.812 .09043 Mdot
.812 .09044 Mdot
.812 .09045 Mdot
.812 .09045 Mdot
.812 .09077 Mdot
.812 .09117 Mdot
.812 .09212 Mdot
.812 .09243 Mdot
.812 .09262 Mdot
.812 .09272 Mdot
.812 .09385 Mdot
.812 .09391 Mdot
.812 .09404 Mdot
.812 .09431 Mdot
.812 .09443 Mdot
.812 .09538 Mdot
.812 .09538 Mdot
.812 .09559 Mdot
.812 .0956 Mdot
.812 .09585 Mdot
.812 .09686 Mdot
.812 .09707 Mdot
.812 .09714 Mdot
.812 .09726 Mdot
.812 .09847 Mdot
.812 .09851 Mdot
.812 .09881 Mdot
.812 .0989 Mdot
.812 .09894 Mdot
.812 .0991 Mdot
.812 .09924 Mdot
.812 .09992 Mdot
.812 .1 Mdot
.812 .10048 Mdot
.812 .10067 Mdot
.812 .10078 Mdot
.812 .10082 Mdot
.812 .10089 Mdot
.812 .10229 Mdot
.812 .10254 Mdot
.812 .10276 Mdot
.812 .10293 Mdot
.812 .10318 Mdot
.812 .10405 Mdot
.812 .10449 Mdot
.812 .10568 Mdot
.812 .10576 Mdot
.812 .10592 Mdot
.812 .10593 Mdot
.812 .10606 Mdot
.812 .10639 Mdot
.812 .10707 Mdot
.812 .10736 Mdot
.812 .10788 Mdot
.812 .10865 Mdot
.812 .10872 Mdot
.812 .10885 Mdot
.812 .10924 Mdot
.812 .10948 Mdot
.812 .11019 Mdot
.812 .1108 Mdot
.812 .11149 Mdot
.812 .11181 Mdot
.812 .11275 Mdot
.812 .11328 Mdot
.812 .11373 Mdot
.812 .11461 Mdot
.812 .11492 Mdot
.812 .11596 Mdot
.812 .11602 Mdot
.812 .11666 Mdot
.812 .11686 Mdot
.812 .11709 Mdot
.812 .11739 Mdot
.812 .11882 Mdot
.812 .1195 Mdot
.812 .11968 Mdot
.812 .11988 Mdot
.812 .12007 Mdot
.812 .1204 Mdot
.812 .12097 Mdot
.812 .12152 Mdot
.812 .12244 Mdot
.812 .12258 Mdot
.812 .12297 Mdot
.812 .12426 Mdot
.812 .1246 Mdot
.812 .12543 Mdot
.812 .1259 Mdot
.812 .12632 Mdot
.812 .12648 Mdot
.812 .12655 Mdot
.812 .12721 Mdot
.812 .12773 Mdot
.812 .12796 Mdot
.812 .12804 Mdot
.812 .12877 Mdot
.812 .12944 Mdot
.812 .12966 Mdot
.812 .12977 Mdot
.812 .13057 Mdot
.812 .13094 Mdot
.812 .13096 Mdot
.812 .13108 Mdot
.812 .13142 Mdot
.812 .13199 Mdot
.812 .13238 Mdot
.812 .13271 Mdot
.812 .13316 Mdot
.812 .13344 Mdot
.812 .13372 Mdot
.812 .13397 Mdot
.812 .13401 Mdot
.812 .13437 Mdot
.812 .13533 Mdot
.812 .13587 Mdot
.812 .13604 Mdot
.812 .13686 Mdot
.812 .13716 Mdot
.812 .13727 Mdot
.812 .13742 Mdot
.812 .13764 Mdot
.812 .13768 Mdot
.812 .13769 Mdot
.812 .13771 Mdot
.812 .13772 Mdot
.812 .1382 Mdot
.812 .13821 Mdot
.812 .13823 Mdot
.812 .13887 Mdot
.812 .13887 Mdot
.812 .13945 Mdot
.812 .13994 Mdot
.812 .1401 Mdot
.812 .14042 Mdot
.812 .14092 Mdot
.812 .14123 Mdot
.812 .14139 Mdot
.812 .14195 Mdot
.812 .14322 Mdot
.812 .14332 Mdot
.812 .14354 Mdot
.812 .14369 Mdot
.812 .14398 Mdot
.812 .14417 Mdot
.812 .14544 Mdot
.812 .14571 Mdot
.812 .14571 Mdot
.812 .14605 Mdot
.812 .14607 Mdot
.812 .1461 Mdot
.812 .14648 Mdot
.812 .14674 Mdot
.812 .14693 Mdot
.812 .14738 Mdot
.812 .14812 Mdot
.812 .14815 Mdot
.812 .14846 Mdot
.812 .14858 Mdot
.812 .14878 Mdot
.812 .14984 Mdot
.812 .15073 Mdot
.812 .1508 Mdot
.812 .15129 Mdot
.812 .15133 Mdot
.812 .15143 Mdot
.812 .1515 Mdot
.812 .15164 Mdot
.812 .15176 Mdot
.812 .15198 Mdot
.812 .1524 Mdot
.812 .15309 Mdot
.812 .15321 Mdot
.812 .154 Mdot
.812 .1543 Mdot
.812 .15448 Mdot
.812 .15455 Mdot
.812 .15467 Mdot
.812 .15595 Mdot
.812 .15694 Mdot
.812 .15735 Mdot
.812 .1577 Mdot
.812 .15798 Mdot
.812 .15838 Mdot
.812 .15872 Mdot
.812 .15897 Mdot
.812 .1598 Mdot
.812 .16051 Mdot
.812 .16245 Mdot
.812 .16257 Mdot
.812 .16283 Mdot
.812 .16285 Mdot
.812 .16305 Mdot
.812 .16359 Mdot
.812 .16372 Mdot
.812 .16433 Mdot
.812 .1647 Mdot
.812 .16516 Mdot
.812 .16548 Mdot
.812 .16602 Mdot
.812 .16726 Mdot
.812 .16729 Mdot
.812 .16738 Mdot
.812 .16759 Mdot
.812 .16782 Mdot
.812 .16822 Mdot
.812 .16861 Mdot
.812 .1689 Mdot
.812 .16902 Mdot
.812 .16977 Mdot
.812 .16988 Mdot
.812 .17075 Mdot
.812 .17188 Mdot
.812 .17217 Mdot
.812 .17239 Mdot
.812 .17273 Mdot
.812 .17392 Mdot
.812 .17478 Mdot
.812 .17533 Mdot
.812 .17551 Mdot
.812 .17693 Mdot
.812 .17694 Mdot
.812 .17745 Mdot
.812 .17793 Mdot
.812 .17892 Mdot
.812 .17914 Mdot
.812 .17923 Mdot
.812 .18015 Mdot
.812 .18027 Mdot
.812 .18027 Mdot
.812 .1806 Mdot
.812 .18097 Mdot
.812 .18146 Mdot
.812 .18258 Mdot
.812 .18378 Mdot
.812 .18489 Mdot
.812 .18519 Mdot
.812 .18551 Mdot
.812 .18581 Mdot
.812 .18635 Mdot
.812 .18643 Mdot
.812 .18728 Mdot
.812 .18791 Mdot
.812 .18801 Mdot
.812 .18816 Mdot
.812 .18842 Mdot
.812 .18932 Mdot
.812 .18966 Mdot
.812 .18989 Mdot
.812 .19029 Mdot
.812 .19046 Mdot
.812 .19051 Mdot
.812 .19202 Mdot
.812 .19261 Mdot
.812 .19316 Mdot
.812 .19367 Mdot
.812 .19375 Mdot
.812 .19452 Mdot
.812 .19494 Mdot
.812 .19527 Mdot
.812 .19544 Mdot
.812 .19596 Mdot
.812 .19623 Mdot
.812 .19634 Mdot
.812 .19739 Mdot
.812 .19741 Mdot
.812 .19826 Mdot
.812 .19863 Mdot
.812 .19864 Mdot
.812 .19876 Mdot
.812 .1991 Mdot
.812 .19994 Mdot
.812 .20085 Mdot
.812 .20102 Mdot
.812 .20139 Mdot
.812 .20156 Mdot
.812 .20285 Mdot
.812 .20287 Mdot
.812 .20346 Mdot
.812 .20349 Mdot
.812 .20369 Mdot
.812 .20424 Mdot
.812 .20517 Mdot
.812 .20581 Mdot
.812 .20633 Mdot
.812 .20696 Mdot
.812 .20707 Mdot
.812 .20753 Mdot
.812 .20767 Mdot
.812 .20778 Mdot
.812 .20798 Mdot
.812 .20838 Mdot
.812 .20845 Mdot
.812 .20892 Mdot
.812 .20903 Mdot
.812 .20987 Mdot
.812 .21032 Mdot
.812 .2106 Mdot
.812 .21134 Mdot
.812 .21147 Mdot
.812 .21175 Mdot
.812 .21308 Mdot
.812 .21356 Mdot
.812 .21375 Mdot
.812 .21399 Mdot
.812 .2144 Mdot
.812 .21443 Mdot
.812 .21446 Mdot
.812 .21447 Mdot
.812 .21526 Mdot
.812 .21527 Mdot
.812 .2153 Mdot
.812 .21634 Mdot
.812 .21635 Mdot
.812 .21642 Mdot
.812 .21688 Mdot
.812 .21729 Mdot
.812 .21738 Mdot
.812 .21808 Mdot
.812 .21835 Mdot
.812 .21885 Mdot
.812 .21967 Mdot
.812 .22011 Mdot
.812 .22018 Mdot
.812 .22044 Mdot
.812 .22134 Mdot
.812 .22244 Mdot
.812 .22323 Mdot
.812 .22341 Mdot
.812 .22357 Mdot
.812 .22392 Mdot
.812 .22417 Mdot
.812 .22457 Mdot
.812 .22464 Mdot
.812 .22495 Mdot
.812 .22562 Mdot
.812 .22701 Mdot
.812 .22737 Mdot
.812 .22745 Mdot
.812 .22745 Mdot
.812 .22793 Mdot
.812 .22801 Mdot
.812 .22804 Mdot
.812 .22808 Mdot
.812 .2287 Mdot
.812 .22912 Mdot
.812 .2293 Mdot
.812 .22937 Mdot
.812 .22943 Mdot
.812 .23017 Mdot
.812 .23033 Mdot
.812 .23137 Mdot
.812 .23142 Mdot
.812 .23154 Mdot
.812 .23191 Mdot
.812 .23211 Mdot
.812 .23243 Mdot
.812 .23348 Mdot
.812 .2336 Mdot
.812 .23416 Mdot
.812 .2356 Mdot
.812 .23571 Mdot
.812 .23652 Mdot
.812 .23659 Mdot
.812 .23673 Mdot
.812 .23686 Mdot
.812 .23707 Mdot
.812 .23728 Mdot
.812 .23763 Mdot
.812 .23783 Mdot
.812 .23832 Mdot
.812 .23877 Mdot
.812 .23916 Mdot
.812 .23944 Mdot
.812 .23964 Mdot
.812 .24041 Mdot
.812 .24091 Mdot
.812 .2414 Mdot
.812 .2417 Mdot
.812 .2418 Mdot
.812 .242 Mdot
.812 .2431 Mdot
.812 .24361 Mdot
.812 .24361 Mdot
.812 .24408 Mdot
.812 .24427 Mdot
.812 .24433 Mdot
.812 .24503 Mdot
.812 .24569 Mdot
.812 .24635 Mdot
.812 .2466 Mdot
.812 .24684 Mdot
.812 .24692 Mdot
.812 .24709 Mdot
.812 .24738 Mdot
.812 .24802 Mdot
.812 .24859 Mdot
.812 .2487 Mdot
.812 .24899 Mdot
.812 .25034 Mdot
.812 .25139 Mdot
.812 .25148 Mdot
.812 .25328 Mdot
.812 .25351 Mdot
.812 .25395 Mdot
.812 .25463 Mdot
.812 .25484 Mdot
.812 .25525 Mdot
.812 .25529 Mdot
.812 .25562 Mdot
.812 .25649 Mdot
.812 .2567 Mdot
.812 .25768 Mdot
.812 .25829 Mdot
.812 .25867 Mdot
.812 .25904 Mdot
.812 .25951 Mdot
.812 .25956 Mdot
.812 .26043 Mdot
.812 .26189 Mdot
.812 .26246 Mdot
.812 .26249 Mdot
.812 .26265 Mdot
.812 .26299 Mdot
.812 .26336 Mdot
.812 .26342 Mdot
.812 .26401 Mdot
.812 .26464 Mdot
.812 .26467 Mdot
.812 .26512 Mdot
.812 .26531 Mdot
.812 .26605 Mdot
.812 .26652 Mdot
.812 .2667 Mdot
.812 .26736 Mdot
.812 .26812 Mdot
.812 .26968 Mdot
.812 .26995 Mdot
.812 .26999 Mdot
.812 .27042 Mdot
.812 .27078 Mdot
.812 .27095 Mdot
.812 .27134 Mdot
.812 .27326 Mdot
.812 .27344 Mdot
.812 .27363 Mdot
.812 .27466 Mdot
.812 .27555 Mdot
.812 .27584 Mdot
.812 .27635 Mdot
.812 .27675 Mdot
.812 .27742 Mdot
.812 .27763 Mdot
.812 .27815 Mdot
.812 .27818 Mdot
.812 .27854 Mdot
.812 .279 Mdot
.812 .27973 Mdot
.812 .27978 Mdot
.812 .28138 Mdot
.812 .28174 Mdot
.812 .28189 Mdot
.812 .28236 Mdot
.812 .28338 Mdot
.812 .28357 Mdot
.812 .28357 Mdot
.812 .28382 Mdot
.812 .28385 Mdot
.812 .28411 Mdot
.812 .28471 Mdot
.812 .2848 Mdot
.812 .28489 Mdot
.812 .2855 Mdot
.812 .28652 Mdot
.812 .28724 Mdot
.812 .28733 Mdot
.812 .28749 Mdot
.812 .28928 Mdot
.812 .2896 Mdot
.812 .29051 Mdot
.812 .29108 Mdot
.812 .29156 Mdot
.812 .29208 Mdot
.812 .29258 Mdot
.812 .29346 Mdot
.812 .29357 Mdot
.812 .29394 Mdot
.812 .29488 Mdot
.812 .29496 Mdot
.812 .29599 Mdot
.812 .29614 Mdot
.812 .29639 Mdot
.812 .29647 Mdot
.812 .29682 Mdot
.812 .29727 Mdot
.812 .29827 Mdot
.812 .29882 Mdot
.812 .29883 Mdot
.812 .29919 Mdot
.812 .29923 Mdot
.812 .29984 Mdot
.812 .30012 Mdot
.812 .30021 Mdot
.812 .30101 Mdot
.812 .30135 Mdot
.812 .30266 Mdot
.812 .30301 Mdot
.812 .30362 Mdot
.812 .30392 Mdot
.812 .30451 Mdot
.812 .30466 Mdot
.812 .30534 Mdot
.812 .30547 Mdot
.812 .3061 Mdot
.812 .30644 Mdot
.812 .30672 Mdot
.812 .30727 Mdot
.812 .3074 Mdot
.812 .30771 Mdot
.812 .30788 Mdot
.812 .30794 Mdot
.812 .30821 Mdot
.812 .30858 Mdot
.812 .30906 Mdot
.812 .30949 Mdot
.812 .30957 Mdot
.812 .30967 Mdot
.812 .31084 Mdot
.812 .31138 Mdot
.812 .31141 Mdot
.812 .31196 Mdot
.812 .31218 Mdot
.812 .31244 Mdot
.812 .31279 Mdot
.812 .31339 Mdot
.812 .31341 Mdot
.812 .3136 Mdot
.812 .31415 Mdot
.812 .31552 Mdot
.812 .317 Mdot
.812 .31728 Mdot
.812 .31788 Mdot
.812 .31815 Mdot
.812 .32024 Mdot
.812 .32028 Mdot
.812 .32124 Mdot
.812 .32128 Mdot
.812 .32161 Mdot
.812 .32251 Mdot
.812 .32402 Mdot
.812 .32505 Mdot
.812 .3259 Mdot
.812 .32692 Mdot
.812 .32711 Mdot
.812 .32784 Mdot
.812 .32807 Mdot
.812 .32825 Mdot
.812 .32859 Mdot
.812 .32923 Mdot
.812 .32934 Mdot
.812 .3301 Mdot
.812 .33029 Mdot
.812 .33165 Mdot
.812 .33237 Mdot
.812 .33283 Mdot
.812 .33403 Mdot
.812 .33424 Mdot
.812 .3347 Mdot
.812 .33686 Mdot
.812 .33764 Mdot
.812 .33794 Mdot
.812 .33833 Mdot
.812 .33901 Mdot
.812 .33904 Mdot
.812 .33911 Mdot
.812 .33911 Mdot
.812 .3404 Mdot
.812 .34042 Mdot
.812 .34047 Mdot
.812 .34215 Mdot
.812 .34217 Mdot
.812 .34228 Mdot
.812 .34303 Mdot
.812 .3437 Mdot
.812 .34385 Mdot
.812 .34498 Mdot
.812 .34541 Mdot
.812 .34624 Mdot
.812 .34757 Mdot
.812 .34827 Mdot
.812 .34839 Mdot
.812 .34881 Mdot
.812 .35027 Mdot
.812 .35206 Mdot
.812 .35334 Mdot
.812 .35364 Mdot
.812 .35389 Mdot
.812 .35446 Mdot
.812 .35486 Mdot
.812 .35552 Mdot
.812 .35563 Mdot
.812 .35613 Mdot
.812 .35723 Mdot
.812 .35948 Mdot
.812 .36006 Mdot
.812 .3602 Mdot
.812 .3602 Mdot
.812 .36098 Mdot
.812 .36111 Mdot
.812 .36115 Mdot
.812 .36123 Mdot
.812 .36223 Mdot
.812 .36291 Mdot
.812 .36321 Mdot
.812 .36332 Mdot
.812 .36342 Mdot
.812 .36461 Mdot
.812 .36487 Mdot
.812 .36657 Mdot
.812 .36664 Mdot
.812 .36684 Mdot
.812 .36744 Mdot
.812 .36777 Mdot
.812 .36828 Mdot
.812 .36999 Mdot
.812 .37018 Mdot
.812 .37109 Mdot
.812 .37343 Mdot
.812 .37362 Mdot
.812 .37492 Mdot
.812 .37503 Mdot
.812 .37527 Mdot
.812 .37548 Mdot
.812 .37583 Mdot
.812 .37616 Mdot
.812 .37673 Mdot
.812 .37705 Mdot
.812 .37785 Mdot
.812 .37857 Mdot
.812 .37922 Mdot
.812 .37967 Mdot
.812 .37999 Mdot
.812 .38124 Mdot
.812 .38205 Mdot
.812 .38285 Mdot
.812 .38333 Mdot
.812 .3835 Mdot
.812 .38383 Mdot
.812 .38561 Mdot
.812 .38644 Mdot
.812 .38644 Mdot
.812 .38684 Mdot
.812 .38721 Mdot
.812 .3875 Mdot
.812 .38761 Mdot
.812 .38874 Mdot
.812 .38981 Mdot
.812 .39089 Mdot
.812 .3913 Mdot
.812 .39169 Mdot
.812 .39181 Mdot
.812 .39209 Mdot
.812 .39256 Mdot
.812 .3936 Mdot
.812 .39452 Mdot
.812 .39471 Mdot
.812 .39518 Mdot
.812 .39736 Mdot
.812 .39907 Mdot
.812 .39923 Mdot
.812 .40215 Mdot
.812 .40252 Mdot
.812 .40323 Mdot
.812 .40434 Mdot
.812 .40467 Mdot
.812 .40534 Mdot
.812 .40541 Mdot
.812 .40594 Mdot
.812 .40735 Mdot
.812 .4077 Mdot
.812 .40929 Mdot
.812 .41028 Mdot
.812 .4109 Mdot
.812 .41151 Mdot
.812 .41226 Mdot
.812 .41234 Mdot
.812 .41376 Mdot
.812 .41613 Mdot
.812 .41705 Mdot
.812 .4171 Mdot
.812 .41736 Mdot
.812 .41791 Mdot
.812 .41851 Mdot
.812 .41861 Mdot
.812 .41957 Mdot
.812 .42059 Mdot
.812 .42064 Mdot
.812 .42137 Mdot
.812 .42168 Mdot
.812 .42288 Mdot
.812 .42365 Mdot
.812 .42393 Mdot
.812 .42501 Mdot
.812 .42624 Mdot
.812 .42877 Mdot
.812 .42921 Mdot
.812 .42928 Mdot
.812 .42998 Mdot
.812 .43057 Mdot
.812 .43084 Mdot
.812 .43147 Mdot
.812 .4346 Mdot
.812 .43488 Mdot
.812 .43519 Mdot
.812 .43687 Mdot
.812 .43831 Mdot
.812 .43879 Mdot
.812 .43962 Mdot
.812 .44027 Mdot
.812 .44134 Mdot
.812 .44169 Mdot
.812 .44253 Mdot
.812 .44258 Mdot
.812 .44316 Mdot
.812 .44391 Mdot
.812 .4451 Mdot
.812 .44518 Mdot
.812 .44778 Mdot
.812 .44836 Mdot
.812 .4486 Mdot
.812 .44937 Mdot
.812 .45103 Mdot
.812 .45134 Mdot
.812 .45134 Mdot
.812 .45174 Mdot
.812 .45178 Mdot
.812 .45221 Mdot
.812 .45318 Mdot
.812 .45333 Mdot
.812 .45348 Mdot
.812 .45448 Mdot
.812 .45613 Mdot
.812 .4573 Mdot
.812 .45744 Mdot
.812 .45771 Mdot
.812 .46061 Mdot
.812 .46113 Mdot
.812 .4626 Mdot
.812 .46354 Mdot
.812 .46431 Mdot
.812 .46516 Mdot
.812 .46597 Mdot
.812 .46739 Mdot
.812 .46758 Mdot
.812 .46818 Mdot
.812 .46971 Mdot
.812 .46983 Mdot
.812 .4715 Mdot
.812 .47175 Mdot
.812 .47216 Mdot
.812 .47229 Mdot
.812 .47285 Mdot
.812 .47358 Mdot
.812 .4752 Mdot
.812 .4761 Mdot
.812 .47612 Mdot
.812 .4767 Mdot
.812 .47676 Mdot
.812 .47777 Mdot
.812 .47821 Mdot
.812 .47836 Mdot
.812 .47966 Mdot
.812 .48022 Mdot
.812 .48233 Mdot
.812 .48291 Mdot
.812 .48389 Mdot
.812 .48438 Mdot
.812 .48534 Mdot
.812 .48559 Mdot
.812 .48669 Mdot
.812 .4869 Mdot
.812 .48792 Mdot
.812 .48848 Mdot
.812 .48893 Mdot
.812 .48982 Mdot
.812 .49003 Mdot
.812 .49054 Mdot
.812 .49081 Mdot
.812 .49092 Mdot
.812 .49135 Mdot
.812 .49196 Mdot
.812 .49274 Mdot
.812 .49343 Mdot
.812 .49356 Mdot
.812 .49373 Mdot
.814 .01487 Mdot
.814 .01496 Mdot
.814 .01512 Mdot
.814 .01512 Mdot
.814 .01537 Mdot
.814 .01538 Mdot
.814 .01567 Mdot
.814 .01578 Mdot
.814 .0158 Mdot
.814 .0159 Mdot
.814 .01611 Mdot
.814 .01628 Mdot
.814 .01641 Mdot
.814 .01641 Mdot
.814 .01645 Mdot
.814 .01648 Mdot
.814 .01665 Mdot
.814 .01699 Mdot
.814 .01707 Mdot
.814 .01726 Mdot
.814 .01748 Mdot
.814 .01748 Mdot
.814 .01754 Mdot
.814 .01759 Mdot
.814 .01779 Mdot
.814 .01786 Mdot
.814 .01841 Mdot
.814 .01855 Mdot
.814 .01885 Mdot
.814 .01921 Mdot
.814 .01922 Mdot
.814 .01931 Mdot
.814 .01935 Mdot
.814 .01939 Mdot
.814 .01972 Mdot
.814 .01984 Mdot
.814 .02014 Mdot
.814 .02074 Mdot
.814 .02075 Mdot
.814 .02096 Mdot
.814 .02096 Mdot
.814 .02096 Mdot
.814 .02145 Mdot
.814 .02203 Mdot
.814 .02204 Mdot
.814 .0222 Mdot
.814 .02227 Mdot
.814 .02233 Mdot
.814 .02287 Mdot
.814 .02306 Mdot
.814 .02355 Mdot
.814 .02412 Mdot
.814 .02452 Mdot
.814 .02453 Mdot
.814 .02483 Mdot
.814 .02488 Mdot
.814 .02489 Mdot
.814 .02489 Mdot
.814 .02568 Mdot
.814 .02633 Mdot
.814 .02663 Mdot
.814 .02664 Mdot
.814 .0269 Mdot
.814 .02701 Mdot
.814 .02712 Mdot
.814 .02799 Mdot
.814 .0283 Mdot
.814 .02842 Mdot
.814 .02902 Mdot
.814 .0291 Mdot
.814 .02971 Mdot
.814 .03002 Mdot
.814 .03017 Mdot
.814 .03064 Mdot
.814 .03067 Mdot
.814 .0307 Mdot
.814 .03118 Mdot
.814 .03127 Mdot
.814 .03127 Mdot
.814 .03128 Mdot
.814 .03182 Mdot
.814 .0323 Mdot
.814 .03256 Mdot
.814 .03295 Mdot
.814 .03362 Mdot
.814 .03401 Mdot
.814 .03411 Mdot
.814 .03413 Mdot
.814 .03452 Mdot
.814 .03455 Mdot
.814 .03473 Mdot
.814 .03491 Mdot
.814 .03514 Mdot
.814 .03527 Mdot
.814 .03541 Mdot
.814 .03632 Mdot
.814 .03683 Mdot
.814 .03701 Mdot
.814 .03702 Mdot
.814 .03747 Mdot
.814 .03801 Mdot
.814 .03814 Mdot
.814 .03912 Mdot
.814 .03964 Mdot
.814 .03988 Mdot
.814 .04063 Mdot
.814 .0407 Mdot
.814 .04074 Mdot
.814 .04091 Mdot
.814 .04149 Mdot
.814 .04151 Mdot
.814 .04155 Mdot
.814 .04167 Mdot
.814 .04167 Mdot
.814 .04168 Mdot
.814 .04213 Mdot
.814 .04257 Mdot
.814 .04291 Mdot
.814 .04334 Mdot
.814 .04355 Mdot
.814 .04376 Mdot
.814 .04377 Mdot
.814 .04416 Mdot
.814 .0444 Mdot
.814 .04539 Mdot
.814 .0455 Mdot
.814 .04613 Mdot
.814 .04629 Mdot
.814 .04633 Mdot
.814 .04663 Mdot
.814 .04671 Mdot
.814 .04691 Mdot
.814 .04696 Mdot
.814 .047 Mdot
.814 .04729 Mdot
.814 .04759 Mdot
.814 .04796 Mdot
.814 .04818 Mdot
.814 .0484 Mdot
.814 .04851 Mdot
.814 .04872 Mdot
.814 .04877 Mdot
.814 .04922 Mdot
.814 .04956 Mdot
.814 .04975 Mdot
.814 .04989 Mdot
.814 .05021 Mdot
.814 .05072 Mdot
.814 .05101 Mdot
.814 .05103 Mdot
.814 .05176 Mdot
.814 .05187 Mdot
.814 .05263 Mdot
.814 .05285 Mdot
.814 .05445 Mdot
.814 .05529 Mdot
.814 .05569 Mdot
.814 .05691 Mdot
.814 .05693 Mdot
.814 .05701 Mdot
.814 .05708 Mdot
.814 .05735 Mdot
.814 .0582 Mdot
.814 .0583 Mdot
.814 .05834 Mdot
.814 .0584 Mdot
.814 .05859 Mdot
.814 .05861 Mdot
.814 .05862 Mdot
.814 .05915 Mdot
.814 .05935 Mdot
.814 .06006 Mdot
.814 .06061 Mdot
.814 .06107 Mdot
.814 .06131 Mdot
.814 .06165 Mdot
.814 .06201 Mdot
.814 .06201 Mdot
.814 .06266 Mdot
.814 .06305 Mdot
.814 .06345 Mdot
.814 .06393 Mdot
.814 .06466 Mdot
.814 .06483 Mdot
.814 .06586 Mdot
.814 .06613 Mdot
.814 .06618 Mdot
.814 .06619 Mdot
.814 .06666 Mdot
.814 .06667 Mdot
.814 .0668 Mdot
.814 .06688 Mdot
.814 .06711 Mdot
.814 .06713 Mdot
.814 .06722 Mdot
.814 .06728 Mdot
.814 .06775 Mdot
.814 .06823 Mdot
.814 .06884 Mdot
.814 .06919 Mdot
.814 .06956 Mdot
.814 .06974 Mdot
.814 .07004 Mdot
.814 .07008 Mdot
.814 .07013 Mdot
.814 .07015 Mdot
.814 .07026 Mdot
.814 .07089 Mdot
.814 .07144 Mdot
.814 .07175 Mdot
.814 .07199 Mdot
.814 .07239 Mdot
.814 .07251 Mdot
.814 .07333 Mdot
.814 .07342 Mdot
.814 .0738 Mdot
.814 .07383 Mdot
.814 .07416 Mdot
.814 .07422 Mdot
.814 .07502 Mdot
.814 .0752 Mdot
.814 .07645 Mdot
.814 .07679 Mdot
.814 .0794 Mdot
.814 .08049 Mdot
.814 .08077 Mdot
.814 .08141 Mdot
.814 .08161 Mdot
.814 .08271 Mdot
.814 .08341 Mdot
.814 .08344 Mdot
.814 .08348 Mdot
.814 .08358 Mdot
.814 .08368 Mdot
.814 .08413 Mdot
.814 .08538 Mdot
.814 .08551 Mdot
.814 .08568 Mdot
.814 .08574 Mdot
.814 .08584 Mdot
.814 .08606 Mdot
.814 .08615 Mdot
.814 .08617 Mdot
.814 .08619 Mdot
.814 .08705 Mdot
.814 .08714 Mdot
.814 .08738 Mdot
.814 .08779 Mdot
.814 .08853 Mdot
.814 .08943 Mdot
.814 .09018 Mdot
.814 .09057 Mdot
.814 .09064 Mdot
.814 .09067 Mdot
.814 .0907 Mdot
.814 .09113 Mdot
.814 .0917 Mdot
.814 .09171 Mdot
.814 .09276 Mdot
.814 .09303 Mdot
.814 .0934 Mdot
.814 .09364 Mdot
.814 .09405 Mdot
.814 .09483 Mdot
.814 .09603 Mdot
.814 .09613 Mdot
.814 .0963 Mdot
.814 .09679 Mdot
.814 .09694 Mdot
.814 .09797 Mdot
.814 .09841 Mdot
.814 .0985 Mdot
.814 .09852 Mdot
.814 .09899 Mdot
.814 .09928 Mdot
.814 .0993 Mdot
.814 .09951 Mdot
.814 .09963 Mdot
.814 .10001 Mdot
.814 .10005 Mdot
.814 .10019 Mdot
.814 .10025 Mdot
.814 .10029 Mdot
.814 .10106 Mdot
.814 .10183 Mdot
.814 .10184 Mdot
.814 .10284 Mdot
.814 .10341 Mdot
.814 .104 Mdot
.814 .10412 Mdot
.814 .10429 Mdot
.814 .10453 Mdot
.814 .10479 Mdot
.814 .10485 Mdot
.814 .10493 Mdot
.814 .10497 Mdot
.814 .10514 Mdot
.814 .10523 Mdot
.814 .10616 Mdot
.814 .10644 Mdot
.814 .10706 Mdot
.814 .10757 Mdot
.814 .10795 Mdot
.814 .1086 Mdot
.814 .1088 Mdot
.814 .10987 Mdot
.814 .11013 Mdot
.814 .11029 Mdot
.814 .11091 Mdot
.814 .11093 Mdot
.814 .11095 Mdot
.814 .11148 Mdot
.814 .11159 Mdot
.814 .11289 Mdot
.814 .11318 Mdot
.814 .11516 Mdot
.814 .11522 Mdot
.814 .11578 Mdot
.814 .11818 Mdot
.814 .12002 Mdot
.814 .12126 Mdot
.814 .12128 Mdot
.814 .1218 Mdot
.814 .12191 Mdot
.814 .12201 Mdot
.814 .12225 Mdot
.814 .12258 Mdot
.814 .1233 Mdot
.814 .12361 Mdot
.814 .12535 Mdot
.814 .12542 Mdot
.814 .12655 Mdot
.814 .1266 Mdot
.814 .12667 Mdot
.814 .12682 Mdot
.814 .12699 Mdot
.814 .12735 Mdot
.814 .12753 Mdot
.814 .12767 Mdot
.814 .12772 Mdot
.814 .12862 Mdot
.814 .12897 Mdot
.814 .12975 Mdot
.814 .12986 Mdot
.814 .12997 Mdot
.814 .13024 Mdot
.814 .13035 Mdot
.814 .1305 Mdot
.814 .13087 Mdot
.814 .13101 Mdot
.814 .13104 Mdot
.814 .13107 Mdot
.814 .13248 Mdot
.814 .1325 Mdot
.814 .13263 Mdot
.814 .13281 Mdot
.814 .13296 Mdot
.814 .13301 Mdot
.814 .13339 Mdot
.814 .13367 Mdot
.814 .13374 Mdot
.814 .13416 Mdot
.814 .1344 Mdot
.814 .1345 Mdot
.814 .13489 Mdot
.814 .13635 Mdot
.814 .13757 Mdot
.814 .13768 Mdot
.814 .13821 Mdot
.814 .13831 Mdot
.814 .13837 Mdot
.814 .13842 Mdot
.814 .1391 Mdot
.814 .13912 Mdot
.814 .13915 Mdot
.814 .13988 Mdot
.814 .14005 Mdot
.814 .14007 Mdot
.814 .14178 Mdot
.814 .14204 Mdot
.814 .14221 Mdot
.814 .14281 Mdot
.814 .14306 Mdot
.814 .14321 Mdot
.814 .14388 Mdot
.814 .14457 Mdot
.814 .14514 Mdot
.814 .1453 Mdot
.814 .14533 Mdot
.814 .14647 Mdot
.814 .14709 Mdot
.814 .14725 Mdot
.814 .14754 Mdot
.814 .14833 Mdot
.814 .14857 Mdot
.814 .15026 Mdot
.814 .15097 Mdot
.814 .15112 Mdot
.814 .15114 Mdot
.814 .15192 Mdot
.814 .15238 Mdot
.814 .15242 Mdot
.814 .15276 Mdot
.814 .15296 Mdot
.814 .15357 Mdot
.814 .15365 Mdot
.814 .15386 Mdot
.814 .15396 Mdot
.814 .15404 Mdot
.814 .15529 Mdot
.814 .15578 Mdot
.814 .15637 Mdot
.814 .15654 Mdot
.814 .15655 Mdot
.814 .15818 Mdot
.814 .15911 Mdot
.814 .16007 Mdot
.814 .16027 Mdot
.814 .16034 Mdot
.814 .16052 Mdot
.814 .16055 Mdot
.814 .16094 Mdot
.814 .16135 Mdot
.814 .16139 Mdot
.814 .16146 Mdot
.814 .16158 Mdot
.814 .16165 Mdot
.814 .16169 Mdot
.814 .16192 Mdot
.814 .16208 Mdot
.814 .16248 Mdot
.814 .16259 Mdot
.814 .1636 Mdot
.814 .16405 Mdot
.814 .16428 Mdot
.814 .16506 Mdot
.814 .16538 Mdot
.814 .16589 Mdot
.814 .16607 Mdot
.814 .16622 Mdot
.814 .16651 Mdot
.814 .16652 Mdot
.814 .16703 Mdot
.814 .16733 Mdot
.814 .1675 Mdot
.814 .16756 Mdot
.814 .16788 Mdot
.814 .16852 Mdot
.814 .16919 Mdot
.814 .16962 Mdot
.814 .17006 Mdot
.814 .17032 Mdot
.814 .17036 Mdot
.814 .17094 Mdot
.814 .17117 Mdot
.814 .17132 Mdot
.814 .17135 Mdot
.814 .17139 Mdot
.814 .17142 Mdot
.814 .17225 Mdot
.814 .17242 Mdot
.814 .17455 Mdot
.814 .17501 Mdot
.814 .17522 Mdot
.814 .17574 Mdot
.814 .17769 Mdot
.814 .17825 Mdot
.814 .17833 Mdot
.814 .17871 Mdot
.814 .17925 Mdot
.814 .18205 Mdot
.814 .1824 Mdot
.814 .18316 Mdot
.814 .18345 Mdot
.814 .18384 Mdot
.814 .18564 Mdot
.814 .18615 Mdot
.814 .18642 Mdot
.814 .18707 Mdot
.814 .1872 Mdot
.814 .18817 Mdot
.814 .1882 Mdot
.814 .18831 Mdot
.814 .18835 Mdot
.814 .18906 Mdot
.814 .18922 Mdot
.814 .18939 Mdot
.814 .18978 Mdot
.814 .19032 Mdot
.814 .19057 Mdot
.814 .19149 Mdot
.814 .19159 Mdot
.814 .19184 Mdot
.814 .192 Mdot
.814 .19257 Mdot
.814 .19286 Mdot
.814 .19425 Mdot
.814 .19483 Mdot
.814 .19494 Mdot
.814 .19679 Mdot
.814 .19686 Mdot
.814 .19698 Mdot
.814 .19698 Mdot
.814 .19723 Mdot
.814 .1975 Mdot
.814 .19809 Mdot
.814 .19839 Mdot
.814 .19861 Mdot
.814 .19869 Mdot
.814 .19869 Mdot
.814 .19989 Mdot
.814 .20015 Mdot
.814 .20072 Mdot
.814 .20151 Mdot
.814 .20174 Mdot
.814 .20199 Mdot
.814 .20217 Mdot
.814 .20234 Mdot
.814 .20279 Mdot
.814 .20297 Mdot
.814 .20322 Mdot
.814 .20362 Mdot
.814 .20381 Mdot
.814 .20404 Mdot
.814 .20409 Mdot
.814 .20414 Mdot
.814 .20475 Mdot
.814 .20492 Mdot
.814 .20622 Mdot
.814 .20644 Mdot
.814 .20646 Mdot
.814 .20668 Mdot
.814 .20697 Mdot
.814 .20722 Mdot
.814 .2073 Mdot
.814 .20745 Mdot
.814 .20791 Mdot
.814 .20838 Mdot
.814 .20841 Mdot
.814 .20849 Mdot
.814 .20909 Mdot
.814 .20917 Mdot
.814 .20919 Mdot
.814 .20936 Mdot
.814 .20948 Mdot
.814 .20956 Mdot
.814 .20973 Mdot
.814 .21035 Mdot
.814 .21227 Mdot
.814 .21274 Mdot
.814 .2131 Mdot
.814 .21383 Mdot
.814 .21472 Mdot
.814 .21491 Mdot
.814 .21576 Mdot
.814 .21594 Mdot
.814 .21602 Mdot
.814 .2161 Mdot
.814 .21721 Mdot
.814 .21724 Mdot
.814 .21729 Mdot
.814 .2181 Mdot
.814 .21849 Mdot
.814 .21876 Mdot
.814 .21879 Mdot
.814 .22116 Mdot
.814 .22158 Mdot
.814 .22199 Mdot
.814 .22228 Mdot
.814 .223 Mdot
.814 .22326 Mdot
.814 .22367 Mdot
.814 .22391 Mdot
.814 .22498 Mdot
.814 .22499 Mdot
.814 .22501 Mdot
.814 .22589 Mdot
.814 .22612 Mdot
.814 .22705 Mdot
.814 .2273 Mdot
.814 .22736 Mdot
.814 .22814 Mdot
.814 .22861 Mdot
.814 .22921 Mdot
.814 .23007 Mdot
.814 .23023 Mdot
.814 .23049 Mdot
.814 .23095 Mdot
.814 .23224 Mdot
.814 .23264 Mdot
.814 .23424 Mdot
.814 .23538 Mdot
.814 .23654 Mdot
.814 .23654 Mdot
.814 .23678 Mdot
.814 .23682 Mdot
.814 .23704 Mdot
.814 .23808 Mdot
.814 .23884 Mdot
.814 .2389 Mdot
.814 .23896 Mdot
.814 .23931 Mdot
.814 .23945 Mdot
.814 .23978 Mdot
.814 .24078 Mdot
.814 .2409 Mdot
.814 .24095 Mdot
.814 .24111 Mdot
.814 .24125 Mdot
.814 .2414 Mdot
.814 .24149 Mdot
.814 .24153 Mdot
.814 .24273 Mdot
.814 .24327 Mdot
.814 .24329 Mdot
.814 .24356 Mdot
.814 .24438 Mdot
.814 .24476 Mdot
.814 .24533 Mdot
.814 .24561 Mdot
.814 .24562 Mdot
.814 .24827 Mdot
.814 .24956 Mdot
.814 .24978 Mdot
.814 .25128 Mdot
.814 .25135 Mdot
.814 .25168 Mdot
.814 .25179 Mdot
.814 .25209 Mdot
.814 .25213 Mdot
.814 .25277 Mdot
.814 .25318 Mdot
.814 .25344 Mdot
.814 .2535 Mdot
.814 .25361 Mdot
.814 .25381 Mdot
.814 .25392 Mdot
.814 .25398 Mdot
.814 .25437 Mdot
.814 .25462 Mdot
.814 .25506 Mdot
.814 .25528 Mdot
.814 .25537 Mdot
.814 .25546 Mdot
.814 .2569 Mdot
.814 .25709 Mdot
.814 .25783 Mdot
.814 .25821 Mdot
.814 .25947 Mdot
.814 .25961 Mdot
.814 .26 Mdot
.814 .26015 Mdot
.814 .26083 Mdot
.814 .26112 Mdot
.814 .26137 Mdot
.814 .26142 Mdot
.814 .26183 Mdot
.814 .26185 Mdot
.814 .26269 Mdot
.814 .26307 Mdot
.814 .26317 Mdot
.814 .26344 Mdot
.814 .26355 Mdot
.814 .26408 Mdot
.814 .26511 Mdot
.814 .26575 Mdot
.814 .2662 Mdot
.814 .26681 Mdot
.814 .2669 Mdot
.814 .26761 Mdot
.814 .26804 Mdot
.814 .2681 Mdot
.814 .26859 Mdot
.814 .26906 Mdot
.814 .26942 Mdot
.814 .26968 Mdot
.814 .26971 Mdot
.814 .26978 Mdot
.814 .26982 Mdot
.814 .27087 Mdot
.814 .27119 Mdot
.814 .27146 Mdot
.814 .27307 Mdot
.814 .27423 Mdot
.814 .27492 Mdot
.814 .27567 Mdot
.814 .27568 Mdot
.814 .27601 Mdot
.814 .27686 Mdot
.814 .27704 Mdot
.814 .27759 Mdot
.814 .27916 Mdot
.814 .28003 Mdot
.814 .28022 Mdot
.814 .28094 Mdot
.814 .28108 Mdot
.814 .2817 Mdot
.814 .28176 Mdot
.814 .2819 Mdot
.814 .28237 Mdot
.814 .28257 Mdot
.814 .28258 Mdot
.814 .28314 Mdot
.814 .28495 Mdot
.814 .28559 Mdot
.814 .28631 Mdot
.814 .28702 Mdot
.814 .28714 Mdot
.814 .28771 Mdot
.814 .28874 Mdot
.814 .28894 Mdot
.814 .28942 Mdot
.814 .29004 Mdot
.814 .29106 Mdot
.814 .29146 Mdot
.814 .29213 Mdot
.814 .29299 Mdot
.814 .29382 Mdot
.814 .29425 Mdot
.814 .2948 Mdot
.814 .29531 Mdot
.814 .29552 Mdot
.814 .29611 Mdot
.814 .29651 Mdot
.814 .29709 Mdot
.814 .29715 Mdot
.814 .29732 Mdot
.814 .2974 Mdot
.814 .29761 Mdot
.814 .2983 Mdot
.814 .29854 Mdot
.814 .29881 Mdot
.814 .29908 Mdot
.814 .29973 Mdot
.814 .3006 Mdot
.814 .30075 Mdot
.814 .30101 Mdot
.814 .30201 Mdot
.814 .30251 Mdot
.814 .30266 Mdot
.814 .30308 Mdot
.814 .30333 Mdot
.814 .30426 Mdot
.814 .30474 Mdot
.814 .30699 Mdot
.814 .30793 Mdot
.814 .30799 Mdot
.814 .30812 Mdot
.814 .31049 Mdot
.814 .31065 Mdot
.814 .31098 Mdot
.814 .31113 Mdot
.814 .31125 Mdot
.814 .31144 Mdot
.814 .31144 Mdot
.814 .31184 Mdot
.814 .31229 Mdot
.814 .31324 Mdot
.814 .31373 Mdot
.814 .3141 Mdot
.814 .31423 Mdot
.814 .31423 Mdot
.814 .31617 Mdot
.814 .31661 Mdot
.814 .31753 Mdot
.814 .31881 Mdot
.814 .31918 Mdot
.814 .3196 Mdot
.814 .31989 Mdot
.814 .32018 Mdot
.814 .3209 Mdot
.814 .32119 Mdot
.814 .3216 Mdot
.814 .32225 Mdot
.814 .32256 Mdot
.814 .32294 Mdot
.814 .32302 Mdot
.814 .32311 Mdot
.814 .32409 Mdot
.814 .32437 Mdot
.814 .32648 Mdot
.814 .32684 Mdot
.814 .32688 Mdot
.814 .32724 Mdot
.814 .32771 Mdot
.814 .32811 Mdot
.814 .32824 Mdot
.814 .32848 Mdot
.814 .32924 Mdot
.814 .33 Mdot
.814 .33005 Mdot
.814 .33017 Mdot
.814 .33116 Mdot
.814 .33129 Mdot
.814 .33131 Mdot
.814 .33159 Mdot
.814 .3318 Mdot
.814 .33192 Mdot
.814 .3322 Mdot
.814 .33322 Mdot
.814 .33633 Mdot
.814 .33711 Mdot
.814 .33769 Mdot
.814 .33887 Mdot
.814 .34033 Mdot
.814 .34062 Mdot
.814 .34201 Mdot
.814 .3423 Mdot
.814 .34244 Mdot
.814 .34258 Mdot
.814 .34438 Mdot
.814 .34443 Mdot
.814 .34451 Mdot
.814 .34582 Mdot
.814 .34646 Mdot
.814 .34691 Mdot
.814 .34695 Mdot
.814 .3508 Mdot
.814 .35148 Mdot
.814 .35216 Mdot
.814 .35264 Mdot
.814 .3538 Mdot
.814 .35422 Mdot
.814 .35489 Mdot
.814 .35528 Mdot
.814 .35703 Mdot
.814 .35705 Mdot
.814 .35707 Mdot
.814 .3585 Mdot
.814 .35888 Mdot
.814 .3604 Mdot
.814 .36081 Mdot
.814 .3609 Mdot
.814 .36216 Mdot
.814 .36293 Mdot
.814 .36391 Mdot
.814 .36531 Mdot
.814 .36557 Mdot
.814 .366 Mdot
.814 .36674 Mdot
.814 .36884 Mdot
.814 .36949 Mdot
.814 .3721 Mdot
.814 .37395 Mdot
.814 .37584 Mdot
.814 .37585 Mdot
.814 .37624 Mdot
.814 .3763 Mdot
.814 .37665 Mdot
.814 .37835 Mdot
.814 .37958 Mdot
.814 .3797 Mdot
.814 .37978 Mdot
.814 .38036 Mdot
.814 .38058 Mdot
.814 .38112 Mdot
.814 .38274 Mdot
.814 .38294 Mdot
.814 .38303 Mdot
.814 .38329 Mdot
.814 .38351 Mdot
.814 .38376 Mdot
.814 .38391 Mdot
.814 .38398 Mdot
.814 .38593 Mdot
.814 .3868 Mdot
.814 .38683 Mdot
.814 .38728 Mdot
.814 .3886 Mdot
.814 .38923 Mdot
.814 .39016 Mdot
.814 .39061 Mdot
.814 .39063 Mdot
.814 .39132 Mdot
.814 .39495 Mdot
.814 .39705 Mdot
.814 .39741 Mdot
.814 .39985 Mdot
.814 .39996 Mdot
.814 .40049 Mdot
.814 .40067 Mdot
.814 .40116 Mdot
.814 .40123 Mdot
.814 .40227 Mdot
.814 .40294 Mdot
.814 .40337 Mdot
.814 .40346 Mdot
.814 .40364 Mdot
.814 .40396 Mdot
.814 .40414 Mdot
.814 .40424 Mdot
.814 .40487 Mdot
.814 .40528 Mdot
.814 .406 Mdot
.814 .40636 Mdot
.814 .4065 Mdot
.814 .40665 Mdot
.814 .40898 Mdot
.814 .40931 Mdot
.814 .4105 Mdot
.814 .41113 Mdot
.814 .41318 Mdot
.814 .4134 Mdot
.814 .41404 Mdot
.814 .41428 Mdot
.814 .41539 Mdot
.814 .41587 Mdot
.814 .41627 Mdot
.814 .41635 Mdot
.814 .41703 Mdot
.814 .41705 Mdot
.814 .41841 Mdot
.814 .41904 Mdot
.814 .4192 Mdot
.814 .41964 Mdot
.814 .41982 Mdot
.814 .42067 Mdot
.814 .42235 Mdot
.814 .42341 Mdot
.814 .42414 Mdot
.814 .42513 Mdot
.814 .42527 Mdot
.814 .42643 Mdot
.814 .42712 Mdot
.814 .42723 Mdot
.814 .42803 Mdot
.814 .42878 Mdot
.814 .42937 Mdot
.814 .42979 Mdot
.814 .42985 Mdot
.814 .42995 Mdot
.814 .43003 Mdot
.814 .43174 Mdot
.814 .43226 Mdot
.814 .4327 Mdot
.814 .43532 Mdot
.814 .4372 Mdot
.814 .43833 Mdot
.814 .43955 Mdot
.814 .43957 Mdot
.814 .44011 Mdot
.814 .44149 Mdot
.814 .44178 Mdot
.814 .44268 Mdot
.814 .44524 Mdot
.814 .44665 Mdot
.814 .44696 Mdot
.814 .44814 Mdot
.814 .44836 Mdot
.814 .44936 Mdot
.814 .44946 Mdot
.814 .4497 Mdot
.814 .45046 Mdot
.814 .45078 Mdot
.814 .4508 Mdot
.814 .4517 Mdot
.814 .45465 Mdot
.814 .45571 Mdot
.814 .45688 Mdot
.814 .45803 Mdot
.814 .45822 Mdot
.814 .45916 Mdot
.814 .46082 Mdot
.814 .46115 Mdot
.814 .46193 Mdot
.814 .46295 Mdot
.814 .4646 Mdot
.814 .46525 Mdot
.814 .46634 Mdot
.814 .46774 Mdot
.814 .46909 Mdot
.814 .4698 Mdot
.814 .47069 Mdot
.814 .47153 Mdot
.814 .47187 Mdot
.814 .47283 Mdot
.814 .47348 Mdot
.814 .47443 Mdot
.814 .47452 Mdot
.814 .4748 Mdot
.814 .47493 Mdot
.814 .47527 Mdot
.814 .47639 Mdot
.814 .47678 Mdot
.814 .47723 Mdot
.814 .47766 Mdot
.814 .47871 Mdot
.814 .48014 Mdot
.814 .48038 Mdot
.814 .4808 Mdot
.814 .48244 Mdot
.814 .48325 Mdot
.814 .48349 Mdot
.814 .48417 Mdot
.814 .48459 Mdot
.814 .48609 Mdot
.814 .48687 Mdot
.814 .49054 Mdot
.814 .49208 Mdot
.814 .49217 Mdot
.814 .49238 Mdot
.816 .01646 Mdot
.816 .01666 Mdot
.816 .01695 Mdot
.816 .01756 Mdot
.816 .01789 Mdot
.816 .01791 Mdot
.816 .01836 Mdot
.816 .01842 Mdot
.816 .01917 Mdot
.816 .01919 Mdot
.816 .01935 Mdot
.816 .01943 Mdot
.816 .0199 Mdot
.816 .01993 Mdot
.816 .02067 Mdot
.816 .02075 Mdot
.816 .02112 Mdot
.816 .02198 Mdot
.816 .02202 Mdot
.816 .02228 Mdot
.816 .0224 Mdot
.816 .02311 Mdot
.816 .02318 Mdot
.816 .02322 Mdot
.816 .02328 Mdot
.816 .02367 Mdot
.816 .02443 Mdot
.816 .02457 Mdot
.816 .02505 Mdot
.816 .02517 Mdot
.816 .02658 Mdot
.816 .02664 Mdot
.816 .02707 Mdot
.816 .02726 Mdot
.816 .02757 Mdot
.816 .02768 Mdot
.816 .02816 Mdot
.816 .02829 Mdot
.816 .02838 Mdot
.816 .02841 Mdot
.816 .02854 Mdot
.816 .02854 Mdot
.816 .0286 Mdot
.816 .02869 Mdot
.816 .02891 Mdot
.816 .02934 Mdot
.816 .03057 Mdot
.816 .0308 Mdot
.816 .03158 Mdot
.816 .03177 Mdot
.816 .03202 Mdot
.816 .03229 Mdot
.816 .03328 Mdot
.816 .03392 Mdot
.816 .03407 Mdot
.816 .03418 Mdot
.816 .03418 Mdot
.816 .03488 Mdot
.816 .03519 Mdot
.816 .0357 Mdot
.816 .03587 Mdot
.816 .03602 Mdot
.816 .03618 Mdot
.816 .03629 Mdot
.816 .03666 Mdot
.816 .03687 Mdot
.816 .03702 Mdot
.816 .03706 Mdot
.816 .03727 Mdot
.816 .03728 Mdot
.816 .03737 Mdot
.816 .03752 Mdot
.816 .03784 Mdot
.816 .03789 Mdot
.816 .03858 Mdot
.816 .04049 Mdot
.816 .04059 Mdot
.816 .04094 Mdot
.816 .04097 Mdot
.816 .04224 Mdot
.816 .04255 Mdot
.816 .04296 Mdot
.816 .04299 Mdot
.816 .04302 Mdot
.816 .04306 Mdot
.816 .0434 Mdot
.816 .04375 Mdot
.816 .04501 Mdot
.816 .04605 Mdot
.816 .0463 Mdot
.816 .04648 Mdot
.816 .04648 Mdot
.816 .04762 Mdot
.816 .04776 Mdot
.816 .04813 Mdot
.816 .04896 Mdot
.816 .04924 Mdot
.816 .04949 Mdot
.816 .04954 Mdot
.816 .04975 Mdot
.816 .04988 Mdot
.816 .04992 Mdot
.816 .05054 Mdot
.816 .05086 Mdot
.816 .05112 Mdot
.816 .05119 Mdot
.816 .05152 Mdot
.816 .05154 Mdot
.816 .05169 Mdot
.816 .05193 Mdot
.816 .05225 Mdot
.816 .05227 Mdot
.816 .05232 Mdot
.816 .05246 Mdot
.816 .05254 Mdot
.816 .05366 Mdot
.816 .05678 Mdot
.816 .05695 Mdot
.816 .05752 Mdot
.816 .05756 Mdot
.816 .05758 Mdot
.816 .05806 Mdot
.816 .05824 Mdot
.816 .05943 Mdot
.816 .05964 Mdot
.816 .06014 Mdot
.816 .0608 Mdot
.816 .06086 Mdot
.816 .06092 Mdot
.816 .06097 Mdot
.816 .06142 Mdot
.816 .06152 Mdot
.816 .06153 Mdot
.816 .06154 Mdot
.816 .0621 Mdot
.816 .06244 Mdot
.816 .06255 Mdot
.816 .06317 Mdot
.816 .06415 Mdot
.816 .06423 Mdot
.816 .06542 Mdot
.816 .06574 Mdot
.816 .06586 Mdot
.816 .06605 Mdot
.816 .06627 Mdot
.816 .06635 Mdot
.816 .06655 Mdot
.816 .06655 Mdot
.816 .06704 Mdot
.816 .06768 Mdot
.816 .06783 Mdot
.816 .06841 Mdot
.816 .06865 Mdot
.816 .06916 Mdot
.816 .06925 Mdot
.816 .06993 Mdot
.816 .07033 Mdot
.816 .0706 Mdot
.816 .07106 Mdot
.816 .07146 Mdot
.816 .07155 Mdot
.816 .07189 Mdot
.816 .0721 Mdot
.816 .07217 Mdot
.816 .07219 Mdot
.816 .0729 Mdot
.816 .07318 Mdot
.816 .07326 Mdot
.816 .07371 Mdot
.816 .07384 Mdot
.816 .07385 Mdot
.816 .07404 Mdot
.816 .07413 Mdot
.816 .07419 Mdot
.816 .07423 Mdot
.816 .07429 Mdot
.816 .07479 Mdot
.816 .07481 Mdot
.816 .07506 Mdot
.816 .07544 Mdot
.816 .07598 Mdot
.816 .076 Mdot
.816 .07609 Mdot
.816 .07619 Mdot
.816 .07631 Mdot
.816 .07644 Mdot
.816 .07827 Mdot
.816 .07897 Mdot
.816 .08074 Mdot
.816 .08085 Mdot
.816 .08219 Mdot
.816 .08337 Mdot
.816 .08364 Mdot
.816 .084 Mdot
.816 .08455 Mdot
.816 .08457 Mdot
.816 .08464 Mdot
.816 .08465 Mdot
.816 .08467 Mdot
.816 .08545 Mdot
.816 .08574 Mdot
.816 .086 Mdot
.816 .08683 Mdot
.816 .0877 Mdot
.816 .08803 Mdot
.816 .08804 Mdot
.816 .08878 Mdot
.816 .08885 Mdot
.816 .08972 Mdot
.816 .08993 Mdot
.816 .09002 Mdot
.816 .09012 Mdot
.816 .09021 Mdot
.816 .09094 Mdot
.816 .0911 Mdot
.816 .09112 Mdot
.816 .09114 Mdot
.816 .09205 Mdot
.816 .0926 Mdot
.816 .09279 Mdot
.816 .09291 Mdot
.816 .09318 Mdot
.816 .0938 Mdot
.816 .0954 Mdot
.816 .09552 Mdot
.816 .09636 Mdot
.816 .09637 Mdot
.816 .09747 Mdot
.816 .09799 Mdot
.816 .09818 Mdot
.816 .09849 Mdot
.816 .09885 Mdot
.816 .09899 Mdot
.816 .09922 Mdot
.816 .09931 Mdot
.816 .09931 Mdot
.816 .09996 Mdot
.816 .10003 Mdot
.816 .10011 Mdot
.816 .10082 Mdot
.816 .10116 Mdot
.816 .1014 Mdot
.816 .10235 Mdot
.816 .10274 Mdot
.816 .10357 Mdot
.816 .10371 Mdot
.816 .10395 Mdot
.816 .10418 Mdot
.816 .10453 Mdot
.816 .10483 Mdot
.816 .10493 Mdot
.816 .10535 Mdot
.816 .10545 Mdot
.816 .10548 Mdot
.816 .10591 Mdot
.816 .10667 Mdot
.816 .10733 Mdot
.816 .10746 Mdot
.816 .10752 Mdot
.816 .1077 Mdot
.816 .10802 Mdot
.816 .10837 Mdot
.816 .10848 Mdot
.816 .10852 Mdot
.816 .10967 Mdot
.816 .11012 Mdot
.816 .11027 Mdot
.816 .11076 Mdot
.816 .111 Mdot
.816 .1112 Mdot
.816 .11122 Mdot
.816 .11132 Mdot
.816 .11141 Mdot
.816 .11153 Mdot
.816 .11168 Mdot
.816 .11178 Mdot
.816 .11185 Mdot
.816 .11195 Mdot
.816 .11242 Mdot
.816 .11275 Mdot
.816 .11279 Mdot
.816 .11319 Mdot
.816 .11376 Mdot
.816 .11382 Mdot
.816 .11439 Mdot
.816 .1147 Mdot
.816 .11473 Mdot
.816 .11474 Mdot
.816 .11487 Mdot
.816 .11505 Mdot
.816 .11524 Mdot
.816 .11545 Mdot
.816 .11821 Mdot
.816 .1183 Mdot
.816 .11843 Mdot
.816 .11923 Mdot
.816 .11949 Mdot
.816 .11958 Mdot
.816 .12076 Mdot
.816 .12122 Mdot
.816 .12247 Mdot
.816 .12265 Mdot
.816 .12291 Mdot
.816 .12426 Mdot
.816 .12483 Mdot
.816 .12647 Mdot
.816 .12675 Mdot
.816 .1272 Mdot
.816 .12779 Mdot
.816 .12869 Mdot
.816 .12871 Mdot
.816 .12882 Mdot
.816 .12885 Mdot
.816 .12888 Mdot
.816 .12891 Mdot
.816 .129 Mdot
.816 .13 Mdot
.816 .13015 Mdot
.816 .13021 Mdot
.816 .13063 Mdot
.816 .13105 Mdot
.816 .13166 Mdot
.816 .13224 Mdot
.816 .13224 Mdot
.816 .13241 Mdot
.816 .13382 Mdot
.816 .13437 Mdot
.816 .13438 Mdot
.816 .13559 Mdot
.816 .1357 Mdot
.816 .13602 Mdot
.816 .1365 Mdot
.816 .13671 Mdot
.816 .13674 Mdot
.816 .13688 Mdot
.816 .13712 Mdot
.816 .1374 Mdot
.816 .13747 Mdot
.816 .13761 Mdot
.816 .13777 Mdot
.816 .13792 Mdot
.816 .13795 Mdot
.816 .13912 Mdot
.816 .13933 Mdot
.816 .13938 Mdot
.816 .13941 Mdot
.816 .13944 Mdot
.816 .14092 Mdot
.816 .1418 Mdot
.816 .14182 Mdot
.816 .14213 Mdot
.816 .14232 Mdot
.816 .1426 Mdot
.816 .14277 Mdot
.816 .14299 Mdot
.816 .14378 Mdot
.816 .14536 Mdot
.816 .14626 Mdot
.816 .14639 Mdot
.816 .14648 Mdot
.816 .14658 Mdot
.816 .14712 Mdot
.816 .14796 Mdot
.816 .14798 Mdot
.816 .14874 Mdot
.816 .14956 Mdot
.816 .14978 Mdot
.816 .15013 Mdot
.816 .15023 Mdot
.816 .15062 Mdot
.816 .15093 Mdot
.816 .15144 Mdot
.816 .152 Mdot
.816 .15202 Mdot
.816 .15225 Mdot
.816 .15263 Mdot
.816 .15277 Mdot
.816 .15277 Mdot
.816 .1538 Mdot
.816 .15384 Mdot
.816 .15395 Mdot
.816 .15408 Mdot
.816 .15524 Mdot
.816 .15579 Mdot
.816 .15619 Mdot
.816 .15656 Mdot
.816 .15773 Mdot
.816 .15836 Mdot
.816 .15973 Mdot
.816 .15995 Mdot
.816 .16034 Mdot
.816 .16035 Mdot
.816 .16073 Mdot
.816 .16129 Mdot
.816 .16179 Mdot
.816 .16194 Mdot
.816 .16248 Mdot
.816 .16264 Mdot
.816 .1628 Mdot
.816 .16284 Mdot
.816 .16348 Mdot
.816 .16355 Mdot
.816 .16478 Mdot
.816 .16514 Mdot
.816 .1652 Mdot
.816 .16586 Mdot
.816 .16608 Mdot
.816 .16617 Mdot
.816 .16646 Mdot
.816 .16684 Mdot
.816 .16699 Mdot
.816 .16756 Mdot
.816 .16773 Mdot
.816 .1678 Mdot
.816 .16928 Mdot
.816 .16968 Mdot
.816 .17042 Mdot
.816 .17066 Mdot
.816 .17145 Mdot
.816 .17145 Mdot
.816 .17185 Mdot
.816 .17211 Mdot
.816 .17218 Mdot
.816 .17222 Mdot
.816 .17238 Mdot
.816 .17247 Mdot
.816 .17252 Mdot
.816 .17272 Mdot
.816 .17296 Mdot
.816 .17312 Mdot
.816 .17324 Mdot
.816 .1734 Mdot
.816 .17417 Mdot
.816 .17447 Mdot
.816 .17471 Mdot
.816 .17478 Mdot
.816 .17514 Mdot
.816 .17543 Mdot
.816 .17585 Mdot
.816 .17602 Mdot
.816 .17635 Mdot
.816 .17646 Mdot
.816 .17739 Mdot
.816 .17789 Mdot
.816 .17793 Mdot
.816 .17795 Mdot
.816 .17818 Mdot
.816 .17846 Mdot
.816 .17877 Mdot
.816 .17879 Mdot
.816 .17911 Mdot
.816 .17912 Mdot
.816 .18312 Mdot
.816 .18362 Mdot
.816 .18376 Mdot
.816 .18398 Mdot
.816 .18447 Mdot
.816 .18529 Mdot
.816 .18571 Mdot
.816 .18585 Mdot
.816 .186 Mdot
.816 .18627 Mdot
.816 .18778 Mdot
.816 .18852 Mdot
.816 .18915 Mdot
.816 .19011 Mdot
.816 .19048 Mdot
.816 .19058 Mdot
.816 .19086 Mdot
.816 .19129 Mdot
.816 .19177 Mdot
.816 .1934 Mdot
.816 .19341 Mdot
.816 .1935 Mdot
.816 .19407 Mdot
.816 .19442 Mdot
.816 .19655 Mdot
.816 .19662 Mdot
.816 .19709 Mdot
.816 .19728 Mdot
.816 .19756 Mdot
.816 .19757 Mdot
.816 .1983 Mdot
.816 .19926 Mdot
.816 .20072 Mdot
.816 .20076 Mdot
.816 .20094 Mdot
.816 .20099 Mdot
.816 .20102 Mdot
.816 .20108 Mdot
.816 .20122 Mdot
.816 .20239 Mdot
.816 .20249 Mdot
.816 .20286 Mdot
.816 .2031 Mdot
.816 .2032 Mdot
.816 .20389 Mdot
.816 .20395 Mdot
.816 .20399 Mdot
.816 .20458 Mdot
.816 .20557 Mdot
.816 .20574 Mdot
.816 .20651 Mdot
.816 .20652 Mdot
.816 .20653 Mdot
.816 .20679 Mdot
.816 .2083 Mdot
.816 .20897 Mdot
.816 .20909 Mdot
.816 .20999 Mdot
.816 .20999 Mdot
.816 .21001 Mdot
.816 .21199 Mdot
.816 .21216 Mdot
.816 .21223 Mdot
.816 .21268 Mdot
.816 .21343 Mdot
.816 .21347 Mdot
.816 .21347 Mdot
.816 .21381 Mdot
.816 .21385 Mdot
.816 .21409 Mdot
.816 .21448 Mdot
.816 .21493 Mdot
.816 .21505 Mdot
.816 .21517 Mdot
.816 .21528 Mdot
.816 .21554 Mdot
.816 .21578 Mdot
.816 .21584 Mdot
.816 .21633 Mdot
.816 .21662 Mdot
.816 .21677 Mdot
.816 .21747 Mdot
.816 .21774 Mdot
.816 .21787 Mdot
.816 .21809 Mdot
.816 .21809 Mdot
.816 .21817 Mdot
.816 .21822 Mdot
.816 .21826 Mdot
.816 .21897 Mdot
.816 .22002 Mdot
.816 .22068 Mdot
.816 .22072 Mdot
.816 .22122 Mdot
.816 .22191 Mdot
.816 .22211 Mdot
.816 .22215 Mdot
.816 .22266 Mdot
.816 .22297 Mdot
.816 .22342 Mdot
.816 .2237 Mdot
.816 .22405 Mdot
.816 .22525 Mdot
.816 .22535 Mdot
.816 .22655 Mdot
.816 .22655 Mdot
.816 .22762 Mdot
.816 .2279 Mdot
.816 .22793 Mdot
.816 .22822 Mdot
.816 .2294 Mdot
.816 .22948 Mdot
.816 .22961 Mdot
.816 .22976 Mdot
.816 .22992 Mdot
.816 .22996 Mdot
.816 .23074 Mdot
.816 .2308 Mdot
.816 .23195 Mdot
.816 .23216 Mdot
.816 .2322 Mdot
.816 .23258 Mdot
.816 .23308 Mdot
.816 .23332 Mdot
.816 .23344 Mdot
.816 .23475 Mdot
.816 .23478 Mdot
.816 .23513 Mdot
.816 .23523 Mdot
.816 .23571 Mdot
.816 .23588 Mdot
.816 .23652 Mdot
.816 .23702 Mdot
.816 .23785 Mdot
.816 .23877 Mdot
.816 .2388 Mdot
.816 .23918 Mdot
.816 .23925 Mdot
.816 .2398 Mdot
.816 .24002 Mdot
.816 .24002 Mdot
.816 .24144 Mdot
.816 .24162 Mdot
.816 .2417 Mdot
.816 .24171 Mdot
.816 .24176 Mdot
.816 .24195 Mdot
.816 .24216 Mdot
.816 .24268 Mdot
.816 .24361 Mdot
.816 .24391 Mdot
.816 .24405 Mdot
.816 .24494 Mdot
.816 .24528 Mdot
.816 .24537 Mdot
.816 .24561 Mdot
.816 .24621 Mdot
.816 .24652 Mdot
.816 .24673 Mdot
.816 .24677 Mdot
.816 .24744 Mdot
.816 .24811 Mdot
.816 .24915 Mdot
.816 .25057 Mdot
.816 .25137 Mdot
.816 .25175 Mdot
.816 .25237 Mdot
.816 .25239 Mdot
.816 .25301 Mdot
.816 .25392 Mdot
.816 .25474 Mdot
.816 .25499 Mdot
.816 .25512 Mdot
.816 .25587 Mdot
.816 .25612 Mdot
.816 .25639 Mdot
.816 .25646 Mdot
.816 .2575 Mdot
.816 .25762 Mdot
.816 .25912 Mdot
.816 .25963 Mdot
.816 .2602 Mdot
.816 .2603 Mdot
.816 .26139 Mdot
.816 .26174 Mdot
.816 .26189 Mdot
.816 .26237 Mdot
.816 .26298 Mdot
.816 .26323 Mdot
.816 .26416 Mdot
.816 .26419 Mdot
.816 .26444 Mdot
.816 .26455 Mdot
.816 .26636 Mdot
.816 .26639 Mdot
.816 .26694 Mdot
.816 .26696 Mdot
.816 .26761 Mdot
.816 .26791 Mdot
.816 .26858 Mdot
.816 .26883 Mdot
.816 .26921 Mdot
.816 .27005 Mdot
.816 .2705 Mdot
.816 .27051 Mdot
.816 .27115 Mdot
.816 .27159 Mdot
.816 .2717 Mdot
.816 .27176 Mdot
.816 .27202 Mdot
.816 .27217 Mdot
.816 .27225 Mdot
.816 .27258 Mdot
.816 .27297 Mdot
.816 .27324 Mdot
.816 .27343 Mdot
.816 .27368 Mdot
.816 .27494 Mdot
.816 .27543 Mdot
.816 .27543 Mdot
.816 .27583 Mdot
.816 .27593 Mdot
.816 .27605 Mdot
.816 .27653 Mdot
.816 .27671 Mdot
.816 .277 Mdot
.816 .27746 Mdot
.816 .27769 Mdot
.816 .27788 Mdot
.816 .27797 Mdot
.816 .27851 Mdot
.816 .27869 Mdot
.816 .2802 Mdot
.816 .28102 Mdot
.816 .28108 Mdot
.816 .28111 Mdot
.816 .28148 Mdot
.816 .28183 Mdot
.816 .28194 Mdot
.816 .28246 Mdot
.816 .28249 Mdot
.816 .28293 Mdot
.816 .28301 Mdot
.816 .28302 Mdot
.816 .28327 Mdot
.816 .28444 Mdot
.816 .28615 Mdot
.816 .28766 Mdot
.816 .28956 Mdot
.816 .29037 Mdot
.816 .29039 Mdot
.816 .29059 Mdot
.816 .29096 Mdot
.816 .29121 Mdot
.816 .29176 Mdot
.816 .29309 Mdot
.816 .29378 Mdot
.816 .29401 Mdot
.816 .29426 Mdot
.816 .29454 Mdot
.816 .2947 Mdot
.816 .29618 Mdot
.816 .29659 Mdot
.816 .29672 Mdot
.816 .29716 Mdot
.816 .29781 Mdot
.816 .29837 Mdot
.816 .29939 Mdot
.816 .2997 Mdot
.816 .30095 Mdot
.816 .30157 Mdot
.816 .30173 Mdot
.816 .30177 Mdot
.816 .30218 Mdot
.816 .30289 Mdot
.816 .30367 Mdot
.816 .30632 Mdot
.816 .30634 Mdot
.816 .30649 Mdot
.816 .30742 Mdot
.816 .30799 Mdot
.816 .30884 Mdot
.816 .30888 Mdot
.816 .30929 Mdot
.816 .31146 Mdot
.816 .31159 Mdot
.816 .31177 Mdot
.816 .31235 Mdot
.816 .31266 Mdot
.816 .31312 Mdot
.816 .31314 Mdot
.816 .31328 Mdot
.816 .31432 Mdot
.816 .31554 Mdot
.816 .31564 Mdot
.816 .31589 Mdot
.816 .31673 Mdot
.816 .31827 Mdot
.816 .31834 Mdot
.816 .31864 Mdot
.816 .31871 Mdot
.816 .31877 Mdot
.816 .31887 Mdot
.816 .3191 Mdot
.816 .321 Mdot
.816 .32117 Mdot
.816 .32177 Mdot
.816 .32216 Mdot
.816 .32232 Mdot
.816 .32345 Mdot
.816 .32355 Mdot
.816 .32361 Mdot
.816 .32457 Mdot
.816 .32619 Mdot
.816 .32647 Mdot
.816 .32772 Mdot
.816 .32774 Mdot
.816 .32776 Mdot
.816 .32819 Mdot
.816 .33065 Mdot
.816 .33173 Mdot
.816 .33194 Mdot
.816 .3334 Mdot
.816 .33341 Mdot
.816 .33344 Mdot
.816 .33666 Mdot
.816 .33695 Mdot
.816 .33706 Mdot
.816 .3378 Mdot
.816 .33902 Mdot
.816 .33908 Mdot
.816 .33909 Mdot
.816 .33964 Mdot
.816 .33971 Mdot
.816 .34009 Mdot
.816 .34073 Mdot
.816 .34147 Mdot
.816 .34166 Mdot
.816 .34185 Mdot
.816 .34204 Mdot
.816 .34246 Mdot
.816 .34285 Mdot
.816 .34294 Mdot
.816 .34376 Mdot
.816 .34423 Mdot
.816 .34447 Mdot
.816 .34561 Mdot
.816 .34605 Mdot
.816 .34627 Mdot
.816 .34662 Mdot
.816 .34663 Mdot
.816 .34675 Mdot
.816 .34684 Mdot
.816 .3469 Mdot
.816 .34807 Mdot
.816 .34977 Mdot
.816 .35086 Mdot
.816 .35092 Mdot
.816 .35174 Mdot
.816 .35285 Mdot
.816 .35319 Mdot
.816 .35325 Mdot
.816 .35408 Mdot
.816 .35459 Mdot
.816 .35533 Mdot
.816 .35578 Mdot
.816 .35635 Mdot
.816 .35831 Mdot
.816 .35848 Mdot
.816 .36042 Mdot
.816 .36043 Mdot
.816 .36218 Mdot
.816 .36263 Mdot
.816 .36267 Mdot
.816 .36316 Mdot
.816 .36508 Mdot
.816 .36522 Mdot
.816 .36543 Mdot
.816 .36567 Mdot
.816 .36593 Mdot
.816 .366 Mdot
.816 .36726 Mdot
.816 .36737 Mdot
.816 .36925 Mdot
.816 .36959 Mdot
.816 .36964 Mdot
.816 .37026 Mdot
.816 .37108 Mdot
.816 .37147 Mdot
.816 .37168 Mdot
.816 .37381 Mdot
.816 .37386 Mdot
.816 .37444 Mdot
.816 .3746 Mdot
.816 .37538 Mdot
.816 .37565 Mdot
.816 .37669 Mdot
.816 .37752 Mdot
.816 .37887 Mdot
.816 .38037 Mdot
.816 .38042 Mdot
.816 .38104 Mdot
.816 .38116 Mdot
.816 .38205 Mdot
.816 .38241 Mdot
.816 .38241 Mdot
.816 .38472 Mdot
.816 .38502 Mdot
.816 .38515 Mdot
.816 .38516 Mdot
.816 .38525 Mdot
.816 .38557 Mdot
.816 .38591 Mdot
.816 .38675 Mdot
.816 .38826 Mdot
.816 .38876 Mdot
.816 .38899 Mdot
.816 .39045 Mdot
.816 .391 Mdot
.816 .39114 Mdot
.816 .39153 Mdot
.816 .39252 Mdot
.816 .39302 Mdot
.816 .39337 Mdot
.816 .39343 Mdot
.816 .39452 Mdot
.816 .39562 Mdot
.816 .39731 Mdot
.816 .39962 Mdot
.816 .40094 Mdot
.816 .40155 Mdot
.816 .40257 Mdot
.816 .4026 Mdot
.816 .40361 Mdot
.816 .4051 Mdot
.816 .40643 Mdot
.816 .40684 Mdot
.816 .40706 Mdot
.816 .40828 Mdot
.816 .4087 Mdot
.816 .40913 Mdot
.816 .40924 Mdot
.816 .41093 Mdot
.816 .41113 Mdot
.816 .41359 Mdot
.816 .41441 Mdot
.816 .41535 Mdot
.816 .41552 Mdot
.816 .41728 Mdot
.816 .41787 Mdot
.816 .4181 Mdot
.816 .41889 Mdot
.816 .41988 Mdot
.816 .41989 Mdot
.816 .42029 Mdot
.816 .42181 Mdot
.816 .42186 Mdot
.816 .42226 Mdot
.816 .42244 Mdot
.816 .42539 Mdot
.816 .42546 Mdot
.816 .42635 Mdot
.816 .42637 Mdot
.816 .42745 Mdot
.816 .42793 Mdot
.816 .42901 Mdot
.816 .42942 Mdot
.816 .43005 Mdot
.816 .43142 Mdot
.816 .43216 Mdot
.816 .43218 Mdot
.816 .43322 Mdot
.816 .43394 Mdot
.816 .43412 Mdot
.816 .43421 Mdot
.816 .43463 Mdot
.816 .43488 Mdot
.816 .43502 Mdot
.816 .43556 Mdot
.816 .43619 Mdot
.816 .43663 Mdot
.816 .43693 Mdot
.816 .43735 Mdot
.816 .4394 Mdot
.816 .44019 Mdot
.816 .4402 Mdot
.816 .44085 Mdot
.816 .44102 Mdot
.816 .44122 Mdot
.816 .44199 Mdot
.816 .44229 Mdot
.816 .44276 Mdot
.816 .44351 Mdot
.816 .44389 Mdot
.816 .4442 Mdot
.816 .44434 Mdot
.816 .44522 Mdot
.816 .44552 Mdot
.816 .44798 Mdot
.816 .44932 Mdot
.816 .44943 Mdot
.816 .44948 Mdot
.816 .45008 Mdot
.816 .45065 Mdot
.816 .45083 Mdot
.816 .45167 Mdot
.816 .45173 Mdot
.816 .45243 Mdot
.816 .45256 Mdot
.816 .45259 Mdot
.816 .453 Mdot
.816 .45491 Mdot
.816 .4577 Mdot
.816 .46016 Mdot
.816 .46326 Mdot
.816 .46459 Mdot
.816 .46461 Mdot
.816 .46495 Mdot
.816 .46554 Mdot
.816 .46595 Mdot
.816 .46685 Mdot
.816 .47015 Mdot
.816 .47053 Mdot
.816 .47093 Mdot
.816 .47139 Mdot
.816 .47165 Mdot
.816 .47407 Mdot
.816 .47474 Mdot
.816 .47495 Mdot
.816 .47567 Mdot
.816 .47672 Mdot
.816 .47764 Mdot
.816 .47931 Mdot
.816 .47981 Mdot
.816 .48186 Mdot
.816 .48286 Mdot
.816 .48312 Mdot
.816 .48319 Mdot
.816 .48386 Mdot
.816 .48502 Mdot
.816 .48629 Mdot
.816 .49062 Mdot
.816 .49064 Mdot
.816 .49089 Mdot
.816 .49241 Mdot
.816 .49334 Mdot
.816 .49472 Mdot
.816 .49479 Mdot
.816 .49545 Mdot
.818 .01556 Mdot
.818 .01602 Mdot
.818 .0161 Mdot
.818 .01634 Mdot
.818 .01684 Mdot
.818 .01698 Mdot
.818 .01738 Mdot
.818 .01743 Mdot
.818 .01755 Mdot
.818 .01755 Mdot
.818 .0182 Mdot
.818 .01842 Mdot
.818 .01868 Mdot
.818 .01907 Mdot
.818 .01915 Mdot
.818 .01935 Mdot
.818 .01936 Mdot
.818 .01958 Mdot
.818 .0199 Mdot
.818 .02013 Mdot
.818 .02041 Mdot
.818 .02057 Mdot
.818 .02071 Mdot
.818 .02078 Mdot
.818 .02087 Mdot
.818 .02089 Mdot
.818 .0212 Mdot
.818 .02184 Mdot
.818 .02197 Mdot
.818 .02228 Mdot
.818 .02229 Mdot
.818 .02231 Mdot
.818 .0225 Mdot
.818 .02265 Mdot
.818 .02267 Mdot
.818 .02273 Mdot
.818 .02277 Mdot
.818 .0232 Mdot
.818 .02358 Mdot
.818 .02369 Mdot
.818 .0238 Mdot
.818 .02393 Mdot
.818 .02404 Mdot
.818 .0243 Mdot
.818 .0245 Mdot
.818 .02453 Mdot
.818 .02453 Mdot
.818 .02464 Mdot
.818 .02479 Mdot
.818 .02482 Mdot
.818 .02532 Mdot
.818 .02637 Mdot
.818 .02658 Mdot
.818 .02686 Mdot
.818 .02709 Mdot
.818 .02711 Mdot
.818 .02714 Mdot
.818 .02745 Mdot
.818 .0277 Mdot
.818 .02773 Mdot
.818 .02783 Mdot
.818 .02789 Mdot
.818 .02844 Mdot
.818 .0286 Mdot
.818 .02876 Mdot
.818 .02921 Mdot
.818 .0294 Mdot
.818 .02951 Mdot
.818 .02958 Mdot
.818 .0298 Mdot
.818 .02992 Mdot
.818 .02996 Mdot
.818 .03039 Mdot
.818 .03072 Mdot
.818 .03077 Mdot
.818 .03078 Mdot
.818 .03095 Mdot
.818 .03119 Mdot
.818 .03119 Mdot
.818 .03125 Mdot
.818 .03206 Mdot
.818 .03308 Mdot
.818 .03336 Mdot
.818 .03341 Mdot
.818 .03378 Mdot
.818 .03413 Mdot
.818 .03459 Mdot
.818 .03469 Mdot
.818 .03484 Mdot
.818 .03488 Mdot
.818 .03496 Mdot
.818 .035 Mdot
.818 .03505 Mdot
.818 .03554 Mdot
.818 .03596 Mdot
.818 .03601 Mdot
.818 .03617 Mdot
.818 .03624 Mdot
.818 .03627 Mdot
.818 .03717 Mdot
.818 .03743 Mdot
.818 .0377 Mdot
.818 .03782 Mdot
.818 .03843 Mdot
.818 .03874 Mdot
.818 .03892 Mdot
.818 .03903 Mdot
.818 .03939 Mdot
.818 .03959 Mdot
.818 .03966 Mdot
.818 .04027 Mdot
.818 .04036 Mdot
.818 .0409 Mdot
.818 .04092 Mdot
.818 .04099 Mdot
.818 .04099 Mdot
.818 .041 Mdot
.818 .04128 Mdot
.818 .04156 Mdot
.818 .04167 Mdot
.818 .04167 Mdot
.818 .04177 Mdot
.818 .04208 Mdot
.818 .0431 Mdot
.818 .04315 Mdot
.818 .04476 Mdot
.818 .04522 Mdot
.818 .0453 Mdot
.818 .04536 Mdot
.818 .04566 Mdot
.818 .04574 Mdot
.818 .0459 Mdot
.818 .04648 Mdot
.818 .04723 Mdot
.818 .04739 Mdot
.818 .04764 Mdot
.818 .0477 Mdot
.818 .04775 Mdot
.818 .04784 Mdot
.818 .04789 Mdot
.818 .0479 Mdot
.818 .04798 Mdot
.818 .04879 Mdot
.818 .04948 Mdot
.818 .04956 Mdot
.818 .04979 Mdot
.818 .04982 Mdot
.818 .04992 Mdot
.818 .04998 Mdot
.818 .05094 Mdot
.818 .05146 Mdot
.818 .05154 Mdot
.818 .05165 Mdot
.818 .05168 Mdot
.818 .05188 Mdot
.818 .05232 Mdot
.818 .05252 Mdot
.818 .05352 Mdot
.818 .05403 Mdot
.818 .05432 Mdot
.818 .0545 Mdot
.818 .05508 Mdot
.818 .05541 Mdot
.818 .05542 Mdot
.818 .05553 Mdot
.818 .05566 Mdot
.818 .05652 Mdot
.818 .05664 Mdot
.818 .05667 Mdot
.818 .05756 Mdot
.818 .05758 Mdot
.818 .05769 Mdot
.818 .05771 Mdot
.818 .05771 Mdot
.818 .05817 Mdot
.818 .05863 Mdot
.818 .05881 Mdot
.818 .05882 Mdot
.818 .05898 Mdot
.818 .05914 Mdot
.818 .05948 Mdot
.818 .06114 Mdot
.818 .06123 Mdot
.818 .06165 Mdot
.818 .06193 Mdot
.818 .0625 Mdot
.818 .06387 Mdot
.818 .06461 Mdot
.818 .06476 Mdot
.818 .06484 Mdot
.818 .06535 Mdot
.818 .06547 Mdot
.818 .06574 Mdot
.818 .06668 Mdot
.818 .06791 Mdot
.818 .06817 Mdot
.818 .06858 Mdot
.818 .06868 Mdot
.818 .06876 Mdot
.818 .06891 Mdot
.818 .06898 Mdot
.818 .06901 Mdot
.818 .06913 Mdot
.818 .07047 Mdot
.818 .07104 Mdot
.818 .07158 Mdot
.818 .07172 Mdot
.818 .0721 Mdot
.818 .07215 Mdot
.818 .07232 Mdot
.818 .0724 Mdot
.818 .07292 Mdot
.818 .07386 Mdot
.818 .07398 Mdot
.818 .07482 Mdot
.818 .07495 Mdot
.818 .07513 Mdot
.818 .07513 Mdot
.818 .0752 Mdot
.818 .07551 Mdot
.818 .07609 Mdot
.818 .07623 Mdot
.818 .07657 Mdot
.818 .07717 Mdot
.818 .0782 Mdot
.818 .07903 Mdot
.818 .07951 Mdot
.818 .07965 Mdot
.818 .07981 Mdot
.818 .07987 Mdot
.818 .08075 Mdot
.818 .08101 Mdot
.818 .08111 Mdot
.818 .08129 Mdot
.818 .0813 Mdot
.818 .08149 Mdot
.818 .08153 Mdot
.818 .08169 Mdot
.818 .0831 Mdot
.818 .0833 Mdot
.818 .08335 Mdot
.818 .08431 Mdot
.818 .08481 Mdot
.818 .08484 Mdot
.818 .08503 Mdot
.818 .08505 Mdot
.818 .08506 Mdot
.818 .08581 Mdot
.818 .08656 Mdot
.818 .08685 Mdot
.818 .08687 Mdot
.818 .08714 Mdot
.818 .0874 Mdot
.818 .08796 Mdot
.818 .08809 Mdot
.818 .08879 Mdot
.818 .09037 Mdot
.818 .09067 Mdot
.818 .09081 Mdot
.818 .09096 Mdot
.818 .09134 Mdot
.818 .0915 Mdot
.818 .09151 Mdot
.818 .09196 Mdot
.818 .09258 Mdot
.818 .09288 Mdot
.818 .0937 Mdot
.818 .09481 Mdot
.818 .09513 Mdot
.818 .09521 Mdot
.818 .09623 Mdot
.818 .09635 Mdot
.818 .09659 Mdot
.818 .09673 Mdot
.818 .09681 Mdot
.818 .09683 Mdot
.818 .09755 Mdot
.818 .09775 Mdot
.818 .09819 Mdot
.818 .09973 Mdot
.818 .10089 Mdot
.818 .10174 Mdot
.818 .10194 Mdot
.818 .10217 Mdot
.818 .10284 Mdot
.818 .103 Mdot
.818 .10313 Mdot
.818 .10337 Mdot
.818 .1035 Mdot
.818 .10353 Mdot
.818 .10374 Mdot
.818 .10473 Mdot
.818 .10592 Mdot
.818 .10686 Mdot
.818 .10703 Mdot
.818 .10762 Mdot
.818 .10775 Mdot
.818 .10798 Mdot
.818 .10859 Mdot
.818 .10868 Mdot
.818 .10895 Mdot
.818 .10909 Mdot
.818 .10993 Mdot
.818 .11148 Mdot
.818 .11167 Mdot
.818 .11305 Mdot
.818 .11327 Mdot
.818 .11355 Mdot
.818 .11356 Mdot
.818 .11366 Mdot
.818 .11417 Mdot
.818 .11493 Mdot
.818 .11512 Mdot
.818 .11536 Mdot
.818 .11577 Mdot
.818 .1159 Mdot
.818 .11591 Mdot
.818 .11689 Mdot
.818 .11749 Mdot
.818 .1182 Mdot
.818 .11849 Mdot
.818 .1185 Mdot
.818 .11858 Mdot
.818 .11909 Mdot
.818 .11921 Mdot
.818 .11993 Mdot
.818 .12072 Mdot
.818 .12095 Mdot
.818 .12121 Mdot
.818 .1213 Mdot
.818 .12178 Mdot
.818 .12271 Mdot
.818 .12275 Mdot
.818 .12318 Mdot
.818 .12334 Mdot
.818 .12363 Mdot
.818 .12366 Mdot
.818 .12396 Mdot
.818 .12403 Mdot
.818 .12429 Mdot
.818 .12435 Mdot
.818 .12469 Mdot
.818 .12538 Mdot
.818 .12581 Mdot
.818 .12583 Mdot
.818 .12659 Mdot
.818 .12692 Mdot
.818 .127 Mdot
.818 .12703 Mdot
.818 .12857 Mdot
.818 .12895 Mdot
.818 .12938 Mdot
.818 .12945 Mdot
.818 .12975 Mdot
.818 .12978 Mdot
.818 .12979 Mdot
.818 .13102 Mdot
.818 .13117 Mdot
.818 .13119 Mdot
.818 .13144 Mdot
.818 .13226 Mdot
.818 .13273 Mdot
.818 .13276 Mdot
.818 .1332 Mdot
.818 .13346 Mdot
.818 .1336 Mdot
.818 .13362 Mdot
.818 .13363 Mdot
.818 .13454 Mdot
.818 .13476 Mdot
.818 .13591 Mdot
.818 .1361 Mdot
.818 .13848 Mdot
.818 .1387 Mdot
.818 .13898 Mdot
.818 .1392 Mdot
.818 .13945 Mdot
.818 .14002 Mdot
.818 .14007 Mdot
.818 .14033 Mdot
.818 .14035 Mdot
.818 .14108 Mdot
.818 .14211 Mdot
.818 .14247 Mdot
.818 .1426 Mdot
.818 .14269 Mdot
.818 .14323 Mdot
.818 .14394 Mdot
.818 .14575 Mdot
.818 .14627 Mdot
.818 .14641 Mdot
.818 .14808 Mdot
.818 .14827 Mdot
.818 .1483 Mdot
.818 .14866 Mdot
.818 .14882 Mdot
.818 .14889 Mdot
.818 .14889 Mdot
.818 .14902 Mdot
.818 .14905 Mdot
.818 .15023 Mdot
.818 .15046 Mdot
.818 .15056 Mdot
.818 .15128 Mdot
.818 .1538 Mdot
.818 .15436 Mdot
.818 .15441 Mdot
.818 .1557 Mdot
.818 .15581 Mdot
.818 .15583 Mdot
.818 .15619 Mdot
.818 .15709 Mdot
.818 .15741 Mdot
.818 .15742 Mdot
.818 .1575 Mdot
.818 .15778 Mdot
.818 .1578 Mdot
.818 .15888 Mdot
.818 .15915 Mdot
.818 .15937 Mdot
.818 .15976 Mdot
.818 .15996 Mdot
.818 .16002 Mdot
.818 .16037 Mdot
.818 .1614 Mdot
.818 .16199 Mdot
.818 .16226 Mdot
.818 .16341 Mdot
.818 .16393 Mdot
.818 .16438 Mdot
.818 .16547 Mdot
.818 .16575 Mdot
.818 .16599 Mdot
.818 .16609 Mdot
.818 .16671 Mdot
.818 .16693 Mdot
.818 .16699 Mdot
.818 .16725 Mdot
.818 .1673 Mdot
.818 .1683 Mdot
.818 .16844 Mdot
.818 .16875 Mdot
.818 .16889 Mdot
.818 .16911 Mdot
.818 .17025 Mdot
.818 .17049 Mdot
.818 .17127 Mdot
.818 .17302 Mdot
.818 .1733 Mdot
.818 .17333 Mdot
.818 .17391 Mdot
.818 .1756 Mdot
.818 .17585 Mdot
.818 .17595 Mdot
.818 .1764 Mdot
.818 .1764 Mdot
.818 .17642 Mdot
.818 .1766 Mdot
.818 .17661 Mdot
.818 .17704 Mdot
.818 .17743 Mdot
.818 .17867 Mdot
.818 .17898 Mdot
.818 .17937 Mdot
.818 .18005 Mdot
.818 .18026 Mdot
.818 .18028 Mdot
.818 .18187 Mdot
.818 .18207 Mdot
.818 .18286 Mdot
.818 .18402 Mdot
.818 .18437 Mdot
.818 .18448 Mdot
.818 .1845 Mdot
.818 .18463 Mdot
.818 .18547 Mdot
.818 .18567 Mdot
.818 .18634 Mdot
.818 .18684 Mdot
.818 .18813 Mdot
.818 .18852 Mdot
.818 .18893 Mdot
.818 .18909 Mdot
.818 .18987 Mdot
.818 .19109 Mdot
.818 .19139 Mdot
.818 .19145 Mdot
.818 .19216 Mdot
.818 .19233 Mdot
.818 .19243 Mdot
.818 .1929 Mdot
.818 .19294 Mdot
.818 .19339 Mdot
.818 .19344 Mdot
.818 .19355 Mdot
.818 .19383 Mdot
.818 .19398 Mdot
.818 .19409 Mdot
.818 .19463 Mdot
.818 .19532 Mdot
.818 .19577 Mdot
.818 .19646 Mdot
.818 .19651 Mdot
.818 .19651 Mdot
.818 .19747 Mdot
.818 .19764 Mdot
.818 .19775 Mdot
.818 .19776 Mdot
.818 .19828 Mdot
.818 .19842 Mdot
.818 .19846 Mdot
.818 .19889 Mdot
.818 .1991 Mdot
.818 .20098 Mdot
.818 .20113 Mdot
.818 .2016 Mdot
.818 .20231 Mdot
.818 .20241 Mdot
.818 .20291 Mdot
.818 .20297 Mdot
.818 .20298 Mdot
.818 .20349 Mdot
.818 .20408 Mdot
.818 .205 Mdot
.818 .20524 Mdot
.818 .20527 Mdot
.818 .20548 Mdot
.818 .20567 Mdot
.818 .20607 Mdot
.818 .2069 Mdot
.818 .20701 Mdot
.818 .20704 Mdot
.818 .20779 Mdot
.818 .20784 Mdot
.818 .20855 Mdot
.818 .20898 Mdot
.818 .20921 Mdot
.818 .20925 Mdot
.818 .20926 Mdot
.818 .21065 Mdot
.818 .21075 Mdot
.818 .21111 Mdot
.818 .21205 Mdot
.818 .21298 Mdot
.818 .21309 Mdot
.818 .2133 Mdot
.818 .21649 Mdot
.818 .21719 Mdot
.818 .21755 Mdot
.818 .21802 Mdot
.818 .21838 Mdot
.818 .21878 Mdot
.818 .21971 Mdot
.818 .21979 Mdot
.818 .22022 Mdot
.818 .22026 Mdot
.818 .22041 Mdot
.818 .22145 Mdot
.818 .22287 Mdot
.818 .22313 Mdot
.818 .22371 Mdot
.818 .22394 Mdot
.818 .22408 Mdot
.818 .22414 Mdot
.818 .22454 Mdot
.818 .22496 Mdot
.818 .22537 Mdot
.818 .22552 Mdot
.818 .22591 Mdot
.818 .22612 Mdot
.818 .22613 Mdot
.818 .22765 Mdot
.818 .22804 Mdot
.818 .22908 Mdot
.818 .22994 Mdot
.818 .23016 Mdot
.818 .23289 Mdot
.818 .23321 Mdot
.818 .23326 Mdot
.818 .23385 Mdot
.818 .23411 Mdot
.818 .23422 Mdot
.818 .23422 Mdot
.818 .23444 Mdot
.818 .23449 Mdot
.818 .23545 Mdot
.818 .2358 Mdot
.818 .23641 Mdot
.818 .23654 Mdot
.818 .2368 Mdot
.818 .23696 Mdot
.818 .23697 Mdot
.818 .23741 Mdot
.818 .23813 Mdot
.818 .23896 Mdot
.818 .23897 Mdot
.818 .23906 Mdot
.818 .23982 Mdot
.818 .23987 Mdot
.818 .23988 Mdot
.818 .2408 Mdot
.818 .24177 Mdot
.818 .24227 Mdot
.818 .24318 Mdot
.818 .24326 Mdot
.818 .24346 Mdot
.818 .24536 Mdot
.818 .24555 Mdot
.818 .24558 Mdot
.818 .24617 Mdot
.818 .24762 Mdot
.818 .24764 Mdot
.818 .24817 Mdot
.818 .24817 Mdot
.818 .24831 Mdot
.818 .24877 Mdot
.818 .2488 Mdot
.818 .2489 Mdot
.818 .25026 Mdot
.818 .25058 Mdot
.818 .251 Mdot
.818 .25137 Mdot
.818 .25197 Mdot
.818 .25201 Mdot
.818 .25234 Mdot
.818 .25244 Mdot
.818 .253 Mdot
.818 .25356 Mdot
.818 .2547 Mdot
.818 .25493 Mdot
.818 .25565 Mdot
.818 .25586 Mdot
.818 .25594 Mdot
.818 .2561 Mdot
.818 .25798 Mdot
.818 .25884 Mdot
.818 .25957 Mdot
.818 .26135 Mdot
.818 .26181 Mdot
.818 .26221 Mdot
.818 .26237 Mdot
.818 .26293 Mdot
.818 .26337 Mdot
.818 .26373 Mdot
.818 .26379 Mdot
.818 .26384 Mdot
.818 .26426 Mdot
.818 .26434 Mdot
.818 .2651 Mdot
.818 .26598 Mdot
.818 .2662 Mdot
.818 .26672 Mdot
.818 .26694 Mdot
.818 .26725 Mdot
.818 .26731 Mdot
.818 .26866 Mdot
.818 .26918 Mdot
.818 .26957 Mdot
.818 .27084 Mdot
.818 .2723 Mdot
.818 .27322 Mdot
.818 .2737 Mdot
.818 .27385 Mdot
.818 .27416 Mdot
.818 .27421 Mdot
.818 .27435 Mdot
.818 .27444 Mdot
.818 .27501 Mdot
.818 .27515 Mdot
.818 .27792 Mdot
.818 .27805 Mdot
.818 .27833 Mdot
.818 .27849 Mdot
.818 .27865 Mdot
.818 .27923 Mdot
.818 .27923 Mdot
.818 .27927 Mdot
.818 .27955 Mdot
.818 .27957 Mdot
.818 .27958 Mdot
.818 .27992 Mdot
.818 .28028 Mdot
.818 .28092 Mdot
.818 .28247 Mdot
.818 .28295 Mdot
.818 .28345 Mdot
.818 .28409 Mdot
.818 .28469 Mdot
.818 .2852 Mdot
.818 .28555 Mdot
.818 .28558 Mdot
.818 .28819 Mdot
.818 .28851 Mdot
.818 .289 Mdot
.818 .2898 Mdot
.818 .29033 Mdot
.818 .29169 Mdot
.818 .29203 Mdot
.818 .29227 Mdot
.818 .29246 Mdot
.818 .29249 Mdot
.818 .2927 Mdot
.818 .29384 Mdot
.818 .29406 Mdot
.818 .29441 Mdot
.818 .29454 Mdot
.818 .29549 Mdot
.818 .29632 Mdot
.818 .29793 Mdot
.818 .29842 Mdot
.818 .29906 Mdot
.818 .29974 Mdot
.818 .3 Mdot
.818 .30126 Mdot
.818 .30327 Mdot
.818 .30329 Mdot
.818 .30334 Mdot
.818 .30349 Mdot
.818 .30375 Mdot
.818 .30386 Mdot
.818 .30387 Mdot
.818 .30459 Mdot
.818 .30488 Mdot
.818 .30491 Mdot
.818 .30502 Mdot
.818 .30529 Mdot
.818 .30545 Mdot
.818 .30622 Mdot
.818 .30629 Mdot
.818 .30683 Mdot
.818 .30703 Mdot
.818 .30711 Mdot
.818 .30729 Mdot
.818 .3076 Mdot
.818 .3077 Mdot
.818 .30775 Mdot
.818 .30797 Mdot
.818 .308 Mdot
.818 .30816 Mdot
.818 .3087 Mdot
.818 .30906 Mdot
.818 .30913 Mdot
.818 .31019 Mdot
.818 .31091 Mdot
.818 .31119 Mdot
.818 .31139 Mdot
.818 .31205 Mdot
.818 .31213 Mdot
.818 .31213 Mdot
.818 .31282 Mdot
.818 .31337 Mdot
.818 .31357 Mdot
.818 .31371 Mdot
.818 .31398 Mdot
.818 .31406 Mdot
.818 .31416 Mdot
.818 .31417 Mdot
.818 .31502 Mdot
.818 .31515 Mdot
.818 .31525 Mdot
.818 .3153 Mdot
.818 .31532 Mdot
.818 .31588 Mdot
.818 .31595 Mdot
.818 .31603 Mdot
.818 .31638 Mdot
.818 .3164 Mdot
.818 .31782 Mdot
.818 .31879 Mdot
.818 .31898 Mdot
.818 .31944 Mdot
.818 .31969 Mdot
.818 .32047 Mdot
.818 .32162 Mdot
.818 .32179 Mdot
.818 .32183 Mdot
.818 .3226 Mdot
.818 .3227 Mdot
.818 .32272 Mdot
.818 .32355 Mdot
.818 .32452 Mdot
.818 .32601 Mdot
.818 .32641 Mdot
.818 .32646 Mdot
.818 .3268 Mdot
.818 .32712 Mdot
.818 .32777 Mdot
.818 .32913 Mdot
.818 .32931 Mdot
.818 .32936 Mdot
.818 .33059 Mdot
.818 .33067 Mdot
.818 .33184 Mdot
.818 .33254 Mdot
.818 .3329 Mdot
.818 .33297 Mdot
.818 .33299 Mdot
.818 .33527 Mdot
.818 .33542 Mdot
.818 .33602 Mdot
.818 .33755 Mdot
.818 .33908 Mdot
.818 .33926 Mdot
.818 .3396 Mdot
.818 .34482 Mdot
.818 .34597 Mdot
.818 .34655 Mdot
.818 .34732 Mdot
.818 .34791 Mdot
.818 .34857 Mdot
.818 .35009 Mdot
.818 .35022 Mdot
.818 .35092 Mdot
.818 .35098 Mdot
.818 .35124 Mdot
.818 .35293 Mdot
.818 .35525 Mdot
.818 .35568 Mdot
.818 .35664 Mdot
.818 .357 Mdot
.818 .35723 Mdot
.818 .35734 Mdot
.818 .35799 Mdot
.818 .35868 Mdot
.818 .35935 Mdot
.818 .3596 Mdot
.818 .36022 Mdot
.818 .36058 Mdot
.818 .36059 Mdot
.818 .36307 Mdot
.818 .36371 Mdot
.818 .36542 Mdot
.818 .36683 Mdot
.818 .36718 Mdot
.818 .37165 Mdot
.818 .37217 Mdot
.818 .37225 Mdot
.818 .37322 Mdot
.818 .37365 Mdot
.818 .37383 Mdot
.818 .37383 Mdot
.818 .37419 Mdot
.818 .37427 Mdot
.818 .37584 Mdot
.818 .37641 Mdot
.818 .37741 Mdot
.818 .37762 Mdot
.818 .37804 Mdot
.818 .3783 Mdot
.818 .37832 Mdot
.818 .37905 Mdot
.818 .38022 Mdot
.818 .38158 Mdot
.818 .38159 Mdot
.818 .38174 Mdot
.818 .38298 Mdot
.818 .38306 Mdot
.818 .38308 Mdot
.818 .38459 Mdot
.818 .38618 Mdot
.818 .38699 Mdot
.818 .38848 Mdot
.818 .38862 Mdot
.818 .38895 Mdot
.818 .39205 Mdot
.818 .39237 Mdot
.818 .39241 Mdot
.818 .39337 Mdot
.818 .39576 Mdot
.818 .39579 Mdot
.818 .39664 Mdot
.818 .39665 Mdot
.818 .39687 Mdot
.818 .39762 Mdot
.818 .39767 Mdot
.818 .39784 Mdot
.818 .40006 Mdot
.818 .40058 Mdot
.818 .40128 Mdot
.818 .40188 Mdot
.818 .40287 Mdot
.818 .40293 Mdot
.818 .40347 Mdot
.818 .40363 Mdot
.818 .40455 Mdot
.818 .40547 Mdot
.818 .40733 Mdot
.818 .4077 Mdot
.818 .40889 Mdot
.818 .40923 Mdot
.818 .40935 Mdot
.818 .40962 Mdot
.818 .41269 Mdot
.818 .4141 Mdot
.818 .4153 Mdot
.818 .41821 Mdot
.818 .41896 Mdot
.818 .41961 Mdot
.818 .41988 Mdot
.818 .42079 Mdot
.818 .42152 Mdot
.818 .42211 Mdot
.818 .42221 Mdot
.818 .42228 Mdot
.818 .42297 Mdot
.818 .4231 Mdot
.818 .42434 Mdot
.818 .42578 Mdot
.818 .42615 Mdot
.818 .427 Mdot
.818 .42736 Mdot
.818 .42787 Mdot
.818 .42795 Mdot
.818 .43016 Mdot
.818 .43102 Mdot
.818 .43165 Mdot
.818 .43373 Mdot
.818 .43613 Mdot
.818 .43763 Mdot
.818 .43841 Mdot
.818 .43865 Mdot
.818 .43916 Mdot
.818 .43925 Mdot
.818 .43949 Mdot
.818 .43962 Mdot
.818 .44055 Mdot
.818 .44079 Mdot
.818 .44532 Mdot
.818 .44553 Mdot
.818 .44598 Mdot
.818 .44625 Mdot
.818 .44652 Mdot
.818 .44747 Mdot
.818 .44747 Mdot
.818 .44753 Mdot
.818 .44799 Mdot
.818 .44802 Mdot
.818 .44803 Mdot
.818 .44859 Mdot
.818 .44918 Mdot
.818 .45022 Mdot
.818 .45276 Mdot
.818 .45354 Mdot
.818 .45437 Mdot
.818 .45542 Mdot
.818 .45639 Mdot
.818 .45722 Mdot
.818 .45779 Mdot
.818 .45784 Mdot
.818 .46212 Mdot
.818 .46264 Mdot
.818 .46344 Mdot
.818 .46476 Mdot
.818 .46562 Mdot
.818 .46785 Mdot
.818 .46841 Mdot
.818 .46879 Mdot
.818 .4691 Mdot
.818 .46915 Mdot
.818 .4695 Mdot
.818 .47136 Mdot
.818 .47173 Mdot
.818 .47229 Mdot
.818 .4725 Mdot
.818 .47406 Mdot
.818 .47542 Mdot
.818 .47805 Mdot
.818 .47886 Mdot
.818 .47991 Mdot
.818 .48101 Mdot
.818 .48144 Mdot
.818 .48351 Mdot
.818 .48678 Mdot
.818 .48682 Mdot
.818 .48691 Mdot
.818 .48714 Mdot
.818 .48758 Mdot
.818 .48776 Mdot
.818 .48778 Mdot
.818 .48895 Mdot
.818 .48942 Mdot
.818 .48948 Mdot
.818 .48965 Mdot
.818 .49009 Mdot
.818 .49036 Mdot
.818 .49162 Mdot
.818 .49174 Mdot
.818 .49261 Mdot
.818 .49295 Mdot
.818 .49307 Mdot
.818 .49337 Mdot
.818 .49387 Mdot
.818 .49404 Mdot
.818 .49413 Mdot
.818 .49448 Mdot
.818 .49453 Mdot
.818 .4948 Mdot
.818 .49567 Mdot
.818 .49626 Mdot
.818 .49638 Mdot
.818 .49812 Mdot
.82 .01517 Mdot
.82 .01545 Mdot
.82 .01593 Mdot
.82 .0162 Mdot
.82 .0167 Mdot
.82 .01715 Mdot
.82 .01798 Mdot
.82 .0187 Mdot
.82 .0187 Mdot
.82 .019 Mdot
.82 .02007 Mdot
.82 .02121 Mdot
.82 .02125 Mdot
.82 .02126 Mdot
.82 .02175 Mdot
.82 .02261 Mdot
.82 .02265 Mdot
.82 .02349 Mdot
.82 .02537 Mdot
.82 .02543 Mdot
.82 .02544 Mdot
.82 .02552 Mdot
.82 .02592 Mdot
.82 .02598 Mdot
.82 .02625 Mdot
.82 .02759 Mdot
.82 .02766 Mdot
.82 .02772 Mdot
.82 .02806 Mdot
.82 .02858 Mdot
.82 .02889 Mdot
.82 .02911 Mdot
.82 .02918 Mdot
.82 .02957 Mdot
.82 .03032 Mdot
.82 .03218 Mdot
.82 .03229 Mdot
.82 .03231 Mdot
.82 .03244 Mdot
.82 .0326 Mdot
.82 .0331 Mdot
.82 .0331 Mdot
.82 .03319 Mdot
.82 .03363 Mdot
.82 .03483 Mdot
.82 .03518 Mdot
.82 .03583 Mdot
.82 .03594 Mdot
.82 .03605 Mdot
.82 .03661 Mdot
.82 .03679 Mdot
.82 .03742 Mdot
.82 .03746 Mdot
.82 .03789 Mdot
.82 .03793 Mdot
.82 .03797 Mdot
.82 .03832 Mdot
.82 .03836 Mdot
.82 .03844 Mdot
.82 .03889 Mdot
.82 .03908 Mdot
.82 .0403 Mdot
.82 .0404 Mdot
.82 .04056 Mdot
.82 .0428 Mdot
.82 .04336 Mdot
.82 .04354 Mdot
.82 .04357 Mdot
.82 .04377 Mdot
.82 .04378 Mdot
.82 .04405 Mdot
.82 .04407 Mdot
.82 .04423 Mdot
.82 .04486 Mdot
.82 .04487 Mdot
.82 .04502 Mdot
.82 .04507 Mdot
.82 .04573 Mdot
.82 .04742 Mdot
.82 .0477 Mdot
.82 .04828 Mdot
.82 .04838 Mdot
.82 .0489 Mdot
.82 .04899 Mdot
.82 .04935 Mdot
.82 .04953 Mdot
.82 .0497 Mdot
.82 .05062 Mdot
.82 .05092 Mdot
.82 .05162 Mdot
.82 .05194 Mdot
.82 .05201 Mdot
.82 .05269 Mdot
.82 .05271 Mdot
.82 .05273 Mdot
.82 .05279 Mdot
.82 .05285 Mdot
.82 .05342 Mdot
.82 .05349 Mdot
.82 .0535 Mdot
.82 .05362 Mdot
.82 .05437 Mdot
.82 .05468 Mdot
.82 .05525 Mdot
.82 .05571 Mdot
.82 .05614 Mdot
.82 .05667 Mdot
.82 .05684 Mdot
.82 .0571 Mdot
.82 .06078 Mdot
.82 .06169 Mdot
.82 .06199 Mdot
.82 .06204 Mdot
.82 .06236 Mdot
.82 .06238 Mdot
.82 .06283 Mdot
.82 .06286 Mdot
.82 .06304 Mdot
.82 .06312 Mdot
.82 .0636 Mdot
.82 .06416 Mdot
.82 .06417 Mdot
.82 .06442 Mdot
.82 .06451 Mdot
.82 .06558 Mdot
.82 .06605 Mdot
.82 .06757 Mdot
.82 .06821 Mdot
.82 .06836 Mdot
.82 .06881 Mdot
.82 .06976 Mdot
.82 .06992 Mdot
.82 .07077 Mdot
.82 .07092 Mdot
.82 .07151 Mdot
.82 .07181 Mdot
.82 .07208 Mdot
.82 .0736 Mdot
.82 .07409 Mdot
.82 .07479 Mdot
.82 .07523 Mdot
.82 .07577 Mdot
.82 .07588 Mdot
.82 .07627 Mdot
.82 .07684 Mdot
.82 .077 Mdot
.82 .07701 Mdot
.82 .07703 Mdot
.82 .07705 Mdot
.82 .07716 Mdot
.82 .07725 Mdot
.82 .07742 Mdot
.82 .07764 Mdot
.82 .07781 Mdot
.82 .0782 Mdot
.82 .0783 Mdot
.82 .07833 Mdot
.82 .07852 Mdot
.82 .07904 Mdot
.82 .07975 Mdot
.82 .08026 Mdot
.82 .08109 Mdot
.82 .0812 Mdot
.82 .08195 Mdot
.82 .08265 Mdot
.82 .08353 Mdot
.82 .08375 Mdot
.82 .0838 Mdot
.82 .08422 Mdot
.82 .08453 Mdot
.82 .08685 Mdot
.82 .087 Mdot
.82 .08711 Mdot
.82 .09026 Mdot
.82 .09064 Mdot
.82 .09129 Mdot
.82 .09176 Mdot
.82 .09224 Mdot
.82 .09233 Mdot
.82 .09286 Mdot
.82 .09287 Mdot
.82 .09289 Mdot
.82 .09362 Mdot
.82 .09368 Mdot
.82 .09396 Mdot
.82 .09411 Mdot
.82 .09427 Mdot
.82 .09489 Mdot
.82 .0951 Mdot
.82 .09513 Mdot
.82 .09517 Mdot
.82 .09529 Mdot
.82 .0958 Mdot
.82 .09582 Mdot
.82 .09623 Mdot
.82 .09637 Mdot
.82 .09814 Mdot
.82 .0989 Mdot
.82 .09921 Mdot
.82 .09944 Mdot
.82 .10056 Mdot
.82 .10099 Mdot
.82 .10122 Mdot
.82 .1014 Mdot
.82 .10161 Mdot
.82 .10166 Mdot
.82 .10245 Mdot
.82 .10269 Mdot
.82 .10307 Mdot
.82 .10344 Mdot
.82 .10411 Mdot
.82 .10434 Mdot
.82 .10449 Mdot
.82 .10487 Mdot
.82 .10498 Mdot
.82 .10526 Mdot
.82 .10526 Mdot
.82 .10665 Mdot
.82 .10689 Mdot
.82 .10786 Mdot
.82 .10835 Mdot
.82 .10843 Mdot
.82 .1088 Mdot
.82 .10976 Mdot
.82 .11128 Mdot
.82 .11129 Mdot
.82 .11149 Mdot
.82 .11173 Mdot
.82 .11182 Mdot
.82 .11209 Mdot
.82 .11266 Mdot
.82 .11306 Mdot
.82 .11323 Mdot
.82 .11396 Mdot
.82 .11484 Mdot
.82 .11502 Mdot
.82 .11567 Mdot
.82 .11639 Mdot
.82 .1165 Mdot
.82 .11659 Mdot
.82 .11686 Mdot
.82 .11687 Mdot
.82 .11692 Mdot
.82 .11695 Mdot
.82 .11713 Mdot
.82 .11727 Mdot
.82 .11756 Mdot
.82 .11791 Mdot
.82 .11797 Mdot
.82 .11818 Mdot
.82 .11883 Mdot
.82 .119 Mdot
.82 .11904 Mdot
.82 .11936 Mdot
.82 .11944 Mdot
.82 .12021 Mdot
.82 .12021 Mdot
.82 .12049 Mdot
.82 .12099 Mdot
.82 .12137 Mdot
.82 .12221 Mdot
.82 .12357 Mdot
.82 .12375 Mdot
.82 .12382 Mdot
.82 .12499 Mdot
.82 .12612 Mdot
.82 .12757 Mdot
.82 .12779 Mdot
.82 .12793 Mdot
.82 .12802 Mdot
.82 .12871 Mdot
.82 .12882 Mdot
.82 .12921 Mdot
.82 .12966 Mdot
.82 .13013 Mdot
.82 .13051 Mdot
.82 .13102 Mdot
.82 .13124 Mdot
.82 .13131 Mdot
.82 .13153 Mdot
.82 .13228 Mdot
.82 .13302 Mdot
.82 .13326 Mdot
.82 .13327 Mdot
.82 .13344 Mdot
.82 .13678 Mdot
.82 .13861 Mdot
.82 .13877 Mdot
.82 .13892 Mdot
.82 .13895 Mdot
.82 .13923 Mdot
.82 .1403 Mdot
.82 .141 Mdot
.82 .14106 Mdot
.82 .14186 Mdot
.82 .14201 Mdot
.82 .14237 Mdot
.82 .14268 Mdot
.82 .14287 Mdot
.82 .14289 Mdot
.82 .14292 Mdot
.82 .1438 Mdot
.82 .14411 Mdot
.82 .14421 Mdot
.82 .14426 Mdot
.82 .14435 Mdot
.82 .14436 Mdot
.82 .14468 Mdot
.82 .14492 Mdot
.82 .14509 Mdot
.82 .14518 Mdot
.82 .1462 Mdot
.82 .14654 Mdot
.82 .14659 Mdot
.82 .14666 Mdot
.82 .14686 Mdot
.82 .1477 Mdot
.82 .14773 Mdot
.82 .14839 Mdot
.82 .14863 Mdot
.82 .15029 Mdot
.82 .15052 Mdot
.82 .15071 Mdot
.82 .15082 Mdot
.82 .1509 Mdot
.82 .15113 Mdot
.82 .15153 Mdot
.82 .15277 Mdot
.82 .15282 Mdot
.82 .15328 Mdot
.82 .15366 Mdot
.82 .15392 Mdot
.82 .15421 Mdot
.82 .15544 Mdot
.82 .15551 Mdot
.82 .15552 Mdot
.82 .15558 Mdot
.82 .15621 Mdot
.82 .15655 Mdot
.82 .15657 Mdot
.82 .15658 Mdot
.82 .15681 Mdot
.82 .15686 Mdot
.82 .15688 Mdot
.82 .15723 Mdot
.82 .1573 Mdot
.82 .15841 Mdot
.82 .15861 Mdot
.82 .15875 Mdot
.82 .15899 Mdot
.82 .15961 Mdot
.82 .16022 Mdot
.82 .16132 Mdot
.82 .16169 Mdot
.82 .16194 Mdot
.82 .16258 Mdot
.82 .16276 Mdot
.82 .16321 Mdot
.82 .16321 Mdot
.82 .16363 Mdot
.82 .16404 Mdot
.82 .1645 Mdot
.82 .16512 Mdot
.82 .16548 Mdot
.82 .16586 Mdot
.82 .16589 Mdot
.82 .16619 Mdot
.82 .16748 Mdot
.82 .16828 Mdot
.82 .16841 Mdot
.82 .16894 Mdot
.82 .16902 Mdot
.82 .17059 Mdot
.82 .17081 Mdot
.82 .17162 Mdot
.82 .17308 Mdot
.82 .17309 Mdot
.82 .17342 Mdot
.82 .1737 Mdot
.82 .17381 Mdot
.82 .17396 Mdot
.82 .17442 Mdot
.82 .17472 Mdot
.82 .17535 Mdot
.82 .17599 Mdot
.82 .17628 Mdot
.82 .17644 Mdot
.82 .17695 Mdot
.82 .17699 Mdot
.82 .17716 Mdot
.82 .17748 Mdot
.82 .17811 Mdot
.82 .17893 Mdot
.82 .1792 Mdot
.82 .17922 Mdot
.82 .18028 Mdot
.82 .18146 Mdot
.82 .18165 Mdot
.82 .1818 Mdot
.82 .18201 Mdot
.82 .18224 Mdot
.82 .18225 Mdot
.82 .18233 Mdot
.82 .18238 Mdot
.82 .18267 Mdot
.82 .1828 Mdot
.82 .18291 Mdot
.82 .18338 Mdot
.82 .18396 Mdot
.82 .18405 Mdot
.82 .18441 Mdot
.82 .18478 Mdot
.82 .18478 Mdot
.82 .18546 Mdot
.82 .18574 Mdot
.82 .18581 Mdot
.82 .18633 Mdot
.82 .18646 Mdot
.82 .18667 Mdot
.82 .18773 Mdot
.82 .18773 Mdot
.82 .18819 Mdot
.82 .18847 Mdot
.82 .189 Mdot
.82 .18963 Mdot
.82 .18981 Mdot
.82 .19047 Mdot
.82 .191 Mdot
.82 .19323 Mdot
.82 .19324 Mdot
.82 .19353 Mdot
.82 .19364 Mdot
.82 .19384 Mdot
.82 .19482 Mdot
.82 .19489 Mdot
.82 .19556 Mdot
.82 .19649 Mdot
.82 .1966 Mdot
.82 .19742 Mdot
.82 .19794 Mdot
.82 .19796 Mdot
.82 .1998 Mdot
.82 .20016 Mdot
.82 .20039 Mdot
.82 .20053 Mdot
.82 .20166 Mdot
.82 .20184 Mdot
.82 .20249 Mdot
.82 .20322 Mdot
.82 .20362 Mdot
.82 .2038 Mdot
.82 .204 Mdot
.82 .20456 Mdot
.82 .20462 Mdot
.82 .20545 Mdot
.82 .20581 Mdot
.82 .20592 Mdot
.82 .20598 Mdot
.82 .2063 Mdot
.82 .20717 Mdot
.82 .20752 Mdot
.82 .20772 Mdot
.82 .20775 Mdot
.82 .20873 Mdot
.82 .20913 Mdot
.82 .20914 Mdot
.82 .20943 Mdot
.82 .21008 Mdot
.82 .21025 Mdot
.82 .21041 Mdot
.82 .21297 Mdot
.82 .21318 Mdot
.82 .21409 Mdot
.82 .21466 Mdot
.82 .2149 Mdot
.82 .21734 Mdot
.82 .2179 Mdot
.82 .21811 Mdot
.82 .21817 Mdot
.82 .21832 Mdot
.82 .2184 Mdot
.82 .21847 Mdot
.82 .21893 Mdot
.82 .21969 Mdot
.82 .22068 Mdot
.82 .22097 Mdot
.82 .22183 Mdot
.82 .22189 Mdot
.82 .22193 Mdot
.82 .22324 Mdot
.82 .22348 Mdot
.82 .22407 Mdot
.82 .22459 Mdot
.82 .22489 Mdot
.82 .22491 Mdot
.82 .22492 Mdot
.82 .22497 Mdot
.82 .22642 Mdot
.82 .22651 Mdot
.82 .22693 Mdot
.82 .22709 Mdot
.82 .22717 Mdot
.82 .22732 Mdot
.82 .22733 Mdot
.82 .22786 Mdot
.82 .22824 Mdot
.82 .22833 Mdot
.82 .22839 Mdot
.82 .22853 Mdot
.82 .22867 Mdot
.82 .22985 Mdot
.82 .23035 Mdot
.82 .23091 Mdot
.82 .23099 Mdot
.82 .23108 Mdot
.82 .23111 Mdot
.82 .23143 Mdot
.82 .23157 Mdot
.82 .23281 Mdot
.82 .23285 Mdot
.82 .2334 Mdot
.82 .23395 Mdot
.82 .23423 Mdot
.82 .23434 Mdot
.82 .23452 Mdot
.82 .23557 Mdot
.82 .23705 Mdot
.82 .23743 Mdot
.82 .23774 Mdot
.82 .23792 Mdot
.82 .23806 Mdot
.82 .23825 Mdot
.82 .23833 Mdot
.82 .23836 Mdot
.82 .23844 Mdot
.82 .23872 Mdot
.82 .23908 Mdot
.82 .24039 Mdot
.82 .24113 Mdot
.82 .24119 Mdot
.82 .2412 Mdot
.82 .24196 Mdot
.82 .24247 Mdot
.82 .24259 Mdot
.82 .243 Mdot
.82 .24317 Mdot
.82 .24321 Mdot
.82 .24321 Mdot
.82 .24348 Mdot
.82 .24541 Mdot
.82 .2455 Mdot
.82 .24557 Mdot
.82 .24561 Mdot
.82 .24564 Mdot
.82 .24573 Mdot
.82 .24635 Mdot
.82 .24676 Mdot
.82 .24687 Mdot
.82 .24733 Mdot
.82 .24736 Mdot
.82 .24738 Mdot
.82 .24774 Mdot
.82 .24775 Mdot
.82 .24784 Mdot
.82 .24786 Mdot
.82 .24844 Mdot
.82 .24856 Mdot
.82 .25038 Mdot
.82 .25053 Mdot
.82 .2507 Mdot
.82 .25093 Mdot
.82 .2512 Mdot
.82 .25133 Mdot
.82 .25235 Mdot
.82 .25304 Mdot
.82 .25335 Mdot
.82 .25412 Mdot
.82 .2545 Mdot
.82 .25514 Mdot
.82 .25533 Mdot
.82 .25534 Mdot
.82 .25541 Mdot
.82 .25576 Mdot
.82 .25617 Mdot
.82 .25721 Mdot
.82 .2575 Mdot
.82 .25824 Mdot
.82 .25824 Mdot
.82 .25894 Mdot
.82 .25961 Mdot
.82 .26011 Mdot
.82 .26035 Mdot
.82 .26138 Mdot
.82 .26161 Mdot
.82 .26197 Mdot
.82 .262 Mdot
.82 .26259 Mdot
.82 .26263 Mdot
.82 .26313 Mdot
.82 .26314 Mdot
.82 .26524 Mdot
.82 .26531 Mdot
.82 .26559 Mdot
.82 .26612 Mdot
.82 .26656 Mdot
.82 .26677 Mdot
.82 .26678 Mdot
.82 .26765 Mdot
.82 .26771 Mdot
.82 .26777 Mdot
.82 .26872 Mdot
.82 .2688 Mdot
.82 .26914 Mdot
.82 .26935 Mdot
.82 .27035 Mdot
.82 .27063 Mdot
.82 .27071 Mdot
.82 .27122 Mdot
.82 .27169 Mdot
.82 .27203 Mdot
.82 .27375 Mdot
.82 .27443 Mdot
.82 .27445 Mdot
.82 .275 Mdot
.82 .27545 Mdot
.82 .27564 Mdot
.82 .27632 Mdot
.82 .27663 Mdot
.82 .27673 Mdot
.82 .27712 Mdot
.82 .27812 Mdot
.82 .27815 Mdot
.82 .27816 Mdot
.82 .27829 Mdot
.82 .27892 Mdot
.82 .27921 Mdot
.82 .27969 Mdot
.82 .27995 Mdot
.82 .27996 Mdot
.82 .27996 Mdot
.82 .28078 Mdot
.82 .28084 Mdot
.82 .28113 Mdot
.82 .28132 Mdot
.82 .28165 Mdot
.82 .28268 Mdot
.82 .28294 Mdot
.82 .28362 Mdot
.82 .28402 Mdot
.82 .28416 Mdot
.82 .28447 Mdot
.82 .28447 Mdot
.82 .2845 Mdot
.82 .28625 Mdot
.82 .2868 Mdot
.82 .28695 Mdot
.82 .28737 Mdot
.82 .28818 Mdot
.82 .28829 Mdot
.82 .28848 Mdot
.82 .28873 Mdot
.82 .28907 Mdot
.82 .28945 Mdot
.82 .28948 Mdot
.82 .2896 Mdot
.82 .28968 Mdot
.82 .29016 Mdot
.82 .29038 Mdot
.82 .29055 Mdot
.82 .29132 Mdot
.82 .29227 Mdot
.82 .29243 Mdot
.82 .29294 Mdot
.82 .29295 Mdot
.82 .29301 Mdot
.82 .29324 Mdot
.82 .29363 Mdot
.82 .29363 Mdot
.82 .29413 Mdot
.82 .29473 Mdot
.82 .29499 Mdot
.82 .29519 Mdot
.82 .2953 Mdot
.82 .29617 Mdot
.82 .29623 Mdot
.82 .29638 Mdot
.82 .29672 Mdot
.82 .29845 Mdot
.82 .29846 Mdot
.82 .29856 Mdot
.82 .2989 Mdot
.82 .29921 Mdot
.82 .29967 Mdot
.82 .30054 Mdot
.82 .30067 Mdot
.82 .30133 Mdot
.82 .30157 Mdot
.82 .30187 Mdot
.82 .30212 Mdot
.82 .3028 Mdot
.82 .30295 Mdot
.82 .30383 Mdot
.82 .30464 Mdot
.82 .30505 Mdot
.82 .30739 Mdot
.82 .30748 Mdot
.82 .3075 Mdot
.82 .30797 Mdot
.82 .30816 Mdot
.82 .30848 Mdot
.82 .30958 Mdot
.82 .31009 Mdot
.82 .31021 Mdot
.82 .31067 Mdot
.82 .3113 Mdot
.82 .31283 Mdot
.82 .31301 Mdot
.82 .31436 Mdot
.82 .31521 Mdot
.82 .31523 Mdot
.82 .31699 Mdot
.82 .31723 Mdot
.82 .31727 Mdot
.82 .31825 Mdot
.82 .31854 Mdot
.82 .31885 Mdot
.82 .31904 Mdot
.82 .31922 Mdot
.82 .31946 Mdot
.82 .31991 Mdot
.82 .3213 Mdot
.82 .32161 Mdot
.82 .32266 Mdot
.82 .32287 Mdot
.82 .32386 Mdot
.82 .32424 Mdot
.82 .32452 Mdot
.82 .32455 Mdot
.82 .32481 Mdot
.82 .32514 Mdot
.82 .32606 Mdot
.82 .32615 Mdot
.82 .32752 Mdot
.82 .32811 Mdot
.82 .3283 Mdot
.82 .32839 Mdot
.82 .32891 Mdot
.82 .33034 Mdot
.82 .33092 Mdot
.82 .33124 Mdot
.82 .33129 Mdot
.82 .3329 Mdot
.82 .33355 Mdot
.82 .33357 Mdot
.82 .33405 Mdot
.82 .33511 Mdot
.82 .3354 Mdot
.82 .33565 Mdot
.82 .33986 Mdot
.82 .3402 Mdot
.82 .3417 Mdot
.82 .34263 Mdot
.82 .34302 Mdot
.82 .34703 Mdot
.82 .34793 Mdot
.82 .34827 Mdot
.82 .34838 Mdot
.82 .34863 Mdot
.82 .34876 Mdot
.82 .34887 Mdot
.82 .34962 Mdot
.82 .35087 Mdot
.82 .35249 Mdot
.82 .35297 Mdot
.82 .35438 Mdot
.82 .35447 Mdot
.82 .35454 Mdot
.82 .35669 Mdot
.82 .35709 Mdot
.82 .35805 Mdot
.82 .3589 Mdot
.82 .35941 Mdot
.82 .35943 Mdot
.82 .35945 Mdot
.82 .35953 Mdot
.82 .36192 Mdot
.82 .36206 Mdot
.82 .36274 Mdot
.82 .363 Mdot
.82 .36314 Mdot
.82 .36338 Mdot
.82 .36341 Mdot
.82 .36427 Mdot
.82 .3649 Mdot
.82 .36504 Mdot
.82 .36514 Mdot
.82 .36537 Mdot
.82 .36561 Mdot
.82 .36754 Mdot
.82 .36835 Mdot
.82 .36928 Mdot
.82 .3694 Mdot
.82 .36955 Mdot
.82 .3696 Mdot
.82 .37012 Mdot
.82 .37036 Mdot
.82 .37239 Mdot
.82 .37246 Mdot
.82 .37336 Mdot
.82 .37425 Mdot
.82 .37472 Mdot
.82 .37489 Mdot
.82 .3752 Mdot
.82 .37692 Mdot
.82 .37935 Mdot
.82 .37997 Mdot
.82 .38048 Mdot
.82 .38077 Mdot
.82 .381 Mdot
.82 .38131 Mdot
.82 .38145 Mdot
.82 .38149 Mdot
.82 .38163 Mdot
.82 .38208 Mdot
.82 .38268 Mdot
.82 .38483 Mdot
.82 .38604 Mdot
.82 .38613 Mdot
.82 .38615 Mdot
.82 .3874 Mdot
.82 .38823 Mdot
.82 .38843 Mdot
.82 .38911 Mdot
.82 .38939 Mdot
.82 .38944 Mdot
.82 .38945 Mdot
.82 .38989 Mdot
.82 .39306 Mdot
.82 .3932 Mdot
.82 .39332 Mdot
.82 .39338 Mdot
.82 .39344 Mdot
.82 .39358 Mdot
.82 .3946 Mdot
.82 .39527 Mdot
.82 .39545 Mdot
.82 .3962 Mdot
.82 .39626 Mdot
.82 .39629 Mdot
.82 .39688 Mdot
.82 .39689 Mdot
.82 .39704 Mdot
.82 .39707 Mdot
.82 .39802 Mdot
.82 .39822 Mdot
.82 .4012 Mdot
.82 .40145 Mdot
.82 .40173 Mdot
.82 .40211 Mdot
.82 .40256 Mdot
.82 .40276 Mdot
.82 .40444 Mdot
.82 .40558 Mdot
.82 .40607 Mdot
.82 .40734 Mdot
.82 .40796 Mdot
.82 .40901 Mdot
.82 .40932 Mdot
.82 .40934 Mdot
.82 .40945 Mdot
.82 .41003 Mdot
.82 .41069 Mdot
.82 .4124 Mdot
.82 .41289 Mdot
.82 .4141 Mdot
.82 .4141 Mdot
.82 .41525 Mdot
.82 .41634 Mdot
.82 .41716 Mdot
.82 .41756 Mdot
.82 .41925 Mdot
.82 .41962 Mdot
.82 .42022 Mdot
.82 .42026 Mdot
.82 .42123 Mdot
.82 .4213 Mdot
.82 .42212 Mdot
.82 .42213 Mdot
.82 .42558 Mdot
.82 .42569 Mdot
.82 .42615 Mdot
.82 .42702 Mdot
.82 .42775 Mdot
.82 .42808 Mdot
.82 .4281 Mdot
.82 .42952 Mdot
.82 .42963 Mdot
.82 .42972 Mdot
.82 .43129 Mdot
.82 .43141 Mdot
.82 .43197 Mdot
.82 .43231 Mdot
.82 .43395 Mdot
.82 .43441 Mdot
.82 .43455 Mdot
.82 .43538 Mdot
.82 .43616 Mdot
.82 .43672 Mdot
.82 .43954 Mdot
.82 .44065 Mdot
.82 .44068 Mdot
.82 .44158 Mdot
.82 .44232 Mdot
.82 .44263 Mdot
.82 .44374 Mdot
.82 .44425 Mdot
.82 .44442 Mdot
.82 .44507 Mdot
.82 .4467 Mdot
.82 .44675 Mdot
.82 .44676 Mdot
.82 .44698 Mdot
.82 .448 Mdot
.82 .44849 Mdot
.82 .44927 Mdot
.82 .4497 Mdot
.82 .44972 Mdot
.82 .44972 Mdot
.82 .45107 Mdot
.82 .45116 Mdot
.82 .45164 Mdot
.82 .45196 Mdot
.82 .45249 Mdot
.82 .45418 Mdot
.82 .4546 Mdot
.82 .45572 Mdot
.82 .45637 Mdot
.82 .45661 Mdot
.82 .45711 Mdot
.82 .45712 Mdot
.82 .45716 Mdot
.82 .46003 Mdot
.82 .46094 Mdot
.82 .46118 Mdot
.82 .46187 Mdot
.82 .4632 Mdot
.82 .46337 Mdot
.82 .46369 Mdot
.82 .46409 Mdot
.82 .46466 Mdot
.82 .46528 Mdot
.82 .46533 Mdot
.82 .46553 Mdot
.82 .46566 Mdot
.82 .46644 Mdot
.82 .4668 Mdot
.82 .46709 Mdot
.82 .46835 Mdot
.82 .46991 Mdot
.82 .47016 Mdot
.82 .47101 Mdot
.82 .47103 Mdot
.82 .47112 Mdot
.82 .47149 Mdot
.82 .47213 Mdot
.82 .47213 Mdot
.82 .47296 Mdot
.82 .47395 Mdot
.82 .47436 Mdot
.82 .47469 Mdot
.82 .47488 Mdot
.82 .4763 Mdot
.82 .47639 Mdot
.82 .47665 Mdot
.82 .47721 Mdot
.82 .48005 Mdot
.82 .48005 Mdot
.82 .48023 Mdot
.82 .48077 Mdot
.82 .48129 Mdot
.82 .48205 Mdot
.82 .48347 Mdot
.82 .48368 Mdot
.82 .48476 Mdot
.82 .48516 Mdot
.82 .48564 Mdot
.82 .48606 Mdot
.82 .48718 Mdot
.82 .48743 Mdot
.82 .48886 Mdot
.82 .49019 Mdot
.82 .49086 Mdot
.82 .49471 Mdot
.82 .49486 Mdot
.82 .49488 Mdot
.82 .49565 Mdot
.82 .49596 Mdot
.82 .49649 Mdot
.82 .4983 Mdot
.82 .49913 Mdot
.82 .49932 Mdot
.822 .01472 Mdot
.822 .01472 Mdot
.822 .01472 Mdot
.822 .01472 Mdot
.822 .01472 Mdot
.822 .01473 Mdot
.822 .01474 Mdot
.822 .01476 Mdot
.822 .01479 Mdot
.822 .01483 Mdot
.822 .0149 Mdot
.822 .015 Mdot
.822 .01503 Mdot
.822 .01509 Mdot
.822 .01518 Mdot
.822 .01523 Mdot
.822 .01533 Mdot
.822 .01548 Mdot
.822 .01556 Mdot
.822 .01563 Mdot
.822 .01572 Mdot
.822 .01597 Mdot
.822 .0161 Mdot
.822 .01621 Mdot
.822 .01637 Mdot
.822 .01675 Mdot
.822 .01678 Mdot
.822 .01699 Mdot
.822 .01718 Mdot
.822 .01741 Mdot
.822 .01744 Mdot
.822 .01784 Mdot
.822 .01806 Mdot
.822 .0181 Mdot
.822 .01846 Mdot
.822 .01846 Mdot
.822 .01856 Mdot
.822 .01876 Mdot
.822 .01915 Mdot
.822 .01919 Mdot
.822 .01985 Mdot
.822 .02 Mdot
.822 .02021 Mdot
.822 .02028 Mdot
.822 .02029 Mdot
.822 .02087 Mdot
.822 .02088 Mdot
.822 .02104 Mdot
.822 .02137 Mdot
.822 .02173 Mdot
.822 .02201 Mdot
.822 .02207 Mdot
.822 .02265 Mdot
.822 .02309 Mdot
.822 .02316 Mdot
.822 .0234 Mdot
.822 .02376 Mdot
.822 .02386 Mdot
.822 .02388 Mdot
.822 .02444 Mdot
.822 .02473 Mdot
.822 .02483 Mdot
.822 .02485 Mdot
.822 .02511 Mdot
.822 .02519 Mdot
.822 .02565 Mdot
.822 .02566 Mdot
.822 .02625 Mdot
.822 .0267 Mdot
.822 .0268 Mdot
.822 .02776 Mdot
.822 .02848 Mdot
.822 .02859 Mdot
.822 .02862 Mdot
.822 .0287 Mdot
.822 .02899 Mdot
.822 .02908 Mdot
.822 .02953 Mdot
.822 .02958 Mdot
.822 .02968 Mdot
.822 .0297 Mdot
.822 .02975 Mdot
.822 .02977 Mdot
.822 .02999 Mdot
.822 .0307 Mdot
.822 .03119 Mdot
.822 .03134 Mdot
.822 .03137 Mdot
.822 .03142 Mdot
.822 .0318 Mdot
.822 .03189 Mdot
.822 .03193 Mdot
.822 .03269 Mdot
.822 .0327 Mdot
.822 .03295 Mdot
.822 .03313 Mdot
.822 .03333 Mdot
.822 .03367 Mdot
.822 .03392 Mdot
.822 .03438 Mdot
.822 .03442 Mdot
.822 .03459 Mdot
.822 .03616 Mdot
.822 .03623 Mdot
.822 .03735 Mdot
.822 .03753 Mdot
.822 .03757 Mdot
.822 .0377 Mdot
.822 .03818 Mdot
.822 .03833 Mdot
.822 .0386 Mdot
.822 .03887 Mdot
.822 .03906 Mdot
.822 .03915 Mdot
.822 .03932 Mdot
.822 .03936 Mdot
.822 .03944 Mdot
.822 .03947 Mdot
.822 .03983 Mdot
.822 .04081 Mdot
.822 .041 Mdot
.822 .04128 Mdot
.822 .04129 Mdot
.822 .0418 Mdot
.822 .04205 Mdot
.822 .0421 Mdot
.822 .04213 Mdot
.822 .04217 Mdot
.822 .0428 Mdot
.822 .04295 Mdot
.822 .04302 Mdot
.822 .04303 Mdot
.822 .04321 Mdot
.822 .04379 Mdot
.822 .04426 Mdot
.822 .04428 Mdot
.822 .04469 Mdot
.822 .04499 Mdot
.822 .0451 Mdot
.822 .04512 Mdot
.822 .04532 Mdot
.822 .04588 Mdot
.822 .04629 Mdot
.822 .04673 Mdot
.822 .04704 Mdot
.822 .04711 Mdot
.822 .04738 Mdot
.822 .04756 Mdot
.822 .04937 Mdot
.822 .04997 Mdot
.822 .05009 Mdot
.822 .05192 Mdot
.822 .05193 Mdot
.822 .05222 Mdot
.822 .05224 Mdot
.822 .05229 Mdot
.822 .0525 Mdot
.822 .05315 Mdot
.822 .05325 Mdot
.822 .0533 Mdot
.822 .0535 Mdot
.822 .05354 Mdot
.822 .05399 Mdot
.822 .05443 Mdot
.822 .05474 Mdot
.822 .05489 Mdot
.822 .05516 Mdot
.822 .05522 Mdot
.822 .05536 Mdot
.822 .05542 Mdot
.822 .05551 Mdot
.822 .056 Mdot
.822 .05673 Mdot
.822 .05761 Mdot
.822 .05772 Mdot
.822 .05793 Mdot
.822 .05839 Mdot
.822 .0584 Mdot
.822 .05923 Mdot
.822 .05959 Mdot
.822 .05965 Mdot
.822 .05973 Mdot
.822 .05978 Mdot
.822 .05986 Mdot
.822 .06089 Mdot
.822 .06113 Mdot
.822 .06125 Mdot
.822 .06127 Mdot
.822 .06156 Mdot
.822 .06194 Mdot
.822 .06251 Mdot
.822 .06262 Mdot
.822 .06325 Mdot
.822 .06329 Mdot
.822 .06332 Mdot
.822 .06399 Mdot
.822 .06407 Mdot
.822 .06436 Mdot
.822 .06449 Mdot
.822 .06467 Mdot
.822 .06471 Mdot
.822 .06503 Mdot
.822 .06595 Mdot
.822 .06627 Mdot
.822 .06662 Mdot
.822 .06687 Mdot
.822 .06735 Mdot
.822 .06757 Mdot
.822 .06786 Mdot
.822 .06797 Mdot
.822 .06826 Mdot
.822 .06842 Mdot
.822 .06871 Mdot
.822 .06921 Mdot
.822 .06984 Mdot
.822 .07073 Mdot
.822 .07169 Mdot
.822 .07267 Mdot
.822 .0727 Mdot
.822 .07286 Mdot
.822 .07332 Mdot
.822 .07533 Mdot
.822 .07588 Mdot
.822 .0759 Mdot
.822 .07638 Mdot
.822 .0764 Mdot
.822 .07648 Mdot
.822 .07683 Mdot
.822 .0779 Mdot
.822 .07807 Mdot
.822 .07814 Mdot
.822 .07847 Mdot
.822 .07854 Mdot
.822 .07872 Mdot
.822 .07928 Mdot
.822 .08 Mdot
.822 .08052 Mdot
.822 .08076 Mdot
.822 .0812 Mdot
.822 .08131 Mdot
.822 .08154 Mdot
.822 .08163 Mdot
.822 .08179 Mdot
.822 .08222 Mdot
.822 .08259 Mdot
.822 .08316 Mdot
.822 .08378 Mdot
.822 .08524 Mdot
.822 .08542 Mdot
.822 .08542 Mdot
.822 .08576 Mdot
.822 .086 Mdot
.822 .0864 Mdot
.822 .08652 Mdot
.822 .08654 Mdot
.822 .08685 Mdot
.822 .08701 Mdot
.822 .0874 Mdot
.822 .08773 Mdot
.822 .08791 Mdot
.822 .0885 Mdot
.822 .08859 Mdot
.822 .08872 Mdot
.822 .08881 Mdot
.822 .08893 Mdot
.822 .09063 Mdot
.822 .09102 Mdot
.822 .09116 Mdot
.822 .09121 Mdot
.822 .09126 Mdot
.822 .09173 Mdot
.822 .09235 Mdot
.822 .09329 Mdot
.822 .09347 Mdot
.822 .09451 Mdot
.822 .09457 Mdot
.822 .09463 Mdot
.822 .09572 Mdot
.822 .09575 Mdot
.822 .09585 Mdot
.822 .09591 Mdot
.822 .09633 Mdot
.822 .09655 Mdot
.822 .09684 Mdot
.822 .0969 Mdot
.822 .09698 Mdot
.822 .09743 Mdot
.822 .09883 Mdot
.822 .09894 Mdot
.822 .09897 Mdot
.822 .09947 Mdot
.822 .10005 Mdot
.822 .10046 Mdot
.822 .10124 Mdot
.822 .1016 Mdot
.822 .10208 Mdot
.822 .1022 Mdot
.822 .10227 Mdot
.822 .10237 Mdot
.822 .10258 Mdot
.822 .1026 Mdot
.822 .10274 Mdot
.822 .103 Mdot
.822 .10348 Mdot
.822 .1035 Mdot
.822 .10389 Mdot
.822 .10431 Mdot
.822 .10528 Mdot
.822 .10533 Mdot
.822 .10675 Mdot
.822 .10681 Mdot
.822 .10838 Mdot
.822 .10999 Mdot
.822 .11005 Mdot
.822 .11031 Mdot
.822 .11107 Mdot
.822 .11151 Mdot
.822 .11197 Mdot
.822 .11237 Mdot
.822 .11326 Mdot
.822 .11437 Mdot
.822 .11526 Mdot
.822 .11527 Mdot
.822 .1153 Mdot
.822 .11609 Mdot
.822 .11613 Mdot
.822 .11626 Mdot
.822 .11684 Mdot
.822 .11706 Mdot
.822 .11858 Mdot
.822 .11886 Mdot
.822 .11899 Mdot
.822 .11953 Mdot
.822 .11964 Mdot
.822 .11968 Mdot
.822 .11994 Mdot
.822 .12037 Mdot
.822 .12053 Mdot
.822 .12086 Mdot
.822 .12132 Mdot
.822 .12176 Mdot
.822 .12205 Mdot
.822 .1222 Mdot
.822 .1229 Mdot
.822 .12329 Mdot
.822 .12402 Mdot
.822 .1242 Mdot
.822 .12457 Mdot
.822 .12472 Mdot
.822 .12482 Mdot
.822 .12498 Mdot
.822 .1253 Mdot
.822 .12569 Mdot
.822 .1259 Mdot
.822 .1263 Mdot
.822 .12637 Mdot
.822 .12724 Mdot
.822 .12826 Mdot
.822 .12854 Mdot
.822 .12896 Mdot
.822 .12949 Mdot
.822 .12955 Mdot
.822 .13066 Mdot
.822 .13095 Mdot
.822 .13096 Mdot
.822 .13151 Mdot
.822 .13192 Mdot
.822 .13256 Mdot
.822 .13276 Mdot
.822 .13279 Mdot
.822 .13284 Mdot
.822 .1333 Mdot
.822 .13357 Mdot
.822 .13422 Mdot
.822 .13474 Mdot
.822 .1349 Mdot
.822 .13504 Mdot
.822 .13585 Mdot
.822 .13601 Mdot
.822 .13617 Mdot
.822 .13638 Mdot
.822 .13652 Mdot
.822 .13672 Mdot
.822 .13717 Mdot
.822 .13852 Mdot
.822 .13952 Mdot
.822 .14016 Mdot
.822 .14039 Mdot
.822 .14048 Mdot
.822 .14055 Mdot
.822 .14132 Mdot
.822 .14235 Mdot
.822 .14308 Mdot
.822 .14389 Mdot
.822 .14389 Mdot
.822 .1441 Mdot
.822 .14419 Mdot
.822 .14483 Mdot
.822 .1459 Mdot
.822 .146 Mdot
.822 .14609 Mdot
.822 .14674 Mdot
.822 .14774 Mdot
.822 .14789 Mdot
.822 .14793 Mdot
.822 .14811 Mdot
.822 .14821 Mdot
.822 .1489 Mdot
.822 .14924 Mdot
.822 .14973 Mdot
.822 .14983 Mdot
.822 .14996 Mdot
.822 .1507 Mdot
.822 .15167 Mdot
.822 .15198 Mdot
.822 .153 Mdot
.822 .15319 Mdot
.822 .15323 Mdot
.822 .15383 Mdot
.822 .15405 Mdot
.822 .15494 Mdot
.822 .15501 Mdot
.822 .15567 Mdot
.822 .15697 Mdot
.822 .15756 Mdot
.822 .15835 Mdot
.822 .15854 Mdot
.822 .15865 Mdot
.822 .15881 Mdot
.822 .15917 Mdot
.822 .15919 Mdot
.822 .15942 Mdot
.822 .15986 Mdot
.822 .16045 Mdot
.822 .16064 Mdot
.822 .16067 Mdot
.822 .16068 Mdot
.822 .16132 Mdot
.822 .16201 Mdot
.822 .1633 Mdot
.822 .16361 Mdot
.822 .16369 Mdot
.822 .16371 Mdot
.822 .16547 Mdot
.822 .16583 Mdot
.822 .16602 Mdot
.822 .16611 Mdot
.822 .16681 Mdot
.822 .16769 Mdot
.822 .16817 Mdot
.822 .1687 Mdot
.822 .16889 Mdot
.822 .17048 Mdot
.822 .17056 Mdot
.822 .17136 Mdot
.822 .17144 Mdot
.822 .1716 Mdot
.822 .17188 Mdot
.822 .17312 Mdot
.822 .17354 Mdot
.822 .17385 Mdot
.822 .1746 Mdot
.822 .17618 Mdot
.822 .17673 Mdot
.822 .177 Mdot
.822 .17715 Mdot
.822 .17718 Mdot
.822 .17855 Mdot
.822 .18001 Mdot
.822 .18003 Mdot
.822 .18004 Mdot
.822 .18008 Mdot
.822 .18138 Mdot
.822 .18144 Mdot
.822 .18165 Mdot
.822 .18227 Mdot
.822 .18261 Mdot
.822 .18298 Mdot
.822 .18311 Mdot
.822 .1833 Mdot
.822 .18548 Mdot
.822 .18593 Mdot
.822 .18614 Mdot
.822 .18703 Mdot
.822 .18721 Mdot
.822 .18727 Mdot
.822 .18771 Mdot
.822 .18841 Mdot
.822 .18868 Mdot
.822 .18884 Mdot
.822 .18922 Mdot
.822 .18997 Mdot
.822 .19019 Mdot
.822 .19056 Mdot
.822 .19065 Mdot
.822 .1907 Mdot
.822 .19117 Mdot
.822 .19142 Mdot
.822 .19258 Mdot
.822 .19321 Mdot
.822 .19441 Mdot
.822 .19471 Mdot
.822 .19532 Mdot
.822 .19557 Mdot
.822 .19573 Mdot
.822 .19599 Mdot
.822 .19652 Mdot
.822 .19716 Mdot
.822 .19751 Mdot
.822 .19817 Mdot
.822 .19828 Mdot
.822 .19844 Mdot
.822 .19861 Mdot
.822 .19971 Mdot
.822 .19988 Mdot
.822 .20005 Mdot
.822 .20011 Mdot
.822 .20022 Mdot
.822 .20075 Mdot
.822 .20092 Mdot
.822 .20132 Mdot
.822 .20138 Mdot
.822 .20184 Mdot
.822 .20253 Mdot
.822 .20341 Mdot
.822 .20351 Mdot
.822 .20422 Mdot
.822 .2044 Mdot
.822 .20533 Mdot
.822 .20581 Mdot
.822 .20582 Mdot
.822 .20642 Mdot
.822 .20672 Mdot
.822 .20739 Mdot
.822 .20834 Mdot
.822 .20845 Mdot
.822 .20879 Mdot
.822 .20883 Mdot
.822 .20892 Mdot
.822 .20966 Mdot
.822 .21011 Mdot
.822 .21048 Mdot
.822 .21117 Mdot
.822 .21204 Mdot
.822 .21229 Mdot
.822 .21253 Mdot
.822 .21283 Mdot
.822 .21294 Mdot
.822 .21364 Mdot
.822 .21387 Mdot
.822 .21412 Mdot
.822 .21438 Mdot
.822 .21473 Mdot
.822 .21496 Mdot
.822 .2153 Mdot
.822 .21603 Mdot
.822 .21625 Mdot
.822 .217 Mdot
.822 .21825 Mdot
.822 .21955 Mdot
.822 .2199 Mdot
.822 .22073 Mdot
.822 .22095 Mdot
.822 .22109 Mdot
.822 .22126 Mdot
.822 .22132 Mdot
.822 .22146 Mdot
.822 .22158 Mdot
.822 .22285 Mdot
.822 .22455 Mdot
.822 .22461 Mdot
.822 .22501 Mdot
.822 .22569 Mdot
.822 .22574 Mdot
.822 .22694 Mdot
.822 .227 Mdot
.822 .22708 Mdot
.822 .22709 Mdot
.822 .22742 Mdot
.822 .22757 Mdot
.822 .22808 Mdot
.822 .22862 Mdot
.822 .23038 Mdot
.822 .23055 Mdot
.822 .2307 Mdot
.822 .23103 Mdot
.822 .23177 Mdot
.822 .23244 Mdot
.822 .2334 Mdot
.822 .23366 Mdot
.822 .23372 Mdot
.822 .23401 Mdot
.822 .23418 Mdot
.822 .23434 Mdot
.822 .23531 Mdot
.822 .23549 Mdot
.822 .23571 Mdot
.822 .23588 Mdot
.822 .23668 Mdot
.822 .23684 Mdot
.822 .23704 Mdot
.822 .23706 Mdot
.822 .23828 Mdot
.822 .23904 Mdot
.822 .23939 Mdot
.822 .23988 Mdot
.822 .24038 Mdot
.822 .24206 Mdot
.822 .24237 Mdot
.822 .24244 Mdot
.822 .24271 Mdot
.822 .24342 Mdot
.822 .24379 Mdot
.822 .24524 Mdot
.822 .24536 Mdot
.822 .24604 Mdot
.822 .24645 Mdot
.822 .24849 Mdot
.822 .24858 Mdot
.822 .24955 Mdot
.822 .2497 Mdot
.822 .25035 Mdot
.822 .25048 Mdot
.822 .25084 Mdot
.822 .25117 Mdot
.822 .25135 Mdot
.822 .25161 Mdot
.822 .2522 Mdot
.822 .25223 Mdot
.822 .25262 Mdot
.822 .25334 Mdot
.822 .25431 Mdot
.822 .25461 Mdot
.822 .25467 Mdot
.822 .25468 Mdot
.822 .25574 Mdot
.822 .25656 Mdot
.822 .25687 Mdot
.822 .25695 Mdot
.822 .25899 Mdot
.822 .25949 Mdot
.822 .25963 Mdot
.822 .25966 Mdot
.822 .26255 Mdot
.822 .26261 Mdot
.822 .26308 Mdot
.822 .26314 Mdot
.822 .26316 Mdot
.822 .26321 Mdot
.822 .2634 Mdot
.822 .26347 Mdot
.822 .26361 Mdot
.822 .26469 Mdot
.822 .26475 Mdot
.822 .2655 Mdot
.822 .26621 Mdot
.822 .267 Mdot
.822 .26787 Mdot
.822 .26817 Mdot
.822 .26914 Mdot
.822 .26941 Mdot
.822 .27036 Mdot
.822 .27079 Mdot
.822 .27093 Mdot
.822 .27099 Mdot
.822 .27223 Mdot
.822 .27238 Mdot
.822 .27263 Mdot
.822 .27309 Mdot
.822 .27311 Mdot
.822 .27351 Mdot
.822 .27461 Mdot
.822 .27513 Mdot
.822 .27583 Mdot
.822 .27625 Mdot
.822 .27634 Mdot
.822 .27683 Mdot
.822 .27757 Mdot
.822 .2777 Mdot
.822 .27893 Mdot
.822 .28016 Mdot
.822 .28107 Mdot
.822 .28151 Mdot
.822 .28175 Mdot
.822 .2818 Mdot
.822 .28405 Mdot
.822 .28419 Mdot
.822 .28629 Mdot
.822 .28646 Mdot
.822 .28649 Mdot
.822 .28651 Mdot
.822 .28658 Mdot
.822 .28706 Mdot
.822 .28736 Mdot
.822 .28871 Mdot
.822 .28881 Mdot
.822 .28916 Mdot
.822 .28939 Mdot
.822 .29018 Mdot
.822 .29032 Mdot
.822 .29073 Mdot
.822 .29134 Mdot
.822 .29155 Mdot
.822 .29187 Mdot
.822 .29233 Mdot
.822 .29428 Mdot
.822 .29505 Mdot
.822 .29534 Mdot
.822 .29545 Mdot
.822 .2962 Mdot
.822 .29654 Mdot
.822 .29728 Mdot
.822 .29801 Mdot
.822 .29829 Mdot
.822 .2984 Mdot
.822 .29912 Mdot
.822 .30027 Mdot
.822 .3004 Mdot
.822 .30071 Mdot
.822 .30074 Mdot
.822 .30097 Mdot
.822 .30159 Mdot
.822 .30159 Mdot
.822 .30167 Mdot
.822 .30229 Mdot
.822 .30284 Mdot
.822 .30319 Mdot
.822 .30381 Mdot
.822 .30395 Mdot
.822 .30397 Mdot
.822 .30397 Mdot
.822 .30403 Mdot
.822 .30418 Mdot
.822 .30481 Mdot
.822 .30522 Mdot
.822 .30585 Mdot
.822 .30712 Mdot
.822 .30734 Mdot
.822 .30816 Mdot
.822 .30829 Mdot
.822 .30995 Mdot
.822 .31014 Mdot
.822 .31034 Mdot
.822 .31038 Mdot
.822 .3104 Mdot
.822 .31057 Mdot
.822 .31062 Mdot
.822 .31095 Mdot
.822 .31163 Mdot
.822 .31204 Mdot
.822 .3123 Mdot
.822 .31268 Mdot
.822 .31274 Mdot
.822 .31361 Mdot
.822 .31378 Mdot
.822 .31466 Mdot
.822 .31522 Mdot
.822 .31549 Mdot
.822 .31631 Mdot
.822 .31649 Mdot
.822 .31677 Mdot
.822 .31705 Mdot
.822 .31885 Mdot
.822 .3189 Mdot
.822 .31913 Mdot
.822 .3194 Mdot
.822 .3195 Mdot
.822 .31951 Mdot
.822 .31969 Mdot
.822 .32056 Mdot
.822 .32084 Mdot
.822 .32149 Mdot
.822 .3216 Mdot
.822 .32172 Mdot
.822 .32208 Mdot
.822 .32236 Mdot
.822 .32348 Mdot
.822 .32493 Mdot
.822 .32509 Mdot
.822 .32627 Mdot
.822 .32656 Mdot
.822 .32656 Mdot
.822 .32707 Mdot
.822 .32762 Mdot
.822 .32773 Mdot
.822 .32808 Mdot
.822 .32888 Mdot
.822 .32889 Mdot
.822 .32987 Mdot
.822 .33037 Mdot
.822 .33148 Mdot
.822 .33303 Mdot
.822 .33322 Mdot
.822 .33377 Mdot
.822 .33384 Mdot
.822 .33399 Mdot
.822 .33521 Mdot
.822 .33595 Mdot
.822 .33656 Mdot
.822 .33769 Mdot
.822 .33912 Mdot
.822 .33953 Mdot
.822 .33992 Mdot
.822 .34042 Mdot
.822 .34059 Mdot
.822 .34176 Mdot
.822 .34212 Mdot
.822 .34254 Mdot
.822 .34296 Mdot
.822 .34355 Mdot
.822 .34392 Mdot
.822 .34447 Mdot
.822 .34567 Mdot
.822 .34605 Mdot
.822 .34727 Mdot
.822 .34933 Mdot
.822 .35146 Mdot
.822 .35203 Mdot
.822 .35341 Mdot
.822 .35376 Mdot
.822 .354 Mdot
.822 .35427 Mdot
.822 .35437 Mdot
.822 .35461 Mdot
.822 .35481 Mdot
.822 .35689 Mdot
.822 .35969 Mdot
.822 .35979 Mdot
.822 .36044 Mdot
.822 .36156 Mdot
.822 .36165 Mdot
.822 .36361 Mdot
.822 .36371 Mdot
.822 .36384 Mdot
.822 .36385 Mdot
.822 .3644 Mdot
.822 .36464 Mdot
.822 .36549 Mdot
.822 .36638 Mdot
.822 .36928 Mdot
.822 .36955 Mdot
.822 .3698 Mdot
.822 .37034 Mdot
.822 .37156 Mdot
.822 .37265 Mdot
.822 .37424 Mdot
.822 .37466 Mdot
.822 .37476 Mdot
.822 .37524 Mdot
.822 .37551 Mdot
.822 .37578 Mdot
.822 .37737 Mdot
.822 .37766 Mdot
.822 .37803 Mdot
.822 .37831 Mdot
.822 .37963 Mdot
.822 .37989 Mdot
.822 .38021 Mdot
.822 .38025 Mdot
.822 .38225 Mdot
.822 .3835 Mdot
.822 .38408 Mdot
.822 .38488 Mdot
.822 .3857 Mdot
.822 .38848 Mdot
.822 .38897 Mdot
.822 .3891 Mdot
.822 .38954 Mdot
.822 .39071 Mdot
.822 .39131 Mdot
.822 .3937 Mdot
.822 .39389 Mdot
.822 .39502 Mdot
.822 .39569 Mdot
.822 .39905 Mdot
.822 .39918 Mdot
.822 .40078 Mdot
.822 .40103 Mdot
.822 .40209 Mdot
.822 .40231 Mdot
.822 .40291 Mdot
.822 .40345 Mdot
.822 .40374 Mdot
.822 .40417 Mdot
.822 .40514 Mdot
.822 .40519 Mdot
.822 .40582 Mdot
.822 .40701 Mdot
.822 .40861 Mdot
.822 .40911 Mdot
.822 .4092 Mdot
.822 .40922 Mdot
.822 .41096 Mdot
.822 .41232 Mdot
.822 .41282 Mdot
.822 .41294 Mdot
.822 .41631 Mdot
.822 .41713 Mdot
.822 .41736 Mdot
.822 .41741 Mdot
.822 .42215 Mdot
.822 .42226 Mdot
.822 .42303 Mdot
.822 .42313 Mdot
.822 .42316 Mdot
.822 .42323 Mdot
.822 .42356 Mdot
.822 .42366 Mdot
.822 .4239 Mdot
.822 .42567 Mdot
.822 .42578 Mdot
.822 .427 Mdot
.822 .42817 Mdot
.822 .42948 Mdot
.822 .4309 Mdot
.822 .4314 Mdot
.822 .43299 Mdot
.822 .43344 Mdot
.822 .43499 Mdot
.822 .43571 Mdot
.822 .43593 Mdot
.822 .43603 Mdot
.822 .43807 Mdot
.822 .43831 Mdot
.822 .43873 Mdot
.822 .43949 Mdot
.822 .43952 Mdot
.822 .44018 Mdot
.822 .44198 Mdot
.822 .44283 Mdot
.822 .44399 Mdot
.822 .44469 Mdot
.822 .44482 Mdot
.822 .44563 Mdot
.822 .44684 Mdot
.822 .44706 Mdot
.822 .44908 Mdot
.822 .45111 Mdot
.822 .4526 Mdot
.822 .45333 Mdot
.822 .45372 Mdot
.822 .45381 Mdot
.822 .45751 Mdot
.822 .45774 Mdot
.822 .46118 Mdot
.822 .46147 Mdot
.822 .46152 Mdot
.822 .46155 Mdot
.822 .46167 Mdot
.822 .46245 Mdot
.822 .46294 Mdot
.822 .46515 Mdot
.822 .46532 Mdot
.822 .4659 Mdot
.822 .46628 Mdot
.822 .46757 Mdot
.822 .46782 Mdot
.822 .46848 Mdot
.822 .46948 Mdot
.822 .46983 Mdot
.822 .47036 Mdot
.822 .47111 Mdot
.822 .47431 Mdot
.822 .47559 Mdot
.822 .47606 Mdot
.822 .47624 Mdot
.822 .47747 Mdot
.822 .47804 Mdot
.822 .47926 Mdot
.822 .48045 Mdot
.822 .48092 Mdot
.822 .48109 Mdot
.822 .48228 Mdot
.822 .48417 Mdot
.822 .48438 Mdot
.822 .48489 Mdot
.822 .48494 Mdot
.822 .48532 Mdot
.822 .48634 Mdot
.822 .48634 Mdot
.822 .48647 Mdot
.822 .48749 Mdot
.822 .48839 Mdot
.822 .48897 Mdot
.822 .48998 Mdot
.822 .49022 Mdot
.822 .49024 Mdot
.822 .49025 Mdot
.822 .49036 Mdot
.822 .49059 Mdot
.822 .49164 Mdot
.822 .49231 Mdot
.822 .49335 Mdot
.822 .49542 Mdot
.822 .4958 Mdot
.822 .49714 Mdot
.822 .49736 Mdot
.822 .50008 Mdot
.822 .50039 Mdot
.822 .50073 Mdot
.822 .50079 Mdot
.824 .01494 Mdot
.824 .01508 Mdot
.824 .01532 Mdot
.824 .01571 Mdot
.824 .01578 Mdot
.824 .01621 Mdot
.824 .01636 Mdot
.824 .01647 Mdot
.824 .01665 Mdot
.824 .01685 Mdot
.824 .01717 Mdot
.824 .01743 Mdot
.824 .01761 Mdot
.824 .0179 Mdot
.824 .01823 Mdot
.824 .01876 Mdot
.824 .01919 Mdot
.824 .01933 Mdot
.824 .01948 Mdot
.824 .01997 Mdot
.824 .0205 Mdot
.824 .02123 Mdot
.824 .02139 Mdot
.824 .02166 Mdot
.824 .02209 Mdot
.824 .02232 Mdot
.824 .02257 Mdot
.824 .02287 Mdot
.824 .02337 Mdot
.824 .02385 Mdot
.824 .02425 Mdot
.824 .02455 Mdot
.824 .02489 Mdot
.824 .02544 Mdot
.824 .02549 Mdot
.824 .02571 Mdot
.824 .02582 Mdot
.824 .02616 Mdot
.824 .02686 Mdot
.824 .02725 Mdot
.824 .02726 Mdot
.824 .02753 Mdot
.824 .02766 Mdot
.824 .02779 Mdot
.824 .02815 Mdot
.824 .02875 Mdot
.824 .02887 Mdot
.824 .02894 Mdot
.824 .02898 Mdot
.824 .02977 Mdot
.824 .03043 Mdot
.824 .03057 Mdot
.824 .03076 Mdot
.824 .03092 Mdot
.824 .03141 Mdot
.824 .03148 Mdot
.824 .0324 Mdot
.824 .03247 Mdot
.824 .03284 Mdot
.824 .03302 Mdot
.824 .03357 Mdot
.824 .03362 Mdot
.824 .03392 Mdot
.824 .03421 Mdot
.824 .03473 Mdot
.824 .03536 Mdot
.824 .03539 Mdot
.824 .03571 Mdot
.824 .03583 Mdot
.824 .03605 Mdot
.824 .03624 Mdot
.824 .03627 Mdot
.824 .03685 Mdot
.824 .03759 Mdot
.824 .03784 Mdot
.824 .03804 Mdot
.824 .03816 Mdot
.824 .03818 Mdot
.824 .03822 Mdot
.824 .03839 Mdot
.824 .03953 Mdot
.824 .03984 Mdot
.824 .04009 Mdot
.824 .04021 Mdot
.824 .04031 Mdot
.824 .04061 Mdot
.824 .04085 Mdot
.824 .04115 Mdot
.824 .04143 Mdot
.824 .0418 Mdot
.824 .04202 Mdot
.824 .04224 Mdot
.824 .04232 Mdot
.824 .04234 Mdot
.824 .04386 Mdot
.824 .04397 Mdot
.824 .04459 Mdot
.824 .04478 Mdot
.824 .04488 Mdot
.824 .04516 Mdot
.824 .04579 Mdot
.824 .04587 Mdot
.824 .04637 Mdot
.824 .04684 Mdot
.824 .04737 Mdot
.824 .04771 Mdot
.824 .04875 Mdot
.824 .04878 Mdot
.824 .04879 Mdot
.824 .04932 Mdot
.824 .04951 Mdot
.824 .04987 Mdot
.824 .05019 Mdot
.824 .05024 Mdot
.824 .05089 Mdot
.824 .05094 Mdot
.824 .05119 Mdot
.824 .05242 Mdot
.824 .05283 Mdot
.824 .05315 Mdot
.824 .05335 Mdot
.824 .05338 Mdot
.824 .05345 Mdot
.824 .05374 Mdot
.824 .05437 Mdot
.824 .05518 Mdot
.824 .05534 Mdot
.824 .05547 Mdot
.824 .05555 Mdot
.824 .05561 Mdot
.824 .05612 Mdot
.824 .05653 Mdot
.824 .05673 Mdot
.824 .0569 Mdot
.824 .05703 Mdot
.824 .05749 Mdot
.824 .05778 Mdot
.824 .05813 Mdot
.824 .05814 Mdot
.824 .05828 Mdot
.824 .05846 Mdot
.824 .05874 Mdot
.824 .05875 Mdot
.824 .05911 Mdot
.824 .05922 Mdot
.824 .05935 Mdot
.824 .05972 Mdot
.824 .06007 Mdot
.824 .0602 Mdot
.824 .06025 Mdot
.824 .06095 Mdot
.824 .06254 Mdot
.824 .06272 Mdot
.824 .06274 Mdot
.824 .06293 Mdot
.824 .06353 Mdot
.824 .06394 Mdot
.824 .06426 Mdot
.824 .06442 Mdot
.824 .06451 Mdot
.824 .06489 Mdot
.824 .06571 Mdot
.824 .06592 Mdot
.824 .06607 Mdot
.824 .06689 Mdot
.824 .06713 Mdot
.824 .06766 Mdot
.824 .0679 Mdot
.824 .06841 Mdot
.824 .06852 Mdot
.824 .06908 Mdot
.824 .06999 Mdot
.824 .0708 Mdot
.824 .07086 Mdot
.824 .07088 Mdot
.824 .07088 Mdot
.824 .07156 Mdot
.824 .07174 Mdot
.824 .07206 Mdot
.824 .07265 Mdot
.824 .07285 Mdot
.824 .07317 Mdot
.824 .07325 Mdot
.824 .07356 Mdot
.824 .07391 Mdot
.824 .0743 Mdot
.824 .07434 Mdot
.824 .07441 Mdot
.824 .07445 Mdot
.824 .07483 Mdot
.824 .07638 Mdot
.824 .07685 Mdot
.824 .07688 Mdot
.824 .07753 Mdot
.824 .07806 Mdot
.824 .07838 Mdot
.824 .07843 Mdot
.824 .07844 Mdot
.824 .07854 Mdot
.824 .07856 Mdot
.824 .07875 Mdot
.824 .07902 Mdot
.824 .08007 Mdot
.824 .08039 Mdot
.824 .08081 Mdot
.824 .08092 Mdot
.824 .0814 Mdot
.824 .08166 Mdot
.824 .08188 Mdot
.824 .08202 Mdot
.824 .08211 Mdot
.824 .08224 Mdot
.824 .08295 Mdot
.824 .08362 Mdot
.824 .08396 Mdot
.824 .08423 Mdot
.824 .08425 Mdot
.824 .08445 Mdot
.824 .0852 Mdot
.824 .08568 Mdot
.824 .08626 Mdot
.824 .08628 Mdot
.824 .08651 Mdot
.824 .0868 Mdot
.824 .08681 Mdot
.824 .08726 Mdot
.824 .08729 Mdot
.824 .08739 Mdot
.824 .08769 Mdot
.824 .08788 Mdot
.824 .08806 Mdot
.824 .08827 Mdot
.824 .08875 Mdot
.824 .08888 Mdot
.824 .08941 Mdot
.824 .08943 Mdot
.824 .08946 Mdot
.824 .08968 Mdot
.824 .08975 Mdot
.824 .0909 Mdot
.824 .09352 Mdot
.824 .09383 Mdot
.824 .09386 Mdot
.824 .09418 Mdot
.824 .09516 Mdot
.824 .09585 Mdot
.824 .09636 Mdot
.824 .09663 Mdot
.824 .09677 Mdot
.824 .09687 Mdot
.824 .09733 Mdot
.824 .0974 Mdot
.824 .09876 Mdot
.824 .09896 Mdot
.824 .0991 Mdot
.824 .09934 Mdot
.824 .10069 Mdot
.824 .1011 Mdot
.824 .10197 Mdot
.824 .10237 Mdot
.824 .1032 Mdot
.824 .10339 Mdot
.824 .10432 Mdot
.824 .10442 Mdot
.824 .10581 Mdot
.824 .10581 Mdot
.824 .10714 Mdot
.824 .10724 Mdot
.824 .10727 Mdot
.824 .10727 Mdot
.824 .10776 Mdot
.824 .1084 Mdot
.824 .1087 Mdot
.824 .10874 Mdot
.824 .10923 Mdot
.824 .11019 Mdot
.824 .11052 Mdot
.824 .11102 Mdot
.824 .11105 Mdot
.824 .11118 Mdot
.824 .1112 Mdot
.824 .11168 Mdot
.824 .11227 Mdot
.824 .11261 Mdot
.824 .11291 Mdot
.824 .11297 Mdot
.824 .11309 Mdot
.824 .11315 Mdot
.824 .11358 Mdot
.824 .11379 Mdot
.824 .11634 Mdot
.824 .11634 Mdot
.824 .11673 Mdot
.824 .11683 Mdot
.824 .11711 Mdot
.824 .11716 Mdot
.824 .11774 Mdot
.824 .11823 Mdot
.824 .11911 Mdot
.824 .11964 Mdot
.824 .11971 Mdot
.824 .11973 Mdot
.824 .11991 Mdot
.824 .11993 Mdot
.824 .12025 Mdot
.824 .12062 Mdot
.824 .1207 Mdot
.824 .12078 Mdot
.824 .12102 Mdot
.824 .12242 Mdot
.824 .12295 Mdot
.824 .12334 Mdot
.824 .12364 Mdot
.824 .12382 Mdot
.824 .12462 Mdot
.824 .12504 Mdot
.824 .12541 Mdot
.824 .12563 Mdot
.824 .12578 Mdot
.824 .12586 Mdot
.824 .12599 Mdot
.824 .12717 Mdot
.824 .12788 Mdot
.824 .12828 Mdot
.824 .12883 Mdot
.824 .12928 Mdot
.824 .1293 Mdot
.824 .12964 Mdot
.824 .12969 Mdot
.824 .13088 Mdot
.824 .1312 Mdot
.824 .13167 Mdot
.824 .13168 Mdot
.824 .13245 Mdot
.824 .13263 Mdot
.824 .13266 Mdot
.824 .13269 Mdot
.824 .13304 Mdot
.824 .13336 Mdot
.824 .13342 Mdot
.824 .1335 Mdot
.824 .13353 Mdot
.824 .13391 Mdot
.824 .13427 Mdot
.824 .13431 Mdot
.824 .13449 Mdot
.824 .13498 Mdot
.824 .1353 Mdot
.824 .13558 Mdot
.824 .13594 Mdot
.824 .13657 Mdot
.824 .13673 Mdot
.824 .13681 Mdot
.824 .1369 Mdot
.824 .13693 Mdot
.824 .13736 Mdot
.824 .13782 Mdot
.824 .13785 Mdot
.824 .13789 Mdot
.824 .13826 Mdot
.824 .13838 Mdot
.824 .13867 Mdot
.824 .13912 Mdot
.824 .13982 Mdot
.824 .14027 Mdot
.824 .14028 Mdot
.824 .14241 Mdot
.824 .14437 Mdot
.824 .14459 Mdot
.824 .1451 Mdot
.824 .14514 Mdot
.824 .14567 Mdot
.824 .1466 Mdot
.824 .14728 Mdot
.824 .14734 Mdot
.824 .14842 Mdot
.824 .14887 Mdot
.824 .14927 Mdot
.824 .14961 Mdot
.824 .14972 Mdot
.824 .14989 Mdot
.824 .14994 Mdot
.824 .15011 Mdot
.824 .15086 Mdot
.824 .15099 Mdot
.824 .15164 Mdot
.824 .15212 Mdot
.824 .15322 Mdot
.824 .15356 Mdot
.824 .15379 Mdot
.824 .15418 Mdot
.824 .15641 Mdot
.824 .15707 Mdot
.824 .15823 Mdot
.824 .15851 Mdot
.824 .15917 Mdot
.824 .15995 Mdot
.824 .16054 Mdot
.824 .16085 Mdot
.824 .16162 Mdot
.824 .16238 Mdot
.824 .16256 Mdot
.824 .16459 Mdot
.824 .1647 Mdot
.824 .16484 Mdot
.824 .16484 Mdot
.824 .16505 Mdot
.824 .16562 Mdot
.824 .16703 Mdot
.824 .16719 Mdot
.824 .16724 Mdot
.824 .16724 Mdot
.824 .16805 Mdot
.824 .16911 Mdot
.824 .1696 Mdot
.824 .16967 Mdot
.824 .16976 Mdot
.824 .17047 Mdot
.824 .17105 Mdot
.824 .17117 Mdot
.824 .17206 Mdot
.824 .17238 Mdot
.824 .17261 Mdot
.824 .17343 Mdot
.824 .17348 Mdot
.824 .1737 Mdot
.824 .17372 Mdot
.824 .17396 Mdot
.824 .17452 Mdot
.824 .17477 Mdot
.824 .17548 Mdot
.824 .17601 Mdot
.824 .17604 Mdot
.824 .17654 Mdot
.824 .17664 Mdot
.824 .17684 Mdot
.824 .17694 Mdot
.824 .17748 Mdot
.824 .17764 Mdot
.824 .17799 Mdot
.824 .18013 Mdot
.824 .18092 Mdot
.824 .18152 Mdot
.824 .18219 Mdot
.824 .1822 Mdot
.824 .18259 Mdot
.824 .18283 Mdot
.824 .183 Mdot
.824 .18347 Mdot
.824 .18355 Mdot
.824 .18356 Mdot
.824 .18402 Mdot
.824 .1845 Mdot
.824 .18456 Mdot
.824 .18496 Mdot
.824 .18531 Mdot
.824 .18676 Mdot
.824 .18763 Mdot
.824 .18775 Mdot
.824 .18778 Mdot
.824 .18807 Mdot
.824 .1881 Mdot
.824 .18834 Mdot
.824 .18864 Mdot
.824 .18879 Mdot
.824 .18914 Mdot
.824 .18925 Mdot
.824 .18937 Mdot
.824 .18952 Mdot
.824 .18991 Mdot
.824 .19221 Mdot
.824 .19309 Mdot
.824 .19372 Mdot
.824 .19422 Mdot
.824 .19453 Mdot
.824 .19583 Mdot
.824 .19653 Mdot
.824 .19713 Mdot
.824 .1975 Mdot
.824 .19775 Mdot
.824 .19788 Mdot
.824 .1981 Mdot
.824 .19822 Mdot
.824 .19875 Mdot
.824 .1993 Mdot
.824 .19934 Mdot
.824 .19937 Mdot
.824 .20004 Mdot
.824 .20028 Mdot
.824 .20121 Mdot
.824 .20186 Mdot
.824 .20277 Mdot
.824 .20285 Mdot
.824 .20352 Mdot
.824 .20356 Mdot
.824 .20411 Mdot
.824 .20419 Mdot
.824 .20616 Mdot
.824 .20668 Mdot
.824 .20745 Mdot
.824 .20747 Mdot
.824 .20873 Mdot
.824 .20903 Mdot
.824 .20909 Mdot
.824 .20914 Mdot
.824 .20917 Mdot
.824 .20971 Mdot
.824 .20988 Mdot
.824 .21012 Mdot
.824 .21012 Mdot
.824 .21024 Mdot
.824 .21035 Mdot
.824 .21048 Mdot
.824 .21052 Mdot
.824 .21116 Mdot
.824 .21174 Mdot
.824 .21181 Mdot
.824 .21211 Mdot
.824 .21291 Mdot
.824 .21343 Mdot
.824 .21372 Mdot
.824 .2139 Mdot
.824 .21449 Mdot
.824 .21481 Mdot
.824 .21506 Mdot
.824 .21554 Mdot
.824 .2158 Mdot
.824 .21593 Mdot
.824 .21607 Mdot
.824 .21613 Mdot
.824 .21684 Mdot
.824 .21702 Mdot
.824 .21759 Mdot
.824 .21764 Mdot
.824 .21771 Mdot
.824 .21832 Mdot
.824 .21847 Mdot
.824 .21851 Mdot
.824 .219 Mdot
.824 .21974 Mdot
.824 .22067 Mdot
.824 .22089 Mdot
.824 .221 Mdot
.824 .22139 Mdot
.824 .22164 Mdot
.824 .22164 Mdot
.824 .22438 Mdot
.824 .22455 Mdot
.824 .22515 Mdot
.824 .22716 Mdot
.824 .22767 Mdot
.824 .22839 Mdot
.824 .22875 Mdot
.824 .22959 Mdot
.824 .22966 Mdot
.824 .23018 Mdot
.824 .23054 Mdot
.824 .23155 Mdot
.824 .23169 Mdot
.824 .23173 Mdot
.824 .23207 Mdot
.824 .23313 Mdot
.824 .23319 Mdot
.824 .23328 Mdot
.824 .23413 Mdot
.824 .23506 Mdot
.824 .2358 Mdot
.824 .23647 Mdot
.824 .23702 Mdot
.824 .2372 Mdot
.824 .23748 Mdot
.824 .23757 Mdot
.824 .23782 Mdot
.824 .23784 Mdot
.824 .23802 Mdot
.824 .239 Mdot
.824 .23909 Mdot
.824 .23912 Mdot
.824 .23929 Mdot
.824 .23977 Mdot
.824 .23994 Mdot
.824 .2402 Mdot
.824 .24037 Mdot
.824 .24115 Mdot
.824 .24187 Mdot
.824 .24269 Mdot
.824 .24296 Mdot
.824 .24353 Mdot
.824 .2438 Mdot
.824 .2439 Mdot
.824 .24455 Mdot
.824 .24472 Mdot
.824 .24697 Mdot
.824 .24761 Mdot
.824 .24822 Mdot
.824 .24932 Mdot
.824 .24936 Mdot
.824 .24949 Mdot
.824 .2497 Mdot
.824 .25122 Mdot
.824 .2517 Mdot
.824 .25174 Mdot
.824 .25219 Mdot
.824 .25277 Mdot
.824 .25307 Mdot
.824 .25352 Mdot
.824 .25406 Mdot
.824 .25504 Mdot
.824 .25533 Mdot
.824 .25555 Mdot
.824 .25595 Mdot
.824 .2563 Mdot
.824 .25647 Mdot
.824 .25667 Mdot
.824 .25682 Mdot
.824 .25806 Mdot
.824 .25823 Mdot
.824 .25836 Mdot
.824 .2617 Mdot
.824 .2619 Mdot
.824 .2621 Mdot
.824 .26211 Mdot
.824 .26212 Mdot
.824 .26246 Mdot
.824 .26341 Mdot
.824 .26573 Mdot
.824 .26599 Mdot
.824 .26608 Mdot
.824 .26608 Mdot
.824 .26741 Mdot
.824 .26781 Mdot
.824 .2679 Mdot
.824 .26862 Mdot
.824 .26916 Mdot
.824 .26997 Mdot
.824 .27009 Mdot
.824 .27023 Mdot
.824 .27133 Mdot
.824 .2714 Mdot
.824 .27236 Mdot
.824 .27254 Mdot
.824 .27347 Mdot
.824 .27397 Mdot
.824 .27403 Mdot
.824 .27404 Mdot
.824 .27455 Mdot
.824 .27492 Mdot
.824 .27628 Mdot
.824 .27636 Mdot
.824 .27672 Mdot
.824 .27676 Mdot
.824 .277 Mdot
.824 .27706 Mdot
.824 .27716 Mdot
.824 .27777 Mdot
.824 .27808 Mdot
.824 .27848 Mdot
.824 .27882 Mdot
.824 .27965 Mdot
.824 .27989 Mdot
.824 .28053 Mdot
.824 .28058 Mdot
.824 .28065 Mdot
.824 .28141 Mdot
.824 .28157 Mdot
.824 .28189 Mdot
.824 .28206 Mdot
.824 .28273 Mdot
.824 .28295 Mdot
.824 .28309 Mdot
.824 .28315 Mdot
.824 .28322 Mdot
.824 .28379 Mdot
.824 .28522 Mdot
.824 .28732 Mdot
.824 .28736 Mdot
.824 .28762 Mdot
.824 .28862 Mdot
.824 .28941 Mdot
.824 .28959 Mdot
.824 .28962 Mdot
.824 .29071 Mdot
.824 .29073 Mdot
.824 .29099 Mdot
.824 .29138 Mdot
.824 .29177 Mdot
.824 .29205 Mdot
.824 .29282 Mdot
.824 .29295 Mdot
.824 .29297 Mdot
.824 .29373 Mdot
.824 .29452 Mdot
.824 .29462 Mdot
.824 .29527 Mdot
.824 .29534 Mdot
.824 .29586 Mdot
.824 .29746 Mdot
.824 .29824 Mdot
.824 .29968 Mdot
.824 .29987 Mdot
.824 .29993 Mdot
.824 .3004 Mdot
.824 .30046 Mdot
.824 .30085 Mdot
.824 .30134 Mdot
.824 .30136 Mdot
.824 .30159 Mdot
.824 .30189 Mdot
.824 .30205 Mdot
.824 .30216 Mdot
.824 .30235 Mdot
.824 .30255 Mdot
.824 .30279 Mdot
.824 .30334 Mdot
.824 .30344 Mdot
.824 .30348 Mdot
.824 .30455 Mdot
.824 .30587 Mdot
.824 .30593 Mdot
.824 .30655 Mdot
.824 .30723 Mdot
.824 .30736 Mdot
.824 .30781 Mdot
.824 .30811 Mdot
.824 .30862 Mdot
.824 .30867 Mdot
.824 .30917 Mdot
.824 .30972 Mdot
.824 .30981 Mdot
.824 .31053 Mdot
.824 .31104 Mdot
.824 .3113 Mdot
.824 .31157 Mdot
.824 .31169 Mdot
.824 .3132 Mdot
.824 .31435 Mdot
.824 .31461 Mdot
.824 .31534 Mdot
.824 .31594 Mdot
.824 .31636 Mdot
.824 .31657 Mdot
.824 .31693 Mdot
.824 .31714 Mdot
.824 .31801 Mdot
.824 .31817 Mdot
.824 .31833 Mdot
.824 .31891 Mdot
.824 .31898 Mdot
.824 .31903 Mdot
.824 .32002 Mdot
.824 .32013 Mdot
.824 .32053 Mdot
.824 .32187 Mdot
.824 .32205 Mdot
.824 .32223 Mdot
.824 .32314 Mdot
.824 .32346 Mdot
.824 .32428 Mdot
.824 .32463 Mdot
.824 .32476 Mdot
.824 .32564 Mdot
.824 .32579 Mdot
.824 .32587 Mdot
.824 .32593 Mdot
.824 .32683 Mdot
.824 .32697 Mdot
.824 .32715 Mdot
.824 .32864 Mdot
.824 .32887 Mdot
.824 .33021 Mdot
.824 .33107 Mdot
.824 .33235 Mdot
.824 .33238 Mdot
.824 .33446 Mdot
.824 .33495 Mdot
.824 .33505 Mdot
.824 .33513 Mdot
.824 .33518 Mdot
.824 .33607 Mdot
.824 .33635 Mdot
.824 .33674 Mdot
.824 .33675 Mdot
.824 .33694 Mdot
.824 .33712 Mdot
.824 .33734 Mdot
.824 .3374 Mdot
.824 .33845 Mdot
.824 .33941 Mdot
.824 .33953 Mdot
.824 .34001 Mdot
.824 .34134 Mdot
.824 .3422 Mdot
.824 .34267 Mdot
.824 .34298 Mdot
.824 .34394 Mdot
.824 .34447 Mdot
.824 .34489 Mdot
.824 .34567 Mdot
.824 .3461 Mdot
.824 .34631 Mdot
.824 .34655 Mdot
.824 .34664 Mdot
.824 .34782 Mdot
.824 .34812 Mdot
.824 .34906 Mdot
.824 .34913 Mdot
.824 .34925 Mdot
.824 .35025 Mdot
.824 .3505 Mdot
.824 .35057 Mdot
.824 .35137 Mdot
.824 .35259 Mdot
.824 .35413 Mdot
.824 .3545 Mdot
.824 .35468 Mdot
.824 .35532 Mdot
.824 .35572 Mdot
.824 .35573 Mdot
.824 .36025 Mdot
.824 .36053 Mdot
.824 .36152 Mdot
.824 .36483 Mdot
.824 .36567 Mdot
.824 .36685 Mdot
.824 .36745 Mdot
.824 .36884 Mdot
.824 .36894 Mdot
.824 .3698 Mdot
.824 .37039 Mdot
.824 .37206 Mdot
.824 .3723 Mdot
.824 .37236 Mdot
.824 .37291 Mdot
.824 .37466 Mdot
.824 .37476 Mdot
.824 .3749 Mdot
.824 .37631 Mdot
.824 .37784 Mdot
.824 .37906 Mdot
.824 .38016 Mdot
.824 .38108 Mdot
.824 .38137 Mdot
.824 .38183 Mdot
.824 .38198 Mdot
.824 .38239 Mdot
.824 .38243 Mdot
.824 .38273 Mdot
.824 .38434 Mdot
.824 .38448 Mdot
.824 .38454 Mdot
.824 .38482 Mdot
.824 .38561 Mdot
.824 .38588 Mdot
.824 .38631 Mdot
.824 .38659 Mdot
.824 .38788 Mdot
.824 .38907 Mdot
.824 .39043 Mdot
.824 .39087 Mdot
.824 .3918 Mdot
.824 .39225 Mdot
.824 .39242 Mdot
.824 .39348 Mdot
.824 .39377 Mdot
.824 .39748 Mdot
.824 .39852 Mdot
.824 .39954 Mdot
.824 .40134 Mdot
.824 .40141 Mdot
.824 .40162 Mdot
.824 .40196 Mdot
.824 .40448 Mdot
.824 .40526 Mdot
.824 .40533 Mdot
.824 .40607 Mdot
.824 .40703 Mdot
.824 .40752 Mdot
.824 .40827 Mdot
.824 .40916 Mdot
.824 .41077 Mdot
.824 .41125 Mdot
.824 .41162 Mdot
.824 .41226 Mdot
.824 .41285 Mdot
.824 .41313 Mdot
.824 .41346 Mdot
.824 .4137 Mdot
.824 .41575 Mdot
.824 .41602 Mdot
.824 .41624 Mdot
.824 .42175 Mdot
.824 .42207 Mdot
.824 .4224 Mdot
.824 .42243 Mdot
.824 .42244 Mdot
.824 .423 Mdot
.824 .42456 Mdot
.824 .42839 Mdot
.824 .42882 Mdot
.824 .42897 Mdot
.824 .42897 Mdot
.824 .43115 Mdot
.824 .43181 Mdot
.824 .43197 Mdot
.824 .43316 Mdot
.824 .43403 Mdot
.824 .43537 Mdot
.824 .43557 Mdot
.824 .43581 Mdot
.824 .43762 Mdot
.824 .43772 Mdot
.824 .43931 Mdot
.824 .43962 Mdot
.824 .44114 Mdot
.824 .44197 Mdot
.824 .44206 Mdot
.824 .44208 Mdot
.824 .44293 Mdot
.824 .44353 Mdot
.824 .44577 Mdot
.824 .4459 Mdot
.824 .44649 Mdot
.824 .44656 Mdot
.824 .44696 Mdot
.824 .44706 Mdot
.824 .44722 Mdot
.824 .44823 Mdot
.824 .44873 Mdot
.824 .44941 Mdot
.824 .44996 Mdot
.824 .45133 Mdot
.824 .45172 Mdot
.824 .45278 Mdot
.824 .45285 Mdot
.824 .45298 Mdot
.824 .45422 Mdot
.824 .45449 Mdot
.824 .45503 Mdot
.824 .4553 Mdot
.824 .4564 Mdot
.824 .45677 Mdot
.824 .45699 Mdot
.824 .45709 Mdot
.824 .45721 Mdot
.824 .45816 Mdot
.824 .46051 Mdot
.824 .46397 Mdot
.824 .46403 Mdot
.824 .46447 Mdot
.824 .46611 Mdot
.824 .46741 Mdot
.824 .46771 Mdot
.824 .46775 Mdot
.824 .46955 Mdot
.824 .46959 Mdot
.824 .47002 Mdot
.824 .47066 Mdot
.824 .4713 Mdot
.824 .47177 Mdot
.824 .47303 Mdot
.824 .47324 Mdot
.824 .47328 Mdot
.824 .47454 Mdot
.824 .47583 Mdot
.824 .476 Mdot
.824 .47708 Mdot
.824 .47719 Mdot
.824 .47804 Mdot
.824 .48068 Mdot
.824 .48197 Mdot
.824 .48433 Mdot
.824 .48465 Mdot
.824 .48475 Mdot
.824 .48553 Mdot
.824 .48562 Mdot
.824 .48627 Mdot
.824 .48707 Mdot
.824 .4871 Mdot
.824 .48748 Mdot
.824 .48797 Mdot
.824 .48825 Mdot
.824 .48843 Mdot
.824 .48873 Mdot
.824 .48907 Mdot
.824 .48946 Mdot
.824 .49036 Mdot
.824 .49053 Mdot
.824 .4906 Mdot
.824 .49237 Mdot
.824 .49453 Mdot
.824 .49463 Mdot
.824 .49565 Mdot
.824 .49678 Mdot
.824 .49699 Mdot
.824 .49774 Mdot
.824 .49824 Mdot
.824 .49907 Mdot
.824 .49916 Mdot
.824 .49998 Mdot
.824 .50088 Mdot
.824 .50102 Mdot
.826 .01669 Mdot
.826 .01746 Mdot
.826 .01757 Mdot
.826 .01775 Mdot
.826 .01793 Mdot
.826 .01797 Mdot
.826 .01909 Mdot
.826 .01924 Mdot
.826 .01944 Mdot
.826 .01947 Mdot
.826 .01956 Mdot
.826 .01972 Mdot
.826 .02003 Mdot
.826 .02009 Mdot
.826 .02082 Mdot
.826 .02195 Mdot
.826 .0222 Mdot
.826 .02252 Mdot
.826 .02252 Mdot
.826 .02258 Mdot
.826 .02271 Mdot
.826 .02279 Mdot
.826 .02299 Mdot
.826 .02317 Mdot
.826 .0235 Mdot
.826 .0236 Mdot
.826 .02369 Mdot
.826 .02408 Mdot
.826 .02457 Mdot
.826 .0248 Mdot
.826 .02486 Mdot
.826 .0258 Mdot
.826 .0261 Mdot
.826 .02666 Mdot
.826 .02692 Mdot
.826 .02707 Mdot
.826 .02738 Mdot
.826 .02755 Mdot
.826 .0276 Mdot
.826 .02761 Mdot
.826 .0277 Mdot
.826 .02793 Mdot
.826 .02794 Mdot
.826 .02806 Mdot
.826 .02838 Mdot
.826 .02866 Mdot
.826 .02869 Mdot
.826 .02919 Mdot
.826 .02922 Mdot
.826 .02939 Mdot
.826 .02954 Mdot
.826 .03019 Mdot
.826 .03054 Mdot
.826 .031 Mdot
.826 .03137 Mdot
.826 .03148 Mdot
.826 .03303 Mdot
.826 .03353 Mdot
.826 .03357 Mdot
.826 .03445 Mdot
.826 .03487 Mdot
.826 .03511 Mdot
.826 .03513 Mdot
.826 .03564 Mdot
.826 .03592 Mdot
.826 .03601 Mdot
.826 .03602 Mdot
.826 .03617 Mdot
.826 .03654 Mdot
.826 .03656 Mdot
.826 .03675 Mdot
.826 .03676 Mdot
.826 .03729 Mdot
.826 .03773 Mdot
.826 .03775 Mdot
.826 .0378 Mdot
.826 .03862 Mdot
.826 .03868 Mdot
.826 .03896 Mdot
.826 .03921 Mdot
.826 .04028 Mdot
.826 .0403 Mdot
.826 .04085 Mdot
.826 .04151 Mdot
.826 .04162 Mdot
.826 .04178 Mdot
.826 .04204 Mdot
.826 .04206 Mdot
.826 .04223 Mdot
.826 .04241 Mdot
.826 .04369 Mdot
.826 .04498 Mdot
.826 .0454 Mdot
.826 .04579 Mdot
.826 .04582 Mdot
.826 .04587 Mdot
.826 .0463 Mdot
.826 .04732 Mdot
.826 .04801 Mdot
.826 .04834 Mdot
.826 .04841 Mdot
.826 .04844 Mdot
.826 .0489 Mdot
.826 .04928 Mdot
.826 .04975 Mdot
.826 .04989 Mdot
.826 .04991 Mdot
.826 .05005 Mdot
.826 .05016 Mdot
.826 .05078 Mdot
.826 .0508 Mdot
.826 .05112 Mdot
.826 .05113 Mdot
.826 .05149 Mdot
.826 .05201 Mdot
.826 .05232 Mdot
.826 .05274 Mdot
.826 .05277 Mdot
.826 .05285 Mdot
.826 .05301 Mdot
.826 .05395 Mdot
.826 .05421 Mdot
.826 .05431 Mdot
.826 .05477 Mdot
.826 .05507 Mdot
.826 .05518 Mdot
.826 .05694 Mdot
.826 .05698 Mdot
.826 .05747 Mdot
.826 .05789 Mdot
.826 .05838 Mdot
.826 .05898 Mdot
.826 .05916 Mdot
.826 .05942 Mdot
.826 .05964 Mdot
.826 .05985 Mdot
.826 .0599 Mdot
.826 .06016 Mdot
.826 .06047 Mdot
.826 .06237 Mdot
.826 .06259 Mdot
.826 .06346 Mdot
.826 .06417 Mdot
.826 .06471 Mdot
.826 .06541 Mdot
.826 .06606 Mdot
.826 .06611 Mdot
.826 .06618 Mdot
.826 .06671 Mdot
.826 .06689 Mdot
.826 .0672 Mdot
.826 .06722 Mdot
.826 .06739 Mdot
.826 .06767 Mdot
.826 .06795 Mdot
.826 .06858 Mdot
.826 .06864 Mdot
.826 .06876 Mdot
.826 .06972 Mdot
.826 .07026 Mdot
.826 .07038 Mdot
.826 .07043 Mdot
.826 .07093 Mdot
.826 .07119 Mdot
.826 .07182 Mdot
.826 .07192 Mdot
.826 .07259 Mdot
.826 .07276 Mdot
.826 .07282 Mdot
.826 .07285 Mdot
.826 .07309 Mdot
.826 .07316 Mdot
.826 .07327 Mdot
.826 .0735 Mdot
.826 .07429 Mdot
.826 .07433 Mdot
.826 .07486 Mdot
.826 .07487 Mdot
.826 .07488 Mdot
.826 .07499 Mdot
.826 .07547 Mdot
.826 .07633 Mdot
.826 .07634 Mdot
.826 .07673 Mdot
.826 .07683 Mdot
.826 .0772 Mdot
.826 .07754 Mdot
.826 .07758 Mdot
.826 .07771 Mdot
.826 .07799 Mdot
.826 .07886 Mdot
.826 .07907 Mdot
.826 .07953 Mdot
.826 .07996 Mdot
.826 .08013 Mdot
.826 .08068 Mdot
.826 .08089 Mdot
.826 .08095 Mdot
.826 .08138 Mdot
.826 .08156 Mdot
.826 .08162 Mdot
.826 .08179 Mdot
.826 .08217 Mdot
.826 .08393 Mdot
.826 .08448 Mdot
.826 .08454 Mdot
.826 .08535 Mdot
.826 .08544 Mdot
.826 .08604 Mdot
.826 .08684 Mdot
.826 .08785 Mdot
.826 .08814 Mdot
.826 .08857 Mdot
.826 .08869 Mdot
.826 .08894 Mdot
.826 .08919 Mdot
.826 .08928 Mdot
.826 .08936 Mdot
.826 .08959 Mdot
.826 .08979 Mdot
.826 .0903 Mdot
.826 .09236 Mdot
.826 .09345 Mdot
.826 .0938 Mdot
.826 .09511 Mdot
.826 .09524 Mdot
.826 .09641 Mdot
.826 .09724 Mdot
.826 .0973 Mdot
.826 .09846 Mdot
.826 .09953 Mdot
.826 .09962 Mdot
.826 .09974 Mdot
.826 .0999 Mdot
.826 .10054 Mdot
.826 .10062 Mdot
.826 .10091 Mdot
.826 .10126 Mdot
.826 .10142 Mdot
.826 .10145 Mdot
.826 .10174 Mdot
.826 .1022 Mdot
.826 .10266 Mdot
.826 .10371 Mdot
.826 .10379 Mdot
.826 .10399 Mdot
.826 .10456 Mdot
.826 .10559 Mdot
.826 .10648 Mdot
.826 .10667 Mdot
.826 .10676 Mdot
.826 .10729 Mdot
.826 .10757 Mdot
.826 .10801 Mdot
.826 .10906 Mdot
.826 .10918 Mdot
.826 .10922 Mdot
.826 .11032 Mdot
.826 .1106 Mdot
.826 .11071 Mdot
.826 .11075 Mdot
.826 .11082 Mdot
.826 .11107 Mdot
.826 .11114 Mdot
.826 .11126 Mdot
.826 .11145 Mdot
.826 .11182 Mdot
.826 .11264 Mdot
.826 .11313 Mdot
.826 .11319 Mdot
.826 .11334 Mdot
.826 .11408 Mdot
.826 .11409 Mdot
.826 .11411 Mdot
.826 .11418 Mdot
.826 .11429 Mdot
.826 .11453 Mdot
.826 .11484 Mdot
.826 .11508 Mdot
.826 .1153 Mdot
.826 .1165 Mdot
.826 .11651 Mdot
.826 .11716 Mdot
.826 .11733 Mdot
.826 .11793 Mdot
.826 .1185 Mdot
.826 .11858 Mdot
.826 .11878 Mdot
.826 .11924 Mdot
.826 .12069 Mdot
.826 .12103 Mdot
.826 .12104 Mdot
.826 .12179 Mdot
.826 .12249 Mdot
.826 .12278 Mdot
.826 .12287 Mdot
.826 .12369 Mdot
.826 .12403 Mdot
.826 .12413 Mdot
.826 .12441 Mdot
.826 .12485 Mdot
.826 .12505 Mdot
.826 .12514 Mdot
.826 .12525 Mdot
.826 .12552 Mdot
.826 .12599 Mdot
.826 .12615 Mdot
.826 .129 Mdot
.826 .12906 Mdot
.826 .12913 Mdot
.826 .12996 Mdot
.826 .13006 Mdot
.826 .1314 Mdot
.826 .13155 Mdot
.826 .13176 Mdot
.826 .13254 Mdot
.826 .13387 Mdot
.826 .13474 Mdot
.826 .13487 Mdot
.826 .13505 Mdot
.826 .13553 Mdot
.826 .13602 Mdot
.826 .1361 Mdot
.826 .13643 Mdot
.826 .13673 Mdot
.826 .13681 Mdot
.826 .13692 Mdot
.826 .13733 Mdot
.826 .13775 Mdot
.826 .1379 Mdot
.826 .13802 Mdot
.826 .13841 Mdot
.826 .13875 Mdot
.826 .13947 Mdot
.826 .13958 Mdot
.826 .14089 Mdot
.826 .14136 Mdot
.826 .1421 Mdot
.826 .14226 Mdot
.826 .14299 Mdot
.826 .14359 Mdot
.826 .14443 Mdot
.826 .14478 Mdot
.826 .14527 Mdot
.826 .14537 Mdot
.826 .14664 Mdot
.826 .14739 Mdot
.826 .14753 Mdot
.826 .14774 Mdot
.826 .14968 Mdot
.826 .14998 Mdot
.826 .15073 Mdot
.826 .15105 Mdot
.826 .15115 Mdot
.826 .15131 Mdot
.826 .15164 Mdot
.826 .15306 Mdot
.826 .15323 Mdot
.826 .15483 Mdot
.826 .15497 Mdot
.826 .15517 Mdot
.826 .15545 Mdot
.826 .15559 Mdot
.826 .1565 Mdot
.826 .15662 Mdot
.826 .1571 Mdot
.826 .15769 Mdot
.826 .15796 Mdot
.826 .15796 Mdot
.826 .15801 Mdot
.826 .1581 Mdot
.826 .15848 Mdot
.826 .15859 Mdot
.826 .15924 Mdot
.826 .15947 Mdot
.826 .1595 Mdot
.826 .16 Mdot
.826 .16073 Mdot
.826 .16138 Mdot
.826 .1617 Mdot
.826 .16173 Mdot
.826 .16187 Mdot
.826 .1622 Mdot
.826 .16314 Mdot
.826 .16404 Mdot
.826 .16484 Mdot
.826 .16549 Mdot
.826 .16604 Mdot
.826 .16631 Mdot
.826 .16641 Mdot
.826 .16663 Mdot
.826 .16678 Mdot
.826 .16703 Mdot
.826 .16765 Mdot
.826 .16812 Mdot
.826 .16821 Mdot
.826 .16884 Mdot
.826 .17057 Mdot
.826 .17077 Mdot
.826 .17084 Mdot
.826 .17087 Mdot
.826 .17205 Mdot
.826 .17206 Mdot
.826 .17227 Mdot
.826 .17265 Mdot
.826 .17268 Mdot
.826 .17312 Mdot
.826 .1733 Mdot
.826 .17337 Mdot
.826 .17348 Mdot
.826 .17389 Mdot
.826 .17402 Mdot
.826 .17421 Mdot
.826 .17441 Mdot
.826 .17452 Mdot
.826 .17489 Mdot
.826 .17509 Mdot
.826 .17514 Mdot
.826 .17648 Mdot
.826 .1773 Mdot
.826 .1774 Mdot
.826 .17764 Mdot
.826 .17785 Mdot
.826 .17885 Mdot
.826 .17887 Mdot
.826 .17888 Mdot
.826 .17891 Mdot
.826 .17901 Mdot
.826 .17903 Mdot
.826 .17922 Mdot
.826 .17962 Mdot
.826 .18012 Mdot
.826 .18053 Mdot
.826 .18088 Mdot
.826 .18126 Mdot
.826 .18286 Mdot
.826 .18289 Mdot
.826 .18356 Mdot
.826 .18395 Mdot
.826 .18424 Mdot
.826 .18457 Mdot
.826 .18523 Mdot
.826 .18616 Mdot
.826 .18629 Mdot
.826 .18663 Mdot
.826 .18739 Mdot
.826 .1875 Mdot
.826 .18891 Mdot
.826 .18905 Mdot
.826 .18969 Mdot
.826 .18978 Mdot
.826 .19034 Mdot
.826 .19037 Mdot
.826 .19117 Mdot
.826 .1916 Mdot
.826 .19231 Mdot
.826 .19276 Mdot
.826 .19323 Mdot
.826 .19339 Mdot
.826 .19358 Mdot
.826 .19475 Mdot
.826 .19488 Mdot
.826 .1953 Mdot
.826 .19544 Mdot
.826 .19547 Mdot
.826 .19593 Mdot
.826 .19666 Mdot
.826 .19699 Mdot
.826 .19713 Mdot
.826 .19731 Mdot
.826 .19776 Mdot
.826 .19787 Mdot
.826 .19854 Mdot
.826 .19881 Mdot
.826 .1995 Mdot
.826 .20117 Mdot
.826 .20213 Mdot
.826 .20307 Mdot
.826 .20352 Mdot
.826 .20362 Mdot
.826 .20372 Mdot
.826 .2051 Mdot
.826 .20527 Mdot
.826 .20602 Mdot
.826 .20748 Mdot
.826 .20773 Mdot
.826 .20807 Mdot
.826 .20849 Mdot
.826 .20937 Mdot
.826 .2097 Mdot
.826 .21016 Mdot
.826 .21116 Mdot
.826 .21156 Mdot
.826 .21182 Mdot
.826 .21275 Mdot
.826 .21293 Mdot
.826 .21294 Mdot
.826 .213 Mdot
.826 .2131 Mdot
.826 .21321 Mdot
.826 .21346 Mdot
.826 .2135 Mdot
.826 .2143 Mdot
.826 .21466 Mdot
.826 .21497 Mdot
.826 .21511 Mdot
.826 .21524 Mdot
.826 .21574 Mdot
.826 .21579 Mdot
.826 .21628 Mdot
.826 .21642 Mdot
.826 .21659 Mdot
.826 .2172 Mdot
.826 .21728 Mdot
.826 .21787 Mdot
.826 .21797 Mdot
.826 .21821 Mdot
.826 .21828 Mdot
.826 .21842 Mdot
.826 .21906 Mdot
.826 .21961 Mdot
.826 .2208 Mdot
.826 .22099 Mdot
.826 .22114 Mdot
.826 .22215 Mdot
.826 .22316 Mdot
.826 .22394 Mdot
.826 .22491 Mdot
.826 .22515 Mdot
.826 .22541 Mdot
.826 .22662 Mdot
.826 .22762 Mdot
.826 .22831 Mdot
.826 .22891 Mdot
.826 .229 Mdot
.826 .22958 Mdot
.826 .22984 Mdot
.826 .23015 Mdot
.826 .23027 Mdot
.826 .23039 Mdot
.826 .23056 Mdot
.826 .23266 Mdot
.826 .23333 Mdot
.826 .23389 Mdot
.826 .23413 Mdot
.826 .23447 Mdot
.826 .23558 Mdot
.826 .23562 Mdot
.826 .23659 Mdot
.826 .23768 Mdot
.826 .23772 Mdot
.826 .23779 Mdot
.826 .23818 Mdot
.826 .2383 Mdot
.826 .23844 Mdot
.826 .23941 Mdot
.826 .23993 Mdot
.826 .24011 Mdot
.826 .24037 Mdot
.826 .24043 Mdot
.826 .24092 Mdot
.826 .24123 Mdot
.826 .24154 Mdot
.826 .24204 Mdot
.826 .24231 Mdot
.826 .24326 Mdot
.826 .24354 Mdot
.826 .24375 Mdot
.826 .24387 Mdot
.826 .24445 Mdot
.826 .24532 Mdot
.826 .24619 Mdot
.826 .24624 Mdot
.826 .24642 Mdot
.826 .24674 Mdot
.826 .24675 Mdot
.826 .2472 Mdot
.826 .24744 Mdot
.826 .24756 Mdot
.826 .24842 Mdot
.826 .24895 Mdot
.826 .24915 Mdot
.826 .24928 Mdot
.826 .24951 Mdot
.826 .24994 Mdot
.826 .25092 Mdot
.826 .25135 Mdot
.826 .25135 Mdot
.826 .25143 Mdot
.826 .25158 Mdot
.826 .25221 Mdot
.826 .25239 Mdot
.826 .25246 Mdot
.826 .25348 Mdot
.826 .25384 Mdot
.826 .2539 Mdot
.826 .25472 Mdot
.826 .25557 Mdot
.826 .25594 Mdot
.826 .25701 Mdot
.826 .25753 Mdot
.826 .25758 Mdot
.826 .25781 Mdot
.826 .25836 Mdot
.826 .25877 Mdot
.826 .25924 Mdot
.826 .25971 Mdot
.826 .25992 Mdot
.826 .26081 Mdot
.826 .26141 Mdot
.826 .26202 Mdot
.826 .26237 Mdot
.826 .26272 Mdot
.826 .2638 Mdot
.826 .2647 Mdot
.826 .26514 Mdot
.826 .26531 Mdot
.826 .26568 Mdot
.826 .26592 Mdot
.826 .26626 Mdot
.826 .26633 Mdot
.826 .26633 Mdot
.826 .26639 Mdot
.826 .26652 Mdot
.826 .26696 Mdot
.826 .26708 Mdot
.826 .26736 Mdot
.826 .26789 Mdot
.826 .26814 Mdot
.826 .26829 Mdot
.826 .26934 Mdot
.826 .26971 Mdot
.826 .27072 Mdot
.826 .27197 Mdot
.826 .27219 Mdot
.826 .27252 Mdot
.826 .27264 Mdot
.826 .27268 Mdot
.826 .2738 Mdot
.826 .27463 Mdot
.826 .27464 Mdot
.826 .275 Mdot
.826 .27541 Mdot
.826 .27544 Mdot
.826 .27562 Mdot
.826 .27568 Mdot
.826 .27641 Mdot
.826 .2767 Mdot
.826 .27681 Mdot
.826 .277 Mdot
.826 .2771 Mdot
.826 .27762 Mdot
.826 .27767 Mdot
.826 .27788 Mdot
.826 .2782 Mdot
.826 .27853 Mdot
.826 .27872 Mdot
.826 .27902 Mdot
.826 .27933 Mdot
.826 .27965 Mdot
.826 .27973 Mdot
.826 .28081 Mdot
.826 .28195 Mdot
.826 .28313 Mdot
.826 .2833 Mdot
.826 .28347 Mdot
.826 .28387 Mdot
.826 .28422 Mdot
.826 .28432 Mdot
.826 .28445 Mdot
.826 .28587 Mdot
.826 .2859 Mdot
.826 .28592 Mdot
.826 .28597 Mdot
.826 .28613 Mdot
.826 .28617 Mdot
.826 .28647 Mdot
.826 .28713 Mdot
.826 .2875 Mdot
.826 .28796 Mdot
.826 .28863 Mdot
.826 .28922 Mdot
.826 .28923 Mdot
.826 .28984 Mdot
.826 .29003 Mdot
.826 .29054 Mdot
.826 .2912 Mdot
.826 .29205 Mdot
.826 .29249 Mdot
.826 .29253 Mdot
.826 .29365 Mdot
.826 .29429 Mdot
.826 .29477 Mdot
.826 .29501 Mdot
.826 .29532 Mdot
.826 .2964 Mdot
.826 .29794 Mdot
.826 .29816 Mdot
.826 .29872 Mdot
.826 .2992 Mdot
.826 .29981 Mdot
.826 .29997 Mdot
.826 .30016 Mdot
.826 .30134 Mdot
.826 .30248 Mdot
.826 .30265 Mdot
.826 .30271 Mdot
.826 .30377 Mdot
.826 .30392 Mdot
.826 .30429 Mdot
.826 .30475 Mdot
.826 .30485 Mdot
.826 .30489 Mdot
.826 .30525 Mdot
.826 .30623 Mdot
.826 .30693 Mdot
.826 .3081 Mdot
.826 .30847 Mdot
.826 .30885 Mdot
.826 .30963 Mdot
.826 .30988 Mdot
.826 .3102 Mdot
.826 .31159 Mdot
.826 .31206 Mdot
.826 .31213 Mdot
.826 .31223 Mdot
.826 .31234 Mdot
.826 .31305 Mdot
.826 .31328 Mdot
.826 .31333 Mdot
.826 .31409 Mdot
.826 .31512 Mdot
.826 .31529 Mdot
.826 .31552 Mdot
.826 .31583 Mdot
.826 .31607 Mdot
.826 .31636 Mdot
.826 .31654 Mdot
.826 .31711 Mdot
.826 .31729 Mdot
.826 .31778 Mdot
.826 .31806 Mdot
.826 .31817 Mdot
.826 .3184 Mdot
.826 .31884 Mdot
.826 .31916 Mdot
.826 .31997 Mdot
.826 .32181 Mdot
.826 .32274 Mdot
.826 .32374 Mdot
.826 .32433 Mdot
.826 .32588 Mdot
.826 .32662 Mdot
.826 .32678 Mdot
.826 .32694 Mdot
.826 .32695 Mdot
.826 .32794 Mdot
.826 .32897 Mdot
.826 .32923 Mdot
.826 .32951 Mdot
.826 .33075 Mdot
.826 .33109 Mdot
.826 .33178 Mdot
.826 .33266 Mdot
.826 .33316 Mdot
.826 .33358 Mdot
.826 .33415 Mdot
.826 .33482 Mdot
.826 .33628 Mdot
.826 .33683 Mdot
.826 .33759 Mdot
.826 .33924 Mdot
.826 .3399 Mdot
.826 .34033 Mdot
.826 .34187 Mdot
.826 .34217 Mdot
.826 .34218 Mdot
.826 .34228 Mdot
.826 .34245 Mdot
.826 .34262 Mdot
.826 .34304 Mdot
.826 .34311 Mdot
.826 .34442 Mdot
.826 .34503 Mdot
.826 .34553 Mdot
.826 .34577 Mdot
.826 .34598 Mdot
.826 .34681 Mdot
.826 .34688 Mdot
.826 .3477 Mdot
.826 .34793 Mdot
.826 .34822 Mdot
.826 .34923 Mdot
.826 .34935 Mdot
.826 .35033 Mdot
.826 .35049 Mdot
.826 .3509 Mdot
.826 .351 Mdot
.826 .35123 Mdot
.826 .35229 Mdot
.826 .35321 Mdot
.826 .35517 Mdot
.826 .35548 Mdot
.826 .35572 Mdot
.826 .3574 Mdot
.826 .35906 Mdot
.826 .36035 Mdot
.826 .36196 Mdot
.826 .36235 Mdot
.826 .36279 Mdot
.826 .36478 Mdot
.826 .36643 Mdot
.826 .36758 Mdot
.826 .36857 Mdot
.826 .36872 Mdot
.826 .36967 Mdot
.826 .3701 Mdot
.826 .37061 Mdot
.826 .37082 Mdot
.826 .371 Mdot
.826 .37128 Mdot
.826 .37476 Mdot
.826 .37586 Mdot
.826 .3768 Mdot
.826 .37718 Mdot
.826 .37775 Mdot
.826 .37958 Mdot
.826 .37965 Mdot
.826 .38125 Mdot
.826 .38305 Mdot
.826 .38313 Mdot
.826 .38324 Mdot
.826 .38387 Mdot
.826 .38407 Mdot
.826 .38431 Mdot
.826 .38591 Mdot
.826 .38677 Mdot
.826 .38706 Mdot
.826 .3875 Mdot
.826 .3876 Mdot
.826 .38841 Mdot
.826 .38892 Mdot
.826 .38942 Mdot
.826 .39026 Mdot
.826 .39071 Mdot
.826 .39228 Mdot
.826 .39273 Mdot
.826 .39308 Mdot
.826 .39328 Mdot
.826 .39424 Mdot
.826 .39567 Mdot
.826 .3971 Mdot
.826 .39719 Mdot
.826 .39749 Mdot
.826 .39802 Mdot
.826 .39804 Mdot
.826 .39879 Mdot
.826 .39918 Mdot
.826 .39937 Mdot
.826 .40079 Mdot
.826 .40166 Mdot
.826 .402 Mdot
.826 .40222 Mdot
.826 .40259 Mdot
.826 .40331 Mdot
.826 .40492 Mdot
.826 .40563 Mdot
.826 .40564 Mdot
.826 .40577 Mdot
.826 .40602 Mdot
.826 .40706 Mdot
.826 .40736 Mdot
.826 .40747 Mdot
.826 .40915 Mdot
.826 .40975 Mdot
.826 .40985 Mdot
.826 .41121 Mdot
.826 .41261 Mdot
.826 .41322 Mdot
.826 .41499 Mdot
.826 .41584 Mdot
.826 .41593 Mdot
.826 .41631 Mdot
.826 .41721 Mdot
.826 .4179 Mdot
.826 .41867 Mdot
.826 .41945 Mdot
.826 .4198 Mdot
.826 .42127 Mdot
.826 .42225 Mdot
.826 .42326 Mdot
.826 .42385 Mdot
.826 .42441 Mdot
.826 .4262 Mdot
.826 .42769 Mdot
.826 .42842 Mdot
.826 .42871 Mdot
.826 .42931 Mdot
.826 .42971 Mdot
.826 .43027 Mdot
.826 .43038 Mdot
.826 .43039 Mdot
.826 .43049 Mdot
.826 .4307 Mdot
.826 .43143 Mdot
.826 .43161 Mdot
.826 .43208 Mdot
.826 .43297 Mdot
.826 .43337 Mdot
.826 .43362 Mdot
.826 .43535 Mdot
.826 .43596 Mdot
.826 .43763 Mdot
.826 .43969 Mdot
.826 .44006 Mdot
.826 .44062 Mdot
.826 .4408 Mdot
.826 .44088 Mdot
.826 .44273 Mdot
.826 .44409 Mdot
.826 .44412 Mdot
.826 .4447 Mdot
.826 .44539 Mdot
.826 .44543 Mdot
.826 .44574 Mdot
.826 .44582 Mdot
.826 .44703 Mdot
.826 .44751 Mdot
.826 .4477 Mdot
.826 .448 Mdot
.826 .44817 Mdot
.826 .44904 Mdot
.826 .44911 Mdot
.826 .44946 Mdot
.826 .44999 Mdot
.826 .45054 Mdot
.826 .45085 Mdot
.826 .45134 Mdot
.826 .45186 Mdot
.826 .45239 Mdot
.826 .45252 Mdot
.826 .45431 Mdot
.826 .45619 Mdot
.826 .45813 Mdot
.826 .45841 Mdot
.826 .4587 Mdot
.826 .45936 Mdot
.826 .4601 Mdot
.826 .46031 Mdot
.826 .46267 Mdot
.826 .4627 Mdot
.826 .46274 Mdot
.826 .46282 Mdot
.826 .46309 Mdot
.826 .46316 Mdot
.826 .46365 Mdot
.826 .46475 Mdot
.826 .46536 Mdot
.826 .46612 Mdot
.826 .46723 Mdot
.826 .4682 Mdot
.826 .46822 Mdot
.826 .46922 Mdot
.826 .46954 Mdot
.826 .47038 Mdot
.826 .47147 Mdot
.826 .47287 Mdot
.826 .47359 Mdot
.826 .47367 Mdot
.826 .47552 Mdot
.826 .47657 Mdot
.826 .47736 Mdot
.826 .47776 Mdot
.826 .47827 Mdot
.826 .48007 Mdot
.826 .48261 Mdot
.826 .48297 Mdot
.826 .4839 Mdot
.826 .48469 Mdot
.826 .48569 Mdot
.826 .48596 Mdot
.826 .48627 Mdot
.826 .48821 Mdot
.826 .4901 Mdot
.826 .49038 Mdot
.826 .49049 Mdot
.826 .49224 Mdot
.826 .49248 Mdot
.826 .4931 Mdot
.826 .49385 Mdot
.826 .49402 Mdot
.826 .49408 Mdot
.826 .49468 Mdot
.826 .49629 Mdot
.826 .49746 Mdot
.826 .49939 Mdot
.826 .5 Mdot
.826 .50062 Mdot
.826 .50191 Mdot
.826 .50233 Mdot
.826 .50286 Mdot
.828 .01575 Mdot
.828 .01643 Mdot
.828 .0167 Mdot
.828 .01693 Mdot
.828 .01755 Mdot
.828 .018 Mdot
.828 .01815 Mdot
.828 .01838 Mdot
.828 .01883 Mdot
.828 .01933 Mdot
.828 .01942 Mdot
.828 .02015 Mdot
.828 .0204 Mdot
.828 .02079 Mdot
.828 .02122 Mdot
.828 .02153 Mdot
.828 .02203 Mdot
.828 .02235 Mdot
.828 .0225 Mdot
.828 .02371 Mdot
.828 .02413 Mdot
.828 .02434 Mdot
.828 .02478 Mdot
.828 .02501 Mdot
.828 .02548 Mdot
.828 .02561 Mdot
.828 .02571 Mdot
.828 .02601 Mdot
.828 .02603 Mdot
.828 .0264 Mdot
.828 .02683 Mdot
.828 .02702 Mdot
.828 .02724 Mdot
.828 .02736 Mdot
.828 .02761 Mdot
.828 .02803 Mdot
.828 .02819 Mdot
.828 .02877 Mdot
.828 .02877 Mdot
.828 .02938 Mdot
.828 .02946 Mdot
.828 .02961 Mdot
.828 .02976 Mdot
.828 .03031 Mdot
.828 .03063 Mdot
.828 .03066 Mdot
.828 .03081 Mdot
.828 .03138 Mdot
.828 .03176 Mdot
.828 .03255 Mdot
.828 .03273 Mdot
.828 .03275 Mdot
.828 .03292 Mdot
.828 .03341 Mdot
.828 .03346 Mdot
.828 .03368 Mdot
.828 .03391 Mdot
.828 .03407 Mdot
.828 .03444 Mdot
.828 .03478 Mdot
.828 .0351 Mdot
.828 .03518 Mdot
.828 .03546 Mdot
.828 .03561 Mdot
.828 .03566 Mdot
.828 .03607 Mdot
.828 .03676 Mdot
.828 .03691 Mdot
.828 .03703 Mdot
.828 .0376 Mdot
.828 .03799 Mdot
.828 .03799 Mdot
.828 .03881 Mdot
.828 .03901 Mdot
.828 .03914 Mdot
.828 .03923 Mdot
.828 .03939 Mdot
.828 .03941 Mdot
.828 .03963 Mdot
.828 .04054 Mdot
.828 .04108 Mdot
.828 .04111 Mdot
.828 .04137 Mdot
.828 .04207 Mdot
.828 .04231 Mdot
.828 .04294 Mdot
.828 .04425 Mdot
.828 .0444 Mdot
.828 .04455 Mdot
.828 .04458 Mdot
.828 .04466 Mdot
.828 .04477 Mdot
.828 .04487 Mdot
.828 .04568 Mdot
.828 .04575 Mdot
.828 .04611 Mdot
.828 .04646 Mdot
.828 .04649 Mdot
.828 .04656 Mdot
.828 .04677 Mdot
.828 .04738 Mdot
.828 .04794 Mdot
.828 .04847 Mdot
.828 .0486 Mdot
.828 .04872 Mdot
.828 .04907 Mdot
.828 .04931 Mdot
.828 .04939 Mdot
.828 .05008 Mdot
.828 .05022 Mdot
.828 .05072 Mdot
.828 .05122 Mdot
.828 .05147 Mdot
.828 .05166 Mdot
.828 .05261 Mdot
.828 .05282 Mdot
.828 .05289 Mdot
.828 .05326 Mdot
.828 .05327 Mdot
.828 .05462 Mdot
.828 .05491 Mdot
.828 .05494 Mdot
.828 .05502 Mdot
.828 .05516 Mdot
.828 .05522 Mdot
.828 .05532 Mdot
.828 .05557 Mdot
.828 .05562 Mdot
.828 .05597 Mdot
.828 .05748 Mdot
.828 .05762 Mdot
.828 .05813 Mdot
.828 .05837 Mdot
.828 .05843 Mdot
.828 .05877 Mdot
.828 .05885 Mdot
.828 .05886 Mdot
.828 .05941 Mdot
.828 .06002 Mdot
.828 .0604 Mdot
.828 .06041 Mdot
.828 .06122 Mdot
.828 .06145 Mdot
.828 .06222 Mdot
.828 .06362 Mdot
.828 .06387 Mdot
.828 .06412 Mdot
.828 .06418 Mdot
.828 .0643 Mdot
.828 .06448 Mdot
.828 .06465 Mdot
.828 .06523 Mdot
.828 .0658 Mdot
.828 .06599 Mdot
.828 .06611 Mdot
.828 .06671 Mdot
.828 .06728 Mdot
.828 .06734 Mdot
.828 .06746 Mdot
.828 .06754 Mdot
.828 .06779 Mdot
.828 .06871 Mdot
.828 .06881 Mdot
.828 .06941 Mdot
.828 .06949 Mdot
.828 .06973 Mdot
.828 .07022 Mdot
.828 .07061 Mdot
.828 .07083 Mdot
.828 .07102 Mdot
.828 .0715 Mdot
.828 .07161 Mdot
.828 .07201 Mdot
.828 .07214 Mdot
.828 .07306 Mdot
.828 .07328 Mdot
.828 .07351 Mdot
.828 .07367 Mdot
.828 .07407 Mdot
.828 .07434 Mdot
.828 .07468 Mdot
.828 .07484 Mdot
.828 .07517 Mdot
.828 .07558 Mdot
.828 .0759 Mdot
.828 .07746 Mdot
.828 .07782 Mdot
.828 .07788 Mdot
.828 .07794 Mdot
.828 .07855 Mdot
.828 .07856 Mdot
.828 .08009 Mdot
.828 .0808 Mdot
.828 .08127 Mdot
.828 .08133 Mdot
.828 .08146 Mdot
.828 .08149 Mdot
.828 .08169 Mdot
.828 .08169 Mdot
.828 .08179 Mdot
.828 .08195 Mdot
.828 .08238 Mdot
.828 .08245 Mdot
.828 .08303 Mdot
.828 .08308 Mdot
.828 .08405 Mdot
.828 .08553 Mdot
.828 .0856 Mdot
.828 .08577 Mdot
.828 .0859 Mdot
.828 .08662 Mdot
.828 .087 Mdot
.828 .08711 Mdot
.828 .08766 Mdot
.828 .08772 Mdot
.828 .0878 Mdot
.828 .08782 Mdot
.828 .08852 Mdot
.828 .08873 Mdot
.828 .08925 Mdot
.828 .08964 Mdot
.828 .08974 Mdot
.828 .09033 Mdot
.828 .09037 Mdot
.828 .09039 Mdot
.828 .09116 Mdot
.828 .09173 Mdot
.828 .09211 Mdot
.828 .09338 Mdot
.828 .09376 Mdot
.828 .09403 Mdot
.828 .09414 Mdot
.828 .09571 Mdot
.828 .09576 Mdot
.828 .09612 Mdot
.828 .09653 Mdot
.828 .09657 Mdot
.828 .09662 Mdot
.828 .09683 Mdot
.828 .09697 Mdot
.828 .09712 Mdot
.828 .09741 Mdot
.828 .09837 Mdot
.828 .09866 Mdot
.828 .09874 Mdot
.828 .09931 Mdot
.828 .09963 Mdot
.828 .09982 Mdot
.828 .09993 Mdot
.828 .10082 Mdot
.828 .10176 Mdot
.828 .10187 Mdot
.828 .10205 Mdot
.828 .1022 Mdot
.828 .10261 Mdot
.828 .10413 Mdot
.828 .10428 Mdot
.828 .1043 Mdot
.828 .10529 Mdot
.828 .10531 Mdot
.828 .10542 Mdot
.828 .10582 Mdot
.828 .10587 Mdot
.828 .10663 Mdot
.828 .10711 Mdot
.828 .10727 Mdot
.828 .10764 Mdot
.828 .10796 Mdot
.828 .10875 Mdot
.828 .10894 Mdot
.828 .10959 Mdot
.828 .10981 Mdot
.828 .10996 Mdot
.828 .11059 Mdot
.828 .11134 Mdot
.828 .1117 Mdot
.828 .11207 Mdot
.828 .11234 Mdot
.828 .113 Mdot
.828 .11345 Mdot
.828 .11401 Mdot
.828 .11429 Mdot
.828 .11482 Mdot
.828 .11551 Mdot
.828 .11584 Mdot
.828 .11587 Mdot
.828 .11604 Mdot
.828 .1163 Mdot
.828 .11667 Mdot
.828 .11863 Mdot
.828 .11922 Mdot
.828 .11932 Mdot
.828 .11942 Mdot
.828 .11951 Mdot
.828 .12042 Mdot
.828 .12043 Mdot
.828 .12098 Mdot
.828 .12155 Mdot
.828 .1217 Mdot
.828 .12239 Mdot
.828 .12297 Mdot
.828 .12344 Mdot
.828 .12415 Mdot
.828 .12493 Mdot
.828 .12503 Mdot
.828 .12525 Mdot
.828 .12529 Mdot
.828 .12547 Mdot
.828 .1255 Mdot
.828 .12563 Mdot
.828 .12563 Mdot
.828 .12578 Mdot
.828 .12606 Mdot
.828 .1265 Mdot
.828 .12676 Mdot
.828 .12688 Mdot
.828 .12784 Mdot
.828 .12793 Mdot
.828 .12907 Mdot
.828 .12953 Mdot
.828 .13093 Mdot
.828 .13139 Mdot
.828 .13198 Mdot
.828 .1321 Mdot
.828 .13238 Mdot
.828 .1326 Mdot
.828 .13378 Mdot
.828 .13417 Mdot
.828 .13443 Mdot
.828 .13458 Mdot
.828 .1346 Mdot
.828 .13476 Mdot
.828 .13504 Mdot
.828 .13552 Mdot
.828 .13561 Mdot
.828 .13574 Mdot
.828 .13578 Mdot
.828 .13693 Mdot
.828 .13724 Mdot
.828 .13728 Mdot
.828 .13814 Mdot
.828 .13879 Mdot
.828 .13895 Mdot
.828 .13903 Mdot
.828 .13994 Mdot
.828 .14 Mdot
.828 .14003 Mdot
.828 .14038 Mdot
.828 .14065 Mdot
.828 .14104 Mdot
.828 .1413 Mdot
.828 .14226 Mdot
.828 .14261 Mdot
.828 .14288 Mdot
.828 .14351 Mdot
.828 .14365 Mdot
.828 .14481 Mdot
.828 .14499 Mdot
.828 .14561 Mdot
.828 .14606 Mdot
.828 .14625 Mdot
.828 .14648 Mdot
.828 .14693 Mdot
.828 .14772 Mdot
.828 .14884 Mdot
.828 .14893 Mdot
.828 .14903 Mdot
.828 .14952 Mdot
.828 .15021 Mdot
.828 .15027 Mdot
.828 .15035 Mdot
.828 .1507 Mdot
.828 .15093 Mdot
.828 .15118 Mdot
.828 .15165 Mdot
.828 .15324 Mdot
.828 .15373 Mdot
.828 .15387 Mdot
.828 .15415 Mdot
.828 .1548 Mdot
.828 .15533 Mdot
.828 .15565 Mdot
.828 .15583 Mdot
.828 .15638 Mdot
.828 .15699 Mdot
.828 .15731 Mdot
.828 .15793 Mdot
.828 .15829 Mdot
.828 .15887 Mdot
.828 .15904 Mdot
.828 .15935 Mdot
.828 .15959 Mdot
.828 .15964 Mdot
.828 .16027 Mdot
.828 .1609 Mdot
.828 .16094 Mdot
.828 .16123 Mdot
.828 .16161 Mdot
.828 .16279 Mdot
.828 .16303 Mdot
.828 .16306 Mdot
.828 .16364 Mdot
.828 .1647 Mdot
.828 .16474 Mdot
.828 .16492 Mdot
.828 .16509 Mdot
.828 .16559 Mdot
.828 .16567 Mdot
.828 .16591 Mdot
.828 .16693 Mdot
.828 .16771 Mdot
.828 .16799 Mdot
.828 .16843 Mdot
.828 .16859 Mdot
.828 .16913 Mdot
.828 .17044 Mdot
.828 .17075 Mdot
.828 .17118 Mdot
.828 .17184 Mdot
.828 .17219 Mdot
.828 .17243 Mdot
.828 .17264 Mdot
.828 .17349 Mdot
.828 .17472 Mdot
.828 .17498 Mdot
.828 .17533 Mdot
.828 .17543 Mdot
.828 .17594 Mdot
.828 .17638 Mdot
.828 .17707 Mdot
.828 .17748 Mdot
.828 .17819 Mdot
.828 .17822 Mdot
.828 .17915 Mdot
.828 .17961 Mdot
.828 .17971 Mdot
.828 .18047 Mdot
.828 .18049 Mdot
.828 .18164 Mdot
.828 .18189 Mdot
.828 .18218 Mdot
.828 .18223 Mdot
.828 .1825 Mdot
.828 .18255 Mdot
.828 .18295 Mdot
.828 .18298 Mdot
.828 .18323 Mdot
.828 .18355 Mdot
.828 .18384 Mdot
.828 .18454 Mdot
.828 .18609 Mdot
.828 .18679 Mdot
.828 .18778 Mdot
.828 .18794 Mdot
.828 .1881 Mdot
.828 .18826 Mdot
.828 .18893 Mdot
.828 .18911 Mdot
.828 .18976 Mdot
.828 .18979 Mdot
.828 .19017 Mdot
.828 .19042 Mdot
.828 .19069 Mdot
.828 .19164 Mdot
.828 .19188 Mdot
.828 .19217 Mdot
.828 .19303 Mdot
.828 .19399 Mdot
.828 .19477 Mdot
.828 .19564 Mdot
.828 .19593 Mdot
.828 .19724 Mdot
.828 .19739 Mdot
.828 .19753 Mdot
.828 .19775 Mdot
.828 .19784 Mdot
.828 .19812 Mdot
.828 .19818 Mdot
.828 .19839 Mdot
.828 .19839 Mdot
.828 .19862 Mdot
.828 .19864 Mdot
.828 .19875 Mdot
.828 .1991 Mdot
.828 .19984 Mdot
.828 .20026 Mdot
.828 .20046 Mdot
.828 .20073 Mdot
.828 .20136 Mdot
.828 .20205 Mdot
.828 .20221 Mdot
.828 .20409 Mdot
.828 .20419 Mdot
.828 .20484 Mdot
.828 .20621 Mdot
.828 .2064 Mdot
.828 .20716 Mdot
.828 .20719 Mdot
.828 .20792 Mdot
.828 .20796 Mdot
.828 .20891 Mdot
.828 .2091 Mdot
.828 .20933 Mdot
.828 .20936 Mdot
.828 .20956 Mdot
.828 .20993 Mdot
.828 .21023 Mdot
.828 .21059 Mdot
.828 .21169 Mdot
.828 .21189 Mdot
.828 .21253 Mdot
.828 .21296 Mdot
.828 .21321 Mdot
.828 .21324 Mdot
.828 .21351 Mdot
.828 .21397 Mdot
.828 .21454 Mdot
.828 .21476 Mdot
.828 .21491 Mdot
.828 .21513 Mdot
.828 .21519 Mdot
.828 .2163 Mdot
.828 .2171 Mdot
.828 .21762 Mdot
.828 .21769 Mdot
.828 .2182 Mdot
.828 .21855 Mdot
.828 .21911 Mdot
.828 .21922 Mdot
.828 .21989 Mdot
.828 .22018 Mdot
.828 .22045 Mdot
.828 .22059 Mdot
.828 .22084 Mdot
.828 .22114 Mdot
.828 .22209 Mdot
.828 .22219 Mdot
.828 .22223 Mdot
.828 .22282 Mdot
.828 .22312 Mdot
.828 .22326 Mdot
.828 .22388 Mdot
.828 .22391 Mdot
.828 .22434 Mdot
.828 .22593 Mdot
.828 .2263 Mdot
.828 .22651 Mdot
.828 .22696 Mdot
.828 .228 Mdot
.828 .22823 Mdot
.828 .23014 Mdot
.828 .23015 Mdot
.828 .23031 Mdot
.828 .23044 Mdot
.828 .23148 Mdot
.828 .23202 Mdot
.828 .23223 Mdot
.828 .23228 Mdot
.828 .23253 Mdot
.828 .23291 Mdot
.828 .23365 Mdot
.828 .23367 Mdot
.828 .23497 Mdot
.828 .23564 Mdot
.828 .23581 Mdot
.828 .23683 Mdot
.828 .23698 Mdot
.828 .23704 Mdot
.828 .23714 Mdot
.828 .23795 Mdot
.828 .2386 Mdot
.828 .23909 Mdot
.828 .23919 Mdot
.828 .23933 Mdot
.828 .2399 Mdot
.828 .24023 Mdot
.828 .24028 Mdot
.828 .24071 Mdot
.828 .24131 Mdot
.828 .24148 Mdot
.828 .24177 Mdot
.828 .24225 Mdot
.828 .24411 Mdot
.828 .24493 Mdot
.828 .24515 Mdot
.828 .24549 Mdot
.828 .24562 Mdot
.828 .24611 Mdot
.828 .24657 Mdot
.828 .24659 Mdot
.828 .24669 Mdot
.828 .24683 Mdot
.828 .24757 Mdot
.828 .2481 Mdot
.828 .2484 Mdot
.828 .24932 Mdot
.828 .25032 Mdot
.828 .25085 Mdot
.828 .25171 Mdot
.828 .25187 Mdot
.828 .25247 Mdot
.828 .25288 Mdot
.828 .25343 Mdot
.828 .25371 Mdot
.828 .25423 Mdot
.828 .25447 Mdot
.828 .25462 Mdot
.828 .25472 Mdot
.828 .25494 Mdot
.828 .25519 Mdot
.828 .25576 Mdot
.828 .25679 Mdot
.828 .25686 Mdot
.828 .25725 Mdot
.828 .25734 Mdot
.828 .25797 Mdot
.828 .25924 Mdot
.828 .25993 Mdot
.828 .26033 Mdot
.828 .26038 Mdot
.828 .2611 Mdot
.828 .26133 Mdot
.828 .26236 Mdot
.828 .2631 Mdot
.828 .26316 Mdot
.828 .26345 Mdot
.828 .26374 Mdot
.828 .26423 Mdot
.828 .26424 Mdot
.828 .26456 Mdot
.828 .26469 Mdot
.828 .26509 Mdot
.828 .26613 Mdot
.828 .26678 Mdot
.828 .26747 Mdot
.828 .26759 Mdot
.828 .26784 Mdot
.828 .26808 Mdot
.828 .26843 Mdot
.828 .26854 Mdot
.828 .26926 Mdot
.828 .26954 Mdot
.828 .27042 Mdot
.828 .27182 Mdot
.828 .27188 Mdot
.828 .27251 Mdot
.828 .2726 Mdot
.828 .2731 Mdot
.828 .27383 Mdot
.828 .27389 Mdot
.828 .27434 Mdot
.828 .27491 Mdot
.828 .2755 Mdot
.828 .2759 Mdot
.828 .27606 Mdot
.828 .27624 Mdot
.828 .27742 Mdot
.828 .27765 Mdot
.828 .27781 Mdot
.828 .27782 Mdot
.828 .27791 Mdot
.828 .27969 Mdot
.828 .28011 Mdot
.828 .28069 Mdot
.828 .28086 Mdot
.828 .28096 Mdot
.828 .28171 Mdot
.828 .28243 Mdot
.828 .28311 Mdot
.828 .28357 Mdot
.828 .28425 Mdot
.828 .28426 Mdot
.828 .28495 Mdot
.828 .28543 Mdot
.828 .28548 Mdot
.828 .28557 Mdot
.828 .28578 Mdot
.828 .28702 Mdot
.828 .28704 Mdot
.828 .28727 Mdot
.828 .28778 Mdot
.828 .28794 Mdot
.828 .28857 Mdot
.828 .28906 Mdot
.828 .28921 Mdot
.828 .28921 Mdot
.828 .28924 Mdot
.828 .29035 Mdot
.828 .29114 Mdot
.828 .29155 Mdot
.828 .29181 Mdot
.828 .29203 Mdot
.828 .29211 Mdot
.828 .29257 Mdot
.828 .29265 Mdot
.828 .29313 Mdot
.828 .29331 Mdot
.828 .29336 Mdot
.828 .29378 Mdot
.828 .29431 Mdot
.828 .29479 Mdot
.828 .29595 Mdot
.828 .2963 Mdot
.828 .29726 Mdot
.828 .29852 Mdot
.828 .29968 Mdot
.828 .29989 Mdot
.828 .30132 Mdot
.828 .30158 Mdot
.828 .30184 Mdot
.828 .3021 Mdot
.828 .30321 Mdot
.828 .30335 Mdot
.828 .30351 Mdot
.828 .30459 Mdot
.828 .30463 Mdot
.828 .30526 Mdot
.828 .30569 Mdot
.828 .30613 Mdot
.828 .30653 Mdot
.828 .30711 Mdot
.828 .3077 Mdot
.828 .3081 Mdot
.828 .30857 Mdot
.828 .31001 Mdot
.828 .31102 Mdot
.828 .31159 Mdot
.828 .31173 Mdot
.828 .31247 Mdot
.828 .31288 Mdot
.828 .31318 Mdot
.828 .31432 Mdot
.828 .31481 Mdot
.828 .31621 Mdot
.828 .31661 Mdot
.828 .31697 Mdot
.828 .31704 Mdot
.828 .31723 Mdot
.828 .31745 Mdot
.828 .31783 Mdot
.828 .31796 Mdot
.828 .31843 Mdot
.828 .31853 Mdot
.828 .31888 Mdot
.828 .31889 Mdot
.828 .31925 Mdot
.828 .3193 Mdot
.828 .31948 Mdot
.828 .32001 Mdot
.828 .32006 Mdot
.828 .32012 Mdot
.828 .32128 Mdot
.828 .32185 Mdot
.828 .32198 Mdot
.828 .32231 Mdot
.828 .32275 Mdot
.828 .32301 Mdot
.828 .3238 Mdot
.828 .32421 Mdot
.828 .32495 Mdot
.828 .3252 Mdot
.828 .32531 Mdot
.828 .32692 Mdot
.828 .32832 Mdot
.828 .32848 Mdot
.828 .32854 Mdot
.828 .32956 Mdot
.828 .32963 Mdot
.828 .33093 Mdot
.828 .33183 Mdot
.828 .33214 Mdot
.828 .33341 Mdot
.828 .33345 Mdot
.828 .33467 Mdot
.828 .33474 Mdot
.828 .33485 Mdot
.828 .33631 Mdot
.828 .33662 Mdot
.828 .337 Mdot
.828 .33705 Mdot
.828 .33739 Mdot
.828 .33798 Mdot
.828 .33848 Mdot
.828 .33908 Mdot
.828 .3409 Mdot
.828 .34124 Mdot
.828 .3423 Mdot
.828 .343 Mdot
.828 .34342 Mdot
.828 .34347 Mdot
.828 .34391 Mdot
.828 .34469 Mdot
.828 .34563 Mdot
.828 .346 Mdot
.828 .34624 Mdot
.828 .34661 Mdot
.828 .34671 Mdot
.828 .34854 Mdot
.828 .34987 Mdot
.828 .35072 Mdot
.828 .35084 Mdot
.828 .35168 Mdot
.828 .35226 Mdot
.828 .3532 Mdot
.828 .35338 Mdot
.828 .35448 Mdot
.828 .35496 Mdot
.828 .3554 Mdot
.828 .35564 Mdot
.828 .35606 Mdot
.828 .35656 Mdot
.828 .35813 Mdot
.828 .35829 Mdot
.828 .35836 Mdot
.828 .35934 Mdot
.828 .35983 Mdot
.828 .36007 Mdot
.828 .36109 Mdot
.828 .36114 Mdot
.828 .36185 Mdot
.828 .36448 Mdot
.828 .3651 Mdot
.828 .36544 Mdot
.828 .36619 Mdot
.828 .36791 Mdot
.828 .36829 Mdot
.828 .37146 Mdot
.828 .37148 Mdot
.828 .37174 Mdot
.828 .37196 Mdot
.828 .37368 Mdot
.828 .37457 Mdot
.828 .37491 Mdot
.828 .375 Mdot
.828 .37542 Mdot
.828 .37605 Mdot
.828 .37728 Mdot
.828 .3773 Mdot
.828 .37945 Mdot
.828 .38057 Mdot
.828 .38085 Mdot
.828 .38253 Mdot
.828 .38278 Mdot
.828 .38289 Mdot
.828 .38306 Mdot
.828 .38438 Mdot
.828 .38547 Mdot
.828 .38628 Mdot
.828 .38644 Mdot
.828 .38668 Mdot
.828 .38763 Mdot
.828 .38817 Mdot
.828 .38825 Mdot
.828 .38896 Mdot
.828 .38996 Mdot
.828 .39024 Mdot
.828 .39071 Mdot
.828 .39151 Mdot
.828 .3946 Mdot
.828 .39594 Mdot
.828 .39631 Mdot
.828 .39688 Mdot
.828 .39709 Mdot
.828 .39791 Mdot
.828 .39867 Mdot
.828 .39869 Mdot
.828 .39887 Mdot
.828 .3991 Mdot
.828 .40032 Mdot
.828 .4012 Mdot
.828 .4017 Mdot
.828 .40322 Mdot
.828 .40488 Mdot
.828 .40576 Mdot
.828 .40717 Mdot
.828 .40745 Mdot
.828 .40843 Mdot
.828 .40911 Mdot
.828 .41003 Mdot
.828 .41049 Mdot
.828 .41135 Mdot
.828 .41175 Mdot
.828 .412 Mdot
.828 .41216 Mdot
.828 .41253 Mdot
.828 .41295 Mdot
.828 .41389 Mdot
.828 .4156 Mdot
.828 .41571 Mdot
.828 .41635 Mdot
.828 .4165 Mdot
.828 .41755 Mdot
.828 .41965 Mdot
.828 .42079 Mdot
.828 .42145 Mdot
.828 .42153 Mdot
.828 .42272 Mdot
.828 .4231 Mdot
.828 .42481 Mdot
.828 .42603 Mdot
.828 .42615 Mdot
.828 .42662 Mdot
.828 .42709 Mdot
.828 .42792 Mdot
.828 .42793 Mdot
.828 .42846 Mdot
.828 .42868 Mdot
.828 .42934 Mdot
.828 .43107 Mdot
.828 .43213 Mdot
.828 .43327 Mdot
.828 .43348 Mdot
.828 .43389 Mdot
.828 .43429 Mdot
.828 .43487 Mdot
.828 .43505 Mdot
.828 .43624 Mdot
.828 .4367 Mdot
.828 .43817 Mdot
.828 .44048 Mdot
.828 .44059 Mdot
.828 .44162 Mdot
.828 .44177 Mdot
.828 .4426 Mdot
.828 .44381 Mdot
.828 .44391 Mdot
.828 .44465 Mdot
.828 .44559 Mdot
.828 .44658 Mdot
.828 .44723 Mdot
.828 .4475 Mdot
.828 .44779 Mdot
.828 .44975 Mdot
.828 .45013 Mdot
.828 .45041 Mdot
.828 .45042 Mdot
.828 .45056 Mdot
.828 .45351 Mdot
.828 .45421 Mdot
.828 .45518 Mdot
.828 .45546 Mdot
.828 .45561 Mdot
.828 .45685 Mdot
.828 .45806 Mdot
.828 .45918 Mdot
.828 .45994 Mdot
.828 .46107 Mdot
.828 .46108 Mdot
.828 .46222 Mdot
.828 .46302 Mdot
.828 .4631 Mdot
.828 .46325 Mdot
.828 .46361 Mdot
.828 .46565 Mdot
.828 .46569 Mdot
.828 .46607 Mdot
.828 .4669 Mdot
.828 .46717 Mdot
.828 .46821 Mdot
.828 .46903 Mdot
.828 .46927 Mdot
.828 .46928 Mdot
.828 .46933 Mdot
.828 .47117 Mdot
.828 .47247 Mdot
.828 .47316 Mdot
.828 .47358 Mdot
.828 .47396 Mdot
.828 .47409 Mdot
.828 .47485 Mdot
.828 .47498 Mdot
.828 .47577 Mdot
.828 .47606 Mdot
.828 .47615 Mdot
.828 .47684 Mdot
.828 .47772 Mdot
.828 .47852 Mdot
.828 .48043 Mdot
.828 .48101 Mdot
.828 .4826 Mdot
.828 .48469 Mdot
.828 .48661 Mdot
.828 .48696 Mdot
.828 .48933 Mdot
.828 .48976 Mdot
.828 .4902 Mdot
.828 .49063 Mdot
.828 .49246 Mdot
.828 .4927 Mdot
.828 .49296 Mdot
.828 .49475 Mdot
.828 .49482 Mdot
.828 .49586 Mdot
.828 .49657 Mdot
.828 .49729 Mdot
.828 .49795 Mdot
.828 .49892 Mdot
.828 .49991 Mdot
.828 .50056 Mdot
.828 .50135 Mdot
.828 .50372 Mdot
.83 .0148 Mdot
.83 .01486 Mdot
.83 .01496 Mdot
.83 .01512 Mdot
.83 .01539 Mdot
.83 .01583 Mdot
.83 .01634 Mdot
.83 .01656 Mdot
.83 .01724 Mdot
.83 .01741 Mdot
.83 .01778 Mdot
.83 .01819 Mdot
.83 .01891 Mdot
.83 .01894 Mdot
.83 .01919 Mdot
.83 .01925 Mdot
.83 .01981 Mdot
.83 .02022 Mdot
.83 .02034 Mdot
.83 .02048 Mdot
.83 .02166 Mdot
.83 .02168 Mdot
.83 .02172 Mdot
.83 .02214 Mdot
.83 .02225 Mdot
.83 .02317 Mdot
.83 .02385 Mdot
.83 .02396 Mdot
.83 .02405 Mdot
.83 .02428 Mdot
.83 .02624 Mdot
.83 .02627 Mdot
.83 .02635 Mdot
.83 .02688 Mdot
.83 .02703 Mdot
.83 .02704 Mdot
.83 .02715 Mdot
.83 .02721 Mdot
.83 .02791 Mdot
.83 .02826 Mdot
.83 .0286 Mdot
.83 .02874 Mdot
.83 .02877 Mdot
.83 .02923 Mdot
.83 .02924 Mdot
.83 .0297 Mdot
.83 .02989 Mdot
.83 .03007 Mdot
.83 .03022 Mdot
.83 .03049 Mdot
.83 .03059 Mdot
.83 .03092 Mdot
.83 .03222 Mdot
.83 .03283 Mdot
.83 .03306 Mdot
.83 .03384 Mdot
.83 .0339 Mdot
.83 .03402 Mdot
.83 .03403 Mdot
.83 .0349 Mdot
.83 .03513 Mdot
.83 .03517 Mdot
.83 .03518 Mdot
.83 .03535 Mdot
.83 .03546 Mdot
.83 .03645 Mdot
.83 .03662 Mdot
.83 .0372 Mdot
.83 .03777 Mdot
.83 .038 Mdot
.83 .03805 Mdot
.83 .03839 Mdot
.83 .0388 Mdot
.83 .03882 Mdot
.83 .03887 Mdot
.83 .03915 Mdot
.83 .03959 Mdot
.83 .0399 Mdot
.83 .0402 Mdot
.83 .04038 Mdot
.83 .04045 Mdot
.83 .0409 Mdot
.83 .04107 Mdot
.83 .04115 Mdot
.83 .0415 Mdot
.83 .04162 Mdot
.83 .04304 Mdot
.83 .04309 Mdot
.83 .04312 Mdot
.83 .04377 Mdot
.83 .04436 Mdot
.83 .0444 Mdot
.83 .04478 Mdot
.83 .04516 Mdot
.83 .04534 Mdot
.83 .04647 Mdot
.83 .04657 Mdot
.83 .04676 Mdot
.83 .04678 Mdot
.83 .04823 Mdot
.83 .0486 Mdot
.83 .04866 Mdot
.83 .04868 Mdot
.83 .04898 Mdot
.83 .04916 Mdot
.83 .04982 Mdot
.83 .04995 Mdot
.83 .05029 Mdot
.83 .05053 Mdot
.83 .05079 Mdot
.83 .0508 Mdot
.83 .05108 Mdot
.83 .0517 Mdot
.83 .05204 Mdot
.83 .05299 Mdot
.83 .05316 Mdot
.83 .05337 Mdot
.83 .05346 Mdot
.83 .05386 Mdot
.83 .05402 Mdot
.83 .0547 Mdot
.83 .05473 Mdot
.83 .05476 Mdot
.83 .05481 Mdot
.83 .05511 Mdot
.83 .05527 Mdot
.83 .05601 Mdot
.83 .05648 Mdot
.83 .05652 Mdot
.83 .05702 Mdot
.83 .05717 Mdot
.83 .05732 Mdot
.83 .05743 Mdot
.83 .05759 Mdot
.83 .05768 Mdot
.83 .0579 Mdot
.83 .05818 Mdot
.83 .05846 Mdot
.83 .0586 Mdot
.83 .05897 Mdot
.83 .05918 Mdot
.83 .05923 Mdot
.83 .05937 Mdot
.83 .06 Mdot
.83 .06039 Mdot
.83 .06048 Mdot
.83 .06081 Mdot
.83 .06097 Mdot
.83 .06173 Mdot
.83 .06183 Mdot
.83 .06186 Mdot
.83 .06233 Mdot
.83 .0625 Mdot
.83 .06294 Mdot
.83 .06393 Mdot
.83 .06399 Mdot
.83 .06435 Mdot
.83 .06462 Mdot
.83 .06526 Mdot
.83 .0655 Mdot
.83 .06556 Mdot
.83 .0658 Mdot
.83 .06742 Mdot
.83 .06759 Mdot
.83 .06792 Mdot
.83 .06794 Mdot
.83 .06795 Mdot
.83 .06814 Mdot
.83 .06819 Mdot
.83 .07034 Mdot
.83 .07097 Mdot
.83 .07103 Mdot
.83 .07107 Mdot
.83 .0711 Mdot
.83 .07159 Mdot
.83 .07172 Mdot
.83 .07189 Mdot
.83 .0723 Mdot
.83 .07299 Mdot
.83 .07321 Mdot
.83 .07377 Mdot
.83 .07417 Mdot
.83 .0746 Mdot
.83 .07462 Mdot
.83 .07477 Mdot
.83 .07487 Mdot
.83 .07508 Mdot
.83 .07528 Mdot
.83 .07528 Mdot
.83 .07535 Mdot
.83 .0761 Mdot
.83 .07668 Mdot
.83 .077 Mdot
.83 .07824 Mdot
.83 .07853 Mdot
.83 .07888 Mdot
.83 .07903 Mdot
.83 .07969 Mdot
.83 .07997 Mdot
.83 .08109 Mdot
.83 .08114 Mdot
.83 .08118 Mdot
.83 .08127 Mdot
.83 .08166 Mdot
.83 .08177 Mdot
.83 .08204 Mdot
.83 .08326 Mdot
.83 .08404 Mdot
.83 .08411 Mdot
.83 .08442 Mdot
.83 .08495 Mdot
.83 .08504 Mdot
.83 .08518 Mdot
.83 .08537 Mdot
.83 .08545 Mdot
.83 .08563 Mdot
.83 .08589 Mdot
.83 .08604 Mdot
.83 .08608 Mdot
.83 .0864 Mdot
.83 .08677 Mdot
.83 .08686 Mdot
.83 .08733 Mdot
.83 .08756 Mdot
.83 .08817 Mdot
.83 .08853 Mdot
.83 .08862 Mdot
.83 .08875 Mdot
.83 .08884 Mdot
.83 .08989 Mdot
.83 .09053 Mdot
.83 .09068 Mdot
.83 .09123 Mdot
.83 .09151 Mdot
.83 .09276 Mdot
.83 .09292 Mdot
.83 .09298 Mdot
.83 .09359 Mdot
.83 .09375 Mdot
.83 .09404 Mdot
.83 .09469 Mdot
.83 .09477 Mdot
.83 .09502 Mdot
.83 .09639 Mdot
.83 .09641 Mdot
.83 .09651 Mdot
.83 .09712 Mdot
.83 .09756 Mdot
.83 .09861 Mdot
.83 .09902 Mdot
.83 .09911 Mdot
.83 .09951 Mdot
.83 .09959 Mdot
.83 .1007 Mdot
.83 .1007 Mdot
.83 .10084 Mdot
.83 .10187 Mdot
.83 .10221 Mdot
.83 .10249 Mdot
.83 .10303 Mdot
.83 .10308 Mdot
.83 .10308 Mdot
.83 .10341 Mdot
.83 .10348 Mdot
.83 .10359 Mdot
.83 .10397 Mdot
.83 .10487 Mdot
.83 .10698 Mdot
.83 .10706 Mdot
.83 .10798 Mdot
.83 .10809 Mdot
.83 .1082 Mdot
.83 .10826 Mdot
.83 .10831 Mdot
.83 .10913 Mdot
.83 .10934 Mdot
.83 .10963 Mdot
.83 .11031 Mdot
.83 .11045 Mdot
.83 .11096 Mdot
.83 .11145 Mdot
.83 .11182 Mdot
.83 .11274 Mdot
.83 .11341 Mdot
.83 .11412 Mdot
.83 .11415 Mdot
.83 .11441 Mdot
.83 .11441 Mdot
.83 .11458 Mdot
.83 .11492 Mdot
.83 .11525 Mdot
.83 .11526 Mdot
.83 .11537 Mdot
.83 .11567 Mdot
.83 .11612 Mdot
.83 .11647 Mdot
.83 .11662 Mdot
.83 .11757 Mdot
.83 .1177 Mdot
.83 .11811 Mdot
.83 .11818 Mdot
.83 .11973 Mdot
.83 .12017 Mdot
.83 .12065 Mdot
.83 .12123 Mdot
.83 .12147 Mdot
.83 .12257 Mdot
.83 .12278 Mdot
.83 .12294 Mdot
.83 .12303 Mdot
.83 .12404 Mdot
.83 .1249 Mdot
.83 .12498 Mdot
.83 .12505 Mdot
.83 .12519 Mdot
.83 .12519 Mdot
.83 .12584 Mdot
.83 .12603 Mdot
.83 .12624 Mdot
.83 .12648 Mdot
.83 .12736 Mdot
.83 .12821 Mdot
.83 .12851 Mdot
.83 .12871 Mdot
.83 .12972 Mdot
.83 .12979 Mdot
.83 .12985 Mdot
.83 .12991 Mdot
.83 .13042 Mdot
.83 .13115 Mdot
.83 .1313 Mdot
.83 .13146 Mdot
.83 .13169 Mdot
.83 .13175 Mdot
.83 .132 Mdot
.83 .13213 Mdot
.83 .13243 Mdot
.83 .13287 Mdot
.83 .13312 Mdot
.83 .13318 Mdot
.83 .1337 Mdot
.83 .13371 Mdot
.83 .13433 Mdot
.83 .13448 Mdot
.83 .13461 Mdot
.83 .13515 Mdot
.83 .13526 Mdot
.83 .13563 Mdot
.83 .13665 Mdot
.83 .13725 Mdot
.83 .13739 Mdot
.83 .13746 Mdot
.83 .13762 Mdot
.83 .13777 Mdot
.83 .1382 Mdot
.83 .1395 Mdot
.83 .14057 Mdot
.83 .14082 Mdot
.83 .14082 Mdot
.83 .14173 Mdot
.83 .14219 Mdot
.83 .14381 Mdot
.83 .14409 Mdot
.83 .14418 Mdot
.83 .14426 Mdot
.83 .14453 Mdot
.83 .14464 Mdot
.83 .14497 Mdot
.83 .14564 Mdot
.83 .14592 Mdot
.83 .1464 Mdot
.83 .14683 Mdot
.83 .14719 Mdot
.83 .14747 Mdot
.83 .1476 Mdot
.83 .14803 Mdot
.83 .14823 Mdot
.83 .14885 Mdot
.83 .14901 Mdot
.83 .14958 Mdot
.83 .1503 Mdot
.83 .15032 Mdot
.83 .15049 Mdot
.83 .1512 Mdot
.83 .1515 Mdot
.83 .15224 Mdot
.83 .15295 Mdot
.83 .15399 Mdot
.83 .15467 Mdot
.83 .15482 Mdot
.83 .15548 Mdot
.83 .1556 Mdot
.83 .15623 Mdot
.83 .15736 Mdot
.83 .15746 Mdot
.83 .15746 Mdot
.83 .15768 Mdot
.83 .1594 Mdot
.83 .15996 Mdot
.83 .16042 Mdot
.83 .16096 Mdot
.83 .16132 Mdot
.83 .16139 Mdot
.83 .1614 Mdot
.83 .16194 Mdot
.83 .16207 Mdot
.83 .16224 Mdot
.83 .16287 Mdot
.83 .16406 Mdot
.83 .16437 Mdot
.83 .16475 Mdot
.83 .16721 Mdot
.83 .16779 Mdot
.83 .16787 Mdot
.83 .16801 Mdot
.83 .16836 Mdot
.83 .16954 Mdot
.83 .16972 Mdot
.83 .16989 Mdot
.83 .17 Mdot
.83 .17008 Mdot
.83 .1712 Mdot
.83 .17144 Mdot
.83 .1716 Mdot
.83 .17178 Mdot
.83 .17227 Mdot
.83 .1734 Mdot
.83 .17363 Mdot
.83 .17447 Mdot
.83 .17448 Mdot
.83 .17529 Mdot
.83 .1759 Mdot
.83 .1761 Mdot
.83 .17641 Mdot
.83 .17682 Mdot
.83 .17683 Mdot
.83 .17744 Mdot
.83 .17784 Mdot
.83 .17786 Mdot
.83 .17855 Mdot
.83 .17973 Mdot
.83 .17978 Mdot
.83 .18021 Mdot
.83 .18021 Mdot
.83 .18048 Mdot
.83 .18105 Mdot
.83 .1816 Mdot
.83 .18162 Mdot
.83 .18181 Mdot
.83 .18231 Mdot
.83 .18304 Mdot
.83 .18363 Mdot
.83 .18387 Mdot
.83 .185 Mdot
.83 .18513 Mdot
.83 .18545 Mdot
.83 .18568 Mdot
.83 .18569 Mdot
.83 .18634 Mdot
.83 .18646 Mdot
.83 .18826 Mdot
.83 .18904 Mdot
.83 .18978 Mdot
.83 .1904 Mdot
.83 .19056 Mdot
.83 .19153 Mdot
.83 .19193 Mdot
.83 .19262 Mdot
.83 .19273 Mdot
.83 .19287 Mdot
.83 .19375 Mdot
.83 .1941 Mdot
.83 .19437 Mdot
.83 .19448 Mdot
.83 .19452 Mdot
.83 .19483 Mdot
.83 .19488 Mdot
.83 .19536 Mdot
.83 .19619 Mdot
.83 .19735 Mdot
.83 .19763 Mdot
.83 .19775 Mdot
.83 .19788 Mdot
.83 .19794 Mdot
.83 .1981 Mdot
.83 .19811 Mdot
.83 .19872 Mdot
.83 .19919 Mdot
.83 .19949 Mdot
.83 .19985 Mdot
.83 .20024 Mdot
.83 .2016 Mdot
.83 .2017 Mdot
.83 .20215 Mdot
.83 .20311 Mdot
.83 .20314 Mdot
.83 .20361 Mdot
.83 .20395 Mdot
.83 .20558 Mdot
.83 .20562 Mdot
.83 .20575 Mdot
.83 .20583 Mdot
.83 .20593 Mdot
.83 .20679 Mdot
.83 .20704 Mdot
.83 .20799 Mdot
.83 .20824 Mdot
.83 .20843 Mdot
.83 .20851 Mdot
.83 .20889 Mdot
.83 .20899 Mdot
.83 .20941 Mdot
.83 .20944 Mdot
.83 .20962 Mdot
.83 .21011 Mdot
.83 .21018 Mdot
.83 .21085 Mdot
.83 .21127 Mdot
.83 .21137 Mdot
.83 .21223 Mdot
.83 .21224 Mdot
.83 .21327 Mdot
.83 .21352 Mdot
.83 .21373 Mdot
.83 .21463 Mdot
.83 .21467 Mdot
.83 .21481 Mdot
.83 .21482 Mdot
.83 .21484 Mdot
.83 .21544 Mdot
.83 .21713 Mdot
.83 .21813 Mdot
.83 .21836 Mdot
.83 .21848 Mdot
.83 .21874 Mdot
.83 .21899 Mdot
.83 .2197 Mdot
.83 .22146 Mdot
.83 .22186 Mdot
.83 .22198 Mdot
.83 .22248 Mdot
.83 .22364 Mdot
.83 .22404 Mdot
.83 .22404 Mdot
.83 .22409 Mdot
.83 .22447 Mdot
.83 .22509 Mdot
.83 .22523 Mdot
.83 .22555 Mdot
.83 .22632 Mdot
.83 .22668 Mdot
.83 .22758 Mdot
.83 .22776 Mdot
.83 .22902 Mdot
.83 .22947 Mdot
.83 .22963 Mdot
.83 .22976 Mdot
.83 .23021 Mdot
.83 .23038 Mdot
.83 .23095 Mdot
.83 .23205 Mdot
.83 .23211 Mdot
.83 .23251 Mdot
.83 .23293 Mdot
.83 .23331 Mdot
.83 .23371 Mdot
.83 .23402 Mdot
.83 .23421 Mdot
.83 .23457 Mdot
.83 .23462 Mdot
.83 .23509 Mdot
.83 .23531 Mdot
.83 .23601 Mdot
.83 .23634 Mdot
.83 .23654 Mdot
.83 .23738 Mdot
.83 .23765 Mdot
.83 .2386 Mdot
.83 .23969 Mdot
.83 .23979 Mdot
.83 .23982 Mdot
.83 .24011 Mdot
.83 .24078 Mdot
.83 .24091 Mdot
.83 .24129 Mdot
.83 .24151 Mdot
.83 .24157 Mdot
.83 .24178 Mdot
.83 .24237 Mdot
.83 .243 Mdot
.83 .24419 Mdot
.83 .2446 Mdot
.83 .24591 Mdot
.83 .24703 Mdot
.83 .24728 Mdot
.83 .24818 Mdot
.83 .24839 Mdot
.83 .24859 Mdot
.83 .24962 Mdot
.83 .24977 Mdot
.83 .25081 Mdot
.83 .2514 Mdot
.83 .25151 Mdot
.83 .25166 Mdot
.83 .25167 Mdot
.83 .25204 Mdot
.83 .25204 Mdot
.83 .25463 Mdot
.83 .25468 Mdot
.83 .25488 Mdot
.83 .25581 Mdot
.83 .25659 Mdot
.83 .2574 Mdot
.83 .25744 Mdot
.83 .25749 Mdot
.83 .25807 Mdot
.83 .2582 Mdot
.83 .25822 Mdot
.83 .25839 Mdot
.83 .25911 Mdot
.83 .25933 Mdot
.83 .25961 Mdot
.83 .26066 Mdot
.83 .26086 Mdot
.83 .26121 Mdot
.83 .2621 Mdot
.83 .26263 Mdot
.83 .26313 Mdot
.83 .2635 Mdot
.83 .26377 Mdot
.83 .2654 Mdot
.83 .26545 Mdot
.83 .26546 Mdot
.83 .26786 Mdot
.83 .26805 Mdot
.83 .26823 Mdot
.83 .26882 Mdot
.83 .26895 Mdot
.83 .26918 Mdot
.83 .26923 Mdot
.83 .26976 Mdot
.83 .27008 Mdot
.83 .27015 Mdot
.83 .27173 Mdot
.83 .27202 Mdot
.83 .27231 Mdot
.83 .27249 Mdot
.83 .27262 Mdot
.83 .27334 Mdot
.83 .27448 Mdot
.83 .27487 Mdot
.83 .27492 Mdot
.83 .27514 Mdot
.83 .27516 Mdot
.83 .27545 Mdot
.83 .27626 Mdot
.83 .27756 Mdot
.83 .27814 Mdot
.83 .27851 Mdot
.83 .27873 Mdot
.83 .27896 Mdot
.83 .2799 Mdot
.83 .27992 Mdot
.83 .28091 Mdot
.83 .28092 Mdot
.83 .28127 Mdot
.83 .28216 Mdot
.83 .28229 Mdot
.83 .28261 Mdot
.83 .28312 Mdot
.83 .28381 Mdot
.83 .28383 Mdot
.83 .28383 Mdot
.83 .28477 Mdot
.83 .28484 Mdot
.83 .2852 Mdot
.83 .28551 Mdot
.83 .28553 Mdot
.83 .28669 Mdot
.83 .28726 Mdot
.83 .28735 Mdot
.83 .28822 Mdot
.83 .28865 Mdot
.83 .28873 Mdot
.83 .28944 Mdot
.83 .28944 Mdot
.83 .28989 Mdot
.83 .2905 Mdot
.83 .29084 Mdot
.83 .29099 Mdot
.83 .29174 Mdot
.83 .29178 Mdot
.83 .29209 Mdot
.83 .29292 Mdot
.83 .2931 Mdot
.83 .29386 Mdot
.83 .29414 Mdot
.83 .29511 Mdot
.83 .29552 Mdot
.83 .29654 Mdot
.83 .29739 Mdot
.83 .2976 Mdot
.83 .29767 Mdot
.83 .29814 Mdot
.83 .29851 Mdot
.83 .29854 Mdot
.83 .29962 Mdot
.83 .29982 Mdot
.83 .30049 Mdot
.83 .3028 Mdot
.83 .30283 Mdot
.83 .30341 Mdot
.83 .30359 Mdot
.83 .3041 Mdot
.83 .30489 Mdot
.83 .30531 Mdot
.83 .30592 Mdot
.83 .30599 Mdot
.83 .30635 Mdot
.83 .30662 Mdot
.83 .30822 Mdot
.83 .30889 Mdot
.83 .30897 Mdot
.83 .30951 Mdot
.83 .31004 Mdot
.83 .31021 Mdot
.83 .31045 Mdot
.83 .31137 Mdot
.83 .31192 Mdot
.83 .31249 Mdot
.83 .31294 Mdot
.83 .31313 Mdot
.83 .31371 Mdot
.83 .31379 Mdot
.83 .31458 Mdot
.83 .31597 Mdot
.83 .31772 Mdot
.83 .31782 Mdot
.83 .31789 Mdot
.83 .31835 Mdot
.83 .31856 Mdot
.83 .31876 Mdot
.83 .31887 Mdot
.83 .31914 Mdot
.83 .31914 Mdot
.83 .31942 Mdot
.83 .3199 Mdot
.83 .32016 Mdot
.83 .32094 Mdot
.83 .32131 Mdot
.83 .32145 Mdot
.83 .32203 Mdot
.83 .32269 Mdot
.83 .32349 Mdot
.83 .32466 Mdot
.83 .32495 Mdot
.83 .32511 Mdot
.83 .32586 Mdot
.83 .32632 Mdot
.83 .32653 Mdot
.83 .32746 Mdot
.83 .32749 Mdot
.83 .32751 Mdot
.83 .32825 Mdot
.83 .32828 Mdot
.83 .32885 Mdot
.83 .33154 Mdot
.83 .33162 Mdot
.83 .33183 Mdot
.83 .33197 Mdot
.83 .33213 Mdot
.83 .33267 Mdot
.83 .33355 Mdot
.83 .33397 Mdot
.83 .33452 Mdot
.83 .33473 Mdot
.83 .33555 Mdot
.83 .33597 Mdot
.83 .33623 Mdot
.83 .33628 Mdot
.83 .33641 Mdot
.83 .33705 Mdot
.83 .33721 Mdot
.83 .33768 Mdot
.83 .33791 Mdot
.83 .33796 Mdot
.83 .33816 Mdot
.83 .33826 Mdot
.83 .33908 Mdot
.83 .33918 Mdot
.83 .3403 Mdot
.83 .34099 Mdot
.83 .34117 Mdot
.83 .34246 Mdot
.83 .34258 Mdot
.83 .34261 Mdot
.83 .34432 Mdot
.83 .34473 Mdot
.83 .34509 Mdot
.83 .34658 Mdot
.83 .34664 Mdot
.83 .34688 Mdot
.83 .34688 Mdot
.83 .34693 Mdot
.83 .34792 Mdot
.83 .35072 Mdot
.83 .35239 Mdot
.83 .35276 Mdot
.83 .35296 Mdot
.83 .35339 Mdot
.83 .3538 Mdot
.83 .355 Mdot
.83 .35791 Mdot
.83 .35857 Mdot
.83 .35878 Mdot
.83 .3596 Mdot
.83 .36152 Mdot
.83 .3622 Mdot
.83 .3622 Mdot
.83 .36228 Mdot
.83 .3629 Mdot
.83 .36393 Mdot
.83 .36416 Mdot
.83 .3647 Mdot
.83 .36598 Mdot
.83 .36658 Mdot
.83 .36807 Mdot
.83 .36837 Mdot
.83 .37045 Mdot
.83 .37121 Mdot
.83 .37148 Mdot
.83 .37169 Mdot
.83 .37244 Mdot
.83 .37272 Mdot
.83 .37366 Mdot
.83 .37549 Mdot
.83 .37559 Mdot
.83 .37625 Mdot
.83 .37695 Mdot
.83 .37758 Mdot
.83 .37825 Mdot
.83 .37877 Mdot
.83 .37907 Mdot
.83 .37968 Mdot
.83 .37975 Mdot
.83 .38054 Mdot
.83 .3809 Mdot
.83 .38207 Mdot
.83 .38262 Mdot
.83 .38295 Mdot
.83 .38434 Mdot
.83 .38479 Mdot
.83 .38636 Mdot
.83 .38817 Mdot
.83 .38833 Mdot
.83 .38839 Mdot
.83 .38887 Mdot
.83 .38998 Mdot
.83 .3902 Mdot
.83 .39082 Mdot
.83 .3912 Mdot
.83 .3913 Mdot
.83 .39164 Mdot
.83 .39262 Mdot
.83 .39367 Mdot
.83 .39564 Mdot
.83 .39633 Mdot
.83 .3985 Mdot
.83 .40036 Mdot
.83 .40078 Mdot
.83 .40226 Mdot
.83 .40261 Mdot
.83 .40295 Mdot
.83 .40466 Mdot
.83 .4049 Mdot
.83 .40663 Mdot
.83 .40761 Mdot
.83 .4078 Mdot
.83 .40805 Mdot
.83 .40806 Mdot
.83 .40867 Mdot
.83 .40868 Mdot
.83 .41298 Mdot
.83 .41306 Mdot
.83 .4134 Mdot
.83 .41494 Mdot
.83 .41623 Mdot
.83 .41757 Mdot
.83 .41763 Mdot
.83 .41772 Mdot
.83 .41869 Mdot
.83 .4189 Mdot
.83 .41893 Mdot
.83 .41922 Mdot
.83 .42042 Mdot
.83 .42077 Mdot
.83 .42124 Mdot
.83 .42298 Mdot
.83 .42331 Mdot
.83 .4239 Mdot
.83 .42537 Mdot
.83 .42625 Mdot
.83 .42709 Mdot
.83 .4277 Mdot
.83 .42814 Mdot
.83 .43085 Mdot
.83 .43094 Mdot
.83 .43095 Mdot
.83 .43494 Mdot
.83 .43525 Mdot
.83 .43555 Mdot
.83 .43653 Mdot
.83 .43675 Mdot
.83 .43713 Mdot
.83 .43721 Mdot
.83 .43809 Mdot
.83 .43863 Mdot
.83 .43874 Mdot
.83 .44136 Mdot
.83 .44185 Mdot
.83 .44232 Mdot
.83 .44262 Mdot
.83 .44284 Mdot
.83 .44403 Mdot
.83 .44592 Mdot
.83 .44658 Mdot
.83 .44666 Mdot
.83 .44702 Mdot
.83 .44706 Mdot
.83 .44754 Mdot
.83 .44888 Mdot
.83 .45104 Mdot
.83 .45199 Mdot
.83 .45262 Mdot
.83 .45298 Mdot
.83 .45336 Mdot
.83 .45493 Mdot
.83 .45495 Mdot
.83 .45659 Mdot
.83 .45661 Mdot
.83 .45719 Mdot
.83 .45867 Mdot
.83 .45889 Mdot
.83 .45942 Mdot
.83 .46027 Mdot
.83 .46141 Mdot
.83 .46144 Mdot
.83 .46145 Mdot
.83 .46301 Mdot
.83 .46312 Mdot
.83 .46372 Mdot
.83 .46423 Mdot
.83 .46427 Mdot
.83 .46619 Mdot
.83 .46715 Mdot
.83 .46729 Mdot
.83 .46874 Mdot
.83 .46944 Mdot
.83 .46958 Mdot
.83 .47075 Mdot
.83 .47076 Mdot
.83 .47151 Mdot
.83 .47251 Mdot
.83 .47308 Mdot
.83 .47334 Mdot
.83 .47458 Mdot
.83 .47464 Mdot
.83 .47516 Mdot
.83 .47653 Mdot
.83 .47683 Mdot
.83 .4781 Mdot
.83 .47856 Mdot
.83 .48017 Mdot
.83 .48085 Mdot
.83 .48255 Mdot
.83 .48396 Mdot
.83 .48431 Mdot
.83 .48441 Mdot
.83 .4852 Mdot
.83 .48582 Mdot
.83 .48587 Mdot
.83 .48766 Mdot
.83 .48798 Mdot
.83 .48911 Mdot
.83 .49293 Mdot
.83 .49299 Mdot
.83 .49396 Mdot
.83 .49424 Mdot
.83 .49509 Mdot
.83 .4964 Mdot
.83 .49711 Mdot
.83 .49811 Mdot
.83 .49824 Mdot
.83 .49882 Mdot
.83 .49928 Mdot
.83 .50194 Mdot
.83 .50305 Mdot
.83 .50318 Mdot
.83 .50408 Mdot
.83 .50495 Mdot
.83 .50524 Mdot
.832 .01492 Mdot
.832 .01506 Mdot
.832 .01528 Mdot
.832 .0153 Mdot
.832 .01565 Mdot
.832 .01568 Mdot
.832 .01599 Mdot
.832 .01627 Mdot
.832 .01632 Mdot
.832 .01684 Mdot
.832 .01698 Mdot
.832 .0173 Mdot
.832 .01739 Mdot
.832 .01776 Mdot
.832 .01793 Mdot
.832 .01826 Mdot
.832 .01848 Mdot
.832 .01878 Mdot
.832 .01899 Mdot
.832 .01902 Mdot
.832 .01916 Mdot
.832 .01979 Mdot
.832 .01982 Mdot
.832 .01984 Mdot
.832 .02007 Mdot
.832 .02036 Mdot
.832 .02061 Mdot
.832 .02098 Mdot
.832 .02138 Mdot
.832 .02148 Mdot
.832 .02169 Mdot
.832 .02179 Mdot
.832 .02183 Mdot
.832 .02188 Mdot
.832 .02212 Mdot
.832 .02309 Mdot
.832 .0231 Mdot
.832 .02315 Mdot
.832 .02321 Mdot
.832 .02324 Mdot
.832 .02362 Mdot
.832 .02373 Mdot
.832 .02397 Mdot
.832 .02408 Mdot
.832 .02411 Mdot
.832 .02453 Mdot
.832 .02514 Mdot
.832 .02548 Mdot
.832 .02581 Mdot
.832 .02598 Mdot
.832 .02617 Mdot
.832 .02633 Mdot
.832 .02649 Mdot
.832 .02656 Mdot
.832 .02664 Mdot
.832 .02664 Mdot
.832 .02703 Mdot
.832 .02794 Mdot
.832 .02865 Mdot
.832 .02866 Mdot
.832 .02876 Mdot
.832 .02884 Mdot
.832 .02891 Mdot
.832 .02927 Mdot
.832 .02954 Mdot
.832 .02972 Mdot
.832 .03011 Mdot
.832 .0303 Mdot
.832 .03035 Mdot
.832 .03048 Mdot
.832 .03104 Mdot
.832 .03206 Mdot
.832 .03224 Mdot
.832 .03247 Mdot
.832 .03263 Mdot
.832 .03317 Mdot
.832 .03345 Mdot
.832 .03378 Mdot
.832 .03404 Mdot
.832 .03431 Mdot
.832 .03443 Mdot
.832 .03456 Mdot
.832 .03456 Mdot
.832 .035 Mdot
.832 .03521 Mdot
.832 .03558 Mdot
.832 .03673 Mdot
.832 .03686 Mdot
.832 .03774 Mdot
.832 .0379 Mdot
.832 .03792 Mdot
.832 .03808 Mdot
.832 .03809 Mdot
.832 .03823 Mdot
.832 .03833 Mdot
.832 .03894 Mdot
.832 .03934 Mdot
.832 .03938 Mdot
.832 .03968 Mdot
.832 .04033 Mdot
.832 .0405 Mdot
.832 .04065 Mdot
.832 .04074 Mdot
.832 .04095 Mdot
.832 .04156 Mdot
.832 .04188 Mdot
.832 .0428 Mdot
.832 .04286 Mdot
.832 .04357 Mdot
.832 .04387 Mdot
.832 .04425 Mdot
.832 .04452 Mdot
.832 .04459 Mdot
.832 .0454 Mdot
.832 .04543 Mdot
.832 .0459 Mdot
.832 .04612 Mdot
.832 .04634 Mdot
.832 .04645 Mdot
.832 .04687 Mdot
.832 .04731 Mdot
.832 .04732 Mdot
.832 .04752 Mdot
.832 .04774 Mdot
.832 .04774 Mdot
.832 .04824 Mdot
.832 .04827 Mdot
.832 .04847 Mdot
.832 .04882 Mdot
.832 .04944 Mdot
.832 .04965 Mdot
.832 .05032 Mdot
.832 .05058 Mdot
.832 .05135 Mdot
.832 .05135 Mdot
.832 .05156 Mdot
.832 .05277 Mdot
.832 .05303 Mdot
.832 .0533 Mdot
.832 .05333 Mdot
.832 .0536 Mdot
.832 .05362 Mdot
.832 .05384 Mdot
.832 .05402 Mdot
.832 .05432 Mdot
.832 .05492 Mdot
.832 .05502 Mdot
.832 .05569 Mdot
.832 .05576 Mdot
.832 .05626 Mdot
.832 .05705 Mdot
.832 .05734 Mdot
.832 .05753 Mdot
.832 .05763 Mdot
.832 .05773 Mdot
.832 .05788 Mdot
.832 .05802 Mdot
.832 .05837 Mdot
.832 .05938 Mdot
.832 .0595 Mdot
.832 .0596 Mdot
.832 .05981 Mdot
.832 .05992 Mdot
.832 .06035 Mdot
.832 .06144 Mdot
.832 .06154 Mdot
.832 .06158 Mdot
.832 .06273 Mdot
.832 .06279 Mdot
.832 .06323 Mdot
.832 .06386 Mdot
.832 .06431 Mdot
.832 .06442 Mdot
.832 .06517 Mdot
.832 .0654 Mdot
.832 .06578 Mdot
.832 .06583 Mdot
.832 .06647 Mdot
.832 .0666 Mdot
.832 .06697 Mdot
.832 .06733 Mdot
.832 .06751 Mdot
.832 .06771 Mdot
.832 .06823 Mdot
.832 .06848 Mdot
.832 .06894 Mdot
.832 .06895 Mdot
.832 .06897 Mdot
.832 .0693 Mdot
.832 .06966 Mdot
.832 .06967 Mdot
.832 .07014 Mdot
.832 .07051 Mdot
.832 .07056 Mdot
.832 .07088 Mdot
.832 .07146 Mdot
.832 .07153 Mdot
.832 .07211 Mdot
.832 .07249 Mdot
.832 .07284 Mdot
.832 .07336 Mdot
.832 .07382 Mdot
.832 .07397 Mdot
.832 .07437 Mdot
.832 .0744 Mdot
.832 .07448 Mdot
.832 .07517 Mdot
.832 .07567 Mdot
.832 .07567 Mdot
.832 .07598 Mdot
.832 .07602 Mdot
.832 .07635 Mdot
.832 .07685 Mdot
.832 .07799 Mdot
.832 .07804 Mdot
.832 .07848 Mdot
.832 .07892 Mdot
.832 .07896 Mdot
.832 .07942 Mdot
.832 .07945 Mdot
.832 .07963 Mdot
.832 .07981 Mdot
.832 .08011 Mdot
.832 .08062 Mdot
.832 .08154 Mdot
.832 .08161 Mdot
.832 .08178 Mdot
.832 .08289 Mdot
.832 .08301 Mdot
.832 .08385 Mdot
.832 .08441 Mdot
.832 .08516 Mdot
.832 .08564 Mdot
.832 .08596 Mdot
.832 .08612 Mdot
.832 .0863 Mdot
.832 .08654 Mdot
.832 .08677 Mdot
.832 .08736 Mdot
.832 .08798 Mdot
.832 .08845 Mdot
.832 .08905 Mdot
.832 .08925 Mdot
.832 .08941 Mdot
.832 .08942 Mdot
.832 .08975 Mdot
.832 .08994 Mdot
.832 .09065 Mdot
.832 .09247 Mdot
.832 .09258 Mdot
.832 .09263 Mdot
.832 .0927 Mdot
.832 .09411 Mdot
.832 .09461 Mdot
.832 .09471 Mdot
.832 .09535 Mdot
.832 .09545 Mdot
.832 .09545 Mdot
.832 .09586 Mdot
.832 .0965 Mdot
.832 .09725 Mdot
.832 .09743 Mdot
.832 .09797 Mdot
.832 .09868 Mdot
.832 .09906 Mdot
.832 .09924 Mdot
.832 .09944 Mdot
.832 .09969 Mdot
.832 .09976 Mdot
.832 .10084 Mdot
.832 .10106 Mdot
.832 .10134 Mdot
.832 .10167 Mdot
.832 .10172 Mdot
.832 .10217 Mdot
.832 .10227 Mdot
.832 .10257 Mdot
.832 .1029 Mdot
.832 .10376 Mdot
.832 .10418 Mdot
.832 .10427 Mdot
.832 .10488 Mdot
.832 .10495 Mdot
.832 .10497 Mdot
.832 .10499 Mdot
.832 .10554 Mdot
.832 .10615 Mdot
.832 .10617 Mdot
.832 .10619 Mdot
.832 .10638 Mdot
.832 .10694 Mdot
.832 .10745 Mdot
.832 .10754 Mdot
.832 .10755 Mdot
.832 .10764 Mdot
.832 .10768 Mdot
.832 .10786 Mdot
.832 .10818 Mdot
.832 .10913 Mdot
.832 .10925 Mdot
.832 .11022 Mdot
.832 .11086 Mdot
.832 .11144 Mdot
.832 .11231 Mdot
.832 .11307 Mdot
.832 .11331 Mdot
.832 .11398 Mdot
.832 .11403 Mdot
.832 .11417 Mdot
.832 .11531 Mdot
.832 .11614 Mdot
.832 .11614 Mdot
.832 .11666 Mdot
.832 .11673 Mdot
.832 .11727 Mdot
.832 .11811 Mdot
.832 .11811 Mdot
.832 .11883 Mdot
.832 .11926 Mdot
.832 .11966 Mdot
.832 .12001 Mdot
.832 .12008 Mdot
.832 .12009 Mdot
.832 .12033 Mdot
.832 .12061 Mdot
.832 .12081 Mdot
.832 .12155 Mdot
.832 .12162 Mdot
.832 .12178 Mdot
.832 .12216 Mdot
.832 .12238 Mdot
.832 .12243 Mdot
.832 .12273 Mdot
.832 .12304 Mdot
.832 .12354 Mdot
.832 .12437 Mdot
.832 .12466 Mdot
.832 .1259 Mdot
.832 .12603 Mdot
.832 .12631 Mdot
.832 .12816 Mdot
.832 .12837 Mdot
.832 .12908 Mdot
.832 .12976 Mdot
.832 .1301 Mdot
.832 .13069 Mdot
.832 .13084 Mdot
.832 .13122 Mdot
.832 .13141 Mdot
.832 .13194 Mdot
.832 .1325 Mdot
.832 .13273 Mdot
.832 .133 Mdot
.832 .13317 Mdot
.832 .13327 Mdot
.832 .13353 Mdot
.832 .13383 Mdot
.832 .13396 Mdot
.832 .13423 Mdot
.832 .13462 Mdot
.832 .13524 Mdot
.832 .13559 Mdot
.832 .136 Mdot
.832 .13663 Mdot
.832 .1374 Mdot
.832 .13772 Mdot
.832 .1384 Mdot
.832 .13873 Mdot
.832 .139 Mdot
.832 .13902 Mdot
.832 .13957 Mdot
.832 .13989 Mdot
.832 .14094 Mdot
.832 .14107 Mdot
.832 .14163 Mdot
.832 .14165 Mdot
.832 .14168 Mdot
.832 .1441 Mdot
.832 .14419 Mdot
.832 .14428 Mdot
.832 .14437 Mdot
.832 .14442 Mdot
.832 .14448 Mdot
.832 .14474 Mdot
.832 .14482 Mdot
.832 .14683 Mdot
.832 .14766 Mdot
.832 .14783 Mdot
.832 .1489 Mdot
.832 .14905 Mdot
.832 .14906 Mdot
.832 .1496 Mdot
.832 .14972 Mdot
.832 .14974 Mdot
.832 .1508 Mdot
.832 .1512 Mdot
.832 .15157 Mdot
.832 .15205 Mdot
.832 .15235 Mdot
.832 .15324 Mdot
.832 .15325 Mdot
.832 .15443 Mdot
.832 .15506 Mdot
.832 .15537 Mdot
.832 .15546 Mdot
.832 .1557 Mdot
.832 .15612 Mdot
.832 .15624 Mdot
.832 .15638 Mdot
.832 .15685 Mdot
.832 .15802 Mdot
.832 .15838 Mdot
.832 .15886 Mdot
.832 .1594 Mdot
.832 .1595 Mdot
.832 .16025 Mdot
.832 .16041 Mdot
.832 .16091 Mdot
.832 .16097 Mdot
.832 .161 Mdot
.832 .16146 Mdot
.832 .16288 Mdot
.832 .16359 Mdot
.832 .16374 Mdot
.832 .16474 Mdot
.832 .16475 Mdot
.832 .16487 Mdot
.832 .1649 Mdot
.832 .16494 Mdot
.832 .16585 Mdot
.832 .16643 Mdot
.832 .16686 Mdot
.832 .16689 Mdot
.832 .16692 Mdot
.832 .16724 Mdot
.832 .16725 Mdot
.832 .16817 Mdot
.832 .16903 Mdot
.832 .16917 Mdot
.832 .1692 Mdot
.832 .1693 Mdot
.832 .16934 Mdot
.832 .16935 Mdot
.832 .16942 Mdot
.832 .16971 Mdot
.832 .17024 Mdot
.832 .17064 Mdot
.832 .17077 Mdot
.832 .17117 Mdot
.832 .17183 Mdot
.832 .17202 Mdot
.832 .17229 Mdot
.832 .17363 Mdot
.832 .17419 Mdot
.832 .17469 Mdot
.832 .17476 Mdot
.832 .17543 Mdot
.832 .17567 Mdot
.832 .17711 Mdot
.832 .17759 Mdot
.832 .17837 Mdot
.832 .17877 Mdot
.832 .17989 Mdot
.832 .17998 Mdot
.832 .18021 Mdot
.832 .18211 Mdot
.832 .18297 Mdot
.832 .1834 Mdot
.832 .18349 Mdot
.832 .18349 Mdot
.832 .18435 Mdot
.832 .18446 Mdot
.832 .18465 Mdot
.832 .18537 Mdot
.832 .18655 Mdot
.832 .18677 Mdot
.832 .18677 Mdot
.832 .18685 Mdot
.832 .18773 Mdot
.832 .18796 Mdot
.832 .18868 Mdot
.832 .18934 Mdot
.832 .18935 Mdot
.832 .18977 Mdot
.832 .18993 Mdot
.832 .19005 Mdot
.832 .19005 Mdot
.832 .19045 Mdot
.832 .19092 Mdot
.832 .19126 Mdot
.832 .19248 Mdot
.832 .19261 Mdot
.832 .19287 Mdot
.832 .19322 Mdot
.832 .19351 Mdot
.832 .19388 Mdot
.832 .19395 Mdot
.832 .194 Mdot
.832 .19445 Mdot
.832 .19493 Mdot
.832 .19496 Mdot
.832 .19579 Mdot
.832 .1963 Mdot
.832 .19655 Mdot
.832 .19672 Mdot
.832 .19719 Mdot
.832 .19766 Mdot
.832 .19882 Mdot
.832 .19973 Mdot
.832 .19994 Mdot
.832 .2004 Mdot
.832 .2013 Mdot
.832 .2021 Mdot
.832 .20349 Mdot
.832 .20383 Mdot
.832 .20502 Mdot
.832 .20536 Mdot
.832 .20615 Mdot
.832 .20671 Mdot
.832 .2077 Mdot
.832 .20794 Mdot
.832 .20858 Mdot
.832 .20862 Mdot
.832 .20889 Mdot
.832 .20933 Mdot
.832 .20977 Mdot
.832 .21063 Mdot
.832 .21071 Mdot
.832 .2111 Mdot
.832 .21155 Mdot
.832 .21183 Mdot
.832 .21199 Mdot
.832 .21242 Mdot
.832 .21293 Mdot
.832 .21314 Mdot
.832 .21359 Mdot
.832 .21375 Mdot
.832 .21395 Mdot
.832 .21399 Mdot
.832 .21424 Mdot
.832 .21453 Mdot
.832 .21467 Mdot
.832 .21485 Mdot
.832 .21526 Mdot
.832 .21585 Mdot
.832 .21654 Mdot
.832 .21758 Mdot
.832 .21887 Mdot
.832 .21904 Mdot
.832 .21939 Mdot
.832 .22053 Mdot
.832 .22108 Mdot
.832 .22153 Mdot
.832 .22157 Mdot
.832 .22171 Mdot
.832 .22247 Mdot
.832 .22294 Mdot
.832 .22301 Mdot
.832 .22369 Mdot
.832 .22383 Mdot
.832 .22399 Mdot
.832 .22475 Mdot
.832 .22497 Mdot
.832 .22544 Mdot
.832 .22551 Mdot
.832 .2259 Mdot
.832 .22593 Mdot
.832 .22598 Mdot
.832 .22605 Mdot
.832 .22975 Mdot
.832 .23001 Mdot
.832 .23017 Mdot
.832 .23031 Mdot
.832 .23046 Mdot
.832 .23055 Mdot
.832 .23065 Mdot
.832 .23107 Mdot
.832 .23121 Mdot
.832 .23212 Mdot
.832 .23371 Mdot
.832 .23408 Mdot
.832 .23435 Mdot
.832 .23449 Mdot
.832 .23455 Mdot
.832 .23495 Mdot
.832 .23513 Mdot
.832 .23519 Mdot
.832 .23547 Mdot
.832 .23593 Mdot
.832 .23621 Mdot
.832 .23683 Mdot
.832 .23799 Mdot
.832 .23824 Mdot
.832 .23825 Mdot
.832 .23826 Mdot
.832 .23917 Mdot
.832 .23925 Mdot
.832 .23937 Mdot
.832 .2394 Mdot
.832 .24112 Mdot
.832 .24117 Mdot
.832 .2417 Mdot
.832 .24183 Mdot
.832 .24244 Mdot
.832 .24324 Mdot
.832 .24357 Mdot
.832 .24374 Mdot
.832 .24523 Mdot
.832 .24524 Mdot
.832 .24659 Mdot
.832 .2472 Mdot
.832 .2475 Mdot
.832 .24824 Mdot
.832 .24826 Mdot
.832 .24872 Mdot
.832 .24877 Mdot
.832 .24891 Mdot
.832 .24932 Mdot
.832 .25 Mdot
.832 .25021 Mdot
.832 .25045 Mdot
.832 .25123 Mdot
.832 .25318 Mdot
.832 .25333 Mdot
.832 .25378 Mdot
.832 .25447 Mdot
.832 .25458 Mdot
.832 .25489 Mdot
.832 .25547 Mdot
.832 .25563 Mdot
.832 .25688 Mdot
.832 .25716 Mdot
.832 .25749 Mdot
.832 .25799 Mdot
.832 .25808 Mdot
.832 .25814 Mdot
.832 .2589 Mdot
.832 .25979 Mdot
.832 .26008 Mdot
.832 .26126 Mdot
.832 .26244 Mdot
.832 .2627 Mdot
.832 .26316 Mdot
.832 .26429 Mdot
.832 .26436 Mdot
.832 .26438 Mdot
.832 .26457 Mdot
.832 .26462 Mdot
.832 .26469 Mdot
.832 .2662 Mdot
.832 .26717 Mdot
.832 .26761 Mdot
.832 .26788 Mdot
.832 .26793 Mdot
.832 .26799 Mdot
.832 .26851 Mdot
.832 .26854 Mdot
.832 .26873 Mdot
.832 .27007 Mdot
.832 .27092 Mdot
.832 .2715 Mdot
.832 .27163 Mdot
.832 .27173 Mdot
.832 .27178 Mdot
.832 .27195 Mdot
.832 .27201 Mdot
.832 .27203 Mdot
.832 .27214 Mdot
.832 .27263 Mdot
.832 .27314 Mdot
.832 .2735 Mdot
.832 .27418 Mdot
.832 .27439 Mdot
.832 .27506 Mdot
.832 .27615 Mdot
.832 .27648 Mdot
.832 .27675 Mdot
.832 .27692 Mdot
.832 .27858 Mdot
.832 .279 Mdot
.832 .27915 Mdot
.832 .28009 Mdot
.832 .28092 Mdot
.832 .28102 Mdot
.832 .28214 Mdot
.832 .28254 Mdot
.832 .28374 Mdot
.832 .28415 Mdot
.832 .28494 Mdot
.832 .28519 Mdot
.832 .28574 Mdot
.832 .28704 Mdot
.832 .28771 Mdot
.832 .28957 Mdot
.832 .28971 Mdot
.832 .29009 Mdot
.832 .29326 Mdot
.832 .29395 Mdot
.832 .2947 Mdot
.832 .2954 Mdot
.832 .29555 Mdot
.832 .29555 Mdot
.832 .29587 Mdot
.832 .29698 Mdot
.832 .29717 Mdot
.832 .29749 Mdot
.832 .29794 Mdot
.832 .29868 Mdot
.832 .29989 Mdot
.832 .3003 Mdot
.832 .30031 Mdot
.832 .30064 Mdot
.832 .30101 Mdot
.832 .30101 Mdot
.832 .30115 Mdot
.832 .3012 Mdot
.832 .30262 Mdot
.832 .303 Mdot
.832 .30419 Mdot
.832 .30427 Mdot
.832 .30479 Mdot
.832 .30529 Mdot
.832 .3053 Mdot
.832 .30568 Mdot
.832 .30601 Mdot
.832 .30627 Mdot
.832 .30647 Mdot
.832 .30648 Mdot
.832 .30692 Mdot
.832 .30714 Mdot
.832 .30792 Mdot
.832 .30849 Mdot
.832 .30898 Mdot
.832 .31052 Mdot
.832 .31073 Mdot
.832 .31117 Mdot
.832 .31176 Mdot
.832 .31223 Mdot
.832 .31233 Mdot
.832 .31284 Mdot
.832 .31297 Mdot
.832 .31305 Mdot
.832 .31346 Mdot
.832 .31348 Mdot
.832 .31379 Mdot
.832 .3144 Mdot
.832 .31459 Mdot
.832 .31465 Mdot
.832 .31543 Mdot
.832 .31543 Mdot
.832 .31582 Mdot
.832 .31596 Mdot
.832 .31603 Mdot
.832 .31687 Mdot
.832 .31728 Mdot
.832 .31756 Mdot
.832 .31835 Mdot
.832 .31914 Mdot
.832 .31987 Mdot
.832 .32093 Mdot
.832 .32106 Mdot
.832 .32259 Mdot
.832 .32294 Mdot
.832 .3237 Mdot
.832 .32423 Mdot
.832 .32445 Mdot
.832 .32519 Mdot
.832 .32589 Mdot
.832 .32653 Mdot
.832 .32727 Mdot
.832 .32731 Mdot
.832 .32835 Mdot
.832 .32884 Mdot
.832 .32927 Mdot
.832 .3294 Mdot
.832 .32999 Mdot
.832 .33055 Mdot
.832 .33056 Mdot
.832 .33139 Mdot
.832 .33179 Mdot
.832 .33195 Mdot
.832 .33241 Mdot
.832 .33327 Mdot
.832 .3342 Mdot
.832 .33456 Mdot
.832 .33584 Mdot
.832 .33613 Mdot
.832 .33625 Mdot
.832 .33731 Mdot
.832 .33737 Mdot
.832 .33749 Mdot
.832 .33782 Mdot
.832 .33856 Mdot
.832 .33929 Mdot
.832 .34072 Mdot
.832 .34086 Mdot
.832 .3415 Mdot
.832 .34225 Mdot
.832 .34271 Mdot
.832 .34299 Mdot
.832 .3437 Mdot
.832 .34454 Mdot
.832 .34489 Mdot
.832 .34564 Mdot
.832 .34592 Mdot
.832 .34625 Mdot
.832 .34631 Mdot
.832 .34673 Mdot
.832 .34721 Mdot
.832 .34743 Mdot
.832 .34774 Mdot
.832 .34842 Mdot
.832 .34941 Mdot
.832 .35055 Mdot
.832 .35228 Mdot
.832 .35443 Mdot
.832 .35471 Mdot
.832 .35529 Mdot
.832 .35719 Mdot
.832 .35811 Mdot
.832 .35886 Mdot
.832 .35891 Mdot
.832 .35916 Mdot
.832 .36043 Mdot
.832 .36119 Mdot
.832 .36131 Mdot
.832 .36246 Mdot
.832 .36268 Mdot
.832 .36296 Mdot
.832 .36422 Mdot
.832 .36458 Mdot
.832 .36537 Mdot
.832 .36548 Mdot
.832 .36613 Mdot
.832 .36618 Mdot
.832 .36627 Mdot
.832 .36637 Mdot
.832 .37253 Mdot
.832 .37297 Mdot
.832 .37322 Mdot
.832 .37347 Mdot
.832 .37372 Mdot
.832 .37387 Mdot
.832 .37403 Mdot
.832 .37474 Mdot
.832 .37497 Mdot
.832 .37647 Mdot
.832 .37913 Mdot
.832 .37974 Mdot
.832 .38018 Mdot
.832 .38041 Mdot
.832 .38052 Mdot
.832 .38118 Mdot
.832 .38148 Mdot
.832 .38158 Mdot
.832 .38206 Mdot
.832 .38282 Mdot
.832 .38329 Mdot
.832 .38431 Mdot
.832 .38625 Mdot
.832 .38667 Mdot
.832 .38668 Mdot
.832 .3867 Mdot
.832 .38821 Mdot
.832 .38835 Mdot
.832 .38854 Mdot
.832 .38859 Mdot
.832 .39146 Mdot
.832 .39153 Mdot
.832 .39242 Mdot
.832 .39264 Mdot
.832 .39365 Mdot
.832 .39498 Mdot
.832 .39553 Mdot
.832 .39581 Mdot
.832 .39829 Mdot
.832 .39831 Mdot
.832 .40056 Mdot
.832 .40157 Mdot
.832 .40207 Mdot
.832 .4033 Mdot
.832 .40333 Mdot
.832 .4041 Mdot
.832 .40418 Mdot
.832 .40442 Mdot
.832 .40509 Mdot
.832 .40624 Mdot
.832 .40657 Mdot
.832 .40698 Mdot
.832 .40828 Mdot
.832 .41151 Mdot
.832 .41177 Mdot
.832 .41252 Mdot
.832 .41366 Mdot
.832 .41384 Mdot
.832 .41437 Mdot
.832 .41534 Mdot
.832 .4156 Mdot
.832 .41767 Mdot
.832 .41814 Mdot
.832 .4187 Mdot
.832 .41952 Mdot
.832 .41967 Mdot
.832 .41977 Mdot
.832 .42104 Mdot
.832 .42253 Mdot
.832 .42301 Mdot
.832 .42497 Mdot
.832 .42693 Mdot
.832 .42735 Mdot
.832 .42813 Mdot
.832 .43001 Mdot
.832 .43013 Mdot
.832 .43015 Mdot
.832 .43048 Mdot
.832 .43056 Mdot
.832 .43067 Mdot
.832 .43319 Mdot
.832 .43479 Mdot
.832 .43553 Mdot
.832 .43598 Mdot
.832 .43607 Mdot
.832 .43616 Mdot
.832 .43704 Mdot
.832 .43708 Mdot
.832 .4374 Mdot
.832 .43962 Mdot
.832 .44105 Mdot
.832 .44201 Mdot
.832 .44223 Mdot
.832 .44239 Mdot
.832 .44247 Mdot
.832 .44275 Mdot
.832 .44286 Mdot
.832 .44289 Mdot
.832 .44306 Mdot
.832 .44388 Mdot
.832 .44473 Mdot
.832 .44533 Mdot
.832 .44646 Mdot
.832 .44681 Mdot
.832 .44793 Mdot
.832 .44975 Mdot
.832 .45029 Mdot
.832 .45073 Mdot
.832 .45103 Mdot
.832 .45379 Mdot
.832 .45448 Mdot
.832 .45473 Mdot
.832 .4563 Mdot
.832 .45768 Mdot
.832 .45785 Mdot
.832 .4597 Mdot
.832 .46038 Mdot
.832 .46238 Mdot
.832 .46305 Mdot
.832 .46437 Mdot
.832 .46479 Mdot
.832 .4657 Mdot
.832 .46787 Mdot
.832 .46897 Mdot
.832 .47207 Mdot
.832 .47231 Mdot
.832 .47294 Mdot
.832 .47821 Mdot
.832 .47936 Mdot
.832 .4806 Mdot
.832 .48178 Mdot
.832 .48202 Mdot
.832 .48203 Mdot
.832 .48256 Mdot
.832 .48441 Mdot
.832 .48472 Mdot
.832 .48525 Mdot
.832 .486 Mdot
.832 .48724 Mdot
.832 .48925 Mdot
.832 .48993 Mdot
.832 .48994 Mdot
.832 .4905 Mdot
.832 .49111 Mdot
.832 .49112 Mdot
.832 .49135 Mdot
.832 .49143 Mdot
.832 .49378 Mdot
.832 .49442 Mdot
.832 .49641 Mdot
.832 .49653 Mdot
.832 .4974 Mdot
.832 .49823 Mdot
.832 .49825 Mdot
.832 .49888 Mdot
.832 .49943 Mdot
.832 .49986 Mdot
.832 .5002 Mdot
.832 .50021 Mdot
.832 .50095 Mdot
.832 .50132 Mdot
.832 .50261 Mdot
.832 .50355 Mdot
.832 .50437 Mdot
.834 .01495 Mdot
.834 .01497 Mdot
.834 .015 Mdot
.834 .01511 Mdot
.834 .01514 Mdot
.834 .01518 Mdot
.834 .01538 Mdot
.834 .01543 Mdot
.834 .0155 Mdot
.834 .01559 Mdot
.834 .01582 Mdot
.834 .01587 Mdot
.834 .01591 Mdot
.834 .01602 Mdot
.834 .01617 Mdot
.834 .01654 Mdot
.834 .01656 Mdot
.834 .01664 Mdot
.834 .0167 Mdot
.834 .01689 Mdot
.834 .01714 Mdot
.834 .01777 Mdot
.834 .01779 Mdot
.834 .01793 Mdot
.834 .018 Mdot
.834 .01803 Mdot
.834 .01816 Mdot
.834 .01835 Mdot
.834 .01876 Mdot
.834 .01883 Mdot
.834 .01981 Mdot
.834 .01984 Mdot
.834 .02008 Mdot
.834 .02019 Mdot
.834 .02024 Mdot
.834 .02046 Mdot
.834 .02077 Mdot
.834 .02146 Mdot
.834 .02158 Mdot
.834 .02261 Mdot
.834 .02288 Mdot
.834 .02321 Mdot
.834 .02327 Mdot
.834 .02343 Mdot
.834 .02366 Mdot
.834 .02384 Mdot
.834 .02393 Mdot
.834 .0243 Mdot
.834 .02438 Mdot
.834 .02482 Mdot
.834 .02502 Mdot
.834 .02515 Mdot
.834 .02597 Mdot
.834 .02616 Mdot
.834 .02721 Mdot
.834 .02725 Mdot
.834 .02789 Mdot
.834 .02799 Mdot
.834 .02803 Mdot
.834 .02833 Mdot
.834 .02888 Mdot
.834 .02898 Mdot
.834 .02924 Mdot
.834 .02925 Mdot
.834 .02963 Mdot
.834 .02976 Mdot
.834 .02994 Mdot
.834 .03004 Mdot
.834 .03008 Mdot
.834 .03021 Mdot
.834 .03025 Mdot
.834 .03031 Mdot
.834 .03071 Mdot
.834 .03071 Mdot
.834 .03083 Mdot
.834 .03157 Mdot
.834 .03179 Mdot
.834 .03191 Mdot
.834 .03212 Mdot
.834 .03348 Mdot
.834 .03381 Mdot
.834 .03398 Mdot
.834 .034 Mdot
.834 .03503 Mdot
.834 .03556 Mdot
.834 .03563 Mdot
.834 .03668 Mdot
.834 .03669 Mdot
.834 .03685 Mdot
.834 .03693 Mdot
.834 .03742 Mdot
.834 .03755 Mdot
.834 .03834 Mdot
.834 .03851 Mdot
.834 .03892 Mdot
.834 .03894 Mdot
.834 .03895 Mdot
.834 .0396 Mdot
.834 .03965 Mdot
.834 .03981 Mdot
.834 .04011 Mdot
.834 .04028 Mdot
.834 .04029 Mdot
.834 .04035 Mdot
.834 .04056 Mdot
.834 .04062 Mdot
.834 .04073 Mdot
.834 .04114 Mdot
.834 .04139 Mdot
.834 .0414 Mdot
.834 .04159 Mdot
.834 .04231 Mdot
.834 .04271 Mdot
.834 .04272 Mdot
.834 .04283 Mdot
.834 .04294 Mdot
.834 .04319 Mdot
.834 .0433 Mdot
.834 .0434 Mdot
.834 .04353 Mdot
.834 .04374 Mdot
.834 .04602 Mdot
.834 .04656 Mdot
.834 .04658 Mdot
.834 .04661 Mdot
.834 .04684 Mdot
.834 .04688 Mdot
.834 .04859 Mdot
.834 .04904 Mdot
.834 .04949 Mdot
.834 .04952 Mdot
.834 .0496 Mdot
.834 .05135 Mdot
.834 .05137 Mdot
.834 .05164 Mdot
.834 .05177 Mdot
.834 .05259 Mdot
.834 .05262 Mdot
.834 .05281 Mdot
.834 .05317 Mdot
.834 .05366 Mdot
.834 .05388 Mdot
.834 .05388 Mdot
.834 .05412 Mdot
.834 .05441 Mdot
.834 .05484 Mdot
.834 .05508 Mdot
.834 .05513 Mdot
.834 .05514 Mdot
.834 .05623 Mdot
.834 .05631 Mdot
.834 .05657 Mdot
.834 .05708 Mdot
.834 .05733 Mdot
.834 .05737 Mdot
.834 .05738 Mdot
.834 .05747 Mdot
.834 .05748 Mdot
.834 .0577 Mdot
.834 .05782 Mdot
.834 .05793 Mdot
.834 .058 Mdot
.834 .0581 Mdot
.834 .05837 Mdot
.834 .05852 Mdot
.834 .05857 Mdot
.834 .05879 Mdot
.834 .0592 Mdot
.834 .05922 Mdot
.834 .05955 Mdot
.834 .05955 Mdot
.834 .06043 Mdot
.834 .06062 Mdot
.834 .06074 Mdot
.834 .0614 Mdot
.834 .06143 Mdot
.834 .06161 Mdot
.834 .06179 Mdot
.834 .06188 Mdot
.834 .06222 Mdot
.834 .06228 Mdot
.834 .06239 Mdot
.834 .06256 Mdot
.834 .06277 Mdot
.834 .06314 Mdot
.834 .06407 Mdot
.834 .06441 Mdot
.834 .06674 Mdot
.834 .06693 Mdot
.834 .06728 Mdot
.834 .06741 Mdot
.834 .06783 Mdot
.834 .06786 Mdot
.834 .06792 Mdot
.834 .0683 Mdot
.834 .06836 Mdot
.834 .06853 Mdot
.834 .07122 Mdot
.834 .07173 Mdot
.834 .07197 Mdot
.834 .0722 Mdot
.834 .07238 Mdot
.834 .07241 Mdot
.834 .07272 Mdot
.834 .07277 Mdot
.834 .0729 Mdot
.834 .07356 Mdot
.834 .0737 Mdot
.834 .07429 Mdot
.834 .07521 Mdot
.834 .07582 Mdot
.834 .07585 Mdot
.834 .07622 Mdot
.834 .0763 Mdot
.834 .07643 Mdot
.834 .07653 Mdot
.834 .07656 Mdot
.834 .07704 Mdot
.834 .0779 Mdot
.834 .07794 Mdot
.834 .0781 Mdot
.834 .07812 Mdot
.834 .07826 Mdot
.834 .07885 Mdot
.834 .07896 Mdot
.834 .07948 Mdot
.834 .07968 Mdot
.834 .08004 Mdot
.834 .08005 Mdot
.834 .08014 Mdot
.834 .08037 Mdot
.834 .08044 Mdot
.834 .08092 Mdot
.834 .08165 Mdot
.834 .08173 Mdot
.834 .08205 Mdot
.834 .08208 Mdot
.834 .08212 Mdot
.834 .08215 Mdot
.834 .08255 Mdot
.834 .08255 Mdot
.834 .08333 Mdot
.834 .08395 Mdot
.834 .08409 Mdot
.834 .08452 Mdot
.834 .08522 Mdot
.834 .08538 Mdot
.834 .08579 Mdot
.834 .08586 Mdot
.834 .08588 Mdot
.834 .08603 Mdot
.834 .08605 Mdot
.834 .08642 Mdot
.834 .08662 Mdot
.834 .08662 Mdot
.834 .0868 Mdot
.834 .08691 Mdot
.834 .08709 Mdot
.834 .08713 Mdot
.834 .08754 Mdot
.834 .08772 Mdot
.834 .08778 Mdot
.834 .08786 Mdot
.834 .08824 Mdot
.834 .08892 Mdot
.834 .08895 Mdot
.834 .08941 Mdot
.834 .0895 Mdot
.834 .0895 Mdot
.834 .09063 Mdot
.834 .09097 Mdot
.834 .09129 Mdot
.834 .09148 Mdot
.834 .09259 Mdot
.834 .09263 Mdot
.834 .09269 Mdot
.834 .09294 Mdot
.834 .09324 Mdot
.834 .09338 Mdot
.834 .09395 Mdot
.834 .09405 Mdot
.834 .09424 Mdot
.834 .09451 Mdot
.834 .09487 Mdot
.834 .09538 Mdot
.834 .09548 Mdot
.834 .09595 Mdot
.834 .09614 Mdot
.834 .09703 Mdot
.834 .09761 Mdot
.834 .09813 Mdot
.834 .09933 Mdot
.834 .09975 Mdot
.834 .10039 Mdot
.834 .10039 Mdot
.834 .10149 Mdot
.834 .10181 Mdot
.834 .10239 Mdot
.834 .10261 Mdot
.834 .10331 Mdot
.834 .10336 Mdot
.834 .10346 Mdot
.834 .1041 Mdot
.834 .1042 Mdot
.834 .10448 Mdot
.834 .10897 Mdot
.834 .10913 Mdot
.834 .10982 Mdot
.834 .11021 Mdot
.834 .11023 Mdot
.834 .1106 Mdot
.834 .11091 Mdot
.834 .11095 Mdot
.834 .11147 Mdot
.834 .11156 Mdot
.834 .11177 Mdot
.834 .11179 Mdot
.834 .11215 Mdot
.834 .11287 Mdot
.834 .11299 Mdot
.834 .11311 Mdot
.834 .11408 Mdot
.834 .11428 Mdot
.834 .11562 Mdot
.834 .11573 Mdot
.834 .11665 Mdot
.834 .11669 Mdot
.834 .11677 Mdot
.834 .1173 Mdot
.834 .11744 Mdot
.834 .11766 Mdot
.834 .11781 Mdot
.834 .11787 Mdot
.834 .11833 Mdot
.834 .11867 Mdot
.834 .11929 Mdot
.834 .1201 Mdot
.834 .12017 Mdot
.834 .12045 Mdot
.834 .12048 Mdot
.834 .12071 Mdot
.834 .1217 Mdot
.834 .12188 Mdot
.834 .12269 Mdot
.834 .12275 Mdot
.834 .12307 Mdot
.834 .12368 Mdot
.834 .12369 Mdot
.834 .12385 Mdot
.834 .12423 Mdot
.834 .12434 Mdot
.834 .12435 Mdot
.834 .12467 Mdot
.834 .12514 Mdot
.834 .12514 Mdot
.834 .12636 Mdot
.834 .1265 Mdot
.834 .12702 Mdot
.834 .12702 Mdot
.834 .12707 Mdot
.834 .12715 Mdot
.834 .1272 Mdot
.834 .12786 Mdot
.834 .12786 Mdot
.834 .12916 Mdot
.834 .12928 Mdot
.834 .12938 Mdot
.834 .13021 Mdot
.834 .13032 Mdot
.834 .13043 Mdot
.834 .13044 Mdot
.834 .13115 Mdot
.834 .13232 Mdot
.834 .13259 Mdot
.834 .13328 Mdot
.834 .13338 Mdot
.834 .13342 Mdot
.834 .13367 Mdot
.834 .1337 Mdot
.834 .13403 Mdot
.834 .13424 Mdot
.834 .13432 Mdot
.834 .13465 Mdot
.834 .13465 Mdot
.834 .13483 Mdot
.834 .13495 Mdot
.834 .13509 Mdot
.834 .13514 Mdot
.834 .13543 Mdot
.834 .13551 Mdot
.834 .13561 Mdot
.834 .13577 Mdot
.834 .13618 Mdot
.834 .13648 Mdot
.834 .13659 Mdot
.834 .13672 Mdot
.834 .13709 Mdot
.834 .13735 Mdot
.834 .13849 Mdot
.834 .13854 Mdot
.834 .13922 Mdot
.834 .13931 Mdot
.834 .13945 Mdot
.834 .13945 Mdot
.834 .14134 Mdot
.834 .14157 Mdot
.834 .14191 Mdot
.834 .14199 Mdot
.834 .14244 Mdot
.834 .14276 Mdot
.834 .14298 Mdot
.834 .14352 Mdot
.834 .14461 Mdot
.834 .14468 Mdot
.834 .14478 Mdot
.834 .14519 Mdot
.834 .1457 Mdot
.834 .1459 Mdot
.834 .14593 Mdot
.834 .1467 Mdot
.834 .14687 Mdot
.834 .14704 Mdot
.834 .14708 Mdot
.834 .14736 Mdot
.834 .14782 Mdot
.834 .14833 Mdot
.834 .14841 Mdot
.834 .14926 Mdot
.834 .14943 Mdot
.834 .15022 Mdot
.834 .15053 Mdot
.834 .15179 Mdot
.834 .15202 Mdot
.834 .15299 Mdot
.834 .15385 Mdot
.834 .15413 Mdot
.834 .15448 Mdot
.834 .15585 Mdot
.834 .15585 Mdot
.834 .15655 Mdot
.834 .15763 Mdot
.834 .15763 Mdot
.834 .15765 Mdot
.834 .15871 Mdot
.834 .15946 Mdot
.834 .15999 Mdot
.834 .16096 Mdot
.834 .16132 Mdot
.834 .16249 Mdot
.834 .16257 Mdot
.834 .16274 Mdot
.834 .16287 Mdot
.834 .16322 Mdot
.834 .1638 Mdot
.834 .16397 Mdot
.834 .16444 Mdot
.834 .16721 Mdot
.834 .16851 Mdot
.834 .16999 Mdot
.834 .17012 Mdot
.834 .17193 Mdot
.834 .1722 Mdot
.834 .17335 Mdot
.834 .17401 Mdot
.834 .17403 Mdot
.834 .17465 Mdot
.834 .17516 Mdot
.834 .17524 Mdot
.834 .17611 Mdot
.834 .17624 Mdot
.834 .17649 Mdot
.834 .1765 Mdot
.834 .1766 Mdot
.834 .17664 Mdot
.834 .17724 Mdot
.834 .17843 Mdot
.834 .17863 Mdot
.834 .17884 Mdot
.834 .17925 Mdot
.834 .17975 Mdot
.834 .18045 Mdot
.834 .18078 Mdot
.834 .18276 Mdot
.834 .18303 Mdot
.834 .18321 Mdot
.834 .18473 Mdot
.834 .18474 Mdot
.834 .18474 Mdot
.834 .18482 Mdot
.834 .18485 Mdot
.834 .18494 Mdot
.834 .18583 Mdot
.834 .18605 Mdot
.834 .18642 Mdot
.834 .18668 Mdot
.834 .18677 Mdot
.834 .18754 Mdot
.834 .18812 Mdot
.834 .18914 Mdot
.834 .18976 Mdot
.834 .1905 Mdot
.834 .19061 Mdot
.834 .19108 Mdot
.834 .19112 Mdot
.834 .19151 Mdot
.834 .19316 Mdot
.834 .19322 Mdot
.834 .19346 Mdot
.834 .19482 Mdot
.834 .19492 Mdot
.834 .19545 Mdot
.834 .19569 Mdot
.834 .19647 Mdot
.834 .19649 Mdot
.834 .19675 Mdot
.834 .19739 Mdot
.834 .19755 Mdot
.834 .19756 Mdot
.834 .19759 Mdot
.834 .19812 Mdot
.834 .1989 Mdot
.834 .19891 Mdot
.834 .20019 Mdot
.834 .20094 Mdot
.834 .20118 Mdot
.834 .2019 Mdot
.834 .20204 Mdot
.834 .20205 Mdot
.834 .20213 Mdot
.834 .20226 Mdot
.834 .20234 Mdot
.834 .20343 Mdot
.834 .20345 Mdot
.834 .20449 Mdot
.834 .2056 Mdot
.834 .2058 Mdot
.834 .20598 Mdot
.834 .20606 Mdot
.834 .20641 Mdot
.834 .2073 Mdot
.834 .20735 Mdot
.834 .20754 Mdot
.834 .20767 Mdot
.834 .20773 Mdot
.834 .20774 Mdot
.834 .20848 Mdot
.834 .20893 Mdot
.834 .20908 Mdot
.834 .21068 Mdot
.834 .21087 Mdot
.834 .21132 Mdot
.834 .21248 Mdot
.834 .21264 Mdot
.834 .21271 Mdot
.834 .21272 Mdot
.834 .21313 Mdot
.834 .21318 Mdot
.834 .21339 Mdot
.834 .21373 Mdot
.834 .21409 Mdot
.834 .21416 Mdot
.834 .21421 Mdot
.834 .21438 Mdot
.834 .21477 Mdot
.834 .21477 Mdot
.834 .21507 Mdot
.834 .21526 Mdot
.834 .2155 Mdot
.834 .21558 Mdot
.834 .21607 Mdot
.834 .21619 Mdot
.834 .21636 Mdot
.834 .21636 Mdot
.834 .21664 Mdot
.834 .21732 Mdot
.834 .21783 Mdot
.834 .21801 Mdot
.834 .21822 Mdot
.834 .21883 Mdot
.834 .21927 Mdot
.834 .22001 Mdot
.834 .22097 Mdot
.834 .22118 Mdot
.834 .22125 Mdot
.834 .22196 Mdot
.834 .22239 Mdot
.834 .22255 Mdot
.834 .22278 Mdot
.834 .22278 Mdot
.834 .22592 Mdot
.834 .22631 Mdot
.834 .22687 Mdot
.834 .227 Mdot
.834 .2273 Mdot
.834 .22777 Mdot
.834 .22829 Mdot
.834 .22866 Mdot
.834 .22922 Mdot
.834 .22957 Mdot
.834 .23139 Mdot
.834 .2315 Mdot
.834 .23167 Mdot
.834 .23235 Mdot
.834 .23316 Mdot
.834 .2332 Mdot
.834 .23353 Mdot
.834 .23358 Mdot
.834 .23487 Mdot
.834 .23494 Mdot
.834 .23516 Mdot
.834 .23525 Mdot
.834 .23543 Mdot
.834 .23549 Mdot
.834 .23597 Mdot
.834 .23673 Mdot
.834 .23758 Mdot
.834 .23773 Mdot
.834 .23808 Mdot
.834 .23828 Mdot
.834 .23913 Mdot
.834 .23942 Mdot
.834 .23956 Mdot
.834 .24 Mdot
.834 .24073 Mdot
.834 .24125 Mdot
.834 .24209 Mdot
.834 .24222 Mdot
.834 .24271 Mdot
.834 .24336 Mdot
.834 .24374 Mdot
.834 .24523 Mdot
.834 .24536 Mdot
.834 .24679 Mdot
.834 .24726 Mdot
.834 .24779 Mdot
.834 .24784 Mdot
.834 .25013 Mdot
.834 .25013 Mdot
.834 .25112 Mdot
.834 .2513 Mdot
.834 .25238 Mdot
.834 .25309 Mdot
.834 .25309 Mdot
.834 .25313 Mdot
.834 .2549 Mdot
.834 .25614 Mdot
.834 .25703 Mdot
.834 .2577 Mdot
.834 .25865 Mdot
.834 .25926 Mdot
.834 .26019 Mdot
.834 .26076 Mdot
.834 .26088 Mdot
.834 .2612 Mdot
.834 .26134 Mdot
.834 .26163 Mdot
.834 .26184 Mdot
.834 .26242 Mdot
.834 .26315 Mdot
.834 .26339 Mdot
.834 .26367 Mdot
.834 .26375 Mdot
.834 .26446 Mdot
.834 .26577 Mdot
.834 .26612 Mdot
.834 .26647 Mdot
.834 .26839 Mdot
.834 .26908 Mdot
.834 .2705 Mdot
.834 .27114 Mdot
.834 .27125 Mdot
.834 .27227 Mdot
.834 .27234 Mdot
.834 .2728 Mdot
.834 .27296 Mdot
.834 .27371 Mdot
.834 .27375 Mdot
.834 .27393 Mdot
.834 .27484 Mdot
.834 .27575 Mdot
.834 .27695 Mdot
.834 .27741 Mdot
.834 .27932 Mdot
.834 .28021 Mdot
.834 .28042 Mdot
.834 .28046 Mdot
.834 .28128 Mdot
.834 .28149 Mdot
.834 .28222 Mdot
.834 .28234 Mdot
.834 .28247 Mdot
.834 .28316 Mdot
.834 .28392 Mdot
.834 .28415 Mdot
.834 .28455 Mdot
.834 .28458 Mdot
.834 .28474 Mdot
.834 .2848 Mdot
.834 .28509 Mdot
.834 .28548 Mdot
.834 .28581 Mdot
.834 .28741 Mdot
.834 .28779 Mdot
.834 .28813 Mdot
.834 .28847 Mdot
.834 .28916 Mdot
.834 .2893 Mdot
.834 .28999 Mdot
.834 .29067 Mdot
.834 .29117 Mdot
.834 .29171 Mdot
.834 .29219 Mdot
.834 .29352 Mdot
.834 .29502 Mdot
.834 .29547 Mdot
.834 .29577 Mdot
.834 .29722 Mdot
.834 .29831 Mdot
.834 .29831 Mdot
.834 .29832 Mdot
.834 .29844 Mdot
.834 .29851 Mdot
.834 .29865 Mdot
.834 .30013 Mdot
.834 .30051 Mdot
.834 .30113 Mdot
.834 .30139 Mdot
.834 .30156 Mdot
.834 .3017 Mdot
.834 .30263 Mdot
.834 .30299 Mdot
.834 .30347 Mdot
.834 .30395 Mdot
.834 .30565 Mdot
.834 .3067 Mdot
.834 .30752 Mdot
.834 .30792 Mdot
.834 .30811 Mdot
.834 .30889 Mdot
.834 .30897 Mdot
.834 .30961 Mdot
.834 .31054 Mdot
.834 .31055 Mdot
.834 .31056 Mdot
.834 .31092 Mdot
.834 .31109 Mdot
.834 .31149 Mdot
.834 .31236 Mdot
.834 .31246 Mdot
.834 .31286 Mdot
.834 .31513 Mdot
.834 .31529 Mdot
.834 .31562 Mdot
.834 .31619 Mdot
.834 .31658 Mdot
.834 .31665 Mdot
.834 .31789 Mdot
.834 .31791 Mdot
.834 .31835 Mdot
.834 .31838 Mdot
.834 .3191 Mdot
.834 .31941 Mdot
.834 .31959 Mdot
.834 .31969 Mdot
.834 .31971 Mdot
.834 .31975 Mdot
.834 .31998 Mdot
.834 .32063 Mdot
.834 .32194 Mdot
.834 .32196 Mdot
.834 .32257 Mdot
.834 .32356 Mdot
.834 .32409 Mdot
.834 .3249 Mdot
.834 .32534 Mdot
.834 .32573 Mdot
.834 .32624 Mdot
.834 .32694 Mdot
.834 .32718 Mdot
.834 .32719 Mdot
.834 .32732 Mdot
.834 .32753 Mdot
.834 .32767 Mdot
.834 .3295 Mdot
.834 .32952 Mdot
.834 .33097 Mdot
.834 .33126 Mdot
.834 .33312 Mdot
.834 .33345 Mdot
.834 .33375 Mdot
.834 .33388 Mdot
.834 .33388 Mdot
.834 .33445 Mdot
.834 .33594 Mdot
.834 .33604 Mdot
.834 .33617 Mdot
.834 .33635 Mdot
.834 .33657 Mdot
.834 .33666 Mdot
.834 .33669 Mdot
.834 .33727 Mdot
.834 .3378 Mdot
.834 .33792 Mdot
.834 .33867 Mdot
.834 .33891 Mdot
.834 .33998 Mdot
.834 .34019 Mdot
.834 .34159 Mdot
.834 .34191 Mdot
.834 .34199 Mdot
.834 .34266 Mdot
.834 .34458 Mdot
.834 .34486 Mdot
.834 .34497 Mdot
.834 .34499 Mdot
.834 .34567 Mdot
.834 .34576 Mdot
.834 .34611 Mdot
.834 .34667 Mdot
.834 .34727 Mdot
.834 .3474 Mdot
.834 .34747 Mdot
.834 .34776 Mdot
.834 .3484 Mdot
.834 .34841 Mdot
.834 .34891 Mdot
.834 .34923 Mdot
.834 .34962 Mdot
.834 .34976 Mdot
.834 .35058 Mdot
.834 .35078 Mdot
.834 .35106 Mdot
.834 .35106 Mdot
.834 .35153 Mdot
.834 .35267 Mdot
.834 .3535 Mdot
.834 .35381 Mdot
.834 .35416 Mdot
.834 .35518 Mdot
.834 .35591 Mdot
.834 .35715 Mdot
.834 .35875 Mdot
.834 .3591 Mdot
.834 .35921 Mdot
.834 .3604 Mdot
.834 .36112 Mdot
.834 .36138 Mdot
.834 .36176 Mdot
.834 .36176 Mdot
.834 .367 Mdot
.834 .36766 Mdot
.834 .36859 Mdot
.834 .36881 Mdot
.834 .36931 Mdot
.834 .37008 Mdot
.834 .37096 Mdot
.834 .37158 Mdot
.834 .37251 Mdot
.834 .37309 Mdot
.834 .37612 Mdot
.834 .37632 Mdot
.834 .3766 Mdot
.834 .37773 Mdot
.834 .37908 Mdot
.834 .37914 Mdot
.834 .3797 Mdot
.834 .37978 Mdot
.834 .38193 Mdot
.834 .38206 Mdot
.834 .38241 Mdot
.834 .38256 Mdot
.834 .38287 Mdot
.834 .38297 Mdot
.834 .38376 Mdot
.834 .38504 Mdot
.834 .38645 Mdot
.834 .3867 Mdot
.834 .38729 Mdot
.834 .38762 Mdot
.834 .38904 Mdot
.834 .38952 Mdot
.834 .38975 Mdot
.834 .3905 Mdot
.834 .39171 Mdot
.834 .39258 Mdot
.834 .39398 Mdot
.834 .39419 Mdot
.834 .39501 Mdot
.834 .39609 Mdot
.834 .39672 Mdot
.834 .39922 Mdot
.834 .39943 Mdot
.834 .40182 Mdot
.834 .4026 Mdot
.834 .40348 Mdot
.834 .40356 Mdot
.834 .40738 Mdot
.834 .40739 Mdot
.834 .40904 Mdot
.834 .40934 Mdot
.834 .41114 Mdot
.834 .41233 Mdot
.834 .41233 Mdot
.834 .4124 Mdot
.834 .41534 Mdot
.834 .41741 Mdot
.834 .41889 Mdot
.834 .42001 Mdot
.834 .42159 Mdot
.834 .42262 Mdot
.834 .42417 Mdot
.834 .42511 Mdot
.834 .42532 Mdot
.834 .42585 Mdot
.834 .42608 Mdot
.834 .42656 Mdot
.834 .42692 Mdot
.834 .42788 Mdot
.834 .4291 Mdot
.834 .42951 Mdot
.834 .42997 Mdot
.834 .4301 Mdot
.834 .43129 Mdot
.834 .43347 Mdot
.834 .43405 Mdot
.834 .43465 Mdot
.834 .43785 Mdot
.834 .439 Mdot
.834 .44136 Mdot
.834 .44243 Mdot
.834 .44261 Mdot
.834 .44431 Mdot
.834 .44443 Mdot
.834 .44519 Mdot
.834 .44546 Mdot
.834 .44671 Mdot
.834 .44679 Mdot
.834 .44708 Mdot
.834 .4486 Mdot
.834 .45013 Mdot
.834 .45213 Mdot
.834 .45288 Mdot
.834 .45607 Mdot
.834 .45756 Mdot
.834 .4579 Mdot
.834 .45798 Mdot
.834 .45934 Mdot
.834 .4597 Mdot
.834 .46091 Mdot
.834 .46112 Mdot
.834 .46133 Mdot
.834 .46248 Mdot
.834 .46374 Mdot
.834 .46413 Mdot
.834 .4648 Mdot
.834 .46485 Mdot
.834 .46512 Mdot
.834 .46522 Mdot
.834 .46569 Mdot
.834 .46634 Mdot
.834 .46689 Mdot
.834 .46957 Mdot
.834 .4702 Mdot
.834 .47077 Mdot
.834 .47133 Mdot
.834 .47249 Mdot
.834 .47272 Mdot
.834 .47388 Mdot
.834 .47502 Mdot
.834 .47584 Mdot
.834 .47675 Mdot
.834 .47755 Mdot
.834 .47977 Mdot
.834 .48226 Mdot
.834 .48301 Mdot
.834 .48351 Mdot
.834 .48594 Mdot
.834 .48775 Mdot
.834 .48776 Mdot
.834 .48776 Mdot
.834 .48798 Mdot
.834 .48808 Mdot
.834 .48832 Mdot
.834 .49079 Mdot
.834 .49141 Mdot
.834 .49245 Mdot
.834 .49288 Mdot
.834 .49317 Mdot
.834 .49341 Mdot
.834 .49496 Mdot
.834 .49556 Mdot
.834 .49636 Mdot
.834 .49716 Mdot
.834 .5 Mdot
.834 .50174 Mdot
.834 .50311 Mdot
.834 .50378 Mdot
.834 .50409 Mdot
.834 .5054 Mdot
.834 .50553 Mdot
.834 .5066 Mdot
.836 .01473 Mdot
.836 .01474 Mdot
.836 .01476 Mdot
.836 .01479 Mdot
.836 .01484 Mdot
.836 .01493 Mdot
.836 .01508 Mdot
.836 .01532 Mdot
.836 .01573 Mdot
.836 .01586 Mdot
.836 .01602 Mdot
.836 .01602 Mdot
.836 .01641 Mdot
.836 .01663 Mdot
.836 .01689 Mdot
.836 .0169 Mdot
.836 .01754 Mdot
.836 .01773 Mdot
.836 .01791 Mdot
.836 .01835 Mdot
.836 .01836 Mdot
.836 .01881 Mdot
.836 .01886 Mdot
.836 .01912 Mdot
.836 .01923 Mdot
.836 .01945 Mdot
.836 .01975 Mdot
.836 .01998 Mdot
.836 .02 Mdot
.836 .02006 Mdot
.836 .0208 Mdot
.836 .02081 Mdot
.836 .02157 Mdot
.836 .02165 Mdot
.836 .02207 Mdot
.836 .02227 Mdot
.836 .02262 Mdot
.836 .02314 Mdot
.836 .02353 Mdot
.836 .02356 Mdot
.836 .02365 Mdot
.836 .0237 Mdot
.836 .02489 Mdot
.836 .02491 Mdot
.836 .02616 Mdot
.836 .02617 Mdot
.836 .02631 Mdot
.836 .02702 Mdot
.836 .02715 Mdot
.836 .02734 Mdot
.836 .02794 Mdot
.836 .02878 Mdot
.836 .02879 Mdot
.836 .02923 Mdot
.836 .0293 Mdot
.836 .02945 Mdot
.836 .0295 Mdot
.836 .02963 Mdot
.836 .02966 Mdot
.836 .02967 Mdot
.836 .02973 Mdot
.836 .02988 Mdot
.836 .0312 Mdot
.836 .03172 Mdot
.836 .03176 Mdot
.836 .03225 Mdot
.836 .03269 Mdot
.836 .03275 Mdot
.836 .03294 Mdot
.836 .0336 Mdot
.836 .03386 Mdot
.836 .03387 Mdot
.836 .0341 Mdot
.836 .03411 Mdot
.836 .03462 Mdot
.836 .03529 Mdot
.836 .03551 Mdot
.836 .03582 Mdot
.836 .03619 Mdot
.836 .03629 Mdot
.836 .03683 Mdot
.836 .0374 Mdot
.836 .03804 Mdot
.836 .03823 Mdot
.836 .03825 Mdot
.836 .03833 Mdot
.836 .03841 Mdot
.836 .03896 Mdot
.836 .03898 Mdot
.836 .03899 Mdot
.836 .03909 Mdot
.836 .03935 Mdot
.836 .03943 Mdot
.836 .03965 Mdot
.836 .0397 Mdot
.836 .03971 Mdot
.836 .03982 Mdot
.836 .04008 Mdot
.836 .0406 Mdot
.836 .04099 Mdot
.836 .04227 Mdot
.836 .04315 Mdot
.836 .04322 Mdot
.836 .04404 Mdot
.836 .04422 Mdot
.836 .04476 Mdot
.836 .04486 Mdot
.836 .04519 Mdot
.836 .04538 Mdot
.836 .04629 Mdot
.836 .04672 Mdot
.836 .04674 Mdot
.836 .04701 Mdot
.836 .04712 Mdot
.836 .04714 Mdot
.836 .04799 Mdot
.836 .04911 Mdot
.836 .04913 Mdot
.836 .04934 Mdot
.836 .04948 Mdot
.836 .04997 Mdot
.836 .05001 Mdot
.836 .05013 Mdot
.836 .0504 Mdot
.836 .05062 Mdot
.836 .05072 Mdot
.836 .0508 Mdot
.836 .05168 Mdot
.836 .05265 Mdot
.836 .05295 Mdot
.836 .05371 Mdot
.836 .05403 Mdot
.836 .05407 Mdot
.836 .0542 Mdot
.836 .05433 Mdot
.836 .05526 Mdot
.836 .05528 Mdot
.836 .0553 Mdot
.836 .05548 Mdot
.836 .0559 Mdot
.836 .05604 Mdot
.836 .0564 Mdot
.836 .05649 Mdot
.836 .05651 Mdot
.836 .0567 Mdot
.836 .05712 Mdot
.836 .058 Mdot
.836 .05846 Mdot
.836 .05864 Mdot
.836 .05866 Mdot
.836 .05881 Mdot
.836 .05908 Mdot
.836 .05957 Mdot
.836 .05976 Mdot
.836 .06031 Mdot
.836 .06079 Mdot
.836 .06164 Mdot
.836 .06226 Mdot
.836 .06237 Mdot
.836 .06268 Mdot
.836 .06374 Mdot
.836 .06405 Mdot
.836 .06425 Mdot
.836 .06471 Mdot
.836 .06496 Mdot
.836 .06502 Mdot
.836 .06512 Mdot
.836 .06566 Mdot
.836 .06599 Mdot
.836 .06616 Mdot
.836 .06649 Mdot
.836 .06653 Mdot
.836 .06675 Mdot
.836 .06737 Mdot
.836 .06751 Mdot
.836 .06768 Mdot
.836 .06823 Mdot
.836 .06826 Mdot
.836 .06871 Mdot
.836 .0689 Mdot
.836 .0689 Mdot
.836 .06892 Mdot
.836 .06901 Mdot
.836 .07036 Mdot
.836 .07223 Mdot
.836 .07226 Mdot
.836 .07261 Mdot
.836 .07265 Mdot
.836 .07284 Mdot
.836 .07314 Mdot
.836 .07317 Mdot
.836 .07366 Mdot
.836 .07368 Mdot
.836 .07372 Mdot
.836 .07384 Mdot
.836 .07392 Mdot
.836 .07438 Mdot
.836 .07442 Mdot
.836 .07475 Mdot
.836 .07491 Mdot
.836 .07504 Mdot
.836 .07536 Mdot
.836 .07538 Mdot
.836 .07653 Mdot
.836 .07721 Mdot
.836 .07814 Mdot
.836 .07865 Mdot
.836 .07991 Mdot
.836 .08045 Mdot
.836 .08052 Mdot
.836 .08073 Mdot
.836 .08096 Mdot
.836 .08108 Mdot
.836 .0825 Mdot
.836 .08254 Mdot
.836 .08258 Mdot
.836 .08287 Mdot
.836 .08357 Mdot
.836 .08381 Mdot
.836 .08441 Mdot
.836 .08456 Mdot
.836 .0846 Mdot
.836 .08491 Mdot
.836 .08561 Mdot
.836 .08597 Mdot
.836 .08709 Mdot
.836 .08786 Mdot
.836 .08815 Mdot
.836 .08818 Mdot
.836 .08844 Mdot
.836 .0889 Mdot
.836 .08971 Mdot
.836 .09002 Mdot
.836 .09039 Mdot
.836 .09095 Mdot
.836 .09175 Mdot
.836 .092 Mdot
.836 .09312 Mdot
.836 .09317 Mdot
.836 .09421 Mdot
.836 .09423 Mdot
.836 .09427 Mdot
.836 .09427 Mdot
.836 .0944 Mdot
.836 .09451 Mdot
.836 .0949 Mdot
.836 .09653 Mdot
.836 .09668 Mdot
.836 .09721 Mdot
.836 .09754 Mdot
.836 .09831 Mdot
.836 .09872 Mdot
.836 .09882 Mdot
.836 .099 Mdot
.836 .0999 Mdot
.836 .1001 Mdot
.836 .10045 Mdot
.836 .10065 Mdot
.836 .10074 Mdot
.836 .10128 Mdot
.836 .10136 Mdot
.836 .10171 Mdot
.836 .10266 Mdot
.836 .10275 Mdot
.836 .10298 Mdot
.836 .10327 Mdot
.836 .10419 Mdot
.836 .10424 Mdot
.836 .10499 Mdot
.836 .10531 Mdot
.836 .10531 Mdot
.836 .10535 Mdot
.836 .10549 Mdot
.836 .10647 Mdot
.836 .10775 Mdot
.836 .10888 Mdot
.836 .10951 Mdot
.836 .11062 Mdot
.836 .11088 Mdot
.836 .11092 Mdot
.836 .11152 Mdot
.836 .11159 Mdot
.836 .11172 Mdot
.836 .1119 Mdot
.836 .1124 Mdot
.836 .11245 Mdot
.836 .11328 Mdot
.836 .1133 Mdot
.836 .11337 Mdot
.836 .11337 Mdot
.836 .11358 Mdot
.836 .11371 Mdot
.836 .11413 Mdot
.836 .11447 Mdot
.836 .11454 Mdot
.836 .1151 Mdot
.836 .11536 Mdot
.836 .11558 Mdot
.836 .11572 Mdot
.836 .11575 Mdot
.836 .11612 Mdot
.836 .11612 Mdot
.836 .11615 Mdot
.836 .11761 Mdot
.836 .11762 Mdot
.836 .11806 Mdot
.836 .11846 Mdot
.836 .1192 Mdot
.836 .11948 Mdot
.836 .1196 Mdot
.836 .12028 Mdot
.836 .12076 Mdot
.836 .12161 Mdot
.836 .12161 Mdot
.836 .1224 Mdot
.836 .12373 Mdot
.836 .12433 Mdot
.836 .12434 Mdot
.836 .12463 Mdot
.836 .12474 Mdot
.836 .1251 Mdot
.836 .12547 Mdot
.836 .12567 Mdot
.836 .12806 Mdot
.836 .12812 Mdot
.836 .12818 Mdot
.836 .12866 Mdot
.836 .12984 Mdot
.836 .13024 Mdot
.836 .13124 Mdot
.836 .13149 Mdot
.836 .13156 Mdot
.836 .13207 Mdot
.836 .1321 Mdot
.836 .1331 Mdot
.836 .13326 Mdot
.836 .13346 Mdot
.836 .13385 Mdot
.836 .13573 Mdot
.836 .13667 Mdot
.836 .13702 Mdot
.836 .1375 Mdot
.836 .13755 Mdot
.836 .13799 Mdot
.836 .13875 Mdot
.836 .13887 Mdot
.836 .14011 Mdot
.836 .14063 Mdot
.836 .14124 Mdot
.836 .14159 Mdot
.836 .14175 Mdot
.836 .14209 Mdot
.836 .1421 Mdot
.836 .14218 Mdot
.836 .14289 Mdot
.836 .14292 Mdot
.836 .14307 Mdot
.836 .14352 Mdot
.836 .14393 Mdot
.836 .14394 Mdot
.836 .14581 Mdot
.836 .14589 Mdot
.836 .14704 Mdot
.836 .14763 Mdot
.836 .14766 Mdot
.836 .14773 Mdot
.836 .14773 Mdot
.836 .14791 Mdot
.836 .14794 Mdot
.836 .14813 Mdot
.836 .14879 Mdot
.836 .15085 Mdot
.836 .15151 Mdot
.836 .15177 Mdot
.836 .15251 Mdot
.836 .15264 Mdot
.836 .1532 Mdot
.836 .1535 Mdot
.836 .15449 Mdot
.836 .15501 Mdot
.836 .15517 Mdot
.836 .15533 Mdot
.836 .15564 Mdot
.836 .15668 Mdot
.836 .15714 Mdot
.836 .15748 Mdot
.836 .15806 Mdot
.836 .1584 Mdot
.836 .15855 Mdot
.836 .15946 Mdot
.836 .15958 Mdot
.836 .15976 Mdot
.836 .16017 Mdot
.836 .16095 Mdot
.836 .16169 Mdot
.836 .16176 Mdot
.836 .16191 Mdot
.836 .1623 Mdot
.836 .16279 Mdot
.836 .16432 Mdot
.836 .1644 Mdot
.836 .1644 Mdot
.836 .16505 Mdot
.836 .16566 Mdot
.836 .16619 Mdot
.836 .16619 Mdot
.836 .16626 Mdot
.836 .1665 Mdot
.836 .16765 Mdot
.836 .16813 Mdot
.836 .16886 Mdot
.836 .16905 Mdot
.836 .17011 Mdot
.836 .17026 Mdot
.836 .17084 Mdot
.836 .17216 Mdot
.836 .17322 Mdot
.836 .17367 Mdot
.836 .17506 Mdot
.836 .1755 Mdot
.836 .17558 Mdot
.836 .1761 Mdot
.836 .17657 Mdot
.836 .17669 Mdot
.836 .17687 Mdot
.836 .17691 Mdot
.836 .17721 Mdot
.836 .17762 Mdot
.836 .17805 Mdot
.836 .17813 Mdot
.836 .17832 Mdot
.836 .17903 Mdot
.836 .17951 Mdot
.836 .17955 Mdot
.836 .17967 Mdot
.836 .17967 Mdot
.836 .18002 Mdot
.836 .18023 Mdot
.836 .18094 Mdot
.836 .18151 Mdot
.836 .18161 Mdot
.836 .18163 Mdot
.836 .18256 Mdot
.836 .183 Mdot
.836 .18337 Mdot
.836 .1836 Mdot
.836 .18365 Mdot
.836 .18391 Mdot
.836 .18426 Mdot
.836 .18427 Mdot
.836 .18432 Mdot
.836 .18606 Mdot
.836 .18676 Mdot
.836 .18677 Mdot
.836 .1871 Mdot
.836 .18752 Mdot
.836 .18766 Mdot
.836 .18787 Mdot
.836 .18817 Mdot
.836 .18942 Mdot
.836 .18988 Mdot
.836 .19008 Mdot
.836 .19037 Mdot
.836 .19122 Mdot
.836 .1915 Mdot
.836 .19197 Mdot
.836 .19202 Mdot
.836 .19264 Mdot
.836 .19344 Mdot
.836 .19345 Mdot
.836 .19477 Mdot
.836 .19565 Mdot
.836 .19689 Mdot
.836 .19698 Mdot
.836 .19745 Mdot
.836 .19799 Mdot
.836 .19801 Mdot
.836 .19808 Mdot
.836 .19831 Mdot
.836 .19849 Mdot
.836 .19868 Mdot
.836 .19924 Mdot
.836 .19928 Mdot
.836 .19967 Mdot
.836 .1999 Mdot
.836 .20023 Mdot
.836 .20024 Mdot
.836 .20387 Mdot
.836 .20422 Mdot
.836 .20432 Mdot
.836 .20444 Mdot
.836 .20524 Mdot
.836 .20721 Mdot
.836 .20733 Mdot
.836 .20767 Mdot
.836 .20787 Mdot
.836 .20834 Mdot
.836 .20944 Mdot
.836 .20955 Mdot
.836 .20996 Mdot
.836 .21008 Mdot
.836 .21017 Mdot
.836 .21039 Mdot
.836 .21094 Mdot
.836 .21098 Mdot
.836 .21246 Mdot
.836 .21265 Mdot
.836 .21292 Mdot
.836 .21325 Mdot
.836 .21391 Mdot
.836 .2153 Mdot
.836 .21705 Mdot
.836 .21863 Mdot
.836 .2192 Mdot
.836 .2196 Mdot
.836 .22 Mdot
.836 .22002 Mdot
.836 .22002 Mdot
.836 .2201 Mdot
.836 .22082 Mdot
.836 .2221 Mdot
.836 .2223 Mdot
.836 .22302 Mdot
.836 .22438 Mdot
.836 .22524 Mdot
.836 .22547 Mdot
.836 .22586 Mdot
.836 .22626 Mdot
.836 .22685 Mdot
.836 .22712 Mdot
.836 .22769 Mdot
.836 .2277 Mdot
.836 .22783 Mdot
.836 .22837 Mdot
.836 .22837 Mdot
.836 .22867 Mdot
.836 .22903 Mdot
.836 .22908 Mdot
.836 .22932 Mdot
.836 .22979 Mdot
.836 .23008 Mdot
.836 .23077 Mdot
.836 .23077 Mdot
.836 .23355 Mdot
.836 .2339 Mdot
.836 .23403 Mdot
.836 .23518 Mdot
.836 .23597 Mdot
.836 .23694 Mdot
.836 .237 Mdot
.836 .23712 Mdot
.836 .23712 Mdot
.836 .23741 Mdot
.836 .23742 Mdot
.836 .23747 Mdot
.836 .23778 Mdot
.836 .23889 Mdot
.836 .2392 Mdot
.836 .24026 Mdot
.836 .24085 Mdot
.836 .2412 Mdot
.836 .24174 Mdot
.836 .24234 Mdot
.836 .24344 Mdot
.836 .24387 Mdot
.836 .24413 Mdot
.836 .2451 Mdot
.836 .24533 Mdot
.836 .24626 Mdot
.836 .2467 Mdot
.836 .24677 Mdot
.836 .24714 Mdot
.836 .2474 Mdot
.836 .24842 Mdot
.836 .24929 Mdot
.836 .24956 Mdot
.836 .24983 Mdot
.836 .25008 Mdot
.836 .25033 Mdot
.836 .25126 Mdot
.836 .25208 Mdot
.836 .25285 Mdot
.836 .25322 Mdot
.836 .25342 Mdot
.836 .2535 Mdot
.836 .25439 Mdot
.836 .2548 Mdot
.836 .25496 Mdot
.836 .2552 Mdot
.836 .25628 Mdot
.836 .25672 Mdot
.836 .25692 Mdot
.836 .25715 Mdot
.836 .25723 Mdot
.836 .25772 Mdot
.836 .25792 Mdot
.836 .25922 Mdot
.836 .26046 Mdot
.836 .26058 Mdot
.836 .26082 Mdot
.836 .26121 Mdot
.836 .26147 Mdot
.836 .26155 Mdot
.836 .26229 Mdot
.836 .26331 Mdot
.836 .26485 Mdot
.836 .26499 Mdot
.836 .265 Mdot
.836 .26607 Mdot
.836 .26695 Mdot
.836 .26709 Mdot
.836 .26798 Mdot
.836 .26798 Mdot
.836 .26809 Mdot
.836 .26849 Mdot
.836 .26984 Mdot
.836 .27042 Mdot
.836 .27122 Mdot
.836 .27186 Mdot
.836 .27224 Mdot
.836 .27245 Mdot
.836 .27257 Mdot
.836 .27277 Mdot
.836 .27362 Mdot
.836 .27454 Mdot
.836 .2747 Mdot
.836 .27479 Mdot
.836 .27575 Mdot
.836 .27617 Mdot
.836 .27687 Mdot
.836 .27697 Mdot
.836 .27744 Mdot
.836 .27797 Mdot
.836 .27828 Mdot
.836 .27848 Mdot
.836 .27973 Mdot
.836 .27985 Mdot
.836 .28048 Mdot
.836 .28178 Mdot
.836 .28282 Mdot
.836 .28354 Mdot
.836 .28367 Mdot
.836 .2838 Mdot
.836 .28417 Mdot
.836 .28456 Mdot
.836 .28508 Mdot
.836 .28533 Mdot
.836 .28537 Mdot
.836 .28554 Mdot
.836 .28584 Mdot
.836 .28591 Mdot
.836 .2864 Mdot
.836 .28709 Mdot
.836 .28781 Mdot
.836 .28794 Mdot
.836 .28827 Mdot
.836 .28837 Mdot
.836 .28945 Mdot
.836 .29026 Mdot
.836 .29032 Mdot
.836 .29052 Mdot
.836 .29052 Mdot
.836 .29063 Mdot
.836 .29081 Mdot
.836 .2911 Mdot
.836 .29136 Mdot
.836 .29138 Mdot
.836 .29146 Mdot
.836 .29169 Mdot
.836 .29218 Mdot
.836 .29265 Mdot
.836 .29299 Mdot
.836 .2936 Mdot
.836 .29373 Mdot
.836 .29376 Mdot
.836 .29377 Mdot
.836 .29379 Mdot
.836 .29399 Mdot
.836 .29463 Mdot
.836 .29535 Mdot
.836 .29601 Mdot
.836 .29608 Mdot
.836 .2967 Mdot
.836 .29708 Mdot
.836 .29717 Mdot
.836 .29733 Mdot
.836 .2976 Mdot
.836 .2982 Mdot
.836 .29821 Mdot
.836 .29827 Mdot
.836 .29829 Mdot
.836 .29999 Mdot
.836 .30033 Mdot
.836 .30043 Mdot
.836 .30044 Mdot
.836 .30052 Mdot
.836 .30108 Mdot
.836 .30238 Mdot
.836 .30239 Mdot
.836 .30286 Mdot
.836 .30295 Mdot
.836 .30364 Mdot
.836 .30389 Mdot
.836 .30423 Mdot
.836 .30473 Mdot
.836 .30487 Mdot
.836 .30672 Mdot
.836 .30682 Mdot
.836 .30692 Mdot
.836 .30759 Mdot
.836 .30792 Mdot
.836 .30841 Mdot
.836 .30866 Mdot
.836 .30972 Mdot
.836 .30983 Mdot
.836 .30998 Mdot
.836 .3103 Mdot
.836 .31041 Mdot
.836 .31108 Mdot
.836 .31117 Mdot
.836 .31118 Mdot
.836 .3122 Mdot
.836 .31285 Mdot
.836 .31288 Mdot
.836 .31303 Mdot
.836 .3131 Mdot
.836 .31355 Mdot
.836 .31356 Mdot
.836 .31577 Mdot
.836 .31724 Mdot
.836 .31783 Mdot
.836 .31881 Mdot
.836 .31908 Mdot
.836 .31912 Mdot
.836 .31931 Mdot
.836 .31934 Mdot
.836 .31947 Mdot
.836 .32025 Mdot
.836 .32088 Mdot
.836 .32115 Mdot
.836 .32118 Mdot
.836 .3213 Mdot
.836 .32169 Mdot
.836 .32199 Mdot
.836 .3223 Mdot
.836 .32324 Mdot
.836 .3233 Mdot
.836 .32397 Mdot
.836 .32434 Mdot
.836 .32452 Mdot
.836 .32457 Mdot
.836 .3249 Mdot
.836 .32491 Mdot
.836 .32588 Mdot
.836 .32611 Mdot
.836 .32804 Mdot
.836 .32874 Mdot
.836 .32971 Mdot
.836 .33098 Mdot
.836 .33111 Mdot
.836 .33148 Mdot
.836 .33157 Mdot
.836 .33174 Mdot
.836 .33193 Mdot
.836 .33327 Mdot
.836 .33656 Mdot
.836 .33667 Mdot
.836 .33677 Mdot
.836 .33693 Mdot
.836 .33722 Mdot
.836 .33733 Mdot
.836 .33767 Mdot
.836 .33846 Mdot
.836 .33908 Mdot
.836 .34002 Mdot
.836 .3403 Mdot
.836 .34048 Mdot
.836 .34117 Mdot
.836 .34136 Mdot
.836 .34139 Mdot
.836 .34152 Mdot
.836 .34189 Mdot
.836 .34207 Mdot
.836 .3428 Mdot
.836 .34287 Mdot
.836 .34505 Mdot
.836 .34534 Mdot
.836 .34536 Mdot
.836 .34566 Mdot
.836 .34576 Mdot
.836 .34611 Mdot
.836 .34667 Mdot
.836 .34668 Mdot
.836 .34777 Mdot
.836 .35009 Mdot
.836 .35301 Mdot
.836 .35565 Mdot
.836 .35662 Mdot
.836 .35729 Mdot
.836 .35795 Mdot
.836 .35798 Mdot
.836 .35798 Mdot
.836 .35812 Mdot
.836 .35933 Mdot
.836 .36147 Mdot
.836 .36179 Mdot
.836 .363 Mdot
.836 .36527 Mdot
.836 .36672 Mdot
.836 .36709 Mdot
.836 .36775 Mdot
.836 .36842 Mdot
.836 .3694 Mdot
.836 .36986 Mdot
.836 .37081 Mdot
.836 .37083 Mdot
.836 .37105 Mdot
.836 .37194 Mdot
.836 .37194 Mdot
.836 .37244 Mdot
.836 .37305 Mdot
.836 .37312 Mdot
.836 .37353 Mdot
.836 .37433 Mdot
.836 .3748 Mdot
.836 .37595 Mdot
.836 .37596 Mdot
.836 .3806 Mdot
.836 .3812 Mdot
.836 .38141 Mdot
.836 .38334 Mdot
.836 .38465 Mdot
.836 .38628 Mdot
.836 .38638 Mdot
.836 .38658 Mdot
.836 .38658 Mdot
.836 .38706 Mdot
.836 .38707 Mdot
.836 .38716 Mdot
.836 .38768 Mdot
.836 .38954 Mdot
.836 .39006 Mdot
.836 .39182 Mdot
.836 .39281 Mdot
.836 .3934 Mdot
.836 .3943 Mdot
.836 .3953 Mdot
.836 .39715 Mdot
.836 .39786 Mdot
.836 .3983 Mdot
.836 .39992 Mdot
.836 .40031 Mdot
.836 .40186 Mdot
.836 .40259 Mdot
.836 .4027 Mdot
.836 .40334 Mdot
.836 .40377 Mdot
.836 .40546 Mdot
.836 .40692 Mdot
.836 .40738 Mdot
.836 .40783 Mdot
.836 .40825 Mdot
.836 .40867 Mdot
.836 .41021 Mdot
.836 .41159 Mdot
.836 .41287 Mdot
.836 .4135 Mdot
.836 .41383 Mdot
.836 .41396 Mdot
.836 .41545 Mdot
.836 .41613 Mdot
.836 .41641 Mdot
.836 .41681 Mdot
.836 .41861 Mdot
.836 .41935 Mdot
.836 .41969 Mdot
.836 .42006 Mdot
.836 .4202 Mdot
.836 .42102 Mdot
.836 .42135 Mdot
.836 .42353 Mdot
.836 .4256 Mdot
.836 .4258 Mdot
.836 .4262 Mdot
.836 .42686 Mdot
.836 .42729 Mdot
.836 .42743 Mdot
.836 .42866 Mdot
.836 .43036 Mdot
.836 .43294 Mdot
.836 .43317 Mdot
.836 .43318 Mdot
.836 .43498 Mdot
.836 .43644 Mdot
.836 .43668 Mdot
.836 .43818 Mdot
.836 .43818 Mdot
.836 .43836 Mdot
.836 .43903 Mdot
.836 .44128 Mdot
.836 .44225 Mdot
.836 .44359 Mdot
.836 .44466 Mdot
.836 .44529 Mdot
.836 .44564 Mdot
.836 .44586 Mdot
.836 .44618 Mdot
.836 .44761 Mdot
.836 .44914 Mdot
.836 .44941 Mdot
.836 .44956 Mdot
.836 .45117 Mdot
.836 .45187 Mdot
.836 .45304 Mdot
.836 .45321 Mdot
.836 .45399 Mdot
.836 .45487 Mdot
.836 .45539 Mdot
.836 .45573 Mdot
.836 .45782 Mdot
.836 .45803 Mdot
.836 .45908 Mdot
.836 .46125 Mdot
.836 .46298 Mdot
.836 .46419 Mdot
.836 .46442 Mdot
.836 .46462 Mdot
.836 .46524 Mdot
.836 .46589 Mdot
.836 .46677 Mdot
.836 .46719 Mdot
.836 .46725 Mdot
.836 .46753 Mdot
.836 .46803 Mdot
.836 .46815 Mdot
.836 .46897 Mdot
.836 .47013 Mdot
.836 .47133 Mdot
.836 .47155 Mdot
.836 .4721 Mdot
.836 .47227 Mdot
.836 .47407 Mdot
.836 .47542 Mdot
.836 .47552 Mdot
.836 .47585 Mdot
.836 .47586 Mdot
.836 .47605 Mdot
.836 .47634 Mdot
.836 .47683 Mdot
.836 .47727 Mdot
.836 .47729 Mdot
.836 .47743 Mdot
.836 .47781 Mdot
.836 .47864 Mdot
.836 .47942 Mdot
.836 .47998 Mdot
.836 .48101 Mdot
.836 .48122 Mdot
.836 .48128 Mdot
.836 .48129 Mdot
.836 .48133 Mdot
.836 .48167 Mdot
.836 .48273 Mdot
.836 .48393 Mdot
.836 .48504 Mdot
.836 .48516 Mdot
.836 .4862 Mdot
.836 .48683 Mdot
.836 .48699 Mdot
.836 .48724 Mdot
.836 .4877 Mdot
.836 .4887 Mdot
.836 .48872 Mdot
.836 .48881 Mdot
.836 .48885 Mdot
.836 .49169 Mdot
.836 .49227 Mdot
.836 .49243 Mdot
.836 .49245 Mdot
.836 .49259 Mdot
.836 .49351 Mdot
.836 .49569 Mdot
.836 .49571 Mdot
.836 .4965 Mdot
.836 .49664 Mdot
.836 .49779 Mdot
.836 .49821 Mdot
.836 .49879 Mdot
.836 .49963 Mdot
.836 .49985 Mdot
.836 .50295 Mdot
.836 .50311 Mdot
.836 .50328 Mdot
.836 .50439 Mdot
.836 .50496 Mdot
.836 .50577 Mdot
.836 .50619 Mdot
.836 .50796 Mdot
.836 .50815 Mdot
.836 .50839 Mdot
.836 .50894 Mdot
.838 .01648 Mdot
.838 .01664 Mdot
.838 .01738 Mdot
.838 .01744 Mdot
.838 .01767 Mdot
.838 .0179 Mdot
.838 .01793 Mdot
.838 .01795 Mdot
.838 .01917 Mdot
.838 .01929 Mdot
.838 .01945 Mdot
.838 .01967 Mdot
.838 .02006 Mdot
.838 .0201 Mdot
.838 .02013 Mdot
.838 .02045 Mdot
.838 .02192 Mdot
.838 .02219 Mdot
.838 .02238 Mdot
.838 .02266 Mdot
.838 .02302 Mdot
.838 .0231 Mdot
.838 .02367 Mdot
.838 .02373 Mdot
.838 .02379 Mdot
.838 .02433 Mdot
.838 .0245 Mdot
.838 .02499 Mdot
.838 .02514 Mdot
.838 .02538 Mdot
.838 .02629 Mdot
.838 .02679 Mdot
.838 .02724 Mdot
.838 .02756 Mdot
.838 .02767 Mdot
.838 .02803 Mdot
.838 .02864 Mdot
.838 .02869 Mdot
.838 .02876 Mdot
.838 .02919 Mdot
.838 .02949 Mdot
.838 .02972 Mdot
.838 .02983 Mdot
.838 .02993 Mdot
.838 .03082 Mdot
.838 .03111 Mdot
.838 .03193 Mdot
.838 .03193 Mdot
.838 .03219 Mdot
.838 .03259 Mdot
.838 .03412 Mdot
.838 .03468 Mdot
.838 .03495 Mdot
.838 .03571 Mdot
.838 .03625 Mdot
.838 .03641 Mdot
.838 .03643 Mdot
.838 .03667 Mdot
.838 .03702 Mdot
.838 .03722 Mdot
.838 .03756 Mdot
.838 .03805 Mdot
.838 .0381 Mdot
.838 .03813 Mdot
.838 .03818 Mdot
.838 .03826 Mdot
.838 .03887 Mdot
.838 .03897 Mdot
.838 .03919 Mdot
.838 .03936 Mdot
.838 .03947 Mdot
.838 .03986 Mdot
.838 .04005 Mdot
.838 .04009 Mdot
.838 .04021 Mdot
.838 .04028 Mdot
.838 .04039 Mdot
.838 .04096 Mdot
.838 .04171 Mdot
.838 .04173 Mdot
.838 .04219 Mdot
.838 .04219 Mdot
.838 .04229 Mdot
.838 .04255 Mdot
.838 .04302 Mdot
.838 .04338 Mdot
.838 .04356 Mdot
.838 .04357 Mdot
.838 .04401 Mdot
.838 .04467 Mdot
.838 .0448 Mdot
.838 .04544 Mdot
.838 .04572 Mdot
.838 .04602 Mdot
.838 .0466 Mdot
.838 .04723 Mdot
.838 .04749 Mdot
.838 .04779 Mdot
.838 .04817 Mdot
.838 .04863 Mdot
.838 .04989 Mdot
.838 .0508 Mdot
.838 .05108 Mdot
.838 .05111 Mdot
.838 .05151 Mdot
.838 .05198 Mdot
.838 .0521 Mdot
.838 .05233 Mdot
.838 .05243 Mdot
.838 .05282 Mdot
.838 .05298 Mdot
.838 .053 Mdot
.838 .0537 Mdot
.838 .05383 Mdot
.838 .05389 Mdot
.838 .05392 Mdot
.838 .05396 Mdot
.838 .05404 Mdot
.838 .05417 Mdot
.838 .05446 Mdot
.838 .05519 Mdot
.838 .05536 Mdot
.838 .05548 Mdot
.838 .05574 Mdot
.838 .05602 Mdot
.838 .05621 Mdot
.838 .05666 Mdot
.838 .05686 Mdot
.838 .05717 Mdot
.838 .05724 Mdot
.838 .05744 Mdot
.838 .05756 Mdot
.838 .05773 Mdot
.838 .05774 Mdot
.838 .05821 Mdot
.838 .0587 Mdot
.838 .05888 Mdot
.838 .05996 Mdot
.838 .05999 Mdot
.838 .06076 Mdot
.838 .06076 Mdot
.838 .06094 Mdot
.838 .06109 Mdot
.838 .06136 Mdot
.838 .06167 Mdot
.838 .06215 Mdot
.838 .06275 Mdot
.838 .06307 Mdot
.838 .06308 Mdot
.838 .06381 Mdot
.838 .06382 Mdot
.838 .06438 Mdot
.838 .06452 Mdot
.838 .06492 Mdot
.838 .06514 Mdot
.838 .06544 Mdot
.838 .06621 Mdot
.838 .06658 Mdot
.838 .06669 Mdot
.838 .06717 Mdot
.838 .06717 Mdot
.838 .06785 Mdot
.838 .06792 Mdot
.838 .06816 Mdot
.838 .06921 Mdot
.838 .06964 Mdot
.838 .07015 Mdot
.838 .07079 Mdot
.838 .07135 Mdot
.838 .07155 Mdot
.838 .07299 Mdot
.838 .07308 Mdot
.838 .07353 Mdot
.838 .07368 Mdot
.838 .07387 Mdot
.838 .07513 Mdot
.838 .0752 Mdot
.838 .07566 Mdot
.838 .07571 Mdot
.838 .07579 Mdot
.838 .0758 Mdot
.838 .07595 Mdot
.838 .07639 Mdot
.838 .07654 Mdot
.838 .07718 Mdot
.838 .07738 Mdot
.838 .0774 Mdot
.838 .07777 Mdot
.838 .07793 Mdot
.838 .07793 Mdot
.838 .07858 Mdot
.838 .07882 Mdot
.838 .07884 Mdot
.838 .07887 Mdot
.838 .07929 Mdot
.838 .08005 Mdot
.838 .08027 Mdot
.838 .08037 Mdot
.838 .08042 Mdot
.838 .08049 Mdot
.838 .08058 Mdot
.838 .08062 Mdot
.838 .08085 Mdot
.838 .08133 Mdot
.838 .08156 Mdot
.838 .08256 Mdot
.838 .08284 Mdot
.838 .08303 Mdot
.838 .08347 Mdot
.838 .08395 Mdot
.838 .08409 Mdot
.838 .08417 Mdot
.838 .08426 Mdot
.838 .08502 Mdot
.838 .08528 Mdot
.838 .08536 Mdot
.838 .08571 Mdot
.838 .08587 Mdot
.838 .08599 Mdot
.838 .08632 Mdot
.838 .08652 Mdot
.838 .0868 Mdot
.838 .08682 Mdot
.838 .08762 Mdot
.838 .08788 Mdot
.838 .08796 Mdot
.838 .08804 Mdot
.838 .08812 Mdot
.838 .08843 Mdot
.838 .08873 Mdot
.838 .08987 Mdot
.838 .09025 Mdot
.838 .09055 Mdot
.838 .09059 Mdot
.838 .09113 Mdot
.838 .09189 Mdot
.838 .09189 Mdot
.838 .09218 Mdot
.838 .09245 Mdot
.838 .09259 Mdot
.838 .0929 Mdot
.838 .09342 Mdot
.838 .09421 Mdot
.838 .09439 Mdot
.838 .09522 Mdot
.838 .09575 Mdot
.838 .09578 Mdot
.838 .09643 Mdot
.838 .09694 Mdot
.838 .097 Mdot
.838 .09702 Mdot
.838 .09707 Mdot
.838 .09771 Mdot
.838 .09795 Mdot
.838 .09819 Mdot
.838 .09837 Mdot
.838 .09886 Mdot
.838 .09923 Mdot
.838 .09945 Mdot
.838 .09973 Mdot
.838 .10021 Mdot
.838 .10077 Mdot
.838 .10087 Mdot
.838 .10103 Mdot
.838 .10164 Mdot
.838 .10182 Mdot
.838 .10264 Mdot
.838 .10264 Mdot
.838 .10319 Mdot
.838 .10359 Mdot
.838 .10377 Mdot
.838 .10389 Mdot
.838 .10428 Mdot
.838 .10538 Mdot
.838 .10605 Mdot
.838 .10658 Mdot
.838 .10677 Mdot
.838 .10763 Mdot
.838 .10869 Mdot
.838 .10962 Mdot
.838 .10964 Mdot
.838 .10997 Mdot
.838 .11218 Mdot
.838 .11224 Mdot
.838 .11238 Mdot
.838 .11253 Mdot
.838 .11329 Mdot
.838 .11353 Mdot
.838 .11385 Mdot
.838 .11513 Mdot
.838 .11597 Mdot
.838 .11609 Mdot
.838 .11686 Mdot
.838 .11694 Mdot
.838 .11707 Mdot
.838 .1171 Mdot
.838 .11734 Mdot
.838 .1175 Mdot
.838 .11781 Mdot
.838 .11808 Mdot
.838 .11833 Mdot
.838 .1194 Mdot
.838 .11974 Mdot
.838 .11977 Mdot
.838 .12039 Mdot
.838 .12066 Mdot
.838 .12066 Mdot
.838 .12176 Mdot
.838 .12206 Mdot
.838 .12216 Mdot
.838 .12219 Mdot
.838 .12224 Mdot
.838 .12295 Mdot
.838 .12422 Mdot
.838 .12459 Mdot
.838 .12476 Mdot
.838 .12483 Mdot
.838 .12496 Mdot
.838 .12511 Mdot
.838 .12518 Mdot
.838 .12555 Mdot
.838 .12572 Mdot
.838 .12637 Mdot
.838 .1265 Mdot
.838 .12675 Mdot
.838 .12807 Mdot
.838 .12811 Mdot
.838 .12842 Mdot
.838 .12889 Mdot
.838 .12922 Mdot
.838 .12983 Mdot
.838 .12995 Mdot
.838 .13041 Mdot
.838 .13056 Mdot
.838 .13075 Mdot
.838 .13099 Mdot
.838 .13112 Mdot
.838 .13128 Mdot
.838 .13247 Mdot
.838 .13254 Mdot
.838 .13281 Mdot
.838 .13298 Mdot
.838 .13311 Mdot
.838 .1336 Mdot
.838 .13369 Mdot
.838 .13397 Mdot
.838 .13418 Mdot
.838 .13473 Mdot
.838 .13497 Mdot
.838 .13506 Mdot
.838 .13554 Mdot
.838 .13557 Mdot
.838 .13594 Mdot
.838 .13602 Mdot
.838 .13652 Mdot
.838 .1369 Mdot
.838 .13734 Mdot
.838 .13747 Mdot
.838 .13761 Mdot
.838 .13775 Mdot
.838 .13826 Mdot
.838 .13877 Mdot
.838 .13924 Mdot
.838 .13949 Mdot
.838 .14014 Mdot
.838 .14068 Mdot
.838 .14131 Mdot
.838 .14181 Mdot
.838 .14188 Mdot
.838 .14278 Mdot
.838 .14406 Mdot
.838 .14406 Mdot
.838 .14443 Mdot
.838 .14455 Mdot
.838 .14499 Mdot
.838 .14506 Mdot
.838 .14523 Mdot
.838 .14573 Mdot
.838 .14574 Mdot
.838 .14643 Mdot
.838 .14662 Mdot
.838 .14753 Mdot
.838 .14781 Mdot
.838 .14796 Mdot
.838 .14825 Mdot
.838 .14964 Mdot
.838 .15053 Mdot
.838 .15057 Mdot
.838 .15141 Mdot
.838 .15167 Mdot
.838 .15253 Mdot
.838 .15262 Mdot
.838 .15266 Mdot
.838 .15274 Mdot
.838 .15355 Mdot
.838 .15382 Mdot
.838 .15422 Mdot
.838 .15438 Mdot
.838 .15461 Mdot
.838 .15492 Mdot
.838 .15575 Mdot
.838 .15637 Mdot
.838 .15673 Mdot
.838 .1572 Mdot
.838 .158 Mdot
.838 .15857 Mdot
.838 .15875 Mdot
.838 .15911 Mdot
.838 .15937 Mdot
.838 .15959 Mdot
.838 .1604 Mdot
.838 .1607 Mdot
.838 .16187 Mdot
.838 .16207 Mdot
.838 .16207 Mdot
.838 .1627 Mdot
.838 .163 Mdot
.838 .16323 Mdot
.838 .16367 Mdot
.838 .16386 Mdot
.838 .16392 Mdot
.838 .16397 Mdot
.838 .16417 Mdot
.838 .16483 Mdot
.838 .16666 Mdot
.838 .16689 Mdot
.838 .16731 Mdot
.838 .16779 Mdot
.838 .16795 Mdot
.838 .16841 Mdot
.838 .16858 Mdot
.838 .16868 Mdot
.838 .16873 Mdot
.838 .16896 Mdot
.838 .16899 Mdot
.838 .17044 Mdot
.838 .17167 Mdot
.838 .17222 Mdot
.838 .17276 Mdot
.838 .17378 Mdot
.838 .1738 Mdot
.838 .17403 Mdot
.838 .17437 Mdot
.838 .1759 Mdot
.838 .17665 Mdot
.838 .17777 Mdot
.838 .17806 Mdot
.838 .17817 Mdot
.838 .1784 Mdot
.838 .17866 Mdot
.838 .1792 Mdot
.838 .17993 Mdot
.838 .18033 Mdot
.838 .18087 Mdot
.838 .18301 Mdot
.838 .18312 Mdot
.838 .18443 Mdot
.838 .18462 Mdot
.838 .18591 Mdot
.838 .18602 Mdot
.838 .18604 Mdot
.838 .18627 Mdot
.838 .18631 Mdot
.838 .18642 Mdot
.838 .18671 Mdot
.838 .18698 Mdot
.838 .18751 Mdot
.838 .18775 Mdot
.838 .18795 Mdot
.838 .18838 Mdot
.838 .18996 Mdot
.838 .19017 Mdot
.838 .19073 Mdot
.838 .1908 Mdot
.838 .19182 Mdot
.838 .19227 Mdot
.838 .19228 Mdot
.838 .1937 Mdot
.838 .19412 Mdot
.838 .19462 Mdot
.838 .19479 Mdot
.838 .19485 Mdot
.838 .19493 Mdot
.838 .19611 Mdot
.838 .1964 Mdot
.838 .19726 Mdot
.838 .19824 Mdot
.838 .19886 Mdot
.838 .19895 Mdot
.838 .19915 Mdot
.838 .19927 Mdot
.838 .19949 Mdot
.838 .19973 Mdot
.838 .19985 Mdot
.838 .20017 Mdot
.838 .20048 Mdot
.838 .20075 Mdot
.838 .20121 Mdot
.838 .20185 Mdot
.838 .20207 Mdot
.838 .20228 Mdot
.838 .20249 Mdot
.838 .2028 Mdot
.838 .20453 Mdot
.838 .2047 Mdot
.838 .20476 Mdot
.838 .20501 Mdot
.838 .20529 Mdot
.838 .20607 Mdot
.838 .20645 Mdot
.838 .20662 Mdot
.838 .20765 Mdot
.838 .20785 Mdot
.838 .20862 Mdot
.838 .20887 Mdot
.838 .20919 Mdot
.838 .2096 Mdot
.838 .20981 Mdot
.838 .21005 Mdot
.838 .21008 Mdot
.838 .21191 Mdot
.838 .21208 Mdot
.838 .21219 Mdot
.838 .21264 Mdot
.838 .21288 Mdot
.838 .21288 Mdot
.838 .21293 Mdot
.838 .21315 Mdot
.838 .21396 Mdot
.838 .21413 Mdot
.838 .21458 Mdot
.838 .21493 Mdot
.838 .21583 Mdot
.838 .21586 Mdot
.838 .21626 Mdot
.838 .21641 Mdot
.838 .21718 Mdot
.838 .21721 Mdot
.838 .21724 Mdot
.838 .21727 Mdot
.838 .21789 Mdot
.838 .21803 Mdot
.838 .21834 Mdot
.838 .21886 Mdot
.838 .2195 Mdot
.838 .22023 Mdot
.838 .22041 Mdot
.838 .22045 Mdot
.838 .22068 Mdot
.838 .22092 Mdot
.838 .2213 Mdot
.838 .22157 Mdot
.838 .22177 Mdot
.838 .22181 Mdot
.838 .22263 Mdot
.838 .22278 Mdot
.838 .22341 Mdot
.838 .22384 Mdot
.838 .22492 Mdot
.838 .22583 Mdot
.838 .22586 Mdot
.838 .22688 Mdot
.838 .22773 Mdot
.838 .22784 Mdot
.838 .22935 Mdot
.838 .23065 Mdot
.838 .23093 Mdot
.838 .23149 Mdot
.838 .2315 Mdot
.838 .23212 Mdot
.838 .23232 Mdot
.838 .23238 Mdot
.838 .23306 Mdot
.838 .23318 Mdot
.838 .23346 Mdot
.838 .23395 Mdot
.838 .23429 Mdot
.838 .23432 Mdot
.838 .2345 Mdot
.838 .23547 Mdot
.838 .23556 Mdot
.838 .23579 Mdot
.838 .23731 Mdot
.838 .23754 Mdot
.838 .23778 Mdot
.838 .23803 Mdot
.838 .23842 Mdot
.838 .23852 Mdot
.838 .2398 Mdot
.838 .24056 Mdot
.838 .24086 Mdot
.838 .24235 Mdot
.838 .24241 Mdot
.838 .24271 Mdot
.838 .24352 Mdot
.838 .24382 Mdot
.838 .24401 Mdot
.838 .24423 Mdot
.838 .24425 Mdot
.838 .24531 Mdot
.838 .24546 Mdot
.838 .24569 Mdot
.838 .24585 Mdot
.838 .24591 Mdot
.838 .24605 Mdot
.838 .24701 Mdot
.838 .2474 Mdot
.838 .24785 Mdot
.838 .24852 Mdot
.838 .24879 Mdot
.838 .24918 Mdot
.838 .24969 Mdot
.838 .25109 Mdot
.838 .25212 Mdot
.838 .25226 Mdot
.838 .25274 Mdot
.838 .25352 Mdot
.838 .25485 Mdot
.838 .25581 Mdot
.838 .25612 Mdot
.838 .25672 Mdot
.838 .25716 Mdot
.838 .25753 Mdot
.838 .25791 Mdot
.838 .25809 Mdot
.838 .25871 Mdot
.838 .25888 Mdot
.838 .25939 Mdot
.838 .26068 Mdot
.838 .26134 Mdot
.838 .26168 Mdot
.838 .26168 Mdot
.838 .26273 Mdot
.838 .26321 Mdot
.838 .26323 Mdot
.838 .26363 Mdot
.838 .26436 Mdot
.838 .26468 Mdot
.838 .26478 Mdot
.838 .26486 Mdot
.838 .26521 Mdot
.838 .2663 Mdot
.838 .26801 Mdot
.838 .26811 Mdot
.838 .26862 Mdot
.838 .26918 Mdot
.838 .26938 Mdot
.838 .26976 Mdot
.838 .27046 Mdot
.838 .27077 Mdot
.838 .27127 Mdot
.838 .27154 Mdot
.838 .2723 Mdot
.838 .27259 Mdot
.838 .27276 Mdot
.838 .27284 Mdot
.838 .27323 Mdot
.838 .27328 Mdot
.838 .27383 Mdot
.838 .2757 Mdot
.838 .27771 Mdot
.838 .27778 Mdot
.838 .278 Mdot
.838 .2787 Mdot
.838 .2796 Mdot
.838 .28131 Mdot
.838 .28134 Mdot
.838 .28153 Mdot
.838 .28173 Mdot
.838 .28229 Mdot
.838 .28338 Mdot
.838 .28476 Mdot
.838 .28486 Mdot
.838 .28612 Mdot
.838 .28678 Mdot
.838 .28727 Mdot
.838 .28799 Mdot
.838 .28817 Mdot
.838 .28849 Mdot
.838 .28867 Mdot
.838 .28868 Mdot
.838 .28871 Mdot
.838 .2888 Mdot
.838 .28906 Mdot
.838 .28907 Mdot
.838 .28949 Mdot
.838 .28977 Mdot
.838 .2898 Mdot
.838 .29038 Mdot
.838 .29098 Mdot
.838 .29162 Mdot
.838 .29177 Mdot
.838 .29185 Mdot
.838 .29229 Mdot
.838 .29318 Mdot
.838 .2935 Mdot
.838 .29517 Mdot
.838 .29677 Mdot
.838 .29696 Mdot
.838 .29698 Mdot
.838 .29741 Mdot
.838 .29762 Mdot
.838 .29886 Mdot
.838 .29915 Mdot
.838 .29947 Mdot
.838 .30137 Mdot
.838 .30163 Mdot
.838 .30183 Mdot
.838 .30185 Mdot
.838 .30223 Mdot
.838 .30226 Mdot
.838 .30231 Mdot
.838 .30249 Mdot
.838 .30299 Mdot
.838 .30342 Mdot
.838 .30431 Mdot
.838 .30472 Mdot
.838 .30506 Mdot
.838 .30578 Mdot
.838 .30695 Mdot
.838 .30843 Mdot
.838 .30878 Mdot
.838 .30971 Mdot
.838 .30983 Mdot
.838 .31145 Mdot
.838 .31155 Mdot
.838 .31198 Mdot
.838 .31202 Mdot
.838 .3123 Mdot
.838 .31231 Mdot
.838 .31322 Mdot
.838 .31382 Mdot
.838 .31469 Mdot
.838 .3154 Mdot
.838 .31623 Mdot
.838 .31653 Mdot
.838 .31662 Mdot
.838 .31676 Mdot
.838 .3173 Mdot
.838 .31813 Mdot
.838 .31873 Mdot
.838 .31903 Mdot
.838 .31921 Mdot
.838 .32067 Mdot
.838 .32231 Mdot
.838 .32334 Mdot
.838 .3235 Mdot
.838 .32382 Mdot
.838 .32402 Mdot
.838 .32435 Mdot
.838 .3244 Mdot
.838 .32481 Mdot
.838 .325 Mdot
.838 .3251 Mdot
.838 .32554 Mdot
.838 .32565 Mdot
.838 .32571 Mdot
.838 .32605 Mdot
.838 .32651 Mdot
.838 .32679 Mdot
.838 .32685 Mdot
.838 .327 Mdot
.838 .32728 Mdot
.838 .3275 Mdot
.838 .32835 Mdot
.838 .32873 Mdot
.838 .3289 Mdot
.838 .32907 Mdot
.838 .32942 Mdot
.838 .32995 Mdot
.838 .33013 Mdot
.838 .33263 Mdot
.838 .33284 Mdot
.838 .33313 Mdot
.838 .33323 Mdot
.838 .33366 Mdot
.838 .33377 Mdot
.838 .33411 Mdot
.838 .33472 Mdot
.838 .33542 Mdot
.838 .33606 Mdot
.838 .33635 Mdot
.838 .33675 Mdot
.838 .33807 Mdot
.838 .33841 Mdot
.838 .3397 Mdot
.838 .34003 Mdot
.838 .34011 Mdot
.838 .34066 Mdot
.838 .34134 Mdot
.838 .3417 Mdot
.838 .3421 Mdot
.838 .34214 Mdot
.838 .34419 Mdot
.838 .34517 Mdot
.838 .34522 Mdot
.838 .34549 Mdot
.838 .34569 Mdot
.838 .34644 Mdot
.838 .34684 Mdot
.838 .34685 Mdot
.838 .34693 Mdot
.838 .34728 Mdot
.838 .3478 Mdot
.838 .34811 Mdot
.838 .34865 Mdot
.838 .34893 Mdot
.838 .3497 Mdot
.838 .35028 Mdot
.838 .35179 Mdot
.838 .35184 Mdot
.838 .3525 Mdot
.838 .35275 Mdot
.838 .35405 Mdot
.838 .3541 Mdot
.838 .35415 Mdot
.838 .3542 Mdot
.838 .35524 Mdot
.838 .35546 Mdot
.838 .35599 Mdot
.838 .35686 Mdot
.838 .35793 Mdot
.838 .35915 Mdot
.838 .35946 Mdot
.838 .35953 Mdot
.838 .35992 Mdot
.838 .36031 Mdot
.838 .36095 Mdot
.838 .3614 Mdot
.838 .36174 Mdot
.838 .3618 Mdot
.838 .36318 Mdot
.838 .36342 Mdot
.838 .36449 Mdot
.838 .36521 Mdot
.838 .36702 Mdot
.838 .36855 Mdot
.838 .36859 Mdot
.838 .37031 Mdot
.838 .37172 Mdot
.838 .37191 Mdot
.838 .37444 Mdot
.838 .37663 Mdot
.838 .3771 Mdot
.838 .37803 Mdot
.838 .37805 Mdot
.838 .37908 Mdot
.838 .37943 Mdot
.838 .37951 Mdot
.838 .38066 Mdot
.838 .38086 Mdot
.838 .38133 Mdot
.838 .38215 Mdot
.838 .38273 Mdot
.838 .38277 Mdot
.838 .38307 Mdot
.838 .38469 Mdot
.838 .38485 Mdot
.838 .38523 Mdot
.838 .38779 Mdot
.838 .38817 Mdot
.838 .38857 Mdot
.838 .38898 Mdot
.838 .38964 Mdot
.838 .38981 Mdot
.838 .39196 Mdot
.838 .39323 Mdot
.838 .39373 Mdot
.838 .39623 Mdot
.838 .39634 Mdot
.838 .39684 Mdot
.838 .39819 Mdot
.838 .39869 Mdot
.838 .39901 Mdot
.838 .39938 Mdot
.838 .39942 Mdot
.838 .40119 Mdot
.838 .40144 Mdot
.838 .40183 Mdot
.838 .4021 Mdot
.838 .4022 Mdot
.838 .40243 Mdot
.838 .40405 Mdot
.838 .4047 Mdot
.838 .40545 Mdot
.838 .40657 Mdot
.838 .40702 Mdot
.838 .40768 Mdot
.838 .40853 Mdot
.838 .41088 Mdot
.838 .41261 Mdot
.838 .41284 Mdot
.838 .41364 Mdot
.838 .41496 Mdot
.838 .41719 Mdot
.838 .4188 Mdot
.838 .41932 Mdot
.838 .42032 Mdot
.838 .42105 Mdot
.838 .42167 Mdot
.838 .42231 Mdot
.838 .42262 Mdot
.838 .42365 Mdot
.838 .42394 Mdot
.838 .4248 Mdot
.838 .42695 Mdot
.838 .42806 Mdot
.838 .42863 Mdot
.838 .42863 Mdot
.838 .4304 Mdot
.838 .4312 Mdot
.838 .43123 Mdot
.838 .43189 Mdot
.838 .43312 Mdot
.838 .43366 Mdot
.838 .43382 Mdot
.838 .43396 Mdot
.838 .43454 Mdot
.838 .43638 Mdot
.838 .43924 Mdot
.838 .4394 Mdot
.838 .44027 Mdot
.838 .4412 Mdot
.838 .44153 Mdot
.838 .44216 Mdot
.838 .44335 Mdot
.838 .44387 Mdot
.838 .44469 Mdot
.838 .44515 Mdot
.838 .44643 Mdot
.838 .44692 Mdot
.838 .44721 Mdot
.838 .44734 Mdot
.838 .44798 Mdot
.838 .44807 Mdot
.838 .449 Mdot
.838 .45213 Mdot
.838 .4555 Mdot
.838 .45561 Mdot
.838 .45598 Mdot
.838 .45715 Mdot
.838 .45867 Mdot
.838 .46153 Mdot
.838 .46159 Mdot
.838 .46189 Mdot
.838 .46223 Mdot
.838 .46318 Mdot
.838 .465 Mdot
.838 .46732 Mdot
.838 .46749 Mdot
.838 .46959 Mdot
.838 .4707 Mdot
.838 .47152 Mdot
.838 .47273 Mdot
.838 .47302 Mdot
.838 .47355 Mdot
.838 .47386 Mdot
.838 .47388 Mdot
.838 .47393 Mdot
.838 .47409 Mdot
.838 .47451 Mdot
.838 .47453 Mdot
.838 .47523 Mdot
.838 .47571 Mdot
.838 .47575 Mdot
.838 .47674 Mdot
.838 .47773 Mdot
.838 .47881 Mdot
.838 .47907 Mdot
.838 .47919 Mdot
.838 .47993 Mdot
.838 .48143 Mdot
.838 .48196 Mdot
.838 .48476 Mdot
.838 .48745 Mdot
.838 .48776 Mdot
.838 .48779 Mdot
.838 .4885 Mdot
.838 .48886 Mdot
.838 .49094 Mdot
.838 .49143 Mdot
.838 .49197 Mdot
.838 .49514 Mdot
.838 .49559 Mdot
.838 .49592 Mdot
.838 .49596 Mdot
.838 .4966 Mdot
.838 .49663 Mdot
.838 .49673 Mdot
.838 .49702 Mdot
.838 .49786 Mdot
.838 .49859 Mdot
.838 .50008 Mdot
.838 .50076 Mdot
.838 .50133 Mdot
.838 .50254 Mdot
.838 .5045 Mdot
.838 .50698 Mdot
.838 .50756 Mdot
.838 .50913 Mdot
.838 .50932 Mdot
.84 .01662 Mdot
.84 .01791 Mdot
.84 .01831 Mdot
.84 .01833 Mdot
.84 .01859 Mdot
.84 .01995 Mdot
.84 .02009 Mdot
.84 .02075 Mdot
.84 .02079 Mdot
.84 .02089 Mdot
.84 .02102 Mdot
.84 .02122 Mdot
.84 .02173 Mdot
.84 .02204 Mdot
.84 .02285 Mdot
.84 .02331 Mdot
.84 .02351 Mdot
.84 .02375 Mdot
.84 .02486 Mdot
.84 .02492 Mdot
.84 .02509 Mdot
.84 .02532 Mdot
.84 .02565 Mdot
.84 .02566 Mdot
.84 .02622 Mdot
.84 .0265 Mdot
.84 .02683 Mdot
.84 .02702 Mdot
.84 .02838 Mdot
.84 .02894 Mdot
.84 .02902 Mdot
.84 .02916 Mdot
.84 .0295 Mdot
.84 .02988 Mdot
.84 .02989 Mdot
.84 .03024 Mdot
.84 .03052 Mdot
.84 .03091 Mdot
.84 .03176 Mdot
.84 .03187 Mdot
.84 .03214 Mdot
.84 .03252 Mdot
.84 .03309 Mdot
.84 .0331 Mdot
.84 .03368 Mdot
.84 .03378 Mdot
.84 .03403 Mdot
.84 .03405 Mdot
.84 .03421 Mdot
.84 .03429 Mdot
.84 .03451 Mdot
.84 .03493 Mdot
.84 .03507 Mdot
.84 .03539 Mdot
.84 .03556 Mdot
.84 .0367 Mdot
.84 .03697 Mdot
.84 .03767 Mdot
.84 .03861 Mdot
.84 .03874 Mdot
.84 .03898 Mdot
.84 .03955 Mdot
.84 .04019 Mdot
.84 .0402 Mdot
.84 .0408 Mdot
.84 .04097 Mdot
.84 .04126 Mdot
.84 .04175 Mdot
.84 .04192 Mdot
.84 .04334 Mdot
.84 .04353 Mdot
.84 .04367 Mdot
.84 .04399 Mdot
.84 .04463 Mdot
.84 .04477 Mdot
.84 .04499 Mdot
.84 .04542 Mdot
.84 .04558 Mdot
.84 .0456 Mdot
.84 .0456 Mdot
.84 .04635 Mdot
.84 .04657 Mdot
.84 .04674 Mdot
.84 .04716 Mdot
.84 .0472 Mdot
.84 .04747 Mdot
.84 .04761 Mdot
.84 .04797 Mdot
.84 .04837 Mdot
.84 .04868 Mdot
.84 .04891 Mdot
.84 .04945 Mdot
.84 .0495 Mdot
.84 .04954 Mdot
.84 .04973 Mdot
.84 .05012 Mdot
.84 .05034 Mdot
.84 .05133 Mdot
.84 .05165 Mdot
.84 .0521 Mdot
.84 .05301 Mdot
.84 .05325 Mdot
.84 .05328 Mdot
.84 .05485 Mdot
.84 .05508 Mdot
.84 .05508 Mdot
.84 .05513 Mdot
.84 .05516 Mdot
.84 .05528 Mdot
.84 .05547 Mdot
.84 .05644 Mdot
.84 .05752 Mdot
.84 .05754 Mdot
.84 .05812 Mdot
.84 .05818 Mdot
.84 .05854 Mdot
.84 .05878 Mdot
.84 .05883 Mdot
.84 .05918 Mdot
.84 .05921 Mdot
.84 .05931 Mdot
.84 .06014 Mdot
.84 .06015 Mdot
.84 .06042 Mdot
.84 .06053 Mdot
.84 .06059 Mdot
.84 .06076 Mdot
.84 .0608 Mdot
.84 .06128 Mdot
.84 .06133 Mdot
.84 .06138 Mdot
.84 .06141 Mdot
.84 .06281 Mdot
.84 .06302 Mdot
.84 .0631 Mdot
.84 .06312 Mdot
.84 .06336 Mdot
.84 .06345 Mdot
.84 .06368 Mdot
.84 .0639 Mdot
.84 .06415 Mdot
.84 .06498 Mdot
.84 .06521 Mdot
.84 .06557 Mdot
.84 .06595 Mdot
.84 .06629 Mdot
.84 .06637 Mdot
.84 .06654 Mdot
.84 .06657 Mdot
.84 .0666 Mdot
.84 .06661 Mdot
.84 .06717 Mdot
.84 .06787 Mdot
.84 .06823 Mdot
.84 .06852 Mdot
.84 .06873 Mdot
.84 .06922 Mdot
.84 .06929 Mdot
.84 .06975 Mdot
.84 .06997 Mdot
.84 .07012 Mdot
.84 .07058 Mdot
.84 .07125 Mdot
.84 .07147 Mdot
.84 .07178 Mdot
.84 .07216 Mdot
.84 .07307 Mdot
.84 .07316 Mdot
.84 .07323 Mdot
.84 .07331 Mdot
.84 .07334 Mdot
.84 .07355 Mdot
.84 .0742 Mdot
.84 .07456 Mdot
.84 .07456 Mdot
.84 .0746 Mdot
.84 .07478 Mdot
.84 .07563 Mdot
.84 .07598 Mdot
.84 .07623 Mdot
.84 .07633 Mdot
.84 .07674 Mdot
.84 .07677 Mdot
.84 .07752 Mdot
.84 .07795 Mdot
.84 .07852 Mdot
.84 .07906 Mdot
.84 .07945 Mdot
.84 .0795 Mdot
.84 .0813 Mdot
.84 .08155 Mdot
.84 .08191 Mdot
.84 .08215 Mdot
.84 .08217 Mdot
.84 .08252 Mdot
.84 .08253 Mdot
.84 .08261 Mdot
.84 .08266 Mdot
.84 .08286 Mdot
.84 .08319 Mdot
.84 .0842 Mdot
.84 .08461 Mdot
.84 .08481 Mdot
.84 .08662 Mdot
.84 .08665 Mdot
.84 .08719 Mdot
.84 .08763 Mdot
.84 .08774 Mdot
.84 .08834 Mdot
.84 .08875 Mdot
.84 .08883 Mdot
.84 .08942 Mdot
.84 .08946 Mdot
.84 .08964 Mdot
.84 .09042 Mdot
.84 .09078 Mdot
.84 .09102 Mdot
.84 .09104 Mdot
.84 .09104 Mdot
.84 .0915 Mdot
.84 .09169 Mdot
.84 .09178 Mdot
.84 .09206 Mdot
.84 .09214 Mdot
.84 .09295 Mdot
.84 .09302 Mdot
.84 .09311 Mdot
.84 .09316 Mdot
.84 .09532 Mdot
.84 .09552 Mdot
.84 .09586 Mdot
.84 .096 Mdot
.84 .09604 Mdot
.84 .09644 Mdot
.84 .09659 Mdot
.84 .09698 Mdot
.84 .09731 Mdot
.84 .09735 Mdot
.84 .09777 Mdot
.84 .09879 Mdot
.84 .09915 Mdot
.84 .09945 Mdot
.84 .09955 Mdot
.84 .09971 Mdot
.84 .10016 Mdot
.84 .10051 Mdot
.84 .1008 Mdot
.84 .10137 Mdot
.84 .1015 Mdot
.84 .10177 Mdot
.84 .10183 Mdot
.84 .10188 Mdot
.84 .10189 Mdot
.84 .10216 Mdot
.84 .10284 Mdot
.84 .10401 Mdot
.84 .10445 Mdot
.84 .10462 Mdot
.84 .1051 Mdot
.84 .10547 Mdot
.84 .10629 Mdot
.84 .10639 Mdot
.84 .10703 Mdot
.84 .10717 Mdot
.84 .10754 Mdot
.84 .10772 Mdot
.84 .1078 Mdot
.84 .10837 Mdot
.84 .10857 Mdot
.84 .1097 Mdot
.84 .11006 Mdot
.84 .11058 Mdot
.84 .11122 Mdot
.84 .11275 Mdot
.84 .1129 Mdot
.84 .11301 Mdot
.84 .11303 Mdot
.84 .11316 Mdot
.84 .1132 Mdot
.84 .11339 Mdot
.84 .11355 Mdot
.84 .11458 Mdot
.84 .11465 Mdot
.84 .1148 Mdot
.84 .11525 Mdot
.84 .11526 Mdot
.84 .11532 Mdot
.84 .11562 Mdot
.84 .11705 Mdot
.84 .11752 Mdot
.84 .11763 Mdot
.84 .11806 Mdot
.84 .11823 Mdot
.84 .11883 Mdot
.84 .11892 Mdot
.84 .11896 Mdot
.84 .12024 Mdot
.84 .12029 Mdot
.84 .12096 Mdot
.84 .12102 Mdot
.84 .1219 Mdot
.84 .12281 Mdot
.84 .12348 Mdot
.84 .12355 Mdot
.84 .12359 Mdot
.84 .12374 Mdot
.84 .12387 Mdot
.84 .12558 Mdot
.84 .12582 Mdot
.84 .12595 Mdot
.84 .12599 Mdot
.84 .12657 Mdot
.84 .12699 Mdot
.84 .1276 Mdot
.84 .128 Mdot
.84 .12803 Mdot
.84 .12863 Mdot
.84 .12864 Mdot
.84 .12877 Mdot
.84 .12885 Mdot
.84 .12915 Mdot
.84 .1292 Mdot
.84 .12966 Mdot
.84 .12968 Mdot
.84 .12976 Mdot
.84 .13116 Mdot
.84 .13145 Mdot
.84 .13184 Mdot
.84 .13214 Mdot
.84 .13247 Mdot
.84 .13352 Mdot
.84 .13357 Mdot
.84 .13413 Mdot
.84 .13476 Mdot
.84 .13552 Mdot
.84 .13557 Mdot
.84 .13648 Mdot
.84 .13721 Mdot
.84 .13735 Mdot
.84 .1374 Mdot
.84 .13757 Mdot
.84 .1384 Mdot
.84 .13909 Mdot
.84 .13923 Mdot
.84 .14021 Mdot
.84 .14029 Mdot
.84 .14058 Mdot
.84 .14116 Mdot
.84 .14174 Mdot
.84 .1419 Mdot
.84 .14247 Mdot
.84 .1425 Mdot
.84 .14286 Mdot
.84 .14291 Mdot
.84 .14294 Mdot
.84 .14295 Mdot
.84 .14372 Mdot
.84 .14404 Mdot
.84 .14418 Mdot
.84 .14466 Mdot
.84 .1448 Mdot
.84 .14614 Mdot
.84 .14627 Mdot
.84 .14642 Mdot
.84 .1465 Mdot
.84 .14819 Mdot
.84 .14838 Mdot
.84 .15014 Mdot
.84 .15046 Mdot
.84 .15085 Mdot
.84 .15104 Mdot
.84 .15127 Mdot
.84 .15134 Mdot
.84 .15177 Mdot
.84 .15201 Mdot
.84 .15226 Mdot
.84 .15292 Mdot
.84 .15347 Mdot
.84 .15354 Mdot
.84 .15424 Mdot
.84 .15596 Mdot
.84 .15631 Mdot
.84 .15657 Mdot
.84 .15707 Mdot
.84 .15724 Mdot
.84 .1575 Mdot
.84 .15826 Mdot
.84 .15886 Mdot
.84 .15933 Mdot
.84 .16008 Mdot
.84 .16025 Mdot
.84 .16029 Mdot
.84 .16052 Mdot
.84 .16097 Mdot
.84 .16107 Mdot
.84 .16115 Mdot
.84 .16117 Mdot
.84 .16162 Mdot
.84 .16164 Mdot
.84 .16277 Mdot
.84 .16349 Mdot
.84 .16438 Mdot
.84 .16473 Mdot
.84 .16515 Mdot
.84 .16547 Mdot
.84 .16548 Mdot
.84 .16576 Mdot
.84 .16578 Mdot
.84 .16657 Mdot
.84 .16718 Mdot
.84 .16784 Mdot
.84 .16856 Mdot
.84 .16874 Mdot
.84 .16898 Mdot
.84 .1698 Mdot
.84 .17004 Mdot
.84 .17016 Mdot
.84 .17067 Mdot
.84 .17096 Mdot
.84 .1711 Mdot
.84 .17175 Mdot
.84 .17206 Mdot
.84 .17239 Mdot
.84 .17329 Mdot
.84 .17429 Mdot
.84 .17484 Mdot
.84 .17489 Mdot
.84 .17577 Mdot
.84 .17588 Mdot
.84 .17621 Mdot
.84 .17684 Mdot
.84 .1772 Mdot
.84 .17941 Mdot
.84 .17956 Mdot
.84 .17967 Mdot
.84 .17986 Mdot
.84 .17989 Mdot
.84 .1801 Mdot
.84 .18016 Mdot
.84 .18024 Mdot
.84 .18048 Mdot
.84 .18049 Mdot
.84 .18076 Mdot
.84 .18249 Mdot
.84 .18261 Mdot
.84 .18286 Mdot
.84 .18362 Mdot
.84 .18363 Mdot
.84 .18374 Mdot
.84 .18423 Mdot
.84 .18628 Mdot
.84 .18664 Mdot
.84 .18742 Mdot
.84 .18762 Mdot
.84 .18769 Mdot
.84 .18834 Mdot
.84 .18862 Mdot
.84 .18935 Mdot
.84 .18962 Mdot
.84 .18977 Mdot
.84 .18985 Mdot
.84 .19061 Mdot
.84 .19139 Mdot
.84 .19199 Mdot
.84 .19209 Mdot
.84 .19295 Mdot
.84 .1932 Mdot
.84 .19331 Mdot
.84 .19376 Mdot
.84 .19459 Mdot
.84 .19479 Mdot
.84 .19501 Mdot
.84 .19622 Mdot
.84 .19631 Mdot
.84 .19743 Mdot
.84 .19756 Mdot
.84 .19762 Mdot
.84 .19788 Mdot
.84 .1981 Mdot
.84 .1986 Mdot
.84 .20097 Mdot
.84 .20137 Mdot
.84 .20144 Mdot
.84 .20159 Mdot
.84 .20166 Mdot
.84 .20264 Mdot
.84 .20304 Mdot
.84 .20334 Mdot
.84 .20369 Mdot
.84 .20437 Mdot
.84 .20503 Mdot
.84 .20509 Mdot
.84 .20609 Mdot
.84 .20612 Mdot
.84 .20633 Mdot
.84 .20647 Mdot
.84 .20681 Mdot
.84 .20695 Mdot
.84 .20697 Mdot
.84 .20705 Mdot
.84 .20721 Mdot
.84 .20726 Mdot
.84 .20783 Mdot
.84 .20786 Mdot
.84 .20798 Mdot
.84 .20807 Mdot
.84 .20823 Mdot
.84 .20887 Mdot
.84 .20902 Mdot
.84 .2093 Mdot
.84 .21035 Mdot
.84 .21082 Mdot
.84 .21148 Mdot
.84 .21149 Mdot
.84 .21192 Mdot
.84 .212 Mdot
.84 .2123 Mdot
.84 .21242 Mdot
.84 .21255 Mdot
.84 .21431 Mdot
.84 .21439 Mdot
.84 .21452 Mdot
.84 .21461 Mdot
.84 .21533 Mdot
.84 .2164 Mdot
.84 .21754 Mdot
.84 .21766 Mdot
.84 .21776 Mdot
.84 .21928 Mdot
.84 .21998 Mdot
.84 .2205 Mdot
.84 .22074 Mdot
.84 .22083 Mdot
.84 .22112 Mdot
.84 .2217 Mdot
.84 .22251 Mdot
.84 .22342 Mdot
.84 .22367 Mdot
.84 .2239 Mdot
.84 .22555 Mdot
.84 .22568 Mdot
.84 .2261 Mdot
.84 .22618 Mdot
.84 .22714 Mdot
.84 .2276 Mdot
.84 .22812 Mdot
.84 .22838 Mdot
.84 .22929 Mdot
.84 .22934 Mdot
.84 .22939 Mdot
.84 .23 Mdot
.84 .23008 Mdot
.84 .23013 Mdot
.84 .23014 Mdot
.84 .23126 Mdot
.84 .23144 Mdot
.84 .23197 Mdot
.84 .23221 Mdot
.84 .23281 Mdot
.84 .23283 Mdot
.84 .23303 Mdot
.84 .23325 Mdot
.84 .23417 Mdot
.84 .23425 Mdot
.84 .23552 Mdot
.84 .23572 Mdot
.84 .23598 Mdot
.84 .23612 Mdot
.84 .23801 Mdot
.84 .23808 Mdot
.84 .23895 Mdot
.84 .23928 Mdot
.84 .24088 Mdot
.84 .24222 Mdot
.84 .24228 Mdot
.84 .24277 Mdot
.84 .24343 Mdot
.84 .24374 Mdot
.84 .24401 Mdot
.84 .24413 Mdot
.84 .24424 Mdot
.84 .24497 Mdot
.84 .24537 Mdot
.84 .24579 Mdot
.84 .24635 Mdot
.84 .2469 Mdot
.84 .24745 Mdot
.84 .24782 Mdot
.84 .24793 Mdot
.84 .24829 Mdot
.84 .24912 Mdot
.84 .24936 Mdot
.84 .24945 Mdot
.84 .2515 Mdot
.84 .252 Mdot
.84 .25259 Mdot
.84 .25304 Mdot
.84 .25331 Mdot
.84 .25387 Mdot
.84 .25415 Mdot
.84 .25445 Mdot
.84 .25459 Mdot
.84 .25502 Mdot
.84 .25587 Mdot
.84 .25687 Mdot
.84 .25744 Mdot
.84 .25767 Mdot
.84 .25878 Mdot
.84 .25883 Mdot
.84 .25892 Mdot
.84 .25894 Mdot
.84 .25922 Mdot
.84 .25928 Mdot
.84 .25951 Mdot
.84 .25956 Mdot
.84 .25966 Mdot
.84 .26043 Mdot
.84 .26059 Mdot
.84 .26072 Mdot
.84 .26076 Mdot
.84 .26151 Mdot
.84 .26154 Mdot
.84 .26258 Mdot
.84 .26344 Mdot
.84 .26405 Mdot
.84 .26466 Mdot
.84 .26561 Mdot
.84 .26614 Mdot
.84 .26674 Mdot
.84 .26744 Mdot
.84 .26799 Mdot
.84 .26799 Mdot
.84 .26847 Mdot
.84 .2685 Mdot
.84 .26983 Mdot
.84 .26985 Mdot
.84 .27085 Mdot
.84 .27134 Mdot
.84 .27196 Mdot
.84 .27279 Mdot
.84 .27318 Mdot
.84 .27347 Mdot
.84 .27385 Mdot
.84 .27388 Mdot
.84 .27461 Mdot
.84 .27525 Mdot
.84 .27566 Mdot
.84 .27586 Mdot
.84 .27672 Mdot
.84 .27719 Mdot
.84 .27721 Mdot
.84 .27724 Mdot
.84 .27745 Mdot
.84 .27747 Mdot
.84 .27854 Mdot
.84 .27906 Mdot
.84 .27961 Mdot
.84 .28111 Mdot
.84 .28164 Mdot
.84 .28215 Mdot
.84 .28253 Mdot
.84 .2828 Mdot
.84 .28371 Mdot
.84 .28373 Mdot
.84 .28381 Mdot
.84 .28529 Mdot
.84 .28547 Mdot
.84 .2856 Mdot
.84 .28602 Mdot
.84 .28669 Mdot
.84 .28708 Mdot
.84 .28769 Mdot
.84 .28842 Mdot
.84 .29046 Mdot
.84 .2914 Mdot
.84 .29166 Mdot
.84 .29184 Mdot
.84 .29215 Mdot
.84 .29221 Mdot
.84 .29256 Mdot
.84 .29267 Mdot
.84 .29279 Mdot
.84 .29321 Mdot
.84 .29321 Mdot
.84 .29368 Mdot
.84 .29624 Mdot
.84 .29658 Mdot
.84 .29678 Mdot
.84 .29719 Mdot
.84 .29848 Mdot
.84 .29849 Mdot
.84 .29868 Mdot
.84 .29889 Mdot
.84 .2995 Mdot
.84 .29961 Mdot
.84 .30011 Mdot
.84 .30102 Mdot
.84 .30118 Mdot
.84 .30215 Mdot
.84 .30247 Mdot
.84 .30282 Mdot
.84 .30295 Mdot
.84 .30356 Mdot
.84 .30399 Mdot
.84 .30401 Mdot
.84 .30486 Mdot
.84 .30519 Mdot
.84 .30531 Mdot
.84 .30532 Mdot
.84 .30641 Mdot
.84 .30687 Mdot
.84 .30811 Mdot
.84 .30856 Mdot
.84 .30881 Mdot
.84 .30893 Mdot
.84 .31022 Mdot
.84 .31153 Mdot
.84 .31254 Mdot
.84 .31255 Mdot
.84 .3127 Mdot
.84 .31351 Mdot
.84 .31407 Mdot
.84 .31415 Mdot
.84 .31457 Mdot
.84 .31476 Mdot
.84 .31524 Mdot
.84 .31551 Mdot
.84 .31691 Mdot
.84 .31725 Mdot
.84 .31761 Mdot
.84 .31886 Mdot
.84 .31891 Mdot
.84 .31942 Mdot
.84 .31964 Mdot
.84 .3198 Mdot
.84 .32004 Mdot
.84 .32168 Mdot
.84 .32174 Mdot
.84 .32189 Mdot
.84 .322 Mdot
.84 .32205 Mdot
.84 .32243 Mdot
.84 .3228 Mdot
.84 .32348 Mdot
.84 .32364 Mdot
.84 .32603 Mdot
.84 .32649 Mdot
.84 .32763 Mdot
.84 .32829 Mdot
.84 .32842 Mdot
.84 .32867 Mdot
.84 .32878 Mdot
.84 .32923 Mdot
.84 .33013 Mdot
.84 .33043 Mdot
.84 .3311 Mdot
.84 .33113 Mdot
.84 .33147 Mdot
.84 .3316 Mdot
.84 .33219 Mdot
.84 .33319 Mdot
.84 .33333 Mdot
.84 .33442 Mdot
.84 .33445 Mdot
.84 .33447 Mdot
.84 .33454 Mdot
.84 .33623 Mdot
.84 .33627 Mdot
.84 .33663 Mdot
.84 .33686 Mdot
.84 .33688 Mdot
.84 .33744 Mdot
.84 .33767 Mdot
.84 .3377 Mdot
.84 .3378 Mdot
.84 .33783 Mdot
.84 .33811 Mdot
.84 .33814 Mdot
.84 .33817 Mdot
.84 .33819 Mdot
.84 .33915 Mdot
.84 .3392 Mdot
.84 .3394 Mdot
.84 .33954 Mdot
.84 .33982 Mdot
.84 .3409 Mdot
.84 .34115 Mdot
.84 .34124 Mdot
.84 .34162 Mdot
.84 .34255 Mdot
.84 .34338 Mdot
.84 .34418 Mdot
.84 .34527 Mdot
.84 .34529 Mdot
.84 .34602 Mdot
.84 .34604 Mdot
.84 .34615 Mdot
.84 .34666 Mdot
.84 .34686 Mdot
.84 .34707 Mdot
.84 .34732 Mdot
.84 .34804 Mdot
.84 .34837 Mdot
.84 .35003 Mdot
.84 .35018 Mdot
.84 .35039 Mdot
.84 .35055 Mdot
.84 .35175 Mdot
.84 .352 Mdot
.84 .35354 Mdot
.84 .35546 Mdot
.84 .35567 Mdot
.84 .35583 Mdot
.84 .35838 Mdot
.84 .35956 Mdot
.84 .36044 Mdot
.84 .36083 Mdot
.84 .36099 Mdot
.84 .36147 Mdot
.84 .36244 Mdot
.84 .36381 Mdot
.84 .36534 Mdot
.84 .36575 Mdot
.84 .36615 Mdot
.84 .36892 Mdot
.84 .36913 Mdot
.84 .36984 Mdot
.84 .36997 Mdot
.84 .37159 Mdot
.84 .37237 Mdot
.84 .37324 Mdot
.84 .37367 Mdot
.84 .3752 Mdot
.84 .37529 Mdot
.84 .37537 Mdot
.84 .37639 Mdot
.84 .37653 Mdot
.84 .37661 Mdot
.84 .37663 Mdot
.84 .37851 Mdot
.84 .37882 Mdot
.84 .37971 Mdot
.84 .38011 Mdot
.84 .38111 Mdot
.84 .38114 Mdot
.84 .38148 Mdot
.84 .38185 Mdot
.84 .38339 Mdot
.84 .38353 Mdot
.84 .38566 Mdot
.84 .38601 Mdot
.84 .38644 Mdot
.84 .38667 Mdot
.84 .38984 Mdot
.84 .38996 Mdot
.84 .39143 Mdot
.84 .39198 Mdot
.84 .39468 Mdot
.84 .39693 Mdot
.84 .39703 Mdot
.84 .39785 Mdot
.84 .39895 Mdot
.84 .39948 Mdot
.84 .39994 Mdot
.84 .40013 Mdot
.84 .40031 Mdot
.84 .40154 Mdot
.84 .40222 Mdot
.84 .40292 Mdot
.84 .40387 Mdot
.84 .40478 Mdot
.84 .40571 Mdot
.84 .40633 Mdot
.84 .40652 Mdot
.84 .40711 Mdot
.84 .40852 Mdot
.84 .40892 Mdot
.84 .40907 Mdot
.84 .41252 Mdot
.84 .41336 Mdot
.84 .41435 Mdot
.84 .4151 Mdot
.84 .41556 Mdot
.84 .41649 Mdot
.84 .41697 Mdot
.84 .41747 Mdot
.84 .41771 Mdot
.84 .41843 Mdot
.84 .41985 Mdot
.84 .42154 Mdot
.84 .4225 Mdot
.84 .42288 Mdot
.84 .42474 Mdot
.84 .42482 Mdot
.84 .42498 Mdot
.84 .42501 Mdot
.84 .42549 Mdot
.84 .42558 Mdot
.84 .42596 Mdot
.84 .42605 Mdot
.84 .42622 Mdot
.84 .42752 Mdot
.84 .42778 Mdot
.84 .42801 Mdot
.84 .42808 Mdot
.84 .42933 Mdot
.84 .42938 Mdot
.84 .43112 Mdot
.84 .43258 Mdot
.84 .4336 Mdot
.84 .43463 Mdot
.84 .43622 Mdot
.84 .43712 Mdot
.84 .43812 Mdot
.84 .43929 Mdot
.84 .44021 Mdot
.84 .44023 Mdot
.84 .44102 Mdot
.84 .44107 Mdot
.84 .44331 Mdot
.84 .44335 Mdot
.84 .44502 Mdot
.84 .44585 Mdot
.84 .44688 Mdot
.84 .44828 Mdot
.84 .44893 Mdot
.84 .44943 Mdot
.84 .45007 Mdot
.84 .45012 Mdot
.84 .45134 Mdot
.84 .45242 Mdot
.84 .45309 Mdot
.84 .45344 Mdot
.84 .45488 Mdot
.84 .45567 Mdot
.84 .4557 Mdot
.84 .45576 Mdot
.84 .45611 Mdot
.84 .45614 Mdot
.84 .45793 Mdot
.84 .45881 Mdot
.84 .45974 Mdot
.84 .46226 Mdot
.84 .46315 Mdot
.84 .46401 Mdot
.84 .46464 Mdot
.84 .4651 Mdot
.84 .46663 Mdot
.84 .46666 Mdot
.84 .4668 Mdot
.84 .46928 Mdot
.84 .46959 Mdot
.84 .46981 Mdot
.84 .47051 Mdot
.84 .47164 Mdot
.84 .47229 Mdot
.84 .47331 Mdot
.84 .47453 Mdot
.84 .47797 Mdot
.84 .47955 Mdot
.84 .47997 Mdot
.84 .48028 Mdot
.84 .48081 Mdot
.84 .48091 Mdot
.84 .48149 Mdot
.84 .48168 Mdot
.84 .48189 Mdot
.84 .48258 Mdot
.84 .48259 Mdot
.84 .48337 Mdot
.84 .48768 Mdot
.84 .48825 Mdot
.84 .48858 Mdot
.84 .48928 Mdot
.84 .49144 Mdot
.84 .49146 Mdot
.84 .49177 Mdot
.84 .49213 Mdot
.84 .49315 Mdot
.84 .49333 Mdot
.84 .49419 Mdot
.84 .4957 Mdot
.84 .49598 Mdot
.84 .49761 Mdot
.84 .49814 Mdot
.84 .49874 Mdot
.84 .49894 Mdot
.84 .49997 Mdot
.84 .5007 Mdot
.84 .50073 Mdot
.84 .50216 Mdot
.84 .50271 Mdot
.84 .50291 Mdot
.84 .50293 Mdot
.84 .50476 Mdot
.84 .50554 Mdot
.84 .50762 Mdot
.84 .50837 Mdot
.84 .5088 Mdot
.84 .509 Mdot
.84 .51116 Mdot
.842 .01476 Mdot
.842 .01479 Mdot
.842 .01485 Mdot
.842 .01493 Mdot
.842 .01502 Mdot
.842 .01509 Mdot
.842 .01523 Mdot
.842 .01534 Mdot
.842 .01557 Mdot
.842 .01576 Mdot
.842 .01578 Mdot
.842 .01611 Mdot
.842 .01616 Mdot
.842 .01648 Mdot
.842 .01651 Mdot
.842 .01706 Mdot
.842 .01715 Mdot
.842 .01769 Mdot
.842 .01774 Mdot
.842 .01821 Mdot
.842 .01866 Mdot
.842 .01882 Mdot
.842 .01973 Mdot
.842 .0198 Mdot
.842 .02061 Mdot
.842 .02129 Mdot
.842 .02137 Mdot
.842 .02163 Mdot
.842 .02238 Mdot
.842 .02315 Mdot
.842 .02328 Mdot
.842 .02373 Mdot
.842 .02381 Mdot
.842 .02464 Mdot
.842 .02531 Mdot
.842 .02543 Mdot
.842 .02579 Mdot
.842 .02592 Mdot
.842 .02635 Mdot
.842 .02652 Mdot
.842 .02668 Mdot
.842 .02669 Mdot
.842 .02714 Mdot
.842 .02762 Mdot
.842 .02772 Mdot
.842 .02874 Mdot
.842 .02892 Mdot
.842 .02914 Mdot
.842 .0299 Mdot
.842 .03003 Mdot
.842 .03052 Mdot
.842 .03062 Mdot
.842 .03132 Mdot
.842 .03143 Mdot
.842 .03212 Mdot
.842 .03219 Mdot
.842 .03228 Mdot
.842 .03256 Mdot
.842 .03276 Mdot
.842 .03288 Mdot
.842 .03309 Mdot
.842 .03336 Mdot
.842 .03358 Mdot
.842 .03371 Mdot
.842 .03399 Mdot
.842 .03432 Mdot
.842 .0346 Mdot
.842 .03486 Mdot
.842 .03489 Mdot
.842 .03564 Mdot
.842 .03628 Mdot
.842 .03644 Mdot
.842 .03656 Mdot
.842 .03661 Mdot
.842 .03701 Mdot
.842 .03731 Mdot
.842 .03833 Mdot
.842 .03864 Mdot
.842 .03885 Mdot
.842 .03901 Mdot
.842 .03967 Mdot
.842 .03983 Mdot
.842 .04029 Mdot
.842 .04051 Mdot
.842 .04132 Mdot
.842 .0415 Mdot
.842 .04268 Mdot
.842 .04286 Mdot
.842 .04325 Mdot
.842 .04402 Mdot
.842 .04414 Mdot
.842 .0443 Mdot
.842 .04477 Mdot
.842 .04509 Mdot
.842 .0453 Mdot
.842 .04541 Mdot
.842 .04566 Mdot
.842 .04612 Mdot
.842 .04648 Mdot
.842 .0467 Mdot
.842 .04709 Mdot
.842 .04718 Mdot
.842 .04749 Mdot
.842 .04768 Mdot
.842 .04772 Mdot
.842 .04815 Mdot
.842 .0482 Mdot
.842 .0486 Mdot
.842 .04863 Mdot
.842 .04869 Mdot
.842 .04873 Mdot
.842 .04968 Mdot
.842 .04979 Mdot
.842 .04995 Mdot
.842 .05037 Mdot
.842 .05103 Mdot
.842 .05131 Mdot
.842 .0515 Mdot
.842 .05158 Mdot
.842 .05226 Mdot
.842 .05277 Mdot
.842 .05375 Mdot
.842 .05447 Mdot
.842 .05449 Mdot
.842 .05459 Mdot
.842 .05467 Mdot
.842 .05471 Mdot
.842 .05501 Mdot
.842 .0552 Mdot
.842 .05535 Mdot
.842 .05545 Mdot
.842 .05562 Mdot
.842 .05628 Mdot
.842 .05675 Mdot
.842 .05678 Mdot
.842 .057 Mdot
.842 .05753 Mdot
.842 .05778 Mdot
.842 .05783 Mdot
.842 .05792 Mdot
.842 .05815 Mdot
.842 .05839 Mdot
.842 .05945 Mdot
.842 .05953 Mdot
.842 .05982 Mdot
.842 .06139 Mdot
.842 .06181 Mdot
.842 .06211 Mdot
.842 .06227 Mdot
.842 .06248 Mdot
.842 .06277 Mdot
.842 .06283 Mdot
.842 .0632 Mdot
.842 .06406 Mdot
.842 .06412 Mdot
.842 .06426 Mdot
.842 .06434 Mdot
.842 .06454 Mdot
.842 .06501 Mdot
.842 .06533 Mdot
.842 .06587 Mdot
.842 .06621 Mdot
.842 .06641 Mdot
.842 .06682 Mdot
.842 .06717 Mdot
.842 .06727 Mdot
.842 .06759 Mdot
.842 .06797 Mdot
.842 .0682 Mdot
.842 .06844 Mdot
.842 .06858 Mdot
.842 .06923 Mdot
.842 .06939 Mdot
.842 .06952 Mdot
.842 .06964 Mdot
.842 .06991 Mdot
.842 .07004 Mdot
.842 .07024 Mdot
.842 .07028 Mdot
.842 .0703 Mdot
.842 .07076 Mdot
.842 .07102 Mdot
.842 .0711 Mdot
.842 .07178 Mdot
.842 .07183 Mdot
.842 .07192 Mdot
.842 .07199 Mdot
.842 .07281 Mdot
.842 .0736 Mdot
.842 .07378 Mdot
.842 .07386 Mdot
.842 .07404 Mdot
.842 .07475 Mdot
.842 .07586 Mdot
.842 .07633 Mdot
.842 .07667 Mdot
.842 .0768 Mdot
.842 .07795 Mdot
.842 .07879 Mdot
.842 .0788 Mdot
.842 .07973 Mdot
.842 .08018 Mdot
.842 .08045 Mdot
.842 .08166 Mdot
.842 .0817 Mdot
.842 .08186 Mdot
.842 .082 Mdot
.842 .08206 Mdot
.842 .08257 Mdot
.842 .08261 Mdot
.842 .08266 Mdot
.842 .08288 Mdot
.842 .08315 Mdot
.842 .08316 Mdot
.842 .08331 Mdot
.842 .08354 Mdot
.842 .0836 Mdot
.842 .08472 Mdot
.842 .0855 Mdot
.842 .08555 Mdot
.842 .08593 Mdot
.842 .08602 Mdot
.842 .08644 Mdot
.842 .08682 Mdot
.842 .08723 Mdot
.842 .08731 Mdot
.842 .08747 Mdot
.842 .08786 Mdot
.842 .08826 Mdot
.842 .0895 Mdot
.842 .09005 Mdot
.842 .0901 Mdot
.842 .09018 Mdot
.842 .09025 Mdot
.842 .09068 Mdot
.842 .09321 Mdot
.842 .09329 Mdot
.842 .09331 Mdot
.842 .09365 Mdot
.842 .09396 Mdot
.842 .09403 Mdot
.842 .09453 Mdot
.842 .0948 Mdot
.842 .09516 Mdot
.842 .09563 Mdot
.842 .09575 Mdot
.842 .09636 Mdot
.842 .09669 Mdot
.842 .0971 Mdot
.842 .09781 Mdot
.842 .09791 Mdot
.842 .09815 Mdot
.842 .09829 Mdot
.842 .09862 Mdot
.842 .09941 Mdot
.842 .09995 Mdot
.842 .1 Mdot
.842 .10063 Mdot
.842 .10087 Mdot
.842 .10144 Mdot
.842 .10177 Mdot
.842 .10191 Mdot
.842 .10246 Mdot
.842 .10304 Mdot
.842 .10321 Mdot
.842 .10376 Mdot
.842 .1044 Mdot
.842 .10479 Mdot
.842 .10502 Mdot
.842 .10519 Mdot
.842 .10542 Mdot
.842 .10594 Mdot
.842 .10651 Mdot
.842 .10678 Mdot
.842 .10701 Mdot
.842 .10721 Mdot
.842 .10766 Mdot
.842 .10788 Mdot
.842 .10821 Mdot
.842 .10823 Mdot
.842 .10829 Mdot
.842 .10832 Mdot
.842 .10909 Mdot
.842 .10954 Mdot
.842 .10966 Mdot
.842 .11082 Mdot
.842 .1109 Mdot
.842 .11106 Mdot
.842 .11117 Mdot
.842 .11177 Mdot
.842 .11179 Mdot
.842 .11254 Mdot
.842 .11388 Mdot
.842 .11419 Mdot
.842 .11431 Mdot
.842 .11462 Mdot
.842 .11582 Mdot
.842 .11769 Mdot
.842 .11823 Mdot
.842 .11848 Mdot
.842 .11904 Mdot
.842 .1192 Mdot
.842 .11927 Mdot
.842 .1212 Mdot
.842 .12229 Mdot
.842 .12262 Mdot
.842 .12264 Mdot
.842 .12266 Mdot
.842 .12278 Mdot
.842 .12296 Mdot
.842 .12302 Mdot
.842 .12365 Mdot
.842 .12421 Mdot
.842 .12424 Mdot
.842 .12496 Mdot
.842 .12541 Mdot
.842 .12576 Mdot
.842 .1261 Mdot
.842 .12746 Mdot
.842 .12751 Mdot
.842 .12768 Mdot
.842 .12779 Mdot
.842 .12803 Mdot
.842 .12813 Mdot
.842 .12898 Mdot
.842 .12906 Mdot
.842 .12913 Mdot
.842 .12951 Mdot
.842 .12996 Mdot
.842 .12998 Mdot
.842 .13023 Mdot
.842 .13062 Mdot
.842 .13072 Mdot
.842 .1326 Mdot
.842 .13391 Mdot
.842 .134 Mdot
.842 .13464 Mdot
.842 .1348 Mdot
.842 .13543 Mdot
.842 .13551 Mdot
.842 .13557 Mdot
.842 .13614 Mdot
.842 .13684 Mdot
.842 .13697 Mdot
.842 .13724 Mdot
.842 .13789 Mdot
.842 .13856 Mdot
.842 .14066 Mdot
.842 .14151 Mdot
.842 .14158 Mdot
.842 .14166 Mdot
.842 .14179 Mdot
.842 .14191 Mdot
.842 .14223 Mdot
.842 .14264 Mdot
.842 .1469 Mdot
.842 .14704 Mdot
.842 .14707 Mdot
.842 .14726 Mdot
.842 .14763 Mdot
.842 .14805 Mdot
.842 .14816 Mdot
.842 .14823 Mdot
.842 .14828 Mdot
.842 .1487 Mdot
.842 .14885 Mdot
.842 .14912 Mdot
.842 .14957 Mdot
.842 .14979 Mdot
.842 .15001 Mdot
.842 .15018 Mdot
.842 .15098 Mdot
.842 .15117 Mdot
.842 .15155 Mdot
.842 .15217 Mdot
.842 .1522 Mdot
.842 .15275 Mdot
.842 .15345 Mdot
.842 .15354 Mdot
.842 .15409 Mdot
.842 .15419 Mdot
.842 .15441 Mdot
.842 .15464 Mdot
.842 .15465 Mdot
.842 .15482 Mdot
.842 .15522 Mdot
.842 .15545 Mdot
.842 .15601 Mdot
.842 .15663 Mdot
.842 .15734 Mdot
.842 .15736 Mdot
.842 .15825 Mdot
.842 .15833 Mdot
.842 .15863 Mdot
.842 .15893 Mdot
.842 .15905 Mdot
.842 .15939 Mdot
.842 .15979 Mdot
.842 .16076 Mdot
.842 .1608 Mdot
.842 .16131 Mdot
.842 .16154 Mdot
.842 .16183 Mdot
.842 .16248 Mdot
.842 .16292 Mdot
.842 .16346 Mdot
.842 .16373 Mdot
.842 .16374 Mdot
.842 .16467 Mdot
.842 .16574 Mdot
.842 .1664 Mdot
.842 .16707 Mdot
.842 .16746 Mdot
.842 .16754 Mdot
.842 .16813 Mdot
.842 .16835 Mdot
.842 .16845 Mdot
.842 .1693 Mdot
.842 .16975 Mdot
.842 .17014 Mdot
.842 .17025 Mdot
.842 .17048 Mdot
.842 .17124 Mdot
.842 .17161 Mdot
.842 .17216 Mdot
.842 .17219 Mdot
.842 .17229 Mdot
.842 .17234 Mdot
.842 .17321 Mdot
.842 .17335 Mdot
.842 .17337 Mdot
.842 .17365 Mdot
.842 .17439 Mdot
.842 .17445 Mdot
.842 .17461 Mdot
.842 .176 Mdot
.842 .17655 Mdot
.842 .17669 Mdot
.842 .17695 Mdot
.842 .17715 Mdot
.842 .17815 Mdot
.842 .17819 Mdot
.842 .17933 Mdot
.842 .17946 Mdot
.842 .17976 Mdot
.842 .18171 Mdot
.842 .18223 Mdot
.842 .18236 Mdot
.842 .18239 Mdot
.842 .18244 Mdot
.842 .18287 Mdot
.842 .18296 Mdot
.842 .1839 Mdot
.842 .18497 Mdot
.842 .185 Mdot
.842 .18505 Mdot
.842 .18533 Mdot
.842 .18585 Mdot
.842 .1867 Mdot
.842 .18752 Mdot
.842 .18778 Mdot
.842 .18812 Mdot
.842 .18886 Mdot
.842 .18904 Mdot
.842 .18945 Mdot
.842 .1904 Mdot
.842 .19067 Mdot
.842 .19079 Mdot
.842 .19153 Mdot
.842 .193 Mdot
.842 .19348 Mdot
.842 .19403 Mdot
.842 .19452 Mdot
.842 .19587 Mdot
.842 .19643 Mdot
.842 .19646 Mdot
.842 .19649 Mdot
.842 .1967 Mdot
.842 .197 Mdot
.842 .1971 Mdot
.842 .1979 Mdot
.842 .198 Mdot
.842 .19816 Mdot
.842 .19827 Mdot
.842 .1991 Mdot
.842 .19915 Mdot
.842 .20036 Mdot
.842 .20112 Mdot
.842 .20171 Mdot
.842 .20225 Mdot
.842 .20229 Mdot
.842 .20263 Mdot
.842 .20406 Mdot
.842 .20432 Mdot
.842 .2044 Mdot
.842 .20457 Mdot
.842 .20466 Mdot
.842 .20496 Mdot
.842 .20513 Mdot
.842 .2055 Mdot
.842 .20553 Mdot
.842 .2057 Mdot
.842 .20607 Mdot
.842 .20714 Mdot
.842 .20727 Mdot
.842 .20739 Mdot
.842 .20772 Mdot
.842 .20803 Mdot
.842 .20879 Mdot
.842 .20883 Mdot
.842 .20924 Mdot
.842 .20962 Mdot
.842 .20967 Mdot
.842 .20989 Mdot
.842 .21006 Mdot
.842 .21115 Mdot
.842 .21323 Mdot
.842 .21424 Mdot
.842 .21426 Mdot
.842 .21443 Mdot
.842 .21544 Mdot
.842 .21559 Mdot
.842 .21667 Mdot
.842 .21688 Mdot
.842 .21693 Mdot
.842 .21798 Mdot
.842 .21801 Mdot
.842 .21813 Mdot
.842 .21824 Mdot
.842 .2192 Mdot
.842 .21935 Mdot
.842 .22037 Mdot
.842 .22059 Mdot
.842 .22104 Mdot
.842 .22214 Mdot
.842 .22247 Mdot
.842 .22327 Mdot
.842 .22452 Mdot
.842 .22453 Mdot
.842 .2268 Mdot
.842 .22714 Mdot
.842 .22823 Mdot
.842 .22836 Mdot
.842 .22841 Mdot
.842 .22847 Mdot
.842 .22849 Mdot
.842 .22871 Mdot
.842 .22892 Mdot
.842 .22945 Mdot
.842 .22958 Mdot
.842 .23013 Mdot
.842 .23287 Mdot
.842 .23292 Mdot
.842 .23501 Mdot
.842 .23704 Mdot
.842 .23732 Mdot
.842 .23738 Mdot
.842 .23754 Mdot
.842 .2376 Mdot
.842 .23793 Mdot
.842 .23801 Mdot
.842 .23855 Mdot
.842 .23877 Mdot
.842 .23925 Mdot
.842 .23944 Mdot
.842 .23948 Mdot
.842 .23956 Mdot
.842 .23964 Mdot
.842 .24034 Mdot
.842 .2406 Mdot
.842 .24105 Mdot
.842 .24115 Mdot
.842 .24119 Mdot
.842 .24181 Mdot
.842 .24217 Mdot
.842 .24256 Mdot
.842 .24284 Mdot
.842 .24419 Mdot
.842 .2444 Mdot
.842 .24451 Mdot
.842 .24514 Mdot
.842 .24619 Mdot
.842 .24624 Mdot
.842 .24624 Mdot
.842 .24662 Mdot
.842 .24717 Mdot
.842 .24835 Mdot
.842 .2485 Mdot
.842 .24942 Mdot
.842 .24942 Mdot
.842 .24959 Mdot
.842 .24996 Mdot
.842 .25034 Mdot
.842 .25036 Mdot
.842 .25046 Mdot
.842 .25065 Mdot
.842 .25094 Mdot
.842 .25123 Mdot
.842 .25132 Mdot
.842 .25171 Mdot
.842 .25265 Mdot
.842 .25317 Mdot
.842 .25333 Mdot
.842 .2537 Mdot
.842 .25489 Mdot
.842 .25493 Mdot
.842 .25502 Mdot
.842 .25643 Mdot
.842 .25656 Mdot
.842 .25707 Mdot
.842 .25716 Mdot
.842 .25719 Mdot
.842 .25757 Mdot
.842 .25778 Mdot
.842 .25836 Mdot
.842 .25903 Mdot
.842 .25904 Mdot
.842 .25957 Mdot
.842 .26066 Mdot
.842 .26066 Mdot
.842 .26072 Mdot
.842 .26159 Mdot
.842 .26197 Mdot
.842 .26246 Mdot
.842 .26356 Mdot
.842 .26428 Mdot
.842 .26428 Mdot
.842 .26521 Mdot
.842 .26565 Mdot
.842 .26567 Mdot
.842 .26606 Mdot
.842 .26722 Mdot
.842 .26724 Mdot
.842 .26798 Mdot
.842 .26869 Mdot
.842 .26882 Mdot
.842 .26904 Mdot
.842 .2693 Mdot
.842 .26956 Mdot
.842 .27015 Mdot
.842 .27016 Mdot
.842 .27129 Mdot
.842 .27194 Mdot
.842 .27207 Mdot
.842 .27306 Mdot
.842 .27343 Mdot
.842 .2736 Mdot
.842 .2737 Mdot
.842 .27438 Mdot
.842 .27444 Mdot
.842 .27504 Mdot
.842 .27579 Mdot
.842 .2758 Mdot
.842 .27645 Mdot
.842 .27664 Mdot
.842 .27703 Mdot
.842 .2783 Mdot
.842 .27893 Mdot
.842 .27934 Mdot
.842 .27961 Mdot
.842 .27986 Mdot
.842 .2799 Mdot
.842 .28007 Mdot
.842 .28016 Mdot
.842 .28037 Mdot
.842 .28162 Mdot
.842 .28186 Mdot
.842 .28188 Mdot
.842 .28236 Mdot
.842 .28361 Mdot
.842 .28371 Mdot
.842 .28398 Mdot
.842 .28632 Mdot
.842 .28701 Mdot
.842 .28725 Mdot
.842 .28749 Mdot
.842 .28792 Mdot
.842 .28825 Mdot
.842 .28898 Mdot
.842 .28965 Mdot
.842 .28994 Mdot
.842 .29002 Mdot
.842 .29034 Mdot
.842 .29157 Mdot
.842 .29193 Mdot
.842 .29214 Mdot
.842 .29249 Mdot
.842 .29264 Mdot
.842 .29457 Mdot
.842 .29594 Mdot
.842 .29647 Mdot
.842 .29681 Mdot
.842 .29704 Mdot
.842 .29707 Mdot
.842 .29716 Mdot
.842 .29729 Mdot
.842 .2975 Mdot
.842 .29789 Mdot
.842 .29804 Mdot
.842 .29841 Mdot
.842 .29962 Mdot
.842 .30143 Mdot
.842 .30147 Mdot
.842 .30156 Mdot
.842 .30191 Mdot
.842 .30203 Mdot
.842 .30291 Mdot
.842 .30293 Mdot
.842 .30353 Mdot
.842 .30434 Mdot
.842 .30452 Mdot
.842 .30495 Mdot
.842 .30571 Mdot
.842 .30615 Mdot
.842 .30673 Mdot
.842 .30798 Mdot
.842 .30827 Mdot
.842 .30897 Mdot
.842 .31042 Mdot
.842 .31058 Mdot
.842 .31103 Mdot
.842 .31122 Mdot
.842 .31247 Mdot
.842 .3143 Mdot
.842 .31495 Mdot
.842 .31575 Mdot
.842 .3158 Mdot
.842 .31669 Mdot
.842 .31676 Mdot
.842 .31741 Mdot
.842 .3175 Mdot
.842 .31751 Mdot
.842 .31777 Mdot
.842 .31812 Mdot
.842 .31872 Mdot
.842 .31978 Mdot
.842 .31984 Mdot
.842 .32026 Mdot
.842 .32073 Mdot
.842 .32077 Mdot
.842 .32083 Mdot
.842 .32118 Mdot
.842 .32131 Mdot
.842 .32167 Mdot
.842 .32184 Mdot
.842 .3232 Mdot
.842 .32337 Mdot
.842 .32364 Mdot
.842 .32381 Mdot
.842 .32473 Mdot
.842 .32522 Mdot
.842 .32531 Mdot
.842 .32734 Mdot
.842 .32863 Mdot
.842 .32962 Mdot
.842 .32986 Mdot
.842 .32997 Mdot
.842 .33025 Mdot
.842 .33052 Mdot
.842 .33059 Mdot
.842 .33116 Mdot
.842 .33123 Mdot
.842 .33157 Mdot
.842 .33358 Mdot
.842 .334 Mdot
.842 .33407 Mdot
.842 .33412 Mdot
.842 .33414 Mdot
.842 .33443 Mdot
.842 .33458 Mdot
.842 .33508 Mdot
.842 .33537 Mdot
.842 .33582 Mdot
.842 .336 Mdot
.842 .33605 Mdot
.842 .33633 Mdot
.842 .33696 Mdot
.842 .33811 Mdot
.842 .33863 Mdot
.842 .33876 Mdot
.842 .33897 Mdot
.842 .33919 Mdot
.842 .33973 Mdot
.842 .33987 Mdot
.842 .34026 Mdot
.842 .34154 Mdot
.842 .3416 Mdot
.842 .34202 Mdot
.842 .3423 Mdot
.842 .34294 Mdot
.842 .34301 Mdot
.842 .34325 Mdot
.842 .34339 Mdot
.842 .34368 Mdot
.842 .34489 Mdot
.842 .34552 Mdot
.842 .34845 Mdot
.842 .34901 Mdot
.842 .34927 Mdot
.842 .35072 Mdot
.842 .35074 Mdot
.842 .35104 Mdot
.842 .35127 Mdot
.842 .35274 Mdot
.842 .35299 Mdot
.842 .35481 Mdot
.842 .35516 Mdot
.842 .35525 Mdot
.842 .35701 Mdot
.842 .35706 Mdot
.842 .35727 Mdot
.842 .35745 Mdot
.842 .35907 Mdot
.842 .35932 Mdot
.842 .36104 Mdot
.842 .36141 Mdot
.842 .36217 Mdot
.842 .36402 Mdot
.842 .36457 Mdot
.842 .36593 Mdot
.842 .36803 Mdot
.842 .36804 Mdot
.842 .37187 Mdot
.842 .37244 Mdot
.842 .37428 Mdot
.842 .3745 Mdot
.842 .37457 Mdot
.842 .37467 Mdot
.842 .37471 Mdot
.842 .37508 Mdot
.842 .37543 Mdot
.842 .37634 Mdot
.842 .37654 Mdot
.842 .37748 Mdot
.842 .38208 Mdot
.842 .38217 Mdot
.842 .38569 Mdot
.842 .38911 Mdot
.842 .38957 Mdot
.842 .38968 Mdot
.842 .38996 Mdot
.842 .39005 Mdot
.842 .3906 Mdot
.842 .39074 Mdot
.842 .39165 Mdot
.842 .39202 Mdot
.842 .39283 Mdot
.842 .39316 Mdot
.842 .39322 Mdot
.842 .39335 Mdot
.842 .39348 Mdot
.842 .39467 Mdot
.842 .3951 Mdot
.842 .39586 Mdot
.842 .39603 Mdot
.842 .39611 Mdot
.842 .39715 Mdot
.842 .39776 Mdot
.842 .3984 Mdot
.842 .39888 Mdot
.842 .40115 Mdot
.842 .4015 Mdot
.842 .40169 Mdot
.842 .40276 Mdot
.842 .40452 Mdot
.842 .4046 Mdot
.842 .40461 Mdot
.842 .40525 Mdot
.842 .40617 Mdot
.842 .40815 Mdot
.842 .4084 Mdot
.842 .40995 Mdot
.842 .40996 Mdot
.842 .41025 Mdot
.842 .41086 Mdot
.842 .41151 Mdot
.842 .41155 Mdot
.842 .41171 Mdot
.842 .41202 Mdot
.842 .41252 Mdot
.842 .41301 Mdot
.842 .41316 Mdot
.842 .41381 Mdot
.842 .41539 Mdot
.842 .41627 Mdot
.842 .41655 Mdot
.842 .41717 Mdot
.842 .41918 Mdot
.842 .41924 Mdot
.842 .41939 Mdot
.842 .42176 Mdot
.842 .42198 Mdot
.842 .42283 Mdot
.842 .42299 Mdot
.842 .42304 Mdot
.842 .42369 Mdot
.842 .42403 Mdot
.842 .42501 Mdot
.842 .42614 Mdot
.842 .42616 Mdot
.842 .42705 Mdot
.842 .42888 Mdot
.842 .42889 Mdot
.842 .42899 Mdot
.842 .43045 Mdot
.842 .4311 Mdot
.842 .43191 Mdot
.842 .43376 Mdot
.842 .43498 Mdot
.842 .43499 Mdot
.842 .43654 Mdot
.842 .43729 Mdot
.842 .43733 Mdot
.842 .43799 Mdot
.842 .43994 Mdot
.842 .43997 Mdot
.842 .44121 Mdot
.842 .44242 Mdot
.842 .44262 Mdot
.842 .44299 Mdot
.842 .44344 Mdot
.842 .44387 Mdot
.842 .44486 Mdot
.842 .44488 Mdot
.842 .44679 Mdot
.842 .44788 Mdot
.842 .44811 Mdot
.842 .44977 Mdot
.842 .45039 Mdot
.842 .45067 Mdot
.842 .45085 Mdot
.842 .45199 Mdot
.842 .45209 Mdot
.842 .4531 Mdot
.842 .45436 Mdot
.842 .45438 Mdot
.842 .45548 Mdot
.842 .4558 Mdot
.842 .45645 Mdot
.842 .45859 Mdot
.842 .45965 Mdot
.842 .46034 Mdot
.842 .46079 Mdot
.842 .46122 Mdot
.842 .46129 Mdot
.842 .46158 Mdot
.842 .46173 Mdot
.842 .46209 Mdot
.842 .46419 Mdot
.842 .46459 Mdot
.842 .46463 Mdot
.842 .46543 Mdot
.842 .46754 Mdot
.842 .46769 Mdot
.842 .46815 Mdot
.842 .47209 Mdot
.842 .47326 Mdot
.842 .47366 Mdot
.842 .47407 Mdot
.842 .4748 Mdot
.842 .47535 Mdot
.842 .47658 Mdot
.842 .47771 Mdot
.842 .47819 Mdot
.842 .47832 Mdot
.842 .47886 Mdot
.842 .48094 Mdot
.842 .48155 Mdot
.842 .4819 Mdot
.842 .48249 Mdot
.842 .48275 Mdot
.842 .48599 Mdot
.842 .4883 Mdot
.842 .48919 Mdot
.842 .48976 Mdot
.842 .49014 Mdot
.842 .4902 Mdot
.842 .49036 Mdot
.842 .49056 Mdot
.842 .49092 Mdot
.842 .49159 Mdot
.842 .49184 Mdot
.842 .49246 Mdot
.842 .49449 Mdot
.842 .49754 Mdot
.842 .4976 Mdot
.842 .49777 Mdot
.842 .49835 Mdot
.842 .49855 Mdot
.842 .50004 Mdot
.842 .50007 Mdot
.842 .50108 Mdot
.842 .50244 Mdot
.842 .50275 Mdot
.842 .50348 Mdot
.842 .50476 Mdot
.842 .50549 Mdot
.842 .50646 Mdot
.842 .50858 Mdot
.842 .50906 Mdot
.842 .51025 Mdot
.844 .0153 Mdot
.844 .01537 Mdot
.844 .01571 Mdot
.844 .01583 Mdot
.844 .0159 Mdot
.844 .01639 Mdot
.844 .01659 Mdot
.844 .01666 Mdot
.844 .01672 Mdot
.844 .01754 Mdot
.844 .01782 Mdot
.844 .01789 Mdot
.844 .018 Mdot
.844 .0181 Mdot
.844 .01948 Mdot
.844 .01963 Mdot
.844 .01996 Mdot
.844 .02007 Mdot
.844 .02025 Mdot
.844 .02044 Mdot
.844 .02166 Mdot
.844 .02217 Mdot
.844 .02277 Mdot
.844 .02292 Mdot
.844 .02298 Mdot
.844 .02301 Mdot
.844 .02339 Mdot
.844 .02357 Mdot
.844 .02373 Mdot
.844 .02375 Mdot
.844 .02406 Mdot
.844 .02437 Mdot
.844 .02514 Mdot
.844 .02644 Mdot
.844 .02648 Mdot
.844 .02685 Mdot
.844 .0273 Mdot
.844 .0283 Mdot
.844 .02853 Mdot
.844 .02856 Mdot
.844 .02857 Mdot
.844 .02867 Mdot
.844 .02871 Mdot
.844 .02873 Mdot
.844 .029 Mdot
.844 .02937 Mdot
.844 .02965 Mdot
.844 .02993 Mdot
.844 .02996 Mdot
.844 .0302 Mdot
.844 .0305 Mdot
.844 .03102 Mdot
.844 .03188 Mdot
.844 .03231 Mdot
.844 .0332 Mdot
.844 .03451 Mdot
.844 .03454 Mdot
.844 .03457 Mdot
.844 .03464 Mdot
.844 .03519 Mdot
.844 .03588 Mdot
.844 .03595 Mdot
.844 .03721 Mdot
.844 .03765 Mdot
.844 .03796 Mdot
.844 .03803 Mdot
.844 .03808 Mdot
.844 .03811 Mdot
.844 .03826 Mdot
.844 .03834 Mdot
.844 .03838 Mdot
.844 .03868 Mdot
.844 .03883 Mdot
.844 .03945 Mdot
.844 .03993 Mdot
.844 .0404 Mdot
.844 .04046 Mdot
.844 .04075 Mdot
.844 .04076 Mdot
.844 .04085 Mdot
.844 .04136 Mdot
.844 .04166 Mdot
.844 .04224 Mdot
.844 .04258 Mdot
.844 .04261 Mdot
.844 .04361 Mdot
.844 .04369 Mdot
.844 .04433 Mdot
.844 .04442 Mdot
.844 .04479 Mdot
.844 .04526 Mdot
.844 .04593 Mdot
.844 .04605 Mdot
.844 .04623 Mdot
.844 .04754 Mdot
.844 .04758 Mdot
.844 .04812 Mdot
.844 .04818 Mdot
.844 .04823 Mdot
.844 .04834 Mdot
.844 .04907 Mdot
.844 .04928 Mdot
.844 .04955 Mdot
.844 .05005 Mdot
.844 .05043 Mdot
.844 .05057 Mdot
.844 .05118 Mdot
.844 .05149 Mdot
.844 .05168 Mdot
.844 .05226 Mdot
.844 .05268 Mdot
.844 .05304 Mdot
.844 .0533 Mdot
.844 .05343 Mdot
.844 .05395 Mdot
.844 .05407 Mdot
.844 .05415 Mdot
.844 .05421 Mdot
.844 .05447 Mdot
.844 .05459 Mdot
.844 .05466 Mdot
.844 .0549 Mdot
.844 .05516 Mdot
.844 .05543 Mdot
.844 .05611 Mdot
.844 .05646 Mdot
.844 .05681 Mdot
.844 .05728 Mdot
.844 .05755 Mdot
.844 .05807 Mdot
.844 .05816 Mdot
.844 .05843 Mdot
.844 .05866 Mdot
.844 .05868 Mdot
.844 .05883 Mdot
.844 .05889 Mdot
.844 .05968 Mdot
.844 .0602 Mdot
.844 .06038 Mdot
.844 .06117 Mdot
.844 .06175 Mdot
.844 .06181 Mdot
.844 .06213 Mdot
.844 .06218 Mdot
.844 .06276 Mdot
.844 .06293 Mdot
.844 .06298 Mdot
.844 .06349 Mdot
.844 .06362 Mdot
.844 .0647 Mdot
.844 .06486 Mdot
.844 .06547 Mdot
.844 .06628 Mdot
.844 .06628 Mdot
.844 .06638 Mdot
.844 .06735 Mdot
.844 .0674 Mdot
.844 .0676 Mdot
.844 .0679 Mdot
.844 .06792 Mdot
.844 .06871 Mdot
.844 .06988 Mdot
.844 .07008 Mdot
.844 .07013 Mdot
.844 .07018 Mdot
.844 .07111 Mdot
.844 .0712 Mdot
.844 .07129 Mdot
.844 .07148 Mdot
.844 .0727 Mdot
.844 .07306 Mdot
.844 .07309 Mdot
.844 .07351 Mdot
.844 .07357 Mdot
.844 .07437 Mdot
.844 .07501 Mdot
.844 .07523 Mdot
.844 .07556 Mdot
.844 .07626 Mdot
.844 .07627 Mdot
.844 .0768 Mdot
.844 .07711 Mdot
.844 .07789 Mdot
.844 .0781 Mdot
.844 .07831 Mdot
.844 .0788 Mdot
.844 .07914 Mdot
.844 .0794 Mdot
.844 .07984 Mdot
.844 .08007 Mdot
.844 .08023 Mdot
.844 .08054 Mdot
.844 .08082 Mdot
.844 .08094 Mdot
.844 .08114 Mdot
.844 .08129 Mdot
.844 .08138 Mdot
.844 .08163 Mdot
.844 .08182 Mdot
.844 .08203 Mdot
.844 .08214 Mdot
.844 .08255 Mdot
.844 .08284 Mdot
.844 .08299 Mdot
.844 .08344 Mdot
.844 .08458 Mdot
.844 .08518 Mdot
.844 .08555 Mdot
.844 .08577 Mdot
.844 .08657 Mdot
.844 .08693 Mdot
.844 .08703 Mdot
.844 .0877 Mdot
.844 .0878 Mdot
.844 .0879 Mdot
.844 .08806 Mdot
.844 .08851 Mdot
.844 .0889 Mdot
.844 .08893 Mdot
.844 .08918 Mdot
.844 .08928 Mdot
.844 .09062 Mdot
.844 .09067 Mdot
.844 .091 Mdot
.844 .09103 Mdot
.844 .09107 Mdot
.844 .0915 Mdot
.844 .09179 Mdot
.844 .09248 Mdot
.844 .09255 Mdot
.844 .09277 Mdot
.844 .09313 Mdot
.844 .09371 Mdot
.844 .09412 Mdot
.844 .0942 Mdot
.844 .09475 Mdot
.844 .09484 Mdot
.844 .0949 Mdot
.844 .09501 Mdot
.844 .09581 Mdot
.844 .0961 Mdot
.844 .09619 Mdot
.844 .09665 Mdot
.844 .09704 Mdot
.844 .09727 Mdot
.844 .0977 Mdot
.844 .09838 Mdot
.844 .09897 Mdot
.844 .09909 Mdot
.844 .09936 Mdot
.844 .1004 Mdot
.844 .10176 Mdot
.844 .10176 Mdot
.844 .10189 Mdot
.844 .10192 Mdot
.844 .10268 Mdot
.844 .10356 Mdot
.844 .10364 Mdot
.844 .10399 Mdot
.844 .1045 Mdot
.844 .10453 Mdot
.844 .10586 Mdot
.844 .107 Mdot
.844 .10711 Mdot
.844 .10783 Mdot
.844 .10816 Mdot
.844 .10819 Mdot
.844 .10825 Mdot
.844 .10835 Mdot
.844 .10893 Mdot
.844 .10978 Mdot
.844 .10991 Mdot
.844 .11007 Mdot
.844 .11014 Mdot
.844 .11022 Mdot
.844 .11053 Mdot
.844 .11082 Mdot
.844 .11106 Mdot
.844 .1126 Mdot
.844 .11321 Mdot
.844 .11324 Mdot
.844 .11347 Mdot
.844 .11396 Mdot
.844 .11406 Mdot
.844 .11472 Mdot
.844 .11541 Mdot
.844 .11649 Mdot
.844 .11687 Mdot
.844 .11741 Mdot
.844 .11788 Mdot
.844 .11818 Mdot
.844 .11861 Mdot
.844 .11862 Mdot
.844 .11951 Mdot
.844 .12004 Mdot
.844 .12021 Mdot
.844 .12101 Mdot
.844 .12136 Mdot
.844 .12171 Mdot
.844 .12206 Mdot
.844 .12289 Mdot
.844 .12316 Mdot
.844 .12347 Mdot
.844 .1239 Mdot
.844 .1239 Mdot
.844 .12464 Mdot
.844 .12474 Mdot
.844 .12504 Mdot
.844 .12531 Mdot
.844 .12583 Mdot
.844 .12613 Mdot
.844 .12629 Mdot
.844 .12651 Mdot
.844 .12684 Mdot
.844 .12709 Mdot
.844 .12724 Mdot
.844 .12739 Mdot
.844 .12767 Mdot
.844 .12798 Mdot
.844 .12835 Mdot
.844 .12836 Mdot
.844 .12852 Mdot
.844 .12923 Mdot
.844 .12971 Mdot
.844 .12996 Mdot
.844 .13072 Mdot
.844 .13171 Mdot
.844 .13188 Mdot
.844 .13223 Mdot
.844 .13265 Mdot
.844 .13366 Mdot
.844 .13428 Mdot
.844 .13465 Mdot
.844 .13491 Mdot
.844 .13518 Mdot
.844 .13552 Mdot
.844 .136 Mdot
.844 .13661 Mdot
.844 .13678 Mdot
.844 .13792 Mdot
.844 .13808 Mdot
.844 .13825 Mdot
.844 .13852 Mdot
.844 .13902 Mdot
.844 .13928 Mdot
.844 .13994 Mdot
.844 .14 Mdot
.844 .14042 Mdot
.844 .14059 Mdot
.844 .14136 Mdot
.844 .14285 Mdot
.844 .14292 Mdot
.844 .14348 Mdot
.844 .14353 Mdot
.844 .1436 Mdot
.844 .14433 Mdot
.844 .14482 Mdot
.844 .14597 Mdot
.844 .1461 Mdot
.844 .14648 Mdot
.844 .14692 Mdot
.844 .14708 Mdot
.844 .14754 Mdot
.844 .14765 Mdot
.844 .14806 Mdot
.844 .14874 Mdot
.844 .14882 Mdot
.844 .14889 Mdot
.844 .14934 Mdot
.844 .14982 Mdot
.844 .14996 Mdot
.844 .15007 Mdot
.844 .15025 Mdot
.844 .1507 Mdot
.844 .15149 Mdot
.844 .15161 Mdot
.844 .15209 Mdot
.844 .15224 Mdot
.844 .15225 Mdot
.844 .15302 Mdot
.844 .15369 Mdot
.844 .15407 Mdot
.844 .15446 Mdot
.844 .1548 Mdot
.844 .15499 Mdot
.844 .15595 Mdot
.844 .15694 Mdot
.844 .15694 Mdot
.844 .15714 Mdot
.844 .1576 Mdot
.844 .15867 Mdot
.844 .15875 Mdot
.844 .15895 Mdot
.844 .15935 Mdot
.844 .16024 Mdot
.844 .16059 Mdot
.844 .16096 Mdot
.844 .16164 Mdot
.844 .16165 Mdot
.844 .16187 Mdot
.844 .16192 Mdot
.844 .16313 Mdot
.844 .1632 Mdot
.844 .16469 Mdot
.844 .16483 Mdot
.844 .16541 Mdot
.844 .16542 Mdot
.844 .16611 Mdot
.844 .16627 Mdot
.844 .16632 Mdot
.844 .16662 Mdot
.844 .16747 Mdot
.844 .16828 Mdot
.844 .16857 Mdot
.844 .16964 Mdot
.844 .17047 Mdot
.844 .17048 Mdot
.844 .17068 Mdot
.844 .17109 Mdot
.844 .1719 Mdot
.844 .17246 Mdot
.844 .1725 Mdot
.844 .17261 Mdot
.844 .17276 Mdot
.844 .17347 Mdot
.844 .17375 Mdot
.844 .17401 Mdot
.844 .17519 Mdot
.844 .17531 Mdot
.844 .1754 Mdot
.844 .17567 Mdot
.844 .17579 Mdot
.844 .17592 Mdot
.844 .17633 Mdot
.844 .17644 Mdot
.844 .17693 Mdot
.844 .17708 Mdot
.844 .17709 Mdot
.844 .17734 Mdot
.844 .17914 Mdot
.844 .17995 Mdot
.844 .18082 Mdot
.844 .18097 Mdot
.844 .18103 Mdot
.844 .18141 Mdot
.844 .18224 Mdot
.844 .1824 Mdot
.844 .18352 Mdot
.844 .18401 Mdot
.844 .18468 Mdot
.844 .18588 Mdot
.844 .18652 Mdot
.844 .18715 Mdot
.844 .18774 Mdot
.844 .18807 Mdot
.844 .18886 Mdot
.844 .18936 Mdot
.844 .18936 Mdot
.844 .19009 Mdot
.844 .19011 Mdot
.844 .1903 Mdot
.844 .19056 Mdot
.844 .19161 Mdot
.844 .1925 Mdot
.844 .19278 Mdot
.844 .19414 Mdot
.844 .19473 Mdot
.844 .1949 Mdot
.844 .19532 Mdot
.844 .19591 Mdot
.844 .19731 Mdot
.844 .19777 Mdot
.844 .19804 Mdot
.844 .19829 Mdot
.844 .19902 Mdot
.844 .19902 Mdot
.844 .19966 Mdot
.844 .19967 Mdot
.844 .20027 Mdot
.844 .20044 Mdot
.844 .2006 Mdot
.844 .20088 Mdot
.844 .20094 Mdot
.844 .2014 Mdot
.844 .20194 Mdot
.844 .20228 Mdot
.844 .20268 Mdot
.844 .20279 Mdot
.844 .20285 Mdot
.844 .20306 Mdot
.844 .20342 Mdot
.844 .20399 Mdot
.844 .20441 Mdot
.844 .20465 Mdot
.844 .20492 Mdot
.844 .20539 Mdot
.844 .20591 Mdot
.844 .20652 Mdot
.844 .20654 Mdot
.844 .2068 Mdot
.844 .20682 Mdot
.844 .20798 Mdot
.844 .20801 Mdot
.844 .20835 Mdot
.844 .20883 Mdot
.844 .20924 Mdot
.844 .20931 Mdot
.844 .21054 Mdot
.844 .21123 Mdot
.844 .2122 Mdot
.844 .21249 Mdot
.844 .21288 Mdot
.844 .21308 Mdot
.844 .21379 Mdot
.844 .2155 Mdot
.844 .21553 Mdot
.844 .21654 Mdot
.844 .21668 Mdot
.844 .21717 Mdot
.844 .2172 Mdot
.844 .21761 Mdot
.844 .21806 Mdot
.844 .21864 Mdot
.844 .21901 Mdot
.844 .21925 Mdot
.844 .21945 Mdot
.844 .22048 Mdot
.844 .22075 Mdot
.844 .22227 Mdot
.844 .22231 Mdot
.844 .22269 Mdot
.844 .22295 Mdot
.844 .22325 Mdot
.844 .22337 Mdot
.844 .22361 Mdot
.844 .22369 Mdot
.844 .22454 Mdot
.844 .22498 Mdot
.844 .22609 Mdot
.844 .22619 Mdot
.844 .2269 Mdot
.844 .22719 Mdot
.844 .22794 Mdot
.844 .2282 Mdot
.844 .2285 Mdot
.844 .22943 Mdot
.844 .22976 Mdot
.844 .23094 Mdot
.844 .231 Mdot
.844 .23112 Mdot
.844 .23207 Mdot
.844 .23216 Mdot
.844 .23228 Mdot
.844 .23351 Mdot
.844 .23433 Mdot
.844 .23628 Mdot
.844 .2365 Mdot
.844 .23654 Mdot
.844 .23695 Mdot
.844 .23713 Mdot
.844 .23761 Mdot
.844 .23789 Mdot
.844 .23815 Mdot
.844 .23893 Mdot
.844 .23911 Mdot
.844 .2398 Mdot
.844 .2404 Mdot
.844 .24043 Mdot
.844 .2405 Mdot
.844 .24095 Mdot
.844 .24108 Mdot
.844 .24121 Mdot
.844 .24197 Mdot
.844 .24277 Mdot
.844 .24302 Mdot
.844 .2432 Mdot
.844 .24349 Mdot
.844 .24378 Mdot
.844 .24425 Mdot
.844 .24454 Mdot
.844 .24476 Mdot
.844 .2456 Mdot
.844 .24579 Mdot
.844 .24624 Mdot
.844 .2466 Mdot
.844 .24687 Mdot
.844 .24687 Mdot
.844 .24759 Mdot
.844 .24818 Mdot
.844 .2493 Mdot
.844 .24995 Mdot
.844 .25061 Mdot
.844 .25118 Mdot
.844 .2515 Mdot
.844 .2516 Mdot
.844 .25312 Mdot
.844 .25422 Mdot
.844 .25479 Mdot
.844 .25479 Mdot
.844 .25512 Mdot
.844 .25522 Mdot
.844 .25559 Mdot
.844 .25585 Mdot
.844 .25591 Mdot
.844 .2573 Mdot
.844 .25771 Mdot
.844 .25784 Mdot
.844 .25818 Mdot
.844 .25885 Mdot
.844 .25943 Mdot
.844 .26036 Mdot
.844 .26076 Mdot
.844 .26094 Mdot
.844 .26158 Mdot
.844 .26166 Mdot
.844 .26272 Mdot
.844 .26274 Mdot
.844 .26311 Mdot
.844 .26319 Mdot
.844 .26472 Mdot
.844 .26481 Mdot
.844 .26524 Mdot
.844 .26535 Mdot
.844 .26577 Mdot
.844 .26773 Mdot
.844 .26787 Mdot
.844 .26811 Mdot
.844 .26909 Mdot
.844 .2691 Mdot
.844 .26912 Mdot
.844 .27027 Mdot
.844 .27054 Mdot
.844 .27062 Mdot
.844 .27114 Mdot
.844 .27161 Mdot
.844 .27256 Mdot
.844 .27302 Mdot
.844 .27394 Mdot
.844 .27429 Mdot
.844 .27442 Mdot
.844 .27451 Mdot
.844 .27502 Mdot
.844 .27577 Mdot
.844 .27623 Mdot
.844 .27655 Mdot
.844 .27762 Mdot
.844 .27765 Mdot
.844 .27799 Mdot
.844 .27868 Mdot
.844 .27917 Mdot
.844 .28004 Mdot
.844 .28053 Mdot
.844 .28098 Mdot
.844 .28106 Mdot
.844 .28124 Mdot
.844 .2815 Mdot
.844 .28177 Mdot
.844 .28269 Mdot
.844 .28317 Mdot
.844 .28361 Mdot
.844 .28559 Mdot
.844 .28579 Mdot
.844 .28595 Mdot
.844 .28641 Mdot
.844 .28661 Mdot
.844 .28683 Mdot
.844 .28743 Mdot
.844 .28753 Mdot
.844 .28771 Mdot
.844 .288 Mdot
.844 .28843 Mdot
.844 .28854 Mdot
.844 .28879 Mdot
.844 .2888 Mdot
.844 .28923 Mdot
.844 .28974 Mdot
.844 .29032 Mdot
.844 .29097 Mdot
.844 .29227 Mdot
.844 .29266 Mdot
.844 .29295 Mdot
.844 .29347 Mdot
.844 .29363 Mdot
.844 .2943 Mdot
.844 .2951 Mdot
.844 .29536 Mdot
.844 .29546 Mdot
.844 .29553 Mdot
.844 .29582 Mdot
.844 .2961 Mdot
.844 .29653 Mdot
.844 .29657 Mdot
.844 .2975 Mdot
.844 .29778 Mdot
.844 .29779 Mdot
.844 .29926 Mdot
.844 .29966 Mdot
.844 .30049 Mdot
.844 .30089 Mdot
.844 .30162 Mdot
.844 .30274 Mdot
.844 .30364 Mdot
.844 .30472 Mdot
.844 .30579 Mdot
.844 .30645 Mdot
.844 .30679 Mdot
.844 .30734 Mdot
.844 .30757 Mdot
.844 .30838 Mdot
.844 .30867 Mdot
.844 .30951 Mdot
.844 .30952 Mdot
.844 .30988 Mdot
.844 .31033 Mdot
.844 .31074 Mdot
.844 .31079 Mdot
.844 .3111 Mdot
.844 .31155 Mdot
.844 .31224 Mdot
.844 .31331 Mdot
.844 .31451 Mdot
.844 .31481 Mdot
.844 .31525 Mdot
.844 .31529 Mdot
.844 .31554 Mdot
.844 .31574 Mdot
.844 .31657 Mdot
.844 .31736 Mdot
.844 .31758 Mdot
.844 .31858 Mdot
.844 .31861 Mdot
.844 .3187 Mdot
.844 .31886 Mdot
.844 .31957 Mdot
.844 .32057 Mdot
.844 .32135 Mdot
.844 .32214 Mdot
.844 .3222 Mdot
.844 .32293 Mdot
.844 .32372 Mdot
.844 .32417 Mdot
.844 .32459 Mdot
.844 .32582 Mdot
.844 .32583 Mdot
.844 .32636 Mdot
.844 .3269 Mdot
.844 .32692 Mdot
.844 .32751 Mdot
.844 .32794 Mdot
.844 .32821 Mdot
.844 .32849 Mdot
.844 .32896 Mdot
.844 .32906 Mdot
.844 .32984 Mdot
.844 .32986 Mdot
.844 .33075 Mdot
.844 .33103 Mdot
.844 .33133 Mdot
.844 .332 Mdot
.844 .33218 Mdot
.844 .33229 Mdot
.844 .33264 Mdot
.844 .3331 Mdot
.844 .33325 Mdot
.844 .3342 Mdot
.844 .33492 Mdot
.844 .33533 Mdot
.844 .33577 Mdot
.844 .33629 Mdot
.844 .33657 Mdot
.844 .33745 Mdot
.844 .33849 Mdot
.844 .33852 Mdot
.844 .33886 Mdot
.844 .33896 Mdot
.844 .33899 Mdot
.844 .34095 Mdot
.844 .341 Mdot
.844 .34158 Mdot
.844 .34192 Mdot
.844 .34238 Mdot
.844 .34308 Mdot
.844 .34319 Mdot
.844 .34498 Mdot
.844 .34526 Mdot
.844 .34644 Mdot
.844 .34686 Mdot
.844 .34782 Mdot
.844 .34807 Mdot
.844 .34856 Mdot
.844 .34921 Mdot
.844 .34939 Mdot
.844 .34956 Mdot
.844 .35004 Mdot
.844 .35076 Mdot
.844 .35236 Mdot
.844 .35318 Mdot
.844 .35364 Mdot
.844 .35369 Mdot
.844 .35539 Mdot
.844 .35559 Mdot
.844 .35561 Mdot
.844 .35563 Mdot
.844 .35646 Mdot
.844 .35651 Mdot
.844 .35664 Mdot
.844 .35719 Mdot
.844 .3579 Mdot
.844 .35796 Mdot
.844 .35894 Mdot
.844 .35956 Mdot
.844 .35996 Mdot
.844 .36031 Mdot
.844 .36204 Mdot
.844 .36251 Mdot
.844 .36506 Mdot
.844 .36513 Mdot
.844 .36577 Mdot
.844 .36621 Mdot
.844 .36672 Mdot
.844 .36693 Mdot
.844 .36733 Mdot
.844 .36747 Mdot
.844 .3689 Mdot
.844 .36964 Mdot
.844 .37151 Mdot
.844 .37169 Mdot
.844 .37289 Mdot
.844 .37337 Mdot
.844 .37464 Mdot
.844 .37508 Mdot
.844 .37558 Mdot
.844 .37715 Mdot
.844 .37772 Mdot
.844 .3797 Mdot
.844 .37981 Mdot
.844 .38001 Mdot
.844 .3816 Mdot
.844 .38176 Mdot
.844 .38196 Mdot
.844 .38404 Mdot
.844 .38542 Mdot
.844 .38872 Mdot
.844 .38909 Mdot
.844 .38915 Mdot
.844 .38984 Mdot
.844 .39015 Mdot
.844 .39095 Mdot
.844 .39143 Mdot
.844 .39187 Mdot
.844 .39318 Mdot
.844 .3935 Mdot
.844 .39465 Mdot
.844 .39568 Mdot
.844 .39572 Mdot
.844 .39584 Mdot
.844 .39661 Mdot
.844 .39681 Mdot
.844 .39704 Mdot
.844 .39832 Mdot
.844 .39967 Mdot
.844 .40009 Mdot
.844 .40039 Mdot
.844 .40089 Mdot
.844 .40137 Mdot
.844 .40218 Mdot
.844 .40267 Mdot
.844 .40304 Mdot
.844 .40445 Mdot
.844 .40477 Mdot
.844 .40553 Mdot
.844 .40614 Mdot
.844 .40658 Mdot
.844 .40659 Mdot
.844 .40781 Mdot
.844 .4088 Mdot
.844 .41069 Mdot
.844 .4118 Mdot
.844 .4129 Mdot
.844 .41386 Mdot
.844 .41442 Mdot
.844 .41457 Mdot
.844 .41714 Mdot
.844 .419 Mdot
.844 .41996 Mdot
.844 .41997 Mdot
.844 .42052 Mdot
.844 .42068 Mdot
.844 .42131 Mdot
.844 .42175 Mdot
.844 .42185 Mdot
.844 .42419 Mdot
.844 .42489 Mdot
.844 .42511 Mdot
.844 .42568 Mdot
.844 .42682 Mdot
.844 .42779 Mdot
.844 .42936 Mdot
.844 .43004 Mdot
.844 .43035 Mdot
.844 .43142 Mdot
.844 .43156 Mdot
.844 .43335 Mdot
.844 .43338 Mdot
.844 .43401 Mdot
.844 .43415 Mdot
.844 .43672 Mdot
.844 .43687 Mdot
.844 .4376 Mdot
.844 .4378 Mdot
.844 .43849 Mdot
.844 .44181 Mdot
.844 .44205 Mdot
.844 .44244 Mdot
.844 .4441 Mdot
.844 .44411 Mdot
.844 .44416 Mdot
.844 .4461 Mdot
.844 .44655 Mdot
.844 .44668 Mdot
.844 .44756 Mdot
.844 .44835 Mdot
.844 .44996 Mdot
.844 .45073 Mdot
.844 .45228 Mdot
.844 .45287 Mdot
.844 .45309 Mdot
.844 .45325 Mdot
.844 .45411 Mdot
.844 .45537 Mdot
.844 .45616 Mdot
.844 .45669 Mdot
.844 .4585 Mdot
.844 .45855 Mdot
.844 .45912 Mdot
.844 .46029 Mdot
.844 .46111 Mdot
.844 .46259 Mdot
.844 .46342 Mdot
.844 .46417 Mdot
.844 .4643 Mdot
.844 .4646 Mdot
.844 .46505 Mdot
.844 .46551 Mdot
.844 .46706 Mdot
.844 .46787 Mdot
.844 .46861 Mdot
.844 .47196 Mdot
.844 .4723 Mdot
.844 .47255 Mdot
.844 .47333 Mdot
.844 .47367 Mdot
.844 .47405 Mdot
.844 .47506 Mdot
.844 .47522 Mdot
.844 .47554 Mdot
.844 .47603 Mdot
.844 .47675 Mdot
.844 .47693 Mdot
.844 .47735 Mdot
.844 .47737 Mdot
.844 .4781 Mdot
.844 .47896 Mdot
.844 .47993 Mdot
.844 .48103 Mdot
.844 .48323 Mdot
.844 .48389 Mdot
.844 .48437 Mdot
.844 .48526 Mdot
.844 .48552 Mdot
.844 .48665 Mdot
.844 .488 Mdot
.844 .48844 Mdot
.844 .48861 Mdot
.844 .48873 Mdot
.844 .48922 Mdot
.844 .48969 Mdot
.844 .49043 Mdot
.844 .49048 Mdot
.844 .49205 Mdot
.844 .49252 Mdot
.844 .49255 Mdot
.844 .49502 Mdot
.844 .4957 Mdot
.844 .4971 Mdot
.844 .49779 Mdot
.844 .49901 Mdot
.844 .50091 Mdot
.844 .50242 Mdot
.844 .50424 Mdot
.844 .50605 Mdot
.844 .50717 Mdot
.844 .50774 Mdot
.844 .50867 Mdot
.844 .50905 Mdot
.844 .51042 Mdot
.844 .51091 Mdot
.844 .51233 Mdot
.844 .51235 Mdot
.844 .51296 Mdot
.844 .5137 Mdot
.846 .01591 Mdot
.846 .0167 Mdot
.846 .01673 Mdot
.846 .01676 Mdot
.846 .01807 Mdot
.846 .0181 Mdot
.846 .01812 Mdot
.846 .01817 Mdot
.846 .01824 Mdot
.846 .01897 Mdot
.846 .01979 Mdot
.846 .02004 Mdot
.846 .02039 Mdot
.846 .02044 Mdot
.846 .02048 Mdot
.846 .02057 Mdot
.846 .02066 Mdot
.846 .02068 Mdot
.846 .02192 Mdot
.846 .02293 Mdot
.846 .02304 Mdot
.846 .02331 Mdot
.846 .02373 Mdot
.846 .02384 Mdot
.846 .02432 Mdot
.846 .02441 Mdot
.846 .02447 Mdot
.846 .02456 Mdot
.846 .02462 Mdot
.846 .02478 Mdot
.846 .02481 Mdot
.846 .02535 Mdot
.846 .0269 Mdot
.846 .02713 Mdot
.846 .02843 Mdot
.846 .02862 Mdot
.846 .0288 Mdot
.846 .02917 Mdot
.846 .02925 Mdot
.846 .02997 Mdot
.846 .03016 Mdot
.846 .03097 Mdot
.846 .03111 Mdot
.846 .03122 Mdot
.846 .03122 Mdot
.846 .03137 Mdot
.846 .03147 Mdot
.846 .03175 Mdot
.846 .0318 Mdot
.846 .0318 Mdot
.846 .03225 Mdot
.846 .03233 Mdot
.846 .03238 Mdot
.846 .03271 Mdot
.846 .03533 Mdot
.846 .03564 Mdot
.846 .03571 Mdot
.846 .03701 Mdot
.846 .03756 Mdot
.846 .03792 Mdot
.846 .03823 Mdot
.846 .03834 Mdot
.846 .03855 Mdot
.846 .03918 Mdot
.846 .03931 Mdot
.846 .03986 Mdot
.846 .03997 Mdot
.846 .04015 Mdot
.846 .04053 Mdot
.846 .04085 Mdot
.846 .04146 Mdot
.846 .04154 Mdot
.846 .04221 Mdot
.846 .04246 Mdot
.846 .04264 Mdot
.846 .04264 Mdot
.846 .04289 Mdot
.846 .04306 Mdot
.846 .04353 Mdot
.846 .04362 Mdot
.846 .04363 Mdot
.846 .04438 Mdot
.846 .04452 Mdot
.846 .0446 Mdot
.846 .04497 Mdot
.846 .04516 Mdot
.846 .04604 Mdot
.846 .047 Mdot
.846 .047 Mdot
.846 .04749 Mdot
.846 .04754 Mdot
.846 .04959 Mdot
.846 .0497 Mdot
.846 .04978 Mdot
.846 .04992 Mdot
.846 .05012 Mdot
.846 .05024 Mdot
.846 .05056 Mdot
.846 .05138 Mdot
.846 .05244 Mdot
.846 .05261 Mdot
.846 .05297 Mdot
.846 .05312 Mdot
.846 .05333 Mdot
.846 .05338 Mdot
.846 .05397 Mdot
.846 .05451 Mdot
.846 .05465 Mdot
.846 .05469 Mdot
.846 .05483 Mdot
.846 .05504 Mdot
.846 .05543 Mdot
.846 .05581 Mdot
.846 .05611 Mdot
.846 .05632 Mdot
.846 .05665 Mdot
.846 .05683 Mdot
.846 .05725 Mdot
.846 .05745 Mdot
.846 .05776 Mdot
.846 .05817 Mdot
.846 .0584 Mdot
.846 .05886 Mdot
.846 .05893 Mdot
.846 .05912 Mdot
.846 .05932 Mdot
.846 .05997 Mdot
.846 .06007 Mdot
.846 .0601 Mdot
.846 .06107 Mdot
.846 .06124 Mdot
.846 .06166 Mdot
.846 .06196 Mdot
.846 .06197 Mdot
.846 .06238 Mdot
.846 .06268 Mdot
.846 .06337 Mdot
.846 .06348 Mdot
.846 .06362 Mdot
.846 .06364 Mdot
.846 .06376 Mdot
.846 .0649 Mdot
.846 .06493 Mdot
.846 .06514 Mdot
.846 .06528 Mdot
.846 .06567 Mdot
.846 .06571 Mdot
.846 .06591 Mdot
.846 .06598 Mdot
.846 .06623 Mdot
.846 .06627 Mdot
.846 .06772 Mdot
.846 .06813 Mdot
.846 .06824 Mdot
.846 .06882 Mdot
.846 .06934 Mdot
.846 .06935 Mdot
.846 .07016 Mdot
.846 .07025 Mdot
.846 .07076 Mdot
.846 .07361 Mdot
.846 .07368 Mdot
.846 .07373 Mdot
.846 .07374 Mdot
.846 .07375 Mdot
.846 .07382 Mdot
.846 .07391 Mdot
.846 .07405 Mdot
.846 .07429 Mdot
.846 .07462 Mdot
.846 .07463 Mdot
.846 .07483 Mdot
.846 .07485 Mdot
.846 .07537 Mdot
.846 .07558 Mdot
.846 .0759 Mdot
.846 .07676 Mdot
.846 .07831 Mdot
.846 .07848 Mdot
.846 .07854 Mdot
.846 .07882 Mdot
.846 .07884 Mdot
.846 .07902 Mdot
.846 .07903 Mdot
.846 .07945 Mdot
.846 .07958 Mdot
.846 .0797 Mdot
.846 .08002 Mdot
.846 .08005 Mdot
.846 .08013 Mdot
.846 .08114 Mdot
.846 .08205 Mdot
.846 .08229 Mdot
.846 .08236 Mdot
.846 .08259 Mdot
.846 .08295 Mdot
.846 .08309 Mdot
.846 .0836 Mdot
.846 .0841 Mdot
.846 .08425 Mdot
.846 .08434 Mdot
.846 .08463 Mdot
.846 .08475 Mdot
.846 .08508 Mdot
.846 .08512 Mdot
.846 .08566 Mdot
.846 .08579 Mdot
.846 .08598 Mdot
.846 .08669 Mdot
.846 .08702 Mdot
.846 .0873 Mdot
.846 .08749 Mdot
.846 .08754 Mdot
.846 .08825 Mdot
.846 .08845 Mdot
.846 .08863 Mdot
.846 .08941 Mdot
.846 .08953 Mdot
.846 .08965 Mdot
.846 .08985 Mdot
.846 .09019 Mdot
.846 .09073 Mdot
.846 .09102 Mdot
.846 .09105 Mdot
.846 .09117 Mdot
.846 .09129 Mdot
.846 .09145 Mdot
.846 .09145 Mdot
.846 .09149 Mdot
.846 .09151 Mdot
.846 .09314 Mdot
.846 .09343 Mdot
.846 .09404 Mdot
.846 .09414 Mdot
.846 .09466 Mdot
.846 .09466 Mdot
.846 .09537 Mdot
.846 .09587 Mdot
.846 .09589 Mdot
.846 .09601 Mdot
.846 .09699 Mdot
.846 .09705 Mdot
.846 .09722 Mdot
.846 .09747 Mdot
.846 .0975 Mdot
.846 .09769 Mdot
.846 .09816 Mdot
.846 .09847 Mdot
.846 .09963 Mdot
.846 .09967 Mdot
.846 .10003 Mdot
.846 .10027 Mdot
.846 .10093 Mdot
.846 .10101 Mdot
.846 .10134 Mdot
.846 .10145 Mdot
.846 .10187 Mdot
.846 .10195 Mdot
.846 .10434 Mdot
.846 .1044 Mdot
.846 .10501 Mdot
.846 .1051 Mdot
.846 .10528 Mdot
.846 .10626 Mdot
.846 .1069 Mdot
.846 .10705 Mdot
.846 .10714 Mdot
.846 .10715 Mdot
.846 .10746 Mdot
.846 .10853 Mdot
.846 .10868 Mdot
.846 .10872 Mdot
.846 .109 Mdot
.846 .10908 Mdot
.846 .10936 Mdot
.846 .10954 Mdot
.846 .11091 Mdot
.846 .11132 Mdot
.846 .11436 Mdot
.846 .11448 Mdot
.846 .11457 Mdot
.846 .11459 Mdot
.846 .1146 Mdot
.846 .11471 Mdot
.846 .11477 Mdot
.846 .11487 Mdot
.846 .1151 Mdot
.846 .11551 Mdot
.846 .11608 Mdot
.846 .11609 Mdot
.846 .11609 Mdot
.846 .11643 Mdot
.846 .11646 Mdot
.846 .11708 Mdot
.846 .11734 Mdot
.846 .11734 Mdot
.846 .11769 Mdot
.846 .11824 Mdot
.846 .11872 Mdot
.846 .11969 Mdot
.846 .12019 Mdot
.846 .12056 Mdot
.846 .12152 Mdot
.846 .12162 Mdot
.846 .12232 Mdot
.846 .1226 Mdot
.846 .12271 Mdot
.846 .12287 Mdot
.846 .12319 Mdot
.846 .12321 Mdot
.846 .12352 Mdot
.846 .12353 Mdot
.846 .12424 Mdot
.846 .12446 Mdot
.846 .12466 Mdot
.846 .12522 Mdot
.846 .12527 Mdot
.846 .1254 Mdot
.846 .12628 Mdot
.846 .12665 Mdot
.846 .12711 Mdot
.846 .1272 Mdot
.846 .12757 Mdot
.846 .12858 Mdot
.846 .12864 Mdot
.846 .12902 Mdot
.846 .12905 Mdot
.846 .12917 Mdot
.846 .12957 Mdot
.846 .13017 Mdot
.846 .1302 Mdot
.846 .13041 Mdot
.846 .13113 Mdot
.846 .13127 Mdot
.846 .13139 Mdot
.846 .13211 Mdot
.846 .13237 Mdot
.846 .13252 Mdot
.846 .13267 Mdot
.846 .13298 Mdot
.846 .13302 Mdot
.846 .13322 Mdot
.846 .13369 Mdot
.846 .13378 Mdot
.846 .13384 Mdot
.846 .13476 Mdot
.846 .13498 Mdot
.846 .13529 Mdot
.846 .1365 Mdot
.846 .13706 Mdot
.846 .1374 Mdot
.846 .13746 Mdot
.846 .13748 Mdot
.846 .13754 Mdot
.846 .13785 Mdot
.846 .13794 Mdot
.846 .13892 Mdot
.846 .13913 Mdot
.846 .13947 Mdot
.846 .13977 Mdot
.846 .13985 Mdot
.846 .14005 Mdot
.846 .14007 Mdot
.846 .14103 Mdot
.846 .14111 Mdot
.846 .14129 Mdot
.846 .1415 Mdot
.846 .14184 Mdot
.846 .14203 Mdot
.846 .14241 Mdot
.846 .14332 Mdot
.846 .14334 Mdot
.846 .14334 Mdot
.846 .14364 Mdot
.846 .14383 Mdot
.846 .14387 Mdot
.846 .14387 Mdot
.846 .14407 Mdot
.846 .14428 Mdot
.846 .14455 Mdot
.846 .14455 Mdot
.846 .14461 Mdot
.846 .14466 Mdot
.846 .14741 Mdot
.846 .14791 Mdot
.846 .14894 Mdot
.846 .1491 Mdot
.846 .14998 Mdot
.846 .14999 Mdot
.846 .15119 Mdot
.846 .15203 Mdot
.846 .15207 Mdot
.846 .15227 Mdot
.846 .15392 Mdot
.846 .15402 Mdot
.846 .15432 Mdot
.846 .15473 Mdot
.846 .15478 Mdot
.846 .15512 Mdot
.846 .15591 Mdot
.846 .15644 Mdot
.846 .15721 Mdot
.846 .15839 Mdot
.846 .15846 Mdot
.846 .15908 Mdot
.846 .15948 Mdot
.846 .15961 Mdot
.846 .16058 Mdot
.846 .16072 Mdot
.846 .16076 Mdot
.846 .16129 Mdot
.846 .16147 Mdot
.846 .16218 Mdot
.846 .16232 Mdot
.846 .1646 Mdot
.846 .16537 Mdot
.846 .16636 Mdot
.846 .16646 Mdot
.846 .16749 Mdot
.846 .16765 Mdot
.846 .16796 Mdot
.846 .16961 Mdot
.846 .16965 Mdot
.846 .16967 Mdot
.846 .1707 Mdot
.846 .17095 Mdot
.846 .17109 Mdot
.846 .17112 Mdot
.846 .17144 Mdot
.846 .17164 Mdot
.846 .17346 Mdot
.846 .1737 Mdot
.846 .17377 Mdot
.846 .17425 Mdot
.846 .17437 Mdot
.846 .17439 Mdot
.846 .17485 Mdot
.846 .17516 Mdot
.846 .17548 Mdot
.846 .17747 Mdot
.846 .17818 Mdot
.846 .17956 Mdot
.846 .17976 Mdot
.846 .18071 Mdot
.846 .18332 Mdot
.846 .18351 Mdot
.846 .18366 Mdot
.846 .18371 Mdot
.846 .18372 Mdot
.846 .18391 Mdot
.846 .18401 Mdot
.846 .18418 Mdot
.846 .18446 Mdot
.846 .18457 Mdot
.846 .18516 Mdot
.846 .18526 Mdot
.846 .18622 Mdot
.846 .18624 Mdot
.846 .18624 Mdot
.846 .1865 Mdot
.846 .18682 Mdot
.846 .18686 Mdot
.846 .18792 Mdot
.846 .18835 Mdot
.846 .18835 Mdot
.846 .18872 Mdot
.846 .18896 Mdot
.846 .18922 Mdot
.846 .18988 Mdot
.846 .19016 Mdot
.846 .19065 Mdot
.846 .1907 Mdot
.846 .19133 Mdot
.846 .19234 Mdot
.846 .19266 Mdot
.846 .1929 Mdot
.846 .19318 Mdot
.846 .1938 Mdot
.846 .19452 Mdot
.846 .19544 Mdot
.846 .19559 Mdot
.846 .19678 Mdot
.846 .19726 Mdot
.846 .19745 Mdot
.846 .19772 Mdot
.846 .19825 Mdot
.846 .19829 Mdot
.846 .19835 Mdot
.846 .19881 Mdot
.846 .19884 Mdot
.846 .20004 Mdot
.846 .20041 Mdot
.846 .20074 Mdot
.846 .20075 Mdot
.846 .20091 Mdot
.846 .20169 Mdot
.846 .20177 Mdot
.846 .20199 Mdot
.846 .20296 Mdot
.846 .20348 Mdot
.846 .20382 Mdot
.846 .20411 Mdot
.846 .20465 Mdot
.846 .20489 Mdot
.846 .20505 Mdot
.846 .20566 Mdot
.846 .20727 Mdot
.846 .20737 Mdot
.846 .20748 Mdot
.846 .20813 Mdot
.846 .20816 Mdot
.846 .20837 Mdot
.846 .20904 Mdot
.846 .21006 Mdot
.846 .21011 Mdot
.846 .2104 Mdot
.846 .21047 Mdot
.846 .21073 Mdot
.846 .21168 Mdot
.846 .21193 Mdot
.846 .21193 Mdot
.846 .21212 Mdot
.846 .21335 Mdot
.846 .2137 Mdot
.846 .21379 Mdot
.846 .21405 Mdot
.846 .2143 Mdot
.846 .21482 Mdot
.846 .21488 Mdot
.846 .21522 Mdot
.846 .21564 Mdot
.846 .21602 Mdot
.846 .21617 Mdot
.846 .21627 Mdot
.846 .21628 Mdot
.846 .21782 Mdot
.846 .2182 Mdot
.846 .21872 Mdot
.846 .22077 Mdot
.846 .22101 Mdot
.846 .22167 Mdot
.846 .22172 Mdot
.846 .22186 Mdot
.846 .2223 Mdot
.846 .2224 Mdot
.846 .22243 Mdot
.846 .22253 Mdot
.846 .22307 Mdot
.846 .22321 Mdot
.846 .22442 Mdot
.846 .22488 Mdot
.846 .22522 Mdot
.846 .22531 Mdot
.846 .2258 Mdot
.846 .22631 Mdot
.846 .22644 Mdot
.846 .22678 Mdot
.846 .22681 Mdot
.846 .22725 Mdot
.846 .22844 Mdot
.846 .22857 Mdot
.846 .22876 Mdot
.846 .22889 Mdot
.846 .22924 Mdot
.846 .2294 Mdot
.846 .22981 Mdot
.846 .23013 Mdot
.846 .23022 Mdot
.846 .23067 Mdot
.846 .23078 Mdot
.846 .23103 Mdot
.846 .23232 Mdot
.846 .23234 Mdot
.846 .23235 Mdot
.846 .23285 Mdot
.846 .23318 Mdot
.846 .23325 Mdot
.846 .23325 Mdot
.846 .23359 Mdot
.846 .23394 Mdot
.846 .23439 Mdot
.846 .2344 Mdot
.846 .2345 Mdot
.846 .23458 Mdot
.846 .23924 Mdot
.846 .24008 Mdot
.846 .24048 Mdot
.846 .24182 Mdot
.846 .24209 Mdot
.846 .24358 Mdot
.846 .24359 Mdot
.846 .24421 Mdot
.846 .24523 Mdot
.846 .24562 Mdot
.846 .24705 Mdot
.846 .24712 Mdot
.846 .24745 Mdot
.846 .24876 Mdot
.846 .24901 Mdot
.846 .24947 Mdot
.846 .25025 Mdot
.846 .25042 Mdot
.846 .25075 Mdot
.846 .25092 Mdot
.846 .25116 Mdot
.846 .25162 Mdot
.846 .25171 Mdot
.846 .25227 Mdot
.846 .25361 Mdot
.846 .25445 Mdot
.846 .25451 Mdot
.846 .25522 Mdot
.846 .25552 Mdot
.846 .25581 Mdot
.846 .25673 Mdot
.846 .25782 Mdot
.846 .25793 Mdot
.846 .25836 Mdot
.846 .25897 Mdot
.846 .25965 Mdot
.846 .25988 Mdot
.846 .26153 Mdot
.846 .26176 Mdot
.846 .26182 Mdot
.846 .26272 Mdot
.846 .26303 Mdot
.846 .26423 Mdot
.846 .26446 Mdot
.846 .26474 Mdot
.846 .2649 Mdot
.846 .26502 Mdot
.846 .26833 Mdot
.846 .26963 Mdot
.846 .26999 Mdot
.846 .27122 Mdot
.846 .27131 Mdot
.846 .27147 Mdot
.846 .27191 Mdot
.846 .27206 Mdot
.846 .27321 Mdot
.846 .27348 Mdot
.846 .27358 Mdot
.846 .274 Mdot
.846 .27457 Mdot
.846 .2768 Mdot
.846 .27686 Mdot
.846 .2769 Mdot
.846 .27863 Mdot
.846 .27906 Mdot
.846 .27931 Mdot
.846 .27936 Mdot
.846 .27989 Mdot
.846 .28024 Mdot
.846 .28331 Mdot
.846 .28336 Mdot
.846 .28352 Mdot
.846 .28372 Mdot
.846 .28383 Mdot
.846 .28397 Mdot
.846 .28456 Mdot
.846 .28464 Mdot
.846 .28485 Mdot
.846 .28488 Mdot
.846 .28488 Mdot
.846 .28526 Mdot
.846 .28567 Mdot
.846 .28619 Mdot
.846 .28673 Mdot
.846 .28695 Mdot
.846 .28719 Mdot
.846 .28778 Mdot
.846 .28786 Mdot
.846 .28786 Mdot
.846 .28895 Mdot
.846 .29009 Mdot
.846 .29012 Mdot
.846 .29129 Mdot
.846 .29163 Mdot
.846 .29317 Mdot
.846 .29363 Mdot
.846 .2938 Mdot
.846 .29398 Mdot
.846 .29447 Mdot
.846 .29558 Mdot
.846 .29616 Mdot
.846 .29639 Mdot
.846 .2964 Mdot
.846 .29952 Mdot
.846 .29999 Mdot
.846 .30032 Mdot
.846 .30057 Mdot
.846 .30065 Mdot
.846 .30068 Mdot
.846 .30099 Mdot
.846 .30115 Mdot
.846 .30144 Mdot
.846 .30192 Mdot
.846 .30211 Mdot
.846 .30279 Mdot
.846 .30287 Mdot
.846 .30311 Mdot
.846 .30328 Mdot
.846 .30491 Mdot
.846 .30494 Mdot
.846 .30494 Mdot
.846 .30538 Mdot
.846 .30591 Mdot
.846 .30598 Mdot
.846 .30623 Mdot
.846 .30718 Mdot
.846 .30777 Mdot
.846 .3085 Mdot
.846 .30851 Mdot
.846 .30913 Mdot
.846 .30953 Mdot
.846 .30998 Mdot
.846 .3111 Mdot
.846 .31157 Mdot
.846 .3116 Mdot
.846 .3124 Mdot
.846 .31248 Mdot
.846 .31291 Mdot
.846 .3134 Mdot
.846 .31355 Mdot
.846 .31391 Mdot
.846 .31525 Mdot
.846 .31532 Mdot
.846 .31579 Mdot
.846 .31621 Mdot
.846 .31668 Mdot
.846 .31773 Mdot
.846 .3185 Mdot
.846 .31894 Mdot
.846 .32015 Mdot
.846 .3205 Mdot
.846 .32076 Mdot
.846 .32081 Mdot
.846 .32083 Mdot
.846 .32276 Mdot
.846 .32357 Mdot
.846 .3239 Mdot
.846 .32436 Mdot
.846 .32526 Mdot
.846 .32532 Mdot
.846 .32543 Mdot
.846 .3262 Mdot
.846 .32625 Mdot
.846 .32828 Mdot
.846 .32891 Mdot
.846 .32948 Mdot
.846 .32948 Mdot
.846 .32976 Mdot
.846 .32979 Mdot
.846 .33107 Mdot
.846 .33112 Mdot
.846 .3312 Mdot
.846 .33158 Mdot
.846 .33207 Mdot
.846 .33279 Mdot
.846 .33301 Mdot
.846 .33309 Mdot
.846 .33322 Mdot
.846 .334 Mdot
.846 .33411 Mdot
.846 .33446 Mdot
.846 .33469 Mdot
.846 .33518 Mdot
.846 .33529 Mdot
.846 .33608 Mdot
.846 .33649 Mdot
.846 .33664 Mdot
.846 .33676 Mdot
.846 .3372 Mdot
.846 .33779 Mdot
.846 .33915 Mdot
.846 .33938 Mdot
.846 .34007 Mdot
.846 .34051 Mdot
.846 .34054 Mdot
.846 .34069 Mdot
.846 .34087 Mdot
.846 .34197 Mdot
.846 .34203 Mdot
.846 .34237 Mdot
.846 .34352 Mdot
.846 .3452 Mdot
.846 .34524 Mdot
.846 .34528 Mdot
.846 .34529 Mdot
.846 .34533 Mdot
.846 .34581 Mdot
.846 .34593 Mdot
.846 .34637 Mdot
.846 .34656 Mdot
.846 .34798 Mdot
.846 .34808 Mdot
.846 .34829 Mdot
.846 .3484 Mdot
.846 .34841 Mdot
.846 .34873 Mdot
.846 .349 Mdot
.846 .35081 Mdot
.846 .3514 Mdot
.846 .35155 Mdot
.846 .35172 Mdot
.846 .35199 Mdot
.846 .35241 Mdot
.846 .3533 Mdot
.846 .35341 Mdot
.846 .35397 Mdot
.846 .35468 Mdot
.846 .35532 Mdot
.846 .3555 Mdot
.846 .35551 Mdot
.846 .35558 Mdot
.846 .35575 Mdot
.846 .35577 Mdot
.846 .35728 Mdot
.846 .35837 Mdot
.846 .35844 Mdot
.846 .35902 Mdot
.846 .35971 Mdot
.846 .3599 Mdot
.846 .36337 Mdot
.846 .36376 Mdot
.846 .36488 Mdot
.846 .36497 Mdot
.846 .36521 Mdot
.846 .36595 Mdot
.846 .36612 Mdot
.846 .36617 Mdot
.846 .36633 Mdot
.846 .36725 Mdot
.846 .36749 Mdot
.846 .36953 Mdot
.846 .37031 Mdot
.846 .3709 Mdot
.846 .37105 Mdot
.846 .37187 Mdot
.846 .37273 Mdot
.846 .37295 Mdot
.846 .37352 Mdot
.846 .37358 Mdot
.846 .37432 Mdot
.846 .37633 Mdot
.846 .37655 Mdot
.846 .37688 Mdot
.846 .37709 Mdot
.846 .37769 Mdot
.846 .37795 Mdot
.846 .37865 Mdot
.846 .3792 Mdot
.846 .37935 Mdot
.846 .38011 Mdot
.846 .38029 Mdot
.846 .38071 Mdot
.846 .38291 Mdot
.846 .38294 Mdot
.846 .38295 Mdot
.846 .38381 Mdot
.846 .38435 Mdot
.846 .38447 Mdot
.846 .38448 Mdot
.846 .38505 Mdot
.846 .38564 Mdot
.846 .38641 Mdot
.846 .38641 Mdot
.846 .38659 Mdot
.846 .38673 Mdot
.846 .39461 Mdot
.846 .39603 Mdot
.846 .39671 Mdot
.846 .39898 Mdot
.846 .39944 Mdot
.846 .40196 Mdot
.846 .40198 Mdot
.846 .40302 Mdot
.846 .40475 Mdot
.846 .40541 Mdot
.846 .40782 Mdot
.846 .40794 Mdot
.846 .4085 Mdot
.846 .41072 Mdot
.846 .41113 Mdot
.846 .41193 Mdot
.846 .41323 Mdot
.846 .41353 Mdot
.846 .41409 Mdot
.846 .41438 Mdot
.846 .41478 Mdot
.846 .41556 Mdot
.846 .41571 Mdot
.846 .41666 Mdot
.846 .41893 Mdot
.846 .42034 Mdot
.846 .42044 Mdot
.846 .42165 Mdot
.846 .42216 Mdot
.846 .42265 Mdot
.846 .4242 Mdot
.846 .42605 Mdot
.846 .42624 Mdot
.846 .42695 Mdot
.846 .428 Mdot
.846 .42915 Mdot
.846 .42953 Mdot
.846 .43232 Mdot
.846 .43271 Mdot
.846 .43282 Mdot
.846 .43433 Mdot
.846 .43486 Mdot
.846 .4369 Mdot
.846 .43728 Mdot
.846 .43776 Mdot
.846 .43803 Mdot
.846 .43824 Mdot
.846 .44383 Mdot
.846 .44603 Mdot
.846 .44664 Mdot
.846 .44872 Mdot
.846 .44887 Mdot
.846 .44914 Mdot
.846 .4499 Mdot
.846 .45014 Mdot
.846 .45208 Mdot
.846 .45254 Mdot
.846 .45272 Mdot
.846 .45343 Mdot
.846 .45439 Mdot
.846 .45817 Mdot
.846 .45826 Mdot
.846 .45833 Mdot
.846 .46127 Mdot
.846 .46199 Mdot
.846 .46241 Mdot
.846 .46249 Mdot
.846 .46339 Mdot
.846 .46398 Mdot
.846 .46917 Mdot
.846 .46926 Mdot
.846 .46953 Mdot
.846 .46988 Mdot
.846 .47007 Mdot
.846 .47029 Mdot
.846 .47129 Mdot
.846 .47143 Mdot
.846 .47178 Mdot
.846 .47183 Mdot
.846 .47183 Mdot
.846 .47247 Mdot
.846 .47317 Mdot
.846 .47406 Mdot
.846 .47497 Mdot
.846 .47534 Mdot
.846 .47573 Mdot
.846 .47673 Mdot
.846 .47687 Mdot
.846 .47687 Mdot
.846 .47872 Mdot
.846 .48066 Mdot
.846 .4807 Mdot
.846 .48269 Mdot
.846 .48325 Mdot
.846 .48586 Mdot
.846 .48663 Mdot
.846 .48692 Mdot
.846 .48723 Mdot
.846 .48806 Mdot
.846 .48994 Mdot
.846 .49091 Mdot
.846 .4913 Mdot
.846 .49132 Mdot
.846 .49661 Mdot
.846 .4974 Mdot
.846 .49796 Mdot
.846 .49839 Mdot
.846 .49851 Mdot
.846 .49856 Mdot
.846 .4991 Mdot
.846 .49937 Mdot
.846 .49986 Mdot
.846 .50066 Mdot
.846 .50099 Mdot
.846 .50215 Mdot
.846 .50228 Mdot
.846 .50269 Mdot
.846 .50296 Mdot
.846 .50572 Mdot
.846 .50577 Mdot
.846 .50577 Mdot
.846 .50652 Mdot
.846 .50742 Mdot
.846 .50754 Mdot
.846 .50796 Mdot
.846 .50957 Mdot
.846 .51057 Mdot
.846 .5118 Mdot
.846 .51181 Mdot
.846 .51286 Mdot
.846 .51354 Mdot
.846 .5143 Mdot
.848 .01509 Mdot
.848 .01535 Mdot
.848 .01579 Mdot
.848 .01655 Mdot
.848 .01782 Mdot
.848 .01818 Mdot
.848 .01933 Mdot
.848 .01998 Mdot
.848 .02059 Mdot
.848 .0218 Mdot
.848 .02243 Mdot
.848 .02255 Mdot
.848 .02262 Mdot
.848 .02293 Mdot
.848 .02306 Mdot
.848 .02318 Mdot
.848 .02338 Mdot
.848 .02347 Mdot
.848 .02365 Mdot
.848 .02423 Mdot
.848 .02457 Mdot
.848 .02467 Mdot
.848 .02549 Mdot
.848 .02574 Mdot
.848 .02643 Mdot
.848 .02674 Mdot
.848 .02697 Mdot
.848 .02749 Mdot
.848 .02779 Mdot
.848 .028 Mdot
.848 .02812 Mdot
.848 .02865 Mdot
.848 .02867 Mdot
.848 .02887 Mdot
.848 .02907 Mdot
.848 .02941 Mdot
.848 .02957 Mdot
.848 .02986 Mdot
.848 .03062 Mdot
.848 .03085 Mdot
.848 .03106 Mdot
.848 .03143 Mdot
.848 .0316 Mdot
.848 .03168 Mdot
.848 .03188 Mdot
.848 .03228 Mdot
.848 .0325 Mdot
.848 .03295 Mdot
.848 .03298 Mdot
.848 .03342 Mdot
.848 .03441 Mdot
.848 .03458 Mdot
.848 .03505 Mdot
.848 .0351 Mdot
.848 .03521 Mdot
.848 .0355 Mdot
.848 .03625 Mdot
.848 .03637 Mdot
.848 .03661 Mdot
.848 .03689 Mdot
.848 .037 Mdot
.848 .03708 Mdot
.848 .03717 Mdot
.848 .03724 Mdot
.848 .03745 Mdot
.848 .03836 Mdot
.848 .03838 Mdot
.848 .03872 Mdot
.848 .03905 Mdot
.848 .0391 Mdot
.848 .03963 Mdot
.848 .0399 Mdot
.848 .0404 Mdot
.848 .04098 Mdot
.848 .04108 Mdot
.848 .04169 Mdot
.848 .04208 Mdot
.848 .04214 Mdot
.848 .04244 Mdot
.848 .04284 Mdot
.848 .04306 Mdot
.848 .04336 Mdot
.848 .0435 Mdot
.848 .04367 Mdot
.848 .04383 Mdot
.848 .0445 Mdot
.848 .04488 Mdot
.848 .04542 Mdot
.848 .04564 Mdot
.848 .0457 Mdot
.848 .04631 Mdot
.848 .04644 Mdot
.848 .04758 Mdot
.848 .04812 Mdot
.848 .04813 Mdot
.848 .0484 Mdot
.848 .04915 Mdot
.848 .0492 Mdot
.848 .04929 Mdot
.848 .0493 Mdot
.848 .04937 Mdot
.848 .04948 Mdot
.848 .04996 Mdot
.848 .05048 Mdot
.848 .05096 Mdot
.848 .05122 Mdot
.848 .05124 Mdot
.848 .05129 Mdot
.848 .05145 Mdot
.848 .05186 Mdot
.848 .0519 Mdot
.848 .05199 Mdot
.848 .05233 Mdot
.848 .05246 Mdot
.848 .05252 Mdot
.848 .05264 Mdot
.848 .05279 Mdot
.848 .05283 Mdot
.848 .05292 Mdot
.848 .0531 Mdot
.848 .05328 Mdot
.848 .05384 Mdot
.848 .05437 Mdot
.848 .05445 Mdot
.848 .05474 Mdot
.848 .05481 Mdot
.848 .05486 Mdot
.848 .05535 Mdot
.848 .05543 Mdot
.848 .05599 Mdot
.848 .05607 Mdot
.848 .05697 Mdot
.848 .05743 Mdot
.848 .05751 Mdot
.848 .05828 Mdot
.848 .05828 Mdot
.848 .05835 Mdot
.848 .05873 Mdot
.848 .05877 Mdot
.848 .05925 Mdot
.848 .05942 Mdot
.848 .06046 Mdot
.848 .06112 Mdot
.848 .06123 Mdot
.848 .06134 Mdot
.848 .06174 Mdot
.848 .06227 Mdot
.848 .06241 Mdot
.848 .06279 Mdot
.848 .06319 Mdot
.848 .0633 Mdot
.848 .06348 Mdot
.848 .06353 Mdot
.848 .06382 Mdot
.848 .0641 Mdot
.848 .06414 Mdot
.848 .06523 Mdot
.848 .06552 Mdot
.848 .06572 Mdot
.848 .06588 Mdot
.848 .06589 Mdot
.848 .06679 Mdot
.848 .06717 Mdot
.848 .06727 Mdot
.848 .0683 Mdot
.848 .06852 Mdot
.848 .06926 Mdot
.848 .06933 Mdot
.848 .06962 Mdot
.848 .07017 Mdot
.848 .07046 Mdot
.848 .07083 Mdot
.848 .07136 Mdot
.848 .07138 Mdot
.848 .07185 Mdot
.848 .07189 Mdot
.848 .07311 Mdot
.848 .07321 Mdot
.848 .07335 Mdot
.848 .07337 Mdot
.848 .07348 Mdot
.848 .07357 Mdot
.848 .07366 Mdot
.848 .07367 Mdot
.848 .07449 Mdot
.848 .07488 Mdot
.848 .07537 Mdot
.848 .07588 Mdot
.848 .07618 Mdot
.848 .07628 Mdot
.848 .07652 Mdot
.848 .07663 Mdot
.848 .07666 Mdot
.848 .07674 Mdot
.848 .07701 Mdot
.848 .07771 Mdot
.848 .07778 Mdot
.848 .07793 Mdot
.848 .07851 Mdot
.848 .07872 Mdot
.848 .07882 Mdot
.848 .07904 Mdot
.848 .07914 Mdot
.848 .0793 Mdot
.848 .07936 Mdot
.848 .07951 Mdot
.848 .07965 Mdot
.848 .07974 Mdot
.848 .07982 Mdot
.848 .08012 Mdot
.848 .08024 Mdot
.848 .08107 Mdot
.848 .08196 Mdot
.848 .08203 Mdot
.848 .08211 Mdot
.848 .08224 Mdot
.848 .08244 Mdot
.848 .0826 Mdot
.848 .08272 Mdot
.848 .08277 Mdot
.848 .08279 Mdot
.848 .08317 Mdot
.848 .08346 Mdot
.848 .08363 Mdot
.848 .08377 Mdot
.848 .08462 Mdot
.848 .08472 Mdot
.848 .08485 Mdot
.848 .08524 Mdot
.848 .08639 Mdot
.848 .08716 Mdot
.848 .08729 Mdot
.848 .08829 Mdot
.848 .0886 Mdot
.848 .08861 Mdot
.848 .08872 Mdot
.848 .08937 Mdot
.848 .08944 Mdot
.848 .09025 Mdot
.848 .09054 Mdot
.848 .09162 Mdot
.848 .09226 Mdot
.848 .09231 Mdot
.848 .09245 Mdot
.848 .09342 Mdot
.848 .09348 Mdot
.848 .0936 Mdot
.848 .09379 Mdot
.848 .09431 Mdot
.848 .09447 Mdot
.848 .09457 Mdot
.848 .09513 Mdot
.848 .09525 Mdot
.848 .09531 Mdot
.848 .09537 Mdot
.848 .09561 Mdot
.848 .09625 Mdot
.848 .09676 Mdot
.848 .09693 Mdot
.848 .09711 Mdot
.848 .09742 Mdot
.848 .0975 Mdot
.848 .098 Mdot
.848 .09847 Mdot
.848 .09854 Mdot
.848 .09924 Mdot
.848 .10039 Mdot
.848 .10087 Mdot
.848 .10122 Mdot
.848 .1015 Mdot
.848 .1015 Mdot
.848 .10303 Mdot
.848 .10367 Mdot
.848 .10384 Mdot
.848 .10397 Mdot
.848 .1056 Mdot
.848 .1058 Mdot
.848 .10596 Mdot
.848 .10623 Mdot
.848 .10722 Mdot
.848 .10734 Mdot
.848 .10735 Mdot
.848 .10784 Mdot
.848 .10877 Mdot
.848 .10926 Mdot
.848 .10972 Mdot
.848 .10988 Mdot
.848 .11079 Mdot
.848 .11082 Mdot
.848 .11161 Mdot
.848 .11168 Mdot
.848 .11223 Mdot
.848 .11266 Mdot
.848 .11372 Mdot
.848 .11375 Mdot
.848 .11391 Mdot
.848 .11417 Mdot
.848 .1142 Mdot
.848 .11439 Mdot
.848 .11454 Mdot
.848 .11468 Mdot
.848 .11471 Mdot
.848 .11565 Mdot
.848 .11609 Mdot
.848 .11659 Mdot
.848 .11675 Mdot
.848 .11759 Mdot
.848 .11846 Mdot
.848 .11896 Mdot
.848 .11913 Mdot
.848 .11953 Mdot
.848 .11972 Mdot
.848 .11977 Mdot
.848 .11991 Mdot
.848 .12037 Mdot
.848 .12116 Mdot
.848 .12125 Mdot
.848 .12155 Mdot
.848 .12168 Mdot
.848 .12192 Mdot
.848 .122 Mdot
.848 .12291 Mdot
.848 .12327 Mdot
.848 .12345 Mdot
.848 .1238 Mdot
.848 .12399 Mdot
.848 .12425 Mdot
.848 .12436 Mdot
.848 .12457 Mdot
.848 .1246 Mdot
.848 .12461 Mdot
.848 .12484 Mdot
.848 .12499 Mdot
.848 .12513 Mdot
.848 .12553 Mdot
.848 .12564 Mdot
.848 .12584 Mdot
.848 .12645 Mdot
.848 .12726 Mdot
.848 .12745 Mdot
.848 .12877 Mdot
.848 .12888 Mdot
.848 .12901 Mdot
.848 .12923 Mdot
.848 .12957 Mdot
.848 .12959 Mdot
.848 .12984 Mdot
.848 .13005 Mdot
.848 .13013 Mdot
.848 .13018 Mdot
.848 .13082 Mdot
.848 .13094 Mdot
.848 .13131 Mdot
.848 .13135 Mdot
.848 .13146 Mdot
.848 .1316 Mdot
.848 .13184 Mdot
.848 .13327 Mdot
.848 .13344 Mdot
.848 .13366 Mdot
.848 .13433 Mdot
.848 .13618 Mdot
.848 .13627 Mdot
.848 .13759 Mdot
.848 .1378 Mdot
.848 .1382 Mdot
.848 .1395 Mdot
.848 .14003 Mdot
.848 .14003 Mdot
.848 .14023 Mdot
.848 .14062 Mdot
.848 .14133 Mdot
.848 .14142 Mdot
.848 .14144 Mdot
.848 .14282 Mdot
.848 .14332 Mdot
.848 .14348 Mdot
.848 .14514 Mdot
.848 .14623 Mdot
.848 .14631 Mdot
.848 .14649 Mdot
.848 .14655 Mdot
.848 .14819 Mdot
.848 .14831 Mdot
.848 .1485 Mdot
.848 .14883 Mdot
.848 .1495 Mdot
.848 .14971 Mdot
.848 .14998 Mdot
.848 .15015 Mdot
.848 .15109 Mdot
.848 .15131 Mdot
.848 .1514 Mdot
.848 .15151 Mdot
.848 .15191 Mdot
.848 .15236 Mdot
.848 .153 Mdot
.848 .15387 Mdot
.848 .15416 Mdot
.848 .15446 Mdot
.848 .15484 Mdot
.848 .15498 Mdot
.848 .15512 Mdot
.848 .1552 Mdot
.848 .15596 Mdot
.848 .15608 Mdot
.848 .15638 Mdot
.848 .15677 Mdot
.848 .15688 Mdot
.848 .15713 Mdot
.848 .15807 Mdot
.848 .16002 Mdot
.848 .16084 Mdot
.848 .16143 Mdot
.848 .16189 Mdot
.848 .1619 Mdot
.848 .1644 Mdot
.848 .16449 Mdot
.848 .16496 Mdot
.848 .16558 Mdot
.848 .16588 Mdot
.848 .16591 Mdot
.848 .1661 Mdot
.848 .16749 Mdot
.848 .1682 Mdot
.848 .16886 Mdot
.848 .1692 Mdot
.848 .16947 Mdot
.848 .16992 Mdot
.848 .17079 Mdot
.848 .17118 Mdot
.848 .17161 Mdot
.848 .17178 Mdot
.848 .17181 Mdot
.848 .17183 Mdot
.848 .17254 Mdot
.848 .17265 Mdot
.848 .17312 Mdot
.848 .17395 Mdot
.848 .17423 Mdot
.848 .17506 Mdot
.848 .17584 Mdot
.848 .17612 Mdot
.848 .17766 Mdot
.848 .1777 Mdot
.848 .17854 Mdot
.848 .17905 Mdot
.848 .17913 Mdot
.848 .17917 Mdot
.848 .1796 Mdot
.848 .18004 Mdot
.848 .1801 Mdot
.848 .1806 Mdot
.848 .18082 Mdot
.848 .18254 Mdot
.848 .18263 Mdot
.848 .18268 Mdot
.848 .18296 Mdot
.848 .18339 Mdot
.848 .18345 Mdot
.848 .18376 Mdot
.848 .18401 Mdot
.848 .18426 Mdot
.848 .1843 Mdot
.848 .18472 Mdot
.848 .18591 Mdot
.848 .18639 Mdot
.848 .18664 Mdot
.848 .18749 Mdot
.848 .18777 Mdot
.848 .18784 Mdot
.848 .18786 Mdot
.848 .18919 Mdot
.848 .19066 Mdot
.848 .19152 Mdot
.848 .1918 Mdot
.848 .19191 Mdot
.848 .1921 Mdot
.848 .19236 Mdot
.848 .19248 Mdot
.848 .1928 Mdot
.848 .19289 Mdot
.848 .19313 Mdot
.848 .19349 Mdot
.848 .19391 Mdot
.848 .19495 Mdot
.848 .19502 Mdot
.848 .19524 Mdot
.848 .19539 Mdot
.848 .1959 Mdot
.848 .19612 Mdot
.848 .19654 Mdot
.848 .19667 Mdot
.848 .1968 Mdot
.848 .19753 Mdot
.848 .19818 Mdot
.848 .19822 Mdot
.848 .19859 Mdot
.848 .19883 Mdot
.848 .19912 Mdot
.848 .19973 Mdot
.848 .20004 Mdot
.848 .20048 Mdot
.848 .20067 Mdot
.848 .20103 Mdot
.848 .20108 Mdot
.848 .2011 Mdot
.848 .20149 Mdot
.848 .20175 Mdot
.848 .20198 Mdot
.848 .20231 Mdot
.848 .2024 Mdot
.848 .20266 Mdot
.848 .20284 Mdot
.848 .20287 Mdot
.848 .20318 Mdot
.848 .20423 Mdot
.848 .20436 Mdot
.848 .20559 Mdot
.848 .20591 Mdot
.848 .20624 Mdot
.848 .20679 Mdot
.848 .20802 Mdot
.848 .20814 Mdot
.848 .20834 Mdot
.848 .20856 Mdot
.848 .20893 Mdot
.848 .20952 Mdot
.848 .20955 Mdot
.848 .20997 Mdot
.848 .21032 Mdot
.848 .21046 Mdot
.848 .21054 Mdot
.848 .21163 Mdot
.848 .21183 Mdot
.848 .21246 Mdot
.848 .21253 Mdot
.848 .2126 Mdot
.848 .21271 Mdot
.848 .21296 Mdot
.848 .21336 Mdot
.848 .21463 Mdot
.848 .21579 Mdot
.848 .21608 Mdot
.848 .21644 Mdot
.848 .21758 Mdot
.848 .22072 Mdot
.848 .22087 Mdot
.848 .22126 Mdot
.848 .22208 Mdot
.848 .22296 Mdot
.848 .2231 Mdot
.848 .22347 Mdot
.848 .22415 Mdot
.848 .22447 Mdot
.848 .22606 Mdot
.848 .22609 Mdot
.848 .22635 Mdot
.848 .22725 Mdot
.848 .22726 Mdot
.848 .22758 Mdot
.848 .2279 Mdot
.848 .22825 Mdot
.848 .22899 Mdot
.848 .22946 Mdot
.848 .2296 Mdot
.848 .22964 Mdot
.848 .23128 Mdot
.848 .23199 Mdot
.848 .23283 Mdot
.848 .2331 Mdot
.848 .23382 Mdot
.848 .23591 Mdot
.848 .23691 Mdot
.848 .23777 Mdot
.848 .2379 Mdot
.848 .2382 Mdot
.848 .23831 Mdot
.848 .23857 Mdot
.848 .24109 Mdot
.848 .24129 Mdot
.848 .24162 Mdot
.848 .24217 Mdot
.848 .24241 Mdot
.848 .24332 Mdot
.848 .24345 Mdot
.848 .24366 Mdot
.848 .24392 Mdot
.848 .24413 Mdot
.848 .24441 Mdot
.848 .24601 Mdot
.848 .24621 Mdot
.848 .24638 Mdot
.848 .24653 Mdot
.848 .24673 Mdot
.848 .2474 Mdot
.848 .24816 Mdot
.848 .24874 Mdot
.848 .24924 Mdot
.848 .24925 Mdot
.848 .25066 Mdot
.848 .25072 Mdot
.848 .25082 Mdot
.848 .25121 Mdot
.848 .25172 Mdot
.848 .25174 Mdot
.848 .25236 Mdot
.848 .25261 Mdot
.848 .25284 Mdot
.848 .25298 Mdot
.848 .25427 Mdot
.848 .25431 Mdot
.848 .25447 Mdot
.848 .25499 Mdot
.848 .25564 Mdot
.848 .25583 Mdot
.848 .25626 Mdot
.848 .25785 Mdot
.848 .25856 Mdot
.848 .26086 Mdot
.848 .26115 Mdot
.848 .26145 Mdot
.848 .26198 Mdot
.848 .26253 Mdot
.848 .26254 Mdot
.848 .26317 Mdot
.848 .26355 Mdot
.848 .26433 Mdot
.848 .26435 Mdot
.848 .26523 Mdot
.848 .2663 Mdot
.848 .26688 Mdot
.848 .26822 Mdot
.848 .26858 Mdot
.848 .26874 Mdot
.848 .26954 Mdot
.848 .27042 Mdot
.848 .27059 Mdot
.848 .27108 Mdot
.848 .27114 Mdot
.848 .27146 Mdot
.848 .27235 Mdot
.848 .27383 Mdot
.848 .27463 Mdot
.848 .27483 Mdot
.848 .27502 Mdot
.848 .27521 Mdot
.848 .27543 Mdot
.848 .27615 Mdot
.848 .27652 Mdot
.848 .27672 Mdot
.848 .27719 Mdot
.848 .27795 Mdot
.848 .27862 Mdot
.848 .27942 Mdot
.848 .27949 Mdot
.848 .27962 Mdot
.848 .27969 Mdot
.848 .28007 Mdot
.848 .2808 Mdot
.848 .2811 Mdot
.848 .28115 Mdot
.848 .28118 Mdot
.848 .28238 Mdot
.848 .28258 Mdot
.848 .28315 Mdot
.848 .28337 Mdot
.848 .28372 Mdot
.848 .28477 Mdot
.848 .28526 Mdot
.848 .28537 Mdot
.848 .28601 Mdot
.848 .28665 Mdot
.848 .287 Mdot
.848 .28799 Mdot
.848 .28845 Mdot
.848 .29004 Mdot
.848 .29107 Mdot
.848 .29114 Mdot
.848 .29143 Mdot
.848 .29176 Mdot
.848 .29256 Mdot
.848 .29343 Mdot
.848 .29356 Mdot
.848 .29358 Mdot
.848 .29363 Mdot
.848 .29436 Mdot
.848 .29511 Mdot
.848 .2952 Mdot
.848 .29545 Mdot
.848 .29605 Mdot
.848 .29643 Mdot
.848 .29645 Mdot
.848 .29928 Mdot
.848 .29935 Mdot
.848 .29949 Mdot
.848 .29959 Mdot
.848 .30005 Mdot
.848 .30062 Mdot
.848 .30078 Mdot
.848 .30088 Mdot
.848 .30141 Mdot
.848 .30185 Mdot
.848 .30226 Mdot
.848 .30234 Mdot
.848 .30305 Mdot
.848 .30506 Mdot
.848 .30518 Mdot
.848 .30588 Mdot
.848 .30631 Mdot
.848 .30775 Mdot
.848 .30817 Mdot
.848 .30822 Mdot
.848 .30833 Mdot
.848 .30836 Mdot
.848 .30837 Mdot
.848 .30918 Mdot
.848 .31015 Mdot
.848 .31062 Mdot
.848 .31244 Mdot
.848 .31312 Mdot
.848 .31458 Mdot
.848 .31494 Mdot
.848 .31506 Mdot
.848 .31524 Mdot
.848 .31532 Mdot
.848 .31539 Mdot
.848 .3155 Mdot
.848 .31556 Mdot
.848 .316 Mdot
.848 .31621 Mdot
.848 .31675 Mdot
.848 .3169 Mdot
.848 .3173 Mdot
.848 .31762 Mdot
.848 .31793 Mdot
.848 .31862 Mdot
.848 .31977 Mdot
.848 .32004 Mdot
.848 .3204 Mdot
.848 .32052 Mdot
.848 .32075 Mdot
.848 .32088 Mdot
.848 .32115 Mdot
.848 .32201 Mdot
.848 .32239 Mdot
.848 .32248 Mdot
.848 .32309 Mdot
.848 .32331 Mdot
.848 .32354 Mdot
.848 .32358 Mdot
.848 .32363 Mdot
.848 .32477 Mdot
.848 .32588 Mdot
.848 .32594 Mdot
.848 .32657 Mdot
.848 .32698 Mdot
.848 .32747 Mdot
.848 .3285 Mdot
.848 .32903 Mdot
.848 .32978 Mdot
.848 .33009 Mdot
.848 .3307 Mdot
.848 .33079 Mdot
.848 .33083 Mdot
.848 .33148 Mdot
.848 .33177 Mdot
.848 .33192 Mdot
.848 .33196 Mdot
.848 .33232 Mdot
.848 .33237 Mdot
.848 .33265 Mdot
.848 .33287 Mdot
.848 .33303 Mdot
.848 .33347 Mdot
.848 .33377 Mdot
.848 .33383 Mdot
.848 .334 Mdot
.848 .33436 Mdot
.848 .33563 Mdot
.848 .33608 Mdot
.848 .33612 Mdot
.848 .33635 Mdot
.848 .33637 Mdot
.848 .33789 Mdot
.848 .33844 Mdot
.848 .33898 Mdot
.848 .33915 Mdot
.848 .33954 Mdot
.848 .34035 Mdot
.848 .34047 Mdot
.848 .34057 Mdot
.848 .34256 Mdot
.848 .3426 Mdot
.848 .34277 Mdot
.848 .34309 Mdot
.848 .34348 Mdot
.848 .34411 Mdot
.848 .3451 Mdot
.848 .34515 Mdot
.848 .34587 Mdot
.848 .34646 Mdot
.848 .3467 Mdot
.848 .34684 Mdot
.848 .34839 Mdot
.848 .34868 Mdot
.848 .34873 Mdot
.848 .34903 Mdot
.848 .35009 Mdot
.848 .35021 Mdot
.848 .35033 Mdot
.848 .35052 Mdot
.848 .35076 Mdot
.848 .35093 Mdot
.848 .35161 Mdot
.848 .35198 Mdot
.848 .35378 Mdot
.848 .35574 Mdot
.848 .35612 Mdot
.848 .35623 Mdot
.848 .35684 Mdot
.848 .35733 Mdot
.848 .35748 Mdot
.848 .35781 Mdot
.848 .35788 Mdot
.848 .35792 Mdot
.848 .35877 Mdot
.848 .36024 Mdot
.848 .36302 Mdot
.848 .3641 Mdot
.848 .36436 Mdot
.848 .36502 Mdot
.848 .36641 Mdot
.848 .36789 Mdot
.848 .36814 Mdot
.848 .36877 Mdot
.848 .36991 Mdot
.848 .37046 Mdot
.848 .37316 Mdot
.848 .37321 Mdot
.848 .37365 Mdot
.848 .37517 Mdot
.848 .37519 Mdot
.848 .37574 Mdot
.848 .37628 Mdot
.848 .37687 Mdot
.848 .37813 Mdot
.848 .37893 Mdot
.848 .37917 Mdot
.848 .37923 Mdot
.848 .38202 Mdot
.848 .38321 Mdot
.848 .38463 Mdot
.848 .3851 Mdot
.848 .38632 Mdot
.848 .38809 Mdot
.848 .38987 Mdot
.848 .39155 Mdot
.848 .39301 Mdot
.848 .39323 Mdot
.848 .39375 Mdot
.848 .39393 Mdot
.848 .39437 Mdot
.848 .39865 Mdot
.848 .39899 Mdot
.848 .39954 Mdot
.848 .40048 Mdot
.848 .40089 Mdot
.848 .40242 Mdot
.848 .40265 Mdot
.848 .40301 Mdot
.848 .40345 Mdot
.848 .4038 Mdot
.848 .40428 Mdot
.848 .40699 Mdot
.848 .40734 Mdot
.848 .40762 Mdot
.848 .40788 Mdot
.848 .4082 Mdot
.848 .40935 Mdot
.848 .41064 Mdot
.848 .41162 Mdot
.848 .41247 Mdot
.848 .41249 Mdot
.848 .41488 Mdot
.848 .41499 Mdot
.848 .41514 Mdot
.848 .41581 Mdot
.848 .41667 Mdot
.848 .41671 Mdot
.848 .41776 Mdot
.848 .41819 Mdot
.848 .41857 Mdot
.848 .41881 Mdot
.848 .421 Mdot
.848 .42106 Mdot
.848 .42134 Mdot
.848 .42221 Mdot
.848 .42332 Mdot
.848 .42365 Mdot
.848 .42437 Mdot
.848 .42707 Mdot
.848 .42827 Mdot
.848 .43218 Mdot
.848 .43267 Mdot
.848 .43318 Mdot
.848 .43407 Mdot
.848 .43501 Mdot
.848 .43503 Mdot
.848 .4361 Mdot
.848 .43674 Mdot
.848 .43809 Mdot
.848 .43959 Mdot
.848 .44141 Mdot
.848 .44238 Mdot
.848 .44465 Mdot
.848 .44526 Mdot
.848 .44554 Mdot
.848 .44689 Mdot
.848 .44838 Mdot
.848 .44868 Mdot
.848 .44951 Mdot
.848 .44961 Mdot
.848 .45015 Mdot
.848 .45166 Mdot
.848 .45417 Mdot
.848 .45553 Mdot
.848 .45588 Mdot
.848 .45619 Mdot
.848 .45651 Mdot
.848 .45689 Mdot
.848 .4581 Mdot
.848 .45874 Mdot
.848 .45908 Mdot
.848 .45987 Mdot
.848 .46116 Mdot
.848 .4623 Mdot
.848 .46365 Mdot
.848 .46377 Mdot
.848 .46399 Mdot
.848 .46412 Mdot
.848 .46476 Mdot
.848 .466 Mdot
.848 .46651 Mdot
.848 .46659 Mdot
.848 .46663 Mdot
.848 .46867 Mdot
.848 .46901 Mdot
.848 .46998 Mdot
.848 .47036 Mdot
.848 .47094 Mdot
.848 .47273 Mdot
.848 .47355 Mdot
.848 .47375 Mdot
.848 .47482 Mdot
.848 .47592 Mdot
.848 .47652 Mdot
.848 .47818 Mdot
.848 .47897 Mdot
.848 .48166 Mdot
.848 .48342 Mdot
.848 .48354 Mdot
.848 .48402 Mdot
.848 .48459 Mdot
.848 .48594 Mdot
.848 .48742 Mdot
.848 .48764 Mdot
.848 .48768 Mdot
.848 .48775 Mdot
.848 .489 Mdot
.848 .49027 Mdot
.848 .49042 Mdot
.848 .49084 Mdot
.848 .49186 Mdot
.848 .49251 Mdot
.848 .49254 Mdot
.848 .49734 Mdot
.848 .49745 Mdot
.848 .49769 Mdot
.848 .49786 Mdot
.848 .49865 Mdot
.848 .49961 Mdot
.848 .49988 Mdot
.848 .50005 Mdot
.848 .50095 Mdot
.848 .50169 Mdot
.848 .5024 Mdot
.848 .50253 Mdot
.848 .50372 Mdot
.848 .50714 Mdot
.848 .50734 Mdot
.848 .50854 Mdot
.848 .50926 Mdot
.848 .5117 Mdot
.848 .51241 Mdot
.848 .5125 Mdot
.848 .51269 Mdot
.848 .51274 Mdot
.848 .51275 Mdot
.848 .51412 Mdot
.848 .51577 Mdot
.85 .01498 Mdot
.85 .01517 Mdot
.85 .01525 Mdot
.85 .01525 Mdot
.85 .01549 Mdot
.85 .01562 Mdot
.85 .01563 Mdot
.85 .01604 Mdot
.85 .01606 Mdot
.85 .01622 Mdot
.85 .01625 Mdot
.85 .01627 Mdot
.85 .01694 Mdot
.85 .01697 Mdot
.85 .01699 Mdot
.85 .01727 Mdot
.85 .01733 Mdot
.85 .01736 Mdot
.85 .01842 Mdot
.85 .01849 Mdot
.85 .01851 Mdot
.85 .01854 Mdot
.85 .01859 Mdot
.85 .01873 Mdot
.85 .01883 Mdot
.85 .01891 Mdot
.85 .01906 Mdot
.85 .01915 Mdot
.85 .01921 Mdot
.85 .02082 Mdot
.85 .02101 Mdot
.85 .02113 Mdot
.85 .02116 Mdot
.85 .02123 Mdot
.85 .0213 Mdot
.85 .02153 Mdot
.85 .02172 Mdot
.85 .02184 Mdot
.85 .0221 Mdot
.85 .02226 Mdot
.85 .02235 Mdot
.85 .0249 Mdot
.85 .02509 Mdot
.85 .02541 Mdot
.85 .02563 Mdot
.85 .02568 Mdot
.85 .02578 Mdot
.85 .02592 Mdot
.85 .02631 Mdot
.85 .02649 Mdot
.85 .02662 Mdot
.85 .02666 Mdot
.85 .02683 Mdot
.85 .02728 Mdot
.85 .02742 Mdot
.85 .02749 Mdot
.85 .02755 Mdot
.85 .02769 Mdot
.85 .02806 Mdot
.85 .0301 Mdot
.85 .03011 Mdot
.85 .03049 Mdot
.85 .03084 Mdot
.85 .03202 Mdot
.85 .03229 Mdot
.85 .03236 Mdot
.85 .0329 Mdot
.85 .03326 Mdot
.85 .03327 Mdot
.85 .03335 Mdot
.85 .03338 Mdot
.85 .03353 Mdot
.85 .03376 Mdot
.85 .03442 Mdot
.85 .03472 Mdot
.85 .03473 Mdot
.85 .03475 Mdot
.85 .03495 Mdot
.85 .03503 Mdot
.85 .03513 Mdot
.85 .0353 Mdot
.85 .03569 Mdot
.85 .03607 Mdot
.85 .03618 Mdot
.85 .03631 Mdot
.85 .03643 Mdot
.85 .03653 Mdot
.85 .03702 Mdot
.85 .03739 Mdot
.85 .03857 Mdot
.85 .03916 Mdot
.85 .0405 Mdot
.85 .04087 Mdot
.85 .04089 Mdot
.85 .04093 Mdot
.85 .04152 Mdot
.85 .04153 Mdot
.85 .04185 Mdot
.85 .04192 Mdot
.85 .04213 Mdot
.85 .04304 Mdot
.85 .04367 Mdot
.85 .04414 Mdot
.85 .0446 Mdot
.85 .0447 Mdot
.85 .04563 Mdot
.85 .04625 Mdot
.85 .04626 Mdot
.85 .04639 Mdot
.85 .04645 Mdot
.85 .0467 Mdot
.85 .04708 Mdot
.85 .04732 Mdot
.85 .04822 Mdot
.85 .04845 Mdot
.85 .04873 Mdot
.85 .04874 Mdot
.85 .04878 Mdot
.85 .04912 Mdot
.85 .04918 Mdot
.85 .04924 Mdot
.85 .04941 Mdot
.85 .04971 Mdot
.85 .04976 Mdot
.85 .05021 Mdot
.85 .05038 Mdot
.85 .0504 Mdot
.85 .05055 Mdot
.85 .05102 Mdot
.85 .0512 Mdot
.85 .05143 Mdot
.85 .05163 Mdot
.85 .0518 Mdot
.85 .05259 Mdot
.85 .05263 Mdot
.85 .0531 Mdot
.85 .05327 Mdot
.85 .05352 Mdot
.85 .05457 Mdot
.85 .05501 Mdot
.85 .05516 Mdot
.85 .05527 Mdot
.85 .05536 Mdot
.85 .05627 Mdot
.85 .05708 Mdot
.85 .0579 Mdot
.85 .05856 Mdot
.85 .05911 Mdot
.85 .05917 Mdot
.85 .05921 Mdot
.85 .05927 Mdot
.85 .05948 Mdot
.85 .06029 Mdot
.85 .06031 Mdot
.85 .06084 Mdot
.85 .06096 Mdot
.85 .06133 Mdot
.85 .06153 Mdot
.85 .06208 Mdot
.85 .06286 Mdot
.85 .06301 Mdot
.85 .0638 Mdot
.85 .06394 Mdot
.85 .06473 Mdot
.85 .06551 Mdot
.85 .06552 Mdot
.85 .06569 Mdot
.85 .06727 Mdot
.85 .06832 Mdot
.85 .06835 Mdot
.85 .06857 Mdot
.85 .06867 Mdot
.85 .06907 Mdot
.85 .06909 Mdot
.85 .06918 Mdot
.85 .06974 Mdot
.85 .07014 Mdot
.85 .07167 Mdot
.85 .07171 Mdot
.85 .07195 Mdot
.85 .07207 Mdot
.85 .07253 Mdot
.85 .07255 Mdot
.85 .07263 Mdot
.85 .0732 Mdot
.85 .0733 Mdot
.85 .07341 Mdot
.85 .07345 Mdot
.85 .0737 Mdot
.85 .07421 Mdot
.85 .07429 Mdot
.85 .07437 Mdot
.85 .07506 Mdot
.85 .07516 Mdot
.85 .07534 Mdot
.85 .07535 Mdot
.85 .07538 Mdot
.85 .07563 Mdot
.85 .07612 Mdot
.85 .07643 Mdot
.85 .07674 Mdot
.85 .07679 Mdot
.85 .07713 Mdot
.85 .07747 Mdot
.85 .07775 Mdot
.85 .07799 Mdot
.85 .07909 Mdot
.85 .07915 Mdot
.85 .07917 Mdot
.85 .07919 Mdot
.85 .07974 Mdot
.85 .07997 Mdot
.85 .08026 Mdot
.85 .08068 Mdot
.85 .08141 Mdot
.85 .08233 Mdot
.85 .08247 Mdot
.85 .08299 Mdot
.85 .08321 Mdot
.85 .08348 Mdot
.85 .08365 Mdot
.85 .08381 Mdot
.85 .08412 Mdot
.85 .08535 Mdot
.85 .08635 Mdot
.85 .08674 Mdot
.85 .08781 Mdot
.85 .08813 Mdot
.85 .08914 Mdot
.85 .08925 Mdot
.85 .09018 Mdot
.85 .0903 Mdot
.85 .09036 Mdot
.85 .09046 Mdot
.85 .09081 Mdot
.85 .09171 Mdot
.85 .0922 Mdot
.85 .09222 Mdot
.85 .09265 Mdot
.85 .09312 Mdot
.85 .09324 Mdot
.85 .09334 Mdot
.85 .09366 Mdot
.85 .09366 Mdot
.85 .09396 Mdot
.85 .0943 Mdot
.85 .09523 Mdot
.85 .09547 Mdot
.85 .09556 Mdot
.85 .09628 Mdot
.85 .09657 Mdot
.85 .09681 Mdot
.85 .09751 Mdot
.85 .09816 Mdot
.85 .09839 Mdot
.85 .09839 Mdot
.85 .09898 Mdot
.85 .09974 Mdot
.85 .09986 Mdot
.85 .10085 Mdot
.85 .10107 Mdot
.85 .10108 Mdot
.85 .10138 Mdot
.85 .10203 Mdot
.85 .10299 Mdot
.85 .10357 Mdot
.85 .10406 Mdot
.85 .10553 Mdot
.85 .10584 Mdot
.85 .10589 Mdot
.85 .10627 Mdot
.85 .10644 Mdot
.85 .10684 Mdot
.85 .10712 Mdot
.85 .10715 Mdot
.85 .1073 Mdot
.85 .10826 Mdot
.85 .10846 Mdot
.85 .10894 Mdot
.85 .10937 Mdot
.85 .11032 Mdot
.85 .11034 Mdot
.85 .1106 Mdot
.85 .11154 Mdot
.85 .11161 Mdot
.85 .11171 Mdot
.85 .11202 Mdot
.85 .11221 Mdot
.85 .113 Mdot
.85 .11303 Mdot
.85 .11316 Mdot
.85 .1136 Mdot
.85 .11388 Mdot
.85 .11414 Mdot
.85 .11431 Mdot
.85 .1145 Mdot
.85 .11456 Mdot
.85 .11457 Mdot
.85 .115 Mdot
.85 .11586 Mdot
.85 .11599 Mdot
.85 .11613 Mdot
.85 .11652 Mdot
.85 .1173 Mdot
.85 .11748 Mdot
.85 .11778 Mdot
.85 .1178 Mdot
.85 .11784 Mdot
.85 .11827 Mdot
.85 .1191 Mdot
.85 .11961 Mdot
.85 .11963 Mdot
.85 .12016 Mdot
.85 .12024 Mdot
.85 .12083 Mdot
.85 .1214 Mdot
.85 .12188 Mdot
.85 .12228 Mdot
.85 .12256 Mdot
.85 .12389 Mdot
.85 .12404 Mdot
.85 .12416 Mdot
.85 .12425 Mdot
.85 .12429 Mdot
.85 .12432 Mdot
.85 .12523 Mdot
.85 .12526 Mdot
.85 .12565 Mdot
.85 .12614 Mdot
.85 .12686 Mdot
.85 .12809 Mdot
.85 .12966 Mdot
.85 .12991 Mdot
.85 .13079 Mdot
.85 .13115 Mdot
.85 .13161 Mdot
.85 .1319 Mdot
.85 .13217 Mdot
.85 .1327 Mdot
.85 .13363 Mdot
.85 .13456 Mdot
.85 .1348 Mdot
.85 .13649 Mdot
.85 .13715 Mdot
.85 .13838 Mdot
.85 .13898 Mdot
.85 .13928 Mdot
.85 .13952 Mdot
.85 .14123 Mdot
.85 .14142 Mdot
.85 .14238 Mdot
.85 .14301 Mdot
.85 .1432 Mdot
.85 .14331 Mdot
.85 .14332 Mdot
.85 .14349 Mdot
.85 .14376 Mdot
.85 .14385 Mdot
.85 .14388 Mdot
.85 .14398 Mdot
.85 .14408 Mdot
.85 .14472 Mdot
.85 .14547 Mdot
.85 .1456 Mdot
.85 .14604 Mdot
.85 .14643 Mdot
.85 .14648 Mdot
.85 .14652 Mdot
.85 .14662 Mdot
.85 .14713 Mdot
.85 .1472 Mdot
.85 .14761 Mdot
.85 .14801 Mdot
.85 .1482 Mdot
.85 .14837 Mdot
.85 .14892 Mdot
.85 .14892 Mdot
.85 .14943 Mdot
.85 .15001 Mdot
.85 .15079 Mdot
.85 .15126 Mdot
.85 .1516 Mdot
.85 .152 Mdot
.85 .15215 Mdot
.85 .15337 Mdot
.85 .15387 Mdot
.85 .15427 Mdot
.85 .15447 Mdot
.85 .1551 Mdot
.85 .15547 Mdot
.85 .15657 Mdot
.85 .15697 Mdot
.85 .15697 Mdot
.85 .15724 Mdot
.85 .15796 Mdot
.85 .15916 Mdot
.85 .15918 Mdot
.85 .15926 Mdot
.85 .15941 Mdot
.85 .15946 Mdot
.85 .1596 Mdot
.85 .16012 Mdot
.85 .16114 Mdot
.85 .16152 Mdot
.85 .16153 Mdot
.85 .16205 Mdot
.85 .1626 Mdot
.85 .16295 Mdot
.85 .16315 Mdot
.85 .1641 Mdot
.85 .16478 Mdot
.85 .16497 Mdot
.85 .16576 Mdot
.85 .1666 Mdot
.85 .16692 Mdot
.85 .16696 Mdot
.85 .16787 Mdot
.85 .1687 Mdot
.85 .16909 Mdot
.85 .16962 Mdot
.85 .16972 Mdot
.85 .17035 Mdot
.85 .17064 Mdot
.85 .17133 Mdot
.85 .17141 Mdot
.85 .17142 Mdot
.85 .17181 Mdot
.85 .17186 Mdot
.85 .17212 Mdot
.85 .17374 Mdot
.85 .17389 Mdot
.85 .17408 Mdot
.85 .1749 Mdot
.85 .17562 Mdot
.85 .17678 Mdot
.85 .17724 Mdot
.85 .17727 Mdot
.85 .17771 Mdot
.85 .17931 Mdot
.85 .17943 Mdot
.85 .17961 Mdot
.85 .17988 Mdot
.85 .18014 Mdot
.85 .18042 Mdot
.85 .18046 Mdot
.85 .1806 Mdot
.85 .18181 Mdot
.85 .18186 Mdot
.85 .18208 Mdot
.85 .18282 Mdot
.85 .18288 Mdot
.85 .18329 Mdot
.85 .18373 Mdot
.85 .18403 Mdot
.85 .18435 Mdot
.85 .18445 Mdot
.85 .18447 Mdot
.85 .18456 Mdot
.85 .185 Mdot
.85 .1852 Mdot
.85 .18654 Mdot
.85 .18666 Mdot
.85 .18689 Mdot
.85 .18712 Mdot
.85 .1873 Mdot
.85 .18778 Mdot
.85 .18911 Mdot
.85 .18941 Mdot
.85 .18993 Mdot
.85 .18996 Mdot
.85 .19003 Mdot
.85 .19007 Mdot
.85 .19076 Mdot
.85 .19217 Mdot
.85 .19278 Mdot
.85 .19304 Mdot
.85 .19306 Mdot
.85 .19326 Mdot
.85 .19397 Mdot
.85 .1941 Mdot
.85 .19511 Mdot
.85 .19571 Mdot
.85 .1959 Mdot
.85 .19607 Mdot
.85 .1969 Mdot
.85 .19757 Mdot
.85 .19771 Mdot
.85 .19806 Mdot
.85 .19866 Mdot
.85 .19993 Mdot
.85 .20032 Mdot
.85 .20057 Mdot
.85 .20077 Mdot
.85 .20093 Mdot
.85 .20099 Mdot
.85 .20104 Mdot
.85 .20175 Mdot
.85 .20259 Mdot
.85 .20264 Mdot
.85 .2033 Mdot
.85 .20359 Mdot
.85 .20401 Mdot
.85 .20413 Mdot
.85 .20535 Mdot
.85 .20745 Mdot
.85 .20897 Mdot
.85 .21012 Mdot
.85 .21054 Mdot
.85 .21094 Mdot
.85 .21095 Mdot
.85 .21204 Mdot
.85 .21227 Mdot
.85 .21266 Mdot
.85 .21343 Mdot
.85 .21394 Mdot
.85 .2144 Mdot
.85 .21529 Mdot
.85 .21581 Mdot
.85 .21596 Mdot
.85 .21687 Mdot
.85 .2176 Mdot
.85 .21845 Mdot
.85 .21886 Mdot
.85 .21939 Mdot
.85 .22052 Mdot
.85 .22108 Mdot
.85 .2214 Mdot
.85 .22173 Mdot
.85 .22173 Mdot
.85 .22182 Mdot
.85 .22221 Mdot
.85 .22286 Mdot
.85 .22296 Mdot
.85 .2232 Mdot
.85 .22387 Mdot
.85 .22494 Mdot
.85 .22596 Mdot
.85 .22642 Mdot
.85 .22647 Mdot
.85 .22688 Mdot
.85 .22979 Mdot
.85 .23011 Mdot
.85 .23144 Mdot
.85 .23175 Mdot
.85 .23282 Mdot
.85 .23314 Mdot
.85 .2333 Mdot
.85 .23333 Mdot
.85 .23334 Mdot
.85 .23337 Mdot
.85 .23363 Mdot
.85 .23389 Mdot
.85 .23408 Mdot
.85 .23425 Mdot
.85 .23429 Mdot
.85 .23446 Mdot
.85 .23463 Mdot
.85 .23573 Mdot
.85 .23589 Mdot
.85 .237 Mdot
.85 .23722 Mdot
.85 .23796 Mdot
.85 .23863 Mdot
.85 .23863 Mdot
.85 .23871 Mdot
.85 .23878 Mdot
.85 .23896 Mdot
.85 .23982 Mdot
.85 .23994 Mdot
.85 .24034 Mdot
.85 .24064 Mdot
.85 .24131 Mdot
.85 .24133 Mdot
.85 .24164 Mdot
.85 .24193 Mdot
.85 .24287 Mdot
.85 .24287 Mdot
.85 .24372 Mdot
.85 .24472 Mdot
.85 .2458 Mdot
.85 .24598 Mdot
.85 .24605 Mdot
.85 .24683 Mdot
.85 .24742 Mdot
.85 .24757 Mdot
.85 .2481 Mdot
.85 .24836 Mdot
.85 .24932 Mdot
.85 .25026 Mdot
.85 .25043 Mdot
.85 .25127 Mdot
.85 .25134 Mdot
.85 .25197 Mdot
.85 .2523 Mdot
.85 .25336 Mdot
.85 .254 Mdot
.85 .25414 Mdot
.85 .25586 Mdot
.85 .25654 Mdot
.85 .25655 Mdot
.85 .257 Mdot
.85 .25823 Mdot
.85 .25828 Mdot
.85 .25885 Mdot
.85 .25947 Mdot
.85 .25986 Mdot
.85 .26005 Mdot
.85 .26016 Mdot
.85 .26028 Mdot
.85 .26031 Mdot
.85 .26044 Mdot
.85 .2607 Mdot
.85 .26078 Mdot
.85 .26102 Mdot
.85 .2619 Mdot
.85 .26363 Mdot
.85 .26428 Mdot
.85 .26431 Mdot
.85 .26448 Mdot
.85 .26518 Mdot
.85 .26612 Mdot
.85 .26671 Mdot
.85 .26706 Mdot
.85 .2686 Mdot
.85 .26867 Mdot
.85 .26922 Mdot
.85 .26982 Mdot
.85 .27015 Mdot
.85 .27052 Mdot
.85 .27149 Mdot
.85 .27292 Mdot
.85 .27312 Mdot
.85 .27333 Mdot
.85 .27347 Mdot
.85 .27354 Mdot
.85 .27357 Mdot
.85 .27507 Mdot
.85 .2765 Mdot
.85 .27671 Mdot
.85 .27716 Mdot
.85 .27806 Mdot
.85 .27813 Mdot
.85 .27822 Mdot
.85 .2793 Mdot
.85 .27979 Mdot
.85 .28096 Mdot
.85 .2811 Mdot
.85 .28111 Mdot
.85 .28151 Mdot
.85 .28178 Mdot
.85 .28186 Mdot
.85 .28192 Mdot
.85 .28194 Mdot
.85 .2823 Mdot
.85 .2831 Mdot
.85 .28387 Mdot
.85 .28412 Mdot
.85 .28427 Mdot
.85 .28434 Mdot
.85 .28506 Mdot
.85 .28531 Mdot
.85 .28537 Mdot
.85 .28564 Mdot
.85 .28704 Mdot
.85 .28769 Mdot
.85 .28826 Mdot
.85 .28992 Mdot
.85 .29023 Mdot
.85 .29063 Mdot
.85 .29101 Mdot
.85 .29107 Mdot
.85 .29107 Mdot
.85 .29126 Mdot
.85 .29181 Mdot
.85 .29335 Mdot
.85 .29409 Mdot
.85 .29424 Mdot
.85 .29453 Mdot
.85 .29473 Mdot
.85 .29503 Mdot
.85 .29504 Mdot
.85 .2955 Mdot
.85 .29593 Mdot
.85 .29642 Mdot
.85 .29648 Mdot
.85 .29672 Mdot
.85 .29877 Mdot
.85 .29885 Mdot
.85 .29907 Mdot
.85 .29923 Mdot
.85 .30049 Mdot
.85 .3006 Mdot
.85 .30095 Mdot
.85 .3013 Mdot
.85 .30204 Mdot
.85 .30256 Mdot
.85 .30261 Mdot
.85 .3031 Mdot
.85 .30326 Mdot
.85 .3033 Mdot
.85 .30345 Mdot
.85 .30419 Mdot
.85 .30453 Mdot
.85 .30682 Mdot
.85 .30703 Mdot
.85 .30739 Mdot
.85 .30741 Mdot
.85 .30781 Mdot
.85 .30811 Mdot
.85 .30829 Mdot
.85 .30892 Mdot
.85 .30944 Mdot
.85 .31055 Mdot
.85 .31071 Mdot
.85 .31071 Mdot
.85 .31118 Mdot
.85 .31128 Mdot
.85 .3117 Mdot
.85 .31257 Mdot
.85 .31263 Mdot
.85 .31276 Mdot
.85 .31282 Mdot
.85 .31286 Mdot
.85 .31399 Mdot
.85 .31638 Mdot
.85 .31732 Mdot
.85 .31742 Mdot
.85 .31787 Mdot
.85 .31791 Mdot
.85 .31824 Mdot
.85 .31945 Mdot
.85 .31945 Mdot
.85 .31967 Mdot
.85 .31988 Mdot
.85 .32074 Mdot
.85 .32131 Mdot
.85 .32138 Mdot
.85 .32216 Mdot
.85 .32218 Mdot
.85 .3224 Mdot
.85 .32274 Mdot
.85 .32302 Mdot
.85 .32352 Mdot
.85 .32443 Mdot
.85 .32477 Mdot
.85 .32557 Mdot
.85 .32581 Mdot
.85 .32617 Mdot
.85 .32636 Mdot
.85 .3264 Mdot
.85 .32706 Mdot
.85 .32743 Mdot
.85 .32958 Mdot
.85 .33024 Mdot
.85 .33067 Mdot
.85 .33101 Mdot
.85 .33128 Mdot
.85 .33139 Mdot
.85 .33147 Mdot
.85 .33267 Mdot
.85 .33298 Mdot
.85 .33322 Mdot
.85 .33384 Mdot
.85 .3341 Mdot
.85 .33419 Mdot
.85 .3343 Mdot
.85 .33532 Mdot
.85 .3358 Mdot
.85 .33651 Mdot
.85 .33673 Mdot
.85 .33794 Mdot
.85 .33826 Mdot
.85 .3388 Mdot
.85 .33927 Mdot
.85 .34028 Mdot
.85 .34237 Mdot
.85 .34243 Mdot
.85 .34392 Mdot
.85 .34407 Mdot
.85 .34494 Mdot
.85 .34549 Mdot
.85 .34595 Mdot
.85 .34607 Mdot
.85 .34652 Mdot
.85 .34691 Mdot
.85 .34761 Mdot
.85 .3483 Mdot
.85 .34832 Mdot
.85 .34865 Mdot
.85 .34963 Mdot
.85 .35017 Mdot
.85 .35056 Mdot
.85 .35122 Mdot
.85 .35253 Mdot
.85 .35339 Mdot
.85 .35417 Mdot
.85 .35569 Mdot
.85 .35624 Mdot
.85 .35658 Mdot
.85 .35683 Mdot
.85 .35683 Mdot
.85 .3579 Mdot
.85 .35795 Mdot
.85 .35837 Mdot
.85 .3591 Mdot
.85 .35962 Mdot
.85 .35996 Mdot
.85 .36048 Mdot
.85 .36106 Mdot
.85 .36176 Mdot
.85 .36232 Mdot
.85 .36266 Mdot
.85 .36381 Mdot
.85 .36459 Mdot
.85 .36554 Mdot
.85 .36607 Mdot
.85 .36663 Mdot
.85 .36664 Mdot
.85 .3668 Mdot
.85 .36745 Mdot
.85 .36856 Mdot
.85 .36873 Mdot
.85 .36914 Mdot
.85 .37028 Mdot
.85 .3721 Mdot
.85 .37384 Mdot
.85 .37462 Mdot
.85 .37471 Mdot
.85 .3754 Mdot
.85 .38034 Mdot
.85 .38089 Mdot
.85 .38314 Mdot
.85 .38367 Mdot
.85 .38549 Mdot
.85 .38604 Mdot
.85 .3863 Mdot
.85 .38636 Mdot
.85 .38637 Mdot
.85 .38643 Mdot
.85 .38687 Mdot
.85 .38731 Mdot
.85 .38764 Mdot
.85 .38793 Mdot
.85 .38799 Mdot
.85 .38829 Mdot
.85 .38857 Mdot
.85 .39044 Mdot
.85 .39071 Mdot
.85 .3926 Mdot
.85 .39297 Mdot
.85 .39423 Mdot
.85 .39537 Mdot
.85 .39538 Mdot
.85 .39551 Mdot
.85 .39562 Mdot
.85 .39593 Mdot
.85 .39739 Mdot
.85 .39759 Mdot
.85 .39827 Mdot
.85 .39878 Mdot
.85 .39993 Mdot
.85 .39995 Mdot
.85 .40048 Mdot
.85 .40098 Mdot
.85 .40257 Mdot
.85 .40257 Mdot
.85 .40403 Mdot
.85 .40573 Mdot
.85 .40755 Mdot
.85 .40787 Mdot
.85 .40798 Mdot
.85 .40932 Mdot
.85 .41031 Mdot
.85 .41056 Mdot
.85 .41147 Mdot
.85 .41192 Mdot
.85 .41355 Mdot
.85 .41514 Mdot
.85 .41542 Mdot
.85 .41686 Mdot
.85 .41698 Mdot
.85 .41804 Mdot
.85 .4186 Mdot
.85 .42042 Mdot
.85 .4215 Mdot
.85 .42174 Mdot
.85 .42466 Mdot
.85 .42582 Mdot
.85 .42583 Mdot
.85 .42661 Mdot
.85 .42869 Mdot
.85 .42878 Mdot
.85 .42974 Mdot
.85 .43079 Mdot
.85 .43146 Mdot
.85 .43179 Mdot
.85 .43197 Mdot
.85 .43217 Mdot
.85 .43222 Mdot
.85 .43245 Mdot
.85 .43289 Mdot
.85 .43303 Mdot
.85 .43343 Mdot
.85 .43493 Mdot
.85 .43788 Mdot
.85 .43897 Mdot
.85 .43902 Mdot
.85 .43932 Mdot
.85 .4405 Mdot
.85 .44211 Mdot
.85 .44311 Mdot
.85 .4437 Mdot
.85 .44633 Mdot
.85 .44644 Mdot
.85 .44737 Mdot
.85 .4484 Mdot
.85 .44895 Mdot
.85 .44959 Mdot
.85 .45124 Mdot
.85 .45367 Mdot
.85 .454 Mdot
.85 .45437 Mdot
.85 .4546 Mdot
.85 .45471 Mdot
.85 .45478 Mdot
.85 .45732 Mdot
.85 .45974 Mdot
.85 .4601 Mdot
.85 .46087 Mdot
.85 .4624 Mdot
.85 .46253 Mdot
.85 .46267 Mdot
.85 .46451 Mdot
.85 .46535 Mdot
.85 .46734 Mdot
.85 .46757 Mdot
.85 .46759 Mdot
.85 .46827 Mdot
.85 .46872 Mdot
.85 .46887 Mdot
.85 .46896 Mdot
.85 .469 Mdot
.85 .4696 Mdot
.85 .47097 Mdot
.85 .47228 Mdot
.85 .4727 Mdot
.85 .47296 Mdot
.85 .47307 Mdot
.85 .4743 Mdot
.85 .47473 Mdot
.85 .47482 Mdot
.85 .47529 Mdot
.85 .47766 Mdot
.85 .47877 Mdot
.85 .47974 Mdot
.85 .48256 Mdot
.85 .48309 Mdot
.85 .48376 Mdot
.85 .48442 Mdot
.85 .48451 Mdot
.85 .48451 Mdot
.85 .48485 Mdot
.85 .48578 Mdot
.85 .4884 Mdot
.85 .48965 Mdot
.85 .48991 Mdot
.85 .49041 Mdot
.85 .49075 Mdot
.85 .49125 Mdot
.85 .49126 Mdot
.85 .49204 Mdot
.85 .49278 Mdot
.85 .49361 Mdot
.85 .49371 Mdot
.85 .49413 Mdot
.85 .49761 Mdot
.85 .49775 Mdot
.85 .49812 Mdot
.85 .49839 Mdot
.85 .50053 Mdot
.85 .50072 Mdot
.85 .50131 Mdot
.85 .5019 Mdot
.85 .50317 Mdot
.85 .50405 Mdot
.85 .50413 Mdot
.85 .50497 Mdot
.85 .50524 Mdot
.85 .50531 Mdot
.85 .50557 Mdot
.85 .50683 Mdot
.85 .5074 Mdot
.85 .51129 Mdot
.85 .51164 Mdot
.85 .51227 Mdot
.85 .5123 Mdot
.85 .51298 Mdot
.85 .51348 Mdot
.85 .51379 Mdot
.85 .51487 Mdot
.85 .51575 Mdot
.852 .01507 Mdot
.852 .01532 Mdot
.852 .01539 Mdot
.852 .01574 Mdot
.852 .01586 Mdot
.852 .01646 Mdot
.852 .01667 Mdot
.852 .01769 Mdot
.852 .01805 Mdot
.852 .01884 Mdot
.852 .0191 Mdot
.852 .01979 Mdot
.852 .02018 Mdot
.852 .0204 Mdot
.852 .02096 Mdot
.852 .0216 Mdot
.852 .02169 Mdot
.852 .02174 Mdot
.852 .0222 Mdot
.852 .02221 Mdot
.852 .02269 Mdot
.852 .02319 Mdot
.852 .02336 Mdot
.852 .02403 Mdot
.852 .0244 Mdot
.852 .02535 Mdot
.852 .02536 Mdot
.852 .02645 Mdot
.852 .02661 Mdot
.852 .02666 Mdot
.852 .02669 Mdot
.852 .02746 Mdot
.852 .02748 Mdot
.852 .02822 Mdot
.852 .0283 Mdot
.852 .02856 Mdot
.852 .02916 Mdot
.852 .02919 Mdot
.852 .02945 Mdot
.852 .02953 Mdot
.852 .03044 Mdot
.852 .03059 Mdot
.852 .03096 Mdot
.852 .03104 Mdot
.852 .03122 Mdot
.852 .03156 Mdot
.852 .03284 Mdot
.852 .03285 Mdot
.852 .03319 Mdot
.852 .03376 Mdot
.852 .03411 Mdot
.852 .03472 Mdot
.852 .03498 Mdot
.852 .03507 Mdot
.852 .03513 Mdot
.852 .03532 Mdot
.852 .03644 Mdot
.852 .03647 Mdot
.852 .03699 Mdot
.852 .03774 Mdot
.852 .03787 Mdot
.852 .0383 Mdot
.852 .03918 Mdot
.852 .03933 Mdot
.852 .03938 Mdot
.852 .03951 Mdot
.852 .03983 Mdot
.852 .03996 Mdot
.852 .04075 Mdot
.852 .04126 Mdot
.852 .0413 Mdot
.852 .0415 Mdot
.852 .04177 Mdot
.852 .04199 Mdot
.852 .04239 Mdot
.852 .04253 Mdot
.852 .04259 Mdot
.852 .04284 Mdot
.852 .04333 Mdot
.852 .04341 Mdot
.852 .04559 Mdot
.852 .04562 Mdot
.852 .04581 Mdot
.852 .04619 Mdot
.852 .0467 Mdot
.852 .04696 Mdot
.852 .04706 Mdot
.852 .04717 Mdot
.852 .04776 Mdot
.852 .04848 Mdot
.852 .0488 Mdot
.852 .04924 Mdot
.852 .04941 Mdot
.852 .04949 Mdot
.852 .04983 Mdot
.852 .05017 Mdot
.852 .05075 Mdot
.852 .05173 Mdot
.852 .05178 Mdot
.852 .05225 Mdot
.852 .05267 Mdot
.852 .05273 Mdot
.852 .05394 Mdot
.852 .05416 Mdot
.852 .0549 Mdot
.852 .05502 Mdot
.852 .05619 Mdot
.852 .05641 Mdot
.852 .05666 Mdot
.852 .05674 Mdot
.852 .05697 Mdot
.852 .05699 Mdot
.852 .05726 Mdot
.852 .05751 Mdot
.852 .05773 Mdot
.852 .05855 Mdot
.852 .05909 Mdot
.852 .05951 Mdot
.852 .05965 Mdot
.852 .05994 Mdot
.852 .06001 Mdot
.852 .06029 Mdot
.852 .06036 Mdot
.852 .0607 Mdot
.852 .06082 Mdot
.852 .06119 Mdot
.852 .06135 Mdot
.852 .06165 Mdot
.852 .06187 Mdot
.852 .06212 Mdot
.852 .06221 Mdot
.852 .06233 Mdot
.852 .06264 Mdot
.852 .06264 Mdot
.852 .06347 Mdot
.852 .06361 Mdot
.852 .06366 Mdot
.852 .0653 Mdot
.852 .06733 Mdot
.852 .06737 Mdot
.852 .0677 Mdot
.852 .06806 Mdot
.852 .06835 Mdot
.852 .06921 Mdot
.852 .06966 Mdot
.852 .06984 Mdot
.852 .07002 Mdot
.852 .07017 Mdot
.852 .07103 Mdot
.852 .07225 Mdot
.852 .07279 Mdot
.852 .07283 Mdot
.852 .07355 Mdot
.852 .07382 Mdot
.852 .07383 Mdot
.852 .07398 Mdot
.852 .07412 Mdot
.852 .07435 Mdot
.852 .07441 Mdot
.852 .07456 Mdot
.852 .07496 Mdot
.852 .07512 Mdot
.852 .07522 Mdot
.852 .07612 Mdot
.852 .07692 Mdot
.852 .07756 Mdot
.852 .07762 Mdot
.852 .07763 Mdot
.852 .07778 Mdot
.852 .07787 Mdot
.852 .07868 Mdot
.852 .07939 Mdot
.852 .07949 Mdot
.852 .07967 Mdot
.852 .08149 Mdot
.852 .08156 Mdot
.852 .08185 Mdot
.852 .08194 Mdot
.852 .08282 Mdot
.852 .08319 Mdot
.852 .0834 Mdot
.852 .08362 Mdot
.852 .08438 Mdot
.852 .08479 Mdot
.852 .08508 Mdot
.852 .08538 Mdot
.852 .08576 Mdot
.852 .08618 Mdot
.852 .08633 Mdot
.852 .08672 Mdot
.852 .08676 Mdot
.852 .08721 Mdot
.852 .08763 Mdot
.852 .08765 Mdot
.852 .08768 Mdot
.852 .088 Mdot
.852 .08821 Mdot
.852 .08892 Mdot
.852 .08915 Mdot
.852 .0894 Mdot
.852 .08944 Mdot
.852 .08982 Mdot
.852 .08996 Mdot
.852 .09032 Mdot
.852 .09056 Mdot
.852 .09105 Mdot
.852 .09129 Mdot
.852 .09178 Mdot
.852 .09179 Mdot
.852 .0919 Mdot
.852 .09191 Mdot
.852 .09237 Mdot
.852 .0925 Mdot
.852 .09266 Mdot
.852 .09307 Mdot
.852 .09328 Mdot
.852 .09391 Mdot
.852 .09418 Mdot
.852 .09446 Mdot
.852 .09469 Mdot
.852 .09507 Mdot
.852 .09549 Mdot
.852 .09565 Mdot
.852 .09585 Mdot
.852 .09637 Mdot
.852 .09638 Mdot
.852 .0978 Mdot
.852 .09804 Mdot
.852 .09812 Mdot
.852 .09821 Mdot
.852 .09896 Mdot
.852 .09922 Mdot
.852 .0995 Mdot
.852 .10091 Mdot
.852 .101 Mdot
.852 .10144 Mdot
.852 .10169 Mdot
.852 .10224 Mdot
.852 .1031 Mdot
.852 .10414 Mdot
.852 .10437 Mdot
.852 .10444 Mdot
.852 .105 Mdot
.852 .10562 Mdot
.852 .10611 Mdot
.852 .10667 Mdot
.852 .10669 Mdot
.852 .10749 Mdot
.852 .10758 Mdot
.852 .10767 Mdot
.852 .10835 Mdot
.852 .10864 Mdot
.852 .10895 Mdot
.852 .10921 Mdot
.852 .10985 Mdot
.852 .11038 Mdot
.852 .11068 Mdot
.852 .11216 Mdot
.852 .11275 Mdot
.852 .11326 Mdot
.852 .11341 Mdot
.852 .11368 Mdot
.852 .1137 Mdot
.852 .11374 Mdot
.852 .11462 Mdot
.852 .11497 Mdot
.852 .11543 Mdot
.852 .11545 Mdot
.852 .1157 Mdot
.852 .11595 Mdot
.852 .11633 Mdot
.852 .11644 Mdot
.852 .11668 Mdot
.852 .11738 Mdot
.852 .11765 Mdot
.852 .11781 Mdot
.852 .11796 Mdot
.852 .11816 Mdot
.852 .11826 Mdot
.852 .11934 Mdot
.852 .11985 Mdot
.852 .12071 Mdot
.852 .12181 Mdot
.852 .12191 Mdot
.852 .12192 Mdot
.852 .12206 Mdot
.852 .12218 Mdot
.852 .12233 Mdot
.852 .12301 Mdot
.852 .12337 Mdot
.852 .12371 Mdot
.852 .12383 Mdot
.852 .12493 Mdot
.852 .12509 Mdot
.852 .12515 Mdot
.852 .12541 Mdot
.852 .12563 Mdot
.852 .12576 Mdot
.852 .12603 Mdot
.852 .12849 Mdot
.852 .12861 Mdot
.852 .12878 Mdot
.852 .12912 Mdot
.852 .12926 Mdot
.852 .12926 Mdot
.852 .13004 Mdot
.852 .13047 Mdot
.852 .13077 Mdot
.852 .1314 Mdot
.852 .13176 Mdot
.852 .13212 Mdot
.852 .13342 Mdot
.852 .13357 Mdot
.852 .13413 Mdot
.852 .13462 Mdot
.852 .13513 Mdot
.852 .1353 Mdot
.852 .13578 Mdot
.852 .13646 Mdot
.852 .13649 Mdot
.852 .13674 Mdot
.852 .13741 Mdot
.852 .13745 Mdot
.852 .13747 Mdot
.852 .13824 Mdot
.852 .13843 Mdot
.852 .1386 Mdot
.852 .13896 Mdot
.852 .13899 Mdot
.852 .13905 Mdot
.852 .1396 Mdot
.852 .13986 Mdot
.852 .13994 Mdot
.852 .14057 Mdot
.852 .14092 Mdot
.852 .14115 Mdot
.852 .14155 Mdot
.852 .14159 Mdot
.852 .14198 Mdot
.852 .14205 Mdot
.852 .14269 Mdot
.852 .14293 Mdot
.852 .14355 Mdot
.852 .14368 Mdot
.852 .14396 Mdot
.852 .14404 Mdot
.852 .14478 Mdot
.852 .14491 Mdot
.852 .1452 Mdot
.852 .14527 Mdot
.852 .14603 Mdot
.852 .14605 Mdot
.852 .14625 Mdot
.852 .14625 Mdot
.852 .14704 Mdot
.852 .14726 Mdot
.852 .14754 Mdot
.852 .14823 Mdot
.852 .14834 Mdot
.852 .14858 Mdot
.852 .14895 Mdot
.852 .14966 Mdot
.852 .15012 Mdot
.852 .15036 Mdot
.852 .1506 Mdot
.852 .15076 Mdot
.852 .15099 Mdot
.852 .15164 Mdot
.852 .15236 Mdot
.852 .15263 Mdot
.852 .15297 Mdot
.852 .15386 Mdot
.852 .15387 Mdot
.852 .15442 Mdot
.852 .15503 Mdot
.852 .15629 Mdot
.852 .1565 Mdot
.852 .1567 Mdot
.852 .15678 Mdot
.852 .15682 Mdot
.852 .15685 Mdot
.852 .15699 Mdot
.852 .15809 Mdot
.852 .15828 Mdot
.852 .1587 Mdot
.852 .15894 Mdot
.852 .15918 Mdot
.852 .1593 Mdot
.852 .16016 Mdot
.852 .16059 Mdot
.852 .16068 Mdot
.852 .1616 Mdot
.852 .16166 Mdot
.852 .16168 Mdot
.852 .16174 Mdot
.852 .1625 Mdot
.852 .16293 Mdot
.852 .16386 Mdot
.852 .16533 Mdot
.852 .16561 Mdot
.852 .1667 Mdot
.852 .1671 Mdot
.852 .16749 Mdot
.852 .16761 Mdot
.852 .16806 Mdot
.852 .16857 Mdot
.852 .16961 Mdot
.852 .17045 Mdot
.852 .17101 Mdot
.852 .17141 Mdot
.852 .17144 Mdot
.852 .17145 Mdot
.852 .17202 Mdot
.852 .1728 Mdot
.852 .17289 Mdot
.852 .17295 Mdot
.852 .17311 Mdot
.852 .17321 Mdot
.852 .17427 Mdot
.852 .17477 Mdot
.852 .17504 Mdot
.852 .1753 Mdot
.852 .17574 Mdot
.852 .17683 Mdot
.852 .1772 Mdot
.852 .17772 Mdot
.852 .17791 Mdot
.852 .17823 Mdot
.852 .17857 Mdot
.852 .18076 Mdot
.852 .18082 Mdot
.852 .18176 Mdot
.852 .18199 Mdot
.852 .18264 Mdot
.852 .18289 Mdot
.852 .1832 Mdot
.852 .18335 Mdot
.852 .18338 Mdot
.852 .18345 Mdot
.852 .18401 Mdot
.852 .18496 Mdot
.852 .18514 Mdot
.852 .18555 Mdot
.852 .18633 Mdot
.852 .18636 Mdot
.852 .18679 Mdot
.852 .18722 Mdot
.852 .18787 Mdot
.852 .18805 Mdot
.852 .18836 Mdot
.852 .18847 Mdot
.852 .18966 Mdot
.852 .19012 Mdot
.852 .19039 Mdot
.852 .19061 Mdot
.852 .19064 Mdot
.852 .19098 Mdot
.852 .19116 Mdot
.852 .1919 Mdot
.852 .193 Mdot
.852 .19322 Mdot
.852 .19386 Mdot
.852 .19492 Mdot
.852 .19533 Mdot
.852 .19666 Mdot
.852 .1972 Mdot
.852 .19738 Mdot
.852 .19739 Mdot
.852 .19763 Mdot
.852 .19784 Mdot
.852 .19809 Mdot
.852 .19925 Mdot
.852 .19934 Mdot
.852 .19938 Mdot
.852 .19986 Mdot
.852 .20045 Mdot
.852 .20065 Mdot
.852 .20212 Mdot
.852 .20252 Mdot
.852 .2028 Mdot
.852 .20289 Mdot
.852 .20333 Mdot
.852 .20371 Mdot
.852 .20393 Mdot
.852 .2044 Mdot
.852 .20509 Mdot
.852 .20859 Mdot
.852 .2088 Mdot
.852 .20907 Mdot
.852 .20966 Mdot
.852 .2099 Mdot
.852 .2099 Mdot
.852 .21123 Mdot
.852 .21136 Mdot
.852 .21169 Mdot
.852 .21197 Mdot
.852 .21237 Mdot
.852 .21247 Mdot
.852 .21337 Mdot
.852 .21355 Mdot
.852 .21379 Mdot
.852 .21397 Mdot
.852 .2141 Mdot
.852 .21415 Mdot
.852 .21478 Mdot
.852 .21482 Mdot
.852 .2157 Mdot
.852 .21699 Mdot
.852 .21725 Mdot
.852 .21795 Mdot
.852 .21819 Mdot
.852 .21904 Mdot
.852 .21991 Mdot
.852 .22019 Mdot
.852 .22025 Mdot
.852 .221 Mdot
.852 .22118 Mdot
.852 .22218 Mdot
.852 .22223 Mdot
.852 .22264 Mdot
.852 .2233 Mdot
.852 .22379 Mdot
.852 .22386 Mdot
.852 .2239 Mdot
.852 .22444 Mdot
.852 .22521 Mdot
.852 .22553 Mdot
.852 .22566 Mdot
.852 .22582 Mdot
.852 .22627 Mdot
.852 .22644 Mdot
.852 .22648 Mdot
.852 .22657 Mdot
.852 .22752 Mdot
.852 .22769 Mdot
.852 .22796 Mdot
.852 .2281 Mdot
.852 .22917 Mdot
.852 .22977 Mdot
.852 .23017 Mdot
.852 .23051 Mdot
.852 .23085 Mdot
.852 .2309 Mdot
.852 .23134 Mdot
.852 .23158 Mdot
.852 .2317 Mdot
.852 .23193 Mdot
.852 .23265 Mdot
.852 .23278 Mdot
.852 .23307 Mdot
.852 .2332 Mdot
.852 .23426 Mdot
.852 .23447 Mdot
.852 .23495 Mdot
.852 .23509 Mdot
.852 .23635 Mdot
.852 .23656 Mdot
.852 .23707 Mdot
.852 .23716 Mdot
.852 .23718 Mdot
.852 .23761 Mdot
.852 .23791 Mdot
.852 .23803 Mdot
.852 .23833 Mdot
.852 .23848 Mdot
.852 .23851 Mdot
.852 .23884 Mdot
.852 .23885 Mdot
.852 .2402 Mdot
.852 .24058 Mdot
.852 .24105 Mdot
.852 .24206 Mdot
.852 .24222 Mdot
.852 .24241 Mdot
.852 .24271 Mdot
.852 .24282 Mdot
.852 .24345 Mdot
.852 .2442 Mdot
.852 .24444 Mdot
.852 .24467 Mdot
.852 .24544 Mdot
.852 .24585 Mdot
.852 .24626 Mdot
.852 .24654 Mdot
.852 .24693 Mdot
.852 .24804 Mdot
.852 .24881 Mdot
.852 .24926 Mdot
.852 .24971 Mdot
.852 .2503 Mdot
.852 .2509 Mdot
.852 .25182 Mdot
.852 .25183 Mdot
.852 .25278 Mdot
.852 .2538 Mdot
.852 .25596 Mdot
.852 .25608 Mdot
.852 .25631 Mdot
.852 .25665 Mdot
.852 .2568 Mdot
.852 .25686 Mdot
.852 .25691 Mdot
.852 .25715 Mdot
.852 .25746 Mdot
.852 .25823 Mdot
.852 .25902 Mdot
.852 .25934 Mdot
.852 .26007 Mdot
.852 .26047 Mdot
.852 .26089 Mdot
.852 .2611 Mdot
.852 .26158 Mdot
.852 .26256 Mdot
.852 .26284 Mdot
.852 .26329 Mdot
.852 .26344 Mdot
.852 .26485 Mdot
.852 .265 Mdot
.852 .2651 Mdot
.852 .26515 Mdot
.852 .26525 Mdot
.852 .26654 Mdot
.852 .26676 Mdot
.852 .26727 Mdot
.852 .26735 Mdot
.852 .26886 Mdot
.852 .26958 Mdot
.852 .27136 Mdot
.852 .27184 Mdot
.852 .2721 Mdot
.852 .27326 Mdot
.852 .27369 Mdot
.852 .27438 Mdot
.852 .27504 Mdot
.852 .27525 Mdot
.852 .27601 Mdot
.852 .27688 Mdot
.852 .27728 Mdot
.852 .27866 Mdot
.852 .28008 Mdot
.852 .28103 Mdot
.852 .2814 Mdot
.852 .28173 Mdot
.852 .28178 Mdot
.852 .2818 Mdot
.852 .28276 Mdot
.852 .2841 Mdot
.852 .28416 Mdot
.852 .28424 Mdot
.852 .28435 Mdot
.852 .28462 Mdot
.852 .28479 Mdot
.852 .28523 Mdot
.852 .28619 Mdot
.852 .28631 Mdot
.852 .28638 Mdot
.852 .28659 Mdot
.852 .28744 Mdot
.852 .28792 Mdot
.852 .28835 Mdot
.852 .2891 Mdot
.852 .28916 Mdot
.852 .29096 Mdot
.852 .29158 Mdot
.852 .29248 Mdot
.852 .2928 Mdot
.852 .29306 Mdot
.852 .29325 Mdot
.852 .29335 Mdot
.852 .29347 Mdot
.852 .2938 Mdot
.852 .29392 Mdot
.852 .29457 Mdot
.852 .29508 Mdot
.852 .29635 Mdot
.852 .29766 Mdot
.852 .29775 Mdot
.852 .29912 Mdot
.852 .29936 Mdot
.852 .29949 Mdot
.852 .29969 Mdot
.852 .29975 Mdot
.852 .30029 Mdot
.852 .30085 Mdot
.852 .30128 Mdot
.852 .30181 Mdot
.852 .30208 Mdot
.852 .30212 Mdot
.852 .30225 Mdot
.852 .30277 Mdot
.852 .3032 Mdot
.852 .30415 Mdot
.852 .30481 Mdot
.852 .30511 Mdot
.852 .3054 Mdot
.852 .30582 Mdot
.852 .30715 Mdot
.852 .3072 Mdot
.852 .3076 Mdot
.852 .30776 Mdot
.852 .30793 Mdot
.852 .30866 Mdot
.852 .30976 Mdot
.852 .31007 Mdot
.852 .3106 Mdot
.852 .31079 Mdot
.852 .31282 Mdot
.852 .31297 Mdot
.852 .31361 Mdot
.852 .31406 Mdot
.852 .31444 Mdot
.852 .31449 Mdot
.852 .31479 Mdot
.852 .31508 Mdot
.852 .31537 Mdot
.852 .31664 Mdot
.852 .31741 Mdot
.852 .31832 Mdot
.852 .31852 Mdot
.852 .31889 Mdot
.852 .31909 Mdot
.852 .31962 Mdot
.852 .31993 Mdot
.852 .31998 Mdot
.852 .32028 Mdot
.852 .32124 Mdot
.852 .32157 Mdot
.852 .32178 Mdot
.852 .32249 Mdot
.852 .32347 Mdot
.852 .32476 Mdot
.852 .32495 Mdot
.852 .32568 Mdot
.852 .32597 Mdot
.852 .326 Mdot
.852 .3264 Mdot
.852 .32675 Mdot
.852 .32719 Mdot
.852 .32864 Mdot
.852 .32916 Mdot
.852 .32932 Mdot
.852 .32938 Mdot
.852 .33021 Mdot
.852 .3312 Mdot
.852 .33154 Mdot
.852 .33243 Mdot
.852 .3327 Mdot
.852 .33405 Mdot
.852 .33473 Mdot
.852 .33521 Mdot
.852 .33536 Mdot
.852 .33612 Mdot
.852 .33668 Mdot
.852 .33677 Mdot
.852 .33714 Mdot
.852 .33738 Mdot
.852 .33776 Mdot
.852 .33794 Mdot
.852 .33834 Mdot
.852 .33852 Mdot
.852 .33912 Mdot
.852 .34008 Mdot
.852 .3417 Mdot
.852 .34294 Mdot
.852 .3445 Mdot
.852 .34508 Mdot
.852 .34526 Mdot
.852 .34539 Mdot
.852 .34543 Mdot
.852 .34575 Mdot
.852 .3459 Mdot
.852 .3469 Mdot
.852 .34728 Mdot
.852 .34731 Mdot
.852 .34732 Mdot
.852 .34852 Mdot
.852 .34958 Mdot
.852 .3498 Mdot
.852 .35036 Mdot
.852 .35083 Mdot
.852 .35128 Mdot
.852 .35152 Mdot
.852 .35169 Mdot
.852 .3532 Mdot
.852 .35322 Mdot
.852 .35352 Mdot
.852 .35394 Mdot
.852 .35408 Mdot
.852 .35425 Mdot
.852 .35447 Mdot
.852 .35455 Mdot
.852 .35491 Mdot
.852 .35563 Mdot
.852 .3557 Mdot
.852 .35614 Mdot
.852 .35719 Mdot
.852 .3594 Mdot
.852 .35984 Mdot
.852 .35999 Mdot
.852 .36015 Mdot
.852 .36103 Mdot
.852 .36129 Mdot
.852 .36144 Mdot
.852 .36176 Mdot
.852 .36227 Mdot
.852 .36288 Mdot
.852 .36436 Mdot
.852 .36437 Mdot
.852 .36484 Mdot
.852 .36495 Mdot
.852 .36623 Mdot
.852 .36654 Mdot
.852 .36758 Mdot
.852 .36823 Mdot
.852 .36831 Mdot
.852 .36848 Mdot
.852 .36903 Mdot
.852 .37098 Mdot
.852 .3711 Mdot
.852 .37116 Mdot
.852 .37209 Mdot
.852 .37339 Mdot
.852 .37395 Mdot
.852 .37416 Mdot
.852 .37443 Mdot
.852 .3752 Mdot
.852 .37549 Mdot
.852 .37556 Mdot
.852 .37572 Mdot
.852 .37733 Mdot
.852 .37762 Mdot
.852 .37808 Mdot
.852 .37833 Mdot
.852 .38015 Mdot
.852 .38116 Mdot
.852 .38185 Mdot
.852 .38243 Mdot
.852 .383 Mdot
.852 .3831 Mdot
.852 .38384 Mdot
.852 .38425 Mdot
.852 .38446 Mdot
.852 .38485 Mdot
.852 .38608 Mdot
.852 .38629 Mdot
.852 .3868 Mdot
.852 .38701 Mdot
.852 .38881 Mdot
.852 .38917 Mdot
.852 .39 Mdot
.852 .39024 Mdot
.852 .39238 Mdot
.852 .39274 Mdot
.852 .3936 Mdot
.852 .39377 Mdot
.852 .39379 Mdot
.852 .39454 Mdot
.852 .39503 Mdot
.852 .39525 Mdot
.852 .39575 Mdot
.852 .39601 Mdot
.852 .39606 Mdot
.852 .39663 Mdot
.852 .39664 Mdot
.852 .39895 Mdot
.852 .39959 Mdot
.852 .40039 Mdot
.852 .40212 Mdot
.852 .40238 Mdot
.852 .40271 Mdot
.852 .40322 Mdot
.852 .40341 Mdot
.852 .40449 Mdot
.852 .40575 Mdot
.852 .40617 Mdot
.852 .40655 Mdot
.852 .40787 Mdot
.852 .40856 Mdot
.852 .40927 Mdot
.852 .40975 Mdot
.852 .41041 Mdot
.852 .4123 Mdot
.852 .41362 Mdot
.852 .41438 Mdot
.852 .41515 Mdot
.852 .41615 Mdot
.852 .41717 Mdot
.852 .41875 Mdot
.852 .41877 Mdot
.852 .42037 Mdot
.852 .42212 Mdot
.852 .4258 Mdot
.852 .42599 Mdot
.852 .42639 Mdot
.852 .42698 Mdot
.852 .42723 Mdot
.852 .42733 Mdot
.852 .42741 Mdot
.852 .42783 Mdot
.852 .42835 Mdot
.852 .42967 Mdot
.852 .43102 Mdot
.852 .43156 Mdot
.852 .4328 Mdot
.852 .43348 Mdot
.852 .43419 Mdot
.852 .43455 Mdot
.852 .43538 Mdot
.852 .43704 Mdot
.852 .43752 Mdot
.852 .43787 Mdot
.852 .43829 Mdot
.852 .43854 Mdot
.852 .44094 Mdot
.852 .44121 Mdot
.852 .44138 Mdot
.852 .44145 Mdot
.852 .44162 Mdot
.852 .44382 Mdot
.852 .4442 Mdot
.852 .44507 Mdot
.852 .44521 Mdot
.852 .44778 Mdot
.852 .449 Mdot
.852 .45204 Mdot
.852 .45285 Mdot
.852 .4533 Mdot
.852 .45527 Mdot
.852 .45601 Mdot
.852 .45719 Mdot
.852 .45831 Mdot
.852 .45866 Mdot
.852 .45996 Mdot
.852 .46145 Mdot
.852 .46212 Mdot
.852 .46448 Mdot
.852 .4669 Mdot
.852 .46852 Mdot
.852 .46915 Mdot
.852 .46971 Mdot
.852 .46979 Mdot
.852 .46983 Mdot
.852 .47146 Mdot
.852 .47375 Mdot
.852 .47385 Mdot
.852 .47399 Mdot
.852 .47418 Mdot
.852 .47463 Mdot
.852 .47493 Mdot
.852 .47568 Mdot
.852 .4773 Mdot
.852 .47752 Mdot
.852 .47764 Mdot
.852 .47799 Mdot
.852 .47944 Mdot
.852 .48025 Mdot
.852 .48099 Mdot
.852 .48228 Mdot
.852 .48237 Mdot
.852 .48543 Mdot
.852 .4865 Mdot
.852 .48803 Mdot
.852 .48857 Mdot
.852 .48902 Mdot
.852 .48933 Mdot
.852 .48951 Mdot
.852 .48972 Mdot
.852 .49028 Mdot
.852 .49048 Mdot
.852 .49159 Mdot
.852 .49246 Mdot
.852 .49463 Mdot
.852 .49685 Mdot
.852 .49701 Mdot
.852 .49935 Mdot
.852 .49975 Mdot
.852 .49998 Mdot
.852 .50032 Mdot
.852 .50042 Mdot
.852 .50134 Mdot
.852 .50229 Mdot
.852 .50302 Mdot
.852 .50393 Mdot
.852 .50438 Mdot
.852 .50446 Mdot
.852 .50467 Mdot
.852 .50556 Mdot
.852 .50629 Mdot
.852 .50791 Mdot
.852 .50904 Mdot
.852 .50955 Mdot
.852 .51004 Mdot
.852 .51076 Mdot
.852 .51302 Mdot
.852 .51312 Mdot
.852 .51379 Mdot
.852 .51406 Mdot
.852 .51436 Mdot
.852 .51559 Mdot
.852 .51748 Mdot
.852 .51801 Mdot
.854 .01535 Mdot
.854 .01553 Mdot
.854 .01566 Mdot
.854 .0158 Mdot
.854 .01611 Mdot
.854 .01618 Mdot
.854 .01633 Mdot
.854 .01656 Mdot
.854 .01656 Mdot
.854 .01683 Mdot
.854 .0171 Mdot
.854 .01722 Mdot
.854 .01748 Mdot
.854 .01786 Mdot
.854 .01787 Mdot
.854 .01833 Mdot
.854 .01879 Mdot
.854 .019 Mdot
.854 .01918 Mdot
.854 .0192 Mdot
.854 .01942 Mdot
.854 .01944 Mdot
.854 .01958 Mdot
.854 .02009 Mdot
.854 .0201 Mdot
.854 .0209 Mdot
.854 .02154 Mdot
.854 .02168 Mdot
.854 .02176 Mdot
.854 .02203 Mdot
.854 .02234 Mdot
.854 .02238 Mdot
.854 .02247 Mdot
.854 .02275 Mdot
.854 .02278 Mdot
.854 .02302 Mdot
.854 .0239 Mdot
.854 .02391 Mdot
.854 .02462 Mdot
.854 .02527 Mdot
.854 .02565 Mdot
.854 .02637 Mdot
.854 .02662 Mdot
.854 .02674 Mdot
.854 .02691 Mdot
.854 .02696 Mdot
.854 .0272 Mdot
.854 .02724 Mdot
.854 .02747 Mdot
.854 .02774 Mdot
.854 .02781 Mdot
.854 .02795 Mdot
.854 .02844 Mdot
.854 .02849 Mdot
.854 .02877 Mdot
.854 .02885 Mdot
.854 .02891 Mdot
.854 .03024 Mdot
.854 .03041 Mdot
.854 .03042 Mdot
.854 .03089 Mdot
.854 .0315 Mdot
.854 .03164 Mdot
.854 .03164 Mdot
.854 .03188 Mdot
.854 .03275 Mdot
.854 .03338 Mdot
.854 .03339 Mdot
.854 .03361 Mdot
.854 .03369 Mdot
.854 .03416 Mdot
.854 .03421 Mdot
.854 .03462 Mdot
.854 .03504 Mdot
.854 .03525 Mdot
.854 .03555 Mdot
.854 .03563 Mdot
.854 .03581 Mdot
.854 .03604 Mdot
.854 .03611 Mdot
.854 .03651 Mdot
.854 .03684 Mdot
.854 .03696 Mdot
.854 .03708 Mdot
.854 .03733 Mdot
.854 .03793 Mdot
.854 .03807 Mdot
.854 .03815 Mdot
.854 .03825 Mdot
.854 .03872 Mdot
.854 .03887 Mdot
.854 .03896 Mdot
.854 .03923 Mdot
.854 .03999 Mdot
.854 .0409 Mdot
.854 .04124 Mdot
.854 .04152 Mdot
.854 .04153 Mdot
.854 .0417 Mdot
.854 .04189 Mdot
.854 .04235 Mdot
.854 .04293 Mdot
.854 .04338 Mdot
.854 .04357 Mdot
.854 .04362 Mdot
.854 .04363 Mdot
.854 .04404 Mdot
.854 .04552 Mdot
.854 .04576 Mdot
.854 .0466 Mdot
.854 .04661 Mdot
.854 .04692 Mdot
.854 .04698 Mdot
.854 .04713 Mdot
.854 .04793 Mdot
.854 .04801 Mdot
.854 .04872 Mdot
.854 .04944 Mdot
.854 .04956 Mdot
.854 .04979 Mdot
.854 .0503 Mdot
.854 .0503 Mdot
.854 .05043 Mdot
.854 .05074 Mdot
.854 .05076 Mdot
.854 .05114 Mdot
.854 .05126 Mdot
.854 .05194 Mdot
.854 .0525 Mdot
.854 .05271 Mdot
.854 .05287 Mdot
.854 .05291 Mdot
.854 .05334 Mdot
.854 .05436 Mdot
.854 .0546 Mdot
.854 .05461 Mdot
.854 .05475 Mdot
.854 .05491 Mdot
.854 .05569 Mdot
.854 .05572 Mdot
.854 .05579 Mdot
.854 .05596 Mdot
.854 .05612 Mdot
.854 .05658 Mdot
.854 .05789 Mdot
.854 .05796 Mdot
.854 .05891 Mdot
.854 .05912 Mdot
.854 .05945 Mdot
.854 .06002 Mdot
.854 .0605 Mdot
.854 .06052 Mdot
.854 .0608 Mdot
.854 .06093 Mdot
.854 .06113 Mdot
.854 .06192 Mdot
.854 .06203 Mdot
.854 .0629 Mdot
.854 .06317 Mdot
.854 .06368 Mdot
.854 .064 Mdot
.854 .06408 Mdot
.854 .0641 Mdot
.854 .06429 Mdot
.854 .0648 Mdot
.854 .06489 Mdot
.854 .06563 Mdot
.854 .06616 Mdot
.854 .06733 Mdot
.854 .06774 Mdot
.854 .06917 Mdot
.854 .06919 Mdot
.854 .06933 Mdot
.854 .06935 Mdot
.854 .06964 Mdot
.854 .06972 Mdot
.854 .06983 Mdot
.854 .07007 Mdot
.854 .0711 Mdot
.854 .07145 Mdot
.854 .07159 Mdot
.854 .07262 Mdot
.854 .07279 Mdot
.854 .073 Mdot
.854 .07402 Mdot
.854 .07423 Mdot
.854 .07458 Mdot
.854 .07463 Mdot
.854 .07549 Mdot
.854 .0755 Mdot
.854 .07572 Mdot
.854 .07605 Mdot
.854 .07625 Mdot
.854 .07629 Mdot
.854 .07634 Mdot
.854 .0768 Mdot
.854 .07694 Mdot
.854 .07713 Mdot
.854 .07815 Mdot
.854 .07829 Mdot
.854 .07925 Mdot
.854 .07962 Mdot
.854 .07975 Mdot
.854 .07988 Mdot
.854 .07995 Mdot
.854 .08068 Mdot
.854 .08243 Mdot
.854 .08284 Mdot
.854 .08285 Mdot
.854 .08309 Mdot
.854 .08337 Mdot
.854 .08355 Mdot
.854 .0847 Mdot
.854 .08476 Mdot
.854 .08484 Mdot
.854 .08486 Mdot
.854 .08487 Mdot
.854 .08517 Mdot
.854 .08543 Mdot
.854 .08596 Mdot
.854 .08601 Mdot
.854 .08602 Mdot
.854 .08622 Mdot
.854 .08641 Mdot
.854 .08773 Mdot
.854 .08775 Mdot
.854 .08846 Mdot
.854 .08858 Mdot
.854 .08893 Mdot
.854 .08944 Mdot
.854 .08955 Mdot
.854 .08962 Mdot
.854 .08969 Mdot
.854 .09016 Mdot
.854 .09021 Mdot
.854 .09055 Mdot
.854 .09105 Mdot
.854 .09112 Mdot
.854 .09148 Mdot
.854 .0916 Mdot
.854 .09192 Mdot
.854 .09209 Mdot
.854 .09291 Mdot
.854 .09295 Mdot
.854 .09343 Mdot
.854 .09365 Mdot
.854 .09397 Mdot
.854 .094 Mdot
.854 .09418 Mdot
.854 .09533 Mdot
.854 .09549 Mdot
.854 .09553 Mdot
.854 .09702 Mdot
.854 .09747 Mdot
.854 .09835 Mdot
.854 .09889 Mdot
.854 .09904 Mdot
.854 .09906 Mdot
.854 .09939 Mdot
.854 .10026 Mdot
.854 .10042 Mdot
.854 .10168 Mdot
.854 .10222 Mdot
.854 .10234 Mdot
.854 .10258 Mdot
.854 .10258 Mdot
.854 .10454 Mdot
.854 .10458 Mdot
.854 .10527 Mdot
.854 .10528 Mdot
.854 .10576 Mdot
.854 .10649 Mdot
.854 .10669 Mdot
.854 .10671 Mdot
.854 .10772 Mdot
.854 .10776 Mdot
.854 .10799 Mdot
.854 .10803 Mdot
.854 .10853 Mdot
.854 .10866 Mdot
.854 .10884 Mdot
.854 .10912 Mdot
.854 .10927 Mdot
.854 .10928 Mdot
.854 .11079 Mdot
.854 .11102 Mdot
.854 .11154 Mdot
.854 .11163 Mdot
.854 .11185 Mdot
.854 .11278 Mdot
.854 .11362 Mdot
.854 .11382 Mdot
.854 .11391 Mdot
.854 .11427 Mdot
.854 .11599 Mdot
.854 .116 Mdot
.854 .11637 Mdot
.854 .11644 Mdot
.854 .1165 Mdot
.854 .11697 Mdot
.854 .11705 Mdot
.854 .11826 Mdot
.854 .11852 Mdot
.854 .11853 Mdot
.854 .11891 Mdot
.854 .11919 Mdot
.854 .11944 Mdot
.854 .11947 Mdot
.854 .11982 Mdot
.854 .11986 Mdot
.854 .11988 Mdot
.854 .11997 Mdot
.854 .1203 Mdot
.854 .12076 Mdot
.854 .12099 Mdot
.854 .12133 Mdot
.854 .12306 Mdot
.854 .12331 Mdot
.854 .12494 Mdot
.854 .12535 Mdot
.854 .12557 Mdot
.854 .12579 Mdot
.854 .12602 Mdot
.854 .12614 Mdot
.854 .12629 Mdot
.854 .12704 Mdot
.854 .12709 Mdot
.854 .12739 Mdot
.854 .12989 Mdot
.854 .13037 Mdot
.854 .13038 Mdot
.854 .13107 Mdot
.854 .13109 Mdot
.854 .13112 Mdot
.854 .13121 Mdot
.854 .1315 Mdot
.854 .13198 Mdot
.854 .13228 Mdot
.854 .13425 Mdot
.854 .13434 Mdot
.854 .13449 Mdot
.854 .13453 Mdot
.854 .13453 Mdot
.854 .13505 Mdot
.854 .13535 Mdot
.854 .1355 Mdot
.854 .1364 Mdot
.854 .13649 Mdot
.854 .1365 Mdot
.854 .13685 Mdot
.854 .13717 Mdot
.854 .13726 Mdot
.854 .13827 Mdot
.854 .13861 Mdot
.854 .13862 Mdot
.854 .13943 Mdot
.854 .13945 Mdot
.854 .14028 Mdot
.854 .14067 Mdot
.854 .14087 Mdot
.854 .14127 Mdot
.854 .14147 Mdot
.854 .14235 Mdot
.854 .14253 Mdot
.854 .14265 Mdot
.854 .14276 Mdot
.854 .14358 Mdot
.854 .14365 Mdot
.854 .14424 Mdot
.854 .1451 Mdot
.854 .14521 Mdot
.854 .14565 Mdot
.854 .14583 Mdot
.854 .14603 Mdot
.854 .14653 Mdot
.854 .14658 Mdot
.854 .14685 Mdot
.854 .14687 Mdot
.854 .14713 Mdot
.854 .14772 Mdot
.854 .14827 Mdot
.854 .14834 Mdot
.854 .14916 Mdot
.854 .14953 Mdot
.854 .15009 Mdot
.854 .15013 Mdot
.854 .15044 Mdot
.854 .15169 Mdot
.854 .15178 Mdot
.854 .15216 Mdot
.854 .15241 Mdot
.854 .15267 Mdot
.854 .15275 Mdot
.854 .15509 Mdot
.854 .15529 Mdot
.854 .15607 Mdot
.854 .15756 Mdot
.854 .15849 Mdot
.854 .15874 Mdot
.854 .15877 Mdot
.854 .15934 Mdot
.854 .15934 Mdot
.854 .1599 Mdot
.854 .16024 Mdot
.854 .16083 Mdot
.854 .1611 Mdot
.854 .16209 Mdot
.854 .16302 Mdot
.854 .16325 Mdot
.854 .16401 Mdot
.854 .16417 Mdot
.854 .16422 Mdot
.854 .16438 Mdot
.854 .16479 Mdot
.854 .16479 Mdot
.854 .1665 Mdot
.854 .16671 Mdot
.854 .16806 Mdot
.854 .16813 Mdot
.854 .16818 Mdot
.854 .16821 Mdot
.854 .16922 Mdot
.854 .16939 Mdot
.854 .1694 Mdot
.854 .16947 Mdot
.854 .17022 Mdot
.854 .17147 Mdot
.854 .17181 Mdot
.854 .17185 Mdot
.854 .17241 Mdot
.854 .17357 Mdot
.854 .17364 Mdot
.854 .17403 Mdot
.854 .1741 Mdot
.854 .17469 Mdot
.854 .17496 Mdot
.854 .17515 Mdot
.854 .17517 Mdot
.854 .17549 Mdot
.854 .17551 Mdot
.854 .17597 Mdot
.854 .17621 Mdot
.854 .17624 Mdot
.854 .17838 Mdot
.854 .17861 Mdot
.854 .1788 Mdot
.854 .1792 Mdot
.854 .17959 Mdot
.854 .1801 Mdot
.854 .18024 Mdot
.854 .18063 Mdot
.854 .18146 Mdot
.854 .18222 Mdot
.854 .18365 Mdot
.854 .18384 Mdot
.854 .18399 Mdot
.854 .18413 Mdot
.854 .18421 Mdot
.854 .18443 Mdot
.854 .18448 Mdot
.854 .18475 Mdot
.854 .18597 Mdot
.854 .18769 Mdot
.854 .18772 Mdot
.854 .18816 Mdot
.854 .18833 Mdot
.854 .18846 Mdot
.854 .18856 Mdot
.854 .18936 Mdot
.854 .1895 Mdot
.854 .19158 Mdot
.854 .19201 Mdot
.854 .19203 Mdot
.854 .19212 Mdot
.854 .1922 Mdot
.854 .19265 Mdot
.854 .19268 Mdot
.854 .19315 Mdot
.854 .19358 Mdot
.854 .19363 Mdot
.854 .19423 Mdot
.854 .19431 Mdot
.854 .19434 Mdot
.854 .1945 Mdot
.854 .19451 Mdot
.854 .19506 Mdot
.854 .19541 Mdot
.854 .19579 Mdot
.854 .19584 Mdot
.854 .19623 Mdot
.854 .19681 Mdot
.854 .19708 Mdot
.854 .1975 Mdot
.854 .19977 Mdot
.854 .20019 Mdot
.854 .20298 Mdot
.854 .20367 Mdot
.854 .20405 Mdot
.854 .20444 Mdot
.854 .20482 Mdot
.854 .20503 Mdot
.854 .20528 Mdot
.854 .20655 Mdot
.854 .20656 Mdot
.854 .20666 Mdot
.854 .20716 Mdot
.854 .20885 Mdot
.854 .20911 Mdot
.854 .20958 Mdot
.854 .21012 Mdot
.854 .21143 Mdot
.854 .21188 Mdot
.854 .21225 Mdot
.854 .21227 Mdot
.854 .21345 Mdot
.854 .21348 Mdot
.854 .21353 Mdot
.854 .21369 Mdot
.854 .214 Mdot
.854 .21419 Mdot
.854 .215 Mdot
.854 .21552 Mdot
.854 .21783 Mdot
.854 .21787 Mdot
.854 .21888 Mdot
.854 .21904 Mdot
.854 .21929 Mdot
.854 .21936 Mdot
.854 .21937 Mdot
.854 .22025 Mdot
.854 .22076 Mdot
.854 .22102 Mdot
.854 .22145 Mdot
.854 .22255 Mdot
.854 .2227 Mdot
.854 .22272 Mdot
.854 .22333 Mdot
.854 .22387 Mdot
.854 .22402 Mdot
.854 .22575 Mdot
.854 .22608 Mdot
.854 .22633 Mdot
.854 .22635 Mdot
.854 .22731 Mdot
.854 .22748 Mdot
.854 .22773 Mdot
.854 .22776 Mdot
.854 .22918 Mdot
.854 .22984 Mdot
.854 .23018 Mdot
.854 .2303 Mdot
.854 .23031 Mdot
.854 .23087 Mdot
.854 .23121 Mdot
.854 .23271 Mdot
.854 .23302 Mdot
.854 .23312 Mdot
.854 .23322 Mdot
.854 .23342 Mdot
.854 .23478 Mdot
.854 .23481 Mdot
.854 .23494 Mdot
.854 .23595 Mdot
.854 .23741 Mdot
.854 .2376 Mdot
.854 .23771 Mdot
.854 .23835 Mdot
.854 .23867 Mdot
.854 .23901 Mdot
.854 .23908 Mdot
.854 .23986 Mdot
.854 .23993 Mdot
.854 .24039 Mdot
.854 .24044 Mdot
.854 .24079 Mdot
.854 .24088 Mdot
.854 .24188 Mdot
.854 .24267 Mdot
.854 .24282 Mdot
.854 .24295 Mdot
.854 .24393 Mdot
.854 .24401 Mdot
.854 .24435 Mdot
.854 .24499 Mdot
.854 .2458 Mdot
.854 .24593 Mdot
.854 .24601 Mdot
.854 .24602 Mdot
.854 .24653 Mdot
.854 .24728 Mdot
.854 .24864 Mdot
.854 .24867 Mdot
.854 .24882 Mdot
.854 .24946 Mdot
.854 .24977 Mdot
.854 .2499 Mdot
.854 .25034 Mdot
.854 .25049 Mdot
.854 .25359 Mdot
.854 .25438 Mdot
.854 .25447 Mdot
.854 .25463 Mdot
.854 .25481 Mdot
.854 .25542 Mdot
.854 .25614 Mdot
.854 .25745 Mdot
.854 .25747 Mdot
.854 .2587 Mdot
.854 .26028 Mdot
.854 .2607 Mdot
.854 .26076 Mdot
.854 .26173 Mdot
.854 .26173 Mdot
.854 .2627 Mdot
.854 .26327 Mdot
.854 .26427 Mdot
.854 .26474 Mdot
.854 .26533 Mdot
.854 .26597 Mdot
.854 .2664 Mdot
.854 .26643 Mdot
.854 .26704 Mdot
.854 .26712 Mdot
.854 .26755 Mdot
.854 .26802 Mdot
.854 .2684 Mdot
.854 .26971 Mdot
.854 .26998 Mdot
.854 .27007 Mdot
.854 .27034 Mdot
.854 .27104 Mdot
.854 .27104 Mdot
.854 .27374 Mdot
.854 .27396 Mdot
.854 .27411 Mdot
.854 .27433 Mdot
.854 .27435 Mdot
.854 .2745 Mdot
.854 .27662 Mdot
.854 .27675 Mdot
.854 .27683 Mdot
.854 .27688 Mdot
.854 .27861 Mdot
.854 .2789 Mdot
.854 .27892 Mdot
.854 .27904 Mdot
.854 .27953 Mdot
.854 .28032 Mdot
.854 .28039 Mdot
.854 .28044 Mdot
.854 .2808 Mdot
.854 .28222 Mdot
.854 .28245 Mdot
.854 .28303 Mdot
.854 .2831 Mdot
.854 .28405 Mdot
.854 .28454 Mdot
.854 .28473 Mdot
.854 .28489 Mdot
.854 .28593 Mdot
.854 .28603 Mdot
.854 .28616 Mdot
.854 .28682 Mdot
.854 .28694 Mdot
.854 .28796 Mdot
.854 .28841 Mdot
.854 .28873 Mdot
.854 .28877 Mdot
.854 .28931 Mdot
.854 .28935 Mdot
.854 .29009 Mdot
.854 .29013 Mdot
.854 .29056 Mdot
.854 .2906 Mdot
.854 .29074 Mdot
.854 .29243 Mdot
.854 .29263 Mdot
.854 .29426 Mdot
.854 .29464 Mdot
.854 .29498 Mdot
.854 .29542 Mdot
.854 .29565 Mdot
.854 .29633 Mdot
.854 .29684 Mdot
.854 .29719 Mdot
.854 .29741 Mdot
.854 .29743 Mdot
.854 .29786 Mdot
.854 .2981 Mdot
.854 .29951 Mdot
.854 .30081 Mdot
.854 .30088 Mdot
.854 .3012 Mdot
.854 .30155 Mdot
.854 .30326 Mdot
.854 .30349 Mdot
.854 .30358 Mdot
.854 .30384 Mdot
.854 .30384 Mdot
.854 .30408 Mdot
.854 .30422 Mdot
.854 .30459 Mdot
.854 .30468 Mdot
.854 .30513 Mdot
.854 .30682 Mdot
.854 .30721 Mdot
.854 .30813 Mdot
.854 .30908 Mdot
.854 .30917 Mdot
.854 .31015 Mdot
.854 .3102 Mdot
.854 .31077 Mdot
.854 .31088 Mdot
.854 .31095 Mdot
.854 .31126 Mdot
.854 .31148 Mdot
.854 .31164 Mdot
.854 .31301 Mdot
.854 .31302 Mdot
.854 .31315 Mdot
.854 .31324 Mdot
.854 .31439 Mdot
.854 .31452 Mdot
.854 .31493 Mdot
.854 .3168 Mdot
.854 .31754 Mdot
.854 .31756 Mdot
.854 .31773 Mdot
.854 .31787 Mdot
.854 .31863 Mdot
.854 .31867 Mdot
.854 .31949 Mdot
.854 .31987 Mdot
.854 .32022 Mdot
.854 .32031 Mdot
.854 .32045 Mdot
.854 .32132 Mdot
.854 .32146 Mdot
.854 .32151 Mdot
.854 .32178 Mdot
.854 .32181 Mdot
.854 .32275 Mdot
.854 .32335 Mdot
.854 .32399 Mdot
.854 .32407 Mdot
.854 .32475 Mdot
.854 .3252 Mdot
.854 .32573 Mdot
.854 .32619 Mdot
.854 .32631 Mdot
.854 .32691 Mdot
.854 .32729 Mdot
.854 .32857 Mdot
.854 .32925 Mdot
.854 .3308 Mdot
.854 .33123 Mdot
.854 .3315 Mdot
.854 .33273 Mdot
.854 .33375 Mdot
.854 .33439 Mdot
.854 .33444 Mdot
.854 .33571 Mdot
.854 .33627 Mdot
.854 .33639 Mdot
.854 .33745 Mdot
.854 .3381 Mdot
.854 .33876 Mdot
.854 .33942 Mdot
.854 .33977 Mdot
.854 .34021 Mdot
.854 .34052 Mdot
.854 .34237 Mdot
.854 .34238 Mdot
.854 .34256 Mdot
.854 .34341 Mdot
.854 .3443 Mdot
.854 .34452 Mdot
.854 .34545 Mdot
.854 .3463 Mdot
.854 .34648 Mdot
.854 .34675 Mdot
.854 .34754 Mdot
.854 .34847 Mdot
.854 .3507 Mdot
.854 .35145 Mdot
.854 .35147 Mdot
.854 .35211 Mdot
.854 .35214 Mdot
.854 .35214 Mdot
.854 .35237 Mdot
.854 .35315 Mdot
.854 .35315 Mdot
.854 .35385 Mdot
.854 .35415 Mdot
.854 .35421 Mdot
.854 .35425 Mdot
.854 .35429 Mdot
.854 .35457 Mdot
.854 .35509 Mdot
.854 .35534 Mdot
.854 .35541 Mdot
.854 .3556 Mdot
.854 .3568 Mdot
.854 .35692 Mdot
.854 .35769 Mdot
.854 .36163 Mdot
.854 .3617 Mdot
.854 .36184 Mdot
.854 .36298 Mdot
.854 .36342 Mdot
.854 .3637 Mdot
.854 .36413 Mdot
.854 .36425 Mdot
.854 .36426 Mdot
.854 .36567 Mdot
.854 .36576 Mdot
.854 .36664 Mdot
.854 .36709 Mdot
.854 .36781 Mdot
.854 .36842 Mdot
.854 .36869 Mdot
.854 .36969 Mdot
.854 .36995 Mdot
.854 .36999 Mdot
.854 .37102 Mdot
.854 .37156 Mdot
.854 .37171 Mdot
.854 .37196 Mdot
.854 .37222 Mdot
.854 .37517 Mdot
.854 .37572 Mdot
.854 .37616 Mdot
.854 .37619 Mdot
.854 .37783 Mdot
.854 .37812 Mdot
.854 .37855 Mdot
.854 .3786 Mdot
.854 .38103 Mdot
.854 .38214 Mdot
.854 .38274 Mdot
.854 .38294 Mdot
.854 .38294 Mdot
.854 .38391 Mdot
.854 .38449 Mdot
.854 .38705 Mdot
.854 .38757 Mdot
.854 .38776 Mdot
.854 .38792 Mdot
.854 .38827 Mdot
.854 .39059 Mdot
.854 .39065 Mdot
.854 .39086 Mdot
.854 .39258 Mdot
.854 .39507 Mdot
.854 .3954 Mdot
.854 .3956 Mdot
.854 .39668 Mdot
.854 .39723 Mdot
.854 .39781 Mdot
.854 .39793 Mdot
.854 .39926 Mdot
.854 .39939 Mdot
.854 .40017 Mdot
.854 .40025 Mdot
.854 .40085 Mdot
.854 .401 Mdot
.854 .40272 Mdot
.854 .40406 Mdot
.854 .40433 Mdot
.854 .40454 Mdot
.854 .40622 Mdot
.854 .40635 Mdot
.854 .40693 Mdot
.854 .40802 Mdot
.854 .40941 Mdot
.854 .40963 Mdot
.854 .40976 Mdot
.854 .40979 Mdot
.854 .41066 Mdot
.854 .41194 Mdot
.854 .41427 Mdot
.854 .41431 Mdot
.854 .41457 Mdot
.854 .41566 Mdot
.854 .41619 Mdot
.854 .41641 Mdot
.854 .41717 Mdot
.854 .41741 Mdot
.854 .42271 Mdot
.854 .42406 Mdot
.854 .42421 Mdot
.854 .42448 Mdot
.854 .4248 Mdot
.854 .42583 Mdot
.854 .42707 Mdot
.854 .42931 Mdot
.854 .42934 Mdot
.854 .43143 Mdot
.854 .43414 Mdot
.854 .43487 Mdot
.854 .43497 Mdot
.854 .43662 Mdot
.854 .43662 Mdot
.854 .43827 Mdot
.854 .43924 Mdot
.854 .44096 Mdot
.854 .44176 Mdot
.854 .44276 Mdot
.854 .44386 Mdot
.854 .4446 Mdot
.854 .44464 Mdot
.854 .44569 Mdot
.854 .44582 Mdot
.854 .44656 Mdot
.854 .44736 Mdot
.854 .44802 Mdot
.854 .45025 Mdot
.854 .45071 Mdot
.854 .45086 Mdot
.854 .45132 Mdot
.854 .45251 Mdot
.854 .45252 Mdot
.854 .45712 Mdot
.854 .4575 Mdot
.854 .45775 Mdot
.854 .45813 Mdot
.854 .45817 Mdot
.854 .45843 Mdot
.854 .46205 Mdot
.854 .46226 Mdot
.854 .46241 Mdot
.854 .46249 Mdot
.854 .46544 Mdot
.854 .46594 Mdot
.854 .46597 Mdot
.854 .46618 Mdot
.854 .46702 Mdot
.854 .46837 Mdot
.854 .46849 Mdot
.854 .46858 Mdot
.854 .46918 Mdot
.854 .47162 Mdot
.854 .472 Mdot
.854 .47299 Mdot
.854 .47311 Mdot
.854 .47474 Mdot
.854 .47558 Mdot
.854 .47591 Mdot
.854 .47617 Mdot
.854 .47794 Mdot
.854 .47813 Mdot
.854 .47833 Mdot
.854 .47947 Mdot
.854 .47967 Mdot
.854 .48142 Mdot
.854 .48219 Mdot
.854 .48274 Mdot
.854 .48279 Mdot
.854 .48373 Mdot
.854 .48379 Mdot
.854 .48505 Mdot
.854 .48512 Mdot
.854 .48585 Mdot
.854 .48592 Mdot
.854 .48617 Mdot
.854 .48906 Mdot
.854 .4894 Mdot
.854 .49218 Mdot
.854 .49283 Mdot
.854 .4934 Mdot
.854 .49415 Mdot
.854 .49455 Mdot
.854 .49571 Mdot
.854 .49659 Mdot
.854 .49719 Mdot
.854 .49756 Mdot
.854 .49759 Mdot
.854 .49833 Mdot
.854 .49873 Mdot
.854 .50115 Mdot
.854 .50336 Mdot
.854 .50349 Mdot
.854 .50403 Mdot
.854 .50464 Mdot
.854 .50755 Mdot
.854 .50795 Mdot
.854 .50809 Mdot
.854 .50854 Mdot
.854 .50855 Mdot
.854 .50895 Mdot
.854 .50919 Mdot
.854 .50983 Mdot
.854 .50998 Mdot
.854 .51075 Mdot
.854 .51363 Mdot
.854 .5143 Mdot
.854 .51587 Mdot
.854 .51748 Mdot
.854 .51764 Mdot
.854 .51932 Mdot
.854 .51941 Mdot
.856 .01483 Mdot
.856 .01491 Mdot
.856 .01506 Mdot
.856 .0153 Mdot
.856 .01564 Mdot
.856 .01572 Mdot
.856 .01629 Mdot
.856 .01643 Mdot
.856 .01733 Mdot
.856 .01741 Mdot
.856 .01759 Mdot
.856 .01765 Mdot
.856 .01783 Mdot
.856 .01786 Mdot
.856 .0179 Mdot
.856 .018 Mdot
.856 .01804 Mdot
.856 .01824 Mdot
.856 .01843 Mdot
.856 .01884 Mdot
.856 .01915 Mdot
.856 .0192 Mdot
.856 .01928 Mdot
.856 .01933 Mdot
.856 .01963 Mdot
.856 .01974 Mdot
.856 .02004 Mdot
.856 .0201 Mdot
.856 .02017 Mdot
.856 .02034 Mdot
.856 .02041 Mdot
.856 .02074 Mdot
.856 .02108 Mdot
.856 .02143 Mdot
.856 .02178 Mdot
.856 .02203 Mdot
.856 .02205 Mdot
.856 .02232 Mdot
.856 .02238 Mdot
.856 .02253 Mdot
.856 .02255 Mdot
.856 .02262 Mdot
.856 .023 Mdot
.856 .02313 Mdot
.856 .02332 Mdot
.856 .02374 Mdot
.856 .02383 Mdot
.856 .02394 Mdot
.856 .02405 Mdot
.856 .02435 Mdot
.856 .02446 Mdot
.856 .02503 Mdot
.856 .02561 Mdot
.856 .02622 Mdot
.856 .0268 Mdot
.856 .02725 Mdot
.856 .02728 Mdot
.856 .02773 Mdot
.856 .02785 Mdot
.856 .02792 Mdot
.856 .0281 Mdot
.856 .02813 Mdot
.856 .02825 Mdot
.856 .0289 Mdot
.856 .02912 Mdot
.856 .02945 Mdot
.856 .02948 Mdot
.856 .02954 Mdot
.856 .02965 Mdot
.856 .02969 Mdot
.856 .02976 Mdot
.856 .03017 Mdot
.856 .03033 Mdot
.856 .0305 Mdot
.856 .03069 Mdot
.856 .0307 Mdot
.856 .03121 Mdot
.856 .03125 Mdot
.856 .0314 Mdot
.856 .03162 Mdot
.856 .03238 Mdot
.856 .03336 Mdot
.856 .03441 Mdot
.856 .03513 Mdot
.856 .03518 Mdot
.856 .03541 Mdot
.856 .03613 Mdot
.856 .03617 Mdot
.856 .03623 Mdot
.856 .03631 Mdot
.856 .03672 Mdot
.856 .03681 Mdot
.856 .03699 Mdot
.856 .03719 Mdot
.856 .03733 Mdot
.856 .03763 Mdot
.856 .03768 Mdot
.856 .03789 Mdot
.856 .039 Mdot
.856 .03937 Mdot
.856 .03992 Mdot
.856 .03994 Mdot
.856 .03999 Mdot
.856 .04009 Mdot
.856 .04019 Mdot
.856 .04028 Mdot
.856 .04036 Mdot
.856 .04047 Mdot
.856 .04118 Mdot
.856 .04144 Mdot
.856 .04174 Mdot
.856 .04206 Mdot
.856 .04209 Mdot
.856 .04296 Mdot
.856 .04297 Mdot
.856 .04303 Mdot
.856 .04328 Mdot
.856 .04365 Mdot
.856 .04461 Mdot
.856 .04494 Mdot
.856 .04496 Mdot
.856 .04664 Mdot
.856 .04665 Mdot
.856 .04691 Mdot
.856 .04769 Mdot
.856 .04778 Mdot
.856 .04842 Mdot
.856 .04865 Mdot
.856 .04892 Mdot
.856 .04967 Mdot
.856 .04975 Mdot
.856 .05014 Mdot
.856 .05015 Mdot
.856 .05064 Mdot
.856 .05138 Mdot
.856 .05144 Mdot
.856 .05154 Mdot
.856 .05168 Mdot
.856 .05212 Mdot
.856 .05239 Mdot
.856 .05255 Mdot
.856 .05266 Mdot
.856 .05285 Mdot
.856 .05304 Mdot
.856 .0532 Mdot
.856 .05343 Mdot
.856 .05395 Mdot
.856 .05402 Mdot
.856 .05438 Mdot
.856 .05471 Mdot
.856 .05532 Mdot
.856 .05628 Mdot
.856 .05692 Mdot
.856 .05787 Mdot
.856 .0579 Mdot
.856 .05799 Mdot
.856 .05817 Mdot
.856 .05832 Mdot
.856 .05849 Mdot
.856 .05861 Mdot
.856 .05861 Mdot
.856 .0588 Mdot
.856 .05963 Mdot
.856 .06002 Mdot
.856 .06047 Mdot
.856 .06098 Mdot
.856 .06153 Mdot
.856 .06158 Mdot
.856 .06229 Mdot
.856 .06263 Mdot
.856 .06307 Mdot
.856 .06309 Mdot
.856 .06319 Mdot
.856 .0634 Mdot
.856 .06357 Mdot
.856 .06363 Mdot
.856 .06426 Mdot
.856 .06491 Mdot
.856 .06589 Mdot
.856 .06614 Mdot
.856 .06645 Mdot
.856 .06649 Mdot
.856 .06654 Mdot
.856 .06721 Mdot
.856 .0684 Mdot
.856 .06936 Mdot
.856 .06937 Mdot
.856 .06938 Mdot
.856 .06984 Mdot
.856 .07117 Mdot
.856 .07132 Mdot
.856 .0722 Mdot
.856 .07243 Mdot
.856 .07262 Mdot
.856 .07281 Mdot
.856 .07309 Mdot
.856 .07328 Mdot
.856 .07375 Mdot
.856 .07442 Mdot
.856 .07449 Mdot
.856 .0745 Mdot
.856 .07455 Mdot
.856 .07469 Mdot
.856 .07536 Mdot
.856 .07537 Mdot
.856 .07538 Mdot
.856 .07557 Mdot
.856 .07602 Mdot
.856 .07621 Mdot
.856 .07749 Mdot
.856 .07759 Mdot
.856 .07777 Mdot
.856 .07782 Mdot
.856 .078 Mdot
.856 .07875 Mdot
.856 .07922 Mdot
.856 .07948 Mdot
.856 .07967 Mdot
.856 .08 Mdot
.856 .08033 Mdot
.856 .0806 Mdot
.856 .08099 Mdot
.856 .08188 Mdot
.856 .08201 Mdot
.856 .08263 Mdot
.856 .08319 Mdot
.856 .08336 Mdot
.856 .08423 Mdot
.856 .08547 Mdot
.856 .08588 Mdot
.856 .08663 Mdot
.856 .08698 Mdot
.856 .08731 Mdot
.856 .08843 Mdot
.856 .08859 Mdot
.856 .08865 Mdot
.856 .08879 Mdot
.856 .0891 Mdot
.856 .08914 Mdot
.856 .08937 Mdot
.856 .08956 Mdot
.856 .08959 Mdot
.856 .08965 Mdot
.856 .08977 Mdot
.856 .08985 Mdot
.856 .08986 Mdot
.856 .08986 Mdot
.856 .09019 Mdot
.856 .09031 Mdot
.856 .09161 Mdot
.856 .09191 Mdot
.856 .09191 Mdot
.856 .09228 Mdot
.856 .09306 Mdot
.856 .09393 Mdot
.856 .09487 Mdot
.856 .09493 Mdot
.856 .09495 Mdot
.856 .09616 Mdot
.856 .09663 Mdot
.856 .09672 Mdot
.856 .09675 Mdot
.856 .0975 Mdot
.856 .09754 Mdot
.856 .09762 Mdot
.856 .0977 Mdot
.856 .09787 Mdot
.856 .09807 Mdot
.856 .09818 Mdot
.856 .09835 Mdot
.856 .09845 Mdot
.856 .09954 Mdot
.856 .09984 Mdot
.856 .10065 Mdot
.856 .10213 Mdot
.856 .10232 Mdot
.856 .10276 Mdot
.856 .10289 Mdot
.856 .10304 Mdot
.856 .10329 Mdot
.856 .10336 Mdot
.856 .10343 Mdot
.856 .10459 Mdot
.856 .10464 Mdot
.856 .10568 Mdot
.856 .10653 Mdot
.856 .10662 Mdot
.856 .10828 Mdot
.856 .10829 Mdot
.856 .10829 Mdot
.856 .1083 Mdot
.856 .10908 Mdot
.856 .10921 Mdot
.856 .11023 Mdot
.856 .11137 Mdot
.856 .11156 Mdot
.856 .11163 Mdot
.856 .11223 Mdot
.856 .11312 Mdot
.856 .11352 Mdot
.856 .11385 Mdot
.856 .11418 Mdot
.856 .1143 Mdot
.856 .11465 Mdot
.856 .11498 Mdot
.856 .11538 Mdot
.856 .11562 Mdot
.856 .11578 Mdot
.856 .11634 Mdot
.856 .11642 Mdot
.856 .11648 Mdot
.856 .11694 Mdot
.856 .11706 Mdot
.856 .11706 Mdot
.856 .11716 Mdot
.856 .1174 Mdot
.856 .11854 Mdot
.856 .11855 Mdot
.856 .11857 Mdot
.856 .11858 Mdot
.856 .11889 Mdot
.856 .11968 Mdot
.856 .11987 Mdot
.856 .11998 Mdot
.856 .12 Mdot
.856 .12219 Mdot
.856 .12236 Mdot
.856 .12242 Mdot
.856 .12266 Mdot
.856 .12276 Mdot
.856 .12305 Mdot
.856 .12357 Mdot
.856 .12435 Mdot
.856 .12515 Mdot
.856 .1256 Mdot
.856 .12593 Mdot
.856 .1263 Mdot
.856 .12631 Mdot
.856 .12649 Mdot
.856 .12705 Mdot
.856 .12723 Mdot
.856 .12751 Mdot
.856 .12817 Mdot
.856 .12928 Mdot
.856 .1297 Mdot
.856 .12993 Mdot
.856 .13056 Mdot
.856 .13057 Mdot
.856 .13098 Mdot
.856 .13194 Mdot
.856 .13217 Mdot
.856 .13223 Mdot
.856 .13317 Mdot
.856 .13373 Mdot
.856 .13585 Mdot
.856 .13655 Mdot
.856 .13784 Mdot
.856 .13843 Mdot
.856 .13901 Mdot
.856 .14092 Mdot
.856 .14119 Mdot
.856 .14128 Mdot
.856 .14152 Mdot
.856 .14154 Mdot
.856 .14177 Mdot
.856 .14206 Mdot
.856 .14212 Mdot
.856 .14252 Mdot
.856 .14285 Mdot
.856 .14291 Mdot
.856 .14301 Mdot
.856 .14311 Mdot
.856 .14321 Mdot
.856 .14335 Mdot
.856 .14336 Mdot
.856 .14337 Mdot
.856 .14361 Mdot
.856 .14393 Mdot
.856 .14413 Mdot
.856 .14477 Mdot
.856 .14488 Mdot
.856 .14602 Mdot
.856 .14636 Mdot
.856 .14687 Mdot
.856 .14687 Mdot
.856 .14751 Mdot
.856 .14752 Mdot
.856 .14782 Mdot
.856 .14883 Mdot
.856 .14981 Mdot
.856 .15033 Mdot
.856 .15149 Mdot
.856 .15175 Mdot
.856 .15194 Mdot
.856 .15205 Mdot
.856 .15207 Mdot
.856 .15226 Mdot
.856 .15278 Mdot
.856 .15325 Mdot
.856 .15395 Mdot
.856 .15403 Mdot
.856 .15408 Mdot
.856 .15414 Mdot
.856 .15495 Mdot
.856 .15511 Mdot
.856 .15516 Mdot
.856 .15527 Mdot
.856 .15644 Mdot
.856 .15651 Mdot
.856 .15665 Mdot
.856 .15679 Mdot
.856 .15686 Mdot
.856 .15708 Mdot
.856 .15742 Mdot
.856 .1576 Mdot
.856 .15789 Mdot
.856 .1579 Mdot
.856 .15807 Mdot
.856 .15993 Mdot
.856 .16044 Mdot
.856 .16045 Mdot
.856 .16108 Mdot
.856 .16162 Mdot
.856 .16183 Mdot
.856 .16437 Mdot
.856 .1647 Mdot
.856 .16544 Mdot
.856 .16567 Mdot
.856 .16593 Mdot
.856 .16636 Mdot
.856 .16647 Mdot
.856 .1666 Mdot
.856 .16737 Mdot
.856 .16806 Mdot
.856 .16817 Mdot
.856 .16857 Mdot
.856 .16866 Mdot
.856 .16906 Mdot
.856 .17045 Mdot
.856 .17163 Mdot
.856 .17164 Mdot
.856 .17191 Mdot
.856 .17206 Mdot
.856 .17338 Mdot
.856 .17483 Mdot
.856 .17489 Mdot
.856 .1749 Mdot
.856 .17491 Mdot
.856 .17491 Mdot
.856 .17493 Mdot
.856 .17628 Mdot
.856 .17638 Mdot
.856 .17649 Mdot
.856 .17746 Mdot
.856 .17824 Mdot
.856 .18019 Mdot
.856 .18051 Mdot
.856 .18064 Mdot
.856 .18148 Mdot
.856 .18166 Mdot
.856 .18311 Mdot
.856 .18319 Mdot
.856 .18386 Mdot
.856 .18443 Mdot
.856 .18499 Mdot
.856 .18521 Mdot
.856 .18542 Mdot
.856 .1858 Mdot
.856 .18636 Mdot
.856 .18637 Mdot
.856 .18706 Mdot
.856 .18747 Mdot
.856 .18774 Mdot
.856 .18849 Mdot
.856 .18869 Mdot
.856 .18883 Mdot
.856 .18894 Mdot
.856 .18898 Mdot
.856 .18972 Mdot
.856 .18992 Mdot
.856 .18993 Mdot
.856 .1901 Mdot
.856 .19051 Mdot
.856 .19246 Mdot
.856 .19248 Mdot
.856 .19252 Mdot
.856 .19254 Mdot
.856 .19307 Mdot
.856 .19439 Mdot
.856 .19441 Mdot
.856 .19473 Mdot
.856 .19479 Mdot
.856 .19493 Mdot
.856 .19497 Mdot
.856 .19612 Mdot
.856 .19707 Mdot
.856 .19762 Mdot
.856 .19774 Mdot
.856 .19868 Mdot
.856 .19871 Mdot
.856 .199 Mdot
.856 .1991 Mdot
.856 .19952 Mdot
.856 .19968 Mdot
.856 .20019 Mdot
.856 .20107 Mdot
.856 .20128 Mdot
.856 .2024 Mdot
.856 .20366 Mdot
.856 .20377 Mdot
.856 .20455 Mdot
.856 .20511 Mdot
.856 .20574 Mdot
.856 .20576 Mdot
.856 .20607 Mdot
.856 .20704 Mdot
.856 .20718 Mdot
.856 .20734 Mdot
.856 .20757 Mdot
.856 .2078 Mdot
.856 .20782 Mdot
.856 .20812 Mdot
.856 .20819 Mdot
.856 .20896 Mdot
.856 .21085 Mdot
.856 .21157 Mdot
.856 .21196 Mdot
.856 .2122 Mdot
.856 .21296 Mdot
.856 .21297 Mdot
.856 .21303 Mdot
.856 .21306 Mdot
.856 .21322 Mdot
.856 .21376 Mdot
.856 .21376 Mdot
.856 .2154 Mdot
.856 .2158 Mdot
.856 .2159 Mdot
.856 .21725 Mdot
.856 .21751 Mdot
.856 .21756 Mdot
.856 .21846 Mdot
.856 .21967 Mdot
.856 .22002 Mdot
.856 .2207 Mdot
.856 .2214 Mdot
.856 .22177 Mdot
.856 .2221 Mdot
.856 .22286 Mdot
.856 .2233 Mdot
.856 .22334 Mdot
.856 .22457 Mdot
.856 .2255 Mdot
.856 .2255 Mdot
.856 .22581 Mdot
.856 .22651 Mdot
.856 .22695 Mdot
.856 .22695 Mdot
.856 .2275 Mdot
.856 .22784 Mdot
.856 .23069 Mdot
.856 .23077 Mdot
.856 .23123 Mdot
.856 .2314 Mdot
.856 .2318 Mdot
.856 .23183 Mdot
.856 .23223 Mdot
.856 .23274 Mdot
.856 .23284 Mdot
.856 .23352 Mdot
.856 .23409 Mdot
.856 .23418 Mdot
.856 .23435 Mdot
.856 .23453 Mdot
.856 .23469 Mdot
.856 .23493 Mdot
.856 .23496 Mdot
.856 .23497 Mdot
.856 .23538 Mdot
.856 .23592 Mdot
.856 .23628 Mdot
.856 .23715 Mdot
.856 .23736 Mdot
.856 .23755 Mdot
.856 .23951 Mdot
.856 .23975 Mdot
.856 .23978 Mdot
.856 .24009 Mdot
.856 .24096 Mdot
.856 .24097 Mdot
.856 .24156 Mdot
.856 .24205 Mdot
.856 .24208 Mdot
.856 .24259 Mdot
.856 .24295 Mdot
.856 .24433 Mdot
.856 .24488 Mdot
.856 .24567 Mdot
.856 .24599 Mdot
.856 .24671 Mdot
.856 .24688 Mdot
.856 .24873 Mdot
.856 .24887 Mdot
.856 .24932 Mdot
.856 .24964 Mdot
.856 .24983 Mdot
.856 .24987 Mdot
.856 .25019 Mdot
.856 .25108 Mdot
.856 .25189 Mdot
.856 .25309 Mdot
.856 .25322 Mdot
.856 .2533 Mdot
.856 .25341 Mdot
.856 .25344 Mdot
.856 .2548 Mdot
.856 .25507 Mdot
.856 .25507 Mdot
.856 .25515 Mdot
.856 .25534 Mdot
.856 .25653 Mdot
.856 .25663 Mdot
.856 .25735 Mdot
.856 .25747 Mdot
.856 .2577 Mdot
.856 .25795 Mdot
.856 .25807 Mdot
.856 .25844 Mdot
.856 .25861 Mdot
.856 .25902 Mdot
.856 .25934 Mdot
.856 .25945 Mdot
.856 .25984 Mdot
.856 .25984 Mdot
.856 .26014 Mdot
.856 .26111 Mdot
.856 .26332 Mdot
.856 .2642 Mdot
.856 .26422 Mdot
.856 .26482 Mdot
.856 .2653 Mdot
.856 .26595 Mdot
.856 .26622 Mdot
.856 .26658 Mdot
.856 .26727 Mdot
.856 .26943 Mdot
.856 .26993 Mdot
.856 .26997 Mdot
.856 .27064 Mdot
.856 .27093 Mdot
.856 .27149 Mdot
.856 .27276 Mdot
.856 .27315 Mdot
.856 .27359 Mdot
.856 .27433 Mdot
.856 .2745 Mdot
.856 .27451 Mdot
.856 .27474 Mdot
.856 .27606 Mdot
.856 .27725 Mdot
.856 .27743 Mdot
.856 .27798 Mdot
.856 .27812 Mdot
.856 .27827 Mdot
.856 .27851 Mdot
.856 .27895 Mdot
.856 .28012 Mdot
.856 .28054 Mdot
.856 .28097 Mdot
.856 .28134 Mdot
.856 .28167 Mdot
.856 .28296 Mdot
.856 .28335 Mdot
.856 .28338 Mdot
.856 .28383 Mdot
.856 .28409 Mdot
.856 .28634 Mdot
.856 .28641 Mdot
.856 .28763 Mdot
.856 .28883 Mdot
.856 .28888 Mdot
.856 .28894 Mdot
.856 .28894 Mdot
.856 .28896 Mdot
.856 .28897 Mdot
.856 .28901 Mdot
.856 .28996 Mdot
.856 .29094 Mdot
.856 .29131 Mdot
.856 .29149 Mdot
.856 .29168 Mdot
.856 .29333 Mdot
.856 .29467 Mdot
.856 .29473 Mdot
.856 .29587 Mdot
.856 .29595 Mdot
.856 .29726 Mdot
.856 .29801 Mdot
.856 .29804 Mdot
.856 .29856 Mdot
.856 .29877 Mdot
.856 .30022 Mdot
.856 .30053 Mdot
.856 .303 Mdot
.856 .30314 Mdot
.856 .3043 Mdot
.856 .30463 Mdot
.856 .30483 Mdot
.856 .30527 Mdot
.856 .30623 Mdot
.856 .30661 Mdot
.856 .30696 Mdot
.856 .30761 Mdot
.856 .30842 Mdot
.856 .30858 Mdot
.856 .30859 Mdot
.856 .30977 Mdot
.856 .31046 Mdot
.856 .31093 Mdot
.856 .31192 Mdot
.856 .31207 Mdot
.856 .31221 Mdot
.856 .31223 Mdot
.856 .31226 Mdot
.856 .31232 Mdot
.856 .31234 Mdot
.856 .31245 Mdot
.856 .31257 Mdot
.856 .31281 Mdot
.856 .31299 Mdot
.856 .31306 Mdot
.856 .31432 Mdot
.856 .31467 Mdot
.856 .31468 Mdot
.856 .31497 Mdot
.856 .31524 Mdot
.856 .31567 Mdot
.856 .31811 Mdot
.856 .31902 Mdot
.856 .31906 Mdot
.856 .31912 Mdot
.856 .31914 Mdot
.856 .31918 Mdot
.856 .31973 Mdot
.856 .32006 Mdot
.856 .32027 Mdot
.856 .32232 Mdot
.856 .32235 Mdot
.856 .32291 Mdot
.856 .32301 Mdot
.856 .32325 Mdot
.856 .3233 Mdot
.856 .32512 Mdot
.856 .32527 Mdot
.856 .3269 Mdot
.856 .32786 Mdot
.856 .32805 Mdot
.856 .32905 Mdot
.856 .3292 Mdot
.856 .32966 Mdot
.856 .32971 Mdot
.856 .33022 Mdot
.856 .33038 Mdot
.856 .33109 Mdot
.856 .33138 Mdot
.856 .33224 Mdot
.856 .33256 Mdot
.856 .33278 Mdot
.856 .33376 Mdot
.856 .33411 Mdot
.856 .33603 Mdot
.856 .33663 Mdot
.856 .33818 Mdot
.856 .33839 Mdot
.856 .33884 Mdot
.856 .33893 Mdot
.856 .33972 Mdot
.856 .34043 Mdot
.856 .34067 Mdot
.856 .34106 Mdot
.856 .34175 Mdot
.856 .34232 Mdot
.856 .34397 Mdot
.856 .34422 Mdot
.856 .34449 Mdot
.856 .34488 Mdot
.856 .34527 Mdot
.856 .34531 Mdot
.856 .34532 Mdot
.856 .34582 Mdot
.856 .34594 Mdot
.856 .34621 Mdot
.856 .34726 Mdot
.856 .35049 Mdot
.856 .35173 Mdot
.856 .3524 Mdot
.856 .3528 Mdot
.856 .35345 Mdot
.856 .35387 Mdot
.856 .35412 Mdot
.856 .35413 Mdot
.856 .35424 Mdot
.856 .35428 Mdot
.856 .35455 Mdot
.856 .35549 Mdot
.856 .35549 Mdot
.856 .35725 Mdot
.856 .35824 Mdot
.856 .3583 Mdot
.856 .35882 Mdot
.856 .35897 Mdot
.856 .35915 Mdot
.856 .36012 Mdot
.856 .36146 Mdot
.856 .3619 Mdot
.856 .36199 Mdot
.856 .36292 Mdot
.856 .36353 Mdot
.856 .36403 Mdot
.856 .36505 Mdot
.856 .36559 Mdot
.856 .36619 Mdot
.856 .36696 Mdot
.856 .36736 Mdot
.856 .36857 Mdot
.856 .3692 Mdot
.856 .36934 Mdot
.856 .36976 Mdot
.856 .3698 Mdot
.856 .36984 Mdot
.856 .37107 Mdot
.856 .37182 Mdot
.856 .37188 Mdot
.856 .3733 Mdot
.856 .37398 Mdot
.856 .37557 Mdot
.856 .37558 Mdot
.856 .37612 Mdot
.856 .37731 Mdot
.856 .37806 Mdot
.856 .37807 Mdot
.856 .379 Mdot
.856 .37959 Mdot
.856 .38446 Mdot
.856 .38461 Mdot
.856 .38539 Mdot
.856 .38568 Mdot
.856 .38636 Mdot
.856 .38642 Mdot
.856 .38709 Mdot
.856 .38797 Mdot
.856 .38814 Mdot
.856 .38931 Mdot
.856 .39029 Mdot
.856 .39044 Mdot
.856 .39074 Mdot
.856 .39104 Mdot
.856 .39132 Mdot
.856 .39173 Mdot
.856 .39177 Mdot
.856 .3918 Mdot
.856 .39249 Mdot
.856 .39343 Mdot
.856 .39403 Mdot
.856 .39552 Mdot
.856 .39589 Mdot
.856 .39621 Mdot
.856 .39956 Mdot
.856 .39997 Mdot
.856 .40003 Mdot
.856 .40055 Mdot
.856 .40205 Mdot
.856 .40206 Mdot
.856 .40307 Mdot
.856 .40392 Mdot
.856 .40396 Mdot
.856 .40483 Mdot
.856 .40546 Mdot
.856 .40781 Mdot
.856 .40876 Mdot
.856 .41011 Mdot
.856 .41066 Mdot
.856 .4119 Mdot
.856 .41219 Mdot
.856 .41535 Mdot
.856 .41558 Mdot
.856 .41635 Mdot
.856 .41691 Mdot
.856 .41724 Mdot
.856 .4173 Mdot
.856 .41785 Mdot
.856 .41937 Mdot
.856 .42076 Mdot
.856 .42282 Mdot
.856 .42304 Mdot
.856 .42318 Mdot
.856 .42336 Mdot
.856 .42341 Mdot
.856 .42575 Mdot
.856 .4262 Mdot
.856 .4262 Mdot
.856 .42634 Mdot
.856 .42666 Mdot
.856 .4287 Mdot
.856 .42888 Mdot
.856 .43011 Mdot
.856 .43031 Mdot
.856 .43071 Mdot
.856 .43113 Mdot
.856 .43134 Mdot
.856 .43198 Mdot
.856 .43226 Mdot
.856 .43297 Mdot
.856 .43352 Mdot
.856 .4337 Mdot
.856 .43436 Mdot
.856 .43437 Mdot
.856 .43489 Mdot
.856 .43655 Mdot
.856 .44032 Mdot
.856 .44184 Mdot
.856 .44186 Mdot
.856 .4429 Mdot
.856 .44371 Mdot
.856 .44484 Mdot
.856 .4453 Mdot
.856 .44591 Mdot
.856 .44709 Mdot
.856 .44984 Mdot
.856 .45079 Mdot
.856 .45164 Mdot
.856 .4517 Mdot
.856 .45286 Mdot
.856 .45335 Mdot
.856 .45432 Mdot
.856 .45649 Mdot
.856 .45715 Mdot
.856 .45792 Mdot
.856 .45918 Mdot
.856 .45947 Mdot
.856 .45949 Mdot
.856 .45988 Mdot
.856 .46214 Mdot
.856 .46417 Mdot
.856 .46448 Mdot
.856 .46543 Mdot
.856 .46567 Mdot
.856 .46592 Mdot
.856 .46633 Mdot
.856 .46708 Mdot
.856 .4691 Mdot
.856 .46981 Mdot
.856 .47054 Mdot
.856 .47117 Mdot
.856 .47174 Mdot
.856 .47395 Mdot
.856 .47462 Mdot
.856 .47467 Mdot
.856 .47543 Mdot
.856 .47589 Mdot
.856 .47974 Mdot
.856 .47986 Mdot
.856 .48195 Mdot
.856 .484 Mdot
.856 .48409 Mdot
.856 .48418 Mdot
.856 .48419 Mdot
.856 .48423 Mdot
.856 .48424 Mdot
.856 .48431 Mdot
.856 .48593 Mdot
.856 .48761 Mdot
.856 .48824 Mdot
.856 .48856 Mdot
.856 .48887 Mdot
.856 .49171 Mdot
.856 .494 Mdot
.856 .49409 Mdot
.856 .49605 Mdot
.856 .49618 Mdot
.856 .49843 Mdot
.856 .49972 Mdot
.856 .49977 Mdot
.856 .50065 Mdot
.856 .50102 Mdot
.856 .5035 Mdot
.856 .50402 Mdot
.856 .50826 Mdot
.856 .5085 Mdot
.856 .51048 Mdot
.856 .51106 Mdot
.856 .51139 Mdot
.856 .51215 Mdot
.856 .51379 Mdot
.856 .51443 Mdot
.856 .51503 Mdot
.856 .51615 Mdot
.856 .51753 Mdot
.856 .51781 Mdot
.856 .51783 Mdot
.856 .51985 Mdot
.858 .01608 Mdot
.858 .01706 Mdot
.858 .01775 Mdot
.858 .01777 Mdot
.858 .0181 Mdot
.858 .01843 Mdot
.858 .01874 Mdot
.858 .01925 Mdot
.858 .01993 Mdot
.858 .01995 Mdot
.858 .02053 Mdot
.858 .02108 Mdot
.858 .02162 Mdot
.858 .02249 Mdot
.858 .02288 Mdot
.858 .02309 Mdot
.858 .02366 Mdot
.858 .02367 Mdot
.858 .02371 Mdot
.858 .02373 Mdot
.858 .02396 Mdot
.858 .0244 Mdot
.858 .02465 Mdot
.858 .02469 Mdot
.858 .02563 Mdot
.858 .02564 Mdot
.858 .02606 Mdot
.858 .02657 Mdot
.858 .02659 Mdot
.858 .02671 Mdot
.858 .02758 Mdot
.858 .02806 Mdot
.858 .02867 Mdot
.858 .02873 Mdot
.858 .02909 Mdot
.858 .02973 Mdot
.858 .03006 Mdot
.858 .03008 Mdot
.858 .03014 Mdot
.858 .03018 Mdot
.858 .0304 Mdot
.858 .03058 Mdot
.858 .03067 Mdot
.858 .0313 Mdot
.858 .03133 Mdot
.858 .03177 Mdot
.858 .03183 Mdot
.858 .03195 Mdot
.858 .03266 Mdot
.858 .03285 Mdot
.858 .03293 Mdot
.858 .03345 Mdot
.858 .03347 Mdot
.858 .03418 Mdot
.858 .03506 Mdot
.858 .03509 Mdot
.858 .0352 Mdot
.858 .0353 Mdot
.858 .03539 Mdot
.858 .0354 Mdot
.858 .03678 Mdot
.858 .03752 Mdot
.858 .03761 Mdot
.858 .03766 Mdot
.858 .03767 Mdot
.858 .03821 Mdot
.858 .03866 Mdot
.858 .03877 Mdot
.858 .03882 Mdot
.858 .03939 Mdot
.858 .04049 Mdot
.858 .04105 Mdot
.858 .04108 Mdot
.858 .04119 Mdot
.858 .04126 Mdot
.858 .04164 Mdot
.858 .04194 Mdot
.858 .04209 Mdot
.858 .04318 Mdot
.858 .04322 Mdot
.858 .04398 Mdot
.858 .04408 Mdot
.858 .04429 Mdot
.858 .04435 Mdot
.858 .0447 Mdot
.858 .04496 Mdot
.858 .04551 Mdot
.858 .04553 Mdot
.858 .04571 Mdot
.858 .04584 Mdot
.858 .04597 Mdot
.858 .04599 Mdot
.858 .04658 Mdot
.858 .04669 Mdot
.858 .04686 Mdot
.858 .04689 Mdot
.858 .04721 Mdot
.858 .04812 Mdot
.858 .0483 Mdot
.858 .0485 Mdot
.858 .04853 Mdot
.858 .04902 Mdot
.858 .04962 Mdot
.858 .04968 Mdot
.858 .04975 Mdot
.858 .04987 Mdot
.858 .05004 Mdot
.858 .05019 Mdot
.858 .0502 Mdot
.858 .05166 Mdot
.858 .05259 Mdot
.858 .05327 Mdot
.858 .05344 Mdot
.858 .05385 Mdot
.858 .05401 Mdot
.858 .05409 Mdot
.858 .05411 Mdot
.858 .05444 Mdot
.858 .05456 Mdot
.858 .05479 Mdot
.858 .05503 Mdot
.858 .0558 Mdot
.858 .05599 Mdot
.858 .05602 Mdot
.858 .05608 Mdot
.858 .05698 Mdot
.858 .05705 Mdot
.858 .05894 Mdot
.858 .05903 Mdot
.858 .0599 Mdot
.858 .05995 Mdot
.858 .06014 Mdot
.858 .06026 Mdot
.858 .06034 Mdot
.858 .06035 Mdot
.858 .06092 Mdot
.858 .06095 Mdot
.858 .06144 Mdot
.858 .06163 Mdot
.858 .06168 Mdot
.858 .06356 Mdot
.858 .06364 Mdot
.858 .06426 Mdot
.858 .06493 Mdot
.858 .06511 Mdot
.858 .06546 Mdot
.858 .06557 Mdot
.858 .06565 Mdot
.858 .06616 Mdot
.858 .06646 Mdot
.858 .06661 Mdot
.858 .06667 Mdot
.858 .06755 Mdot
.858 .06759 Mdot
.858 .06789 Mdot
.858 .06789 Mdot
.858 .06812 Mdot
.858 .06836 Mdot
.858 .06839 Mdot
.858 .06858 Mdot
.858 .06864 Mdot
.858 .06902 Mdot
.858 .06939 Mdot
.858 .06959 Mdot
.858 .06987 Mdot
.858 .06993 Mdot
.858 .07047 Mdot
.858 .07052 Mdot
.858 .07081 Mdot
.858 .07113 Mdot
.858 .07116 Mdot
.858 .07203 Mdot
.858 .07235 Mdot
.858 .0727 Mdot
.858 .07275 Mdot
.858 .07312 Mdot
.858 .07358 Mdot
.858 .07358 Mdot
.858 .07362 Mdot
.858 .0743 Mdot
.858 .07461 Mdot
.858 .07471 Mdot
.858 .07484 Mdot
.858 .07504 Mdot
.858 .07507 Mdot
.858 .07533 Mdot
.858 .07559 Mdot
.858 .07561 Mdot
.858 .0768 Mdot
.858 .07713 Mdot
.858 .07783 Mdot
.858 .07811 Mdot
.858 .07834 Mdot
.858 .0792 Mdot
.858 .0797 Mdot
.858 .08088 Mdot
.858 .08104 Mdot
.858 .08116 Mdot
.858 .08188 Mdot
.858 .08215 Mdot
.858 .08229 Mdot
.858 .08231 Mdot
.858 .08245 Mdot
.858 .08288 Mdot
.858 .08308 Mdot
.858 .08349 Mdot
.858 .08351 Mdot
.858 .0839 Mdot
.858 .08415 Mdot
.858 .08522 Mdot
.858 .08554 Mdot
.858 .08559 Mdot
.858 .08569 Mdot
.858 .08725 Mdot
.858 .08737 Mdot
.858 .08836 Mdot
.858 .0897 Mdot
.858 .09061 Mdot
.858 .09075 Mdot
.858 .09187 Mdot
.858 .09195 Mdot
.858 .09203 Mdot
.858 .09225 Mdot
.858 .09234 Mdot
.858 .09267 Mdot
.858 .09287 Mdot
.858 .093 Mdot
.858 .09302 Mdot
.858 .09325 Mdot
.858 .09345 Mdot
.858 .09346 Mdot
.858 .094 Mdot
.858 .09405 Mdot
.858 .09466 Mdot
.858 .09489 Mdot
.858 .09521 Mdot
.858 .09531 Mdot
.858 .09643 Mdot
.858 .09834 Mdot
.858 .09835 Mdot
.858 .09853 Mdot
.858 .09867 Mdot
.858 .09961 Mdot
.858 .09973 Mdot
.858 .10013 Mdot
.858 .10016 Mdot
.858 .10053 Mdot
.858 .10088 Mdot
.858 .10119 Mdot
.858 .10179 Mdot
.858 .10198 Mdot
.858 .10212 Mdot
.858 .103 Mdot
.858 .10352 Mdot
.858 .10368 Mdot
.858 .10376 Mdot
.858 .10386 Mdot
.858 .10387 Mdot
.858 .10461 Mdot
.858 .10539 Mdot
.858 .10545 Mdot
.858 .10563 Mdot
.858 .10591 Mdot
.858 .10596 Mdot
.858 .10597 Mdot
.858 .1062 Mdot
.858 .10636 Mdot
.858 .10676 Mdot
.858 .10681 Mdot
.858 .10715 Mdot
.858 .10725 Mdot
.858 .10725 Mdot
.858 .10789 Mdot
.858 .10809 Mdot
.858 .10813 Mdot
.858 .10854 Mdot
.858 .10887 Mdot
.858 .10936 Mdot
.858 .10943 Mdot
.858 .10947 Mdot
.858 .1104 Mdot
.858 .11048 Mdot
.858 .11098 Mdot
.858 .11153 Mdot
.858 .11157 Mdot
.858 .11307 Mdot
.858 .1131 Mdot
.858 .11361 Mdot
.858 .11421 Mdot
.858 .1143 Mdot
.858 .11494 Mdot
.858 .1154 Mdot
.858 .11573 Mdot
.858 .11573 Mdot
.858 .1158 Mdot
.858 .11602 Mdot
.858 .11696 Mdot
.858 .11709 Mdot
.858 .1175 Mdot
.858 .11767 Mdot
.858 .11789 Mdot
.858 .11823 Mdot
.858 .11828 Mdot
.858 .11841 Mdot
.858 .11854 Mdot
.858 .11872 Mdot
.858 .11873 Mdot
.858 .11918 Mdot
.858 .11922 Mdot
.858 .12126 Mdot
.858 .12146 Mdot
.858 .12156 Mdot
.858 .12181 Mdot
.858 .12182 Mdot
.858 .12192 Mdot
.858 .12244 Mdot
.858 .12276 Mdot
.858 .12279 Mdot
.858 .12301 Mdot
.858 .12306 Mdot
.858 .12349 Mdot
.858 .1239 Mdot
.858 .12428 Mdot
.858 .12537 Mdot
.858 .12623 Mdot
.858 .12669 Mdot
.858 .12692 Mdot
.858 .12707 Mdot
.858 .12742 Mdot
.858 .12789 Mdot
.858 .12825 Mdot
.858 .12853 Mdot
.858 .12874 Mdot
.858 .12997 Mdot
.858 .13043 Mdot
.858 .13067 Mdot
.858 .13071 Mdot
.858 .13095 Mdot
.858 .13168 Mdot
.858 .13203 Mdot
.858 .13273 Mdot
.858 .13277 Mdot
.858 .13323 Mdot
.858 .13344 Mdot
.858 .13387 Mdot
.858 .13567 Mdot
.858 .13571 Mdot
.858 .13625 Mdot
.858 .13627 Mdot
.858 .13634 Mdot
.858 .13651 Mdot
.858 .13729 Mdot
.858 .13858 Mdot
.858 .13918 Mdot
.858 .13938 Mdot
.858 .14109 Mdot
.858 .1434 Mdot
.858 .14494 Mdot
.858 .14519 Mdot
.858 .14591 Mdot
.858 .14712 Mdot
.858 .14726 Mdot
.858 .14738 Mdot
.858 .14777 Mdot
.858 .14792 Mdot
.858 .14838 Mdot
.858 .14849 Mdot
.858 .14865 Mdot
.858 .14883 Mdot
.858 .14905 Mdot
.858 .14908 Mdot
.858 .14948 Mdot
.858 .14983 Mdot
.858 .14983 Mdot
.858 .15076 Mdot
.858 .15085 Mdot
.858 .1519 Mdot
.858 .15229 Mdot
.858 .15285 Mdot
.858 .15302 Mdot
.858 .15319 Mdot
.858 .15493 Mdot
.858 .15677 Mdot
.858 .15755 Mdot
.858 .15821 Mdot
.858 .15823 Mdot
.858 .15853 Mdot
.858 .15877 Mdot
.858 .1604 Mdot
.858 .16045 Mdot
.858 .16061 Mdot
.858 .16128 Mdot
.858 .16133 Mdot
.858 .16197 Mdot
.858 .16257 Mdot
.858 .16311 Mdot
.858 .16413 Mdot
.858 .16446 Mdot
.858 .1647 Mdot
.858 .16537 Mdot
.858 .16622 Mdot
.858 .16664 Mdot
.858 .1671 Mdot
.858 .16738 Mdot
.858 .16752 Mdot
.858 .16769 Mdot
.858 .1677 Mdot
.858 .16898 Mdot
.858 .17027 Mdot
.858 .17031 Mdot
.858 .17041 Mdot
.858 .17072 Mdot
.858 .17121 Mdot
.858 .17129 Mdot
.858 .17131 Mdot
.858 .17171 Mdot
.858 .17198 Mdot
.858 .17267 Mdot
.858 .17276 Mdot
.858 .17333 Mdot
.858 .1735 Mdot
.858 .17351 Mdot
.858 .17459 Mdot
.858 .17461 Mdot
.858 .17495 Mdot
.858 .17501 Mdot
.858 .17571 Mdot
.858 .17629 Mdot
.858 .17635 Mdot
.858 .17706 Mdot
.858 .17713 Mdot
.858 .17725 Mdot
.858 .17732 Mdot
.858 .17768 Mdot
.858 .1789 Mdot
.858 .17905 Mdot
.858 .17964 Mdot
.858 .17991 Mdot
.858 .18043 Mdot
.858 .18084 Mdot
.858 .18092 Mdot
.858 .18098 Mdot
.858 .18165 Mdot
.858 .18272 Mdot
.858 .18329 Mdot
.858 .1835 Mdot
.858 .18354 Mdot
.858 .18401 Mdot
.858 .18413 Mdot
.858 .18442 Mdot
.858 .18499 Mdot
.858 .18533 Mdot
.858 .18545 Mdot
.858 .1856 Mdot
.858 .18614 Mdot
.858 .18628 Mdot
.858 .1867 Mdot
.858 .18749 Mdot
.858 .18805 Mdot
.858 .18806 Mdot
.858 .18817 Mdot
.858 .18828 Mdot
.858 .18856 Mdot
.858 .19006 Mdot
.858 .19008 Mdot
.858 .19016 Mdot
.858 .1904 Mdot
.858 .1911 Mdot
.858 .19139 Mdot
.858 .19176 Mdot
.858 .19235 Mdot
.858 .19244 Mdot
.858 .19266 Mdot
.858 .19288 Mdot
.858 .19318 Mdot
.858 .19321 Mdot
.858 .19398 Mdot
.858 .19404 Mdot
.858 .19405 Mdot
.858 .19477 Mdot
.858 .19482 Mdot
.858 .19521 Mdot
.858 .19755 Mdot
.858 .19788 Mdot
.858 .19806 Mdot
.858 .1985 Mdot
.858 .19851 Mdot
.858 .19867 Mdot
.858 .19957 Mdot
.858 .20012 Mdot
.858 .20017 Mdot
.858 .20051 Mdot
.858 .20055 Mdot
.858 .20063 Mdot
.858 .20138 Mdot
.858 .20207 Mdot
.858 .20252 Mdot
.858 .20272 Mdot
.858 .20432 Mdot
.858 .2046 Mdot
.858 .20508 Mdot
.858 .20534 Mdot
.858 .20607 Mdot
.858 .20619 Mdot
.858 .20686 Mdot
.858 .20703 Mdot
.858 .20726 Mdot
.858 .20752 Mdot
.858 .20811 Mdot
.858 .20892 Mdot
.858 .20955 Mdot
.858 .21003 Mdot
.858 .21039 Mdot
.858 .21249 Mdot
.858 .21323 Mdot
.858 .21328 Mdot
.858 .21369 Mdot
.858 .21376 Mdot
.858 .21417 Mdot
.858 .21477 Mdot
.858 .21543 Mdot
.858 .21586 Mdot
.858 .21603 Mdot
.858 .21724 Mdot
.858 .2173 Mdot
.858 .21809 Mdot
.858 .21845 Mdot
.858 .21919 Mdot
.858 .22122 Mdot
.858 .22228 Mdot
.858 .22234 Mdot
.858 .22327 Mdot
.858 .22331 Mdot
.858 .22343 Mdot
.858 .22371 Mdot
.858 .22505 Mdot
.858 .22513 Mdot
.858 .22727 Mdot
.858 .2281 Mdot
.858 .2283 Mdot
.858 .22865 Mdot
.858 .22909 Mdot
.858 .23158 Mdot
.858 .23241 Mdot
.858 .23251 Mdot
.858 .23405 Mdot
.858 .23526 Mdot
.858 .23553 Mdot
.858 .23651 Mdot
.858 .23819 Mdot
.858 .23862 Mdot
.858 .23985 Mdot
.858 .24132 Mdot
.858 .24192 Mdot
.858 .24216 Mdot
.858 .24237 Mdot
.858 .24303 Mdot
.858 .2433 Mdot
.858 .24349 Mdot
.858 .24371 Mdot
.858 .24408 Mdot
.858 .24427 Mdot
.858 .24452 Mdot
.858 .24456 Mdot
.858 .24485 Mdot
.858 .24496 Mdot
.858 .24524 Mdot
.858 .24529 Mdot
.858 .24597 Mdot
.858 .24657 Mdot
.858 .24658 Mdot
.858 .24792 Mdot
.858 .24817 Mdot
.858 .24819 Mdot
.858 .24832 Mdot
.858 .25012 Mdot
.858 .2508 Mdot
.858 .25141 Mdot
.858 .25167 Mdot
.858 .25176 Mdot
.858 .25205 Mdot
.858 .25233 Mdot
.858 .25444 Mdot
.858 .25496 Mdot
.858 .25533 Mdot
.858 .25715 Mdot
.858 .25848 Mdot
.858 .25949 Mdot
.858 .25982 Mdot
.858 .26095 Mdot
.858 .26099 Mdot
.858 .26151 Mdot
.858 .26192 Mdot
.858 .26235 Mdot
.858 .26398 Mdot
.858 .26471 Mdot
.858 .26479 Mdot
.858 .26506 Mdot
.858 .26522 Mdot
.858 .26622 Mdot
.858 .26631 Mdot
.858 .26741 Mdot
.858 .26749 Mdot
.858 .26843 Mdot
.858 .26861 Mdot
.858 .26935 Mdot
.858 .27015 Mdot
.858 .27112 Mdot
.858 .27167 Mdot
.858 .27209 Mdot
.858 .27287 Mdot
.858 .27325 Mdot
.858 .27377 Mdot
.858 .27469 Mdot
.858 .275 Mdot
.858 .27541 Mdot
.858 .27621 Mdot
.858 .27669 Mdot
.858 .27693 Mdot
.858 .27721 Mdot
.858 .27724 Mdot
.858 .27733 Mdot
.858 .27875 Mdot
.858 .27944 Mdot
.858 .27945 Mdot
.858 .28029 Mdot
.858 .28037 Mdot
.858 .28065 Mdot
.858 .28165 Mdot
.858 .28171 Mdot
.858 .2819 Mdot
.858 .28241 Mdot
.858 .28297 Mdot
.858 .28326 Mdot
.858 .28339 Mdot
.858 .28343 Mdot
.858 .28412 Mdot
.858 .28459 Mdot
.858 .28483 Mdot
.858 .28577 Mdot
.858 .28591 Mdot
.858 .28684 Mdot
.858 .28688 Mdot
.858 .2869 Mdot
.858 .28719 Mdot
.858 .28721 Mdot
.858 .28905 Mdot
.858 .28909 Mdot
.858 .28935 Mdot
.858 .2896 Mdot
.858 .28968 Mdot
.858 .28979 Mdot
.858 .29041 Mdot
.858 .29099 Mdot
.858 .29198 Mdot
.858 .29209 Mdot
.858 .2933 Mdot
.858 .29337 Mdot
.858 .29342 Mdot
.858 .29353 Mdot
.858 .29363 Mdot
.858 .29374 Mdot
.858 .29408 Mdot
.858 .29437 Mdot
.858 .29561 Mdot
.858 .29646 Mdot
.858 .29672 Mdot
.858 .29724 Mdot
.858 .29772 Mdot
.858 .2981 Mdot
.858 .29818 Mdot
.858 .29848 Mdot
.858 .2986 Mdot
.858 .29909 Mdot
.858 .29979 Mdot
.858 .29993 Mdot
.858 .30003 Mdot
.858 .30063 Mdot
.858 .30118 Mdot
.858 .30201 Mdot
.858 .30272 Mdot
.858 .30302 Mdot
.858 .30399 Mdot
.858 .30435 Mdot
.858 .30442 Mdot
.858 .30523 Mdot
.858 .30543 Mdot
.858 .30548 Mdot
.858 .30592 Mdot
.858 .30592 Mdot
.858 .30691 Mdot
.858 .30749 Mdot
.858 .3077 Mdot
.858 .30796 Mdot
.858 .30863 Mdot
.858 .30875 Mdot
.858 .30882 Mdot
.858 .30888 Mdot
.858 .30912 Mdot
.858 .30967 Mdot
.858 .30974 Mdot
.858 .30983 Mdot
.858 .31119 Mdot
.858 .31217 Mdot
.858 .31218 Mdot
.858 .31237 Mdot
.858 .31256 Mdot
.858 .31304 Mdot
.858 .31516 Mdot
.858 .31528 Mdot
.858 .31561 Mdot
.858 .31565 Mdot
.858 .31578 Mdot
.858 .31604 Mdot
.858 .31619 Mdot
.858 .31676 Mdot
.858 .31701 Mdot
.858 .31732 Mdot
.858 .31739 Mdot
.858 .31789 Mdot
.858 .31853 Mdot
.858 .31915 Mdot
.858 .31954 Mdot
.858 .31969 Mdot
.858 .32006 Mdot
.858 .32044 Mdot
.858 .32085 Mdot
.858 .32097 Mdot
.858 .32101 Mdot
.858 .32233 Mdot
.858 .32244 Mdot
.858 .32245 Mdot
.858 .32369 Mdot
.858 .32377 Mdot
.858 .32377 Mdot
.858 .32409 Mdot
.858 .32444 Mdot
.858 .32767 Mdot
.858 .32787 Mdot
.858 .32802 Mdot
.858 .32835 Mdot
.858 .32846 Mdot
.858 .32862 Mdot
.858 .32896 Mdot
.858 .32903 Mdot
.858 .32933 Mdot
.858 .32997 Mdot
.858 .33009 Mdot
.858 .3301 Mdot
.858 .33039 Mdot
.858 .33081 Mdot
.858 .33192 Mdot
.858 .33287 Mdot
.858 .33296 Mdot
.858 .33354 Mdot
.858 .33361 Mdot
.858 .33375 Mdot
.858 .33447 Mdot
.858 .33503 Mdot
.858 .33622 Mdot
.858 .33698 Mdot
.858 .33699 Mdot
.858 .33734 Mdot
.858 .33773 Mdot
.858 .33927 Mdot
.858 .34008 Mdot
.858 .34055 Mdot
.858 .34067 Mdot
.858 .34138 Mdot
.858 .34179 Mdot
.858 .34182 Mdot
.858 .34204 Mdot
.858 .34292 Mdot
.858 .34309 Mdot
.858 .34327 Mdot
.858 .34329 Mdot
.858 .34443 Mdot
.858 .3447 Mdot
.858 .34472 Mdot
.858 .34512 Mdot
.858 .34557 Mdot
.858 .34658 Mdot
.858 .34677 Mdot
.858 .34717 Mdot
.858 .34747 Mdot
.858 .34797 Mdot
.858 .34905 Mdot
.858 .34987 Mdot
.858 .35049 Mdot
.858 .35086 Mdot
.858 .35331 Mdot
.858 .3541 Mdot
.858 .35536 Mdot
.858 .35541 Mdot
.858 .35545 Mdot
.858 .35616 Mdot
.858 .35628 Mdot
.858 .35628 Mdot
.858 .35698 Mdot
.858 .35801 Mdot
.858 .35913 Mdot
.858 .35913 Mdot
.858 .35987 Mdot
.858 .36017 Mdot
.858 .36019 Mdot
.858 .3604 Mdot
.858 .36224 Mdot
.858 .36234 Mdot
.858 .36278 Mdot
.858 .36337 Mdot
.858 .36354 Mdot
.858 .36371 Mdot
.858 .36432 Mdot
.858 .36481 Mdot
.858 .36483 Mdot
.858 .36559 Mdot
.858 .36773 Mdot
.858 .36907 Mdot
.858 .36943 Mdot
.858 .37006 Mdot
.858 .37082 Mdot
.858 .3709 Mdot
.858 .371 Mdot
.858 .3726 Mdot
.858 .37266 Mdot
.858 .37281 Mdot
.858 .37287 Mdot
.858 .37317 Mdot
.858 .37336 Mdot
.858 .37338 Mdot
.858 .37353 Mdot
.858 .37424 Mdot
.858 .37565 Mdot
.858 .37578 Mdot
.858 .37587 Mdot
.858 .37607 Mdot
.858 .37635 Mdot
.858 .37946 Mdot
.858 .38089 Mdot
.858 .38123 Mdot
.858 .38183 Mdot
.858 .38258 Mdot
.858 .38685 Mdot
.858 .38829 Mdot
.858 .38845 Mdot
.858 .39109 Mdot
.858 .39318 Mdot
.858 .39363 Mdot
.858 .39532 Mdot
.858 .39819 Mdot
.858 .39893 Mdot
.858 .40105 Mdot
.858 .40356 Mdot
.858 .40459 Mdot
.858 .405 Mdot
.858 .40537 Mdot
.858 .4065 Mdot
.858 .40697 Mdot
.858 .40729 Mdot
.858 .40768 Mdot
.858 .4083 Mdot
.858 .40863 Mdot
.858 .40905 Mdot
.858 .40912 Mdot
.858 .40962 Mdot
.858 .40982 Mdot
.858 .41029 Mdot
.858 .41038 Mdot
.858 .41154 Mdot
.858 .41258 Mdot
.858 .41259 Mdot
.858 .4149 Mdot
.858 .41532 Mdot
.858 .41535 Mdot
.858 .41558 Mdot
.858 .41867 Mdot
.858 .41984 Mdot
.858 .42089 Mdot
.858 .42133 Mdot
.858 .42148 Mdot
.858 .42198 Mdot
.858 .42247 Mdot
.858 .42608 Mdot
.858 .42698 Mdot
.858 .42761 Mdot
.858 .43073 Mdot
.858 .43301 Mdot
.858 .43475 Mdot
.858 .43532 Mdot
.858 .43726 Mdot
.858 .43732 Mdot
.858 .43821 Mdot
.858 .43892 Mdot
.858 .43965 Mdot
.858 .44245 Mdot
.858 .44371 Mdot
.858 .44385 Mdot
.858 .44431 Mdot
.858 .44457 Mdot
.858 .4463 Mdot
.858 .44645 Mdot
.858 .44833 Mdot
.858 .44848 Mdot
.858 .45009 Mdot
.858 .4504 Mdot
.858 .45168 Mdot
.858 .45304 Mdot
.858 .4547 Mdot
.858 .45565 Mdot
.858 .45638 Mdot
.858 .4577 Mdot
.858 .45835 Mdot
.858 .45925 Mdot
.858 .46083 Mdot
.858 .46136 Mdot
.858 .46208 Mdot
.858 .46344 Mdot
.858 .46426 Mdot
.858 .46467 Mdot
.858 .46516 Mdot
.858 .46521 Mdot
.858 .46537 Mdot
.858 .46781 Mdot
.858 .46898 Mdot
.858 .469 Mdot
.858 .47044 Mdot
.858 .47058 Mdot
.858 .47106 Mdot
.858 .47278 Mdot
.858 .47288 Mdot
.858 .4732 Mdot
.858 .47409 Mdot
.858 .47504 Mdot
.858 .47554 Mdot
.858 .47576 Mdot
.858 .47583 Mdot
.858 .47701 Mdot
.858 .47782 Mdot
.858 .47823 Mdot
.858 .47984 Mdot
.858 .48009 Mdot
.858 .48168 Mdot
.858 .48175 Mdot
.858 .48179 Mdot
.858 .48228 Mdot
.858 .48232 Mdot
.858 .48548 Mdot
.858 .48555 Mdot
.858 .48599 Mdot
.858 .48641 Mdot
.858 .48656 Mdot
.858 .48674 Mdot
.858 .4878 Mdot
.858 .4888 Mdot
.858 .4905 Mdot
.858 .49068 Mdot
.858 .49277 Mdot
.858 .49289 Mdot
.858 .49297 Mdot
.858 .49317 Mdot
.858 .49333 Mdot
.858 .49352 Mdot
.858 .49411 Mdot
.858 .4946 Mdot
.858 .49673 Mdot
.858 .4982 Mdot
.858 .49864 Mdot
.858 .49953 Mdot
.858 .50035 Mdot
.858 .501 Mdot
.858 .50114 Mdot
.858 .50166 Mdot
.858 .50186 Mdot
.858 .5027 Mdot
.858 .5039 Mdot
.858 .50414 Mdot
.858 .50431 Mdot
.858 .50629 Mdot
.858 .50771 Mdot
.858 .50893 Mdot
.858 .50944 Mdot
.858 .5111 Mdot
.858 .51172 Mdot
.858 .51185 Mdot
.858 .51323 Mdot
.858 .51358 Mdot
.858 .51367 Mdot
.858 .51442 Mdot
.858 .51443 Mdot
.858 .51612 Mdot
.858 .51711 Mdot
.858 .51747 Mdot
.858 .51792 Mdot
.858 .51908 Mdot
.858 .51929 Mdot
.858 .51941 Mdot
.858 .5195 Mdot
.858 .51991 Mdot
.858 .52086 Mdot
.858 .52098 Mdot
.858 .52114 Mdot
.86 .01498 Mdot
.86 .01517 Mdot
.86 .01549 Mdot
.86 .01564 Mdot
.86 .01605 Mdot
.86 .01613 Mdot
.86 .01621 Mdot
.86 .01631 Mdot
.86 .01646 Mdot
.86 .01701 Mdot
.86 .01714 Mdot
.86 .01728 Mdot
.86 .01747 Mdot
.86 .01768 Mdot
.86 .01771 Mdot
.86 .01843 Mdot
.86 .01867 Mdot
.86 .01874 Mdot
.86 .01889 Mdot
.86 .01913 Mdot
.86 .01945 Mdot
.86 .01968 Mdot
.86 .01981 Mdot
.86 .01982 Mdot
.86 .01987 Mdot
.86 .02087 Mdot
.86 .02111 Mdot
.86 .02151 Mdot
.86 .02163 Mdot
.86 .0219 Mdot
.86 .0223 Mdot
.86 .02285 Mdot
.86 .02325 Mdot
.86 .02347 Mdot
.86 .02349 Mdot
.86 .02359 Mdot
.86 .02475 Mdot
.86 .0253 Mdot
.86 .02571 Mdot
.86 .02591 Mdot
.86 .02641 Mdot
.86 .02661 Mdot
.86 .02678 Mdot
.86 .02693 Mdot
.86 .02707 Mdot
.86 .02717 Mdot
.86 .02776 Mdot
.86 .02871 Mdot
.86 .02939 Mdot
.86 .02977 Mdot
.86 .02981 Mdot
.86 .02997 Mdot
.86 .03088 Mdot
.86 .03095 Mdot
.86 .0313 Mdot
.86 .03198 Mdot
.86 .03292 Mdot
.86 .03349 Mdot
.86 .03363 Mdot
.86 .03381 Mdot
.86 .03398 Mdot
.86 .03483 Mdot
.86 .03498 Mdot
.86 .03517 Mdot
.86 .03546 Mdot
.86 .03572 Mdot
.86 .03587 Mdot
.86 .03596 Mdot
.86 .03614 Mdot
.86 .0364 Mdot
.86 .03716 Mdot
.86 .03778 Mdot
.86 .03879 Mdot
.86 .03996 Mdot
.86 .04033 Mdot
.86 .04062 Mdot
.86 .04068 Mdot
.86 .04096 Mdot
.86 .04106 Mdot
.86 .04251 Mdot
.86 .04264 Mdot
.86 .04324 Mdot
.86 .04335 Mdot
.86 .04342 Mdot
.86 .0444 Mdot
.86 .04526 Mdot
.86 .04544 Mdot
.86 .04603 Mdot
.86 .04669 Mdot
.86 .047 Mdot
.86 .04725 Mdot
.86 .04725 Mdot
.86 .04756 Mdot
.86 .04768 Mdot
.86 .04781 Mdot
.86 .04785 Mdot
.86 .04787 Mdot
.86 .04803 Mdot
.86 .04804 Mdot
.86 .04931 Mdot
.86 .04957 Mdot
.86 .0496 Mdot
.86 .0499 Mdot
.86 .04994 Mdot
.86 .05003 Mdot
.86 .0504 Mdot
.86 .05084 Mdot
.86 .0511 Mdot
.86 .05126 Mdot
.86 .05157 Mdot
.86 .05197 Mdot
.86 .05202 Mdot
.86 .05332 Mdot
.86 .05382 Mdot
.86 .05389 Mdot
.86 .05438 Mdot
.86 .0545 Mdot
.86 .05547 Mdot
.86 .05568 Mdot
.86 .05576 Mdot
.86 .05613 Mdot
.86 .05614 Mdot
.86 .05628 Mdot
.86 .05814 Mdot
.86 .05877 Mdot
.86 .05926 Mdot
.86 .05938 Mdot
.86 .05961 Mdot
.86 .05985 Mdot
.86 .06003 Mdot
.86 .06066 Mdot
.86 .06095 Mdot
.86 .06166 Mdot
.86 .06208 Mdot
.86 .06253 Mdot
.86 .06274 Mdot
.86 .06377 Mdot
.86 .06397 Mdot
.86 .06409 Mdot
.86 .06471 Mdot
.86 .06486 Mdot
.86 .06578 Mdot
.86 .06699 Mdot
.86 .06726 Mdot
.86 .06756 Mdot
.86 .06764 Mdot
.86 .0682 Mdot
.86 .06857 Mdot
.86 .06887 Mdot
.86 .06925 Mdot
.86 .06932 Mdot
.86 .06971 Mdot
.86 .07025 Mdot
.86 .07031 Mdot
.86 .07067 Mdot
.86 .07068 Mdot
.86 .07075 Mdot
.86 .07111 Mdot
.86 .07121 Mdot
.86 .07141 Mdot
.86 .07163 Mdot
.86 .0717 Mdot
.86 .07174 Mdot
.86 .07201 Mdot
.86 .07203 Mdot
.86 .0722 Mdot
.86 .07353 Mdot
.86 .0742 Mdot
.86 .07422 Mdot
.86 .07467 Mdot
.86 .07472 Mdot
.86 .07524 Mdot
.86 .0753 Mdot
.86 .07546 Mdot
.86 .0761 Mdot
.86 .0766 Mdot
.86 .07686 Mdot
.86 .0773 Mdot
.86 .07757 Mdot
.86 .07811 Mdot
.86 .0788 Mdot
.86 .07887 Mdot
.86 .07962 Mdot
.86 .08024 Mdot
.86 .08042 Mdot
.86 .08045 Mdot
.86 .08099 Mdot
.86 .08111 Mdot
.86 .0812 Mdot
.86 .08147 Mdot
.86 .08164 Mdot
.86 .08198 Mdot
.86 .0821 Mdot
.86 .0824 Mdot
.86 .08293 Mdot
.86 .08294 Mdot
.86 .08315 Mdot
.86 .08482 Mdot
.86 .08517 Mdot
.86 .08531 Mdot
.86 .08595 Mdot
.86 .08596 Mdot
.86 .0862 Mdot
.86 .08622 Mdot
.86 .08722 Mdot
.86 .08805 Mdot
.86 .08941 Mdot
.86 .09043 Mdot
.86 .09049 Mdot
.86 .09052 Mdot
.86 .09134 Mdot
.86 .09137 Mdot
.86 .09153 Mdot
.86 .09159 Mdot
.86 .09162 Mdot
.86 .09192 Mdot
.86 .09193 Mdot
.86 .09198 Mdot
.86 .09236 Mdot
.86 .09239 Mdot
.86 .09266 Mdot
.86 .09375 Mdot
.86 .0942 Mdot
.86 .09424 Mdot
.86 .0944 Mdot
.86 .09474 Mdot
.86 .09486 Mdot
.86 .09546 Mdot
.86 .09587 Mdot
.86 .09619 Mdot
.86 .09696 Mdot
.86 .09732 Mdot
.86 .09785 Mdot
.86 .09796 Mdot
.86 .09854 Mdot
.86 .09871 Mdot
.86 .09871 Mdot
.86 .0991 Mdot
.86 .09927 Mdot
.86 .09964 Mdot
.86 .1003 Mdot
.86 .1007 Mdot
.86 .10096 Mdot
.86 .10182 Mdot
.86 .10255 Mdot
.86 .10288 Mdot
.86 .10292 Mdot
.86 .10292 Mdot
.86 .10321 Mdot
.86 .10323 Mdot
.86 .10463 Mdot
.86 .10509 Mdot
.86 .10511 Mdot
.86 .10513 Mdot
.86 .10561 Mdot
.86 .10575 Mdot
.86 .10611 Mdot
.86 .10671 Mdot
.86 .10694 Mdot
.86 .10735 Mdot
.86 .10785 Mdot
.86 .10795 Mdot
.86 .10851 Mdot
.86 .10864 Mdot
.86 .10931 Mdot
.86 .11023 Mdot
.86 .11033 Mdot
.86 .11096 Mdot
.86 .11097 Mdot
.86 .1111 Mdot
.86 .11114 Mdot
.86 .11171 Mdot
.86 .11189 Mdot
.86 .11222 Mdot
.86 .11261 Mdot
.86 .11273 Mdot
.86 .1128 Mdot
.86 .11327 Mdot
.86 .1133 Mdot
.86 .11359 Mdot
.86 .11378 Mdot
.86 .11484 Mdot
.86 .11494 Mdot
.86 .115 Mdot
.86 .11524 Mdot
.86 .11539 Mdot
.86 .11545 Mdot
.86 .11587 Mdot
.86 .11663 Mdot
.86 .11703 Mdot
.86 .11706 Mdot
.86 .11784 Mdot
.86 .11785 Mdot
.86 .11792 Mdot
.86 .11882 Mdot
.86 .11892 Mdot
.86 .11919 Mdot
.86 .1197 Mdot
.86 .11984 Mdot
.86 .12029 Mdot
.86 .1207 Mdot
.86 .12116 Mdot
.86 .1216 Mdot
.86 .12236 Mdot
.86 .12273 Mdot
.86 .1228 Mdot
.86 .12283 Mdot
.86 .12375 Mdot
.86 .12397 Mdot
.86 .12494 Mdot
.86 .12506 Mdot
.86 .12635 Mdot
.86 .12742 Mdot
.86 .12757 Mdot
.86 .12773 Mdot
.86 .12778 Mdot
.86 .12781 Mdot
.86 .12871 Mdot
.86 .12891 Mdot
.86 .12907 Mdot
.86 .12954 Mdot
.86 .12956 Mdot
.86 .12973 Mdot
.86 .12983 Mdot
.86 .12985 Mdot
.86 .13041 Mdot
.86 .13061 Mdot
.86 .131 Mdot
.86 .13113 Mdot
.86 .13178 Mdot
.86 .132 Mdot
.86 .13205 Mdot
.86 .13206 Mdot
.86 .13243 Mdot
.86 .13434 Mdot
.86 .13445 Mdot
.86 .13529 Mdot
.86 .1359 Mdot
.86 .13613 Mdot
.86 .13689 Mdot
.86 .13723 Mdot
.86 .13726 Mdot
.86 .13767 Mdot
.86 .13771 Mdot
.86 .13942 Mdot
.86 .14031 Mdot
.86 .1407 Mdot
.86 .14085 Mdot
.86 .14319 Mdot
.86 .14434 Mdot
.86 .14495 Mdot
.86 .14506 Mdot
.86 .1451 Mdot
.86 .14524 Mdot
.86 .14651 Mdot
.86 .14656 Mdot
.86 .14678 Mdot
.86 .14685 Mdot
.86 .14694 Mdot
.86 .14699 Mdot
.86 .14721 Mdot
.86 .14751 Mdot
.86 .14752 Mdot
.86 .14761 Mdot
.86 .14798 Mdot
.86 .14826 Mdot
.86 .14831 Mdot
.86 .14878 Mdot
.86 .15065 Mdot
.86 .15143 Mdot
.86 .1515 Mdot
.86 .15178 Mdot
.86 .15235 Mdot
.86 .15256 Mdot
.86 .1536 Mdot
.86 .15402 Mdot
.86 .1543 Mdot
.86 .15485 Mdot
.86 .15617 Mdot
.86 .15679 Mdot
.86 .15706 Mdot
.86 .15722 Mdot
.86 .1577 Mdot
.86 .1579 Mdot
.86 .15889 Mdot
.86 .15919 Mdot
.86 .15919 Mdot
.86 .15985 Mdot
.86 .15987 Mdot
.86 .16014 Mdot
.86 .16078 Mdot
.86 .16192 Mdot
.86 .16261 Mdot
.86 .16306 Mdot
.86 .16453 Mdot
.86 .16575 Mdot
.86 .16579 Mdot
.86 .16636 Mdot
.86 .16642 Mdot
.86 .16642 Mdot
.86 .16693 Mdot
.86 .16696 Mdot
.86 .16882 Mdot
.86 .16937 Mdot
.86 .16937 Mdot
.86 .1696 Mdot
.86 .17015 Mdot
.86 .1702 Mdot
.86 .17023 Mdot
.86 .17031 Mdot
.86 .17106 Mdot
.86 .1713 Mdot
.86 .17191 Mdot
.86 .17196 Mdot
.86 .17294 Mdot
.86 .17334 Mdot
.86 .17405 Mdot
.86 .17491 Mdot
.86 .17509 Mdot
.86 .17605 Mdot
.86 .17626 Mdot
.86 .17642 Mdot
.86 .17654 Mdot
.86 .17676 Mdot
.86 .17703 Mdot
.86 .17743 Mdot
.86 .17813 Mdot
.86 .17848 Mdot
.86 .17896 Mdot
.86 .179 Mdot
.86 .17917 Mdot
.86 .17921 Mdot
.86 .18026 Mdot
.86 .18028 Mdot
.86 .18034 Mdot
.86 .1805 Mdot
.86 .18056 Mdot
.86 .18155 Mdot
.86 .18185 Mdot
.86 .18187 Mdot
.86 .18191 Mdot
.86 .18237 Mdot
.86 .18243 Mdot
.86 .1831 Mdot
.86 .18331 Mdot
.86 .18342 Mdot
.86 .18423 Mdot
.86 .18426 Mdot
.86 .18428 Mdot
.86 .18478 Mdot
.86 .18511 Mdot
.86 .18566 Mdot
.86 .18592 Mdot
.86 .18644 Mdot
.86 .18671 Mdot
.86 .18694 Mdot
.86 .1871 Mdot
.86 .18721 Mdot
.86 .18763 Mdot
.86 .18788 Mdot
.86 .18798 Mdot
.86 .18834 Mdot
.86 .1887 Mdot
.86 .19001 Mdot
.86 .1907 Mdot
.86 .19075 Mdot
.86 .19083 Mdot
.86 .19209 Mdot
.86 .19211 Mdot
.86 .19223 Mdot
.86 .19377 Mdot
.86 .19395 Mdot
.86 .19442 Mdot
.86 .19528 Mdot
.86 .19553 Mdot
.86 .1963 Mdot
.86 .19701 Mdot
.86 .19781 Mdot
.86 .19783 Mdot
.86 .19856 Mdot
.86 .19986 Mdot
.86 .20047 Mdot
.86 .2005 Mdot
.86 .20062 Mdot
.86 .20067 Mdot
.86 .2018 Mdot
.86 .20215 Mdot
.86 .20225 Mdot
.86 .20263 Mdot
.86 .20357 Mdot
.86 .20429 Mdot
.86 .20451 Mdot
.86 .2065 Mdot
.86 .20673 Mdot
.86 .20754 Mdot
.86 .20856 Mdot
.86 .20883 Mdot
.86 .2091 Mdot
.86 .20919 Mdot
.86 .20925 Mdot
.86 .21079 Mdot
.86 .21113 Mdot
.86 .21141 Mdot
.86 .21222 Mdot
.86 .21225 Mdot
.86 .21253 Mdot
.86 .21272 Mdot
.86 .21274 Mdot
.86 .21288 Mdot
.86 .21371 Mdot
.86 .21405 Mdot
.86 .21472 Mdot
.86 .21496 Mdot
.86 .21501 Mdot
.86 .21606 Mdot
.86 .21642 Mdot
.86 .21644 Mdot
.86 .21654 Mdot
.86 .21654 Mdot
.86 .21718 Mdot
.86 .21752 Mdot
.86 .21922 Mdot
.86 .22047 Mdot
.86 .22065 Mdot
.86 .22211 Mdot
.86 .22245 Mdot
.86 .22316 Mdot
.86 .22355 Mdot
.86 .22485 Mdot
.86 .22544 Mdot
.86 .2255 Mdot
.86 .22593 Mdot
.86 .22619 Mdot
.86 .22627 Mdot
.86 .22792 Mdot
.86 .22908 Mdot
.86 .22921 Mdot
.86 .23044 Mdot
.86 .23074 Mdot
.86 .23126 Mdot
.86 .23141 Mdot
.86 .23167 Mdot
.86 .23371 Mdot
.86 .23474 Mdot
.86 .23479 Mdot
.86 .23569 Mdot
.86 .23767 Mdot
.86 .23871 Mdot
.86 .2389 Mdot
.86 .23898 Mdot
.86 .23922 Mdot
.86 .23977 Mdot
.86 .24128 Mdot
.86 .24132 Mdot
.86 .2414 Mdot
.86 .24149 Mdot
.86 .24186 Mdot
.86 .24198 Mdot
.86 .24214 Mdot
.86 .24223 Mdot
.86 .24261 Mdot
.86 .24313 Mdot
.86 .24314 Mdot
.86 .24329 Mdot
.86 .24393 Mdot
.86 .24441 Mdot
.86 .24449 Mdot
.86 .24467 Mdot
.86 .24476 Mdot
.86 .24531 Mdot
.86 .24615 Mdot
.86 .24852 Mdot
.86 .24941 Mdot
.86 .24986 Mdot
.86 .24998 Mdot
.86 .25046 Mdot
.86 .25145 Mdot
.86 .2518 Mdot
.86 .25361 Mdot
.86 .25433 Mdot
.86 .2548 Mdot
.86 .25517 Mdot
.86 .25575 Mdot
.86 .25684 Mdot
.86 .25802 Mdot
.86 .25869 Mdot
.86 .25908 Mdot
.86 .25954 Mdot
.86 .25982 Mdot
.86 .26065 Mdot
.86 .26099 Mdot
.86 .26101 Mdot
.86 .2627 Mdot
.86 .26321 Mdot
.86 .26322 Mdot
.86 .26435 Mdot
.86 .26438 Mdot
.86 .26485 Mdot
.86 .26595 Mdot
.86 .2679 Mdot
.86 .26847 Mdot
.86 .26909 Mdot
.86 .26988 Mdot
.86 .2724 Mdot
.86 .27449 Mdot
.86 .27456 Mdot
.86 .27466 Mdot
.86 .27487 Mdot
.86 .27517 Mdot
.86 .27554 Mdot
.86 .27565 Mdot
.86 .27565 Mdot
.86 .27578 Mdot
.86 .27652 Mdot
.86 .27658 Mdot
.86 .27669 Mdot
.86 .27777 Mdot
.86 .27808 Mdot
.86 .27811 Mdot
.86 .27848 Mdot
.86 .27978 Mdot
.86 .28068 Mdot
.86 .28073 Mdot
.86 .28073 Mdot
.86 .28085 Mdot
.86 .28111 Mdot
.86 .28116 Mdot
.86 .28207 Mdot
.86 .28214 Mdot
.86 .28221 Mdot
.86 .28233 Mdot
.86 .28362 Mdot
.86 .28404 Mdot
.86 .28437 Mdot
.86 .2851 Mdot
.86 .28517 Mdot
.86 .28529 Mdot
.86 .28537 Mdot
.86 .28647 Mdot
.86 .28686 Mdot
.86 .28754 Mdot
.86 .28877 Mdot
.86 .29026 Mdot
.86 .29032 Mdot
.86 .29055 Mdot
.86 .29221 Mdot
.86 .29257 Mdot
.86 .29285 Mdot
.86 .29296 Mdot
.86 .29305 Mdot
.86 .29312 Mdot
.86 .29312 Mdot
.86 .29342 Mdot
.86 .29349 Mdot
.86 .29389 Mdot
.86 .29425 Mdot
.86 .29439 Mdot
.86 .29458 Mdot
.86 .2958 Mdot
.86 .29639 Mdot
.86 .29708 Mdot
.86 .29721 Mdot
.86 .29729 Mdot
.86 .2973 Mdot
.86 .29749 Mdot
.86 .29758 Mdot
.86 .29765 Mdot
.86 .29787 Mdot
.86 .29945 Mdot
.86 .29949 Mdot
.86 .29959 Mdot
.86 .29987 Mdot
.86 .29998 Mdot
.86 .30168 Mdot
.86 .30168 Mdot
.86 .30219 Mdot
.86 .30223 Mdot
.86 .3023 Mdot
.86 .30293 Mdot
.86 .30308 Mdot
.86 .30319 Mdot
.86 .3039 Mdot
.86 .30434 Mdot
.86 .30469 Mdot
.86 .30489 Mdot
.86 .30604 Mdot
.86 .30627 Mdot
.86 .30628 Mdot
.86 .30633 Mdot
.86 .30637 Mdot
.86 .3066 Mdot
.86 .30684 Mdot
.86 .30723 Mdot
.86 .3078 Mdot
.86 .30875 Mdot
.86 .30919 Mdot
.86 .31008 Mdot
.86 .3101 Mdot
.86 .31055 Mdot
.86 .31094 Mdot
.86 .31122 Mdot
.86 .31126 Mdot
.86 .31141 Mdot
.86 .31212 Mdot
.86 .31256 Mdot
.86 .31273 Mdot
.86 .31328 Mdot
.86 .31336 Mdot
.86 .31397 Mdot
.86 .31623 Mdot
.86 .31691 Mdot
.86 .31741 Mdot
.86 .3175 Mdot
.86 .31764 Mdot
.86 .31979 Mdot
.86 .31983 Mdot
.86 .32004 Mdot
.86 .32131 Mdot
.86 .3215 Mdot
.86 .32218 Mdot
.86 .3227 Mdot
.86 .323 Mdot
.86 .3238 Mdot
.86 .32529 Mdot
.86 .32571 Mdot
.86 .32705 Mdot
.86 .32709 Mdot
.86 .32816 Mdot
.86 .32826 Mdot
.86 .32899 Mdot
.86 .32931 Mdot
.86 .32956 Mdot
.86 .32964 Mdot
.86 .32967 Mdot
.86 .32976 Mdot
.86 .32977 Mdot
.86 .33068 Mdot
.86 .33088 Mdot
.86 .33093 Mdot
.86 .33206 Mdot
.86 .33313 Mdot
.86 .33317 Mdot
.86 .33353 Mdot
.86 .33409 Mdot
.86 .33421 Mdot
.86 .33426 Mdot
.86 .33448 Mdot
.86 .33456 Mdot
.86 .3365 Mdot
.86 .33711 Mdot
.86 .33728 Mdot
.86 .33769 Mdot
.86 .33794 Mdot
.86 .33946 Mdot
.86 .33955 Mdot
.86 .34079 Mdot
.86 .34117 Mdot
.86 .34149 Mdot
.86 .34188 Mdot
.86 .3421 Mdot
.86 .34214 Mdot
.86 .34272 Mdot
.86 .34298 Mdot
.86 .34318 Mdot
.86 .34382 Mdot
.86 .34459 Mdot
.86 .34498 Mdot
.86 .34638 Mdot
.86 .34813 Mdot
.86 .34849 Mdot
.86 .3486 Mdot
.86 .34861 Mdot
.86 .34893 Mdot
.86 .34905 Mdot
.86 .34921 Mdot
.86 .34931 Mdot
.86 .34975 Mdot
.86 .35006 Mdot
.86 .35197 Mdot
.86 .35255 Mdot
.86 .35303 Mdot
.86 .35442 Mdot
.86 .35447 Mdot
.86 .35496 Mdot
.86 .35509 Mdot
.86 .35511 Mdot
.86 .35528 Mdot
.86 .35532 Mdot
.86 .35555 Mdot
.86 .35661 Mdot
.86 .35673 Mdot
.86 .35692 Mdot
.86 .35699 Mdot
.86 .35758 Mdot
.86 .35873 Mdot
.86 .3588 Mdot
.86 .35913 Mdot
.86 .35923 Mdot
.86 .35923 Mdot
.86 .35955 Mdot
.86 .36104 Mdot
.86 .36165 Mdot
.86 .36168 Mdot
.86 .36168 Mdot
.86 .36185 Mdot
.86 .36186 Mdot
.86 .36295 Mdot
.86 .36296 Mdot
.86 .36353 Mdot
.86 .36401 Mdot
.86 .3646 Mdot
.86 .36646 Mdot
.86 .36799 Mdot
.86 .36861 Mdot
.86 .36867 Mdot
.86 .3687 Mdot
.86 .36884 Mdot
.86 .36893 Mdot
.86 .36896 Mdot
.86 .36965 Mdot
.86 .37036 Mdot
.86 .37143 Mdot
.86 .37151 Mdot
.86 .37202 Mdot
.86 .37319 Mdot
.86 .37324 Mdot
.86 .37392 Mdot
.86 .37601 Mdot
.86 .37615 Mdot
.86 .37717 Mdot
.86 .37726 Mdot
.86 .37733 Mdot
.86 .378 Mdot
.86 .37846 Mdot
.86 .37858 Mdot
.86 .37994 Mdot
.86 .38001 Mdot
.86 .38143 Mdot
.86 .38342 Mdot
.86 .38364 Mdot
.86 .38576 Mdot
.86 .38628 Mdot
.86 .38718 Mdot
.86 .38743 Mdot
.86 .38788 Mdot
.86 .39139 Mdot
.86 .39315 Mdot
.86 .39325 Mdot
.86 .39479 Mdot
.86 .39821 Mdot
.86 .39999 Mdot
.86 .40031 Mdot
.86 .40044 Mdot
.86 .40086 Mdot
.86 .40182 Mdot
.86 .40441 Mdot
.86 .40448 Mdot
.86 .40461 Mdot
.86 .40476 Mdot
.86 .40541 Mdot
.86 .40561 Mdot
.86 .40589 Mdot
.86 .40603 Mdot
.86 .40669 Mdot
.86 .40758 Mdot
.86 .4076 Mdot
.86 .40787 Mdot
.86 .40897 Mdot
.86 .40979 Mdot
.86 .40994 Mdot
.86 .41023 Mdot
.86 .41039 Mdot
.86 .41134 Mdot
.86 .41279 Mdot
.86 .41686 Mdot
.86 .41839 Mdot
.86 .41916 Mdot
.86 .41937 Mdot
.86 .4202 Mdot
.86 .4219 Mdot
.86 .42251 Mdot
.86 .42561 Mdot
.86 .42685 Mdot
.86 .42767 Mdot
.86 .4283 Mdot
.86 .42929 Mdot
.86 .43117 Mdot
.86 .43319 Mdot
.86 .43435 Mdot
.86 .43503 Mdot
.86 .43582 Mdot
.86 .4363 Mdot
.86 .43772 Mdot
.86 .43832 Mdot
.86 .43835 Mdot
.86 .44124 Mdot
.86 .44212 Mdot
.86 .44214 Mdot
.86 .44409 Mdot
.86 .44414 Mdot
.86 .44495 Mdot
.86 .44685 Mdot
.86 .4502 Mdot
.86 .45117 Mdot
.86 .45224 Mdot
.86 .45359 Mdot
.86 .45793 Mdot
.86 .46153 Mdot
.86 .46165 Mdot
.86 .46183 Mdot
.86 .46218 Mdot
.86 .4627 Mdot
.86 .46334 Mdot
.86 .46352 Mdot
.86 .46353 Mdot
.86 .46375 Mdot
.86 .46502 Mdot
.86 .46513 Mdot
.86 .4653 Mdot
.86 .46717 Mdot
.86 .4677 Mdot
.86 .46775 Mdot
.86 .46839 Mdot
.86 .47063 Mdot
.86 .47217 Mdot
.86 .47226 Mdot
.86 .47226 Mdot
.86 .47248 Mdot
.86 .47292 Mdot
.86 .473 Mdot
.86 .47456 Mdot
.86 .47469 Mdot
.86 .4748 Mdot
.86 .47502 Mdot
.86 .47724 Mdot
.86 .47796 Mdot
.86 .47853 Mdot
.86 .47977 Mdot
.86 .4799 Mdot
.86 .4801 Mdot
.86 .48023 Mdot
.86 .48213 Mdot
.86 .48281 Mdot
.86 .48398 Mdot
.86 .48609 Mdot
.86 .48865 Mdot
.86 .48876 Mdot
.86 .48915 Mdot
.86 .49201 Mdot
.86 .49263 Mdot
.86 .49311 Mdot
.86 .4933 Mdot
.86 .49344 Mdot
.86 .49356 Mdot
.86 .49357 Mdot
.86 .4941 Mdot
.86 .49421 Mdot
.86 .4949 Mdot
.86 .49552 Mdot
.86 .49575 Mdot
.86 .49608 Mdot
.86 .49817 Mdot
.86 .4992 Mdot
.86 .50038 Mdot
.86 .50061 Mdot
.86 .50074 Mdot
.86 .50076 Mdot
.86 .50109 Mdot
.86 .50125 Mdot
.86 .50137 Mdot
.86 .50174 Mdot
.86 .50445 Mdot
.86 .50452 Mdot
.86 .50471 Mdot
.86 .50518 Mdot
.86 .50536 Mdot
.86 .50829 Mdot
.86 .5083 Mdot
.86 .50917 Mdot
.86 .50924 Mdot
.86 .50935 Mdot
.86 .51044 Mdot
.86 .5107 Mdot
.86 .51088 Mdot
.86 .51212 Mdot
.86 .51287 Mdot
.86 .51348 Mdot
.86 .51382 Mdot
.86 .51579 Mdot
.86 .51618 Mdot
.86 .5162 Mdot
.86 .51628 Mdot
.86 .51635 Mdot
.86 .51675 Mdot
.86 .51717 Mdot
.86 .51784 Mdot
.86 .51881 Mdot
.86 .52045 Mdot
.86 .52122 Mdot
.86 .52274 Mdot
.86 .52278 Mdot
.862 .01518 Mdot
.862 .01538 Mdot
.862 .01551 Mdot
.862 .01586 Mdot
.862 .01608 Mdot
.862 .01669 Mdot
.862 .01679 Mdot
.862 .01708 Mdot
.862 .01812 Mdot
.862 .01828 Mdot
.862 .01878 Mdot
.862 .01937 Mdot
.862 .02059 Mdot
.862 .02087 Mdot
.862 .02088 Mdot
.862 .02133 Mdot
.862 .02173 Mdot
.862 .02275 Mdot
.862 .0232 Mdot
.862 .0233 Mdot
.862 .02331 Mdot
.862 .0234 Mdot
.862 .02478 Mdot
.862 .02484 Mdot
.862 .02494 Mdot
.862 .02532 Mdot
.862 .02535 Mdot
.862 .02571 Mdot
.862 .02577 Mdot
.862 .02602 Mdot
.862 .02611 Mdot
.862 .0263 Mdot
.862 .02636 Mdot
.862 .02674 Mdot
.862 .02678 Mdot
.862 .02681 Mdot
.862 .02856 Mdot
.862 .02897 Mdot
.862 .02923 Mdot
.862 .02927 Mdot
.862 .02935 Mdot
.862 .02952 Mdot
.862 .02954 Mdot
.862 .02969 Mdot
.862 .032 Mdot
.862 .03207 Mdot
.862 .03216 Mdot
.862 .03217 Mdot
.862 .03235 Mdot
.862 .033 Mdot
.862 .03304 Mdot
.862 .03339 Mdot
.862 .03343 Mdot
.862 .03367 Mdot
.862 .03377 Mdot
.862 .03395 Mdot
.862 .03421 Mdot
.862 .03436 Mdot
.862 .03468 Mdot
.862 .03479 Mdot
.862 .03484 Mdot
.862 .03496 Mdot
.862 .03535 Mdot
.862 .03544 Mdot
.862 .03551 Mdot
.862 .03557 Mdot
.862 .03626 Mdot
.862 .0366 Mdot
.862 .03795 Mdot
.862 .03859 Mdot
.862 .0393 Mdot
.862 .03974 Mdot
.862 .0398 Mdot
.862 .03995 Mdot
.862 .04023 Mdot
.862 .04027 Mdot
.862 .0403 Mdot
.862 .04053 Mdot
.862 .04142 Mdot
.862 .04181 Mdot
.862 .04232 Mdot
.862 .04452 Mdot
.862 .04464 Mdot
.862 .0448 Mdot
.862 .0448 Mdot
.862 .04504 Mdot
.862 .04511 Mdot
.862 .04624 Mdot
.862 .04631 Mdot
.862 .04685 Mdot
.862 .04692 Mdot
.862 .04699 Mdot
.862 .04739 Mdot
.862 .04754 Mdot
.862 .04756 Mdot
.862 .04788 Mdot
.862 .04832 Mdot
.862 .04859 Mdot
.862 .04895 Mdot
.862 .04912 Mdot
.862 .04914 Mdot
.862 .04914 Mdot
.862 .04932 Mdot
.862 .04942 Mdot
.862 .04962 Mdot
.862 .05018 Mdot
.862 .0503 Mdot
.862 .05045 Mdot
.862 .05057 Mdot
.862 .05075 Mdot
.862 .05103 Mdot
.862 .05186 Mdot
.862 .05244 Mdot
.862 .05331 Mdot
.862 .05355 Mdot
.862 .05381 Mdot
.862 .05478 Mdot
.862 .05533 Mdot
.862 .05587 Mdot
.862 .0565 Mdot
.862 .05709 Mdot
.862 .05783 Mdot
.862 .05785 Mdot
.862 .05789 Mdot
.862 .05796 Mdot
.862 .05807 Mdot
.862 .05822 Mdot
.862 .05832 Mdot
.862 .05871 Mdot
.862 .05878 Mdot
.862 .05883 Mdot
.862 .05906 Mdot
.862 .05923 Mdot
.862 .06075 Mdot
.862 .06126 Mdot
.862 .06143 Mdot
.862 .06213 Mdot
.862 .06222 Mdot
.862 .06231 Mdot
.862 .06286 Mdot
.862 .06407 Mdot
.862 .06593 Mdot
.862 .06609 Mdot
.862 .06631 Mdot
.862 .06658 Mdot
.862 .06659 Mdot
.862 .067 Mdot
.862 .06712 Mdot
.862 .06802 Mdot
.862 .06907 Mdot
.862 .06919 Mdot
.862 .07012 Mdot
.862 .07023 Mdot
.862 .07035 Mdot
.862 .07065 Mdot
.862 .07105 Mdot
.862 .0713 Mdot
.862 .07134 Mdot
.862 .07152 Mdot
.862 .07188 Mdot
.862 .07265 Mdot
.862 .07312 Mdot
.862 .07317 Mdot
.862 .07366 Mdot
.862 .07373 Mdot
.862 .07374 Mdot
.862 .07403 Mdot
.862 .07406 Mdot
.862 .07407 Mdot
.862 .07438 Mdot
.862 .07454 Mdot
.862 .0746 Mdot
.862 .0749 Mdot
.862 .07585 Mdot
.862 .07606 Mdot
.862 .07631 Mdot
.862 .07653 Mdot
.862 .07684 Mdot
.862 .07731 Mdot
.862 .07733 Mdot
.862 .07736 Mdot
.862 .07787 Mdot
.862 .07801 Mdot
.862 .07822 Mdot
.862 .07875 Mdot
.862 .07885 Mdot
.862 .07951 Mdot
.862 .07951 Mdot
.862 .07968 Mdot
.862 .07975 Mdot
.862 .08093 Mdot
.862 .08114 Mdot
.862 .08119 Mdot
.862 .08125 Mdot
.862 .08167 Mdot
.862 .08211 Mdot
.862 .0837 Mdot
.862 .08378 Mdot
.862 .08446 Mdot
.862 .08473 Mdot
.862 .08566 Mdot
.862 .08583 Mdot
.862 .08675 Mdot
.862 .08691 Mdot
.862 .08761 Mdot
.862 .08777 Mdot
.862 .08904 Mdot
.862 .08908 Mdot
.862 .08914 Mdot
.862 .08927 Mdot
.862 .08946 Mdot
.862 .0895 Mdot
.862 .08971 Mdot
.862 .0899 Mdot
.862 .08992 Mdot
.862 .09056 Mdot
.862 .09068 Mdot
.862 .09077 Mdot
.862 .09117 Mdot
.862 .09145 Mdot
.862 .09178 Mdot
.862 .09182 Mdot
.862 .09222 Mdot
.862 .09272 Mdot
.862 .09408 Mdot
.862 .09425 Mdot
.862 .09477 Mdot
.862 .09495 Mdot
.862 .09526 Mdot
.862 .09582 Mdot
.862 .09638 Mdot
.862 .09645 Mdot
.862 .09646 Mdot
.862 .09651 Mdot
.862 .09662 Mdot
.862 .09677 Mdot
.862 .09707 Mdot
.862 .09773 Mdot
.862 .09848 Mdot
.862 .09872 Mdot
.862 .09944 Mdot
.862 .0998 Mdot
.862 .10028 Mdot
.862 .10301 Mdot
.862 .10329 Mdot
.862 .10329 Mdot
.862 .10366 Mdot
.862 .10412 Mdot
.862 .10415 Mdot
.862 .10449 Mdot
.862 .10453 Mdot
.862 .10485 Mdot
.862 .10505 Mdot
.862 .10534 Mdot
.862 .10581 Mdot
.862 .10662 Mdot
.862 .10722 Mdot
.862 .10814 Mdot
.862 .10843 Mdot
.862 .10844 Mdot
.862 .10864 Mdot
.862 .11024 Mdot
.862 .11042 Mdot
.862 .11063 Mdot
.862 .11115 Mdot
.862 .11139 Mdot
.862 .11184 Mdot
.862 .11187 Mdot
.862 .11203 Mdot
.862 .11227 Mdot
.862 .11233 Mdot
.862 .11265 Mdot
.862 .11284 Mdot
.862 .11327 Mdot
.862 .11429 Mdot
.862 .11433 Mdot
.862 .1146 Mdot
.862 .11511 Mdot
.862 .1154 Mdot
.862 .11549 Mdot
.862 .11634 Mdot
.862 .1164 Mdot
.862 .11646 Mdot
.862 .11647 Mdot
.862 .11654 Mdot
.862 .11655 Mdot
.862 .11698 Mdot
.862 .11703 Mdot
.862 .11704 Mdot
.862 .11757 Mdot
.862 .1176 Mdot
.862 .11785 Mdot
.862 .11795 Mdot
.862 .1184 Mdot
.862 .11847 Mdot
.862 .11941 Mdot
.862 .12012 Mdot
.862 .12047 Mdot
.862 .1206 Mdot
.862 .12091 Mdot
.862 .12112 Mdot
.862 .12129 Mdot
.862 .12183 Mdot
.862 .12262 Mdot
.862 .12266 Mdot
.862 .12271 Mdot
.862 .12345 Mdot
.862 .12359 Mdot
.862 .12383 Mdot
.862 .12419 Mdot
.862 .12511 Mdot
.862 .12528 Mdot
.862 .12561 Mdot
.862 .12641 Mdot
.862 .12642 Mdot
.862 .12659 Mdot
.862 .12671 Mdot
.862 .12684 Mdot
.862 .12716 Mdot
.862 .12717 Mdot
.862 .12808 Mdot
.862 .12842 Mdot
.862 .12888 Mdot
.862 .12924 Mdot
.862 .12932 Mdot
.862 .12942 Mdot
.862 .13003 Mdot
.862 .13015 Mdot
.862 .13073 Mdot
.862 .1309 Mdot
.862 .13172 Mdot
.862 .13249 Mdot
.862 .13319 Mdot
.862 .13364 Mdot
.862 .13379 Mdot
.862 .13407 Mdot
.862 .13407 Mdot
.862 .13443 Mdot
.862 .13496 Mdot
.862 .13542 Mdot
.862 .13584 Mdot
.862 .13615 Mdot
.862 .13684 Mdot
.862 .13703 Mdot
.862 .13732 Mdot
.862 .13749 Mdot
.862 .13756 Mdot
.862 .13891 Mdot
.862 .13917 Mdot
.862 .13979 Mdot
.862 .14038 Mdot
.862 .1404 Mdot
.862 .14067 Mdot
.862 .14133 Mdot
.862 .1427 Mdot
.862 .14285 Mdot
.862 .14293 Mdot
.862 .14303 Mdot
.862 .14325 Mdot
.862 .14358 Mdot
.862 .14364 Mdot
.862 .14401 Mdot
.862 .14433 Mdot
.862 .14437 Mdot
.862 .14442 Mdot
.862 .14547 Mdot
.862 .14567 Mdot
.862 .14583 Mdot
.862 .14585 Mdot
.862 .14653 Mdot
.862 .14701 Mdot
.862 .14757 Mdot
.862 .14764 Mdot
.862 .14834 Mdot
.862 .1489 Mdot
.862 .14899 Mdot
.862 .1492 Mdot
.862 .14993 Mdot
.862 .15034 Mdot
.862 .15154 Mdot
.862 .15183 Mdot
.862 .15225 Mdot
.862 .15273 Mdot
.862 .15304 Mdot
.862 .15357 Mdot
.862 .15374 Mdot
.862 .15454 Mdot
.862 .15551 Mdot
.862 .15562 Mdot
.862 .15564 Mdot
.862 .15574 Mdot
.862 .15592 Mdot
.862 .15619 Mdot
.862 .1567 Mdot
.862 .15782 Mdot
.862 .15912 Mdot
.862 .15954 Mdot
.862 .16074 Mdot
.862 .16079 Mdot
.862 .1614 Mdot
.862 .16153 Mdot
.862 .16192 Mdot
.862 .16223 Mdot
.862 .16246 Mdot
.862 .16356 Mdot
.862 .16424 Mdot
.862 .16527 Mdot
.862 .16557 Mdot
.862 .16694 Mdot
.862 .16741 Mdot
.862 .16742 Mdot
.862 .16747 Mdot
.862 .16806 Mdot
.862 .16886 Mdot
.862 .16889 Mdot
.862 .16911 Mdot
.862 .16933 Mdot
.862 .16937 Mdot
.862 .16949 Mdot
.862 .16955 Mdot
.862 .16956 Mdot
.862 .17011 Mdot
.862 .17046 Mdot
.862 .17096 Mdot
.862 .17176 Mdot
.862 .17315 Mdot
.862 .1742 Mdot
.862 .17424 Mdot
.862 .17497 Mdot
.862 .17578 Mdot
.862 .17598 Mdot
.862 .17627 Mdot
.862 .1763 Mdot
.862 .17663 Mdot
.862 .17678 Mdot
.862 .17692 Mdot
.862 .1794 Mdot
.862 .17971 Mdot
.862 .18008 Mdot
.862 .18037 Mdot
.862 .18097 Mdot
.862 .18138 Mdot
.862 .18216 Mdot
.862 .18221 Mdot
.862 .18248 Mdot
.862 .18285 Mdot
.862 .1829 Mdot
.862 .18301 Mdot
.862 .18355 Mdot
.862 .18389 Mdot
.862 .18463 Mdot
.862 .18573 Mdot
.862 .18606 Mdot
.862 .18638 Mdot
.862 .18645 Mdot
.862 .18692 Mdot
.862 .18779 Mdot
.862 .1883 Mdot
.862 .18845 Mdot
.862 .18911 Mdot
.862 .18966 Mdot
.862 .18992 Mdot
.862 .19003 Mdot
.862 .19012 Mdot
.862 .19014 Mdot
.862 .19027 Mdot
.862 .19028 Mdot
.862 .19102 Mdot
.862 .19111 Mdot
.862 .19112 Mdot
.862 .19204 Mdot
.862 .1921 Mdot
.862 .19251 Mdot
.862 .19252 Mdot
.862 .1927 Mdot
.862 .193 Mdot
.862 .19347 Mdot
.862 .19359 Mdot
.862 .19404 Mdot
.862 .19521 Mdot
.862 .19551 Mdot
.862 .19643 Mdot
.862 .19704 Mdot
.862 .19727 Mdot
.862 .1978 Mdot
.862 .19781 Mdot
.862 .19816 Mdot
.862 .19844 Mdot
.862 .19938 Mdot
.862 .19989 Mdot
.862 .20075 Mdot
.862 .20081 Mdot
.862 .2009 Mdot
.862 .20218 Mdot
.862 .20242 Mdot
.862 .20283 Mdot
.862 .20346 Mdot
.862 .20504 Mdot
.862 .20534 Mdot
.862 .20589 Mdot
.862 .20606 Mdot
.862 .20728 Mdot
.862 .2073 Mdot
.862 .20752 Mdot
.862 .20759 Mdot
.862 .2078 Mdot
.862 .20802 Mdot
.862 .20857 Mdot
.862 .20859 Mdot
.862 .20969 Mdot
.862 .21015 Mdot
.862 .21075 Mdot
.862 .21153 Mdot
.862 .21215 Mdot
.862 .21216 Mdot
.862 .2123 Mdot
.862 .21247 Mdot
.862 .21351 Mdot
.862 .2137 Mdot
.862 .21372 Mdot
.862 .21375 Mdot
.862 .21449 Mdot
.862 .21473 Mdot
.862 .21501 Mdot
.862 .21643 Mdot
.862 .21644 Mdot
.862 .21735 Mdot
.862 .21776 Mdot
.862 .21896 Mdot
.862 .21973 Mdot
.862 .21974 Mdot
.862 .22 Mdot
.862 .22048 Mdot
.862 .22049 Mdot
.862 .22111 Mdot
.862 .22145 Mdot
.862 .22202 Mdot
.862 .22281 Mdot
.862 .22353 Mdot
.862 .22386 Mdot
.862 .22406 Mdot
.862 .22436 Mdot
.862 .22526 Mdot
.862 .22559 Mdot
.862 .22585 Mdot
.862 .22608 Mdot
.862 .22638 Mdot
.862 .22638 Mdot
.862 .2265 Mdot
.862 .22698 Mdot
.862 .22708 Mdot
.862 .22756 Mdot
.862 .22851 Mdot
.862 .22882 Mdot
.862 .22928 Mdot
.862 .22986 Mdot
.862 .23035 Mdot
.862 .23137 Mdot
.862 .2314 Mdot
.862 .23172 Mdot
.862 .23185 Mdot
.862 .2325 Mdot
.862 .233 Mdot
.862 .23535 Mdot
.862 .23562 Mdot
.862 .23575 Mdot
.862 .23593 Mdot
.862 .2363 Mdot
.862 .23653 Mdot
.862 .23688 Mdot
.862 .23698 Mdot
.862 .23762 Mdot
.862 .23817 Mdot
.862 .23825 Mdot
.862 .23826 Mdot
.862 .23832 Mdot
.862 .2399 Mdot
.862 .24014 Mdot
.862 .24048 Mdot
.862 .24075 Mdot
.862 .2408 Mdot
.862 .24196 Mdot
.862 .24279 Mdot
.862 .24376 Mdot
.862 .24387 Mdot
.862 .2449 Mdot
.862 .24509 Mdot
.862 .24604 Mdot
.862 .24621 Mdot
.862 .24656 Mdot
.862 .24705 Mdot
.862 .24783 Mdot
.862 .24853 Mdot
.862 .2506 Mdot
.862 .25109 Mdot
.862 .25182 Mdot
.862 .25266 Mdot
.862 .25317 Mdot
.862 .25319 Mdot
.862 .25344 Mdot
.862 .2541 Mdot
.862 .2544 Mdot
.862 .2552 Mdot
.862 .25578 Mdot
.862 .25659 Mdot
.862 .25676 Mdot
.862 .25726 Mdot
.862 .25744 Mdot
.862 .25764 Mdot
.862 .25767 Mdot
.862 .25784 Mdot
.862 .25816 Mdot
.862 .25861 Mdot
.862 .25924 Mdot
.862 .2595 Mdot
.862 .26086 Mdot
.862 .26144 Mdot
.862 .26199 Mdot
.862 .26367 Mdot
.862 .2644 Mdot
.862 .26645 Mdot
.862 .26654 Mdot
.862 .26714 Mdot
.862 .2676 Mdot
.862 .26766 Mdot
.862 .26783 Mdot
.862 .26849 Mdot
.862 .26904 Mdot
.862 .26942 Mdot
.862 .27115 Mdot
.862 .27133 Mdot
.862 .2725 Mdot
.862 .27428 Mdot
.862 .27479 Mdot
.862 .27642 Mdot
.862 .27715 Mdot
.862 .27796 Mdot
.862 .27796 Mdot
.862 .27797 Mdot
.862 .27806 Mdot
.862 .27908 Mdot
.862 .28046 Mdot
.862 .28052 Mdot
.862 .2809 Mdot
.862 .28128 Mdot
.862 .28133 Mdot
.862 .28155 Mdot
.862 .28165 Mdot
.862 .28167 Mdot
.862 .28262 Mdot
.862 .28281 Mdot
.862 .28322 Mdot
.862 .28408 Mdot
.862 .28497 Mdot
.862 .28546 Mdot
.862 .28736 Mdot
.862 .28738 Mdot
.862 .2874 Mdot
.862 .28767 Mdot
.862 .28786 Mdot
.862 .28966 Mdot
.862 .28973 Mdot
.862 .2907 Mdot
.862 .291 Mdot
.862 .29239 Mdot
.862 .29274 Mdot
.862 .29324 Mdot
.862 .29329 Mdot
.862 .29386 Mdot
.862 .29412 Mdot
.862 .29436 Mdot
.862 .29479 Mdot
.862 .29498 Mdot
.862 .29611 Mdot
.862 .29722 Mdot
.862 .29739 Mdot
.862 .29803 Mdot
.862 .29835 Mdot
.862 .29839 Mdot
.862 .29863 Mdot
.862 .29917 Mdot
.862 .2998 Mdot
.862 .3003 Mdot
.862 .30123 Mdot
.862 .30133 Mdot
.862 .30178 Mdot
.862 .30205 Mdot
.862 .30299 Mdot
.862 .30339 Mdot
.862 .30348 Mdot
.862 .30394 Mdot
.862 .30457 Mdot
.862 .30467 Mdot
.862 .30486 Mdot
.862 .30555 Mdot
.862 .30579 Mdot
.862 .30637 Mdot
.862 .30765 Mdot
.862 .3079 Mdot
.862 .30821 Mdot
.862 .30954 Mdot
.862 .30967 Mdot
.862 .31012 Mdot
.862 .31066 Mdot
.862 .31078 Mdot
.862 .3116 Mdot
.862 .3131 Mdot
.862 .31397 Mdot
.862 .31423 Mdot
.862 .31532 Mdot
.862 .31538 Mdot
.862 .31538 Mdot
.862 .31543 Mdot
.862 .31624 Mdot
.862 .31633 Mdot
.862 .31677 Mdot
.862 .31681 Mdot
.862 .31695 Mdot
.862 .31711 Mdot
.862 .31715 Mdot
.862 .31737 Mdot
.862 .31739 Mdot
.862 .31867 Mdot
.862 .31881 Mdot
.862 .31884 Mdot
.862 .32042 Mdot
.862 .32052 Mdot
.862 .32123 Mdot
.862 .32125 Mdot
.862 .32155 Mdot
.862 .32207 Mdot
.862 .32214 Mdot
.862 .32237 Mdot
.862 .32289 Mdot
.862 .32309 Mdot
.862 .32388 Mdot
.862 .32524 Mdot
.862 .32588 Mdot
.862 .32611 Mdot
.862 .32641 Mdot
.862 .32799 Mdot
.862 .32904 Mdot
.862 .32944 Mdot
.862 .33025 Mdot
.862 .33035 Mdot
.862 .33037 Mdot
.862 .33097 Mdot
.862 .3313 Mdot
.862 .33146 Mdot
.862 .33278 Mdot
.862 .33292 Mdot
.862 .33307 Mdot
.862 .33395 Mdot
.862 .33463 Mdot
.862 .3354 Mdot
.862 .33544 Mdot
.862 .33555 Mdot
.862 .33569 Mdot
.862 .33612 Mdot
.862 .33739 Mdot
.862 .3379 Mdot
.862 .33795 Mdot
.862 .33833 Mdot
.862 .33902 Mdot
.862 .3401 Mdot
.862 .34132 Mdot
.862 .34284 Mdot
.862 .34335 Mdot
.862 .3443 Mdot
.862 .34459 Mdot
.862 .34463 Mdot
.862 .34513 Mdot
.862 .3467 Mdot
.862 .34673 Mdot
.862 .34703 Mdot
.862 .34711 Mdot
.862 .34723 Mdot
.862 .3476 Mdot
.862 .34798 Mdot
.862 .34798 Mdot
.862 .34808 Mdot
.862 .34881 Mdot
.862 .34893 Mdot
.862 .34896 Mdot
.862 .35041 Mdot
.862 .35085 Mdot
.862 .35165 Mdot
.862 .35227 Mdot
.862 .35268 Mdot
.862 .35377 Mdot
.862 .35402 Mdot
.862 .3551 Mdot
.862 .35512 Mdot
.862 .35536 Mdot
.862 .35564 Mdot
.862 .35653 Mdot
.862 .35683 Mdot
.862 .35744 Mdot
.862 .35777 Mdot
.862 .35781 Mdot
.862 .35784 Mdot
.862 .35817 Mdot
.862 .35898 Mdot
.862 .35912 Mdot
.862 .35954 Mdot
.862 .36003 Mdot
.862 .36177 Mdot
.862 .36247 Mdot
.862 .36249 Mdot
.862 .36296 Mdot
.862 .36323 Mdot
.862 .36405 Mdot
.862 .36459 Mdot
.862 .36476 Mdot
.862 .36647 Mdot
.862 .36675 Mdot
.862 .36684 Mdot
.862 .36732 Mdot
.862 .36815 Mdot
.862 .36818 Mdot
.862 .36863 Mdot
.862 .36938 Mdot
.862 .36946 Mdot
.862 .36947 Mdot
.862 .37008 Mdot
.862 .37054 Mdot
.862 .37112 Mdot
.862 .37182 Mdot
.862 .37212 Mdot
.862 .37347 Mdot
.862 .37472 Mdot
.862 .37529 Mdot
.862 .37562 Mdot
.862 .37563 Mdot
.862 .37615 Mdot
.862 .37635 Mdot
.862 .37728 Mdot
.862 .37769 Mdot
.862 .37826 Mdot
.862 .37871 Mdot
.862 .37912 Mdot
.862 .37963 Mdot
.862 .37963 Mdot
.862 .37984 Mdot
.862 .38065 Mdot
.862 .38083 Mdot
.862 .38123 Mdot
.862 .38161 Mdot
.862 .38165 Mdot
.862 .38295 Mdot
.862 .3833 Mdot
.862 .38384 Mdot
.862 .38463 Mdot
.862 .38563 Mdot
.862 .38646 Mdot
.862 .38823 Mdot
.862 .38828 Mdot
.862 .38883 Mdot
.862 .38906 Mdot
.862 .39017 Mdot
.862 .39104 Mdot
.862 .39509 Mdot
.862 .39556 Mdot
.862 .39578 Mdot
.862 .39609 Mdot
.862 .39673 Mdot
.862 .39713 Mdot
.862 .39773 Mdot
.862 .3979 Mdot
.862 .399 Mdot
.862 .39996 Mdot
.862 .40008 Mdot
.862 .4001 Mdot
.862 .40021 Mdot
.862 .40293 Mdot
.862 .40335 Mdot
.862 .40394 Mdot
.862 .4044 Mdot
.862 .40448 Mdot
.862 .40648 Mdot
.862 .40792 Mdot
.862 .40959 Mdot
.862 .40979 Mdot
.862 .41155 Mdot
.862 .41187 Mdot
.862 .41352 Mdot
.862 .41381 Mdot
.862 .41441 Mdot
.862 .41527 Mdot
.862 .4166 Mdot
.862 .4178 Mdot
.862 .42138 Mdot
.862 .42223 Mdot
.862 .42349 Mdot
.862 .42493 Mdot
.862 .42582 Mdot
.862 .42584 Mdot
.862 .42627 Mdot
.862 .42741 Mdot
.862 .42793 Mdot
.862 .42931 Mdot
.862 .43031 Mdot
.862 .43171 Mdot
.862 .432 Mdot
.862 .43286 Mdot
.862 .43317 Mdot
.862 .43352 Mdot
.862 .43358 Mdot
.862 .43385 Mdot
.862 .43441 Mdot
.862 .43519 Mdot
.862 .43627 Mdot
.862 .43672 Mdot
.862 .43906 Mdot
.862 .44006 Mdot
.862 .44101 Mdot
.862 .44391 Mdot
.862 .44516 Mdot
.862 .44871 Mdot
.862 .44887 Mdot
.862 .44989 Mdot
.862 .4507 Mdot
.862 .45079 Mdot
.862 .45108 Mdot
.862 .45223 Mdot
.862 .45317 Mdot
.862 .45383 Mdot
.862 .45681 Mdot
.862 .45712 Mdot
.862 .45914 Mdot
.862 .4622 Mdot
.862 .46309 Mdot
.862 .4659 Mdot
.862 .46716 Mdot
.862 .46854 Mdot
.862 .46856 Mdot
.862 .46857 Mdot
.862 .46872 Mdot
.862 .47048 Mdot
.862 .47285 Mdot
.862 .47296 Mdot
.862 .47362 Mdot
.862 .47426 Mdot
.862 .47436 Mdot
.862 .47473 Mdot
.862 .47492 Mdot
.862 .47494 Mdot
.862 .47659 Mdot
.862 .47691 Mdot
.862 .47761 Mdot
.862 .4791 Mdot
.862 .48064 Mdot
.862 .48148 Mdot
.862 .48476 Mdot
.862 .4848 Mdot
.862 .48483 Mdot
.862 .48529 Mdot
.862 .48562 Mdot
.862 .48872 Mdot
.862 .48885 Mdot
.862 .49051 Mdot
.862 .49102 Mdot
.862 .49342 Mdot
.862 .49403 Mdot
.862 .49489 Mdot
.862 .49497 Mdot
.862 .49596 Mdot
.862 .49641 Mdot
.862 .49683 Mdot
.862 .49756 Mdot
.862 .49789 Mdot
.862 .49984 Mdot
.862 .50176 Mdot
.862 .50205 Mdot
.862 .50315 Mdot
.862 .50371 Mdot
.862 .50376 Mdot
.862 .50418 Mdot
.862 .50511 Mdot
.862 .50619 Mdot
.862 .50707 Mdot
.862 .50866 Mdot
.862 .50884 Mdot
.862 .50961 Mdot
.862 .51009 Mdot
.862 .51171 Mdot
.862 .5124 Mdot
.862 .51255 Mdot
.862 .51334 Mdot
.862 .51443 Mdot
.862 .51459 Mdot
.862 .51492 Mdot
.862 .51612 Mdot
.862 .51652 Mdot
.862 .51753 Mdot
.862 .51974 Mdot
.862 .52016 Mdot
.862 .5207 Mdot
.862 .52299 Mdot
.862 .52321 Mdot
.862 .52399 Mdot
.864 .01608 Mdot
.864 .01638 Mdot
.864 .01679 Mdot
.864 .01706 Mdot
.864 .01707 Mdot
.864 .0176 Mdot
.864 .01786 Mdot
.864 .0183 Mdot
.864 .0186 Mdot
.864 .01868 Mdot
.864 .01877 Mdot
.864 .01878 Mdot
.864 .0197 Mdot
.864 .02015 Mdot
.864 .02091 Mdot
.864 .02144 Mdot
.864 .02156 Mdot
.864 .02173 Mdot
.864 .02174 Mdot
.864 .02178 Mdot
.864 .02303 Mdot
.864 .02333 Mdot
.864 .0241 Mdot
.864 .02509 Mdot
.864 .02543 Mdot
.864 .02565 Mdot
.864 .02597 Mdot
.864 .02633 Mdot
.864 .02644 Mdot
.864 .02655 Mdot
.864 .02683 Mdot
.864 .02685 Mdot
.864 .02692 Mdot
.864 .02721 Mdot
.864 .02726 Mdot
.864 .02895 Mdot
.864 .02909 Mdot
.864 .0296 Mdot
.864 .02997 Mdot
.864 .03041 Mdot
.864 .03047 Mdot
.864 .03093 Mdot
.864 .03152 Mdot
.864 .03154 Mdot
.864 .03183 Mdot
.864 .03265 Mdot
.864 .03309 Mdot
.864 .03322 Mdot
.864 .03362 Mdot
.864 .03366 Mdot
.864 .03417 Mdot
.864 .03438 Mdot
.864 .03454 Mdot
.864 .03478 Mdot
.864 .03498 Mdot
.864 .03516 Mdot
.864 .0354 Mdot
.864 .03565 Mdot
.864 .03568 Mdot
.864 .03581 Mdot
.864 .03608 Mdot
.864 .03631 Mdot
.864 .0364 Mdot
.864 .0371 Mdot
.864 .03801 Mdot
.864 .03823 Mdot
.864 .03926 Mdot
.864 .03932 Mdot
.864 .03955 Mdot
.864 .04044 Mdot
.864 .04094 Mdot
.864 .04107 Mdot
.864 .04183 Mdot
.864 .04193 Mdot
.864 .04202 Mdot
.864 .04274 Mdot
.864 .04285 Mdot
.864 .04326 Mdot
.864 .04376 Mdot
.864 .04378 Mdot
.864 .04429 Mdot
.864 .04538 Mdot
.864 .0457 Mdot
.864 .04647 Mdot
.864 .04648 Mdot
.864 .0467 Mdot
.864 .04691 Mdot
.864 .04738 Mdot
.864 .04746 Mdot
.864 .04762 Mdot
.864 .04808 Mdot
.864 .04834 Mdot
.864 .04869 Mdot
.864 .0488 Mdot
.864 .04897 Mdot
.864 .04939 Mdot
.864 .04973 Mdot
.864 .05004 Mdot
.864 .05046 Mdot
.864 .05058 Mdot
.864 .05068 Mdot
.864 .05075 Mdot
.864 .05089 Mdot
.864 .05094 Mdot
.864 .05117 Mdot
.864 .05163 Mdot
.864 .05203 Mdot
.864 .05219 Mdot
.864 .05293 Mdot
.864 .05339 Mdot
.864 .05383 Mdot
.864 .05444 Mdot
.864 .05476 Mdot
.864 .05497 Mdot
.864 .05535 Mdot
.864 .05627 Mdot
.864 .05714 Mdot
.864 .05723 Mdot
.864 .05744 Mdot
.864 .05763 Mdot
.864 .05764 Mdot
.864 .05791 Mdot
.864 .05838 Mdot
.864 .05903 Mdot
.864 .05916 Mdot
.864 .05983 Mdot
.864 .06003 Mdot
.864 .06026 Mdot
.864 .06053 Mdot
.864 .06107 Mdot
.864 .06111 Mdot
.864 .06157 Mdot
.864 .06175 Mdot
.864 .0619 Mdot
.864 .06191 Mdot
.864 .06289 Mdot
.864 .06294 Mdot
.864 .06315 Mdot
.864 .06333 Mdot
.864 .06404 Mdot
.864 .06423 Mdot
.864 .06491 Mdot
.864 .06495 Mdot
.864 .06535 Mdot
.864 .06536 Mdot
.864 .06544 Mdot
.864 .06582 Mdot
.864 .06712 Mdot
.864 .06751 Mdot
.864 .06771 Mdot
.864 .06826 Mdot
.864 .06959 Mdot
.864 .0696 Mdot
.864 .06998 Mdot
.864 .07035 Mdot
.864 .07116 Mdot
.864 .07129 Mdot
.864 .07157 Mdot
.864 .07237 Mdot
.864 .07246 Mdot
.864 .07281 Mdot
.864 .07328 Mdot
.864 .07343 Mdot
.864 .07362 Mdot
.864 .07391 Mdot
.864 .07415 Mdot
.864 .07423 Mdot
.864 .07434 Mdot
.864 .07463 Mdot
.864 .07522 Mdot
.864 .07546 Mdot
.864 .07576 Mdot
.864 .07648 Mdot
.864 .07668 Mdot
.864 .07681 Mdot
.864 .07686 Mdot
.864 .07699 Mdot
.864 .07722 Mdot
.864 .07731 Mdot
.864 .0777 Mdot
.864 .07771 Mdot
.864 .0785 Mdot
.864 .07869 Mdot
.864 .07898 Mdot
.864 .07919 Mdot
.864 .07947 Mdot
.864 .08075 Mdot
.864 .08113 Mdot
.864 .08155 Mdot
.864 .08155 Mdot
.864 .08172 Mdot
.864 .08205 Mdot
.864 .08231 Mdot
.864 .08336 Mdot
.864 .08364 Mdot
.864 .08391 Mdot
.864 .08427 Mdot
.864 .08427 Mdot
.864 .08458 Mdot
.864 .08493 Mdot
.864 .08566 Mdot
.864 .08653 Mdot
.864 .08802 Mdot
.864 .08818 Mdot
.864 .08855 Mdot
.864 .08888 Mdot
.864 .0889 Mdot
.864 .08936 Mdot
.864 .09018 Mdot
.864 .09108 Mdot
.864 .09129 Mdot
.864 .09152 Mdot
.864 .09184 Mdot
.864 .09224 Mdot
.864 .09256 Mdot
.864 .09268 Mdot
.864 .09272 Mdot
.864 .09302 Mdot
.864 .09341 Mdot
.864 .09388 Mdot
.864 .09482 Mdot
.864 .09489 Mdot
.864 .09567 Mdot
.864 .09596 Mdot
.864 .09598 Mdot
.864 .09624 Mdot
.864 .09626 Mdot
.864 .09657 Mdot
.864 .09777 Mdot
.864 .09797 Mdot
.864 .09805 Mdot
.864 .09839 Mdot
.864 .0984 Mdot
.864 .09872 Mdot
.864 .09936 Mdot
.864 .09971 Mdot
.864 .09973 Mdot
.864 .09994 Mdot
.864 .10023 Mdot
.864 .10023 Mdot
.864 .10028 Mdot
.864 .10088 Mdot
.864 .10101 Mdot
.864 .10124 Mdot
.864 .10145 Mdot
.864 .10151 Mdot
.864 .10207 Mdot
.864 .10222 Mdot
.864 .10222 Mdot
.864 .10237 Mdot
.864 .10302 Mdot
.864 .10371 Mdot
.864 .10416 Mdot
.864 .10498 Mdot
.864 .10527 Mdot
.864 .10594 Mdot
.864 .10629 Mdot
.864 .10647 Mdot
.864 .10724 Mdot
.864 .10953 Mdot
.864 .10955 Mdot
.864 .11021 Mdot
.864 .11078 Mdot
.864 .11085 Mdot
.864 .11219 Mdot
.864 .11225 Mdot
.864 .11248 Mdot
.864 .11257 Mdot
.864 .11296 Mdot
.864 .11346 Mdot
.864 .11435 Mdot
.864 .11449 Mdot
.864 .11511 Mdot
.864 .11586 Mdot
.864 .11592 Mdot
.864 .11617 Mdot
.864 .1165 Mdot
.864 .11669 Mdot
.864 .11679 Mdot
.864 .117 Mdot
.864 .1173 Mdot
.864 .11741 Mdot
.864 .11755 Mdot
.864 .11775 Mdot
.864 .11808 Mdot
.864 .11825 Mdot
.864 .1183 Mdot
.864 .1185 Mdot
.864 .11927 Mdot
.864 .11968 Mdot
.864 .1202 Mdot
.864 .12071 Mdot
.864 .12144 Mdot
.864 .12179 Mdot
.864 .12202 Mdot
.864 .12211 Mdot
.864 .1222 Mdot
.864 .12233 Mdot
.864 .12262 Mdot
.864 .12272 Mdot
.864 .12288 Mdot
.864 .12355 Mdot
.864 .12355 Mdot
.864 .12357 Mdot
.864 .12389 Mdot
.864 .12397 Mdot
.864 .12493 Mdot
.864 .12526 Mdot
.864 .12577 Mdot
.864 .12614 Mdot
.864 .12661 Mdot
.864 .12669 Mdot
.864 .1271 Mdot
.864 .12722 Mdot
.864 .12854 Mdot
.864 .12882 Mdot
.864 .12886 Mdot
.864 .12948 Mdot
.864 .12983 Mdot
.864 .12995 Mdot
.864 .13021 Mdot
.864 .13021 Mdot
.864 .13051 Mdot
.864 .13107 Mdot
.864 .13123 Mdot
.864 .13152 Mdot
.864 .13288 Mdot
.864 .13334 Mdot
.864 .1335 Mdot
.864 .13352 Mdot
.864 .13381 Mdot
.864 .13428 Mdot
.864 .13457 Mdot
.864 .1349 Mdot
.864 .13491 Mdot
.864 .13544 Mdot
.864 .13554 Mdot
.864 .13586 Mdot
.864 .13605 Mdot
.864 .13632 Mdot
.864 .13716 Mdot
.864 .13731 Mdot
.864 .13881 Mdot
.864 .14118 Mdot
.864 .14138 Mdot
.864 .14167 Mdot
.864 .14177 Mdot
.864 .14224 Mdot
.864 .1423 Mdot
.864 .14287 Mdot
.864 .1429 Mdot
.864 .1437 Mdot
.864 .14407 Mdot
.864 .14511 Mdot
.864 .14667 Mdot
.864 .14704 Mdot
.864 .14744 Mdot
.864 .14799 Mdot
.864 .14867 Mdot
.864 .14873 Mdot
.864 .14911 Mdot
.864 .14923 Mdot
.864 .14944 Mdot
.864 .1495 Mdot
.864 .15003 Mdot
.864 .1507 Mdot
.864 .15144 Mdot
.864 .15151 Mdot
.864 .15314 Mdot
.864 .15325 Mdot
.864 .15461 Mdot
.864 .15511 Mdot
.864 .15515 Mdot
.864 .1556 Mdot
.864 .15562 Mdot
.864 .15616 Mdot
.864 .15633 Mdot
.864 .15736 Mdot
.864 .15738 Mdot
.864 .15823 Mdot
.864 .15858 Mdot
.864 .15872 Mdot
.864 .15884 Mdot
.864 .1593 Mdot
.864 .15933 Mdot
.864 .15938 Mdot
.864 .15988 Mdot
.864 .15994 Mdot
.864 .16098 Mdot
.864 .16159 Mdot
.864 .16161 Mdot
.864 .16176 Mdot
.864 .16199 Mdot
.864 .16208 Mdot
.864 .16248 Mdot
.864 .16248 Mdot
.864 .16257 Mdot
.864 .16362 Mdot
.864 .16384 Mdot
.864 .16422 Mdot
.864 .16459 Mdot
.864 .1647 Mdot
.864 .16502 Mdot
.864 .16518 Mdot
.864 .16566 Mdot
.864 .16592 Mdot
.864 .16593 Mdot
.864 .16618 Mdot
.864 .1673 Mdot
.864 .16851 Mdot
.864 .16927 Mdot
.864 .1693 Mdot
.864 .17069 Mdot
.864 .1712 Mdot
.864 .17123 Mdot
.864 .17236 Mdot
.864 .17296 Mdot
.864 .17327 Mdot
.864 .17461 Mdot
.864 .17586 Mdot
.864 .1766 Mdot
.864 .17856 Mdot
.864 .1786 Mdot
.864 .17969 Mdot
.864 .17974 Mdot
.864 .18063 Mdot
.864 .18072 Mdot
.864 .18084 Mdot
.864 .18314 Mdot
.864 .18325 Mdot
.864 .18365 Mdot
.864 .18381 Mdot
.864 .18449 Mdot
.864 .18463 Mdot
.864 .18535 Mdot
.864 .18652 Mdot
.864 .18688 Mdot
.864 .18713 Mdot
.864 .18715 Mdot
.864 .18819 Mdot
.864 .18861 Mdot
.864 .1893 Mdot
.864 .18949 Mdot
.864 .1896 Mdot
.864 .19003 Mdot
.864 .1906 Mdot
.864 .19093 Mdot
.864 .1911 Mdot
.864 .19146 Mdot
.864 .19146 Mdot
.864 .19198 Mdot
.864 .19217 Mdot
.864 .19241 Mdot
.864 .19275 Mdot
.864 .19332 Mdot
.864 .19363 Mdot
.864 .1937 Mdot
.864 .19405 Mdot
.864 .19461 Mdot
.864 .19497 Mdot
.864 .19525 Mdot
.864 .19539 Mdot
.864 .1961 Mdot
.864 .19685 Mdot
.864 .197 Mdot
.864 .19724 Mdot
.864 .19784 Mdot
.864 .19787 Mdot
.864 .1979 Mdot
.864 .19862 Mdot
.864 .19893 Mdot
.864 .19913 Mdot
.864 .19924 Mdot
.864 .19974 Mdot
.864 .20014 Mdot
.864 .20029 Mdot
.864 .20045 Mdot
.864 .20067 Mdot
.864 .20117 Mdot
.864 .20135 Mdot
.864 .20163 Mdot
.864 .20196 Mdot
.864 .20198 Mdot
.864 .20279 Mdot
.864 .20279 Mdot
.864 .20281 Mdot
.864 .20338 Mdot
.864 .20351 Mdot
.864 .20516 Mdot
.864 .20544 Mdot
.864 .20573 Mdot
.864 .2058 Mdot
.864 .20617 Mdot
.864 .20662 Mdot
.864 .20692 Mdot
.864 .20725 Mdot
.864 .20807 Mdot
.864 .20821 Mdot
.864 .20891 Mdot
.864 .20912 Mdot
.864 .20922 Mdot
.864 .20959 Mdot
.864 .2114 Mdot
.864 .2119 Mdot
.864 .21195 Mdot
.864 .21304 Mdot
.864 .21364 Mdot
.864 .21385 Mdot
.864 .21429 Mdot
.864 .2143 Mdot
.864 .21468 Mdot
.864 .2148 Mdot
.864 .21563 Mdot
.864 .21578 Mdot
.864 .21606 Mdot
.864 .21656 Mdot
.864 .218 Mdot
.864 .2186 Mdot
.864 .2189 Mdot
.864 .2197 Mdot
.864 .21998 Mdot
.864 .22001 Mdot
.864 .22044 Mdot
.864 .22052 Mdot
.864 .22058 Mdot
.864 .22132 Mdot
.864 .22182 Mdot
.864 .22239 Mdot
.864 .22242 Mdot
.864 .22333 Mdot
.864 .2235 Mdot
.864 .22405 Mdot
.864 .22438 Mdot
.864 .22442 Mdot
.864 .22485 Mdot
.864 .22561 Mdot
.864 .22629 Mdot
.864 .22655 Mdot
.864 .22818 Mdot
.864 .22838 Mdot
.864 .22915 Mdot
.864 .23071 Mdot
.864 .23084 Mdot
.864 .23161 Mdot
.864 .23325 Mdot
.864 .2336 Mdot
.864 .2336 Mdot
.864 .23409 Mdot
.864 .23427 Mdot
.864 .23446 Mdot
.864 .23507 Mdot
.864 .23518 Mdot
.864 .23616 Mdot
.864 .23622 Mdot
.864 .2376 Mdot
.864 .23824 Mdot
.864 .23979 Mdot
.864 .24004 Mdot
.864 .24108 Mdot
.864 .24139 Mdot
.864 .24273 Mdot
.864 .24336 Mdot
.864 .24358 Mdot
.864 .24406 Mdot
.864 .2443 Mdot
.864 .24502 Mdot
.864 .24607 Mdot
.864 .24619 Mdot
.864 .24629 Mdot
.864 .24682 Mdot
.864 .24695 Mdot
.864 .24715 Mdot
.864 .24717 Mdot
.864 .24742 Mdot
.864 .24752 Mdot
.864 .24762 Mdot
.864 .24854 Mdot
.864 .24854 Mdot
.864 .2497 Mdot
.864 .24982 Mdot
.864 .24994 Mdot
.864 .2502 Mdot
.864 .25097 Mdot
.864 .25109 Mdot
.864 .2528 Mdot
.864 .25311 Mdot
.864 .25391 Mdot
.864 .25411 Mdot
.864 .25472 Mdot
.864 .25477 Mdot
.864 .25606 Mdot
.864 .25646 Mdot
.864 .25732 Mdot
.864 .25738 Mdot
.864 .25816 Mdot
.864 .25821 Mdot
.864 .25847 Mdot
.864 .25913 Mdot
.864 .25942 Mdot
.864 .26121 Mdot
.864 .26124 Mdot
.864 .26164 Mdot
.864 .26174 Mdot
.864 .26247 Mdot
.864 .26271 Mdot
.864 .26331 Mdot
.864 .26356 Mdot
.864 .26368 Mdot
.864 .26376 Mdot
.864 .26413 Mdot
.864 .26456 Mdot
.864 .2646 Mdot
.864 .26469 Mdot
.864 .26556 Mdot
.864 .26567 Mdot
.864 .26621 Mdot
.864 .26622 Mdot
.864 .26665 Mdot
.864 .26746 Mdot
.864 .26852 Mdot
.864 .26856 Mdot
.864 .2688 Mdot
.864 .2692 Mdot
.864 .26936 Mdot
.864 .27005 Mdot
.864 .27006 Mdot
.864 .2702 Mdot
.864 .27202 Mdot
.864 .27208 Mdot
.864 .27226 Mdot
.864 .2724 Mdot
.864 .2728 Mdot
.864 .27307 Mdot
.864 .27322 Mdot
.864 .2737 Mdot
.864 .27389 Mdot
.864 .27441 Mdot
.864 .27444 Mdot
.864 .27472 Mdot
.864 .27521 Mdot
.864 .27555 Mdot
.864 .27566 Mdot
.864 .276 Mdot
.864 .27601 Mdot
.864 .27645 Mdot
.864 .27711 Mdot
.864 .27768 Mdot
.864 .27838 Mdot
.864 .27922 Mdot
.864 .27931 Mdot
.864 .28016 Mdot
.864 .28047 Mdot
.864 .28161 Mdot
.864 .28179 Mdot
.864 .28184 Mdot
.864 .28262 Mdot
.864 .28295 Mdot
.864 .28396 Mdot
.864 .284 Mdot
.864 .28424 Mdot
.864 .28511 Mdot
.864 .28517 Mdot
.864 .2853 Mdot
.864 .28712 Mdot
.864 .28727 Mdot
.864 .28789 Mdot
.864 .28817 Mdot
.864 .28869 Mdot
.864 .28899 Mdot
.864 .29101 Mdot
.864 .29109 Mdot
.864 .29317 Mdot
.864 .29359 Mdot
.864 .29384 Mdot
.864 .29445 Mdot
.864 .29638 Mdot
.864 .29731 Mdot
.864 .29784 Mdot
.864 .2979 Mdot
.864 .2998 Mdot
.864 .29987 Mdot
.864 .30071 Mdot
.864 .30125 Mdot
.864 .30142 Mdot
.864 .30142 Mdot
.864 .30157 Mdot
.864 .30178 Mdot
.864 .30374 Mdot
.864 .30473 Mdot
.864 .30576 Mdot
.864 .30594 Mdot
.864 .30663 Mdot
.864 .30691 Mdot
.864 .30775 Mdot
.864 .30787 Mdot
.864 .30808 Mdot
.864 .30833 Mdot
.864 .30858 Mdot
.864 .30956 Mdot
.864 .31118 Mdot
.864 .31136 Mdot
.864 .3116 Mdot
.864 .31175 Mdot
.864 .31222 Mdot
.864 .31265 Mdot
.864 .31269 Mdot
.864 .31448 Mdot
.864 .31521 Mdot
.864 .3164 Mdot
.864 .31673 Mdot
.864 .31691 Mdot
.864 .31718 Mdot
.864 .31763 Mdot
.864 .31766 Mdot
.864 .31864 Mdot
.864 .31922 Mdot
.864 .31948 Mdot
.864 .31951 Mdot
.864 .32012 Mdot
.864 .32013 Mdot
.864 .3203 Mdot
.864 .32103 Mdot
.864 .32136 Mdot
.864 .32178 Mdot
.864 .32187 Mdot
.864 .32237 Mdot
.864 .32276 Mdot
.864 .32335 Mdot
.864 .32388 Mdot
.864 .324 Mdot
.864 .3246 Mdot
.864 .32557 Mdot
.864 .3262 Mdot
.864 .32668 Mdot
.864 .32691 Mdot
.864 .32814 Mdot
.864 .32878 Mdot
.864 .32903 Mdot
.864 .32944 Mdot
.864 .32971 Mdot
.864 .33012 Mdot
.864 .33115 Mdot
.864 .33121 Mdot
.864 .33125 Mdot
.864 .33251 Mdot
.864 .33303 Mdot
.864 .33339 Mdot
.864 .33357 Mdot
.864 .33445 Mdot
.864 .33512 Mdot
.864 .33524 Mdot
.864 .33539 Mdot
.864 .33567 Mdot
.864 .33604 Mdot
.864 .33651 Mdot
.864 .33691 Mdot
.864 .33722 Mdot
.864 .33725 Mdot
.864 .3377 Mdot
.864 .33828 Mdot
.864 .33831 Mdot
.864 .33905 Mdot
.864 .3397 Mdot
.864 .3397 Mdot
.864 .33975 Mdot
.864 .34072 Mdot
.864 .34095 Mdot
.864 .34381 Mdot
.864 .34429 Mdot
.864 .34479 Mdot
.864 .34483 Mdot
.864 .3449 Mdot
.864 .34555 Mdot
.864 .34633 Mdot
.864 .34685 Mdot
.864 .34742 Mdot
.864 .34759 Mdot
.864 .34883 Mdot
.864 .34908 Mdot
.864 .34917 Mdot
.864 .34936 Mdot
.864 .35028 Mdot
.864 .35065 Mdot
.864 .35083 Mdot
.864 .35145 Mdot
.864 .35459 Mdot
.864 .35503 Mdot
.864 .35526 Mdot
.864 .35544 Mdot
.864 .35554 Mdot
.864 .35741 Mdot
.864 .35777 Mdot
.864 .35846 Mdot
.864 .35882 Mdot
.864 .35938 Mdot
.864 .35959 Mdot
.864 .35959 Mdot
.864 .35988 Mdot
.864 .35988 Mdot
.864 .36026 Mdot
.864 .36034 Mdot
.864 .36047 Mdot
.864 .36095 Mdot
.864 .3619 Mdot
.864 .36216 Mdot
.864 .36263 Mdot
.864 .36349 Mdot
.864 .36599 Mdot
.864 .3668 Mdot
.864 .36703 Mdot
.864 .36754 Mdot
.864 .36893 Mdot
.864 .36941 Mdot
.864 .36947 Mdot
.864 .36976 Mdot
.864 .37021 Mdot
.864 .37034 Mdot
.864 .37045 Mdot
.864 .37173 Mdot
.864 .3726 Mdot
.864 .37284 Mdot
.864 .37338 Mdot
.864 .37358 Mdot
.864 .37362 Mdot
.864 .3752 Mdot
.864 .37543 Mdot
.864 .3755 Mdot
.864 .37627 Mdot
.864 .37645 Mdot
.864 .37702 Mdot
.864 .37709 Mdot
.864 .37782 Mdot
.864 .37878 Mdot
.864 .37914 Mdot
.864 .37915 Mdot
.864 .37976 Mdot
.864 .38032 Mdot
.864 .3805 Mdot
.864 .38077 Mdot
.864 .38125 Mdot
.864 .38358 Mdot
.864 .38393 Mdot
.864 .38419 Mdot
.864 .38526 Mdot
.864 .38795 Mdot
.864 .38817 Mdot
.864 .38952 Mdot
.864 .39235 Mdot
.864 .39295 Mdot
.864 .39296 Mdot
.864 .3938 Mdot
.864 .39411 Mdot
.864 .39444 Mdot
.864 .39549 Mdot
.864 .39567 Mdot
.864 .39738 Mdot
.864 .39747 Mdot
.864 .39986 Mdot
.864 .40097 Mdot
.864 .40365 Mdot
.864 .40408 Mdot
.864 .40587 Mdot
.864 .40641 Mdot
.864 .40873 Mdot
.864 .40982 Mdot
.864 .41019 Mdot
.864 .41103 Mdot
.864 .41143 Mdot
.864 .41268 Mdot
.864 .4145 Mdot
.864 .41471 Mdot
.864 .41487 Mdot
.864 .4158 Mdot
.864 .41603 Mdot
.864 .41637 Mdot
.864 .4164 Mdot
.864 .41683 Mdot
.864 .417 Mdot
.864 .41718 Mdot
.864 .41876 Mdot
.864 .41877 Mdot
.864 .42077 Mdot
.864 .42097 Mdot
.864 .42119 Mdot
.864 .42163 Mdot
.864 .42296 Mdot
.864 .42317 Mdot
.864 .42612 Mdot
.864 .42667 Mdot
.864 .42804 Mdot
.864 .42838 Mdot
.864 .42945 Mdot
.864 .42953 Mdot
.864 .43175 Mdot
.864 .43244 Mdot
.864 .43393 Mdot
.864 .43404 Mdot
.864 .43539 Mdot
.864 .43547 Mdot
.864 .43592 Mdot
.864 .43707 Mdot
.864 .43756 Mdot
.864 .44065 Mdot
.864 .44139 Mdot
.864 .44158 Mdot
.864 .44284 Mdot
.864 .44326 Mdot
.864 .44428 Mdot
.864 .44472 Mdot
.864 .44492 Mdot
.864 .44506 Mdot
.864 .44571 Mdot
.864 .44645 Mdot
.864 .44652 Mdot
.864 .44667 Mdot
.864 .44817 Mdot
.864 .44836 Mdot
.864 .44929 Mdot
.864 .44932 Mdot
.864 .45006 Mdot
.864 .45146 Mdot
.864 .45329 Mdot
.864 .45335 Mdot
.864 .45377 Mdot
.864 .45447 Mdot
.864 .45474 Mdot
.864 .45593 Mdot
.864 .45594 Mdot
.864 .45619 Mdot
.864 .45933 Mdot
.864 .45944 Mdot
.864 .45975 Mdot
.864 .45999 Mdot
.864 .46068 Mdot
.864 .46114 Mdot
.864 .46141 Mdot
.864 .46224 Mdot
.864 .46258 Mdot
.864 .46347 Mdot
.864 .46352 Mdot
.864 .46401 Mdot
.864 .46485 Mdot
.864 .46543 Mdot
.864 .46563 Mdot
.864 .46621 Mdot
.864 .46623 Mdot
.864 .46699 Mdot
.864 .46813 Mdot
.864 .46912 Mdot
.864 .47034 Mdot
.864 .47178 Mdot
.864 .47193 Mdot
.864 .4734 Mdot
.864 .47393 Mdot
.864 .4759 Mdot
.864 .47622 Mdot
.864 .47631 Mdot
.864 .47766 Mdot
.864 .47823 Mdot
.864 .47998 Mdot
.864 .48005 Mdot
.864 .48046 Mdot
.864 .48196 Mdot
.864 .48207 Mdot
.864 .48229 Mdot
.864 .48544 Mdot
.864 .48569 Mdot
.864 .48676 Mdot
.864 .48724 Mdot
.864 .48815 Mdot
.864 .48866 Mdot
.864 .49214 Mdot
.864 .49229 Mdot
.864 .49588 Mdot
.864 .49662 Mdot
.864 .49705 Mdot
.864 .49809 Mdot
.864 .50144 Mdot
.864 .50303 Mdot
.864 .50395 Mdot
.864 .50406 Mdot
.864 .50734 Mdot
.864 .50747 Mdot
.864 .50892 Mdot
.864 .50985 Mdot
.864 .51015 Mdot
.864 .51015 Mdot
.864 .51041 Mdot
.864 .51076 Mdot
.864 .51415 Mdot
.864 .51586 Mdot
.864 .51764 Mdot
.864 .51796 Mdot
.864 .51914 Mdot
.864 .51963 Mdot
.864 .52108 Mdot
.864 .52129 Mdot
.864 .52165 Mdot
.864 .52208 Mdot
.864 .52251 Mdot
.864 .52421 Mdot
.866 .01536 Mdot
.866 .01584 Mdot
.866 .01666 Mdot
.866 .01672 Mdot
.866 .01809 Mdot
.866 .01818 Mdot
.866 .0189 Mdot
.866 .02007 Mdot
.866 .02056 Mdot
.866 .02072 Mdot
.866 .02074 Mdot
.866 .02074 Mdot
.866 .02135 Mdot
.866 .02196 Mdot
.866 .02257 Mdot
.866 .02374 Mdot
.866 .02375 Mdot
.866 .02388 Mdot
.866 .02398 Mdot
.866 .02484 Mdot
.866 .02511 Mdot
.866 .02515 Mdot
.866 .02515 Mdot
.866 .02581 Mdot
.866 .02608 Mdot
.866 .02613 Mdot
.866 .02621 Mdot
.866 .02714 Mdot
.866 .02727 Mdot
.866 .02734 Mdot
.866 .02832 Mdot
.866 .02927 Mdot
.866 .02938 Mdot
.866 .03028 Mdot
.866 .03034 Mdot
.866 .03036 Mdot
.866 .03059 Mdot
.866 .03072 Mdot
.866 .03076 Mdot
.866 .03126 Mdot
.866 .03226 Mdot
.866 .03273 Mdot
.866 .03275 Mdot
.866 .03278 Mdot
.866 .03278 Mdot
.866 .0335 Mdot
.866 .03393 Mdot
.866 .03411 Mdot
.866 .03423 Mdot
.866 .0344 Mdot
.866 .03448 Mdot
.866 .03463 Mdot
.866 .03469 Mdot
.866 .03612 Mdot
.866 .03615 Mdot
.866 .03622 Mdot
.866 .03624 Mdot
.866 .03626 Mdot
.866 .03646 Mdot
.866 .03657 Mdot
.866 .0375 Mdot
.866 .03827 Mdot
.866 .03833 Mdot
.866 .03875 Mdot
.866 .03922 Mdot
.866 .03993 Mdot
.866 .04012 Mdot
.866 .04021 Mdot
.866 .04167 Mdot
.866 .04178 Mdot
.866 .04181 Mdot
.866 .04193 Mdot
.866 .04222 Mdot
.866 .04244 Mdot
.866 .04251 Mdot
.866 .04268 Mdot
.866 .04337 Mdot
.866 .0451 Mdot
.866 .04591 Mdot
.866 .04591 Mdot
.866 .04595 Mdot
.866 .04601 Mdot
.866 .04601 Mdot
.866 .04662 Mdot
.866 .04725 Mdot
.866 .048 Mdot
.866 .0483 Mdot
.866 .04851 Mdot
.866 .04882 Mdot
.866 .04895 Mdot
.866 .04921 Mdot
.866 .04932 Mdot
.866 .05179 Mdot
.866 .05184 Mdot
.866 .05197 Mdot
.866 .052 Mdot
.866 .05203 Mdot
.866 .05216 Mdot
.866 .05238 Mdot
.866 .05257 Mdot
.866 .05417 Mdot
.866 .05552 Mdot
.866 .05562 Mdot
.866 .05634 Mdot
.866 .05706 Mdot
.866 .05715 Mdot
.866 .05766 Mdot
.866 .05823 Mdot
.866 .05839 Mdot
.866 .05869 Mdot
.866 .05872 Mdot
.866 .05888 Mdot
.866 .05974 Mdot
.866 .06139 Mdot
.866 .06156 Mdot
.866 .0616 Mdot
.866 .06163 Mdot
.866 .06164 Mdot
.866 .0617 Mdot
.866 .06184 Mdot
.866 .06212 Mdot
.866 .06219 Mdot
.866 .06235 Mdot
.866 .06274 Mdot
.866 .06286 Mdot
.866 .06314 Mdot
.866 .06384 Mdot
.866 .06434 Mdot
.866 .06641 Mdot
.866 .06734 Mdot
.866 .06743 Mdot
.866 .06816 Mdot
.866 .06846 Mdot
.866 .06874 Mdot
.866 .06875 Mdot
.866 .06881 Mdot
.866 .06891 Mdot
.866 .06892 Mdot
.866 .06998 Mdot
.866 .07026 Mdot
.866 .07107 Mdot
.866 .07127 Mdot
.866 .07236 Mdot
.866 .07289 Mdot
.866 .07324 Mdot
.866 .07378 Mdot
.866 .07401 Mdot
.866 .07402 Mdot
.866 .07425 Mdot
.866 .07446 Mdot
.866 .07465 Mdot
.866 .07517 Mdot
.866 .07578 Mdot
.866 .07689 Mdot
.866 .07874 Mdot
.866 .07877 Mdot
.866 .07882 Mdot
.866 .07893 Mdot
.866 .07901 Mdot
.866 .07902 Mdot
.866 .07924 Mdot
.866 .07929 Mdot
.866 .07934 Mdot
.866 .0794 Mdot
.866 .07943 Mdot
.866 .07956 Mdot
.866 .07995 Mdot
.866 .08028 Mdot
.866 .0805 Mdot
.866 .08118 Mdot
.866 .0813 Mdot
.866 .08146 Mdot
.866 .08169 Mdot
.866 .08306 Mdot
.866 .08324 Mdot
.866 .08358 Mdot
.866 .0837 Mdot
.866 .08416 Mdot
.866 .08438 Mdot
.866 .08465 Mdot
.866 .08499 Mdot
.866 .08538 Mdot
.866 .08548 Mdot
.866 .08556 Mdot
.866 .08616 Mdot
.866 .0868 Mdot
.866 .08717 Mdot
.866 .08806 Mdot
.866 .08821 Mdot
.866 .08888 Mdot
.866 .0891 Mdot
.866 .08967 Mdot
.866 .08973 Mdot
.866 .09009 Mdot
.866 .09036 Mdot
.866 .09089 Mdot
.866 .09093 Mdot
.866 .09117 Mdot
.866 .09121 Mdot
.866 .09144 Mdot
.866 .09265 Mdot
.866 .09269 Mdot
.866 .09343 Mdot
.866 .0946 Mdot
.866 .09546 Mdot
.866 .09556 Mdot
.866 .09584 Mdot
.866 .09591 Mdot
.866 .09597 Mdot
.866 .09598 Mdot
.866 .0961 Mdot
.866 .09634 Mdot
.866 .09682 Mdot
.866 .09694 Mdot
.866 .09722 Mdot
.866 .09789 Mdot
.866 .0981 Mdot
.866 .09859 Mdot
.866 .09907 Mdot
.866 .09979 Mdot
.866 .10029 Mdot
.866 .10066 Mdot
.866 .10071 Mdot
.866 .10179 Mdot
.866 .10319 Mdot
.866 .10426 Mdot
.866 .10528 Mdot
.866 .10586 Mdot
.866 .10602 Mdot
.866 .10727 Mdot
.866 .1075 Mdot
.866 .1078 Mdot
.866 .10829 Mdot
.866 .1083 Mdot
.866 .1084 Mdot
.866 .10859 Mdot
.866 .10859 Mdot
.866 .1089 Mdot
.866 .11043 Mdot
.866 .11052 Mdot
.866 .11063 Mdot
.866 .11078 Mdot
.866 .11087 Mdot
.866 .11092 Mdot
.866 .11155 Mdot
.866 .11233 Mdot
.866 .11267 Mdot
.866 .11295 Mdot
.866 .11409 Mdot
.866 .11431 Mdot
.866 .11444 Mdot
.866 .11456 Mdot
.866 .11502 Mdot
.866 .11548 Mdot
.866 .11608 Mdot
.866 .1161 Mdot
.866 .11701 Mdot
.866 .11742 Mdot
.866 .11743 Mdot
.866 .11783 Mdot
.866 .11819 Mdot
.866 .11852 Mdot
.866 .11928 Mdot
.866 .11942 Mdot
.866 .12049 Mdot
.866 .12195 Mdot
.866 .1223 Mdot
.866 .1224 Mdot
.866 .12274 Mdot
.866 .12343 Mdot
.866 .12492 Mdot
.866 .12561 Mdot
.866 .12566 Mdot
.866 .12574 Mdot
.866 .12594 Mdot
.866 .12607 Mdot
.866 .1261 Mdot
.866 .12647 Mdot
.866 .12656 Mdot
.866 .12665 Mdot
.866 .12674 Mdot
.866 .12681 Mdot
.866 .12703 Mdot
.866 .12723 Mdot
.866 .12756 Mdot
.866 .12771 Mdot
.866 .12772 Mdot
.866 .12828 Mdot
.866 .12866 Mdot
.866 .12952 Mdot
.866 .12983 Mdot
.866 .13004 Mdot
.866 .13031 Mdot
.866 .13071 Mdot
.866 .13192 Mdot
.866 .1328 Mdot
.866 .13308 Mdot
.866 .13341 Mdot
.866 .13399 Mdot
.866 .1342 Mdot
.866 .135 Mdot
.866 .13503 Mdot
.866 .13538 Mdot
.866 .13584 Mdot
.866 .13644 Mdot
.866 .13698 Mdot
.866 .13711 Mdot
.866 .13728 Mdot
.866 .13741 Mdot
.866 .13768 Mdot
.866 .13785 Mdot
.866 .13823 Mdot
.866 .13845 Mdot
.866 .13854 Mdot
.866 .1394 Mdot
.866 .13957 Mdot
.866 .1401 Mdot
.866 .14021 Mdot
.866 .14134 Mdot
.866 .1415 Mdot
.866 .14175 Mdot
.866 .14201 Mdot
.866 .14227 Mdot
.866 .14238 Mdot
.866 .14272 Mdot
.866 .14291 Mdot
.866 .14317 Mdot
.866 .14355 Mdot
.866 .14435 Mdot
.866 .14453 Mdot
.866 .14463 Mdot
.866 .14526 Mdot
.866 .1455 Mdot
.866 .14573 Mdot
.866 .14594 Mdot
.866 .14618 Mdot
.866 .14664 Mdot
.866 .14672 Mdot
.866 .14673 Mdot
.866 .14714 Mdot
.866 .1472 Mdot
.866 .1473 Mdot
.866 .14734 Mdot
.866 .1476 Mdot
.866 .14793 Mdot
.866 .14886 Mdot
.866 .1497 Mdot
.866 .14977 Mdot
.866 .15029 Mdot
.866 .15044 Mdot
.866 .15104 Mdot
.866 .15132 Mdot
.866 .15307 Mdot
.866 .15406 Mdot
.866 .15457 Mdot
.866 .15465 Mdot
.866 .15474 Mdot
.866 .15523 Mdot
.866 .15535 Mdot
.866 .15546 Mdot
.866 .15547 Mdot
.866 .15567 Mdot
.866 .15609 Mdot
.866 .15642 Mdot
.866 .15692 Mdot
.866 .15713 Mdot
.866 .15762 Mdot
.866 .15824 Mdot
.866 .15878 Mdot
.866 .15914 Mdot
.866 .15922 Mdot
.866 .15994 Mdot
.866 .15999 Mdot
.866 .16018 Mdot
.866 .16052 Mdot
.866 .16082 Mdot
.866 .16135 Mdot
.866 .16207 Mdot
.866 .16263 Mdot
.866 .16293 Mdot
.866 .16326 Mdot
.866 .16357 Mdot
.866 .16366 Mdot
.866 .16399 Mdot
.866 .16533 Mdot
.866 .16552 Mdot
.866 .1659 Mdot
.866 .16769 Mdot
.866 .16795 Mdot
.866 .16867 Mdot
.866 .1698 Mdot
.866 .16986 Mdot
.866 .17002 Mdot
.866 .17157 Mdot
.866 .17197 Mdot
.866 .17257 Mdot
.866 .17286 Mdot
.866 .17496 Mdot
.866 .17503 Mdot
.866 .17508 Mdot
.866 .17541 Mdot
.866 .17593 Mdot
.866 .17613 Mdot
.866 .17678 Mdot
.866 .17681 Mdot
.866 .17698 Mdot
.866 .1771 Mdot
.866 .1773 Mdot
.866 .17731 Mdot
.866 .17761 Mdot
.866 .17784 Mdot
.866 .1805 Mdot
.866 .18066 Mdot
.866 .18084 Mdot
.866 .18088 Mdot
.866 .18111 Mdot
.866 .18126 Mdot
.866 .18134 Mdot
.866 .18211 Mdot
.866 .18244 Mdot
.866 .18269 Mdot
.866 .18331 Mdot
.866 .18378 Mdot
.866 .18436 Mdot
.866 .18441 Mdot
.866 .18486 Mdot
.866 .18565 Mdot
.866 .1861 Mdot
.866 .18683 Mdot
.866 .18722 Mdot
.866 .18744 Mdot
.866 .18764 Mdot
.866 .18805 Mdot
.866 .18844 Mdot
.866 .18844 Mdot
.866 .18849 Mdot
.866 .18922 Mdot
.866 .18924 Mdot
.866 .19028 Mdot
.866 .19032 Mdot
.866 .19062 Mdot
.866 .19095 Mdot
.866 .19144 Mdot
.866 .19169 Mdot
.866 .1919 Mdot
.866 .1926 Mdot
.866 .19261 Mdot
.866 .19303 Mdot
.866 .1933 Mdot
.866 .1936 Mdot
.866 .19393 Mdot
.866 .1945 Mdot
.866 .19475 Mdot
.866 .19583 Mdot
.866 .19607 Mdot
.866 .19791 Mdot
.866 .19955 Mdot
.866 .20044 Mdot
.866 .20105 Mdot
.866 .20123 Mdot
.866 .20126 Mdot
.866 .20181 Mdot
.866 .20301 Mdot
.866 .20335 Mdot
.866 .20395 Mdot
.866 .20428 Mdot
.866 .20558 Mdot
.866 .20678 Mdot
.866 .20686 Mdot
.866 .20699 Mdot
.866 .20701 Mdot
.866 .20736 Mdot
.866 .20759 Mdot
.866 .20763 Mdot
.866 .20776 Mdot
.866 .20828 Mdot
.866 .20843 Mdot
.866 .20858 Mdot
.866 .20874 Mdot
.866 .20886 Mdot
.866 .20925 Mdot
.866 .20959 Mdot
.866 .21016 Mdot
.866 .21042 Mdot
.866 .21044 Mdot
.866 .21092 Mdot
.866 .21141 Mdot
.866 .21167 Mdot
.866 .21206 Mdot
.866 .21235 Mdot
.866 .21355 Mdot
.866 .21396 Mdot
.866 .2141 Mdot
.866 .21446 Mdot
.866 .21492 Mdot
.866 .21562 Mdot
.866 .2174 Mdot
.866 .21771 Mdot
.866 .21868 Mdot
.866 .21923 Mdot
.866 .22029 Mdot
.866 .22129 Mdot
.866 .22144 Mdot
.866 .22167 Mdot
.866 .22305 Mdot
.866 .2231 Mdot
.866 .2237 Mdot
.866 .2245 Mdot
.866 .22554 Mdot
.866 .22648 Mdot
.866 .22661 Mdot
.866 .22671 Mdot
.866 .227 Mdot
.866 .22723 Mdot
.866 .2277 Mdot
.866 .22799 Mdot
.866 .22865 Mdot
.866 .22903 Mdot
.866 .22918 Mdot
.866 .22926 Mdot
.866 .22964 Mdot
.866 .22984 Mdot
.866 .23015 Mdot
.866 .23063 Mdot
.866 .23067 Mdot
.866 .23097 Mdot
.866 .23188 Mdot
.866 .23208 Mdot
.866 .23267 Mdot
.866 .23328 Mdot
.866 .2336 Mdot
.866 .23384 Mdot
.866 .23392 Mdot
.866 .23404 Mdot
.866 .23431 Mdot
.866 .23474 Mdot
.866 .23495 Mdot
.866 .23519 Mdot
.866 .23564 Mdot
.866 .23583 Mdot
.866 .23643 Mdot
.866 .23675 Mdot
.866 .23715 Mdot
.866 .2372 Mdot
.866 .23785 Mdot
.866 .23885 Mdot
.866 .23889 Mdot
.866 .23924 Mdot
.866 .23956 Mdot
.866 .23973 Mdot
.866 .24082 Mdot
.866 .24123 Mdot
.866 .24143 Mdot
.866 .24163 Mdot
.866 .242 Mdot
.866 .24241 Mdot
.866 .24256 Mdot
.866 .24321 Mdot
.866 .24334 Mdot
.866 .24336 Mdot
.866 .2436 Mdot
.866 .24407 Mdot
.866 .24418 Mdot
.866 .24434 Mdot
.866 .24443 Mdot
.866 .24487 Mdot
.866 .24506 Mdot
.866 .24545 Mdot
.866 .24705 Mdot
.866 .24762 Mdot
.866 .24831 Mdot
.866 .24851 Mdot
.866 .24862 Mdot
.866 .24953 Mdot
.866 .24978 Mdot
.866 .25084 Mdot
.866 .25109 Mdot
.866 .25131 Mdot
.866 .25185 Mdot
.866 .253 Mdot
.866 .25342 Mdot
.866 .25434 Mdot
.866 .25607 Mdot
.866 .25695 Mdot
.866 .25708 Mdot
.866 .25714 Mdot
.866 .25725 Mdot
.866 .25741 Mdot
.866 .25809 Mdot
.866 .25829 Mdot
.866 .2584 Mdot
.866 .25848 Mdot
.866 .25851 Mdot
.866 .25885 Mdot
.866 .25958 Mdot
.866 .26015 Mdot
.866 .26016 Mdot
.866 .26101 Mdot
.866 .26139 Mdot
.866 .26173 Mdot
.866 .26222 Mdot
.866 .26307 Mdot
.866 .2633 Mdot
.866 .26423 Mdot
.866 .26448 Mdot
.866 .26486 Mdot
.866 .26501 Mdot
.866 .26625 Mdot
.866 .26633 Mdot
.866 .26666 Mdot
.866 .26725 Mdot
.866 .26778 Mdot
.866 .26822 Mdot
.866 .26869 Mdot
.866 .26994 Mdot
.866 .27091 Mdot
.866 .27113 Mdot
.866 .27143 Mdot
.866 .27179 Mdot
.866 .27199 Mdot
.866 .27253 Mdot
.866 .27268 Mdot
.866 .27269 Mdot
.866 .27327 Mdot
.866 .27378 Mdot
.866 .27439 Mdot
.866 .27558 Mdot
.866 .27591 Mdot
.866 .27601 Mdot
.866 .27645 Mdot
.866 .27648 Mdot
.866 .27657 Mdot
.866 .27821 Mdot
.866 .27967 Mdot
.866 .27974 Mdot
.866 .28012 Mdot
.866 .28136 Mdot
.866 .28157 Mdot
.866 .28332 Mdot
.866 .28342 Mdot
.866 .2837 Mdot
.866 .28516 Mdot
.866 .28613 Mdot
.866 .28639 Mdot
.866 .28643 Mdot
.866 .28708 Mdot
.866 .28775 Mdot
.866 .28784 Mdot
.866 .28812 Mdot
.866 .28812 Mdot
.866 .28862 Mdot
.866 .29226 Mdot
.866 .29237 Mdot
.866 .29246 Mdot
.866 .29303 Mdot
.866 .29304 Mdot
.866 .29395 Mdot
.866 .29428 Mdot
.866 .29541 Mdot
.866 .29546 Mdot
.866 .29575 Mdot
.866 .29596 Mdot
.866 .29632 Mdot
.866 .29634 Mdot
.866 .29684 Mdot
.866 .29725 Mdot
.866 .29741 Mdot
.866 .29762 Mdot
.866 .29876 Mdot
.866 .30186 Mdot
.866 .30213 Mdot
.866 .30244 Mdot
.866 .30249 Mdot
.866 .3025 Mdot
.866 .3029 Mdot
.866 .30312 Mdot
.866 .30317 Mdot
.866 .3033 Mdot
.866 .30464 Mdot
.866 .30521 Mdot
.866 .30565 Mdot
.866 .30672 Mdot
.866 .30753 Mdot
.866 .30837 Mdot
.866 .30855 Mdot
.866 .30864 Mdot
.866 .30867 Mdot
.866 .30941 Mdot
.866 .30952 Mdot
.866 .31077 Mdot
.866 .31155 Mdot
.866 .31281 Mdot
.866 .31349 Mdot
.866 .31387 Mdot
.866 .31387 Mdot
.866 .31423 Mdot
.866 .31493 Mdot
.866 .31561 Mdot
.866 .31561 Mdot
.866 .31569 Mdot
.866 .3168 Mdot
.866 .31696 Mdot
.866 .31699 Mdot
.866 .31757 Mdot
.866 .31768 Mdot
.866 .3188 Mdot
.866 .31887 Mdot
.866 .31938 Mdot
.866 .31964 Mdot
.866 .31995 Mdot
.866 .32081 Mdot
.866 .32124 Mdot
.866 .32159 Mdot
.866 .32166 Mdot
.866 .32193 Mdot
.866 .32276 Mdot
.866 .32277 Mdot
.866 .32281 Mdot
.866 .32283 Mdot
.866 .32355 Mdot
.866 .32403 Mdot
.866 .32427 Mdot
.866 .32454 Mdot
.866 .32512 Mdot
.866 .32611 Mdot
.866 .32654 Mdot
.866 .32841 Mdot
.866 .32882 Mdot
.866 .33201 Mdot
.866 .33485 Mdot
.866 .33519 Mdot
.866 .33552 Mdot
.866 .33579 Mdot
.866 .33639 Mdot
.866 .33744 Mdot
.866 .33748 Mdot
.866 .33753 Mdot
.866 .33777 Mdot
.866 .33781 Mdot
.866 .33876 Mdot
.866 .34024 Mdot
.866 .34083 Mdot
.866 .34125 Mdot
.866 .34143 Mdot
.866 .34247 Mdot
.866 .34305 Mdot
.866 .34464 Mdot
.866 .34477 Mdot
.866 .3453 Mdot
.866 .34566 Mdot
.866 .34629 Mdot
.866 .34736 Mdot
.866 .34738 Mdot
.866 .34741 Mdot
.866 .34752 Mdot
.866 .34774 Mdot
.866 .34776 Mdot
.866 .34838 Mdot
.866 .34877 Mdot
.866 .34884 Mdot
.866 .34893 Mdot
.866 .34906 Mdot
.866 .34996 Mdot
.866 .35016 Mdot
.866 .35023 Mdot
.866 .35049 Mdot
.866 .35062 Mdot
.866 .35077 Mdot
.866 .35097 Mdot
.866 .35125 Mdot
.866 .35164 Mdot
.866 .35223 Mdot
.866 .35322 Mdot
.866 .35367 Mdot
.866 .3537 Mdot
.866 .35454 Mdot
.866 .35469 Mdot
.866 .35539 Mdot
.866 .35584 Mdot
.866 .35652 Mdot
.866 .35702 Mdot
.866 .3591 Mdot
.866 .3598 Mdot
.866 .36005 Mdot
.866 .36067 Mdot
.866 .36148 Mdot
.866 .36268 Mdot
.866 .36396 Mdot
.866 .36478 Mdot
.866 .36571 Mdot
.866 .36577 Mdot
.866 .36586 Mdot
.866 .36591 Mdot
.866 .36631 Mdot
.866 .36711 Mdot
.866 .36777 Mdot
.866 .3679 Mdot
.866 .36797 Mdot
.866 .36831 Mdot
.866 .36894 Mdot
.866 .37077 Mdot
.866 .37231 Mdot
.866 .37251 Mdot
.866 .37276 Mdot
.866 .37316 Mdot
.866 .37402 Mdot
.866 .37536 Mdot
.866 .37555 Mdot
.866 .37564 Mdot
.866 .37668 Mdot
.866 .37807 Mdot
.866 .37857 Mdot
.866 .37986 Mdot
.866 .38099 Mdot
.866 .38139 Mdot
.866 .38149 Mdot
.866 .38171 Mdot
.866 .38189 Mdot
.866 .38239 Mdot
.866 .38279 Mdot
.866 .38351 Mdot
.866 .3836 Mdot
.866 .38404 Mdot
.866 .38411 Mdot
.866 .3843 Mdot
.866 .38441 Mdot
.866 .38524 Mdot
.866 .38591 Mdot
.866 .38616 Mdot
.866 .3863 Mdot
.866 .38662 Mdot
.866 .38694 Mdot
.866 .38697 Mdot
.866 .38731 Mdot
.866 .38784 Mdot
.866 .38867 Mdot
.866 .38876 Mdot
.866 .38927 Mdot
.866 .39085 Mdot
.866 .39119 Mdot
.866 .39221 Mdot
.866 .39326 Mdot
.866 .39383 Mdot
.866 .39424 Mdot
.866 .39438 Mdot
.866 .39458 Mdot
.866 .39506 Mdot
.866 .3958 Mdot
.866 .39616 Mdot
.866 .39659 Mdot
.866 .39736 Mdot
.866 .39769 Mdot
.866 .39872 Mdot
.866 .39928 Mdot
.866 .39997 Mdot
.866 .40006 Mdot
.866 .40119 Mdot
.866 .40292 Mdot
.866 .40298 Mdot
.866 .40359 Mdot
.866 .40415 Mdot
.866 .40444 Mdot
.866 .40633 Mdot
.866 .40704 Mdot
.866 .40738 Mdot
.866 .40774 Mdot
.866 .40838 Mdot
.866 .40909 Mdot
.866 .40935 Mdot
.866 .41047 Mdot
.866 .4107 Mdot
.866 .41073 Mdot
.866 .41115 Mdot
.866 .41196 Mdot
.866 .41215 Mdot
.866 .41243 Mdot
.866 .41258 Mdot
.866 .41335 Mdot
.866 .41368 Mdot
.866 .41434 Mdot
.866 .41711 Mdot
.866 .4181 Mdot
.866 .41931 Mdot
.866 .41965 Mdot
.866 .41985 Mdot
.866 .42141 Mdot
.866 .42185 Mdot
.866 .42368 Mdot
.866 .42411 Mdot
.866 .4245 Mdot
.866 .42543 Mdot
.866 .42742 Mdot
.866 .42816 Mdot
.866 .42975 Mdot
.866 .43274 Mdot
.866 .43426 Mdot
.866 .43449 Mdot
.866 .4346 Mdot
.866 .43478 Mdot
.866 .43506 Mdot
.866 .43624 Mdot
.866 .43659 Mdot
.866 .43678 Mdot
.866 .43691 Mdot
.866 .43696 Mdot
.866 .43755 Mdot
.866 .43882 Mdot
.866 .4398 Mdot
.866 .43983 Mdot
.866 .44129 Mdot
.866 .44195 Mdot
.866 .44255 Mdot
.866 .44339 Mdot
.866 .44487 Mdot
.866 .44527 Mdot
.866 .44687 Mdot
.866 .44731 Mdot
.866 .44797 Mdot
.866 .44822 Mdot
.866 .45037 Mdot
.866 .45052 Mdot
.866 .45109 Mdot
.866 .45211 Mdot
.866 .45302 Mdot
.866 .45379 Mdot
.866 .4546 Mdot
.866 .45676 Mdot
.866 .45844 Mdot
.866 .45882 Mdot
.866 .45934 Mdot
.866 .45997 Mdot
.866 .46032 Mdot
.866 .46126 Mdot
.866 .46151 Mdot
.866 .46153 Mdot
.866 .46253 Mdot
.866 .46341 Mdot
.866 .46447 Mdot
.866 .46654 Mdot
.866 .4671 Mdot
.866 .46727 Mdot
.866 .46804 Mdot
.866 .46809 Mdot
.866 .46825 Mdot
.866 .47108 Mdot
.866 .47361 Mdot
.866 .47373 Mdot
.866 .4744 Mdot
.866 .47655 Mdot
.866 .47691 Mdot
.866 .47994 Mdot
.866 .48012 Mdot
.866 .4806 Mdot
.866 .48312 Mdot
.866 .48481 Mdot
.866 .48526 Mdot
.866 .48532 Mdot
.866 .48645 Mdot
.866 .48762 Mdot
.866 .48777 Mdot
.866 .48825 Mdot
.866 .48826 Mdot
.866 .48912 Mdot
.866 .49543 Mdot
.866 .49562 Mdot
.866 .49577 Mdot
.866 .49675 Mdot
.866 .49678 Mdot
.866 .49835 Mdot
.866 .49893 Mdot
.866 .50088 Mdot
.866 .50096 Mdot
.866 .50147 Mdot
.866 .50184 Mdot
.866 .50246 Mdot
.866 .50248 Mdot
.866 .50336 Mdot
.866 .50407 Mdot
.866 .50434 Mdot
.866 .5047 Mdot
.866 .50669 Mdot
.866 .51204 Mdot
.866 .51251 Mdot
.866 .51305 Mdot
.866 .51314 Mdot
.866 .51317 Mdot
.866 .51386 Mdot
.866 .51424 Mdot
.866 .51431 Mdot
.866 .51455 Mdot
.866 .51686 Mdot
.866 .51785 Mdot
.866 .51862 Mdot
.866 .52048 Mdot
.866 .52187 Mdot
.866 .52332 Mdot
.866 .52363 Mdot
.866 .52378 Mdot
.866 .52385 Mdot
.866 .52512 Mdot
.866 .52531 Mdot
.868 .01717 Mdot
.868 .0173 Mdot
.868 .01823 Mdot
.868 .01897 Mdot
.868 .01915 Mdot
.868 .01921 Mdot
.868 .02082 Mdot
.868 .02159 Mdot
.868 .02181 Mdot
.868 .0221 Mdot
.868 .02242 Mdot
.868 .02251 Mdot
.868 .02281 Mdot
.868 .0233 Mdot
.868 .02442 Mdot
.868 .02465 Mdot
.868 .0248 Mdot
.868 .02531 Mdot
.868 .02666 Mdot
.868 .0269 Mdot
.868 .02703 Mdot
.868 .02753 Mdot
.868 .02756 Mdot
.868 .02809 Mdot
.868 .02825 Mdot
.868 .0286 Mdot
.868 .02877 Mdot
.868 .02925 Mdot
.868 .02961 Mdot
.868 .03157 Mdot
.868 .03197 Mdot
.868 .03201 Mdot
.868 .03222 Mdot
.868 .03236 Mdot
.868 .0331 Mdot
.868 .03326 Mdot
.868 .03347 Mdot
.868 .03544 Mdot
.868 .03586 Mdot
.868 .03587 Mdot
.868 .0361 Mdot
.868 .0369 Mdot
.868 .03697 Mdot
.868 .03702 Mdot
.868 .03714 Mdot
.868 .03727 Mdot
.868 .03768 Mdot
.868 .03768 Mdot
.868 .03793 Mdot
.868 .03809 Mdot
.868 .03822 Mdot
.868 .03882 Mdot
.868 .03903 Mdot
.868 .03911 Mdot
.868 .03926 Mdot
.868 .03973 Mdot
.868 .03995 Mdot
.868 .04058 Mdot
.868 .04163 Mdot
.868 .04206 Mdot
.868 .04227 Mdot
.868 .04397 Mdot
.868 .04466 Mdot
.868 .04475 Mdot
.868 .0451 Mdot
.868 .04534 Mdot
.868 .04557 Mdot
.868 .04664 Mdot
.868 .04691 Mdot
.868 .04714 Mdot
.868 .04727 Mdot
.868 .04881 Mdot
.868 .04933 Mdot
.868 .0507 Mdot
.868 .0511 Mdot
.868 .05143 Mdot
.868 .05144 Mdot
.868 .05175 Mdot
.868 .05184 Mdot
.868 .05322 Mdot
.868 .05335 Mdot
.868 .05344 Mdot
.868 .05346 Mdot
.868 .05364 Mdot
.868 .05387 Mdot
.868 .05431 Mdot
.868 .05444 Mdot
.868 .05457 Mdot
.868 .05458 Mdot
.868 .05459 Mdot
.868 .05483 Mdot
.868 .05502 Mdot
.868 .05529 Mdot
.868 .05551 Mdot
.868 .05656 Mdot
.868 .05692 Mdot
.868 .05706 Mdot
.868 .05715 Mdot
.868 .05733 Mdot
.868 .05768 Mdot
.868 .05815 Mdot
.868 .05852 Mdot
.868 .05947 Mdot
.868 .05962 Mdot
.868 .06039 Mdot
.868 .06041 Mdot
.868 .06143 Mdot
.868 .06185 Mdot
.868 .06194 Mdot
.868 .06219 Mdot
.868 .06255 Mdot
.868 .06438 Mdot
.868 .0649 Mdot
.868 .06551 Mdot
.868 .06553 Mdot
.868 .06565 Mdot
.868 .06581 Mdot
.868 .0667 Mdot
.868 .06685 Mdot
.868 .06747 Mdot
.868 .06788 Mdot
.868 .06802 Mdot
.868 .06828 Mdot
.868 .06881 Mdot
.868 .06936 Mdot
.868 .07014 Mdot
.868 .0706 Mdot
.868 .071 Mdot
.868 .07122 Mdot
.868 .07201 Mdot
.868 .07212 Mdot
.868 .07391 Mdot
.868 .07399 Mdot
.868 .07419 Mdot
.868 .07424 Mdot
.868 .0748 Mdot
.868 .07504 Mdot
.868 .07642 Mdot
.868 .07676 Mdot
.868 .07686 Mdot
.868 .07719 Mdot
.868 .07754 Mdot
.868 .07787 Mdot
.868 .07845 Mdot
.868 .07848 Mdot
.868 .07901 Mdot
.868 .07916 Mdot
.868 .08024 Mdot
.868 .08037 Mdot
.868 .08052 Mdot
.868 .0812 Mdot
.868 .08156 Mdot
.868 .08178 Mdot
.868 .08194 Mdot
.868 .08194 Mdot
.868 .08197 Mdot
.868 .08229 Mdot
.868 .0823 Mdot
.868 .08268 Mdot
.868 .08346 Mdot
.868 .08368 Mdot
.868 .08391 Mdot
.868 .08391 Mdot
.868 .08393 Mdot
.868 .08436 Mdot
.868 .08468 Mdot
.868 .08516 Mdot
.868 .08539 Mdot
.868 .08554 Mdot
.868 .08617 Mdot
.868 .08674 Mdot
.868 .08716 Mdot
.868 .08736 Mdot
.868 .08798 Mdot
.868 .08799 Mdot
.868 .08805 Mdot
.868 .08818 Mdot
.868 .08823 Mdot
.868 .08838 Mdot
.868 .0887 Mdot
.868 .0893 Mdot
.868 .08976 Mdot
.868 .08997 Mdot
.868 .09011 Mdot
.868 .09035 Mdot
.868 .09067 Mdot
.868 .09076 Mdot
.868 .09088 Mdot
.868 .09123 Mdot
.868 .09241 Mdot
.868 .09266 Mdot
.868 .09298 Mdot
.868 .09389 Mdot
.868 .09401 Mdot
.868 .09404 Mdot
.868 .09581 Mdot
.868 .09649 Mdot
.868 .09654 Mdot
.868 .09668 Mdot
.868 .09669 Mdot
.868 .09713 Mdot
.868 .09773 Mdot
.868 .09777 Mdot
.868 .09906 Mdot
.868 .1003 Mdot
.868 .10084 Mdot
.868 .10093 Mdot
.868 .10183 Mdot
.868 .10289 Mdot
.868 .10292 Mdot
.868 .10314 Mdot
.868 .10342 Mdot
.868 .10373 Mdot
.868 .10394 Mdot
.868 .10407 Mdot
.868 .10471 Mdot
.868 .10491 Mdot
.868 .10496 Mdot
.868 .10522 Mdot
.868 .10524 Mdot
.868 .10614 Mdot
.868 .1063 Mdot
.868 .10702 Mdot
.868 .10725 Mdot
.868 .1077 Mdot
.868 .10856 Mdot
.868 .10862 Mdot
.868 .10959 Mdot
.868 .11049 Mdot
.868 .11093 Mdot
.868 .11173 Mdot
.868 .11191 Mdot
.868 .11196 Mdot
.868 .11197 Mdot
.868 .11226 Mdot
.868 .11243 Mdot
.868 .11282 Mdot
.868 .11418 Mdot
.868 .11437 Mdot
.868 .11447 Mdot
.868 .11468 Mdot
.868 .11516 Mdot
.868 .11528 Mdot
.868 .11613 Mdot
.868 .11747 Mdot
.868 .11761 Mdot
.868 .11797 Mdot
.868 .11805 Mdot
.868 .11873 Mdot
.868 .11903 Mdot
.868 .11944 Mdot
.868 .12045 Mdot
.868 .12156 Mdot
.868 .12184 Mdot
.868 .12242 Mdot
.868 .12259 Mdot
.868 .12317 Mdot
.868 .12378 Mdot
.868 .1242 Mdot
.868 .12436 Mdot
.868 .12484 Mdot
.868 .12535 Mdot
.868 .12538 Mdot
.868 .12541 Mdot
.868 .12568 Mdot
.868 .12575 Mdot
.868 .12634 Mdot
.868 .12649 Mdot
.868 .12659 Mdot
.868 .12728 Mdot
.868 .12779 Mdot
.868 .12846 Mdot
.868 .12869 Mdot
.868 .12895 Mdot
.868 .12919 Mdot
.868 .12988 Mdot
.868 .12991 Mdot
.868 .13007 Mdot
.868 .13013 Mdot
.868 .13076 Mdot
.868 .13113 Mdot
.868 .13142 Mdot
.868 .13142 Mdot
.868 .13147 Mdot
.868 .13203 Mdot
.868 .13205 Mdot
.868 .13271 Mdot
.868 .13398 Mdot
.868 .13405 Mdot
.868 .13444 Mdot
.868 .13484 Mdot
.868 .13485 Mdot
.868 .13488 Mdot
.868 .13562 Mdot
.868 .13617 Mdot
.868 .13685 Mdot
.868 .137 Mdot
.868 .1374 Mdot
.868 .13766 Mdot
.868 .13845 Mdot
.868 .13876 Mdot
.868 .13902 Mdot
.868 .13975 Mdot
.868 .13992 Mdot
.868 .13996 Mdot
.868 .13996 Mdot
.868 .14038 Mdot
.868 .14048 Mdot
.868 .14077 Mdot
.868 .14083 Mdot
.868 .14119 Mdot
.868 .1419 Mdot
.868 .14192 Mdot
.868 .14202 Mdot
.868 .14225 Mdot
.868 .14234 Mdot
.868 .1426 Mdot
.868 .14286 Mdot
.868 .14315 Mdot
.868 .14322 Mdot
.868 .14329 Mdot
.868 .14364 Mdot
.868 .14369 Mdot
.868 .1442 Mdot
.868 .14465 Mdot
.868 .145 Mdot
.868 .14536 Mdot
.868 .14561 Mdot
.868 .14601 Mdot
.868 .14657 Mdot
.868 .14672 Mdot
.868 .14694 Mdot
.868 .14755 Mdot
.868 .14838 Mdot
.868 .14876 Mdot
.868 .1496 Mdot
.868 .15003 Mdot
.868 .1504 Mdot
.868 .15058 Mdot
.868 .15103 Mdot
.868 .15155 Mdot
.868 .15172 Mdot
.868 .15216 Mdot
.868 .15237 Mdot
.868 .15242 Mdot
.868 .15431 Mdot
.868 .1555 Mdot
.868 .15551 Mdot
.868 .15554 Mdot
.868 .15599 Mdot
.868 .15648 Mdot
.868 .15665 Mdot
.868 .15667 Mdot
.868 .15668 Mdot
.868 .15677 Mdot
.868 .157 Mdot
.868 .15703 Mdot
.868 .15708 Mdot
.868 .1578 Mdot
.868 .15882 Mdot
.868 .15884 Mdot
.868 .15889 Mdot
.868 .15938 Mdot
.868 .16089 Mdot
.868 .16113 Mdot
.868 .16121 Mdot
.868 .16313 Mdot
.868 .1633 Mdot
.868 .16423 Mdot
.868 .16439 Mdot
.868 .16595 Mdot
.868 .1664 Mdot
.868 .16682 Mdot
.868 .16691 Mdot
.868 .16742 Mdot
.868 .16778 Mdot
.868 .16784 Mdot
.868 .16822 Mdot
.868 .16866 Mdot
.868 .16871 Mdot
.868 .16914 Mdot
.868 .16924 Mdot
.868 .16961 Mdot
.868 .16983 Mdot
.868 .17045 Mdot
.868 .17094 Mdot
.868 .17129 Mdot
.868 .17139 Mdot
.868 .17181 Mdot
.868 .17183 Mdot
.868 .17187 Mdot
.868 .17335 Mdot
.868 .17342 Mdot
.868 .1737 Mdot
.868 .17372 Mdot
.868 .17407 Mdot
.868 .17427 Mdot
.868 .17437 Mdot
.868 .17494 Mdot
.868 .17495 Mdot
.868 .17536 Mdot
.868 .17566 Mdot
.868 .1759 Mdot
.868 .17614 Mdot
.868 .17619 Mdot
.868 .17763 Mdot
.868 .17773 Mdot
.868 .17883 Mdot
.868 .17941 Mdot
.868 .18099 Mdot
.868 .18122 Mdot
.868 .18174 Mdot
.868 .18195 Mdot
.868 .18303 Mdot
.868 .18313 Mdot
.868 .18345 Mdot
.868 .18354 Mdot
.868 .18354 Mdot
.868 .18406 Mdot
.868 .18435 Mdot
.868 .1849 Mdot
.868 .18502 Mdot
.868 .1862 Mdot
.868 .18739 Mdot
.868 .18772 Mdot
.868 .18789 Mdot
.868 .18826 Mdot
.868 .18834 Mdot
.868 .18908 Mdot
.868 .1893 Mdot
.868 .18965 Mdot
.868 .19078 Mdot
.868 .19126 Mdot
.868 .19206 Mdot
.868 .1924 Mdot
.868 .19266 Mdot
.868 .19279 Mdot
.868 .1931 Mdot
.868 .19318 Mdot
.868 .19334 Mdot
.868 .19397 Mdot
.868 .19411 Mdot
.868 .19418 Mdot
.868 .19528 Mdot
.868 .1958 Mdot
.868 .19635 Mdot
.868 .19652 Mdot
.868 .19789 Mdot
.868 .19827 Mdot
.868 .19835 Mdot
.868 .19912 Mdot
.868 .20019 Mdot
.868 .20068 Mdot
.868 .20071 Mdot
.868 .20169 Mdot
.868 .20199 Mdot
.868 .20273 Mdot
.868 .20299 Mdot
.868 .20405 Mdot
.868 .20477 Mdot
.868 .20506 Mdot
.868 .20588 Mdot
.868 .20678 Mdot
.868 .20682 Mdot
.868 .20687 Mdot
.868 .2071 Mdot
.868 .20734 Mdot
.868 .20747 Mdot
.868 .20849 Mdot
.868 .20875 Mdot
.868 .20894 Mdot
.868 .20937 Mdot
.868 .20994 Mdot
.868 .21013 Mdot
.868 .21043 Mdot
.868 .21101 Mdot
.868 .21131 Mdot
.868 .21217 Mdot
.868 .21223 Mdot
.868 .21258 Mdot
.868 .21302 Mdot
.868 .21344 Mdot
.868 .21457 Mdot
.868 .21465 Mdot
.868 .21469 Mdot
.868 .21497 Mdot
.868 .21508 Mdot
.868 .21618 Mdot
.868 .21682 Mdot
.868 .21729 Mdot
.868 .21731 Mdot
.868 .21731 Mdot
.868 .21741 Mdot
.868 .21821 Mdot
.868 .21837 Mdot
.868 .21841 Mdot
.868 .21955 Mdot
.868 .22049 Mdot
.868 .22137 Mdot
.868 .22158 Mdot
.868 .22176 Mdot
.868 .22186 Mdot
.868 .22188 Mdot
.868 .22256 Mdot
.868 .22325 Mdot
.868 .22326 Mdot
.868 .22331 Mdot
.868 .22461 Mdot
.868 .22556 Mdot
.868 .22658 Mdot
.868 .22673 Mdot
.868 .22686 Mdot
.868 .22701 Mdot
.868 .22768 Mdot
.868 .2277 Mdot
.868 .22815 Mdot
.868 .22952 Mdot
.868 .23006 Mdot
.868 .2305 Mdot
.868 .23176 Mdot
.868 .23177 Mdot
.868 .23208 Mdot
.868 .23214 Mdot
.868 .23214 Mdot
.868 .23286 Mdot
.868 .23304 Mdot
.868 .23354 Mdot
.868 .23365 Mdot
.868 .23428 Mdot
.868 .23537 Mdot
.868 .23551 Mdot
.868 .23554 Mdot
.868 .23571 Mdot
.868 .23612 Mdot
.868 .23628 Mdot
.868 .23672 Mdot
.868 .23717 Mdot
.868 .23768 Mdot
.868 .2378 Mdot
.868 .23792 Mdot
.868 .23798 Mdot
.868 .23802 Mdot
.868 .2382 Mdot
.868 .23844 Mdot
.868 .23852 Mdot
.868 .23862 Mdot
.868 .23949 Mdot
.868 .24029 Mdot
.868 .24053 Mdot
.868 .24089 Mdot
.868 .24151 Mdot
.868 .24194 Mdot
.868 .24265 Mdot
.868 .24308 Mdot
.868 .24362 Mdot
.868 .24388 Mdot
.868 .244 Mdot
.868 .24408 Mdot
.868 .24413 Mdot
.868 .24426 Mdot
.868 .24459 Mdot
.868 .24531 Mdot
.868 .24582 Mdot
.868 .24597 Mdot
.868 .24623 Mdot
.868 .24675 Mdot
.868 .24742 Mdot
.868 .24887 Mdot
.868 .24963 Mdot
.868 .24982 Mdot
.868 .24998 Mdot
.868 .25027 Mdot
.868 .25058 Mdot
.868 .25135 Mdot
.868 .25226 Mdot
.868 .25256 Mdot
.868 .25332 Mdot
.868 .25361 Mdot
.868 .25368 Mdot
.868 .25377 Mdot
.868 .25534 Mdot
.868 .25543 Mdot
.868 .2557 Mdot
.868 .25706 Mdot
.868 .25826 Mdot
.868 .25912 Mdot
.868 .25913 Mdot
.868 .2592 Mdot
.868 .25928 Mdot
.868 .25997 Mdot
.868 .26082 Mdot
.868 .26112 Mdot
.868 .26115 Mdot
.868 .26116 Mdot
.868 .26131 Mdot
.868 .26172 Mdot
.868 .26177 Mdot
.868 .26186 Mdot
.868 .26305 Mdot
.868 .2631 Mdot
.868 .26431 Mdot
.868 .26488 Mdot
.868 .26491 Mdot
.868 .265 Mdot
.868 .26585 Mdot
.868 .26619 Mdot
.868 .26744 Mdot
.868 .26786 Mdot
.868 .26848 Mdot
.868 .2689 Mdot
.868 .26904 Mdot
.868 .27236 Mdot
.868 .27265 Mdot
.868 .27427 Mdot
.868 .27455 Mdot
.868 .27726 Mdot
.868 .27787 Mdot
.868 .27805 Mdot
.868 .27876 Mdot
.868 .27877 Mdot
.868 .27893 Mdot
.868 .27982 Mdot
.868 .28044 Mdot
.868 .28054 Mdot
.868 .2812 Mdot
.868 .28196 Mdot
.868 .28205 Mdot
.868 .28279 Mdot
.868 .28296 Mdot
.868 .28362 Mdot
.868 .28365 Mdot
.868 .284 Mdot
.868 .28447 Mdot
.868 .28508 Mdot
.868 .28593 Mdot
.868 .28652 Mdot
.868 .2867 Mdot
.868 .28744 Mdot
.868 .28746 Mdot
.868 .28754 Mdot
.868 .2901 Mdot
.868 .29023 Mdot
.868 .29072 Mdot
.868 .29074 Mdot
.868 .29136 Mdot
.868 .29171 Mdot
.868 .29188 Mdot
.868 .29264 Mdot
.868 .29286 Mdot
.868 .29289 Mdot
.868 .2936 Mdot
.868 .29412 Mdot
.868 .29448 Mdot
.868 .29453 Mdot
.868 .29495 Mdot
.868 .29501 Mdot
.868 .29503 Mdot
.868 .29716 Mdot
.868 .29719 Mdot
.868 .29753 Mdot
.868 .29767 Mdot
.868 .29771 Mdot
.868 .29961 Mdot
.868 .30035 Mdot
.868 .30062 Mdot
.868 .30222 Mdot
.868 .30254 Mdot
.868 .30336 Mdot
.868 .30451 Mdot
.868 .30467 Mdot
.868 .30503 Mdot
.868 .3068 Mdot
.868 .30691 Mdot
.868 .30709 Mdot
.868 .30709 Mdot
.868 .30764 Mdot
.868 .30779 Mdot
.868 .3078 Mdot
.868 .3087 Mdot
.868 .30921 Mdot
.868 .3093 Mdot
.868 .30983 Mdot
.868 .31015 Mdot
.868 .31036 Mdot
.868 .31181 Mdot
.868 .31189 Mdot
.868 .31242 Mdot
.868 .31295 Mdot
.868 .31436 Mdot
.868 .31448 Mdot
.868 .31506 Mdot
.868 .31534 Mdot
.868 .31599 Mdot
.868 .31612 Mdot
.868 .3162 Mdot
.868 .31742 Mdot
.868 .3178 Mdot
.868 .31839 Mdot
.868 .31877 Mdot
.868 .32036 Mdot
.868 .32056 Mdot
.868 .32108 Mdot
.868 .3212 Mdot
.868 .32258 Mdot
.868 .32317 Mdot
.868 .32331 Mdot
.868 .32339 Mdot
.868 .32362 Mdot
.868 .32363 Mdot
.868 .32386 Mdot
.868 .3244 Mdot
.868 .32454 Mdot
.868 .32481 Mdot
.868 .3259 Mdot
.868 .32615 Mdot
.868 .32627 Mdot
.868 .32817 Mdot
.868 .32907 Mdot
.868 .33004 Mdot
.868 .33033 Mdot
.868 .33135 Mdot
.868 .33173 Mdot
.868 .33271 Mdot
.868 .33321 Mdot
.868 .33328 Mdot
.868 .33336 Mdot
.868 .33351 Mdot
.868 .33484 Mdot
.868 .33515 Mdot
.868 .33618 Mdot
.868 .33671 Mdot
.868 .33672 Mdot
.868 .33755 Mdot
.868 .3376 Mdot
.868 .339 Mdot
.868 .3393 Mdot
.868 .33966 Mdot
.868 .33974 Mdot
.868 .33983 Mdot
.868 .3411 Mdot
.868 .34155 Mdot
.868 .34188 Mdot
.868 .3434 Mdot
.868 .34347 Mdot
.868 .34454 Mdot
.868 .34466 Mdot
.868 .34469 Mdot
.868 .34515 Mdot
.868 .34594 Mdot
.868 .34613 Mdot
.868 .34619 Mdot
.868 .34659 Mdot
.868 .34814 Mdot
.868 .34822 Mdot
.868 .3483 Mdot
.868 .34869 Mdot
.868 .34912 Mdot
.868 .34933 Mdot
.868 .35111 Mdot
.868 .35156 Mdot
.868 .35188 Mdot
.868 .3526 Mdot
.868 .35264 Mdot
.868 .35272 Mdot
.868 .35363 Mdot
.868 .35375 Mdot
.868 .35396 Mdot
.868 .35415 Mdot
.868 .35427 Mdot
.868 .35447 Mdot
.868 .35548 Mdot
.868 .356 Mdot
.868 .3575 Mdot
.868 .35761 Mdot
.868 .35821 Mdot
.868 .35898 Mdot
.868 .3597 Mdot
.868 .36001 Mdot
.868 .36167 Mdot
.868 .36179 Mdot
.868 .36187 Mdot
.868 .36224 Mdot
.868 .36235 Mdot
.868 .36254 Mdot
.868 .36306 Mdot
.868 .36445 Mdot
.868 .36557 Mdot
.868 .36639 Mdot
.868 .36641 Mdot
.868 .36642 Mdot
.868 .36659 Mdot
.868 .36786 Mdot
.868 .36798 Mdot
.868 .36825 Mdot
.868 .36833 Mdot
.868 .36882 Mdot
.868 .37031 Mdot
.868 .3713 Mdot
.868 .37194 Mdot
.868 .37346 Mdot
.868 .37383 Mdot
.868 .37414 Mdot
.868 .37431 Mdot
.868 .37435 Mdot
.868 .37478 Mdot
.868 .37524 Mdot
.868 .37553 Mdot
.868 .37634 Mdot
.868 .37674 Mdot
.868 .37675 Mdot
.868 .37684 Mdot
.868 .3791 Mdot
.868 .38075 Mdot
.868 .38167 Mdot
.868 .382 Mdot
.868 .38252 Mdot
.868 .38254 Mdot
.868 .38254 Mdot
.868 .38278 Mdot
.868 .38301 Mdot
.868 .38325 Mdot
.868 .38421 Mdot
.868 .38442 Mdot
.868 .38446 Mdot
.868 .38466 Mdot
.868 .38469 Mdot
.868 .38524 Mdot
.868 .38739 Mdot
.868 .38761 Mdot
.868 .38856 Mdot
.868 .38892 Mdot
.868 .38922 Mdot
.868 .38932 Mdot
.868 .39081 Mdot
.868 .3915 Mdot
.868 .39152 Mdot
.868 .39178 Mdot
.868 .39206 Mdot
.868 .39216 Mdot
.868 .39217 Mdot
.868 .3924 Mdot
.868 .39342 Mdot
.868 .39373 Mdot
.868 .3946 Mdot
.868 .39478 Mdot
.868 .39589 Mdot
.868 .39777 Mdot
.868 .39801 Mdot
.868 .39807 Mdot
.868 .39836 Mdot
.868 .39907 Mdot
.868 .39935 Mdot
.868 .40011 Mdot
.868 .40089 Mdot
.868 .40178 Mdot
.868 .40199 Mdot
.868 .40219 Mdot
.868 .40231 Mdot
.868 .40237 Mdot
.868 .40269 Mdot
.868 .40311 Mdot
.868 .40324 Mdot
.868 .40341 Mdot
.868 .40493 Mdot
.868 .40631 Mdot
.868 .40673 Mdot
.868 .40735 Mdot
.868 .40843 Mdot
.868 .40918 Mdot
.868 .41041 Mdot
.868 .41116 Mdot
.868 .41209 Mdot
.868 .41255 Mdot
.868 .41275 Mdot
.868 .4129 Mdot
.868 .41298 Mdot
.868 .4132 Mdot
.868 .41378 Mdot
.868 .41503 Mdot
.868 .41591 Mdot
.868 .41618 Mdot
.868 .41662 Mdot
.868 .41753 Mdot
.868 .4187 Mdot
.868 .42122 Mdot
.868 .42252 Mdot
.868 .42285 Mdot
.868 .42313 Mdot
.868 .42364 Mdot
.868 .42417 Mdot
.868 .42552 Mdot
.868 .42709 Mdot
.868 .42762 Mdot
.868 .42893 Mdot
.868 .42943 Mdot
.868 .42956 Mdot
.868 .42972 Mdot
.868 .43244 Mdot
.868 .4326 Mdot
.868 .43307 Mdot
.868 .43542 Mdot
.868 .4375 Mdot
.868 .43901 Mdot
.868 .43903 Mdot
.868 .43913 Mdot
.868 .43927 Mdot
.868 .44047 Mdot
.868 .44194 Mdot
.868 .44247 Mdot
.868 .44252 Mdot
.868 .44255 Mdot
.868 .44281 Mdot
.868 .44352 Mdot
.868 .44361 Mdot
.868 .44376 Mdot
.868 .44582 Mdot
.868 .44592 Mdot
.868 .44801 Mdot
.868 .44901 Mdot
.868 .44906 Mdot
.868 .44921 Mdot
.868 .45068 Mdot
.868 .45127 Mdot
.868 .45345 Mdot
.868 .45417 Mdot
.868 .45525 Mdot
.868 .45598 Mdot
.868 .45622 Mdot
.868 .46198 Mdot
.868 .46249 Mdot
.868 .46531 Mdot
.868 .46578 Mdot
.868 .47049 Mdot
.868 .47155 Mdot
.868 .47186 Mdot
.868 .47309 Mdot
.868 .47311 Mdot
.868 .47339 Mdot
.868 .47493 Mdot
.868 .47601 Mdot
.868 .47619 Mdot
.868 .47733 Mdot
.868 .47865 Mdot
.868 .47881 Mdot
.868 .48009 Mdot
.868 .4804 Mdot
.868 .48153 Mdot
.868 .48158 Mdot
.868 .48219 Mdot
.868 .483 Mdot
.868 .48407 Mdot
.868 .48554 Mdot
.868 .48657 Mdot
.868 .48687 Mdot
.868 .48816 Mdot
.868 .4882 Mdot
.868 .48834 Mdot
.868 .49279 Mdot
.868 .49301 Mdot
.868 .49386 Mdot
.868 .4939 Mdot
.868 .49498 Mdot
.868 .49557 Mdot
.868 .49588 Mdot
.868 .4972 Mdot
.868 .49758 Mdot
.868 .49762 Mdot
.868 .49885 Mdot
.868 .49977 Mdot
.868 .50039 Mdot
.868 .50047 Mdot
.868 .50119 Mdot
.868 .50131 Mdot
.868 .50134 Mdot
.868 .50503 Mdot
.868 .5051 Mdot
.868 .50569 Mdot
.868 .50592 Mdot
.868 .50599 Mdot
.868 .5093 Mdot
.868 .51058 Mdot
.868 .51105 Mdot
.868 .51382 Mdot
.868 .51437 Mdot
.868 .5158 Mdot
.868 .51781 Mdot
.868 .51807 Mdot
.868 .5187 Mdot
.868 .52178 Mdot
.868 .52196 Mdot
.868 .52228 Mdot
.868 .52228 Mdot
.868 .52324 Mdot
.868 .5235 Mdot
.868 .52352 Mdot
.868 .52507 Mdot
.868 .52595 Mdot
.868 .52612 Mdot
.868 .52704 Mdot
.868 .5276 Mdot
.868 .52796 Mdot
.87 .01879 Mdot
.87 .01892 Mdot
.87 .01931 Mdot
.87 .02098 Mdot
.87 .0218 Mdot
.87 .02204 Mdot
.87 .02251 Mdot
.87 .0226 Mdot
.87 .02271 Mdot
.87 .02362 Mdot
.87 .02408 Mdot
.87 .02411 Mdot
.87 .02562 Mdot
.87 .02614 Mdot
.87 .02657 Mdot
.87 .02705 Mdot
.87 .02745 Mdot
.87 .02827 Mdot
.87 .02843 Mdot
.87 .02862 Mdot
.87 .03021 Mdot
.87 .03053 Mdot
.87 .03062 Mdot
.87 .03101 Mdot
.87 .03106 Mdot
.87 .0313 Mdot
.87 .03168 Mdot
.87 .03262 Mdot
.87 .03368 Mdot
.87 .03441 Mdot
.87 .03459 Mdot
.87 .03535 Mdot
.87 .03617 Mdot
.87 .03671 Mdot
.87 .03688 Mdot
.87 .03724 Mdot
.87 .03784 Mdot
.87 .0383 Mdot
.87 .03859 Mdot
.87 .03891 Mdot
.87 .03909 Mdot
.87 .03911 Mdot
.87 .03975 Mdot
.87 .04064 Mdot
.87 .0413 Mdot
.87 .04168 Mdot
.87 .04224 Mdot
.87 .04238 Mdot
.87 .04239 Mdot
.87 .04268 Mdot
.87 .04306 Mdot
.87 .04316 Mdot
.87 .0435 Mdot
.87 .04358 Mdot
.87 .0436 Mdot
.87 .04372 Mdot
.87 .04424 Mdot
.87 .04436 Mdot
.87 .04488 Mdot
.87 .04488 Mdot
.87 .04586 Mdot
.87 .04633 Mdot
.87 .04694 Mdot
.87 .04696 Mdot
.87 .04772 Mdot
.87 .04838 Mdot
.87 .04842 Mdot
.87 .04899 Mdot
.87 .0493 Mdot
.87 .04932 Mdot
.87 .04956 Mdot
.87 .05061 Mdot
.87 .0518 Mdot
.87 .05193 Mdot
.87 .05205 Mdot
.87 .05223 Mdot
.87 .05268 Mdot
.87 .05299 Mdot
.87 .05328 Mdot
.87 .05351 Mdot
.87 .0539 Mdot
.87 .05496 Mdot
.87 .05576 Mdot
.87 .05597 Mdot
.87 .05625 Mdot
.87 .05659 Mdot
.87 .05681 Mdot
.87 .05713 Mdot
.87 .05717 Mdot
.87 .05828 Mdot
.87 .05983 Mdot
.87 .06056 Mdot
.87 .06065 Mdot
.87 .06096 Mdot
.87 .06163 Mdot
.87 .06164 Mdot
.87 .0618 Mdot
.87 .06238 Mdot
.87 .06261 Mdot
.87 .06286 Mdot
.87 .06287 Mdot
.87 .06338 Mdot
.87 .06404 Mdot
.87 .0642 Mdot
.87 .0648 Mdot
.87 .06481 Mdot
.87 .06493 Mdot
.87 .06497 Mdot
.87 .06518 Mdot
.87 .06608 Mdot
.87 .0663 Mdot
.87 .0672 Mdot
.87 .06721 Mdot
.87 .06792 Mdot
.87 .06799 Mdot
.87 .06851 Mdot
.87 .06876 Mdot
.87 .06891 Mdot
.87 .06973 Mdot
.87 .07015 Mdot
.87 .07078 Mdot
.87 .07083 Mdot
.87 .07153 Mdot
.87 .07214 Mdot
.87 .0728 Mdot
.87 .0733 Mdot
.87 .07337 Mdot
.87 .07357 Mdot
.87 .07389 Mdot
.87 .07436 Mdot
.87 .07489 Mdot
.87 .07494 Mdot
.87 .07534 Mdot
.87 .07604 Mdot
.87 .07631 Mdot
.87 .07718 Mdot
.87 .0773 Mdot
.87 .07924 Mdot
.87 .07928 Mdot
.87 .07947 Mdot
.87 .07967 Mdot
.87 .07999 Mdot
.87 .08077 Mdot
.87 .08089 Mdot
.87 .08131 Mdot
.87 .08166 Mdot
.87 .08183 Mdot
.87 .08222 Mdot
.87 .08245 Mdot
.87 .08261 Mdot
.87 .0829 Mdot
.87 .08338 Mdot
.87 .08474 Mdot
.87 .08518 Mdot
.87 .08613 Mdot
.87 .08649 Mdot
.87 .08687 Mdot
.87 .08699 Mdot
.87 .08745 Mdot
.87 .08758 Mdot
.87 .08796 Mdot
.87 .0883 Mdot
.87 .08851 Mdot
.87 .08858 Mdot
.87 .0888 Mdot
.87 .08904 Mdot
.87 .08953 Mdot
.87 .08972 Mdot
.87 .09052 Mdot
.87 .09072 Mdot
.87 .09157 Mdot
.87 .09171 Mdot
.87 .09177 Mdot
.87 .09205 Mdot
.87 .09321 Mdot
.87 .09378 Mdot
.87 .09449 Mdot
.87 .09464 Mdot
.87 .09519 Mdot
.87 .09564 Mdot
.87 .09574 Mdot
.87 .09634 Mdot
.87 .09636 Mdot
.87 .09664 Mdot
.87 .09683 Mdot
.87 .09766 Mdot
.87 .09798 Mdot
.87 .09805 Mdot
.87 .09848 Mdot
.87 .0985 Mdot
.87 .09856 Mdot
.87 .09939 Mdot
.87 .10054 Mdot
.87 .10082 Mdot
.87 .10154 Mdot
.87 .10163 Mdot
.87 .10186 Mdot
.87 .10187 Mdot
.87 .10209 Mdot
.87 .10217 Mdot
.87 .10253 Mdot
.87 .10259 Mdot
.87 .10285 Mdot
.87 .10339 Mdot
.87 .10359 Mdot
.87 .10409 Mdot
.87 .10448 Mdot
.87 .10496 Mdot
.87 .10499 Mdot
.87 .10553 Mdot
.87 .10573 Mdot
.87 .10604 Mdot
.87 .10605 Mdot
.87 .10658 Mdot
.87 .10679 Mdot
.87 .1073 Mdot
.87 .1074 Mdot
.87 .10832 Mdot
.87 .10876 Mdot
.87 .10901 Mdot
.87 .10905 Mdot
.87 .10957 Mdot
.87 .1102 Mdot
.87 .11044 Mdot
.87 .11064 Mdot
.87 .11117 Mdot
.87 .11195 Mdot
.87 .11227 Mdot
.87 .11235 Mdot
.87 .11318 Mdot
.87 .11357 Mdot
.87 .11386 Mdot
.87 .11407 Mdot
.87 .11416 Mdot
.87 .11463 Mdot
.87 .1154 Mdot
.87 .11577 Mdot
.87 .11665 Mdot
.87 .11677 Mdot
.87 .11713 Mdot
.87 .1173 Mdot
.87 .11763 Mdot
.87 .11769 Mdot
.87 .11784 Mdot
.87 .11849 Mdot
.87 .11878 Mdot
.87 .11899 Mdot
.87 .11942 Mdot
.87 .1195 Mdot
.87 .12021 Mdot
.87 .12108 Mdot
.87 .1211 Mdot
.87 .12143 Mdot
.87 .12188 Mdot
.87 .12259 Mdot
.87 .1234 Mdot
.87 .12361 Mdot
.87 .12527 Mdot
.87 .12648 Mdot
.87 .12658 Mdot
.87 .1268 Mdot
.87 .12699 Mdot
.87 .12706 Mdot
.87 .12738 Mdot
.87 .12774 Mdot
.87 .12797 Mdot
.87 .12829 Mdot
.87 .12911 Mdot
.87 .12925 Mdot
.87 .12962 Mdot
.87 .12965 Mdot
.87 .12986 Mdot
.87 .13059 Mdot
.87 .13084 Mdot
.87 .13107 Mdot
.87 .1312 Mdot
.87 .13149 Mdot
.87 .13185 Mdot
.87 .13217 Mdot
.87 .13257 Mdot
.87 .13285 Mdot
.87 .13336 Mdot
.87 .13365 Mdot
.87 .13412 Mdot
.87 .13419 Mdot
.87 .13446 Mdot
.87 .13504 Mdot
.87 .13511 Mdot
.87 .13656 Mdot
.87 .1367 Mdot
.87 .13733 Mdot
.87 .13791 Mdot
.87 .13898 Mdot
.87 .13961 Mdot
.87 .14026 Mdot
.87 .14048 Mdot
.87 .14049 Mdot
.87 .14127 Mdot
.87 .1415 Mdot
.87 .14212 Mdot
.87 .14217 Mdot
.87 .14275 Mdot
.87 .14287 Mdot
.87 .14312 Mdot
.87 .14325 Mdot
.87 .14337 Mdot
.87 .14363 Mdot
.87 .14403 Mdot
.87 .14489 Mdot
.87 .14522 Mdot
.87 .14616 Mdot
.87 .14662 Mdot
.87 .1468 Mdot
.87 .14697 Mdot
.87 .14845 Mdot
.87 .14868 Mdot
.87 .14878 Mdot
.87 .14925 Mdot
.87 .14928 Mdot
.87 .15039 Mdot
.87 .1513 Mdot
.87 .15228 Mdot
.87 .15252 Mdot
.87 .15352 Mdot
.87 .15374 Mdot
.87 .15379 Mdot
.87 .15474 Mdot
.87 .15487 Mdot
.87 .15553 Mdot
.87 .1557 Mdot
.87 .15591 Mdot
.87 .15641 Mdot
.87 .15675 Mdot
.87 .15678 Mdot
.87 .15727 Mdot
.87 .1576 Mdot
.87 .15817 Mdot
.87 .15904 Mdot
.87 .15959 Mdot
.87 .15971 Mdot
.87 .15991 Mdot
.87 .16047 Mdot
.87 .1605 Mdot
.87 .1606 Mdot
.87 .16072 Mdot
.87 .16094 Mdot
.87 .16161 Mdot
.87 .16204 Mdot
.87 .16233 Mdot
.87 .16274 Mdot
.87 .16279 Mdot
.87 .16377 Mdot
.87 .16405 Mdot
.87 .16454 Mdot
.87 .16579 Mdot
.87 .16594 Mdot
.87 .16634 Mdot
.87 .16637 Mdot
.87 .16676 Mdot
.87 .16688 Mdot
.87 .16692 Mdot
.87 .16751 Mdot
.87 .16761 Mdot
.87 .16806 Mdot
.87 .16814 Mdot
.87 .16901 Mdot
.87 .16936 Mdot
.87 .17023 Mdot
.87 .1709 Mdot
.87 .1714 Mdot
.87 .17166 Mdot
.87 .17174 Mdot
.87 .1718 Mdot
.87 .17274 Mdot
.87 .17307 Mdot
.87 .17362 Mdot
.87 .17364 Mdot
.87 .17455 Mdot
.87 .1747 Mdot
.87 .17493 Mdot
.87 .1752 Mdot
.87 .17533 Mdot
.87 .17581 Mdot
.87 .17589 Mdot
.87 .176 Mdot
.87 .17669 Mdot
.87 .17734 Mdot
.87 .17759 Mdot
.87 .17798 Mdot
.87 .17799 Mdot
.87 .17835 Mdot
.87 .1788 Mdot
.87 .17885 Mdot
.87 .17934 Mdot
.87 .17975 Mdot
.87 .18086 Mdot
.87 .18128 Mdot
.87 .18148 Mdot
.87 .18163 Mdot
.87 .18254 Mdot
.87 .18391 Mdot
.87 .18446 Mdot
.87 .18461 Mdot
.87 .18599 Mdot
.87 .18604 Mdot
.87 .18672 Mdot
.87 .18722 Mdot
.87 .18759 Mdot
.87 .18774 Mdot
.87 .18775 Mdot
.87 .18842 Mdot
.87 .18856 Mdot
.87 .1899 Mdot
.87 .19056 Mdot
.87 .19115 Mdot
.87 .19209 Mdot
.87 .19229 Mdot
.87 .1927 Mdot
.87 .19292 Mdot
.87 .19321 Mdot
.87 .19379 Mdot
.87 .19388 Mdot
.87 .19416 Mdot
.87 .19461 Mdot
.87 .19509 Mdot
.87 .19529 Mdot
.87 .19577 Mdot
.87 .19578 Mdot
.87 .19608 Mdot
.87 .19616 Mdot
.87 .1969 Mdot
.87 .19694 Mdot
.87 .19704 Mdot
.87 .19827 Mdot
.87 .19979 Mdot
.87 .19982 Mdot
.87 .20039 Mdot
.87 .20119 Mdot
.87 .20242 Mdot
.87 .2025 Mdot
.87 .20383 Mdot
.87 .20419 Mdot
.87 .20597 Mdot
.87 .2065 Mdot
.87 .20707 Mdot
.87 .20792 Mdot
.87 .20848 Mdot
.87 .20895 Mdot
.87 .20912 Mdot
.87 .20919 Mdot
.87 .20936 Mdot
.87 .20975 Mdot
.87 .21008 Mdot
.87 .21019 Mdot
.87 .21076 Mdot
.87 .21138 Mdot
.87 .21177 Mdot
.87 .21234 Mdot
.87 .21376 Mdot
.87 .214 Mdot
.87 .21445 Mdot
.87 .21464 Mdot
.87 .21471 Mdot
.87 .21499 Mdot
.87 .21506 Mdot
.87 .21618 Mdot
.87 .21633 Mdot
.87 .21676 Mdot
.87 .21717 Mdot
.87 .21739 Mdot
.87 .2179 Mdot
.87 .21853 Mdot
.87 .21909 Mdot
.87 .21978 Mdot
.87 .21978 Mdot
.87 .22028 Mdot
.87 .22116 Mdot
.87 .22156 Mdot
.87 .22167 Mdot
.87 .22243 Mdot
.87 .22248 Mdot
.87 .2226 Mdot
.87 .22308 Mdot
.87 .22408 Mdot
.87 .2242 Mdot
.87 .22494 Mdot
.87 .22619 Mdot
.87 .22673 Mdot
.87 .22697 Mdot
.87 .22806 Mdot
.87 .22828 Mdot
.87 .22908 Mdot
.87 .23057 Mdot
.87 .23094 Mdot
.87 .23145 Mdot
.87 .23203 Mdot
.87 .2326 Mdot
.87 .23287 Mdot
.87 .23317 Mdot
.87 .23354 Mdot
.87 .23356 Mdot
.87 .23388 Mdot
.87 .23492 Mdot
.87 .23532 Mdot
.87 .2364 Mdot
.87 .23648 Mdot
.87 .23749 Mdot
.87 .23765 Mdot
.87 .2377 Mdot
.87 .23788 Mdot
.87 .23815 Mdot
.87 .23836 Mdot
.87 .23857 Mdot
.87 .23857 Mdot
.87 .23902 Mdot
.87 .23973 Mdot
.87 .24122 Mdot
.87 .2418 Mdot
.87 .24202 Mdot
.87 .24292 Mdot
.87 .24343 Mdot
.87 .24407 Mdot
.87 .24422 Mdot
.87 .24445 Mdot
.87 .24455 Mdot
.87 .24483 Mdot
.87 .24667 Mdot
.87 .24782 Mdot
.87 .24799 Mdot
.87 .24846 Mdot
.87 .24865 Mdot
.87 .2488 Mdot
.87 .24886 Mdot
.87 .25062 Mdot
.87 .2508 Mdot
.87 .25119 Mdot
.87 .25238 Mdot
.87 .25297 Mdot
.87 .25325 Mdot
.87 .25408 Mdot
.87 .2545 Mdot
.87 .25518 Mdot
.87 .25594 Mdot
.87 .25623 Mdot
.87 .25661 Mdot
.87 .2567 Mdot
.87 .25704 Mdot
.87 .25828 Mdot
.87 .25836 Mdot
.87 .25859 Mdot
.87 .25972 Mdot
.87 .26002 Mdot
.87 .2604 Mdot
.87 .26053 Mdot
.87 .26126 Mdot
.87 .26185 Mdot
.87 .26191 Mdot
.87 .26256 Mdot
.87 .26275 Mdot
.87 .26334 Mdot
.87 .26343 Mdot
.87 .26407 Mdot
.87 .26432 Mdot
.87 .26468 Mdot
.87 .2651 Mdot
.87 .26584 Mdot
.87 .26651 Mdot
.87 .2668 Mdot
.87 .26701 Mdot
.87 .26721 Mdot
.87 .26735 Mdot
.87 .26781 Mdot
.87 .26804 Mdot
.87 .26824 Mdot
.87 .26832 Mdot
.87 .26839 Mdot
.87 .26855 Mdot
.87 .26874 Mdot
.87 .26876 Mdot
.87 .26915 Mdot
.87 .26932 Mdot
.87 .26938 Mdot
.87 .27032 Mdot
.87 .27057 Mdot
.87 .27107 Mdot
.87 .27107 Mdot
.87 .27124 Mdot
.87 .27156 Mdot
.87 .27228 Mdot
.87 .27237 Mdot
.87 .27407 Mdot
.87 .2741 Mdot
.87 .27456 Mdot
.87 .27485 Mdot
.87 .27541 Mdot
.87 .27637 Mdot
.87 .27637 Mdot
.87 .27689 Mdot
.87 .27759 Mdot
.87 .27785 Mdot
.87 .27786 Mdot
.87 .27854 Mdot
.87 .27859 Mdot
.87 .27927 Mdot
.87 .27948 Mdot
.87 .27956 Mdot
.87 .28005 Mdot
.87 .28031 Mdot
.87 .28058 Mdot
.87 .28076 Mdot
.87 .28154 Mdot
.87 .28167 Mdot
.87 .28318 Mdot
.87 .28381 Mdot
.87 .28531 Mdot
.87 .28546 Mdot
.87 .28553 Mdot
.87 .28648 Mdot
.87 .28694 Mdot
.87 .28735 Mdot
.87 .28779 Mdot
.87 .28781 Mdot
.87 .28794 Mdot
.87 .28803 Mdot
.87 .28951 Mdot
.87 .28967 Mdot
.87 .29026 Mdot
.87 .29121 Mdot
.87 .29125 Mdot
.87 .29241 Mdot
.87 .29242 Mdot
.87 .29283 Mdot
.87 .29309 Mdot
.87 .29348 Mdot
.87 .29395 Mdot
.87 .294 Mdot
.87 .29419 Mdot
.87 .29502 Mdot
.87 .29517 Mdot
.87 .29534 Mdot
.87 .29612 Mdot
.87 .29655 Mdot
.87 .2969 Mdot
.87 .29693 Mdot
.87 .29769 Mdot
.87 .29811 Mdot
.87 .29879 Mdot
.87 .29881 Mdot
.87 .29899 Mdot
.87 .29914 Mdot
.87 .29945 Mdot
.87 .30022 Mdot
.87 .30031 Mdot
.87 .30117 Mdot
.87 .30119 Mdot
.87 .30184 Mdot
.87 .30188 Mdot
.87 .30206 Mdot
.87 .30354 Mdot
.87 .30381 Mdot
.87 .30435 Mdot
.87 .30454 Mdot
.87 .30489 Mdot
.87 .30515 Mdot
.87 .30516 Mdot
.87 .30569 Mdot
.87 .30673 Mdot
.87 .30806 Mdot
.87 .30847 Mdot
.87 .30911 Mdot
.87 .31007 Mdot
.87 .31033 Mdot
.87 .31274 Mdot
.87 .31281 Mdot
.87 .31304 Mdot
.87 .314 Mdot
.87 .31487 Mdot
.87 .31493 Mdot
.87 .31552 Mdot
.87 .31578 Mdot
.87 .31579 Mdot
.87 .31696 Mdot
.87 .31721 Mdot
.87 .31949 Mdot
.87 .31953 Mdot
.87 .31993 Mdot
.87 .32015 Mdot
.87 .32068 Mdot
.87 .32172 Mdot
.87 .32304 Mdot
.87 .32334 Mdot
.87 .32369 Mdot
.87 .3244 Mdot
.87 .32442 Mdot
.87 .32479 Mdot
.87 .3253 Mdot
.87 .32567 Mdot
.87 .3263 Mdot
.87 .32647 Mdot
.87 .32694 Mdot
.87 .327 Mdot
.87 .32707 Mdot
.87 .32744 Mdot
.87 .32773 Mdot
.87 .32773 Mdot
.87 .32857 Mdot
.87 .32891 Mdot
.87 .32975 Mdot
.87 .32977 Mdot
.87 .33029 Mdot
.87 .33042 Mdot
.87 .33171 Mdot
.87 .33178 Mdot
.87 .33196 Mdot
.87 .33221 Mdot
.87 .33269 Mdot
.87 .3341 Mdot
.87 .33446 Mdot
.87 .33674 Mdot
.87 .3368 Mdot
.87 .33736 Mdot
.87 .33746 Mdot
.87 .33779 Mdot
.87 .33918 Mdot
.87 .34098 Mdot
.87 .34101 Mdot
.87 .34131 Mdot
.87 .34146 Mdot
.87 .34225 Mdot
.87 .34305 Mdot
.87 .34378 Mdot
.87 .34422 Mdot
.87 .34441 Mdot
.87 .34564 Mdot
.87 .34579 Mdot
.87 .34636 Mdot
.87 .3475 Mdot
.87 .34843 Mdot
.87 .34887 Mdot
.87 .34932 Mdot
.87 .34942 Mdot
.87 .34986 Mdot
.87 .35089 Mdot
.87 .35186 Mdot
.87 .3522 Mdot
.87 .35268 Mdot
.87 .35298 Mdot
.87 .35311 Mdot
.87 .35339 Mdot
.87 .3535 Mdot
.87 .35408 Mdot
.87 .35457 Mdot
.87 .35464 Mdot
.87 .35468 Mdot
.87 .35484 Mdot
.87 .35583 Mdot
.87 .3569 Mdot
.87 .35696 Mdot
.87 .35759 Mdot
.87 .35825 Mdot
.87 .35858 Mdot
.87 .3603 Mdot
.87 .36035 Mdot
.87 .3609 Mdot
.87 .36105 Mdot
.87 .36136 Mdot
.87 .36148 Mdot
.87 .36226 Mdot
.87 .36228 Mdot
.87 .36259 Mdot
.87 .3627 Mdot
.87 .36319 Mdot
.87 .36331 Mdot
.87 .36461 Mdot
.87 .36491 Mdot
.87 .36527 Mdot
.87 .36553 Mdot
.87 .36628 Mdot
.87 .36698 Mdot
.87 .36737 Mdot
.87 .3675 Mdot
.87 .36755 Mdot
.87 .36826 Mdot
.87 .36935 Mdot
.87 .36954 Mdot
.87 .36966 Mdot
.87 .3702 Mdot
.87 .37032 Mdot
.87 .37153 Mdot
.87 .37153 Mdot
.87 .37239 Mdot
.87 .37393 Mdot
.87 .37463 Mdot
.87 .37469 Mdot
.87 .37482 Mdot
.87 .37548 Mdot
.87 .37614 Mdot
.87 .37622 Mdot
.87 .37643 Mdot
.87 .37713 Mdot
.87 .37727 Mdot
.87 .37771 Mdot
.87 .37875 Mdot
.87 .37902 Mdot
.87 .37922 Mdot
.87 .37955 Mdot
.87 .37959 Mdot
.87 .3805 Mdot
.87 .3812 Mdot
.87 .38268 Mdot
.87 .38362 Mdot
.87 .38405 Mdot
.87 .38433 Mdot
.87 .38594 Mdot
.87 .38631 Mdot
.87 .38771 Mdot
.87 .38837 Mdot
.87 .38959 Mdot
.87 .39029 Mdot
.87 .39095 Mdot
.87 .39154 Mdot
.87 .39183 Mdot
.87 .39284 Mdot
.87 .39384 Mdot
.87 .39431 Mdot
.87 .39444 Mdot
.87 .39482 Mdot
.87 .39523 Mdot
.87 .39547 Mdot
.87 .3955 Mdot
.87 .39606 Mdot
.87 .39787 Mdot
.87 .39857 Mdot
.87 .40045 Mdot
.87 .40059 Mdot
.87 .40234 Mdot
.87 .40263 Mdot
.87 .4027 Mdot
.87 .40303 Mdot
.87 .40348 Mdot
.87 .40386 Mdot
.87 .40422 Mdot
.87 .40423 Mdot
.87 .40501 Mdot
.87 .40624 Mdot
.87 .40883 Mdot
.87 .40984 Mdot
.87 .41023 Mdot
.87 .4118 Mdot
.87 .41268 Mdot
.87 .41378 Mdot
.87 .41406 Mdot
.87 .41445 Mdot
.87 .41463 Mdot
.87 .41512 Mdot
.87 .41832 Mdot
.87 .42031 Mdot
.87 .42062 Mdot
.87 .42143 Mdot
.87 .42175 Mdot
.87 .42203 Mdot
.87 .42212 Mdot
.87 .42519 Mdot
.87 .4255 Mdot
.87 .42618 Mdot
.87 .42825 Mdot
.87 .42927 Mdot
.87 .42977 Mdot
.87 .43121 Mdot
.87 .43193 Mdot
.87 .43313 Mdot
.87 .43445 Mdot
.87 .43495 Mdot
.87 .43562 Mdot
.87 .43577 Mdot
.87 .43635 Mdot
.87 .43852 Mdot
.87 .43865 Mdot
.87 .43905 Mdot
.87 .44103 Mdot
.87 .44155 Mdot
.87 .44221 Mdot
.87 .44243 Mdot
.87 .4437 Mdot
.87 .44473 Mdot
.87 .44484 Mdot
.87 .44597 Mdot
.87 .4463 Mdot
.87 .44732 Mdot
.87 .44749 Mdot
.87 .4486 Mdot
.87 .44903 Mdot
.87 .44966 Mdot
.87 .45038 Mdot
.87 .45167 Mdot
.87 .45284 Mdot
.87 .45334 Mdot
.87 .4537 Mdot
.87 .45406 Mdot
.87 .45429 Mdot
.87 .45511 Mdot
.87 .45551 Mdot
.87 .45585 Mdot
.87 .45599 Mdot
.87 .4561 Mdot
.87 .45639 Mdot
.87 .45672 Mdot
.87 .45675 Mdot
.87 .45744 Mdot
.87 .45773 Mdot
.87 .45783 Mdot
.87 .45947 Mdot
.87 .4599 Mdot
.87 .46077 Mdot
.87 .46077 Mdot
.87 .46107 Mdot
.87 .46163 Mdot
.87 .46288 Mdot
.87 .46304 Mdot
.87 .466 Mdot
.87 .46604 Mdot
.87 .46685 Mdot
.87 .46735 Mdot
.87 .46833 Mdot
.87 .46999 Mdot
.87 .47 Mdot
.87 .4709 Mdot
.87 .47212 Mdot
.87 .47257 Mdot
.87 .47259 Mdot
.87 .47377 Mdot
.87 .47386 Mdot
.87 .47503 Mdot
.87 .47541 Mdot
.87 .47554 Mdot
.87 .47639 Mdot
.87 .47685 Mdot
.87 .47732 Mdot
.87 .47763 Mdot
.87 .47899 Mdot
.87 .47922 Mdot
.87 .48184 Mdot
.87 .48293 Mdot
.87 .48555 Mdot
.87 .48581 Mdot
.87 .48593 Mdot
.87 .48759 Mdot
.87 .48839 Mdot
.87 .48911 Mdot
.87 .48987 Mdot
.87 .48991 Mdot
.87 .49012 Mdot
.87 .49029 Mdot
.87 .49287 Mdot
.87 .49314 Mdot
.87 .49416 Mdot
.87 .49582 Mdot
.87 .49588 Mdot
.87 .4979 Mdot
.87 .49792 Mdot
.87 .49864 Mdot
.87 .49909 Mdot
.87 .49977 Mdot
.87 .50058 Mdot
.87 .50067 Mdot
.87 .501 Mdot
.87 .50244 Mdot
.87 .5027 Mdot
.87 .50301 Mdot
.87 .50435 Mdot
.87 .5051 Mdot
.87 .50571 Mdot
.87 .50578 Mdot
.87 .50709 Mdot
.87 .50783 Mdot
.87 .50901 Mdot
.87 .50903 Mdot
.87 .50935 Mdot
.87 .50962 Mdot
.87 .51015 Mdot
.87 .51149 Mdot
.87 .51166 Mdot
.87 .51314 Mdot
.87 .51317 Mdot
.87 .51432 Mdot
.87 .51439 Mdot
.87 .5147 Mdot
.87 .51728 Mdot
.87 .51773 Mdot
.87 .51868 Mdot
.87 .51902 Mdot
.87 .51961 Mdot
.87 .52007 Mdot
.87 .52009 Mdot
.87 .52102 Mdot
.87 .52282 Mdot
.87 .52514 Mdot
.87 .52584 Mdot
.87 .52696 Mdot
.87 .52863 Mdot
.87 .52908 Mdot
.872 .01482 Mdot
.872 .0149 Mdot
.872 .01503 Mdot
.872 .01526 Mdot
.872 .01567 Mdot
.872 .01599 Mdot
.872 .01639 Mdot
.872 .01695 Mdot
.872 .01732 Mdot
.872 .01763 Mdot
.872 .01861 Mdot
.872 .01926 Mdot
.872 .01936 Mdot
.872 .01966 Mdot
.872 .0198 Mdot
.872 .02037 Mdot
.872 .0215 Mdot
.872 .02174 Mdot
.872 .02213 Mdot
.872 .02223 Mdot
.872 .02265 Mdot
.872 .02282 Mdot
.872 .02334 Mdot
.872 .02358 Mdot
.872 .02458 Mdot
.872 .02569 Mdot
.872 .02655 Mdot
.872 .02697 Mdot
.872 .02711 Mdot
.872 .02764 Mdot
.872 .02783 Mdot
.872 .02855 Mdot
.872 .02886 Mdot
.872 .02912 Mdot
.872 .02936 Mdot
.872 .02975 Mdot
.872 .02977 Mdot
.872 .03018 Mdot
.872 .03192 Mdot
.872 .03214 Mdot
.872 .03216 Mdot
.872 .03254 Mdot
.872 .03292 Mdot
.872 .03369 Mdot
.872 .03385 Mdot
.872 .03469 Mdot
.872 .03484 Mdot
.872 .03508 Mdot
.872 .03535 Mdot
.872 .03609 Mdot
.872 .03633 Mdot
.872 .03715 Mdot
.872 .03726 Mdot
.872 .03741 Mdot
.872 .03758 Mdot
.872 .03884 Mdot
.872 .03913 Mdot
.872 .03938 Mdot
.872 .03984 Mdot
.872 .04025 Mdot
.872 .04094 Mdot
.872 .04096 Mdot
.872 .04099 Mdot
.872 .04145 Mdot
.872 .04169 Mdot
.872 .0419 Mdot
.872 .04365 Mdot
.872 .04472 Mdot
.872 .04511 Mdot
.872 .04513 Mdot
.872 .0458 Mdot
.872 .04646 Mdot
.872 .04776 Mdot
.872 .04781 Mdot
.872 .04808 Mdot
.872 .04955 Mdot
.872 .04981 Mdot
.872 .05023 Mdot
.872 .0507 Mdot
.872 .05079 Mdot
.872 .05124 Mdot
.872 .05197 Mdot
.872 .052 Mdot
.872 .05241 Mdot
.872 .05385 Mdot
.872 .05403 Mdot
.872 .0543 Mdot
.872 .0546 Mdot
.872 .0559 Mdot
.872 .05668 Mdot
.872 .05679 Mdot
.872 .05719 Mdot
.872 .0573 Mdot
.872 .05773 Mdot
.872 .05854 Mdot
.872 .05924 Mdot
.872 .05991 Mdot
.872 .05992 Mdot
.872 .06024 Mdot
.872 .06046 Mdot
.872 .06049 Mdot
.872 .06054 Mdot
.872 .06105 Mdot
.872 .06134 Mdot
.872 .06154 Mdot
.872 .06175 Mdot
.872 .06212 Mdot
.872 .06268 Mdot
.872 .06336 Mdot
.872 .06347 Mdot
.872 .06518 Mdot
.872 .06527 Mdot
.872 .06568 Mdot
.872 .06704 Mdot
.872 .06752 Mdot
.872 .06772 Mdot
.872 .06776 Mdot
.872 .06893 Mdot
.872 .06894 Mdot
.872 .07008 Mdot
.872 .07201 Mdot
.872 .07208 Mdot
.872 .07234 Mdot
.872 .07242 Mdot
.872 .07291 Mdot
.872 .07505 Mdot
.872 .07534 Mdot
.872 .07547 Mdot
.872 .07592 Mdot
.872 .07597 Mdot
.872 .07665 Mdot
.872 .07748 Mdot
.872 .07763 Mdot
.872 .07841 Mdot
.872 .07878 Mdot
.872 .07966 Mdot
.872 .07968 Mdot
.872 .07974 Mdot
.872 .07977 Mdot
.872 .07987 Mdot
.872 .08012 Mdot
.872 .08045 Mdot
.872 .08099 Mdot
.872 .08111 Mdot
.872 .08285 Mdot
.872 .08296 Mdot
.872 .08328 Mdot
.872 .08374 Mdot
.872 .08427 Mdot
.872 .08454 Mdot
.872 .08493 Mdot
.872 .0855 Mdot
.872 .0856 Mdot
.872 .08594 Mdot
.872 .08654 Mdot
.872 .08755 Mdot
.872 .08761 Mdot
.872 .08791 Mdot
.872 .08809 Mdot
.872 .08827 Mdot
.872 .08879 Mdot
.872 .08899 Mdot
.872 .08973 Mdot
.872 .09045 Mdot
.872 .09052 Mdot
.872 .09071 Mdot
.872 .0911 Mdot
.872 .09114 Mdot
.872 .09137 Mdot
.872 .09175 Mdot
.872 .092 Mdot
.872 .09237 Mdot
.872 .09238 Mdot
.872 .09308 Mdot
.872 .09314 Mdot
.872 .09329 Mdot
.872 .09331 Mdot
.872 .09354 Mdot
.872 .09356 Mdot
.872 .09411 Mdot
.872 .09449 Mdot
.872 .09455 Mdot
.872 .09464 Mdot
.872 .09551 Mdot
.872 .09604 Mdot
.872 .09638 Mdot
.872 .09675 Mdot
.872 .0972 Mdot
.872 .09739 Mdot
.872 .09818 Mdot
.872 .09825 Mdot
.872 .09836 Mdot
.872 .09884 Mdot
.872 .09952 Mdot
.872 .09955 Mdot
.872 .09975 Mdot
.872 .09983 Mdot
.872 .09997 Mdot
.872 .10003 Mdot
.872 .10015 Mdot
.872 .1006 Mdot
.872 .10078 Mdot
.872 .10089 Mdot
.872 .1012 Mdot
.872 .10181 Mdot
.872 .10258 Mdot
.872 .10273 Mdot
.872 .10289 Mdot
.872 .1036 Mdot
.872 .1041 Mdot
.872 .10524 Mdot
.872 .10598 Mdot
.872 .10681 Mdot
.872 .10715 Mdot
.872 .10717 Mdot
.872 .10723 Mdot
.872 .10728 Mdot
.872 .10831 Mdot
.872 .10837 Mdot
.872 .10843 Mdot
.872 .10927 Mdot
.872 .10928 Mdot
.872 .10976 Mdot
.872 .11041 Mdot
.872 .11075 Mdot
.872 .11127 Mdot
.872 .11174 Mdot
.872 .11217 Mdot
.872 .11281 Mdot
.872 .11325 Mdot
.872 .11333 Mdot
.872 .11465 Mdot
.872 .11477 Mdot
.872 .11521 Mdot
.872 .11536 Mdot
.872 .11572 Mdot
.872 .11577 Mdot
.872 .11621 Mdot
.872 .11653 Mdot
.872 .11969 Mdot
.872 .11994 Mdot
.872 .12045 Mdot
.872 .12045 Mdot
.872 .12066 Mdot
.872 .1211 Mdot
.872 .12146 Mdot
.872 .12154 Mdot
.872 .12273 Mdot
.872 .12336 Mdot
.872 .12417 Mdot
.872 .12421 Mdot
.872 .12426 Mdot
.872 .12445 Mdot
.872 .12529 Mdot
.872 .12536 Mdot
.872 .1258 Mdot
.872 .12645 Mdot
.872 .12748 Mdot
.872 .12798 Mdot
.872 .12801 Mdot
.872 .12812 Mdot
.872 .12815 Mdot
.872 .12818 Mdot
.872 .12835 Mdot
.872 .12878 Mdot
.872 .12936 Mdot
.872 .12938 Mdot
.872 .1303 Mdot
.872 .13042 Mdot
.872 .13051 Mdot
.872 .13052 Mdot
.872 .13186 Mdot
.872 .13241 Mdot
.872 .13319 Mdot
.872 .13332 Mdot
.872 .13355 Mdot
.872 .13374 Mdot
.872 .13429 Mdot
.872 .1351 Mdot
.872 .13568 Mdot
.872 .13602 Mdot
.872 .13649 Mdot
.872 .13717 Mdot
.872 .1374 Mdot
.872 .13764 Mdot
.872 .13817 Mdot
.872 .13823 Mdot
.872 .13834 Mdot
.872 .13865 Mdot
.872 .13894 Mdot
.872 .13998 Mdot
.872 .1407 Mdot
.872 .14135 Mdot
.872 .14174 Mdot
.872 .14184 Mdot
.872 .14215 Mdot
.872 .14236 Mdot
.872 .14249 Mdot
.872 .14267 Mdot
.872 .143 Mdot
.872 .14364 Mdot
.872 .1439 Mdot
.872 .14424 Mdot
.872 .145 Mdot
.872 .14555 Mdot
.872 .14679 Mdot
.872 .14691 Mdot
.872 .14725 Mdot
.872 .14792 Mdot
.872 .148 Mdot
.872 .14841 Mdot
.872 .14859 Mdot
.872 .1486 Mdot
.872 .14907 Mdot
.872 .14907 Mdot
.872 .14911 Mdot
.872 .14934 Mdot
.872 .1495 Mdot
.872 .14982 Mdot
.872 .15015 Mdot
.872 .15016 Mdot
.872 .15107 Mdot
.872 .15139 Mdot
.872 .1515 Mdot
.872 .15174 Mdot
.872 .15179 Mdot
.872 .15219 Mdot
.872 .15222 Mdot
.872 .15319 Mdot
.872 .15384 Mdot
.872 .15388 Mdot
.872 .15394 Mdot
.872 .15411 Mdot
.872 .1542 Mdot
.872 .15481 Mdot
.872 .15563 Mdot
.872 .15565 Mdot
.872 .15648 Mdot
.872 .15654 Mdot
.872 .15714 Mdot
.872 .15743 Mdot
.872 .15778 Mdot
.872 .15797 Mdot
.872 .15857 Mdot
.872 .15891 Mdot
.872 .15916 Mdot
.872 .16029 Mdot
.872 .1604 Mdot
.872 .1606 Mdot
.872 .16142 Mdot
.872 .16144 Mdot
.872 .16261 Mdot
.872 .16266 Mdot
.872 .16302 Mdot
.872 .16315 Mdot
.872 .16339 Mdot
.872 .1635 Mdot
.872 .16352 Mdot
.872 .16371 Mdot
.872 .1645 Mdot
.872 .1647 Mdot
.872 .16481 Mdot
.872 .16501 Mdot
.872 .16501 Mdot
.872 .16555 Mdot
.872 .16661 Mdot
.872 .16735 Mdot
.872 .16795 Mdot
.872 .16821 Mdot
.872 .16848 Mdot
.872 .16972 Mdot
.872 .17061 Mdot
.872 .1708 Mdot
.872 .1717 Mdot
.872 .17259 Mdot
.872 .17286 Mdot
.872 .17338 Mdot
.872 .17387 Mdot
.872 .17504 Mdot
.872 .17526 Mdot
.872 .17532 Mdot
.872 .17587 Mdot
.872 .17593 Mdot
.872 .17596 Mdot
.872 .17607 Mdot
.872 .17614 Mdot
.872 .17615 Mdot
.872 .17684 Mdot
.872 .17691 Mdot
.872 .1778 Mdot
.872 .17795 Mdot
.872 .17805 Mdot
.872 .17816 Mdot
.872 .17951 Mdot
.872 .17951 Mdot
.872 .17962 Mdot
.872 .17963 Mdot
.872 .18039 Mdot
.872 .18048 Mdot
.872 .18107 Mdot
.872 .18161 Mdot
.872 .18219 Mdot
.872 .18291 Mdot
.872 .1831 Mdot
.872 .18392 Mdot
.872 .18429 Mdot
.872 .18468 Mdot
.872 .18579 Mdot
.872 .18612 Mdot
.872 .18657 Mdot
.872 .18669 Mdot
.872 .18899 Mdot
.872 .18921 Mdot
.872 .18999 Mdot
.872 .18999 Mdot
.872 .19012 Mdot
.872 .19024 Mdot
.872 .19082 Mdot
.872 .19087 Mdot
.872 .19095 Mdot
.872 .19172 Mdot
.872 .19229 Mdot
.872 .19305 Mdot
.872 .1978 Mdot
.872 .19822 Mdot
.872 .19912 Mdot
.872 .19912 Mdot
.872 .19949 Mdot
.872 .19965 Mdot
.872 .20025 Mdot
.872 .20029 Mdot
.872 .20088 Mdot
.872 .20101 Mdot
.872 .20208 Mdot
.872 .2031 Mdot
.872 .20409 Mdot
.872 .20419 Mdot
.872 .2044 Mdot
.872 .20561 Mdot
.872 .20565 Mdot
.872 .20568 Mdot
.872 .20576 Mdot
.872 .20605 Mdot
.872 .20609 Mdot
.872 .20756 Mdot
.872 .20768 Mdot
.872 .2082 Mdot
.872 .20844 Mdot
.872 .20916 Mdot
.872 .20924 Mdot
.872 .20959 Mdot
.872 .20967 Mdot
.872 .21138 Mdot
.872 .2117 Mdot
.872 .21172 Mdot
.872 .21191 Mdot
.872 .21224 Mdot
.872 .21231 Mdot
.872 .21249 Mdot
.872 .21255 Mdot
.872 .21259 Mdot
.872 .21289 Mdot
.872 .21315 Mdot
.872 .21365 Mdot
.872 .21402 Mdot
.872 .21465 Mdot
.872 .21469 Mdot
.872 .21505 Mdot
.872 .21572 Mdot
.872 .2163 Mdot
.872 .21651 Mdot
.872 .21665 Mdot
.872 .21668 Mdot
.872 .21747 Mdot
.872 .21748 Mdot
.872 .21773 Mdot
.872 .21877 Mdot
.872 .21902 Mdot
.872 .21923 Mdot
.872 .21998 Mdot
.872 .22133 Mdot
.872 .22155 Mdot
.872 .22196 Mdot
.872 .2223 Mdot
.872 .22233 Mdot
.872 .22325 Mdot
.872 .22403 Mdot
.872 .22459 Mdot
.872 .22467 Mdot
.872 .22568 Mdot
.872 .22589 Mdot
.872 .22616 Mdot
.872 .22627 Mdot
.872 .22709 Mdot
.872 .22827 Mdot
.872 .22828 Mdot
.872 .22844 Mdot
.872 .22852 Mdot
.872 .22868 Mdot
.872 .22909 Mdot
.872 .23001 Mdot
.872 .23012 Mdot
.872 .23032 Mdot
.872 .23087 Mdot
.872 .23136 Mdot
.872 .23318 Mdot
.872 .23357 Mdot
.872 .23444 Mdot
.872 .23557 Mdot
.872 .23587 Mdot
.872 .23625 Mdot
.872 .23642 Mdot
.872 .23697 Mdot
.872 .23704 Mdot
.872 .23724 Mdot
.872 .23733 Mdot
.872 .23756 Mdot
.872 .23758 Mdot
.872 .23788 Mdot
.872 .23844 Mdot
.872 .23844 Mdot
.872 .23873 Mdot
.872 .23895 Mdot
.872 .23956 Mdot
.872 .24001 Mdot
.872 .24061 Mdot
.872 .24188 Mdot
.872 .24193 Mdot
.872 .24216 Mdot
.872 .24289 Mdot
.872 .24506 Mdot
.872 .24527 Mdot
.872 .24586 Mdot
.872 .24652 Mdot
.872 .24662 Mdot
.872 .24703 Mdot
.872 .24716 Mdot
.872 .24787 Mdot
.872 .24819 Mdot
.872 .24821 Mdot
.872 .24835 Mdot
.872 .24902 Mdot
.872 .24903 Mdot
.872 .24909 Mdot
.872 .2495 Mdot
.872 .24978 Mdot
.872 .25012 Mdot
.872 .25034 Mdot
.872 .25092 Mdot
.872 .25092 Mdot
.872 .25101 Mdot
.872 .25135 Mdot
.872 .2515 Mdot
.872 .25252 Mdot
.872 .25308 Mdot
.872 .25326 Mdot
.872 .25369 Mdot
.872 .25377 Mdot
.872 .25447 Mdot
.872 .25453 Mdot
.872 .25455 Mdot
.872 .25609 Mdot
.872 .25621 Mdot
.872 .25697 Mdot
.872 .25735 Mdot
.872 .25742 Mdot
.872 .25753 Mdot
.872 .25781 Mdot
.872 .25791 Mdot
.872 .25798 Mdot
.872 .25895 Mdot
.872 .25904 Mdot
.872 .26047 Mdot
.872 .2605 Mdot
.872 .26107 Mdot
.872 .26194 Mdot
.872 .26206 Mdot
.872 .26211 Mdot
.872 .26311 Mdot
.872 .26362 Mdot
.872 .26391 Mdot
.872 .26421 Mdot
.872 .26456 Mdot
.872 .26525 Mdot
.872 .26559 Mdot
.872 .26619 Mdot
.872 .26663 Mdot
.872 .26859 Mdot
.872 .26879 Mdot
.872 .26913 Mdot
.872 .27057 Mdot
.872 .2706 Mdot
.872 .27122 Mdot
.872 .27182 Mdot
.872 .27264 Mdot
.872 .27273 Mdot
.872 .27287 Mdot
.872 .27335 Mdot
.872 .27359 Mdot
.872 .27401 Mdot
.872 .2742 Mdot
.872 .27423 Mdot
.872 .27456 Mdot
.872 .27593 Mdot
.872 .27629 Mdot
.872 .27648 Mdot
.872 .27683 Mdot
.872 .27683 Mdot
.872 .27725 Mdot
.872 .27732 Mdot
.872 .27776 Mdot
.872 .27922 Mdot
.872 .27962 Mdot
.872 .28091 Mdot
.872 .28106 Mdot
.872 .28196 Mdot
.872 .2824 Mdot
.872 .28289 Mdot
.872 .28354 Mdot
.872 .28381 Mdot
.872 .28423 Mdot
.872 .28505 Mdot
.872 .2857 Mdot
.872 .28643 Mdot
.872 .2866 Mdot
.872 .28693 Mdot
.872 .2877 Mdot
.872 .28827 Mdot
.872 .28836 Mdot
.872 .28849 Mdot
.872 .28938 Mdot
.872 .29005 Mdot
.872 .29051 Mdot
.872 .29143 Mdot
.872 .29229 Mdot
.872 .29355 Mdot
.872 .29432 Mdot
.872 .29463 Mdot
.872 .29471 Mdot
.872 .29482 Mdot
.872 .29521 Mdot
.872 .29576 Mdot
.872 .29587 Mdot
.872 .29592 Mdot
.872 .29611 Mdot
.872 .29625 Mdot
.872 .29626 Mdot
.872 .29628 Mdot
.872 .29629 Mdot
.872 .29746 Mdot
.872 .29754 Mdot
.872 .29758 Mdot
.872 .29778 Mdot
.872 .29912 Mdot
.872 .29914 Mdot
.872 .29939 Mdot
.872 .29958 Mdot
.872 .29976 Mdot
.872 .30211 Mdot
.872 .30212 Mdot
.872 .30232 Mdot
.872 .30233 Mdot
.872 .30356 Mdot
.872 .30366 Mdot
.872 .30381 Mdot
.872 .30476 Mdot
.872 .30484 Mdot
.872 .30578 Mdot
.872 .3068 Mdot
.872 .30804 Mdot
.872 .30838 Mdot
.872 .3087 Mdot
.872 .30913 Mdot
.872 .30981 Mdot
.872 .31046 Mdot
.872 .31113 Mdot
.872 .31189 Mdot
.872 .31306 Mdot
.872 .31323 Mdot
.872 .31364 Mdot
.872 .31443 Mdot
.872 .31465 Mdot
.872 .31471 Mdot
.872 .31669 Mdot
.872 .3175 Mdot
.872 .31866 Mdot
.872 .31879 Mdot
.872 .31903 Mdot
.872 .32039 Mdot
.872 .3204 Mdot
.872 .32062 Mdot
.872 .32083 Mdot
.872 .32128 Mdot
.872 .32185 Mdot
.872 .32194 Mdot
.872 .32207 Mdot
.872 .32326 Mdot
.872 .32341 Mdot
.872 .3244 Mdot
.872 .32546 Mdot
.872 .32573 Mdot
.872 .32598 Mdot
.872 .32699 Mdot
.872 .32934 Mdot
.872 .33108 Mdot
.872 .33134 Mdot
.872 .33176 Mdot
.872 .33401 Mdot
.872 .33446 Mdot
.872 .33475 Mdot
.872 .33631 Mdot
.872 .33632 Mdot
.872 .3365 Mdot
.872 .33696 Mdot
.872 .33725 Mdot
.872 .3379 Mdot
.872 .33829 Mdot
.872 .33835 Mdot
.872 .33938 Mdot
.872 .33962 Mdot
.872 .34067 Mdot
.872 .34149 Mdot
.872 .34325 Mdot
.872 .34329 Mdot
.872 .34499 Mdot
.872 .34516 Mdot
.872 .34552 Mdot
.872 .34713 Mdot
.872 .34763 Mdot
.872 .3477 Mdot
.872 .34776 Mdot
.872 .3479 Mdot
.872 .3484 Mdot
.872 .34847 Mdot
.872 .34947 Mdot
.872 .35043 Mdot
.872 .35066 Mdot
.872 .35098 Mdot
.872 .35104 Mdot
.872 .35124 Mdot
.872 .35216 Mdot
.872 .35219 Mdot
.872 .35257 Mdot
.872 .35382 Mdot
.872 .35386 Mdot
.872 .35397 Mdot
.872 .35419 Mdot
.872 .35435 Mdot
.872 .35457 Mdot
.872 .35471 Mdot
.872 .35493 Mdot
.872 .35533 Mdot
.872 .35537 Mdot
.872 .35545 Mdot
.872 .35546 Mdot
.872 .35769 Mdot
.872 .35826 Mdot
.872 .35829 Mdot
.872 .35863 Mdot
.872 .35902 Mdot
.872 .3592 Mdot
.872 .35928 Mdot
.872 .35931 Mdot
.872 .35938 Mdot
.872 .35964 Mdot
.872 .35974 Mdot
.872 .35981 Mdot
.872 .35999 Mdot
.872 .36034 Mdot
.872 .36078 Mdot
.872 .36165 Mdot
.872 .3623 Mdot
.872 .36341 Mdot
.872 .36347 Mdot
.872 .36406 Mdot
.872 .3641 Mdot
.872 .36413 Mdot
.872 .3649 Mdot
.872 .36527 Mdot
.872 .36546 Mdot
.872 .36603 Mdot
.872 .36628 Mdot
.872 .36664 Mdot
.872 .3669 Mdot
.872 .36694 Mdot
.872 .36831 Mdot
.872 .36834 Mdot
.872 .36878 Mdot
.872 .37059 Mdot
.872 .37102 Mdot
.872 .3714 Mdot
.872 .37269 Mdot
.872 .37318 Mdot
.872 .37321 Mdot
.872 .3738 Mdot
.872 .37384 Mdot
.872 .37505 Mdot
.872 .37544 Mdot
.872 .37614 Mdot
.872 .37674 Mdot
.872 .3768 Mdot
.872 .37757 Mdot
.872 .37788 Mdot
.872 .37833 Mdot
.872 .3784 Mdot
.872 .37976 Mdot
.872 .38074 Mdot
.872 .38088 Mdot
.872 .38122 Mdot
.872 .38146 Mdot
.872 .38264 Mdot
.872 .38301 Mdot
.872 .38347 Mdot
.872 .38366 Mdot
.872 .38432 Mdot
.872 .3851 Mdot
.872 .38716 Mdot
.872 .38717 Mdot
.872 .38743 Mdot
.872 .38746 Mdot
.872 .38759 Mdot
.872 .38787 Mdot
.872 .38858 Mdot
.872 .39019 Mdot
.872 .39038 Mdot
.872 .39072 Mdot
.872 .39121 Mdot
.872 .39168 Mdot
.872 .39223 Mdot
.872 .39254 Mdot
.872 .39322 Mdot
.872 .39453 Mdot
.872 .39572 Mdot
.872 .3964 Mdot
.872 .39658 Mdot
.872 .39792 Mdot
.872 .39989 Mdot
.872 .40041 Mdot
.872 .40107 Mdot
.872 .40137 Mdot
.872 .40232 Mdot
.872 .40245 Mdot
.872 .4028 Mdot
.872 .40296 Mdot
.872 .40336 Mdot
.872 .4034 Mdot
.872 .40391 Mdot
.872 .40489 Mdot
.872 .40489 Mdot
.872 .4054 Mdot
.872 .40578 Mdot
.872 .40684 Mdot
.872 .40763 Mdot
.872 .40868 Mdot
.872 .4109 Mdot
.872 .41097 Mdot
.872 .41138 Mdot
.872 .41265 Mdot
.872 .41644 Mdot
.872 .4168 Mdot
.872 .41783 Mdot
.872 .41898 Mdot
.872 .41916 Mdot
.872 .41988 Mdot
.872 .42011 Mdot
.872 .42134 Mdot
.872 .42189 Mdot
.872 .42194 Mdot
.872 .42218 Mdot
.872 .42335 Mdot
.872 .42336 Mdot
.872 .42347 Mdot
.872 .42418 Mdot
.872 .42468 Mdot
.872 .42527 Mdot
.872 .42565 Mdot
.872 .42665 Mdot
.872 .42666 Mdot
.872 .42681 Mdot
.872 .4274 Mdot
.872 .42767 Mdot
.872 .42944 Mdot
.872 .43042 Mdot
.872 .43074 Mdot
.872 .43148 Mdot
.872 .43164 Mdot
.872 .43285 Mdot
.872 .43295 Mdot
.872 .43299 Mdot
.872 .43589 Mdot
.872 .43721 Mdot
.872 .43788 Mdot
.872 .43799 Mdot
.872 .43819 Mdot
.872 .43868 Mdot
.872 .43884 Mdot
.872 .43897 Mdot
.872 .44065 Mdot
.872 .44081 Mdot
.872 .44331 Mdot
.872 .44337 Mdot
.872 .44436 Mdot
.872 .44588 Mdot
.872 .44608 Mdot
.872 .44617 Mdot
.872 .44792 Mdot
.872 .4488 Mdot
.872 .4493 Mdot
.872 .44984 Mdot
.872 .45044 Mdot
.872 .45166 Mdot
.872 .45225 Mdot
.872 .45328 Mdot
.872 .45405 Mdot
.872 .45748 Mdot
.872 .45782 Mdot
.872 .45842 Mdot
.872 .46093 Mdot
.872 .46097 Mdot
.872 .46206 Mdot
.872 .46311 Mdot
.872 .46454 Mdot
.872 .46469 Mdot
.872 .46494 Mdot
.872 .46578 Mdot
.872 .46619 Mdot
.872 .46692 Mdot
.872 .46725 Mdot
.872 .4673 Mdot
.872 .46789 Mdot
.872 .47028 Mdot
.872 .4709 Mdot
.872 .47123 Mdot
.872 .47185 Mdot
.872 .47185 Mdot
.872 .47257 Mdot
.872 .4727 Mdot
.872 .47347 Mdot
.872 .47602 Mdot
.872 .4767 Mdot
.872 .47897 Mdot
.872 .47921 Mdot
.872 .4808 Mdot
.872 .48156 Mdot
.872 .48241 Mdot
.872 .48355 Mdot
.872 .48401 Mdot
.872 .48475 Mdot
.872 .48618 Mdot
.872 .48732 Mdot
.872 .48858 Mdot
.872 .48888 Mdot
.872 .48945 Mdot
.872 .4908 Mdot
.872 .4918 Mdot
.872 .49195 Mdot
.872 .49219 Mdot
.872 .49374 Mdot
.872 .49491 Mdot
.872 .49571 Mdot
.872 .4973 Mdot
.872 .4988 Mdot
.872 .501 Mdot
.872 .50234 Mdot
.872 .5029 Mdot
.872 .50302 Mdot
.872 .50321 Mdot
.872 .5039 Mdot
.872 .50486 Mdot
.872 .50505 Mdot
.872 .50514 Mdot
.872 .50547 Mdot
.872 .5057 Mdot
.872 .50572 Mdot
.872 .50577 Mdot
.872 .50578 Mdot
.872 .50782 Mdot
.872 .50797 Mdot
.872 .50803 Mdot
.872 .50837 Mdot
.872 .51071 Mdot
.872 .51075 Mdot
.872 .51119 Mdot
.872 .51151 Mdot
.872 .51184 Mdot
.872 .51594 Mdot
.872 .51595 Mdot
.872 .51629 Mdot
.872 .51632 Mdot
.872 .51845 Mdot
.872 .51863 Mdot
.872 .51889 Mdot
.872 .52055 Mdot
.872 .52069 Mdot
.872 .52233 Mdot
.872 .52411 Mdot
.872 .52627 Mdot
.872 .52686 Mdot
.872 .52743 Mdot
.872 .52818 Mdot
.872 .52935 Mdot
.874 .01526 Mdot
.874 .0154 Mdot
.874 .01567 Mdot
.874 .01591 Mdot
.874 .01615 Mdot
.874 .01638 Mdot
.874 .01654 Mdot
.874 .0168 Mdot
.874 .01722 Mdot
.874 .01763 Mdot
.874 .0179 Mdot
.874 .01811 Mdot
.874 .01836 Mdot
.874 .01836 Mdot
.874 .01909 Mdot
.874 .01926 Mdot
.874 .01951 Mdot
.874 .01975 Mdot
.874 .01981 Mdot
.874 .01983 Mdot
.874 .02029 Mdot
.874 .02065 Mdot
.874 .02108 Mdot
.874 .02109 Mdot
.874 .02141 Mdot
.874 .02236 Mdot
.874 .02243 Mdot
.874 .02267 Mdot
.874 .0231 Mdot
.874 .02352 Mdot
.874 .02362 Mdot
.874 .02366 Mdot
.874 .02375 Mdot
.874 .02446 Mdot
.874 .02509 Mdot
.874 .02584 Mdot
.874 .02585 Mdot
.874 .02603 Mdot
.874 .02642 Mdot
.874 .02679 Mdot
.874 .02718 Mdot
.874 .02807 Mdot
.874 .02821 Mdot
.874 .02852 Mdot
.874 .02861 Mdot
.874 .02937 Mdot
.874 .03011 Mdot
.874 .03028 Mdot
.874 .03028 Mdot
.874 .03035 Mdot
.874 .0305 Mdot
.874 .03051 Mdot
.874 .03058 Mdot
.874 .03133 Mdot
.874 .03175 Mdot
.874 .03285 Mdot
.874 .03351 Mdot
.874 .03361 Mdot
.874 .03385 Mdot
.874 .03392 Mdot
.874 .03416 Mdot
.874 .03418 Mdot
.874 .03422 Mdot
.874 .03423 Mdot
.874 .03449 Mdot
.874 .03517 Mdot
.874 .03582 Mdot
.874 .03626 Mdot
.874 .03633 Mdot
.874 .03635 Mdot
.874 .03642 Mdot
.874 .03651 Mdot
.874 .03691 Mdot
.874 .0378 Mdot
.874 .03798 Mdot
.874 .03806 Mdot
.874 .0383 Mdot
.874 .03831 Mdot
.874 .03885 Mdot
.874 .03901 Mdot
.874 .04034 Mdot
.874 .04157 Mdot
.874 .04162 Mdot
.874 .04193 Mdot
.874 .04193 Mdot
.874 .04205 Mdot
.874 .04225 Mdot
.874 .0423 Mdot
.874 .04231 Mdot
.874 .04233 Mdot
.874 .04244 Mdot
.874 .04252 Mdot
.874 .04366 Mdot
.874 .04375 Mdot
.874 .04399 Mdot
.874 .04404 Mdot
.874 .04449 Mdot
.874 .04557 Mdot
.874 .04642 Mdot
.874 .04713 Mdot
.874 .04756 Mdot
.874 .04758 Mdot
.874 .04775 Mdot
.874 .04809 Mdot
.874 .04816 Mdot
.874 .04828 Mdot
.874 .0487 Mdot
.874 .04875 Mdot
.874 .04881 Mdot
.874 .04882 Mdot
.874 .04927 Mdot
.874 .05016 Mdot
.874 .05046 Mdot
.874 .05137 Mdot
.874 .05161 Mdot
.874 .05174 Mdot
.874 .05237 Mdot
.874 .05249 Mdot
.874 .05253 Mdot
.874 .05254 Mdot
.874 .05265 Mdot
.874 .05282 Mdot
.874 .05324 Mdot
.874 .0535 Mdot
.874 .05404 Mdot
.874 .05423 Mdot
.874 .05432 Mdot
.874 .05451 Mdot
.874 .05507 Mdot
.874 .05539 Mdot
.874 .05552 Mdot
.874 .05586 Mdot
.874 .05594 Mdot
.874 .05595 Mdot
.874 .05657 Mdot
.874 .05666 Mdot
.874 .05691 Mdot
.874 .05718 Mdot
.874 .05788 Mdot
.874 .0583 Mdot
.874 .05857 Mdot
.874 .05916 Mdot
.874 .0595 Mdot
.874 .0605 Mdot
.874 .06101 Mdot
.874 .06166 Mdot
.874 .06174 Mdot
.874 .06186 Mdot
.874 .062 Mdot
.874 .06228 Mdot
.874 .06228 Mdot
.874 .06249 Mdot
.874 .06284 Mdot
.874 .06293 Mdot
.874 .06295 Mdot
.874 .06299 Mdot
.874 .06318 Mdot
.874 .06332 Mdot
.874 .06372 Mdot
.874 .06405 Mdot
.874 .06506 Mdot
.874 .06531 Mdot
.874 .06547 Mdot
.874 .06589 Mdot
.874 .06597 Mdot
.874 .06675 Mdot
.874 .06713 Mdot
.874 .06791 Mdot
.874 .06865 Mdot
.874 .0697 Mdot
.874 .07013 Mdot
.874 .07044 Mdot
.874 .07062 Mdot
.874 .07104 Mdot
.874 .07137 Mdot
.874 .07213 Mdot
.874 .07216 Mdot
.874 .0724 Mdot
.874 .07245 Mdot
.874 .07305 Mdot
.874 .07318 Mdot
.874 .07338 Mdot
.874 .07365 Mdot
.874 .07413 Mdot
.874 .0742 Mdot
.874 .07432 Mdot
.874 .07434 Mdot
.874 .0747 Mdot
.874 .07484 Mdot
.874 .07512 Mdot
.874 .07514 Mdot
.874 .07639 Mdot
.874 .07668 Mdot
.874 .07721 Mdot
.874 .07753 Mdot
.874 .07878 Mdot
.874 .07891 Mdot
.874 .07921 Mdot
.874 .07943 Mdot
.874 .08053 Mdot
.874 .08075 Mdot
.874 .08082 Mdot
.874 .08082 Mdot
.874 .08103 Mdot
.874 .08103 Mdot
.874 .08128 Mdot
.874 .08131 Mdot
.874 .08206 Mdot
.874 .08252 Mdot
.874 .08345 Mdot
.874 .08378 Mdot
.874 .08394 Mdot
.874 .08427 Mdot
.874 .08432 Mdot
.874 .08526 Mdot
.874 .08582 Mdot
.874 .08604 Mdot
.874 .08608 Mdot
.874 .08639 Mdot
.874 .08651 Mdot
.874 .08664 Mdot
.874 .08678 Mdot
.874 .0868 Mdot
.874 .08765 Mdot
.874 .08788 Mdot
.874 .08803 Mdot
.874 .08846 Mdot
.874 .08895 Mdot
.874 .08895 Mdot
.874 .08964 Mdot
.874 .09017 Mdot
.874 .0909 Mdot
.874 .09138 Mdot
.874 .09163 Mdot
.874 .09202 Mdot
.874 .0924 Mdot
.874 .09301 Mdot
.874 .09375 Mdot
.874 .09475 Mdot
.874 .09542 Mdot
.874 .09564 Mdot
.874 .09569 Mdot
.874 .09601 Mdot
.874 .09677 Mdot
.874 .09692 Mdot
.874 .09712 Mdot
.874 .09719 Mdot
.874 .09736 Mdot
.874 .09786 Mdot
.874 .09786 Mdot
.874 .09822 Mdot
.874 .09884 Mdot
.874 .09899 Mdot
.874 .09903 Mdot
.874 .0991 Mdot
.874 .09944 Mdot
.874 .09955 Mdot
.874 .09968 Mdot
.874 .10002 Mdot
.874 .10038 Mdot
.874 .10095 Mdot
.874 .10179 Mdot
.874 .10204 Mdot
.874 .10272 Mdot
.874 .10316 Mdot
.874 .10344 Mdot
.874 .10376 Mdot
.874 .10417 Mdot
.874 .10431 Mdot
.874 .10528 Mdot
.874 .1056 Mdot
.874 .10568 Mdot
.874 .10634 Mdot
.874 .10694 Mdot
.874 .1077 Mdot
.874 .109 Mdot
.874 .11083 Mdot
.874 .11159 Mdot
.874 .11183 Mdot
.874 .11212 Mdot
.874 .11234 Mdot
.874 .11244 Mdot
.874 .11274 Mdot
.874 .11318 Mdot
.874 .11375 Mdot
.874 .1144 Mdot
.874 .11502 Mdot
.874 .11507 Mdot
.874 .11508 Mdot
.874 .11514 Mdot
.874 .11514 Mdot
.874 .11555 Mdot
.874 .11564 Mdot
.874 .11669 Mdot
.874 .1169 Mdot
.874 .11697 Mdot
.874 .11698 Mdot
.874 .11726 Mdot
.874 .11773 Mdot
.874 .11835 Mdot
.874 .11857 Mdot
.874 .1187 Mdot
.874 .11885 Mdot
.874 .1189 Mdot
.874 .11894 Mdot
.874 .11934 Mdot
.874 .11957 Mdot
.874 .11965 Mdot
.874 .11981 Mdot
.874 .12031 Mdot
.874 .12034 Mdot
.874 .12066 Mdot
.874 .12252 Mdot
.874 .12274 Mdot
.874 .12303 Mdot
.874 .1239 Mdot
.874 .12395 Mdot
.874 .12452 Mdot
.874 .12628 Mdot
.874 .1266 Mdot
.874 .12671 Mdot
.874 .12693 Mdot
.874 .12746 Mdot
.874 .12783 Mdot
.874 .12816 Mdot
.874 .12875 Mdot
.874 .12976 Mdot
.874 .13015 Mdot
.874 .13027 Mdot
.874 .13027 Mdot
.874 .13029 Mdot
.874 .13063 Mdot
.874 .13063 Mdot
.874 .13089 Mdot
.874 .13107 Mdot
.874 .13113 Mdot
.874 .13243 Mdot
.874 .13312 Mdot
.874 .13324 Mdot
.874 .13397 Mdot
.874 .13475 Mdot
.874 .13483 Mdot
.874 .13487 Mdot
.874 .13544 Mdot
.874 .13572 Mdot
.874 .1363 Mdot
.874 .13638 Mdot
.874 .13803 Mdot
.874 .13895 Mdot
.874 .139 Mdot
.874 .13939 Mdot
.874 .1394 Mdot
.874 .13946 Mdot
.874 .13962 Mdot
.874 .14 Mdot
.874 .14022 Mdot
.874 .14029 Mdot
.874 .14044 Mdot
.874 .14068 Mdot
.874 .14071 Mdot
.874 .14221 Mdot
.874 .14261 Mdot
.874 .14267 Mdot
.874 .14288 Mdot
.874 .14363 Mdot
.874 .14417 Mdot
.874 .14448 Mdot
.874 .14448 Mdot
.874 .14568 Mdot
.874 .14624 Mdot
.874 .14661 Mdot
.874 .14686 Mdot
.874 .14726 Mdot
.874 .1477 Mdot
.874 .14789 Mdot
.874 .14872 Mdot
.874 .14916 Mdot
.874 .14954 Mdot
.874 .14985 Mdot
.874 .15051 Mdot
.874 .15085 Mdot
.874 .15157 Mdot
.874 .15204 Mdot
.874 .15287 Mdot
.874 .15462 Mdot
.874 .1558 Mdot
.874 .15617 Mdot
.874 .15625 Mdot
.874 .15651 Mdot
.874 .15682 Mdot
.874 .15814 Mdot
.874 .15841 Mdot
.874 .15875 Mdot
.874 .15887 Mdot
.874 .15918 Mdot
.874 .15967 Mdot
.874 .15977 Mdot
.874 .16005 Mdot
.874 .16006 Mdot
.874 .16069 Mdot
.874 .1614 Mdot
.874 .16167 Mdot
.874 .16176 Mdot
.874 .16203 Mdot
.874 .16209 Mdot
.874 .16222 Mdot
.874 .16281 Mdot
.874 .1629 Mdot
.874 .163 Mdot
.874 .16323 Mdot
.874 .16378 Mdot
.874 .16379 Mdot
.874 .16379 Mdot
.874 .16383 Mdot
.874 .16411 Mdot
.874 .16445 Mdot
.874 .16499 Mdot
.874 .16545 Mdot
.874 .16692 Mdot
.874 .167 Mdot
.874 .16736 Mdot
.874 .16818 Mdot
.874 .16854 Mdot
.874 .16854 Mdot
.874 .16932 Mdot
.874 .16937 Mdot
.874 .1698 Mdot
.874 .17037 Mdot
.874 .17064 Mdot
.874 .17081 Mdot
.874 .17108 Mdot
.874 .17133 Mdot
.874 .17302 Mdot
.874 .17327 Mdot
.874 .17357 Mdot
.874 .17372 Mdot
.874 .17487 Mdot
.874 .17593 Mdot
.874 .17725 Mdot
.874 .1788 Mdot
.874 .17906 Mdot
.874 .17953 Mdot
.874 .18093 Mdot
.874 .18129 Mdot
.874 .18238 Mdot
.874 .18272 Mdot
.874 .18405 Mdot
.874 .18447 Mdot
.874 .18498 Mdot
.874 .18536 Mdot
.874 .18554 Mdot
.874 .18606 Mdot
.874 .1864 Mdot
.874 .18682 Mdot
.874 .18782 Mdot
.874 .18896 Mdot
.874 .18931 Mdot
.874 .19005 Mdot
.874 .19013 Mdot
.874 .19015 Mdot
.874 .19025 Mdot
.874 .19026 Mdot
.874 .19092 Mdot
.874 .19094 Mdot
.874 .19097 Mdot
.874 .19113 Mdot
.874 .19297 Mdot
.874 .19334 Mdot
.874 .19345 Mdot
.874 .19347 Mdot
.874 .19397 Mdot
.874 .19448 Mdot
.874 .19479 Mdot
.874 .19586 Mdot
.874 .19625 Mdot
.874 .19648 Mdot
.874 .19674 Mdot
.874 .19683 Mdot
.874 .19689 Mdot
.874 .19734 Mdot
.874 .1976 Mdot
.874 .198 Mdot
.874 .19813 Mdot
.874 .19841 Mdot
.874 .19885 Mdot
.874 .1993 Mdot
.874 .19934 Mdot
.874 .19991 Mdot
.874 .20035 Mdot
.874 .20186 Mdot
.874 .20217 Mdot
.874 .2023 Mdot
.874 .20316 Mdot
.874 .20355 Mdot
.874 .20364 Mdot
.874 .20405 Mdot
.874 .20557 Mdot
.874 .20565 Mdot
.874 .20665 Mdot
.874 .20816 Mdot
.874 .20917 Mdot
.874 .20974 Mdot
.874 .21028 Mdot
.874 .21047 Mdot
.874 .21086 Mdot
.874 .21179 Mdot
.874 .21245 Mdot
.874 .21301 Mdot
.874 .21361 Mdot
.874 .21405 Mdot
.874 .21582 Mdot
.874 .21595 Mdot
.874 .21649 Mdot
.874 .2167 Mdot
.874 .21671 Mdot
.874 .21674 Mdot
.874 .21733 Mdot
.874 .21734 Mdot
.874 .21779 Mdot
.874 .21795 Mdot
.874 .21811 Mdot
.874 .21821 Mdot
.874 .2196 Mdot
.874 .22049 Mdot
.874 .221 Mdot
.874 .22169 Mdot
.874 .22189 Mdot
.874 .22315 Mdot
.874 .22318 Mdot
.874 .22453 Mdot
.874 .22467 Mdot
.874 .22475 Mdot
.874 .22497 Mdot
.874 .22575 Mdot
.874 .22624 Mdot
.874 .22712 Mdot
.874 .22725 Mdot
.874 .22739 Mdot
.874 .22842 Mdot
.874 .22881 Mdot
.874 .23028 Mdot
.874 .23131 Mdot
.874 .23188 Mdot
.874 .23196 Mdot
.874 .23265 Mdot
.874 .23266 Mdot
.874 .23266 Mdot
.874 .23276 Mdot
.874 .23305 Mdot
.874 .23371 Mdot
.874 .2341 Mdot
.874 .23421 Mdot
.874 .23448 Mdot
.874 .2349 Mdot
.874 .23496 Mdot
.874 .23576 Mdot
.874 .23757 Mdot
.874 .23766 Mdot
.874 .23827 Mdot
.874 .23838 Mdot
.874 .23874 Mdot
.874 .24006 Mdot
.874 .24101 Mdot
.874 .24154 Mdot
.874 .24154 Mdot
.874 .2427 Mdot
.874 .24364 Mdot
.874 .24413 Mdot
.874 .24462 Mdot
.874 .24512 Mdot
.874 .24522 Mdot
.874 .24526 Mdot
.874 .2457 Mdot
.874 .2464 Mdot
.874 .24718 Mdot
.874 .24751 Mdot
.874 .24896 Mdot
.874 .24973 Mdot
.874 .25038 Mdot
.874 .25092 Mdot
.874 .25138 Mdot
.874 .25209 Mdot
.874 .25268 Mdot
.874 .25338 Mdot
.874 .25381 Mdot
.874 .25394 Mdot
.874 .25476 Mdot
.874 .2552 Mdot
.874 .25621 Mdot
.874 .25683 Mdot
.874 .25848 Mdot
.874 .25895 Mdot
.874 .25928 Mdot
.874 .25931 Mdot
.874 .26132 Mdot
.874 .26198 Mdot
.874 .26212 Mdot
.874 .26257 Mdot
.874 .26311 Mdot
.874 .26365 Mdot
.874 .2638 Mdot
.874 .26392 Mdot
.874 .26534 Mdot
.874 .26543 Mdot
.874 .26589 Mdot
.874 .26649 Mdot
.874 .2667 Mdot
.874 .26717 Mdot
.874 .26724 Mdot
.874 .26781 Mdot
.874 .26809 Mdot
.874 .26826 Mdot
.874 .26876 Mdot
.874 .26878 Mdot
.874 .26926 Mdot
.874 .26946 Mdot
.874 .26988 Mdot
.874 .27112 Mdot
.874 .27121 Mdot
.874 .27159 Mdot
.874 .27175 Mdot
.874 .27205 Mdot
.874 .27223 Mdot
.874 .27233 Mdot
.874 .27255 Mdot
.874 .27259 Mdot
.874 .27359 Mdot
.874 .27374 Mdot
.874 .27392 Mdot
.874 .27411 Mdot
.874 .27416 Mdot
.874 .27431 Mdot
.874 .27527 Mdot
.874 .27529 Mdot
.874 .2753 Mdot
.874 .27537 Mdot
.874 .27561 Mdot
.874 .27586 Mdot
.874 .27624 Mdot
.874 .27645 Mdot
.874 .27739 Mdot
.874 .27752 Mdot
.874 .27821 Mdot
.874 .28077 Mdot
.874 .28091 Mdot
.874 .28132 Mdot
.874 .28154 Mdot
.874 .28158 Mdot
.874 .28276 Mdot
.874 .28297 Mdot
.874 .28322 Mdot
.874 .2836 Mdot
.874 .28361 Mdot
.874 .28416 Mdot
.874 .28469 Mdot
.874 .28496 Mdot
.874 .285 Mdot
.874 .28506 Mdot
.874 .28567 Mdot
.874 .28579 Mdot
.874 .2858 Mdot
.874 .28679 Mdot
.874 .28728 Mdot
.874 .28757 Mdot
.874 .28804 Mdot
.874 .28848 Mdot
.874 .28885 Mdot
.874 .28931 Mdot
.874 .28988 Mdot
.874 .29045 Mdot
.874 .2906 Mdot
.874 .29107 Mdot
.874 .29144 Mdot
.874 .29187 Mdot
.874 .2924 Mdot
.874 .29266 Mdot
.874 .294 Mdot
.874 .29406 Mdot
.874 .29408 Mdot
.874 .29429 Mdot
.874 .29467 Mdot
.874 .29504 Mdot
.874 .2958 Mdot
.874 .29652 Mdot
.874 .29694 Mdot
.874 .2976 Mdot
.874 .29882 Mdot
.874 .30048 Mdot
.874 .30086 Mdot
.874 .30153 Mdot
.874 .30199 Mdot
.874 .30281 Mdot
.874 .30297 Mdot
.874 .30526 Mdot
.874 .30588 Mdot
.874 .3078 Mdot
.874 .30838 Mdot
.874 .31071 Mdot
.874 .31079 Mdot
.874 .31121 Mdot
.874 .31144 Mdot
.874 .31234 Mdot
.874 .31248 Mdot
.874 .313 Mdot
.874 .31314 Mdot
.874 .31328 Mdot
.874 .31332 Mdot
.874 .31423 Mdot
.874 .31481 Mdot
.874 .31556 Mdot
.874 .31687 Mdot
.874 .3173 Mdot
.874 .31753 Mdot
.874 .3183 Mdot
.874 .3193 Mdot
.874 .31943 Mdot
.874 .31947 Mdot
.874 .3199 Mdot
.874 .32115 Mdot
.874 .32121 Mdot
.874 .32134 Mdot
.874 .32138 Mdot
.874 .32156 Mdot
.874 .32156 Mdot
.874 .32272 Mdot
.874 .32276 Mdot
.874 .32277 Mdot
.874 .32281 Mdot
.874 .32309 Mdot
.874 .3236 Mdot
.874 .32371 Mdot
.874 .32389 Mdot
.874 .32576 Mdot
.874 .32615 Mdot
.874 .32618 Mdot
.874 .3263 Mdot
.874 .32696 Mdot
.874 .32714 Mdot
.874 .32717 Mdot
.874 .32805 Mdot
.874 .32894 Mdot
.874 .3292 Mdot
.874 .32949 Mdot
.874 .33068 Mdot
.874 .33136 Mdot
.874 .33158 Mdot
.874 .33203 Mdot
.874 .33244 Mdot
.874 .33289 Mdot
.874 .333 Mdot
.874 .33305 Mdot
.874 .33316 Mdot
.874 .33394 Mdot
.874 .33434 Mdot
.874 .33439 Mdot
.874 .33509 Mdot
.874 .33533 Mdot
.874 .33549 Mdot
.874 .33582 Mdot
.874 .33659 Mdot
.874 .33688 Mdot
.874 .33736 Mdot
.874 .33744 Mdot
.874 .33843 Mdot
.874 .33862 Mdot
.874 .3392 Mdot
.874 .34038 Mdot
.874 .34083 Mdot
.874 .34185 Mdot
.874 .34227 Mdot
.874 .34238 Mdot
.874 .34262 Mdot
.874 .3434 Mdot
.874 .34411 Mdot
.874 .34471 Mdot
.874 .34479 Mdot
.874 .34496 Mdot
.874 .34568 Mdot
.874 .34633 Mdot
.874 .34712 Mdot
.874 .34833 Mdot
.874 .34848 Mdot
.874 .35022 Mdot
.874 .35122 Mdot
.874 .3514 Mdot
.874 .35147 Mdot
.874 .35212 Mdot
.874 .35286 Mdot
.874 .35326 Mdot
.874 .3544 Mdot
.874 .35462 Mdot
.874 .35561 Mdot
.874 .35657 Mdot
.874 .35672 Mdot
.874 .3569 Mdot
.874 .35758 Mdot
.874 .35893 Mdot
.874 .3592 Mdot
.874 .36021 Mdot
.874 .36035 Mdot
.874 .36134 Mdot
.874 .36221 Mdot
.874 .36239 Mdot
.874 .36316 Mdot
.874 .36595 Mdot
.874 .36624 Mdot
.874 .36647 Mdot
.874 .36742 Mdot
.874 .36778 Mdot
.874 .36781 Mdot
.874 .36785 Mdot
.874 .36889 Mdot
.874 .3689 Mdot
.874 .36968 Mdot
.874 .36997 Mdot
.874 .37025 Mdot
.874 .37043 Mdot
.874 .37101 Mdot
.874 .3722 Mdot
.874 .37286 Mdot
.874 .37422 Mdot
.874 .3744 Mdot
.874 .37529 Mdot
.874 .37564 Mdot
.874 .37651 Mdot
.874 .37686 Mdot
.874 .37814 Mdot
.874 .37862 Mdot
.874 .37906 Mdot
.874 .37911 Mdot
.874 .38147 Mdot
.874 .38172 Mdot
.874 .38185 Mdot
.874 .38223 Mdot
.874 .3836 Mdot
.874 .38446 Mdot
.874 .38564 Mdot
.874 .38599 Mdot
.874 .38622 Mdot
.874 .38648 Mdot
.874 .38753 Mdot
.874 .38828 Mdot
.874 .38896 Mdot
.874 .39151 Mdot
.874 .39332 Mdot
.874 .39338 Mdot
.874 .39431 Mdot
.874 .39447 Mdot
.874 .39517 Mdot
.874 .39567 Mdot
.874 .39568 Mdot
.874 .39568 Mdot
.874 .39586 Mdot
.874 .39636 Mdot
.874 .39751 Mdot
.874 .39819 Mdot
.874 .3984 Mdot
.874 .39887 Mdot
.874 .3996 Mdot
.874 .3997 Mdot
.874 .4011 Mdot
.874 .40426 Mdot
.874 .40442 Mdot
.874 .40549 Mdot
.874 .40569 Mdot
.874 .40632 Mdot
.874 .40861 Mdot
.874 .41028 Mdot
.874 .4112 Mdot
.874 .41121 Mdot
.874 .41323 Mdot
.874 .41487 Mdot
.874 .41574 Mdot
.874 .41659 Mdot
.874 .41746 Mdot
.874 .41763 Mdot
.874 .41771 Mdot
.874 .41848 Mdot
.874 .42106 Mdot
.874 .42164 Mdot
.874 .42418 Mdot
.874 .42552 Mdot
.874 .42666 Mdot
.874 .42761 Mdot
.874 .42841 Mdot
.874 .42964 Mdot
.874 .43068 Mdot
.874 .43191 Mdot
.874 .43265 Mdot
.874 .43288 Mdot
.874 .43431 Mdot
.874 .43508 Mdot
.874 .43685 Mdot
.874 .43794 Mdot
.874 .44082 Mdot
.874 .44164 Mdot
.874 .44221 Mdot
.874 .44226 Mdot
.874 .44579 Mdot
.874 .44693 Mdot
.874 .44718 Mdot
.874 .44797 Mdot
.874 .44891 Mdot
.874 .44985 Mdot
.874 .45012 Mdot
.874 .45032 Mdot
.874 .45281 Mdot
.874 .45296 Mdot
.874 .45377 Mdot
.874 .45482 Mdot
.874 .45519 Mdot
.874 .45601 Mdot
.874 .45613 Mdot
.874 .45713 Mdot
.874 .45761 Mdot
.874 .45792 Mdot
.874 .45879 Mdot
.874 .45882 Mdot
.874 .45965 Mdot
.874 .46001 Mdot
.874 .46074 Mdot
.874 .46292 Mdot
.874 .46307 Mdot
.874 .46374 Mdot
.874 .46401 Mdot
.874 .46454 Mdot
.874 .46484 Mdot
.874 .46502 Mdot
.874 .4654 Mdot
.874 .46548 Mdot
.874 .46722 Mdot
.874 .46749 Mdot
.874 .46781 Mdot
.874 .46814 Mdot
.874 .46822 Mdot
.874 .4685 Mdot
.874 .47017 Mdot
.874 .4702 Mdot
.874 .47022 Mdot
.874 .47034 Mdot
.874 .47076 Mdot
.874 .4712 Mdot
.874 .47185 Mdot
.874 .47223 Mdot
.874 .47387 Mdot
.874 .4741 Mdot
.874 .4753 Mdot
.874 .47977 Mdot
.874 .48002 Mdot
.874 .48074 Mdot
.874 .48112 Mdot
.874 .4812 Mdot
.874 .48325 Mdot
.874 .48363 Mdot
.874 .48407 Mdot
.874 .48472 Mdot
.874 .48474 Mdot
.874 .4857 Mdot
.874 .48663 Mdot
.874 .48711 Mdot
.874 .48717 Mdot
.874 .48727 Mdot
.874 .48834 Mdot
.874 .48856 Mdot
.874 .48858 Mdot
.874 .49031 Mdot
.874 .49115 Mdot
.874 .49167 Mdot
.874 .49248 Mdot
.874 .49325 Mdot
.874 .4939 Mdot
.874 .4947 Mdot
.874 .4957 Mdot
.874 .4967 Mdot
.874 .49696 Mdot
.874 .49779 Mdot
.874 .49843 Mdot
.874 .49918 Mdot
.874 .50011 Mdot
.874 .50056 Mdot
.874 .50291 Mdot
.874 .50301 Mdot
.874 .50305 Mdot
.874 .50342 Mdot
.874 .50407 Mdot
.874 .50472 Mdot
.874 .50605 Mdot
.874 .50731 Mdot
.874 .50805 Mdot
.874 .50919 Mdot
.874 .51133 Mdot
.874 .51422 Mdot
.874 .5149 Mdot
.874 .51606 Mdot
.874 .51687 Mdot
.874 .5183 Mdot
.874 .51858 Mdot
.874 .5226 Mdot
.874 .52367 Mdot
.874 .52702 Mdot
.874 .52805 Mdot
.876 .01478 Mdot
.876 .01482 Mdot
.876 .0149 Mdot
.876 .01504 Mdot
.876 .01528 Mdot
.876 .0157 Mdot
.876 .01645 Mdot
.876 .01746 Mdot
.876 .01768 Mdot
.876 .01775 Mdot
.876 .01778 Mdot
.876 .01822 Mdot
.876 .01889 Mdot
.876 .01902 Mdot
.876 .01952 Mdot
.876 .01983 Mdot
.876 .01988 Mdot
.876 .01992 Mdot
.876 .02004 Mdot
.876 .02008 Mdot
.876 .02061 Mdot
.876 .02086 Mdot
.876 .02203 Mdot
.876 .02226 Mdot
.876 .02263 Mdot
.876 .02314 Mdot
.876 .02368 Mdot
.876 .02376 Mdot
.876 .02383 Mdot
.876 .02392 Mdot
.876 .02404 Mdot
.876 .02412 Mdot
.876 .0243 Mdot
.876 .0248 Mdot
.876 .02504 Mdot
.876 .02548 Mdot
.876 .02651 Mdot
.876 .02753 Mdot
.876 .02793 Mdot
.876 .02832 Mdot
.876 .02858 Mdot
.876 .02863 Mdot
.876 .02947 Mdot
.876 .03041 Mdot
.876 .03052 Mdot
.876 .03056 Mdot
.876 .03057 Mdot
.876 .03068 Mdot
.876 .03084 Mdot
.876 .03105 Mdot
.876 .03119 Mdot
.876 .0315 Mdot
.876 .03238 Mdot
.876 .0328 Mdot
.876 .03357 Mdot
.876 .03388 Mdot
.876 .03538 Mdot
.876 .03588 Mdot
.876 .03717 Mdot
.876 .03724 Mdot
.876 .03757 Mdot
.876 .03787 Mdot
.876 .03851 Mdot
.876 .03855 Mdot
.876 .0389 Mdot
.876 .03901 Mdot
.876 .03909 Mdot
.876 .0399 Mdot
.876 .04056 Mdot
.876 .04193 Mdot
.876 .04199 Mdot
.876 .04222 Mdot
.876 .0424 Mdot
.876 .04248 Mdot
.876 .04249 Mdot
.876 .04269 Mdot
.876 .04297 Mdot
.876 .04313 Mdot
.876 .04333 Mdot
.876 .04348 Mdot
.876 .04359 Mdot
.876 .04412 Mdot
.876 .04457 Mdot
.876 .04496 Mdot
.876 .04501 Mdot
.876 .04519 Mdot
.876 .04566 Mdot
.876 .04628 Mdot
.876 .04641 Mdot
.876 .04666 Mdot
.876 .04775 Mdot
.876 .04828 Mdot
.876 .04844 Mdot
.876 .05039 Mdot
.876 .05061 Mdot
.876 .0508 Mdot
.876 .05092 Mdot
.876 .0518 Mdot
.876 .05196 Mdot
.876 .05322 Mdot
.876 .05338 Mdot
.876 .0534 Mdot
.876 .0534 Mdot
.876 .05406 Mdot
.876 .05418 Mdot
.876 .05467 Mdot
.876 .05477 Mdot
.876 .05529 Mdot
.876 .05587 Mdot
.876 .05641 Mdot
.876 .05648 Mdot
.876 .05692 Mdot
.876 .05708 Mdot
.876 .05728 Mdot
.876 .05743 Mdot
.876 .05883 Mdot
.876 .06 Mdot
.876 .06066 Mdot
.876 .06188 Mdot
.876 .0624 Mdot
.876 .06243 Mdot
.876 .06249 Mdot
.876 .06291 Mdot
.876 .06319 Mdot
.876 .06323 Mdot
.876 .06324 Mdot
.876 .06335 Mdot
.876 .06337 Mdot
.876 .06341 Mdot
.876 .06373 Mdot
.876 .06421 Mdot
.876 .06449 Mdot
.876 .06485 Mdot
.876 .06511 Mdot
.876 .06518 Mdot
.876 .0653 Mdot
.876 .06624 Mdot
.876 .06702 Mdot
.876 .06731 Mdot
.876 .0677 Mdot
.876 .0678 Mdot
.876 .0681 Mdot
.876 .06884 Mdot
.876 .06894 Mdot
.876 .07001 Mdot
.876 .07024 Mdot
.876 .07067 Mdot
.876 .07071 Mdot
.876 .07095 Mdot
.876 .07259 Mdot
.876 .07353 Mdot
.876 .0738 Mdot
.876 .07457 Mdot
.876 .07487 Mdot
.876 .07627 Mdot
.876 .07646 Mdot
.876 .07668 Mdot
.876 .07668 Mdot
.876 .07688 Mdot
.876 .07721 Mdot
.876 .07761 Mdot
.876 .07794 Mdot
.876 .07815 Mdot
.876 .0783 Mdot
.876 .07842 Mdot
.876 .07858 Mdot
.876 .07909 Mdot
.876 .07969 Mdot
.876 .07998 Mdot
.876 .08037 Mdot
.876 .08052 Mdot
.876 .08054 Mdot
.876 .08118 Mdot
.876 .08218 Mdot
.876 .08238 Mdot
.876 .08245 Mdot
.876 .08248 Mdot
.876 .08249 Mdot
.876 .08365 Mdot
.876 .08386 Mdot
.876 .08472 Mdot
.876 .08488 Mdot
.876 .08549 Mdot
.876 .0858 Mdot
.876 .08604 Mdot
.876 .08682 Mdot
.876 .08773 Mdot
.876 .08776 Mdot
.876 .08788 Mdot
.876 .08866 Mdot
.876 .08895 Mdot
.876 .08924 Mdot
.876 .08929 Mdot
.876 .08955 Mdot
.876 .09201 Mdot
.876 .09235 Mdot
.876 .09325 Mdot
.876 .09405 Mdot
.876 .09433 Mdot
.876 .09521 Mdot
.876 .09534 Mdot
.876 .09578 Mdot
.876 .09643 Mdot
.876 .09688 Mdot
.876 .0969 Mdot
.876 .09735 Mdot
.876 .09825 Mdot
.876 .0983 Mdot
.876 .09839 Mdot
.876 .09842 Mdot
.876 .09843 Mdot
.876 .09902 Mdot
.876 .09915 Mdot
.876 .09964 Mdot
.876 .09971 Mdot
.876 .09972 Mdot
.876 .09993 Mdot
.876 .09996 Mdot
.876 .10003 Mdot
.876 .10059 Mdot
.876 .10144 Mdot
.876 .10169 Mdot
.876 .10192 Mdot
.876 .10254 Mdot
.876 .10301 Mdot
.876 .10312 Mdot
.876 .10325 Mdot
.876 .10334 Mdot
.876 .1035 Mdot
.876 .10498 Mdot
.876 .10606 Mdot
.876 .10635 Mdot
.876 .10687 Mdot
.876 .10746 Mdot
.876 .10755 Mdot
.876 .10772 Mdot
.876 .10824 Mdot
.876 .10853 Mdot
.876 .10859 Mdot
.876 .10864 Mdot
.876 .10887 Mdot
.876 .10917 Mdot
.876 .10955 Mdot
.876 .10962 Mdot
.876 .10971 Mdot
.876 .10977 Mdot
.876 .11024 Mdot
.876 .11042 Mdot
.876 .11043 Mdot
.876 .11155 Mdot
.876 .1116 Mdot
.876 .11161 Mdot
.876 .11199 Mdot
.876 .11276 Mdot
.876 .11283 Mdot
.876 .11324 Mdot
.876 .11523 Mdot
.876 .11529 Mdot
.876 .1161 Mdot
.876 .11668 Mdot
.876 .11691 Mdot
.876 .11775 Mdot
.876 .11824 Mdot
.876 .11959 Mdot
.876 .12007 Mdot
.876 .1201 Mdot
.876 .12082 Mdot
.876 .1215 Mdot
.876 .12217 Mdot
.876 .12249 Mdot
.876 .12252 Mdot
.876 .12257 Mdot
.876 .12289 Mdot
.876 .12292 Mdot
.876 .12328 Mdot
.876 .12328 Mdot
.876 .12363 Mdot
.876 .1242 Mdot
.876 .12431 Mdot
.876 .1249 Mdot
.876 .12548 Mdot
.876 .12585 Mdot
.876 .12604 Mdot
.876 .12612 Mdot
.876 .12624 Mdot
.876 .12633 Mdot
.876 .1266 Mdot
.876 .12661 Mdot
.876 .12751 Mdot
.876 .12855 Mdot
.876 .12905 Mdot
.876 .12906 Mdot
.876 .12975 Mdot
.876 .13 Mdot
.876 .13005 Mdot
.876 .13103 Mdot
.876 .13116 Mdot
.876 .13174 Mdot
.876 .13231 Mdot
.876 .13267 Mdot
.876 .13291 Mdot
.876 .13298 Mdot
.876 .13326 Mdot
.876 .13338 Mdot
.876 .13345 Mdot
.876 .13345 Mdot
.876 .13405 Mdot
.876 .13419 Mdot
.876 .13485 Mdot
.876 .13519 Mdot
.876 .13523 Mdot
.876 .13549 Mdot
.876 .13585 Mdot
.876 .13736 Mdot
.876 .13765 Mdot
.876 .13843 Mdot
.876 .13872 Mdot
.876 .13877 Mdot
.876 .13918 Mdot
.876 .13926 Mdot
.876 .13949 Mdot
.876 .13968 Mdot
.876 .14104 Mdot
.876 .14189 Mdot
.876 .14264 Mdot
.876 .14269 Mdot
.876 .14274 Mdot
.876 .14291 Mdot
.876 .14325 Mdot
.876 .14427 Mdot
.876 .14459 Mdot
.876 .14477 Mdot
.876 .14477 Mdot
.876 .14528 Mdot
.876 .14536 Mdot
.876 .14582 Mdot
.876 .14618 Mdot
.876 .14811 Mdot
.876 .14822 Mdot
.876 .15013 Mdot
.876 .15073 Mdot
.876 .15184 Mdot
.876 .15186 Mdot
.876 .15231 Mdot
.876 .15372 Mdot
.876 .1542 Mdot
.876 .1545 Mdot
.876 .1545 Mdot
.876 .15574 Mdot
.876 .15577 Mdot
.876 .15597 Mdot
.876 .15625 Mdot
.876 .15675 Mdot
.876 .1572 Mdot
.876 .1578 Mdot
.876 .15788 Mdot
.876 .15815 Mdot
.876 .15866 Mdot
.876 .1587 Mdot
.876 .15949 Mdot
.876 .16107 Mdot
.876 .16116 Mdot
.876 .16132 Mdot
.876 .16137 Mdot
.876 .16138 Mdot
.876 .16199 Mdot
.876 .16242 Mdot
.876 .16264 Mdot
.876 .1635 Mdot
.876 .16355 Mdot
.876 .16362 Mdot
.876 .16365 Mdot
.876 .16381 Mdot
.876 .16401 Mdot
.876 .16407 Mdot
.876 .16419 Mdot
.876 .16517 Mdot
.876 .166 Mdot
.876 .16603 Mdot
.876 .16647 Mdot
.876 .16665 Mdot
.876 .1671 Mdot
.876 .1675 Mdot
.876 .1677 Mdot
.876 .16859 Mdot
.876 .1687 Mdot
.876 .16892 Mdot
.876 .16908 Mdot
.876 .16942 Mdot
.876 .16961 Mdot
.876 .16984 Mdot
.876 .16998 Mdot
.876 .17011 Mdot
.876 .17027 Mdot
.876 .17051 Mdot
.876 .17138 Mdot
.876 .17277 Mdot
.876 .17286 Mdot
.876 .17475 Mdot
.876 .17497 Mdot
.876 .17526 Mdot
.876 .17605 Mdot
.876 .17616 Mdot
.876 .17721 Mdot
.876 .17736 Mdot
.876 .17747 Mdot
.876 .17766 Mdot
.876 .1779 Mdot
.876 .17845 Mdot
.876 .17858 Mdot
.876 .17909 Mdot
.876 .17919 Mdot
.876 .17927 Mdot
.876 .17967 Mdot
.876 .1802 Mdot
.876 .18058 Mdot
.876 .18086 Mdot
.876 .181 Mdot
.876 .18115 Mdot
.876 .18125 Mdot
.876 .18208 Mdot
.876 .18239 Mdot
.876 .18241 Mdot
.876 .18304 Mdot
.876 .18438 Mdot
.876 .18445 Mdot
.876 .18448 Mdot
.876 .18462 Mdot
.876 .18489 Mdot
.876 .18515 Mdot
.876 .18516 Mdot
.876 .18606 Mdot
.876 .18648 Mdot
.876 .1866 Mdot
.876 .18733 Mdot
.876 .18792 Mdot
.876 .19082 Mdot
.876 .19093 Mdot
.876 .19235 Mdot
.876 .19335 Mdot
.876 .19341 Mdot
.876 .19377 Mdot
.876 .1951 Mdot
.876 .19524 Mdot
.876 .19608 Mdot
.876 .19608 Mdot
.876 .19609 Mdot
.876 .19689 Mdot
.876 .19845 Mdot
.876 .19885 Mdot
.876 .19927 Mdot
.876 .19929 Mdot
.876 .19935 Mdot
.876 .20062 Mdot
.876 .20112 Mdot
.876 .20173 Mdot
.876 .2018 Mdot
.876 .20298 Mdot
.876 .20354 Mdot
.876 .2036 Mdot
.876 .20367 Mdot
.876 .20367 Mdot
.876 .20424 Mdot
.876 .20429 Mdot
.876 .20487 Mdot
.876 .20492 Mdot
.876 .20493 Mdot
.876 .20553 Mdot
.876 .20654 Mdot
.876 .20672 Mdot
.876 .20776 Mdot
.876 .20878 Mdot
.876 .20907 Mdot
.876 .20942 Mdot
.876 .20975 Mdot
.876 .20989 Mdot
.876 .2101 Mdot
.876 .21026 Mdot
.876 .21074 Mdot
.876 .21076 Mdot
.876 .21233 Mdot
.876 .21405 Mdot
.876 .21407 Mdot
.876 .21408 Mdot
.876 .21416 Mdot
.876 .21466 Mdot
.876 .21503 Mdot
.876 .21505 Mdot
.876 .21625 Mdot
.876 .2167 Mdot
.876 .21678 Mdot
.876 .21849 Mdot
.876 .21873 Mdot
.876 .21975 Mdot
.876 .22074 Mdot
.876 .22138 Mdot
.876 .22179 Mdot
.876 .22191 Mdot
.876 .22236 Mdot
.876 .22241 Mdot
.876 .22262 Mdot
.876 .22273 Mdot
.876 .22274 Mdot
.876 .22379 Mdot
.876 .22403 Mdot
.876 .22491 Mdot
.876 .22519 Mdot
.876 .22579 Mdot
.876 .22585 Mdot
.876 .22631 Mdot
.876 .22694 Mdot
.876 .22816 Mdot
.876 .22959 Mdot
.876 .2301 Mdot
.876 .23146 Mdot
.876 .23197 Mdot
.876 .23206 Mdot
.876 .23278 Mdot
.876 .23292 Mdot
.876 .23332 Mdot
.876 .23365 Mdot
.876 .23411 Mdot
.876 .23424 Mdot
.876 .23452 Mdot
.876 .23498 Mdot
.876 .23604 Mdot
.876 .23665 Mdot
.876 .23752 Mdot
.876 .23832 Mdot
.876 .23884 Mdot
.876 .23892 Mdot
.876 .23901 Mdot
.876 .2393 Mdot
.876 .23991 Mdot
.876 .2417 Mdot
.876 .24225 Mdot
.876 .24257 Mdot
.876 .24257 Mdot
.876 .24283 Mdot
.876 .24347 Mdot
.876 .24361 Mdot
.876 .24421 Mdot
.876 .24441 Mdot
.876 .24504 Mdot
.876 .24543 Mdot
.876 .2468 Mdot
.876 .24842 Mdot
.876 .24843 Mdot
.876 .24843 Mdot
.876 .24862 Mdot
.876 .25113 Mdot
.876 .25196 Mdot
.876 .25302 Mdot
.876 .25496 Mdot
.876 .255 Mdot
.876 .25509 Mdot
.876 .25524 Mdot
.876 .25578 Mdot
.876 .25633 Mdot
.876 .2578 Mdot
.876 .25825 Mdot
.876 .25865 Mdot
.876 .25909 Mdot
.876 .25962 Mdot
.876 .25962 Mdot
.876 .2605 Mdot
.876 .26179 Mdot
.876 .26184 Mdot
.876 .2622 Mdot
.876 .26268 Mdot
.876 .26295 Mdot
.876 .26356 Mdot
.876 .26435 Mdot
.876 .2654 Mdot
.876 .26554 Mdot
.876 .26601 Mdot
.876 .26615 Mdot
.876 .26659 Mdot
.876 .26691 Mdot
.876 .26698 Mdot
.876 .26804 Mdot
.876 .26835 Mdot
.876 .26848 Mdot
.876 .26981 Mdot
.876 .27081 Mdot
.876 .27101 Mdot
.876 .27113 Mdot
.876 .27129 Mdot
.876 .27157 Mdot
.876 .27166 Mdot
.876 .27168 Mdot
.876 .27274 Mdot
.876 .27349 Mdot
.876 .27387 Mdot
.876 .27427 Mdot
.876 .27523 Mdot
.876 .27538 Mdot
.876 .27547 Mdot
.876 .2756 Mdot
.876 .27561 Mdot
.876 .27565 Mdot
.876 .27594 Mdot
.876 .27628 Mdot
.876 .27638 Mdot
.876 .2766 Mdot
.876 .27832 Mdot
.876 .27971 Mdot
.876 .27977 Mdot
.876 .27982 Mdot
.876 .28059 Mdot
.876 .28091 Mdot
.876 .28169 Mdot
.876 .2824 Mdot
.876 .28275 Mdot
.876 .28276 Mdot
.876 .28337 Mdot
.876 .28375 Mdot
.876 .28424 Mdot
.876 .28431 Mdot
.876 .28449 Mdot
.876 .28488 Mdot
.876 .28509 Mdot
.876 .28516 Mdot
.876 .28536 Mdot
.876 .28544 Mdot
.876 .28575 Mdot
.876 .28608 Mdot
.876 .28649 Mdot
.876 .28674 Mdot
.876 .28697 Mdot
.876 .28724 Mdot
.876 .28766 Mdot
.876 .28868 Mdot
.876 .28919 Mdot
.876 .291 Mdot
.876 .29164 Mdot
.876 .29178 Mdot
.876 .29217 Mdot
.876 .29339 Mdot
.876 .29509 Mdot
.876 .29549 Mdot
.876 .29598 Mdot
.876 .29632 Mdot
.876 .2968 Mdot
.876 .29706 Mdot
.876 .29737 Mdot
.876 .29746 Mdot
.876 .29749 Mdot
.876 .29758 Mdot
.876 .29761 Mdot
.876 .2985 Mdot
.876 .2994 Mdot
.876 .29954 Mdot
.876 .29967 Mdot
.876 .29985 Mdot
.876 .29986 Mdot
.876 .30019 Mdot
.876 .30055 Mdot
.876 .30062 Mdot
.876 .30157 Mdot
.876 .3018 Mdot
.876 .30269 Mdot
.876 .30288 Mdot
.876 .30301 Mdot
.876 .30371 Mdot
.876 .30464 Mdot
.876 .30531 Mdot
.876 .30581 Mdot
.876 .30581 Mdot
.876 .30604 Mdot
.876 .30631 Mdot
.876 .30648 Mdot
.876 .30794 Mdot
.876 .30849 Mdot
.876 .30852 Mdot
.876 .30961 Mdot
.876 .31008 Mdot
.876 .31026 Mdot
.876 .31043 Mdot
.876 .31196 Mdot
.876 .31209 Mdot
.876 .31215 Mdot
.876 .3124 Mdot
.876 .31278 Mdot
.876 .31285 Mdot
.876 .31332 Mdot
.876 .31334 Mdot
.876 .31376 Mdot
.876 .31491 Mdot
.876 .31565 Mdot
.876 .31586 Mdot
.876 .31615 Mdot
.876 .31713 Mdot
.876 .31816 Mdot
.876 .31834 Mdot
.876 .31942 Mdot
.876 .31944 Mdot
.876 .32133 Mdot
.876 .32248 Mdot
.876 .32325 Mdot
.876 .32344 Mdot
.876 .32398 Mdot
.876 .3242 Mdot
.876 .32477 Mdot
.876 .32593 Mdot
.876 .32596 Mdot
.876 .32661 Mdot
.876 .32682 Mdot
.876 .32744 Mdot
.876 .32766 Mdot
.876 .32769 Mdot
.876 .32779 Mdot
.876 .32841 Mdot
.876 .32863 Mdot
.876 .32965 Mdot
.876 .33076 Mdot
.876 .33089 Mdot
.876 .33099 Mdot
.876 .33166 Mdot
.876 .33237 Mdot
.876 .33246 Mdot
.876 .33247 Mdot
.876 .33248 Mdot
.876 .3332 Mdot
.876 .33389 Mdot
.876 .33449 Mdot
.876 .33662 Mdot
.876 .33732 Mdot
.876 .33763 Mdot
.876 .33806 Mdot
.876 .33809 Mdot
.876 .33819 Mdot
.876 .3392 Mdot
.876 .34042 Mdot
.876 .34129 Mdot
.876 .34236 Mdot
.876 .34249 Mdot
.876 .34456 Mdot
.876 .34473 Mdot
.876 .34553 Mdot
.876 .34564 Mdot
.876 .34577 Mdot
.876 .34577 Mdot
.876 .34588 Mdot
.876 .34669 Mdot
.876 .34676 Mdot
.876 .34685 Mdot
.876 .34714 Mdot
.876 .34787 Mdot
.876 .34796 Mdot
.876 .34797 Mdot
.876 .34833 Mdot
.876 .34902 Mdot
.876 .35079 Mdot
.876 .35111 Mdot
.876 .35207 Mdot
.876 .35293 Mdot
.876 .35471 Mdot
.876 .35522 Mdot
.876 .35584 Mdot
.876 .35642 Mdot
.876 .35667 Mdot
.876 .35704 Mdot
.876 .35729 Mdot
.876 .3573 Mdot
.876 .35816 Mdot
.876 .35818 Mdot
.876 .35852 Mdot
.876 .36004 Mdot
.876 .36093 Mdot
.876 .36107 Mdot
.876 .36253 Mdot
.876 .36333 Mdot
.876 .36395 Mdot
.876 .36398 Mdot
.876 .36401 Mdot
.876 .36414 Mdot
.876 .36431 Mdot
.876 .36457 Mdot
.876 .36465 Mdot
.876 .36492 Mdot
.876 .36502 Mdot
.876 .36503 Mdot
.876 .36567 Mdot
.876 .3657 Mdot
.876 .36777 Mdot
.876 .3678 Mdot
.876 .36859 Mdot
.876 .36873 Mdot
.876 .37053 Mdot
.876 .37096 Mdot
.876 .37135 Mdot
.876 .37173 Mdot
.876 .37191 Mdot
.876 .37193 Mdot
.876 .37216 Mdot
.876 .37295 Mdot
.876 .37394 Mdot
.876 .37405 Mdot
.876 .37426 Mdot
.876 .37566 Mdot
.876 .37678 Mdot
.876 .37719 Mdot
.876 .37751 Mdot
.876 .37772 Mdot
.876 .3779 Mdot
.876 .37851 Mdot
.876 .37859 Mdot
.876 .37897 Mdot
.876 .37916 Mdot
.876 .37918 Mdot
.876 .38101 Mdot
.876 .3812 Mdot
.876 .38144 Mdot
.876 .38162 Mdot
.876 .38298 Mdot
.876 .38347 Mdot
.876 .38376 Mdot
.876 .38452 Mdot
.876 .38463 Mdot
.876 .38543 Mdot
.876 .38653 Mdot
.876 .3866 Mdot
.876 .38866 Mdot
.876 .38868 Mdot
.876 .39018 Mdot
.876 .39018 Mdot
.876 .39091 Mdot
.876 .39118 Mdot
.876 .39173 Mdot
.876 .39207 Mdot
.876 .39227 Mdot
.876 .39446 Mdot
.876 .39535 Mdot
.876 .3955 Mdot
.876 .39675 Mdot
.876 .39676 Mdot
.876 .39701 Mdot
.876 .39772 Mdot
.876 .39829 Mdot
.876 .39841 Mdot
.876 .3985 Mdot
.876 .39909 Mdot
.876 .39932 Mdot
.876 .39982 Mdot
.876 .40061 Mdot
.876 .40187 Mdot
.876 .40248 Mdot
.876 .40329 Mdot
.876 .40354 Mdot
.876 .40385 Mdot
.876 .40507 Mdot
.876 .40647 Mdot
.876 .40738 Mdot
.876 .40753 Mdot
.876 .40768 Mdot
.876 .4082 Mdot
.876 .40925 Mdot
.876 .41239 Mdot
.876 .41336 Mdot
.876 .41391 Mdot
.876 .41392 Mdot
.876 .41438 Mdot
.876 .41549 Mdot
.876 .41574 Mdot
.876 .41679 Mdot
.876 .41714 Mdot
.876 .41825 Mdot
.876 .41893 Mdot
.876 .42133 Mdot
.876 .42417 Mdot
.876 .42418 Mdot
.876 .42419 Mdot
.876 .42452 Mdot
.876 .42891 Mdot
.876 .43037 Mdot
.876 .43223 Mdot
.876 .43562 Mdot
.876 .43569 Mdot
.876 .43586 Mdot
.876 .43612 Mdot
.876 .43707 Mdot
.876 .43802 Mdot
.876 .4406 Mdot
.876 .44139 Mdot
.876 .44208 Mdot
.876 .44286 Mdot
.876 .44379 Mdot
.876 .4438 Mdot
.876 .44534 Mdot
.876 .4476 Mdot
.876 .44768 Mdot
.876 .4483 Mdot
.876 .44914 Mdot
.876 .44963 Mdot
.876 .45069 Mdot
.876 .45208 Mdot
.876 .45391 Mdot
.876 .45416 Mdot
.876 .45499 Mdot
.876 .45524 Mdot
.876 .456 Mdot
.876 .45657 Mdot
.876 .45668 Mdot
.876 .45854 Mdot
.876 .45909 Mdot
.876 .45931 Mdot
.876 .46165 Mdot
.876 .46339 Mdot
.876 .46374 Mdot
.876 .46395 Mdot
.876 .46423 Mdot
.876 .46472 Mdot
.876 .46488 Mdot
.876 .46492 Mdot
.876 .46677 Mdot
.876 .46809 Mdot
.876 .46876 Mdot
.876 .46946 Mdot
.876 .47113 Mdot
.876 .4714 Mdot
.876 .47155 Mdot
.876 .47178 Mdot
.876 .4718 Mdot
.876 .47187 Mdot
.876 .47238 Mdot
.876 .47297 Mdot
.876 .47315 Mdot
.876 .47354 Mdot
.876 .47654 Mdot
.876 .47898 Mdot
.876 .47908 Mdot
.876 .47918 Mdot
.876 .48052 Mdot
.876 .48108 Mdot
.876 .48245 Mdot
.876 .4837 Mdot
.876 .48431 Mdot
.876 .48433 Mdot
.876 .48541 Mdot
.876 .48606 Mdot
.876 .48692 Mdot
.876 .48704 Mdot
.876 .48737 Mdot
.876 .48805 Mdot
.876 .48842 Mdot
.876 .48854 Mdot
.876 .48889 Mdot
.876 .48902 Mdot
.876 .48957 Mdot
.876 .49015 Mdot
.876 .49086 Mdot
.876 .4913 Mdot
.876 .49171 Mdot
.876 .49218 Mdot
.876 .49291 Mdot
.876 .49471 Mdot
.876 .4956 Mdot
.876 .49876 Mdot
.876 .49988 Mdot
.876 .50014 Mdot
.876 .50082 Mdot
.876 .50295 Mdot
.876 .50593 Mdot
.876 .50663 Mdot
.876 .5075 Mdot
.876 .50809 Mdot
.876 .50892 Mdot
.876 .50938 Mdot
.876 .50994 Mdot
.876 .51008 Mdot
.876 .51013 Mdot
.876 .51029 Mdot
.876 .51035 Mdot
.876 .51191 Mdot
.876 .51349 Mdot
.876 .51373 Mdot
.876 .51395 Mdot
.876 .51428 Mdot
.876 .51429 Mdot
.876 .51487 Mdot
.876 .5155 Mdot
.876 .51562 Mdot
.876 .51729 Mdot
.876 .51769 Mdot
.876 .51958 Mdot
.876 .51981 Mdot
.876 .52104 Mdot
.876 .52266 Mdot
.876 .52384 Mdot
.876 .5247 Mdot
.876 .52471 Mdot
.876 .52512 Mdot
.876 .52558 Mdot
.876 .52589 Mdot
.876 .52845 Mdot
.876 .5294 Mdot
.876 .52945 Mdot
.876 .53137 Mdot
.876 .53219 Mdot
.876 .53251 Mdot
.878 .01491 Mdot
.878 .01507 Mdot
.878 .01518 Mdot
.878 .01533 Mdot
.878 .01553 Mdot
.878 .0158 Mdot
.878 .01615 Mdot
.878 .01626 Mdot
.878 .01635 Mdot
.878 .01638 Mdot
.878 .01661 Mdot
.878 .01686 Mdot
.878 .01723 Mdot
.878 .01743 Mdot
.878 .01759 Mdot
.878 .01763 Mdot
.878 .01764 Mdot
.878 .01796 Mdot
.878 .01805 Mdot
.878 .01848 Mdot
.878 .01863 Mdot
.878 .01896 Mdot
.878 .01914 Mdot
.878 .01949 Mdot
.878 .01976 Mdot
.878 .01977 Mdot
.878 .01984 Mdot
.878 .01986 Mdot
.878 .02041 Mdot
.878 .02056 Mdot
.878 .02133 Mdot
.878 .0216 Mdot
.878 .02195 Mdot
.878 .02216 Mdot
.878 .02248 Mdot
.878 .02275 Mdot
.878 .02309 Mdot
.878 .02357 Mdot
.878 .02359 Mdot
.878 .02371 Mdot
.878 .02374 Mdot
.878 .02393 Mdot
.878 .02432 Mdot
.878 .02472 Mdot
.878 .02477 Mdot
.878 .02499 Mdot
.878 .02514 Mdot
.878 .02576 Mdot
.878 .02586 Mdot
.878 .02634 Mdot
.878 .0268 Mdot
.878 .02742 Mdot
.878 .02763 Mdot
.878 .02768 Mdot
.878 .02779 Mdot
.878 .02835 Mdot
.878 .02839 Mdot
.878 .02883 Mdot
.878 .02943 Mdot
.878 .03026 Mdot
.878 .03029 Mdot
.878 .03051 Mdot
.878 .03057 Mdot
.878 .0309 Mdot
.878 .03125 Mdot
.878 .03158 Mdot
.878 .03213 Mdot
.878 .03228 Mdot
.878 .03238 Mdot
.878 .03243 Mdot
.878 .03275 Mdot
.878 .03303 Mdot
.878 .03347 Mdot
.878 .03411 Mdot
.878 .03429 Mdot
.878 .03485 Mdot
.878 .03513 Mdot
.878 .03593 Mdot
.878 .03604 Mdot
.878 .03703 Mdot
.878 .0374 Mdot
.878 .03748 Mdot
.878 .03752 Mdot
.878 .03768 Mdot
.878 .03782 Mdot
.878 .03866 Mdot
.878 .03873 Mdot
.878 .0395 Mdot
.878 .0395 Mdot
.878 .04001 Mdot
.878 .04055 Mdot
.878 .04202 Mdot
.878 .04207 Mdot
.878 .04246 Mdot
.878 .04255 Mdot
.878 .04313 Mdot
.878 .04335 Mdot
.878 .04375 Mdot
.878 .04432 Mdot
.878 .04463 Mdot
.878 .04529 Mdot
.878 .04548 Mdot
.878 .04556 Mdot
.878 .04573 Mdot
.878 .04582 Mdot
.878 .04612 Mdot
.878 .04639 Mdot
.878 .04659 Mdot
.878 .04687 Mdot
.878 .04766 Mdot
.878 .04769 Mdot
.878 .04877 Mdot
.878 .04909 Mdot
.878 .04931 Mdot
.878 .05008 Mdot
.878 .05028 Mdot
.878 .05056 Mdot
.878 .05066 Mdot
.878 .05116 Mdot
.878 .05197 Mdot
.878 .05216 Mdot
.878 .05261 Mdot
.878 .05372 Mdot
.878 .05389 Mdot
.878 .0539 Mdot
.878 .05455 Mdot
.878 .05469 Mdot
.878 .05476 Mdot
.878 .05503 Mdot
.878 .0553 Mdot
.878 .05575 Mdot
.878 .05593 Mdot
.878 .05676 Mdot
.878 .05689 Mdot
.878 .05789 Mdot
.878 .05823 Mdot
.878 .05824 Mdot
.878 .05892 Mdot
.878 .05914 Mdot
.878 .06008 Mdot
.878 .06176 Mdot
.878 .0624 Mdot
.878 .06266 Mdot
.878 .06275 Mdot
.878 .06343 Mdot
.878 .0636 Mdot
.878 .06416 Mdot
.878 .06461 Mdot
.878 .06499 Mdot
.878 .06568 Mdot
.878 .0657 Mdot
.878 .06577 Mdot
.878 .06671 Mdot
.878 .06725 Mdot
.878 .0682 Mdot
.878 .06841 Mdot
.878 .06874 Mdot
.878 .06888 Mdot
.878 .06918 Mdot
.878 .06931 Mdot
.878 .06934 Mdot
.878 .06937 Mdot
.878 .06985 Mdot
.878 .07008 Mdot
.878 .07033 Mdot
.878 .07068 Mdot
.878 .07076 Mdot
.878 .07119 Mdot
.878 .07256 Mdot
.878 .07262 Mdot
.878 .07306 Mdot
.878 .07315 Mdot
.878 .07366 Mdot
.878 .07427 Mdot
.878 .07452 Mdot
.878 .07507 Mdot
.878 .07547 Mdot
.878 .07603 Mdot
.878 .07681 Mdot
.878 .07716 Mdot
.878 .07766 Mdot
.878 .07782 Mdot
.878 .07784 Mdot
.878 .07785 Mdot
.878 .07785 Mdot
.878 .07827 Mdot
.878 .07845 Mdot
.878 .07867 Mdot
.878 .0787 Mdot
.878 .07924 Mdot
.878 .07925 Mdot
.878 .08014 Mdot
.878 .08047 Mdot
.878 .0805 Mdot
.878 .08063 Mdot
.878 .08126 Mdot
.878 .08156 Mdot
.878 .08161 Mdot
.878 .08321 Mdot
.878 .08338 Mdot
.878 .0835 Mdot
.878 .08352 Mdot
.878 .08354 Mdot
.878 .08466 Mdot
.878 .08469 Mdot
.878 .0849 Mdot
.878 .08503 Mdot
.878 .08552 Mdot
.878 .08592 Mdot
.878 .08597 Mdot
.878 .08678 Mdot
.878 .08709 Mdot
.878 .08731 Mdot
.878 .08854 Mdot
.878 .08877 Mdot
.878 .08923 Mdot
.878 .08928 Mdot
.878 .09053 Mdot
.878 .09113 Mdot
.878 .09115 Mdot
.878 .09234 Mdot
.878 .09272 Mdot
.878 .09396 Mdot
.878 .0941 Mdot
.878 .09437 Mdot
.878 .0955 Mdot
.878 .09572 Mdot
.878 .09582 Mdot
.878 .09582 Mdot
.878 .09611 Mdot
.878 .09732 Mdot
.878 .09841 Mdot
.878 .09845 Mdot
.878 .0989 Mdot
.878 .09906 Mdot
.878 .09983 Mdot
.878 .10026 Mdot
.878 .10055 Mdot
.878 .10061 Mdot
.878 .10146 Mdot
.878 .10154 Mdot
.878 .10233 Mdot
.878 .10301 Mdot
.878 .10362 Mdot
.878 .10391 Mdot
.878 .1042 Mdot
.878 .10425 Mdot
.878 .10437 Mdot
.878 .10601 Mdot
.878 .10644 Mdot
.878 .10697 Mdot
.878 .10811 Mdot
.878 .10864 Mdot
.878 .10901 Mdot
.878 .10904 Mdot
.878 .10909 Mdot
.878 .10959 Mdot
.878 .10983 Mdot
.878 .11008 Mdot
.878 .11023 Mdot
.878 .11035 Mdot
.878 .11058 Mdot
.878 .11064 Mdot
.878 .11069 Mdot
.878 .11154 Mdot
.878 .11194 Mdot
.878 .11238 Mdot
.878 .11299 Mdot
.878 .113 Mdot
.878 .11313 Mdot
.878 .11388 Mdot
.878 .11487 Mdot
.878 .11528 Mdot
.878 .11613 Mdot
.878 .11629 Mdot
.878 .1164 Mdot
.878 .11717 Mdot
.878 .11724 Mdot
.878 .11734 Mdot
.878 .1176 Mdot
.878 .11781 Mdot
.878 .11822 Mdot
.878 .11929 Mdot
.878 .11974 Mdot
.878 .12069 Mdot
.878 .1207 Mdot
.878 .12096 Mdot
.878 .1214 Mdot
.878 .12227 Mdot
.878 .12238 Mdot
.878 .12252 Mdot
.878 .12376 Mdot
.878 .12401 Mdot
.878 .12438 Mdot
.878 .12524 Mdot
.878 .12527 Mdot
.878 .12553 Mdot
.878 .12557 Mdot
.878 .12558 Mdot
.878 .12558 Mdot
.878 .12564 Mdot
.878 .12633 Mdot
.878 .12647 Mdot
.878 .12663 Mdot
.878 .12703 Mdot
.878 .12708 Mdot
.878 .12803 Mdot
.878 .12803 Mdot
.878 .12822 Mdot
.878 .12824 Mdot
.878 .12961 Mdot
.878 .13018 Mdot
.878 .13023 Mdot
.878 .13047 Mdot
.878 .13109 Mdot
.878 .13157 Mdot
.878 .13157 Mdot
.878 .1321 Mdot
.878 .13219 Mdot
.878 .13333 Mdot
.878 .1341 Mdot
.878 .13476 Mdot
.878 .13498 Mdot
.878 .13529 Mdot
.878 .13548 Mdot
.878 .1355 Mdot
.878 .13554 Mdot
.878 .13557 Mdot
.878 .13755 Mdot
.878 .13759 Mdot
.878 .13775 Mdot
.878 .13797 Mdot
.878 .13818 Mdot
.878 .13904 Mdot
.878 .13976 Mdot
.878 .13985 Mdot
.878 .14055 Mdot
.878 .14126 Mdot
.878 .1418 Mdot
.878 .14196 Mdot
.878 .14218 Mdot
.878 .14291 Mdot
.878 .14307 Mdot
.878 .14435 Mdot
.878 .14476 Mdot
.878 .14502 Mdot
.878 .14551 Mdot
.878 .14557 Mdot
.878 .14564 Mdot
.878 .14672 Mdot
.878 .14784 Mdot
.878 .1484 Mdot
.878 .14881 Mdot
.878 .14889 Mdot
.878 .14894 Mdot
.878 .14938 Mdot
.878 .14951 Mdot
.878 .14973 Mdot
.878 .14992 Mdot
.878 .15027 Mdot
.878 .15043 Mdot
.878 .15102 Mdot
.878 .15169 Mdot
.878 .15184 Mdot
.878 .152 Mdot
.878 .15411 Mdot
.878 .15456 Mdot
.878 .15459 Mdot
.878 .15658 Mdot
.878 .15696 Mdot
.878 .15713 Mdot
.878 .15713 Mdot
.878 .15755 Mdot
.878 .15764 Mdot
.878 .15777 Mdot
.878 .1581 Mdot
.878 .15862 Mdot
.878 .15903 Mdot
.878 .1594 Mdot
.878 .15977 Mdot
.878 .15998 Mdot
.878 .16039 Mdot
.878 .16059 Mdot
.878 .16081 Mdot
.878 .16169 Mdot
.878 .16169 Mdot
.878 .16175 Mdot
.878 .16176 Mdot
.878 .16254 Mdot
.878 .16283 Mdot
.878 .16287 Mdot
.878 .16404 Mdot
.878 .16418 Mdot
.878 .16493 Mdot
.878 .16544 Mdot
.878 .16555 Mdot
.878 .16704 Mdot
.878 .16719 Mdot
.878 .16782 Mdot
.878 .16856 Mdot
.878 .16868 Mdot
.878 .16933 Mdot
.878 .16975 Mdot
.878 .17023 Mdot
.878 .17084 Mdot
.878 .17135 Mdot
.878 .17185 Mdot
.878 .17185 Mdot
.878 .17194 Mdot
.878 .17215 Mdot
.878 .17257 Mdot
.878 .17305 Mdot
.878 .17503 Mdot
.878 .17579 Mdot
.878 .17606 Mdot
.878 .17655 Mdot
.878 .17671 Mdot
.878 .17684 Mdot
.878 .17845 Mdot
.878 .17871 Mdot
.878 .17965 Mdot
.878 .18029 Mdot
.878 .18035 Mdot
.878 .18043 Mdot
.878 .18049 Mdot
.878 .18068 Mdot
.878 .18131 Mdot
.878 .18147 Mdot
.878 .18174 Mdot
.878 .18218 Mdot
.878 .18243 Mdot
.878 .18265 Mdot
.878 .18306 Mdot
.878 .18316 Mdot
.878 .18325 Mdot
.878 .1836 Mdot
.878 .18364 Mdot
.878 .18405 Mdot
.878 .18437 Mdot
.878 .18447 Mdot
.878 .18474 Mdot
.878 .18545 Mdot
.878 .18571 Mdot
.878 .18609 Mdot
.878 .18621 Mdot
.878 .18668 Mdot
.878 .18729 Mdot
.878 .1873 Mdot
.878 .18753 Mdot
.878 .18884 Mdot
.878 .18963 Mdot
.878 .19049 Mdot
.878 .19059 Mdot
.878 .1913 Mdot
.878 .1928 Mdot
.878 .19308 Mdot
.878 .19328 Mdot
.878 .19463 Mdot
.878 .19476 Mdot
.878 .19492 Mdot
.878 .19539 Mdot
.878 .19575 Mdot
.878 .19646 Mdot
.878 .19743 Mdot
.878 .19835 Mdot
.878 .19913 Mdot
.878 .19962 Mdot
.878 .2008 Mdot
.878 .20082 Mdot
.878 .20105 Mdot
.878 .20127 Mdot
.878 .20205 Mdot
.878 .20357 Mdot
.878 .20371 Mdot
.878 .20377 Mdot
.878 .20402 Mdot
.878 .20403 Mdot
.878 .20443 Mdot
.878 .20619 Mdot
.878 .20664 Mdot
.878 .20728 Mdot
.878 .2088 Mdot
.878 .20884 Mdot
.878 .2093 Mdot
.878 .20937 Mdot
.878 .2094 Mdot
.878 .2094 Mdot
.878 .20949 Mdot
.878 .21024 Mdot
.878 .2107 Mdot
.878 .21096 Mdot
.878 .21123 Mdot
.878 .21193 Mdot
.878 .21203 Mdot
.878 .21369 Mdot
.878 .2137 Mdot
.878 .21403 Mdot
.878 .21407 Mdot
.878 .21635 Mdot
.878 .21647 Mdot
.878 .21747 Mdot
.878 .21755 Mdot
.878 .21798 Mdot
.878 .21907 Mdot
.878 .21934 Mdot
.878 .21991 Mdot
.878 .21992 Mdot
.878 .22084 Mdot
.878 .221 Mdot
.878 .22156 Mdot
.878 .22182 Mdot
.878 .22203 Mdot
.878 .22226 Mdot
.878 .223 Mdot
.878 .22436 Mdot
.878 .22467 Mdot
.878 .22536 Mdot
.878 .22552 Mdot
.878 .22591 Mdot
.878 .22645 Mdot
.878 .22658 Mdot
.878 .22677 Mdot
.878 .22681 Mdot
.878 .22689 Mdot
.878 .22694 Mdot
.878 .22757 Mdot
.878 .22942 Mdot
.878 .22949 Mdot
.878 .2299 Mdot
.878 .23034 Mdot
.878 .23041 Mdot
.878 .23048 Mdot
.878 .23076 Mdot
.878 .23115 Mdot
.878 .23153 Mdot
.878 .23303 Mdot
.878 .23353 Mdot
.878 .23429 Mdot
.878 .23445 Mdot
.878 .23568 Mdot
.878 .23692 Mdot
.878 .23718 Mdot
.878 .23788 Mdot
.878 .23801 Mdot
.878 .23815 Mdot
.878 .23855 Mdot
.878 .23867 Mdot
.878 .23887 Mdot
.878 .23982 Mdot
.878 .2401 Mdot
.878 .24235 Mdot
.878 .24307 Mdot
.878 .24353 Mdot
.878 .24439 Mdot
.878 .24449 Mdot
.878 .24462 Mdot
.878 .24651 Mdot
.878 .24849 Mdot
.878 .24946 Mdot
.878 .25018 Mdot
.878 .25026 Mdot
.878 .25033 Mdot
.878 .25041 Mdot
.878 .25119 Mdot
.878 .25141 Mdot
.878 .25181 Mdot
.878 .25213 Mdot
.878 .25273 Mdot
.878 .25275 Mdot
.878 .25288 Mdot
.878 .25303 Mdot
.878 .25406 Mdot
.878 .25524 Mdot
.878 .25551 Mdot
.878 .25573 Mdot
.878 .25579 Mdot
.878 .25949 Mdot
.878 .26029 Mdot
.878 .26034 Mdot
.878 .26126 Mdot
.878 .26305 Mdot
.878 .26364 Mdot
.878 .26382 Mdot
.878 .2645 Mdot
.878 .2648 Mdot
.878 .2648 Mdot
.878 .26553 Mdot
.878 .2657 Mdot
.878 .26572 Mdot
.878 .26591 Mdot
.878 .26649 Mdot
.878 .26664 Mdot
.878 .26666 Mdot
.878 .26741 Mdot
.878 .26813 Mdot
.878 .26878 Mdot
.878 .2689 Mdot
.878 .26941 Mdot
.878 .26943 Mdot
.878 .26947 Mdot
.878 .26979 Mdot
.878 .27008 Mdot
.878 .27052 Mdot
.878 .27088 Mdot
.878 .27126 Mdot
.878 .27186 Mdot
.878 .27233 Mdot
.878 .27237 Mdot
.878 .27281 Mdot
.878 .27281 Mdot
.878 .27292 Mdot
.878 .27293 Mdot
.878 .2743 Mdot
.878 .27469 Mdot
.878 .2748 Mdot
.878 .27488 Mdot
.878 .27692 Mdot
.878 .27693 Mdot
.878 .27718 Mdot
.878 .2785 Mdot
.878 .27892 Mdot
.878 .27929 Mdot
.878 .27939 Mdot
.878 .27959 Mdot
.878 .28085 Mdot
.878 .28091 Mdot
.878 .28105 Mdot
.878 .28204 Mdot
.878 .2822 Mdot
.878 .28245 Mdot
.878 .28293 Mdot
.878 .28357 Mdot
.878 .28428 Mdot
.878 .28487 Mdot
.878 .28508 Mdot
.878 .28538 Mdot
.878 .28622 Mdot
.878 .28657 Mdot
.878 .28696 Mdot
.878 .2878 Mdot
.878 .28842 Mdot
.878 .28887 Mdot
.878 .28976 Mdot
.878 .28987 Mdot
.878 .28999 Mdot
.878 .29064 Mdot
.878 .29065 Mdot
.878 .2908 Mdot
.878 .29116 Mdot
.878 .29133 Mdot
.878 .29134 Mdot
.878 .29167 Mdot
.878 .2917 Mdot
.878 .29191 Mdot
.878 .29275 Mdot
.878 .29593 Mdot
.878 .29624 Mdot
.878 .29714 Mdot
.878 .29749 Mdot
.878 .29756 Mdot
.878 .29772 Mdot
.878 .29803 Mdot
.878 .2989 Mdot
.878 .29917 Mdot
.878 .29941 Mdot
.878 .30223 Mdot
.878 .30269 Mdot
.878 .30402 Mdot
.878 .30405 Mdot
.878 .30434 Mdot
.878 .30482 Mdot
.878 .30547 Mdot
.878 .30557 Mdot
.878 .30571 Mdot
.878 .30582 Mdot
.878 .30615 Mdot
.878 .30726 Mdot
.878 .30754 Mdot
.878 .30801 Mdot
.878 .30879 Mdot
.878 .30888 Mdot
.878 .30923 Mdot
.878 .3096 Mdot
.878 .31018 Mdot
.878 .31032 Mdot
.878 .31051 Mdot
.878 .31066 Mdot
.878 .31128 Mdot
.878 .31133 Mdot
.878 .31134 Mdot
.878 .31162 Mdot
.878 .31206 Mdot
.878 .31224 Mdot
.878 .31263 Mdot
.878 .31281 Mdot
.878 .31327 Mdot
.878 .31452 Mdot
.878 .31497 Mdot
.878 .31564 Mdot
.878 .31586 Mdot
.878 .31612 Mdot
.878 .31634 Mdot
.878 .31669 Mdot
.878 .31674 Mdot
.878 .31775 Mdot
.878 .31778 Mdot
.878 .31818 Mdot
.878 .31981 Mdot
.878 .32031 Mdot
.878 .32049 Mdot
.878 .32108 Mdot
.878 .32186 Mdot
.878 .32254 Mdot
.878 .32338 Mdot
.878 .32356 Mdot
.878 .32451 Mdot
.878 .3248 Mdot
.878 .3267 Mdot
.878 .32743 Mdot
.878 .32792 Mdot
.878 .32828 Mdot
.878 .32855 Mdot
.878 .32918 Mdot
.878 .3301 Mdot
.878 .33065 Mdot
.878 .33087 Mdot
.878 .33115 Mdot
.878 .33198 Mdot
.878 .33261 Mdot
.878 .3327 Mdot
.878 .33377 Mdot
.878 .33387 Mdot
.878 .33498 Mdot
.878 .33557 Mdot
.878 .33718 Mdot
.878 .33755 Mdot
.878 .33855 Mdot
.878 .33942 Mdot
.878 .33947 Mdot
.878 .34086 Mdot
.878 .34149 Mdot
.878 .34152 Mdot
.878 .34193 Mdot
.878 .34231 Mdot
.878 .34362 Mdot
.878 .34368 Mdot
.878 .34396 Mdot
.878 .34431 Mdot
.878 .34633 Mdot
.878 .34635 Mdot
.878 .34635 Mdot
.878 .34659 Mdot
.878 .34669 Mdot
.878 .34682 Mdot
.878 .34714 Mdot
.878 .34715 Mdot
.878 .34786 Mdot
.878 .34794 Mdot
.878 .34846 Mdot
.878 .34849 Mdot
.878 .3495 Mdot
.878 .34959 Mdot
.878 .35024 Mdot
.878 .35095 Mdot
.878 .35173 Mdot
.878 .35283 Mdot
.878 .35286 Mdot
.878 .35552 Mdot
.878 .3556 Mdot
.878 .3564 Mdot
.878 .35653 Mdot
.878 .35658 Mdot
.878 .35658 Mdot
.878 .35675 Mdot
.878 .35806 Mdot
.878 .35887 Mdot
.878 .35931 Mdot
.878 .3598 Mdot
.878 .36103 Mdot
.878 .36119 Mdot
.878 .36263 Mdot
.878 .36358 Mdot
.878 .36411 Mdot
.878 .36414 Mdot
.878 .36471 Mdot
.878 .36479 Mdot
.878 .36637 Mdot
.878 .36743 Mdot
.878 .36766 Mdot
.878 .36815 Mdot
.878 .36878 Mdot
.878 .36899 Mdot
.878 .36911 Mdot
.878 .37075 Mdot
.878 .3709 Mdot
.878 .37164 Mdot
.878 .37179 Mdot
.878 .37264 Mdot
.878 .37335 Mdot
.878 .37356 Mdot
.878 .37404 Mdot
.878 .37503 Mdot
.878 .37505 Mdot
.878 .37667 Mdot
.878 .37694 Mdot
.878 .37794 Mdot
.878 .37839 Mdot
.878 .37876 Mdot
.878 .37917 Mdot
.878 .38046 Mdot
.878 .38205 Mdot
.878 .38286 Mdot
.878 .3834 Mdot
.878 .38349 Mdot
.878 .3846 Mdot
.878 .38488 Mdot
.878 .38557 Mdot
.878 .38652 Mdot
.878 .38676 Mdot
.878 .38709 Mdot
.878 .38716 Mdot
.878 .38729 Mdot
.878 .38739 Mdot
.878 .38759 Mdot
.878 .38768 Mdot
.878 .38849 Mdot
.878 .38858 Mdot
.878 .39004 Mdot
.878 .39174 Mdot
.878 .39186 Mdot
.878 .39205 Mdot
.878 .39235 Mdot
.878 .39258 Mdot
.878 .39279 Mdot
.878 .39312 Mdot
.878 .39335 Mdot
.878 .39347 Mdot
.878 .39359 Mdot
.878 .3941 Mdot
.878 .39413 Mdot
.878 .39477 Mdot
.878 .39543 Mdot
.878 .39759 Mdot
.878 .39808 Mdot
.878 .39845 Mdot
.878 .39896 Mdot
.878 .39988 Mdot
.878 .40029 Mdot
.878 .40056 Mdot
.878 .40228 Mdot
.878 .40256 Mdot
.878 .40272 Mdot
.878 .40364 Mdot
.878 .4048 Mdot
.878 .40491 Mdot
.878 .40536 Mdot
.878 .40657 Mdot
.878 .40659 Mdot
.878 .40683 Mdot
.878 .40701 Mdot
.878 .40707 Mdot
.878 .40777 Mdot
.878 .40799 Mdot
.878 .40833 Mdot
.878 .41001 Mdot
.878 .4105 Mdot
.878 .41445 Mdot
.878 .4157 Mdot
.878 .41651 Mdot
.878 .41802 Mdot
.878 .4182 Mdot
.878 .41843 Mdot
.878 .42174 Mdot
.878 .42522 Mdot
.878 .42693 Mdot
.878 .42819 Mdot
.878 .42834 Mdot
.878 .42846 Mdot
.878 .42859 Mdot
.878 .42996 Mdot
.878 .43035 Mdot
.878 .43105 Mdot
.878 .43161 Mdot
.878 .43267 Mdot
.878 .43271 Mdot
.878 .43294 Mdot
.878 .43319 Mdot
.878 .43501 Mdot
.878 .43708 Mdot
.878 .43756 Mdot
.878 .43794 Mdot
.878 .43805 Mdot
.878 .44453 Mdot
.878 .44594 Mdot
.878 .44603 Mdot
.878 .44765 Mdot
.878 .4508 Mdot
.878 .45182 Mdot
.878 .45215 Mdot
.878 .45334 Mdot
.878 .45386 Mdot
.878 .45387 Mdot
.878 .45515 Mdot
.878 .45544 Mdot
.878 .45547 Mdot
.878 .45582 Mdot
.878 .45683 Mdot
.878 .4571 Mdot
.878 .45712 Mdot
.878 .45845 Mdot
.878 .45972 Mdot
.878 .46085 Mdot
.878 .46107 Mdot
.878 .46195 Mdot
.878 .46199 Mdot
.878 .46207 Mdot
.878 .46263 Mdot
.878 .46314 Mdot
.878 .4639 Mdot
.878 .46453 Mdot
.878 .46521 Mdot
.878 .46626 Mdot
.878 .46709 Mdot
.878 .46716 Mdot
.878 .46792 Mdot
.878 .46793 Mdot
.878 .46812 Mdot
.878 .46813 Mdot
.878 .47054 Mdot
.878 .47123 Mdot
.878 .47143 Mdot
.878 .47156 Mdot
.878 .47515 Mdot
.878 .47517 Mdot
.878 .4756 Mdot
.878 .47791 Mdot
.878 .47866 Mdot
.878 .47931 Mdot
.878 .47948 Mdot
.878 .47983 Mdot
.878 .48204 Mdot
.878 .48216 Mdot
.878 .48239 Mdot
.878 .48414 Mdot
.878 .48443 Mdot
.878 .48486 Mdot
.878 .48569 Mdot
.878 .48682 Mdot
.878 .48807 Mdot
.878 .48912 Mdot
.878 .48947 Mdot
.878 .49 Mdot
.878 .49148 Mdot
.878 .49209 Mdot
.878 .49278 Mdot
.878 .49424 Mdot
.878 .49534 Mdot
.878 .49613 Mdot
.878 .4977 Mdot
.878 .49789 Mdot
.878 .49809 Mdot
.878 .49924 Mdot
.878 .49925 Mdot
.878 .49952 Mdot
.878 .50016 Mdot
.878 .50046 Mdot
.878 .50047 Mdot
.878 .50105 Mdot
.878 .5011 Mdot
.878 .50147 Mdot
.878 .50295 Mdot
.878 .50853 Mdot
.878 .50907 Mdot
.878 .51065 Mdot
.878 .51126 Mdot
.878 .51139 Mdot
.878 .51167 Mdot
.878 .51221 Mdot
.878 .51374 Mdot
.878 .51422 Mdot
.878 .51463 Mdot
.878 .51959 Mdot
.878 .5204 Mdot
.878 .52274 Mdot
.878 .52279 Mdot
.878 .5233 Mdot
.878 .52413 Mdot
.878 .52528 Mdot
.878 .52545 Mdot
.878 .5257 Mdot
.878 .52589 Mdot
.878 .52647 Mdot
.878 .52843 Mdot
.878 .52892 Mdot
.878 .52974 Mdot
.878 .5311 Mdot
.878 .53126 Mdot
.878 .53188 Mdot
.878 .53254 Mdot
.878 .53355 Mdot
.878 .5338 Mdot
.88 .01545 Mdot
.88 .01571 Mdot
.88 .01602 Mdot
.88 .01622 Mdot
.88 .01646 Mdot
.88 .01658 Mdot
.88 .01677 Mdot
.88 .01681 Mdot
.88 .017 Mdot
.88 .01736 Mdot
.88 .01779 Mdot
.88 .018 Mdot
.88 .01834 Mdot
.88 .0184 Mdot
.88 .01874 Mdot
.88 .01881 Mdot
.88 .01897 Mdot
.88 .01936 Mdot
.88 .01978 Mdot
.88 .02012 Mdot
.88 .02049 Mdot
.88 .02109 Mdot
.88 .02121 Mdot
.88 .0218 Mdot
.88 .02193 Mdot
.88 .0222 Mdot
.88 .02248 Mdot
.88 .0229 Mdot
.88 .02352 Mdot
.88 .02364 Mdot
.88 .02378 Mdot
.88 .02423 Mdot
.88 .02488 Mdot
.88 .02496 Mdot
.88 .02502 Mdot
.88 .02509 Mdot
.88 .02571 Mdot
.88 .0258 Mdot
.88 .02594 Mdot
.88 .02614 Mdot
.88 .02719 Mdot
.88 .02741 Mdot
.88 .02788 Mdot
.88 .02838 Mdot
.88 .02895 Mdot
.88 .02908 Mdot
.88 .02912 Mdot
.88 .02993 Mdot
.88 .03022 Mdot
.88 .03032 Mdot
.88 .03041 Mdot
.88 .03067 Mdot
.88 .03127 Mdot
.88 .03146 Mdot
.88 .0326 Mdot
.88 .0327 Mdot
.88 .03275 Mdot
.88 .03285 Mdot
.88 .03293 Mdot
.88 .03298 Mdot
.88 .03335 Mdot
.88 .0335 Mdot
.88 .03407 Mdot
.88 .03423 Mdot
.88 .03447 Mdot
.88 .0348 Mdot
.88 .03483 Mdot
.88 .03559 Mdot
.88 .03583 Mdot
.88 .03592 Mdot
.88 .03628 Mdot
.88 .03667 Mdot
.88 .03671 Mdot
.88 .03706 Mdot
.88 .03707 Mdot
.88 .03744 Mdot
.88 .03789 Mdot
.88 .03857 Mdot
.88 .03876 Mdot
.88 .03978 Mdot
.88 .03989 Mdot
.88 .03999 Mdot
.88 .04006 Mdot
.88 .04075 Mdot
.88 .04115 Mdot
.88 .0415 Mdot
.88 .042 Mdot
.88 .04219 Mdot
.88 .04235 Mdot
.88 .04273 Mdot
.88 .0428 Mdot
.88 .04285 Mdot
.88 .04385 Mdot
.88 .04406 Mdot
.88 .04418 Mdot
.88 .04615 Mdot
.88 .04619 Mdot
.88 .04637 Mdot
.88 .04646 Mdot
.88 .04663 Mdot
.88 .04677 Mdot
.88 .04685 Mdot
.88 .04751 Mdot
.88 .04765 Mdot
.88 .04767 Mdot
.88 .04778 Mdot
.88 .04788 Mdot
.88 .04821 Mdot
.88 .04877 Mdot
.88 .04887 Mdot
.88 .04905 Mdot
.88 .04947 Mdot
.88 .04949 Mdot
.88 .05007 Mdot
.88 .05011 Mdot
.88 .05013 Mdot
.88 .05056 Mdot
.88 .05063 Mdot
.88 .05086 Mdot
.88 .05146 Mdot
.88 .05187 Mdot
.88 .05203 Mdot
.88 .05267 Mdot
.88 .05273 Mdot
.88 .05274 Mdot
.88 .05336 Mdot
.88 .05342 Mdot
.88 .05405 Mdot
.88 .05407 Mdot
.88 .05442 Mdot
.88 .05471 Mdot
.88 .05551 Mdot
.88 .05669 Mdot
.88 .05703 Mdot
.88 .05882 Mdot
.88 .05903 Mdot
.88 .0592 Mdot
.88 .05932 Mdot
.88 .05968 Mdot
.88 .05995 Mdot
.88 .06 Mdot
.88 .06053 Mdot
.88 .06124 Mdot
.88 .06169 Mdot
.88 .06186 Mdot
.88 .06252 Mdot
.88 .06273 Mdot
.88 .06306 Mdot
.88 .06334 Mdot
.88 .06403 Mdot
.88 .06415 Mdot
.88 .06423 Mdot
.88 .06497 Mdot
.88 .0651 Mdot
.88 .06552 Mdot
.88 .06599 Mdot
.88 .06599 Mdot
.88 .06635 Mdot
.88 .06658 Mdot
.88 .06755 Mdot
.88 .0678 Mdot
.88 .06915 Mdot
.88 .06948 Mdot
.88 .06987 Mdot
.88 .07003 Mdot
.88 .07011 Mdot
.88 .07043 Mdot
.88 .07058 Mdot
.88 .07089 Mdot
.88 .07113 Mdot
.88 .07115 Mdot
.88 .07128 Mdot
.88 .07132 Mdot
.88 .07223 Mdot
.88 .07244 Mdot
.88 .07257 Mdot
.88 .07269 Mdot
.88 .07272 Mdot
.88 .07291 Mdot
.88 .07309 Mdot
.88 .07367 Mdot
.88 .0742 Mdot
.88 .07462 Mdot
.88 .07466 Mdot
.88 .07483 Mdot
.88 .07515 Mdot
.88 .07588 Mdot
.88 .07592 Mdot
.88 .07592 Mdot
.88 .07602 Mdot
.88 .07694 Mdot
.88 .07701 Mdot
.88 .07704 Mdot
.88 .07781 Mdot
.88 .07793 Mdot
.88 .07811 Mdot
.88 .07817 Mdot
.88 .07832 Mdot
.88 .07938 Mdot
.88 .08011 Mdot
.88 .08039 Mdot
.88 .08119 Mdot
.88 .08151 Mdot
.88 .08152 Mdot
.88 .0816 Mdot
.88 .08162 Mdot
.88 .08163 Mdot
.88 .08164 Mdot
.88 .08254 Mdot
.88 .08274 Mdot
.88 .08284 Mdot
.88 .08379 Mdot
.88 .08394 Mdot
.88 .08397 Mdot
.88 .0846 Mdot
.88 .0851 Mdot
.88 .08651 Mdot
.88 .08804 Mdot
.88 .08836 Mdot
.88 .08848 Mdot
.88 .08859 Mdot
.88 .08919 Mdot
.88 .0914 Mdot
.88 .09209 Mdot
.88 .09234 Mdot
.88 .09235 Mdot
.88 .0925 Mdot
.88 .09271 Mdot
.88 .09301 Mdot
.88 .09322 Mdot
.88 .09385 Mdot
.88 .09434 Mdot
.88 .09442 Mdot
.88 .09535 Mdot
.88 .09594 Mdot
.88 .09661 Mdot
.88 .09694 Mdot
.88 .09695 Mdot
.88 .09739 Mdot
.88 .09768 Mdot
.88 .09886 Mdot
.88 .09922 Mdot
.88 .09955 Mdot
.88 .09971 Mdot
.88 .09981 Mdot
.88 .1003 Mdot
.88 .10084 Mdot
.88 .1015 Mdot
.88 .10172 Mdot
.88 .10186 Mdot
.88 .10235 Mdot
.88 .10245 Mdot
.88 .1026 Mdot
.88 .10317 Mdot
.88 .10319 Mdot
.88 .1034 Mdot
.88 .10413 Mdot
.88 .10464 Mdot
.88 .10496 Mdot
.88 .10496 Mdot
.88 .1056 Mdot
.88 .106 Mdot
.88 .10771 Mdot
.88 .10808 Mdot
.88 .10814 Mdot
.88 .11051 Mdot
.88 .1111 Mdot
.88 .11159 Mdot
.88 .11179 Mdot
.88 .11207 Mdot
.88 .1122 Mdot
.88 .11278 Mdot
.88 .11296 Mdot
.88 .11303 Mdot
.88 .11321 Mdot
.88 .11359 Mdot
.88 .114 Mdot
.88 .11404 Mdot
.88 .11413 Mdot
.88 .11427 Mdot
.88 .11434 Mdot
.88 .11454 Mdot
.88 .11479 Mdot
.88 .11502 Mdot
.88 .11594 Mdot
.88 .11621 Mdot
.88 .11631 Mdot
.88 .11654 Mdot
.88 .11675 Mdot
.88 .1168 Mdot
.88 .11714 Mdot
.88 .11715 Mdot
.88 .11745 Mdot
.88 .11848 Mdot
.88 .11941 Mdot
.88 .11991 Mdot
.88 .12015 Mdot
.88 .12022 Mdot
.88 .12052 Mdot
.88 .12108 Mdot
.88 .12181 Mdot
.88 .12236 Mdot
.88 .12244 Mdot
.88 .12244 Mdot
.88 .12261 Mdot
.88 .12424 Mdot
.88 .12436 Mdot
.88 .12441 Mdot
.88 .12444 Mdot
.88 .12573 Mdot
.88 .12576 Mdot
.88 .12597 Mdot
.88 .12629 Mdot
.88 .1264 Mdot
.88 .12666 Mdot
.88 .1284 Mdot
.88 .12853 Mdot
.88 .12981 Mdot
.88 .1303 Mdot
.88 .13171 Mdot
.88 .13215 Mdot
.88 .13227 Mdot
.88 .13229 Mdot
.88 .13244 Mdot
.88 .13246 Mdot
.88 .13248 Mdot
.88 .13251 Mdot
.88 .13331 Mdot
.88 .13354 Mdot
.88 .13408 Mdot
.88 .13443 Mdot
.88 .13454 Mdot
.88 .13462 Mdot
.88 .13519 Mdot
.88 .13531 Mdot
.88 .13611 Mdot
.88 .13626 Mdot
.88 .13629 Mdot
.88 .13634 Mdot
.88 .13651 Mdot
.88 .13656 Mdot
.88 .13661 Mdot
.88 .13771 Mdot
.88 .13859 Mdot
.88 .14047 Mdot
.88 .14085 Mdot
.88 .14107 Mdot
.88 .1421 Mdot
.88 .14295 Mdot
.88 .14377 Mdot
.88 .14434 Mdot
.88 .14453 Mdot
.88 .14474 Mdot
.88 .14508 Mdot
.88 .1458 Mdot
.88 .14693 Mdot
.88 .147 Mdot
.88 .14756 Mdot
.88 .14802 Mdot
.88 .14881 Mdot
.88 .14969 Mdot
.88 .15089 Mdot
.88 .15113 Mdot
.88 .15134 Mdot
.88 .15135 Mdot
.88 .15162 Mdot
.88 .15179 Mdot
.88 .15199 Mdot
.88 .1521 Mdot
.88 .15251 Mdot
.88 .15289 Mdot
.88 .15399 Mdot
.88 .15485 Mdot
.88 .15499 Mdot
.88 .15506 Mdot
.88 .15508 Mdot
.88 .15606 Mdot
.88 .15616 Mdot
.88 .15663 Mdot
.88 .15696 Mdot
.88 .15714 Mdot
.88 .15738 Mdot
.88 .15767 Mdot
.88 .1583 Mdot
.88 .1584 Mdot
.88 .15856 Mdot
.88 .15884 Mdot
.88 .15886 Mdot
.88 .15944 Mdot
.88 .15944 Mdot
.88 .16022 Mdot
.88 .16074 Mdot
.88 .16164 Mdot
.88 .16175 Mdot
.88 .16273 Mdot
.88 .16281 Mdot
.88 .16333 Mdot
.88 .16344 Mdot
.88 .16402 Mdot
.88 .1643 Mdot
.88 .16448 Mdot
.88 .16483 Mdot
.88 .16535 Mdot
.88 .1663 Mdot
.88 .1665 Mdot
.88 .16746 Mdot
.88 .16784 Mdot
.88 .1681 Mdot
.88 .16896 Mdot
.88 .16912 Mdot
.88 .16939 Mdot
.88 .16964 Mdot
.88 .1704 Mdot
.88 .17044 Mdot
.88 .17079 Mdot
.88 .17208 Mdot
.88 .17209 Mdot
.88 .17298 Mdot
.88 .17354 Mdot
.88 .17355 Mdot
.88 .17464 Mdot
.88 .17467 Mdot
.88 .17537 Mdot
.88 .17677 Mdot
.88 .17838 Mdot
.88 .17903 Mdot
.88 .17903 Mdot
.88 .17914 Mdot
.88 .17989 Mdot
.88 .18189 Mdot
.88 .18195 Mdot
.88 .18199 Mdot
.88 .18252 Mdot
.88 .18304 Mdot
.88 .1832 Mdot
.88 .18332 Mdot
.88 .18339 Mdot
.88 .18435 Mdot
.88 .18522 Mdot
.88 .18556 Mdot
.88 .18602 Mdot
.88 .18607 Mdot
.88 .18629 Mdot
.88 .18731 Mdot
.88 .18735 Mdot
.88 .18763 Mdot
.88 .18775 Mdot
.88 .18806 Mdot
.88 .18852 Mdot
.88 .18873 Mdot
.88 .18878 Mdot
.88 .18946 Mdot
.88 .18953 Mdot
.88 .18956 Mdot
.88 .18968 Mdot
.88 .18982 Mdot
.88 .18993 Mdot
.88 .19005 Mdot
.88 .19042 Mdot
.88 .19084 Mdot
.88 .19125 Mdot
.88 .19286 Mdot
.88 .19335 Mdot
.88 .19342 Mdot
.88 .19353 Mdot
.88 .19393 Mdot
.88 .19429 Mdot
.88 .19431 Mdot
.88 .19438 Mdot
.88 .19499 Mdot
.88 .19499 Mdot
.88 .19553 Mdot
.88 .19723 Mdot
.88 .19734 Mdot
.88 .19788 Mdot
.88 .19898 Mdot
.88 .19985 Mdot
.88 .20029 Mdot
.88 .2004 Mdot
.88 .20052 Mdot
.88 .20093 Mdot
.88 .20099 Mdot
.88 .20192 Mdot
.88 .20206 Mdot
.88 .20248 Mdot
.88 .20318 Mdot
.88 .2032 Mdot
.88 .20418 Mdot
.88 .20431 Mdot
.88 .20432 Mdot
.88 .20461 Mdot
.88 .20502 Mdot
.88 .20747 Mdot
.88 .20769 Mdot
.88 .20778 Mdot
.88 .20783 Mdot
.88 .20894 Mdot
.88 .20926 Mdot
.88 .2101 Mdot
.88 .21015 Mdot
.88 .21052 Mdot
.88 .21109 Mdot
.88 .21128 Mdot
.88 .21174 Mdot
.88 .21481 Mdot
.88 .21502 Mdot
.88 .2151 Mdot
.88 .21548 Mdot
.88 .21578 Mdot
.88 .21729 Mdot
.88 .21814 Mdot
.88 .21855 Mdot
.88 .21942 Mdot
.88 .22063 Mdot
.88 .22107 Mdot
.88 .2214 Mdot
.88 .22161 Mdot
.88 .22165 Mdot
.88 .22191 Mdot
.88 .22195 Mdot
.88 .22198 Mdot
.88 .22203 Mdot
.88 .22344 Mdot
.88 .22384 Mdot
.88 .2248 Mdot
.88 .2254 Mdot
.88 .22542 Mdot
.88 .2256 Mdot
.88 .22575 Mdot
.88 .22675 Mdot
.88 .22697 Mdot
.88 .22707 Mdot
.88 .22838 Mdot
.88 .22864 Mdot
.88 .22869 Mdot
.88 .22877 Mdot
.88 .22907 Mdot
.88 .22915 Mdot
.88 .22925 Mdot
.88 .23015 Mdot
.88 .2305 Mdot
.88 .23118 Mdot
.88 .23172 Mdot
.88 .23273 Mdot
.88 .23435 Mdot
.88 .23604 Mdot
.88 .2367 Mdot
.88 .23672 Mdot
.88 .23711 Mdot
.88 .23802 Mdot
.88 .23891 Mdot
.88 .23916 Mdot
.88 .23924 Mdot
.88 .24041 Mdot
.88 .24069 Mdot
.88 .24164 Mdot
.88 .24185 Mdot
.88 .2427 Mdot
.88 .24285 Mdot
.88 .2432 Mdot
.88 .24333 Mdot
.88 .24356 Mdot
.88 .24415 Mdot
.88 .24542 Mdot
.88 .24552 Mdot
.88 .24741 Mdot
.88 .24753 Mdot
.88 .24763 Mdot
.88 .24852 Mdot
.88 .2488 Mdot
.88 .24933 Mdot
.88 .25073 Mdot
.88 .25127 Mdot
.88 .25226 Mdot
.88 .25238 Mdot
.88 .25277 Mdot
.88 .25362 Mdot
.88 .25438 Mdot
.88 .25481 Mdot
.88 .25517 Mdot
.88 .2552 Mdot
.88 .25567 Mdot
.88 .25597 Mdot
.88 .25632 Mdot
.88 .25652 Mdot
.88 .25723 Mdot
.88 .25791 Mdot
.88 .25829 Mdot
.88 .25908 Mdot
.88 .25944 Mdot
.88 .25957 Mdot
.88 .25984 Mdot
.88 .26135 Mdot
.88 .26161 Mdot
.88 .26172 Mdot
.88 .26176 Mdot
.88 .26349 Mdot
.88 .26365 Mdot
.88 .26449 Mdot
.88 .26491 Mdot
.88 .26506 Mdot
.88 .26538 Mdot
.88 .26542 Mdot
.88 .26581 Mdot
.88 .26632 Mdot
.88 .26742 Mdot
.88 .2676 Mdot
.88 .26789 Mdot
.88 .26802 Mdot
.88 .26838 Mdot
.88 .26842 Mdot
.88 .26931 Mdot
.88 .26943 Mdot
.88 .26943 Mdot
.88 .26979 Mdot
.88 .27078 Mdot
.88 .2708 Mdot
.88 .2709 Mdot
.88 .27172 Mdot
.88 .27211 Mdot
.88 .2733 Mdot
.88 .2735 Mdot
.88 .27368 Mdot
.88 .27521 Mdot
.88 .27536 Mdot
.88 .27628 Mdot
.88 .27647 Mdot
.88 .27709 Mdot
.88 .2775 Mdot
.88 .27767 Mdot
.88 .27799 Mdot
.88 .27831 Mdot
.88 .27855 Mdot
.88 .27892 Mdot
.88 .27895 Mdot
.88 .27983 Mdot
.88 .28006 Mdot
.88 .28019 Mdot
.88 .28151 Mdot
.88 .28186 Mdot
.88 .28295 Mdot
.88 .28331 Mdot
.88 .28333 Mdot
.88 .28355 Mdot
.88 .28421 Mdot
.88 .28444 Mdot
.88 .28467 Mdot
.88 .28619 Mdot
.88 .28647 Mdot
.88 .28694 Mdot
.88 .28739 Mdot
.88 .28749 Mdot
.88 .28758 Mdot
.88 .28786 Mdot
.88 .28872 Mdot
.88 .28878 Mdot
.88 .28942 Mdot
.88 .29042 Mdot
.88 .29162 Mdot
.88 .29168 Mdot
.88 .2917 Mdot
.88 .29325 Mdot
.88 .29425 Mdot
.88 .29426 Mdot
.88 .2953 Mdot
.88 .29594 Mdot
.88 .29619 Mdot
.88 .29624 Mdot
.88 .29648 Mdot
.88 .29747 Mdot
.88 .29992 Mdot
.88 .30124 Mdot
.88 .30169 Mdot
.88 .30277 Mdot
.88 .30391 Mdot
.88 .30392 Mdot
.88 .3041 Mdot
.88 .30453 Mdot
.88 .30514 Mdot
.88 .30543 Mdot
.88 .30704 Mdot
.88 .30789 Mdot
.88 .30831 Mdot
.88 .30884 Mdot
.88 .30895 Mdot
.88 .30905 Mdot
.88 .30911 Mdot
.88 .30984 Mdot
.88 .31005 Mdot
.88 .31082 Mdot
.88 .31096 Mdot
.88 .31125 Mdot
.88 .31146 Mdot
.88 .31157 Mdot
.88 .31159 Mdot
.88 .31273 Mdot
.88 .31281 Mdot
.88 .31328 Mdot
.88 .31481 Mdot
.88 .3154 Mdot
.88 .31555 Mdot
.88 .31622 Mdot
.88 .31625 Mdot
.88 .31629 Mdot
.88 .31664 Mdot
.88 .31669 Mdot
.88 .31849 Mdot
.88 .31856 Mdot
.88 .31904 Mdot
.88 .31926 Mdot
.88 .3198 Mdot
.88 .32062 Mdot
.88 .32074 Mdot
.88 .32098 Mdot
.88 .32107 Mdot
.88 .32181 Mdot
.88 .32226 Mdot
.88 .32239 Mdot
.88 .32244 Mdot
.88 .32265 Mdot
.88 .32289 Mdot
.88 .3231 Mdot
.88 .32331 Mdot
.88 .32395 Mdot
.88 .3247 Mdot
.88 .32519 Mdot
.88 .32542 Mdot
.88 .32632 Mdot
.88 .32638 Mdot
.88 .32707 Mdot
.88 .32825 Mdot
.88 .32911 Mdot
.88 .32912 Mdot
.88 .32924 Mdot
.88 .32943 Mdot
.88 .3298 Mdot
.88 .33014 Mdot
.88 .33052 Mdot
.88 .33076 Mdot
.88 .3308 Mdot
.88 .33093 Mdot
.88 .33199 Mdot
.88 .332 Mdot
.88 .33296 Mdot
.88 .33594 Mdot
.88 .3361 Mdot
.88 .33613 Mdot
.88 .33709 Mdot
.88 .33756 Mdot
.88 .33895 Mdot
.88 .33903 Mdot
.88 .33926 Mdot
.88 .33953 Mdot
.88 .34042 Mdot
.88 .34056 Mdot
.88 .34132 Mdot
.88 .34151 Mdot
.88 .34173 Mdot
.88 .34246 Mdot
.88 .34256 Mdot
.88 .34307 Mdot
.88 .34327 Mdot
.88 .3442 Mdot
.88 .34444 Mdot
.88 .34517 Mdot
.88 .34523 Mdot
.88 .34642 Mdot
.88 .34645 Mdot
.88 .34817 Mdot
.88 .34835 Mdot
.88 .3484 Mdot
.88 .34841 Mdot
.88 .34893 Mdot
.88 .34965 Mdot
.88 .35206 Mdot
.88 .35224 Mdot
.88 .35231 Mdot
.88 .35397 Mdot
.88 .35436 Mdot
.88 .35451 Mdot
.88 .35459 Mdot
.88 .35655 Mdot
.88 .35712 Mdot
.88 .35712 Mdot
.88 .3586 Mdot
.88 .35869 Mdot
.88 .35933 Mdot
.88 .36019 Mdot
.88 .36024 Mdot
.88 .36033 Mdot
.88 .36067 Mdot
.88 .36149 Mdot
.88 .36344 Mdot
.88 .36544 Mdot
.88 .36622 Mdot
.88 .36636 Mdot
.88 .36688 Mdot
.88 .36712 Mdot
.88 .36726 Mdot
.88 .36739 Mdot
.88 .36807 Mdot
.88 .36859 Mdot
.88 .37016 Mdot
.88 .37125 Mdot
.88 .37274 Mdot
.88 .37347 Mdot
.88 .37499 Mdot
.88 .37712 Mdot
.88 .37778 Mdot
.88 .37791 Mdot
.88 .37848 Mdot
.88 .37885 Mdot
.88 .37892 Mdot
.88 .37937 Mdot
.88 .37946 Mdot
.88 .3795 Mdot
.88 .3796 Mdot
.88 .38185 Mdot
.88 .38206 Mdot
.88 .38277 Mdot
.88 .38326 Mdot
.88 .38447 Mdot
.88 .38552 Mdot
.88 .38556 Mdot
.88 .38588 Mdot
.88 .38614 Mdot
.88 .38659 Mdot
.88 .3879 Mdot
.88 .38828 Mdot
.88 .38846 Mdot
.88 .39014 Mdot
.88 .39015 Mdot
.88 .39071 Mdot
.88 .39076 Mdot
.88 .39122 Mdot
.88 .39132 Mdot
.88 .39146 Mdot
.88 .39198 Mdot
.88 .39204 Mdot
.88 .39213 Mdot
.88 .3923 Mdot
.88 .39387 Mdot
.88 .39394 Mdot
.88 .39449 Mdot
.88 .39484 Mdot
.88 .39569 Mdot
.88 .39664 Mdot
.88 .39842 Mdot
.88 .39982 Mdot
.88 .40127 Mdot
.88 .40247 Mdot
.88 .40376 Mdot
.88 .40425 Mdot
.88 .40538 Mdot
.88 .40541 Mdot
.88 .40544 Mdot
.88 .40574 Mdot
.88 .40603 Mdot
.88 .40613 Mdot
.88 .40624 Mdot
.88 .40773 Mdot
.88 .40849 Mdot
.88 .40915 Mdot
.88 .4093 Mdot
.88 .40974 Mdot
.88 .40989 Mdot
.88 .41193 Mdot
.88 .41244 Mdot
.88 .4141 Mdot
.88 .41447 Mdot
.88 .41597 Mdot
.88 .41623 Mdot
.88 .41684 Mdot
.88 .41708 Mdot
.88 .41748 Mdot
.88 .41852 Mdot
.88 .42075 Mdot
.88 .42093 Mdot
.88 .42425 Mdot
.88 .42447 Mdot
.88 .42464 Mdot
.88 .42621 Mdot
.88 .4267 Mdot
.88 .42765 Mdot
.88 .4301 Mdot
.88 .43105 Mdot
.88 .4328 Mdot
.88 .433 Mdot
.88 .43369 Mdot
.88 .43519 Mdot
.88 .43653 Mdot
.88 .43727 Mdot
.88 .43792 Mdot
.88 .43797 Mdot
.88 .43879 Mdot
.88 .43933 Mdot
.88 .43993 Mdot
.88 .44029 Mdot
.88 .44154 Mdot
.88 .44273 Mdot
.88 .4434 Mdot
.88 .4448 Mdot
.88 .44543 Mdot
.88 .44565 Mdot
.88 .44614 Mdot
.88 .44879 Mdot
.88 .44924 Mdot
.88 .44944 Mdot
.88 .44952 Mdot
.88 .45255 Mdot
.88 .45284 Mdot
.88 .45432 Mdot
.88 .45505 Mdot
.88 .45532 Mdot
.88 .45589 Mdot
.88 .45595 Mdot
.88 .45664 Mdot
.88 .45753 Mdot
.88 .45947 Mdot
.88 .4598 Mdot
.88 .4603 Mdot
.88 .46053 Mdot
.88 .46116 Mdot
.88 .46123 Mdot
.88 .4628 Mdot
.88 .46301 Mdot
.88 .46302 Mdot
.88 .46365 Mdot
.88 .46538 Mdot
.88 .46543 Mdot
.88 .46559 Mdot
.88 .46705 Mdot
.88 .46773 Mdot
.88 .46982 Mdot
.88 .47018 Mdot
.88 .47049 Mdot
.88 .47319 Mdot
.88 .47345 Mdot
.88 .47506 Mdot
.88 .47541 Mdot
.88 .47649 Mdot
.88 .47721 Mdot
.88 .47751 Mdot
.88 .47808 Mdot
.88 .47864 Mdot
.88 .47906 Mdot
.88 .47972 Mdot
.88 .47977 Mdot
.88 .48132 Mdot
.88 .48172 Mdot
.88 .48195 Mdot
.88 .48428 Mdot
.88 .48488 Mdot
.88 .4868 Mdot
.88 .48744 Mdot
.88 .48748 Mdot
.88 .48787 Mdot
.88 .48903 Mdot
.88 .48942 Mdot
.88 .48983 Mdot
.88 .493 Mdot
.88 .49383 Mdot
.88 .49462 Mdot
.88 .4948 Mdot
.88 .49495 Mdot
.88 .49545 Mdot
.88 .49696 Mdot
.88 .49707 Mdot
.88 .49819 Mdot
.88 .49996 Mdot
.88 .50207 Mdot
.88 .50217 Mdot
.88 .50221 Mdot
.88 .50494 Mdot
.88 .50669 Mdot
.88 .50672 Mdot
.88 .50854 Mdot
.88 .50967 Mdot
.88 .51011 Mdot
.88 .51019 Mdot
.88 .51062 Mdot
.88 .51236 Mdot
.88 .51668 Mdot
.88 .51899 Mdot
.88 .51979 Mdot
.88 .52169 Mdot
.88 .5237 Mdot
.88 .52371 Mdot
.88 .52403 Mdot
.88 .52478 Mdot
.88 .52587 Mdot
.88 .52637 Mdot
.88 .5292 Mdot
.88 .53071 Mdot
.88 .53144 Mdot
.88 .53237 Mdot
.88 .53257 Mdot
.88 .53274 Mdot
.88 .53285 Mdot
.88 .53413 Mdot
.88 .53451 Mdot
.882 .01488 Mdot
.882 .01501 Mdot
.882 .0152 Mdot
.882 .01523 Mdot
.882 .01556 Mdot
.882 .01563 Mdot
.882 .01615 Mdot
.882 .01621 Mdot
.882 .01633 Mdot
.882 .01724 Mdot
.882 .01736 Mdot
.882 .01756 Mdot
.882 .01781 Mdot
.882 .01868 Mdot
.882 .01917 Mdot
.882 .01918 Mdot
.882 .01937 Mdot
.882 .01974 Mdot
.882 .01987 Mdot
.882 .02018 Mdot
.882 .02171 Mdot
.882 .02258 Mdot
.882 .02258 Mdot
.882 .02293 Mdot
.882 .02357 Mdot
.882 .0238 Mdot
.882 .02397 Mdot
.882 .02436 Mdot
.882 .0245 Mdot
.882 .02511 Mdot
.882 .02549 Mdot
.882 .02573 Mdot
.882 .02624 Mdot
.882 .02642 Mdot
.882 .0265 Mdot
.882 .02691 Mdot
.882 .02706 Mdot
.882 .02858 Mdot
.882 .0286 Mdot
.882 .02862 Mdot
.882 .02881 Mdot
.882 .02894 Mdot
.882 .0292 Mdot
.882 .02921 Mdot
.882 .03006 Mdot
.882 .03034 Mdot
.882 .03074 Mdot
.882 .03104 Mdot
.882 .03172 Mdot
.882 .03197 Mdot
.882 .03201 Mdot
.882 .03283 Mdot
.882 .03302 Mdot
.882 .03305 Mdot
.882 .0334 Mdot
.882 .03372 Mdot
.882 .03415 Mdot
.882 .03423 Mdot
.882 .03491 Mdot
.882 .035 Mdot
.882 .03505 Mdot
.882 .03537 Mdot
.882 .03551 Mdot
.882 .03622 Mdot
.882 .03637 Mdot
.882 .03649 Mdot
.882 .03759 Mdot
.882 .03774 Mdot
.882 .03784 Mdot
.882 .03788 Mdot
.882 .03871 Mdot
.882 .03905 Mdot
.882 .03918 Mdot
.882 .0392 Mdot
.882 .03924 Mdot
.882 .03959 Mdot
.882 .03981 Mdot
.882 .04027 Mdot
.882 .04028 Mdot
.882 .04032 Mdot
.882 .04067 Mdot
.882 .04106 Mdot
.882 .04126 Mdot
.882 .04178 Mdot
.882 .04178 Mdot
.882 .04227 Mdot
.882 .04252 Mdot
.882 .04299 Mdot
.882 .04335 Mdot
.882 .04351 Mdot
.882 .04361 Mdot
.882 .04471 Mdot
.882 .04476 Mdot
.882 .04484 Mdot
.882 .04515 Mdot
.882 .04523 Mdot
.882 .04548 Mdot
.882 .04594 Mdot
.882 .04609 Mdot
.882 .04668 Mdot
.882 .047 Mdot
.882 .04705 Mdot
.882 .04708 Mdot
.882 .04723 Mdot
.882 .04768 Mdot
.882 .04811 Mdot
.882 .04824 Mdot
.882 .04853 Mdot
.882 .04899 Mdot
.882 .04914 Mdot
.882 .05034 Mdot
.882 .0505 Mdot
.882 .05059 Mdot
.882 .05086 Mdot
.882 .05115 Mdot
.882 .05138 Mdot
.882 .05139 Mdot
.882 .05265 Mdot
.882 .05292 Mdot
.882 .05295 Mdot
.882 .05312 Mdot
.882 .05508 Mdot
.882 .05533 Mdot
.882 .0555 Mdot
.882 .05558 Mdot
.882 .05567 Mdot
.882 .05614 Mdot
.882 .05651 Mdot
.882 .05704 Mdot
.882 .05765 Mdot
.882 .05786 Mdot
.882 .05791 Mdot
.882 .05798 Mdot
.882 .05859 Mdot
.882 .05898 Mdot
.882 .05979 Mdot
.882 .05982 Mdot
.882 .05989 Mdot
.882 .06051 Mdot
.882 .06119 Mdot
.882 .06154 Mdot
.882 .06245 Mdot
.882 .06245 Mdot
.882 .06332 Mdot
.882 .06343 Mdot
.882 .06352 Mdot
.882 .06376 Mdot
.882 .06458 Mdot
.882 .06523 Mdot
.882 .06552 Mdot
.882 .06568 Mdot
.882 .06571 Mdot
.882 .06737 Mdot
.882 .06748 Mdot
.882 .06763 Mdot
.882 .06772 Mdot
.882 .06786 Mdot
.882 .06814 Mdot
.882 .06841 Mdot
.882 .06853 Mdot
.882 .0686 Mdot
.882 .0689 Mdot
.882 .06899 Mdot
.882 .06959 Mdot
.882 .06979 Mdot
.882 .0698 Mdot
.882 .07005 Mdot
.882 .07068 Mdot
.882 .0711 Mdot
.882 .07154 Mdot
.882 .07166 Mdot
.882 .07176 Mdot
.882 .07181 Mdot
.882 .07203 Mdot
.882 .07207 Mdot
.882 .07286 Mdot
.882 .07362 Mdot
.882 .07385 Mdot
.882 .07436 Mdot
.882 .07506 Mdot
.882 .07518 Mdot
.882 .07545 Mdot
.882 .07554 Mdot
.882 .07558 Mdot
.882 .07581 Mdot
.882 .07663 Mdot
.882 .07701 Mdot
.882 .07744 Mdot
.882 .07755 Mdot
.882 .07785 Mdot
.882 .078 Mdot
.882 .07848 Mdot
.882 .07861 Mdot
.882 .07863 Mdot
.882 .07899 Mdot
.882 .07939 Mdot
.882 .07941 Mdot
.882 .08024 Mdot
.882 .08118 Mdot
.882 .08164 Mdot
.882 .0821 Mdot
.882 .08211 Mdot
.882 .08216 Mdot
.882 .08246 Mdot
.882 .08247 Mdot
.882 .08385 Mdot
.882 .08474 Mdot
.882 .0855 Mdot
.882 .08591 Mdot
.882 .08636 Mdot
.882 .08666 Mdot
.882 .08679 Mdot
.882 .08697 Mdot
.882 .08769 Mdot
.882 .08778 Mdot
.882 .08807 Mdot
.882 .08843 Mdot
.882 .08938 Mdot
.882 .09045 Mdot
.882 .09083 Mdot
.882 .09091 Mdot
.882 .09104 Mdot
.882 .0912 Mdot
.882 .09211 Mdot
.882 .09266 Mdot
.882 .0928 Mdot
.882 .09301 Mdot
.882 .09424 Mdot
.882 .09428 Mdot
.882 .0944 Mdot
.882 .09503 Mdot
.882 .09541 Mdot
.882 .09549 Mdot
.882 .09627 Mdot
.882 .0967 Mdot
.882 .09732 Mdot
.882 .09892 Mdot
.882 .09893 Mdot
.882 .1003 Mdot
.882 .10046 Mdot
.882 .10052 Mdot
.882 .10064 Mdot
.882 .10081 Mdot
.882 .10124 Mdot
.882 .10152 Mdot
.882 .10157 Mdot
.882 .10268 Mdot
.882 .1037 Mdot
.882 .10382 Mdot
.882 .10433 Mdot
.882 .1044 Mdot
.882 .10462 Mdot
.882 .10466 Mdot
.882 .10493 Mdot
.882 .10589 Mdot
.882 .10607 Mdot
.882 .10649 Mdot
.882 .10759 Mdot
.882 .10779 Mdot
.882 .10806 Mdot
.882 .10821 Mdot
.882 .10847 Mdot
.882 .10865 Mdot
.882 .10896 Mdot
.882 .10942 Mdot
.882 .10943 Mdot
.882 .10965 Mdot
.882 .10977 Mdot
.882 .1103 Mdot
.882 .11046 Mdot
.882 .11055 Mdot
.882 .11152 Mdot
.882 .11184 Mdot
.882 .11187 Mdot
.882 .11188 Mdot
.882 .11196 Mdot
.882 .11227 Mdot
.882 .11233 Mdot
.882 .11253 Mdot
.882 .11289 Mdot
.882 .11307 Mdot
.882 .11343 Mdot
.882 .11396 Mdot
.882 .11417 Mdot
.882 .1148 Mdot
.882 .11495 Mdot
.882 .11517 Mdot
.882 .11534 Mdot
.882 .11543 Mdot
.882 .11545 Mdot
.882 .11582 Mdot
.882 .1159 Mdot
.882 .11728 Mdot
.882 .11861 Mdot
.882 .11863 Mdot
.882 .11903 Mdot
.882 .11933 Mdot
.882 .11955 Mdot
.882 .11977 Mdot
.882 .11993 Mdot
.882 .12018 Mdot
.882 .12082 Mdot
.882 .12117 Mdot
.882 .12138 Mdot
.882 .12185 Mdot
.882 .12201 Mdot
.882 .12208 Mdot
.882 .12249 Mdot
.882 .12394 Mdot
.882 .1246 Mdot
.882 .12537 Mdot
.882 .12556 Mdot
.882 .12608 Mdot
.882 .12635 Mdot
.882 .1272 Mdot
.882 .12743 Mdot
.882 .12745 Mdot
.882 .12751 Mdot
.882 .12756 Mdot
.882 .12762 Mdot
.882 .12809 Mdot
.882 .1288 Mdot
.882 .12884 Mdot
.882 .1303 Mdot
.882 .13031 Mdot
.882 .13195 Mdot
.882 .13277 Mdot
.882 .13339 Mdot
.882 .13359 Mdot
.882 .13359 Mdot
.882 .13368 Mdot
.882 .13422 Mdot
.882 .13423 Mdot
.882 .13665 Mdot
.882 .13666 Mdot
.882 .13736 Mdot
.882 .13824 Mdot
.882 .13917 Mdot
.882 .13958 Mdot
.882 .14016 Mdot
.882 .1403 Mdot
.882 .14058 Mdot
.882 .1411 Mdot
.882 .14112 Mdot
.882 .14162 Mdot
.882 .14186 Mdot
.882 .14217 Mdot
.882 .14345 Mdot
.882 .1436 Mdot
.882 .14411 Mdot
.882 .14457 Mdot
.882 .14475 Mdot
.882 .14562 Mdot
.882 .14565 Mdot
.882 .14613 Mdot
.882 .14643 Mdot
.882 .14756 Mdot
.882 .14831 Mdot
.882 .14898 Mdot
.882 .1491 Mdot
.882 .14911 Mdot
.882 .14912 Mdot
.882 .14917 Mdot
.882 .14936 Mdot
.882 .14963 Mdot
.882 .15124 Mdot
.882 .15194 Mdot
.882 .15221 Mdot
.882 .15245 Mdot
.882 .15283 Mdot
.882 .15499 Mdot
.882 .15507 Mdot
.882 .15527 Mdot
.882 .15639 Mdot
.882 .15707 Mdot
.882 .15721 Mdot
.882 .15859 Mdot
.882 .15867 Mdot
.882 .15934 Mdot
.882 .15936 Mdot
.882 .15941 Mdot
.882 .16026 Mdot
.882 .16043 Mdot
.882 .16047 Mdot
.882 .16111 Mdot
.882 .16244 Mdot
.882 .16251 Mdot
.882 .16275 Mdot
.882 .16311 Mdot
.882 .16326 Mdot
.882 .16327 Mdot
.882 .16334 Mdot
.882 .16554 Mdot
.882 .16562 Mdot
.882 .16569 Mdot
.882 .16584 Mdot
.882 .16597 Mdot
.882 .16608 Mdot
.882 .16629 Mdot
.882 .16633 Mdot
.882 .16659 Mdot
.882 .16671 Mdot
.882 .16734 Mdot
.882 .16739 Mdot
.882 .16784 Mdot
.882 .16792 Mdot
.882 .16984 Mdot
.882 .16989 Mdot
.882 .17 Mdot
.882 .17021 Mdot
.882 .17114 Mdot
.882 .17169 Mdot
.882 .1719 Mdot
.882 .1728 Mdot
.882 .17292 Mdot
.882 .17331 Mdot
.882 .17339 Mdot
.882 .17385 Mdot
.882 .17434 Mdot
.882 .1745 Mdot
.882 .17554 Mdot
.882 .17586 Mdot
.882 .17627 Mdot
.882 .1766 Mdot
.882 .17748 Mdot
.882 .17854 Mdot
.882 .17855 Mdot
.882 .17889 Mdot
.882 .17937 Mdot
.882 .17964 Mdot
.882 .18009 Mdot
.882 .18042 Mdot
.882 .18096 Mdot
.882 .18122 Mdot
.882 .18168 Mdot
.882 .18177 Mdot
.882 .1818 Mdot
.882 .18219 Mdot
.882 .18239 Mdot
.882 .18249 Mdot
.882 .18279 Mdot
.882 .18333 Mdot
.882 .18361 Mdot
.882 .18377 Mdot
.882 .18399 Mdot
.882 .18531 Mdot
.882 .18548 Mdot
.882 .18567 Mdot
.882 .18587 Mdot
.882 .18604 Mdot
.882 .1861 Mdot
.882 .18612 Mdot
.882 .18625 Mdot
.882 .1868 Mdot
.882 .18687 Mdot
.882 .18691 Mdot
.882 .18699 Mdot
.882 .18727 Mdot
.882 .18789 Mdot
.882 .18816 Mdot
.882 .18822 Mdot
.882 .18885 Mdot
.882 .18973 Mdot
.882 .18976 Mdot
.882 .18978 Mdot
.882 .19016 Mdot
.882 .19056 Mdot
.882 .19087 Mdot
.882 .19103 Mdot
.882 .19127 Mdot
.882 .19154 Mdot
.882 .19192 Mdot
.882 .19222 Mdot
.882 .19237 Mdot
.882 .19242 Mdot
.882 .19274 Mdot
.882 .19307 Mdot
.882 .1932 Mdot
.882 .19462 Mdot
.882 .19565 Mdot
.882 .19799 Mdot
.882 .19802 Mdot
.882 .19872 Mdot
.882 .19926 Mdot
.882 .19965 Mdot
.882 .19975 Mdot
.882 .20004 Mdot
.882 .20032 Mdot
.882 .2006 Mdot
.882 .20075 Mdot
.882 .20188 Mdot
.882 .20197 Mdot
.882 .20249 Mdot
.882 .20287 Mdot
.882 .20339 Mdot
.882 .20369 Mdot
.882 .20399 Mdot
.882 .20411 Mdot
.882 .20484 Mdot
.882 .20591 Mdot
.882 .20691 Mdot
.882 .20738 Mdot
.882 .20855 Mdot
.882 .20991 Mdot
.882 .21025 Mdot
.882 .21116 Mdot
.882 .21163 Mdot
.882 .21169 Mdot
.882 .21183 Mdot
.882 .21313 Mdot
.882 .21355 Mdot
.882 .21359 Mdot
.882 .21369 Mdot
.882 .21377 Mdot
.882 .21388 Mdot
.882 .21394 Mdot
.882 .2145 Mdot
.882 .21471 Mdot
.882 .21595 Mdot
.882 .21603 Mdot
.882 .2161 Mdot
.882 .21858 Mdot
.882 .2186 Mdot
.882 .21862 Mdot
.882 .22152 Mdot
.882 .22233 Mdot
.882 .22265 Mdot
.882 .22296 Mdot
.882 .22407 Mdot
.882 .2244 Mdot
.882 .22441 Mdot
.882 .22457 Mdot
.882 .22552 Mdot
.882 .22555 Mdot
.882 .22643 Mdot
.882 .22911 Mdot
.882 .22981 Mdot
.882 .22983 Mdot
.882 .2301 Mdot
.882 .2308 Mdot
.882 .23083 Mdot
.882 .2309 Mdot
.882 .23106 Mdot
.882 .23118 Mdot
.882 .23219 Mdot
.882 .23261 Mdot
.882 .23368 Mdot
.882 .23425 Mdot
.882 .23498 Mdot
.882 .23599 Mdot
.882 .23625 Mdot
.882 .23673 Mdot
.882 .23766 Mdot
.882 .2377 Mdot
.882 .23858 Mdot
.882 .239 Mdot
.882 .23954 Mdot
.882 .2418 Mdot
.882 .24207 Mdot
.882 .24251 Mdot
.882 .24297 Mdot
.882 .24378 Mdot
.882 .2441 Mdot
.882 .24564 Mdot
.882 .24568 Mdot
.882 .24636 Mdot
.882 .24654 Mdot
.882 .24705 Mdot
.882 .24785 Mdot
.882 .24906 Mdot
.882 .24916 Mdot
.882 .25037 Mdot
.882 .25123 Mdot
.882 .25155 Mdot
.882 .25178 Mdot
.882 .25179 Mdot
.882 .25181 Mdot
.882 .2519 Mdot
.882 .25222 Mdot
.882 .2527 Mdot
.882 .25554 Mdot
.882 .25678 Mdot
.882 .25726 Mdot
.882 .25768 Mdot
.882 .25834 Mdot
.882 .26216 Mdot
.882 .2623 Mdot
.882 .26266 Mdot
.882 .2631 Mdot
.882 .26353 Mdot
.882 .26463 Mdot
.882 .26466 Mdot
.882 .26583 Mdot
.882 .26604 Mdot
.882 .26607 Mdot
.882 .26737 Mdot
.882 .2685 Mdot
.882 .26864 Mdot
.882 .26983 Mdot
.882 .26987 Mdot
.882 .26995 Mdot
.882 .27079 Mdot
.882 .27088 Mdot
.882 .27146 Mdot
.882 .27175 Mdot
.882 .27182 Mdot
.882 .27295 Mdot
.882 .27452 Mdot
.882 .27517 Mdot
.882 .27527 Mdot
.882 .27531 Mdot
.882 .27543 Mdot
.882 .27584 Mdot
.882 .27649 Mdot
.882 .27675 Mdot
.882 .27676 Mdot
.882 .27689 Mdot
.882 .27932 Mdot
.882 .28076 Mdot
.882 .28091 Mdot
.882 .28104 Mdot
.882 .2813 Mdot
.882 .28153 Mdot
.882 .28173 Mdot
.882 .28209 Mdot
.882 .28216 Mdot
.882 .28262 Mdot
.882 .28283 Mdot
.882 .28285 Mdot
.882 .28328 Mdot
.882 .28394 Mdot
.882 .28404 Mdot
.882 .28482 Mdot
.882 .28497 Mdot
.882 .28697 Mdot
.882 .28709 Mdot
.882 .28735 Mdot
.882 .28835 Mdot
.882 .28845 Mdot
.882 .28864 Mdot
.882 .289 Mdot
.882 .28995 Mdot
.882 .29025 Mdot
.882 .29065 Mdot
.882 .29162 Mdot
.882 .29199 Mdot
.882 .29206 Mdot
.882 .29295 Mdot
.882 .29317 Mdot
.882 .29357 Mdot
.882 .29379 Mdot
.882 .29447 Mdot
.882 .29461 Mdot
.882 .29544 Mdot
.882 .29629 Mdot
.882 .29657 Mdot
.882 .29669 Mdot
.882 .29842 Mdot
.882 .29898 Mdot
.882 .2997 Mdot
.882 .30029 Mdot
.882 .30156 Mdot
.882 .30184 Mdot
.882 .30358 Mdot
.882 .30371 Mdot
.882 .30372 Mdot
.882 .30391 Mdot
.882 .30403 Mdot
.882 .30433 Mdot
.882 .30439 Mdot
.882 .30517 Mdot
.882 .30565 Mdot
.882 .30568 Mdot
.882 .30644 Mdot
.882 .30701 Mdot
.882 .30769 Mdot
.882 .30798 Mdot
.882 .30844 Mdot
.882 .3085 Mdot
.882 .30854 Mdot
.882 .30896 Mdot
.882 .30925 Mdot
.882 .30939 Mdot
.882 .30945 Mdot
.882 .31013 Mdot
.882 .31049 Mdot
.882 .31067 Mdot
.882 .31121 Mdot
.882 .31215 Mdot
.882 .31264 Mdot
.882 .31293 Mdot
.882 .31332 Mdot
.882 .31564 Mdot
.882 .31594 Mdot
.882 .31629 Mdot
.882 .3165 Mdot
.882 .31664 Mdot
.882 .31693 Mdot
.882 .31703 Mdot
.882 .31708 Mdot
.882 .31731 Mdot
.882 .31828 Mdot
.882 .31839 Mdot
.882 .31846 Mdot
.882 .31861 Mdot
.882 .31909 Mdot
.882 .3202 Mdot
.882 .32067 Mdot
.882 .32077 Mdot
.882 .32099 Mdot
.882 .32146 Mdot
.882 .32184 Mdot
.882 .3219 Mdot
.882 .32267 Mdot
.882 .32337 Mdot
.882 .32345 Mdot
.882 .3235 Mdot
.882 .32353 Mdot
.882 .324 Mdot
.882 .32419 Mdot
.882 .32491 Mdot
.882 .32511 Mdot
.882 .32533 Mdot
.882 .32544 Mdot
.882 .32574 Mdot
.882 .32616 Mdot
.882 .32663 Mdot
.882 .32678 Mdot
.882 .3273 Mdot
.882 .32743 Mdot
.882 .32748 Mdot
.882 .32784 Mdot
.882 .3281 Mdot
.882 .32818 Mdot
.882 .32874 Mdot
.882 .32883 Mdot
.882 .32933 Mdot
.882 .32956 Mdot
.882 .33089 Mdot
.882 .33118 Mdot
.882 .33207 Mdot
.882 .33362 Mdot
.882 .33388 Mdot
.882 .33409 Mdot
.882 .33801 Mdot
.882 .33806 Mdot
.882 .3393 Mdot
.882 .34024 Mdot
.882 .34031 Mdot
.882 .34068 Mdot
.882 .34094 Mdot
.882 .34111 Mdot
.882 .34151 Mdot
.882 .34162 Mdot
.882 .34212 Mdot
.882 .34261 Mdot
.882 .34289 Mdot
.882 .34461 Mdot
.882 .34488 Mdot
.882 .3449 Mdot
.882 .34503 Mdot
.882 .3455 Mdot
.882 .34571 Mdot
.882 .34596 Mdot
.882 .34662 Mdot
.882 .34663 Mdot
.882 .34754 Mdot
.882 .34807 Mdot
.882 .3486 Mdot
.882 .34881 Mdot
.882 .34959 Mdot
.882 .35009 Mdot
.882 .35053 Mdot
.882 .35177 Mdot
.882 .35198 Mdot
.882 .35375 Mdot
.882 .35458 Mdot
.882 .35478 Mdot
.882 .35593 Mdot
.882 .35614 Mdot
.882 .35663 Mdot
.882 .35891 Mdot
.882 .35904 Mdot
.882 .3596 Mdot
.882 .35963 Mdot
.882 .36084 Mdot
.882 .36124 Mdot
.882 .36154 Mdot
.882 .36208 Mdot
.882 .36218 Mdot
.882 .36242 Mdot
.882 .36365 Mdot
.882 .36408 Mdot
.882 .36472 Mdot
.882 .36545 Mdot
.882 .36552 Mdot
.882 .3657 Mdot
.882 .36585 Mdot
.882 .36605 Mdot
.882 .36615 Mdot
.882 .36666 Mdot
.882 .36714 Mdot
.882 .3675 Mdot
.882 .36929 Mdot
.882 .3697 Mdot
.882 .36983 Mdot
.882 .36995 Mdot
.882 .37018 Mdot
.882 .37055 Mdot
.882 .37434 Mdot
.882 .37437 Mdot
.882 .3744 Mdot
.882 .37592 Mdot
.882 .37767 Mdot
.882 .37952 Mdot
.882 .37992 Mdot
.882 .38095 Mdot
.882 .38151 Mdot
.882 .38175 Mdot
.882 .38206 Mdot
.882 .38401 Mdot
.882 .38461 Mdot
.882 .38462 Mdot
.882 .3849 Mdot
.882 .38571 Mdot
.882 .38658 Mdot
.882 .38658 Mdot
.882 .38662 Mdot
.882 .38819 Mdot
.882 .392 Mdot
.882 .39239 Mdot
.882 .39242 Mdot
.882 .39291 Mdot
.882 .39302 Mdot
.882 .39339 Mdot
.882 .39414 Mdot
.882 .39418 Mdot
.882 .39431 Mdot
.882 .39452 Mdot
.882 .39465 Mdot
.882 .39589 Mdot
.882 .39594 Mdot
.882 .39607 Mdot
.882 .39634 Mdot
.882 .39656 Mdot
.882 .39695 Mdot
.882 .39833 Mdot
.882 .39843 Mdot
.882 .39854 Mdot
.882 .39907 Mdot
.882 .40088 Mdot
.882 .40098 Mdot
.882 .40198 Mdot
.882 .40267 Mdot
.882 .40327 Mdot
.882 .40479 Mdot
.882 .40505 Mdot
.882 .40551 Mdot
.882 .40568 Mdot
.882 .40636 Mdot
.882 .4071 Mdot
.882 .40731 Mdot
.882 .40743 Mdot
.882 .40799 Mdot
.882 .40806 Mdot
.882 .40872 Mdot
.882 .40961 Mdot
.882 .40963 Mdot
.882 .41008 Mdot
.882 .41025 Mdot
.882 .41035 Mdot
.882 .41131 Mdot
.882 .41238 Mdot
.882 .41529 Mdot
.882 .41577 Mdot
.882 .41655 Mdot
.882 .41736 Mdot
.882 .41878 Mdot
.882 .41935 Mdot
.882 .42206 Mdot
.882 .42214 Mdot
.882 .42334 Mdot
.882 .42365 Mdot
.882 .42456 Mdot
.882 .42597 Mdot
.882 .42809 Mdot
.882 .42827 Mdot
.882 .43042 Mdot
.882 .43194 Mdot
.882 .4325 Mdot
.882 .4329 Mdot
.882 .43291 Mdot
.882 .43295 Mdot
.882 .43311 Mdot
.882 .43368 Mdot
.882 .43453 Mdot
.882 .43953 Mdot
.882 .44171 Mdot
.882 .44256 Mdot
.882 .4433 Mdot
.882 .44448 Mdot
.882 .4512 Mdot
.882 .45145 Mdot
.882 .45209 Mdot
.882 .45287 Mdot
.882 .45362 Mdot
.882 .45556 Mdot
.882 .45562 Mdot
.882 .45768 Mdot
.882 .45804 Mdot
.882 .4581 Mdot
.882 .4604 Mdot
.882 .4624 Mdot
.882 .46264 Mdot
.882 .46474 Mdot
.882 .4648 Mdot
.882 .46495 Mdot
.882 .46643 Mdot
.882 .4666 Mdot
.882 .46762 Mdot
.882 .46813 Mdot
.882 .46825 Mdot
.882 .47024 Mdot
.882 .47301 Mdot
.882 .47415 Mdot
.882 .47434 Mdot
.882 .47441 Mdot
.882 .47461 Mdot
.882 .47534 Mdot
.882 .47648 Mdot
.882 .47694 Mdot
.882 .47696 Mdot
.882 .4772 Mdot
.882 .48148 Mdot
.882 .48402 Mdot
.882 .48429 Mdot
.882 .48451 Mdot
.882 .48498 Mdot
.882 .48537 Mdot
.882 .48573 Mdot
.882 .48636 Mdot
.882 .48648 Mdot
.882 .4873 Mdot
.882 .48767 Mdot
.882 .4877 Mdot
.882 .48847 Mdot
.882 .48963 Mdot
.882 .4898 Mdot
.882 .49118 Mdot
.882 .49145 Mdot
.882 .49497 Mdot
.882 .49519 Mdot
.882 .49565 Mdot
.882 .49741 Mdot
.882 .49758 Mdot
.882 .49791 Mdot
.882 .49855 Mdot
.882 .50023 Mdot
.882 .50076 Mdot
.882 .50147 Mdot
.882 .50318 Mdot
.882 .50383 Mdot
.882 .50395 Mdot
.882 .50552 Mdot
.882 .50591 Mdot
.882 .50661 Mdot
.882 .50701 Mdot
.882 .5082 Mdot
.882 .50845 Mdot
.882 .50991 Mdot
.882 .5114 Mdot
.882 .51191 Mdot
.882 .51211 Mdot
.882 .51516 Mdot
.882 .51616 Mdot
.882 .51743 Mdot
.882 .51846 Mdot
.882 .52071 Mdot
.882 .5212 Mdot
.882 .52428 Mdot
.882 .5245 Mdot
.882 .52452 Mdot
.882 .52486 Mdot
.882 .52506 Mdot
.882 .52559 Mdot
.882 .52571 Mdot
.882 .52708 Mdot
.882 .52792 Mdot
.882 .52799 Mdot
.882 .52931 Mdot
.882 .53032 Mdot
.882 .53153 Mdot
.882 .53203 Mdot
.882 .53284 Mdot
.882 .53296 Mdot
.882 .53302 Mdot
.882 .53375 Mdot
.882 .53427 Mdot
.882 .53453 Mdot
.882 .53463 Mdot
.882 .53583 Mdot
.884 .01852 Mdot
.884 .01892 Mdot
.884 .02002 Mdot
.884 .02049 Mdot
.884 .02072 Mdot
.884 .02115 Mdot
.884 .02144 Mdot
.884 .02214 Mdot
.884 .02297 Mdot
.884 .02409 Mdot
.884 .0241 Mdot
.884 .02487 Mdot
.884 .02492 Mdot
.884 .02533 Mdot
.884 .02577 Mdot
.884 .02592 Mdot
.884 .02609 Mdot
.884 .02661 Mdot
.884 .02785 Mdot
.884 .02931 Mdot
.884 .03023 Mdot
.884 .03122 Mdot
.884 .03129 Mdot
.884 .0313 Mdot
.884 .03267 Mdot
.884 .03276 Mdot
.884 .03324 Mdot
.884 .03349 Mdot
.884 .0335 Mdot
.884 .03426 Mdot
.884 .03451 Mdot
.884 .03452 Mdot
.884 .03471 Mdot
.884 .03483 Mdot
.884 .03574 Mdot
.884 .03686 Mdot
.884 .03773 Mdot
.884 .03793 Mdot
.884 .03857 Mdot
.884 .04017 Mdot
.884 .04052 Mdot
.884 .04148 Mdot
.884 .04214 Mdot
.884 .04294 Mdot
.884 .04389 Mdot
.884 .04403 Mdot
.884 .04404 Mdot
.884 .04415 Mdot
.884 .04535 Mdot
.884 .04545 Mdot
.884 .04626 Mdot
.884 .04645 Mdot
.884 .04661 Mdot
.884 .04746 Mdot
.884 .04791 Mdot
.884 .04793 Mdot
.884 .04878 Mdot
.884 .04928 Mdot
.884 .04933 Mdot
.884 .04971 Mdot
.884 .04973 Mdot
.884 .05006 Mdot
.884 .05015 Mdot
.884 .05029 Mdot
.884 .05131 Mdot
.884 .05189 Mdot
.884 .05302 Mdot
.884 .05387 Mdot
.884 .05393 Mdot
.884 .05486 Mdot
.884 .0554 Mdot
.884 .05577 Mdot
.884 .05593 Mdot
.884 .0569 Mdot
.884 .05762 Mdot
.884 .05967 Mdot
.884 .05973 Mdot
.884 .06034 Mdot
.884 .06046 Mdot
.884 .06119 Mdot
.884 .06138 Mdot
.884 .06204 Mdot
.884 .06321 Mdot
.884 .06423 Mdot
.884 .06449 Mdot
.884 .06462 Mdot
.884 .06519 Mdot
.884 .06531 Mdot
.884 .06571 Mdot
.884 .06629 Mdot
.884 .06654 Mdot
.884 .06657 Mdot
.884 .06675 Mdot
.884 .0674 Mdot
.884 .06785 Mdot
.884 .06804 Mdot
.884 .06888 Mdot
.884 .06906 Mdot
.884 .06936 Mdot
.884 .07048 Mdot
.884 .07066 Mdot
.884 .07082 Mdot
.884 .07111 Mdot
.884 .07123 Mdot
.884 .07135 Mdot
.884 .07261 Mdot
.884 .07297 Mdot
.884 .0734 Mdot
.884 .07344 Mdot
.884 .07438 Mdot
.884 .07449 Mdot
.884 .07492 Mdot
.884 .07495 Mdot
.884 .07582 Mdot
.884 .07591 Mdot
.884 .07601 Mdot
.884 .07638 Mdot
.884 .07659 Mdot
.884 .07662 Mdot
.884 .07721 Mdot
.884 .07737 Mdot
.884 .07748 Mdot
.884 .0776 Mdot
.884 .07819 Mdot
.884 .07866 Mdot
.884 .07941 Mdot
.884 .07944 Mdot
.884 .07994 Mdot
.884 .08017 Mdot
.884 .08029 Mdot
.884 .08036 Mdot
.884 .08044 Mdot
.884 .08049 Mdot
.884 .08074 Mdot
.884 .08088 Mdot
.884 .08243 Mdot
.884 .08306 Mdot
.884 .08308 Mdot
.884 .0832 Mdot
.884 .08395 Mdot
.884 .08404 Mdot
.884 .08526 Mdot
.884 .0857 Mdot
.884 .08665 Mdot
.884 .08706 Mdot
.884 .08729 Mdot
.884 .08739 Mdot
.884 .08758 Mdot
.884 .08785 Mdot
.884 .08898 Mdot
.884 .08929 Mdot
.884 .08947 Mdot
.884 .08985 Mdot
.884 .09057 Mdot
.884 .09087 Mdot
.884 .09149 Mdot
.884 .0915 Mdot
.884 .09191 Mdot
.884 .0942 Mdot
.884 .0943 Mdot
.884 .09445 Mdot
.884 .09539 Mdot
.884 .0956 Mdot
.884 .09624 Mdot
.884 .09628 Mdot
.884 .09655 Mdot
.884 .09683 Mdot
.884 .09689 Mdot
.884 .09722 Mdot
.884 .09778 Mdot
.884 .09788 Mdot
.884 .09839 Mdot
.884 .09881 Mdot
.884 .10045 Mdot
.884 .10113 Mdot
.884 .10226 Mdot
.884 .10256 Mdot
.884 .10271 Mdot
.884 .10292 Mdot
.884 .10295 Mdot
.884 .1032 Mdot
.884 .10395 Mdot
.884 .10415 Mdot
.884 .10416 Mdot
.884 .10488 Mdot
.884 .10525 Mdot
.884 .1059 Mdot
.884 .10595 Mdot
.884 .10633 Mdot
.884 .10639 Mdot
.884 .10642 Mdot
.884 .10646 Mdot
.884 .10654 Mdot
.884 .10671 Mdot
.884 .10786 Mdot
.884 .10833 Mdot
.884 .10866 Mdot
.884 .10899 Mdot
.884 .10921 Mdot
.884 .10927 Mdot
.884 .11047 Mdot
.884 .1108 Mdot
.884 .11134 Mdot
.884 .11212 Mdot
.884 .11266 Mdot
.884 .11271 Mdot
.884 .11289 Mdot
.884 .11332 Mdot
.884 .11363 Mdot
.884 .11391 Mdot
.884 .11442 Mdot
.884 .11463 Mdot
.884 .11485 Mdot
.884 .11487 Mdot
.884 .11593 Mdot
.884 .11677 Mdot
.884 .11707 Mdot
.884 .11772 Mdot
.884 .11846 Mdot
.884 .11854 Mdot
.884 .11896 Mdot
.884 .11953 Mdot
.884 .1202 Mdot
.884 .1204 Mdot
.884 .12115 Mdot
.884 .12121 Mdot
.884 .12275 Mdot
.884 .1229 Mdot
.884 .12309 Mdot
.884 .12374 Mdot
.884 .12407 Mdot
.884 .12412 Mdot
.884 .12417 Mdot
.884 .12436 Mdot
.884 .12494 Mdot
.884 .1252 Mdot
.884 .12527 Mdot
.884 .12532 Mdot
.884 .12549 Mdot
.884 .12569 Mdot
.884 .1259 Mdot
.884 .12591 Mdot
.884 .12693 Mdot
.884 .12777 Mdot
.884 .1291 Mdot
.884 .12915 Mdot
.884 .12925 Mdot
.884 .13003 Mdot
.884 .13044 Mdot
.884 .13064 Mdot
.884 .13065 Mdot
.884 .13077 Mdot
.884 .13092 Mdot
.884 .13101 Mdot
.884 .13144 Mdot
.884 .13152 Mdot
.884 .13164 Mdot
.884 .13169 Mdot
.884 .13259 Mdot
.884 .13268 Mdot
.884 .13314 Mdot
.884 .13332 Mdot
.884 .13343 Mdot
.884 .13414 Mdot
.884 .13444 Mdot
.884 .13465 Mdot
.884 .13555 Mdot
.884 .13556 Mdot
.884 .13559 Mdot
.884 .1358 Mdot
.884 .13703 Mdot
.884 .13712 Mdot
.884 .13729 Mdot
.884 .13745 Mdot
.884 .13815 Mdot
.884 .13842 Mdot
.884 .13943 Mdot
.884 .13981 Mdot
.884 .14021 Mdot
.884 .1409 Mdot
.884 .14189 Mdot
.884 .14262 Mdot
.884 .14294 Mdot
.884 .14303 Mdot
.884 .1432 Mdot
.884 .14339 Mdot
.884 .14353 Mdot
.884 .14378 Mdot
.884 .1439 Mdot
.884 .14401 Mdot
.884 .1456 Mdot
.884 .14601 Mdot
.884 .14644 Mdot
.884 .14656 Mdot
.884 .14687 Mdot
.884 .14741 Mdot
.884 .14755 Mdot
.884 .14804 Mdot
.884 .14824 Mdot
.884 .14883 Mdot
.884 .14936 Mdot
.884 .15024 Mdot
.884 .15039 Mdot
.884 .15045 Mdot
.884 .15047 Mdot
.884 .15052 Mdot
.884 .15094 Mdot
.884 .15119 Mdot
.884 .15144 Mdot
.884 .15184 Mdot
.884 .15193 Mdot
.884 .15258 Mdot
.884 .15265 Mdot
.884 .15361 Mdot
.884 .15394 Mdot
.884 .15429 Mdot
.884 .15477 Mdot
.884 .15525 Mdot
.884 .15541 Mdot
.884 .15569 Mdot
.884 .15623 Mdot
.884 .15686 Mdot
.884 .15734 Mdot
.884 .15772 Mdot
.884 .15785 Mdot
.884 .15885 Mdot
.884 .15892 Mdot
.884 .15941 Mdot
.884 .15944 Mdot
.884 .15975 Mdot
.884 .15978 Mdot
.884 .15989 Mdot
.884 .15997 Mdot
.884 .16 Mdot
.884 .16059 Mdot
.884 .16097 Mdot
.884 .16115 Mdot
.884 .16157 Mdot
.884 .16175 Mdot
.884 .16265 Mdot
.884 .1634 Mdot
.884 .16385 Mdot
.884 .1645 Mdot
.884 .1663 Mdot
.884 .16749 Mdot
.884 .1679 Mdot
.884 .1684 Mdot
.884 .16931 Mdot
.884 .16936 Mdot
.884 .16949 Mdot
.884 .17003 Mdot
.884 .17022 Mdot
.884 .1703 Mdot
.884 .17067 Mdot
.884 .17071 Mdot
.884 .17115 Mdot
.884 .17249 Mdot
.884 .17284 Mdot
.884 .17286 Mdot
.884 .17413 Mdot
.884 .17413 Mdot
.884 .17468 Mdot
.884 .17478 Mdot
.884 .17561 Mdot
.884 .17593 Mdot
.884 .17602 Mdot
.884 .1767 Mdot
.884 .17671 Mdot
.884 .1768 Mdot
.884 .17684 Mdot
.884 .17692 Mdot
.884 .17706 Mdot
.884 .17736 Mdot
.884 .17939 Mdot
.884 .18023 Mdot
.884 .1808 Mdot
.884 .18118 Mdot
.884 .1814 Mdot
.884 .18178 Mdot
.884 .18188 Mdot
.884 .1833 Mdot
.884 .18388 Mdot
.884 .18401 Mdot
.884 .1846 Mdot
.884 .18496 Mdot
.884 .18549 Mdot
.884 .18554 Mdot
.884 .18692 Mdot
.884 .18788 Mdot
.884 .18797 Mdot
.884 .18829 Mdot
.884 .18904 Mdot
.884 .18932 Mdot
.884 .18959 Mdot
.884 .1901 Mdot
.884 .19052 Mdot
.884 .19099 Mdot
.884 .19137 Mdot
.884 .19176 Mdot
.884 .19179 Mdot
.884 .19366 Mdot
.884 .19421 Mdot
.884 .1945 Mdot
.884 .1948 Mdot
.884 .19514 Mdot
.884 .19568 Mdot
.884 .19634 Mdot
.884 .19682 Mdot
.884 .19689 Mdot
.884 .1981 Mdot
.884 .19814 Mdot
.884 .19827 Mdot
.884 .19881 Mdot
.884 .19895 Mdot
.884 .19901 Mdot
.884 .20004 Mdot
.884 .20007 Mdot
.884 .20059 Mdot
.884 .20104 Mdot
.884 .20108 Mdot
.884 .20122 Mdot
.884 .20157 Mdot
.884 .20168 Mdot
.884 .20204 Mdot
.884 .20266 Mdot
.884 .2029 Mdot
.884 .20296 Mdot
.884 .203 Mdot
.884 .20308 Mdot
.884 .20382 Mdot
.884 .20387 Mdot
.884 .20521 Mdot
.884 .20571 Mdot
.884 .20587 Mdot
.884 .20599 Mdot
.884 .20632 Mdot
.884 .20652 Mdot
.884 .20746 Mdot
.884 .20805 Mdot
.884 .20814 Mdot
.884 .20823 Mdot
.884 .20856 Mdot
.884 .2096 Mdot
.884 .21006 Mdot
.884 .21018 Mdot
.884 .21026 Mdot
.884 .21057 Mdot
.884 .21092 Mdot
.884 .21114 Mdot
.884 .21129 Mdot
.884 .21131 Mdot
.884 .21312 Mdot
.884 .2146 Mdot
.884 .2153 Mdot
.884 .21549 Mdot
.884 .21694 Mdot
.884 .21703 Mdot
.884 .21722 Mdot
.884 .21753 Mdot
.884 .2186 Mdot
.884 .21932 Mdot
.884 .21967 Mdot
.884 .2197 Mdot
.884 .21984 Mdot
.884 .2199 Mdot
.884 .21993 Mdot
.884 .22016 Mdot
.884 .22032 Mdot
.884 .22061 Mdot
.884 .22109 Mdot
.884 .22122 Mdot
.884 .22145 Mdot
.884 .22153 Mdot
.884 .22232 Mdot
.884 .22312 Mdot
.884 .22328 Mdot
.884 .2241 Mdot
.884 .22441 Mdot
.884 .22461 Mdot
.884 .22531 Mdot
.884 .22585 Mdot
.884 .22608 Mdot
.884 .22639 Mdot
.884 .22661 Mdot
.884 .22676 Mdot
.884 .22723 Mdot
.884 .22826 Mdot
.884 .22835 Mdot
.884 .22836 Mdot
.884 .22842 Mdot
.884 .22875 Mdot
.884 .2288 Mdot
.884 .22987 Mdot
.884 .23096 Mdot
.884 .23112 Mdot
.884 .23143 Mdot
.884 .2317 Mdot
.884 .23295 Mdot
.884 .23313 Mdot
.884 .23343 Mdot
.884 .23521 Mdot
.884 .23589 Mdot
.884 .23607 Mdot
.884 .23659 Mdot
.884 .23781 Mdot
.884 .23947 Mdot
.884 .23957 Mdot
.884 .24062 Mdot
.884 .24085 Mdot
.884 .2409 Mdot
.884 .24142 Mdot
.884 .24158 Mdot
.884 .24177 Mdot
.884 .24188 Mdot
.884 .24208 Mdot
.884 .24218 Mdot
.884 .24222 Mdot
.884 .24245 Mdot
.884 .24247 Mdot
.884 .2429 Mdot
.884 .24311 Mdot
.884 .24332 Mdot
.884 .2448 Mdot
.884 .24613 Mdot
.884 .24619 Mdot
.884 .24684 Mdot
.884 .24758 Mdot
.884 .24761 Mdot
.884 .24783 Mdot
.884 .24837 Mdot
.884 .24933 Mdot
.884 .24958 Mdot
.884 .24974 Mdot
.884 .24994 Mdot
.884 .25027 Mdot
.884 .25043 Mdot
.884 .25079 Mdot
.884 .25183 Mdot
.884 .25277 Mdot
.884 .25386 Mdot
.884 .25423 Mdot
.884 .25431 Mdot
.884 .25459 Mdot
.884 .25469 Mdot
.884 .25472 Mdot
.884 .25481 Mdot
.884 .25556 Mdot
.884 .25601 Mdot
.884 .25645 Mdot
.884 .25714 Mdot
.884 .25721 Mdot
.884 .25731 Mdot
.884 .25846 Mdot
.884 .25858 Mdot
.884 .25953 Mdot
.884 .26028 Mdot
.884 .26086 Mdot
.884 .26135 Mdot
.884 .26148 Mdot
.884 .26233 Mdot
.884 .2629 Mdot
.884 .26317 Mdot
.884 .26329 Mdot
.884 .26347 Mdot
.884 .26396 Mdot
.884 .26491 Mdot
.884 .26594 Mdot
.884 .26603 Mdot
.884 .26688 Mdot
.884 .26755 Mdot
.884 .26772 Mdot
.884 .26777 Mdot
.884 .26859 Mdot
.884 .26896 Mdot
.884 .26952 Mdot
.884 .26955 Mdot
.884 .26968 Mdot
.884 .27053 Mdot
.884 .27059 Mdot
.884 .27104 Mdot
.884 .27114 Mdot
.884 .27119 Mdot
.884 .27139 Mdot
.884 .27152 Mdot
.884 .27158 Mdot
.884 .27262 Mdot
.884 .2733 Mdot
.884 .27361 Mdot
.884 .27401 Mdot
.884 .27435 Mdot
.884 .27467 Mdot
.884 .27627 Mdot
.884 .27724 Mdot
.884 .27751 Mdot
.884 .27759 Mdot
.884 .27839 Mdot
.884 .27953 Mdot
.884 .28017 Mdot
.884 .28226 Mdot
.884 .28271 Mdot
.884 .28281 Mdot
.884 .28296 Mdot
.884 .28483 Mdot
.884 .28551 Mdot
.884 .28555 Mdot
.884 .28644 Mdot
.884 .28667 Mdot
.884 .28803 Mdot
.884 .28812 Mdot
.884 .28835 Mdot
.884 .28841 Mdot
.884 .28852 Mdot
.884 .28892 Mdot
.884 .28931 Mdot
.884 .28964 Mdot
.884 .28978 Mdot
.884 .29044 Mdot
.884 .29052 Mdot
.884 .2913 Mdot
.884 .29158 Mdot
.884 .29177 Mdot
.884 .29316 Mdot
.884 .29349 Mdot
.884 .29365 Mdot
.884 .29366 Mdot
.884 .29427 Mdot
.884 .29428 Mdot
.884 .29431 Mdot
.884 .29467 Mdot
.884 .29486 Mdot
.884 .29655 Mdot
.884 .29656 Mdot
.884 .29752 Mdot
.884 .29771 Mdot
.884 .29811 Mdot
.884 .29918 Mdot
.884 .29975 Mdot
.884 .2999 Mdot
.884 .30023 Mdot
.884 .3011 Mdot
.884 .30112 Mdot
.884 .3012 Mdot
.884 .30129 Mdot
.884 .30136 Mdot
.884 .30149 Mdot
.884 .30174 Mdot
.884 .30227 Mdot
.884 .30245 Mdot
.884 .30353 Mdot
.884 .30452 Mdot
.884 .30586 Mdot
.884 .30735 Mdot
.884 .30836 Mdot
.884 .30903 Mdot
.884 .30941 Mdot
.884 .30951 Mdot
.884 .31009 Mdot
.884 .31026 Mdot
.884 .31255 Mdot
.884 .31277 Mdot
.884 .3134 Mdot
.884 .31366 Mdot
.884 .31379 Mdot
.884 .31404 Mdot
.884 .31507 Mdot
.884 .3157 Mdot
.884 .31614 Mdot
.884 .31665 Mdot
.884 .31673 Mdot
.884 .31917 Mdot
.884 .31973 Mdot
.884 .32087 Mdot
.884 .32102 Mdot
.884 .32159 Mdot
.884 .3217 Mdot
.884 .32292 Mdot
.884 .32341 Mdot
.884 .32389 Mdot
.884 .3248 Mdot
.884 .32554 Mdot
.884 .32636 Mdot
.884 .32704 Mdot
.884 .32772 Mdot
.884 .32778 Mdot
.884 .32824 Mdot
.884 .32967 Mdot
.884 .32997 Mdot
.884 .33044 Mdot
.884 .33109 Mdot
.884 .33206 Mdot
.884 .33258 Mdot
.884 .3331 Mdot
.884 .33371 Mdot
.884 .33466 Mdot
.884 .33582 Mdot
.884 .33627 Mdot
.884 .33669 Mdot
.884 .33679 Mdot
.884 .3384 Mdot
.884 .33855 Mdot
.884 .33894 Mdot
.884 .33901 Mdot
.884 .33924 Mdot
.884 .34019 Mdot
.884 .34045 Mdot
.884 .34056 Mdot
.884 .34131 Mdot
.884 .34204 Mdot
.884 .34236 Mdot
.884 .34243 Mdot
.884 .34335 Mdot
.884 .34414 Mdot
.884 .34421 Mdot
.884 .34445 Mdot
.884 .34507 Mdot
.884 .34527 Mdot
.884 .3459 Mdot
.884 .3463 Mdot
.884 .34657 Mdot
.884 .347 Mdot
.884 .34729 Mdot
.884 .34742 Mdot
.884 .34749 Mdot
.884 .34752 Mdot
.884 .3476 Mdot
.884 .34774 Mdot
.884 .34782 Mdot
.884 .34906 Mdot
.884 .34907 Mdot
.884 .34913 Mdot
.884 .35029 Mdot
.884 .35131 Mdot
.884 .3515 Mdot
.884 .35176 Mdot
.884 .3524 Mdot
.884 .35268 Mdot
.884 .35289 Mdot
.884 .35347 Mdot
.884 .35382 Mdot
.884 .35383 Mdot
.884 .35406 Mdot
.884 .3555 Mdot
.884 .35651 Mdot
.884 .35653 Mdot
.884 .35668 Mdot
.884 .35684 Mdot
.884 .35738 Mdot
.884 .35743 Mdot
.884 .35796 Mdot
.884 .35927 Mdot
.884 .36008 Mdot
.884 .36029 Mdot
.884 .36044 Mdot
.884 .36098 Mdot
.884 .3616 Mdot
.884 .362 Mdot
.884 .36226 Mdot
.884 .36229 Mdot
.884 .36233 Mdot
.884 .36335 Mdot
.884 .36384 Mdot
.884 .36388 Mdot
.884 .36549 Mdot
.884 .36579 Mdot
.884 .36582 Mdot
.884 .36593 Mdot
.884 .36705 Mdot
.884 .36764 Mdot
.884 .36812 Mdot
.884 .36936 Mdot
.884 .36968 Mdot
.884 .37225 Mdot
.884 .37241 Mdot
.884 .37274 Mdot
.884 .37293 Mdot
.884 .37295 Mdot
.884 .37329 Mdot
.884 .37518 Mdot
.884 .37596 Mdot
.884 .37646 Mdot
.884 .37653 Mdot
.884 .37707 Mdot
.884 .37712 Mdot
.884 .37738 Mdot
.884 .37748 Mdot
.884 .37754 Mdot
.884 .37794 Mdot
.884 .37823 Mdot
.884 .37874 Mdot
.884 .37958 Mdot
.884 .37981 Mdot
.884 .38021 Mdot
.884 .38037 Mdot
.884 .38115 Mdot
.884 .38177 Mdot
.884 .38292 Mdot
.884 .38318 Mdot
.884 .38339 Mdot
.884 .38346 Mdot
.884 .38443 Mdot
.884 .3849 Mdot
.884 .38545 Mdot
.884 .3858 Mdot
.884 .38592 Mdot
.884 .38705 Mdot
.884 .38714 Mdot
.884 .38721 Mdot
.884 .38745 Mdot
.884 .38773 Mdot
.884 .38795 Mdot
.884 .38801 Mdot
.884 .38837 Mdot
.884 .38841 Mdot
.884 .38896 Mdot
.884 .38914 Mdot
.884 .38934 Mdot
.884 .38961 Mdot
.884 .39044 Mdot
.884 .39079 Mdot
.884 .39135 Mdot
.884 .39225 Mdot
.884 .39243 Mdot
.884 .39245 Mdot
.884 .39255 Mdot
.884 .39312 Mdot
.884 .39322 Mdot
.884 .39475 Mdot
.884 .39512 Mdot
.884 .39704 Mdot
.884 .39732 Mdot
.884 .39783 Mdot
.884 .39786 Mdot
.884 .39835 Mdot
.884 .40056 Mdot
.884 .40087 Mdot
.884 .4014 Mdot
.884 .40202 Mdot
.884 .40455 Mdot
.884 .40575 Mdot
.884 .40608 Mdot
.884 .40669 Mdot
.884 .40699 Mdot
.884 .40915 Mdot
.884 .40983 Mdot
.884 .41192 Mdot
.884 .41208 Mdot
.884 .41225 Mdot
.884 .41312 Mdot
.884 .41343 Mdot
.884 .41412 Mdot
.884 .41452 Mdot
.884 .4146 Mdot
.884 .41524 Mdot
.884 .41553 Mdot
.884 .41579 Mdot
.884 .41581 Mdot
.884 .41615 Mdot
.884 .41635 Mdot
.884 .4167 Mdot
.884 .41687 Mdot
.884 .41694 Mdot
.884 .41736 Mdot
.884 .41738 Mdot
.884 .41814 Mdot
.884 .41852 Mdot
.884 .41888 Mdot
.884 .4215 Mdot
.884 .42385 Mdot
.884 .42396 Mdot
.884 .42511 Mdot
.884 .42642 Mdot
.884 .42647 Mdot
.884 .42685 Mdot
.884 .42782 Mdot
.884 .42951 Mdot
.884 .42995 Mdot
.884 .43024 Mdot
.884 .4306 Mdot
.884 .43118 Mdot
.884 .43145 Mdot
.884 .43209 Mdot
.884 .43393 Mdot
.884 .4356 Mdot
.884 .43752 Mdot
.884 .43817 Mdot
.884 .43833 Mdot
.884 .43882 Mdot
.884 .439 Mdot
.884 .43905 Mdot
.884 .43921 Mdot
.884 .44053 Mdot
.884 .44132 Mdot
.884 .44211 Mdot
.884 .44333 Mdot
.884 .44344 Mdot
.884 .44363 Mdot
.884 .44566 Mdot
.884 .44587 Mdot
.884 .44755 Mdot
.884 .44887 Mdot
.884 .4499 Mdot
.884 .45077 Mdot
.884 .45099 Mdot
.884 .45249 Mdot
.884 .4535 Mdot
.884 .45399 Mdot
.884 .4542 Mdot
.884 .45451 Mdot
.884 .45537 Mdot
.884 .45705 Mdot
.884 .45888 Mdot
.884 .45903 Mdot
.884 .46054 Mdot
.884 .46172 Mdot
.884 .46203 Mdot
.884 .46212 Mdot
.884 .46356 Mdot
.884 .46422 Mdot
.884 .4652 Mdot
.884 .46526 Mdot
.884 .46549 Mdot
.884 .46699 Mdot
.884 .4671 Mdot
.884 .46789 Mdot
.884 .46807 Mdot
.884 .46816 Mdot
.884 .46852 Mdot
.884 .46874 Mdot
.884 .46885 Mdot
.884 .47069 Mdot
.884 .47189 Mdot
.884 .47243 Mdot
.884 .47314 Mdot
.884 .47376 Mdot
.884 .47431 Mdot
.884 .47714 Mdot
.884 .47885 Mdot
.884 .47933 Mdot
.884 .47948 Mdot
.884 .48088 Mdot
.884 .48292 Mdot
.884 .48403 Mdot
.884 .48773 Mdot
.884 .48854 Mdot
.884 .48871 Mdot
.884 .48897 Mdot
.884 .49227 Mdot
.884 .49348 Mdot
.884 .49356 Mdot
.884 .49512 Mdot
.884 .49553 Mdot
.884 .49794 Mdot
.884 .49809 Mdot
.884 .4985 Mdot
.884 .49862 Mdot
.884 .4988 Mdot
.884 .49951 Mdot
.884 .5002 Mdot
.884 .50078 Mdot
.884 .50103 Mdot
.884 .5022 Mdot
.884 .50233 Mdot
.884 .50372 Mdot
.884 .50421 Mdot
.884 .50454 Mdot
.884 .50701 Mdot
.884 .50759 Mdot
.884 .50787 Mdot
.884 .50788 Mdot
.884 .50897 Mdot
.884 .50899 Mdot
.884 .50904 Mdot
.884 .50968 Mdot
.884 .51002 Mdot
.884 .513 Mdot
.884 .51302 Mdot
.884 .51472 Mdot
.884 .51504 Mdot
.884 .51766 Mdot
.884 .51866 Mdot
.884 .51893 Mdot
.884 .51951 Mdot
.884 .52104 Mdot
.884 .52108 Mdot
.884 .52122 Mdot
.884 .52138 Mdot
.884 .5215 Mdot
.884 .52174 Mdot
.884 .52218 Mdot
.884 .52311 Mdot
.884 .52343 Mdot
.884 .52535 Mdot
.884 .52709 Mdot
.884 .52946 Mdot
.884 .5321 Mdot
.884 .53388 Mdot
.884 .53506 Mdot
.884 .53574 Mdot
.884 .53592 Mdot
.884 .53694 Mdot
.884 .53725 Mdot
.886 .01509 Mdot
.886 .01538 Mdot
.886 .01589 Mdot
.886 .01626 Mdot
.886 .01628 Mdot
.886 .0168 Mdot
.886 .01731 Mdot
.886 .01746 Mdot
.886 .01749 Mdot
.886 .01759 Mdot
.886 .01791 Mdot
.886 .01841 Mdot
.886 .01901 Mdot
.886 .01931 Mdot
.886 .01958 Mdot
.886 .01962 Mdot
.886 .01982 Mdot
.886 .02022 Mdot
.886 .02037 Mdot
.886 .0207 Mdot
.886 .02086 Mdot
.886 .02088 Mdot
.886 .02108 Mdot
.886 .02126 Mdot
.886 .02139 Mdot
.886 .02233 Mdot
.886 .02286 Mdot
.886 .02312 Mdot
.886 .02333 Mdot
.886 .02341 Mdot
.886 .02344 Mdot
.886 .02375 Mdot
.886 .02448 Mdot
.886 .02473 Mdot
.886 .02532 Mdot
.886 .0256 Mdot
.886 .02564 Mdot
.886 .026 Mdot
.886 .02631 Mdot
.886 .02631 Mdot
.886 .02655 Mdot
.886 .02821 Mdot
.886 .02835 Mdot
.886 .02915 Mdot
.886 .02962 Mdot
.886 .02988 Mdot
.886 .02997 Mdot
.886 .02999 Mdot
.886 .03013 Mdot
.886 .03018 Mdot
.886 .03037 Mdot
.886 .03073 Mdot
.886 .03201 Mdot
.886 .03247 Mdot
.886 .03351 Mdot
.886 .03358 Mdot
.886 .03388 Mdot
.886 .034 Mdot
.886 .03408 Mdot
.886 .03471 Mdot
.886 .03481 Mdot
.886 .03526 Mdot
.886 .03526 Mdot
.886 .03547 Mdot
.886 .03569 Mdot
.886 .0362 Mdot
.886 .03636 Mdot
.886 .03725 Mdot
.886 .03813 Mdot
.886 .03862 Mdot
.886 .03888 Mdot
.886 .03898 Mdot
.886 .0395 Mdot
.886 .0403 Mdot
.886 .04034 Mdot
.886 .04112 Mdot
.886 .04158 Mdot
.886 .04174 Mdot
.886 .04178 Mdot
.886 .04203 Mdot
.886 .04212 Mdot
.886 .04217 Mdot
.886 .04245 Mdot
.886 .0431 Mdot
.886 .04311 Mdot
.886 .04331 Mdot
.886 .04457 Mdot
.886 .04485 Mdot
.886 .04519 Mdot
.886 .04537 Mdot
.886 .04612 Mdot
.886 .04617 Mdot
.886 .04691 Mdot
.886 .04802 Mdot
.886 .04815 Mdot
.886 .04868 Mdot
.886 .04873 Mdot
.886 .04889 Mdot
.886 .04903 Mdot
.886 .04925 Mdot
.886 .05004 Mdot
.886 .05014 Mdot
.886 .05033 Mdot
.886 .05112 Mdot
.886 .05113 Mdot
.886 .05149 Mdot
.886 .05188 Mdot
.886 .05278 Mdot
.886 .05307 Mdot
.886 .05328 Mdot
.886 .05431 Mdot
.886 .05437 Mdot
.886 .05463 Mdot
.886 .05465 Mdot
.886 .05514 Mdot
.886 .05617 Mdot
.886 .05621 Mdot
.886 .05708 Mdot
.886 .05754 Mdot
.886 .05772 Mdot
.886 .05776 Mdot
.886 .05863 Mdot
.886 .05989 Mdot
.886 .06005 Mdot
.886 .06013 Mdot
.886 .06058 Mdot
.886 .06095 Mdot
.886 .06147 Mdot
.886 .0615 Mdot
.886 .06212 Mdot
.886 .06233 Mdot
.886 .06252 Mdot
.886 .0626 Mdot
.886 .06267 Mdot
.886 .06311 Mdot
.886 .06324 Mdot
.886 .06329 Mdot
.886 .06336 Mdot
.886 .06386 Mdot
.886 .06404 Mdot
.886 .06442 Mdot
.886 .06449 Mdot
.886 .06501 Mdot
.886 .06502 Mdot
.886 .06538 Mdot
.886 .06599 Mdot
.886 .06609 Mdot
.886 .06761 Mdot
.886 .06812 Mdot
.886 .06815 Mdot
.886 .06842 Mdot
.886 .06871 Mdot
.886 .06903 Mdot
.886 .06924 Mdot
.886 .06944 Mdot
.886 .07037 Mdot
.886 .07046 Mdot
.886 .07177 Mdot
.886 .07244 Mdot
.886 .07266 Mdot
.886 .0727 Mdot
.886 .0729 Mdot
.886 .07374 Mdot
.886 .07396 Mdot
.886 .07421 Mdot
.886 .07474 Mdot
.886 .07477 Mdot
.886 .0749 Mdot
.886 .07491 Mdot
.886 .07498 Mdot
.886 .07527 Mdot
.886 .07553 Mdot
.886 .07579 Mdot
.886 .07591 Mdot
.886 .07731 Mdot
.886 .07731 Mdot
.886 .07749 Mdot
.886 .07782 Mdot
.886 .07922 Mdot
.886 .07924 Mdot
.886 .07989 Mdot
.886 .08057 Mdot
.886 .08217 Mdot
.886 .08261 Mdot
.886 .08269 Mdot
.886 .08286 Mdot
.886 .08305 Mdot
.886 .08374 Mdot
.886 .08417 Mdot
.886 .0843 Mdot
.886 .08488 Mdot
.886 .08498 Mdot
.886 .08499 Mdot
.886 .08545 Mdot
.886 .08547 Mdot
.886 .08609 Mdot
.886 .08635 Mdot
.886 .08757 Mdot
.886 .08779 Mdot
.886 .08817 Mdot
.886 .08824 Mdot
.886 .0886 Mdot
.886 .08936 Mdot
.886 .08942 Mdot
.886 .08978 Mdot
.886 .09036 Mdot
.886 .0906 Mdot
.886 .09092 Mdot
.886 .09099 Mdot
.886 .09253 Mdot
.886 .09291 Mdot
.886 .09356 Mdot
.886 .09405 Mdot
.886 .09409 Mdot
.886 .09413 Mdot
.886 .09415 Mdot
.886 .09445 Mdot
.886 .09476 Mdot
.886 .09505 Mdot
.886 .09518 Mdot
.886 .09599 Mdot
.886 .09665 Mdot
.886 .09757 Mdot
.886 .09762 Mdot
.886 .09872 Mdot
.886 .09908 Mdot
.886 .09942 Mdot
.886 .09957 Mdot
.886 .09969 Mdot
.886 .10047 Mdot
.886 .1007 Mdot
.886 .10078 Mdot
.886 .1009 Mdot
.886 .10092 Mdot
.886 .10097 Mdot
.886 .10128 Mdot
.886 .1018 Mdot
.886 .10212 Mdot
.886 .1028 Mdot
.886 .10292 Mdot
.886 .10339 Mdot
.886 .10383 Mdot
.886 .10386 Mdot
.886 .1045 Mdot
.886 .10558 Mdot
.886 .10563 Mdot
.886 .10574 Mdot
.886 .10662 Mdot
.886 .10791 Mdot
.886 .10794 Mdot
.886 .10795 Mdot
.886 .10811 Mdot
.886 .10845 Mdot
.886 .10916 Mdot
.886 .10935 Mdot
.886 .1094 Mdot
.886 .10965 Mdot
.886 .10987 Mdot
.886 .10999 Mdot
.886 .11039 Mdot
.886 .11097 Mdot
.886 .11133 Mdot
.886 .11161 Mdot
.886 .11169 Mdot
.886 .11293 Mdot
.886 .11334 Mdot
.886 .11349 Mdot
.886 .11402 Mdot
.886 .11523 Mdot
.886 .11581 Mdot
.886 .117 Mdot
.886 .1174 Mdot
.886 .11747 Mdot
.886 .11775 Mdot
.886 .11782 Mdot
.886 .1193 Mdot
.886 .1193 Mdot
.886 .11957 Mdot
.886 .1197 Mdot
.886 .11986 Mdot
.886 .12013 Mdot
.886 .12108 Mdot
.886 .12113 Mdot
.886 .12137 Mdot
.886 .12139 Mdot
.886 .12151 Mdot
.886 .12171 Mdot
.886 .12202 Mdot
.886 .12231 Mdot
.886 .12248 Mdot
.886 .12294 Mdot
.886 .12316 Mdot
.886 .12564 Mdot
.886 .12564 Mdot
.886 .12586 Mdot
.886 .12594 Mdot
.886 .12653 Mdot
.886 .12673 Mdot
.886 .12695 Mdot
.886 .1274 Mdot
.886 .12901 Mdot
.886 .12905 Mdot
.886 .12913 Mdot
.886 .1302 Mdot
.886 .13093 Mdot
.886 .13109 Mdot
.886 .1314 Mdot
.886 .13304 Mdot
.886 .13334 Mdot
.886 .13424 Mdot
.886 .13503 Mdot
.886 .13516 Mdot
.886 .13547 Mdot
.886 .1358 Mdot
.886 .13703 Mdot
.886 .13738 Mdot
.886 .1378 Mdot
.886 .13801 Mdot
.886 .13829 Mdot
.886 .13905 Mdot
.886 .13922 Mdot
.886 .13924 Mdot
.886 .14002 Mdot
.886 .14006 Mdot
.886 .1401 Mdot
.886 .14114 Mdot
.886 .14118 Mdot
.886 .14165 Mdot
.886 .142 Mdot
.886 .14381 Mdot
.886 .14421 Mdot
.886 .14487 Mdot
.886 .145 Mdot
.886 .14503 Mdot
.886 .14564 Mdot
.886 .14698 Mdot
.886 .14709 Mdot
.886 .1475 Mdot
.886 .14773 Mdot
.886 .14858 Mdot
.886 .14877 Mdot
.886 .14915 Mdot
.886 .14918 Mdot
.886 .14975 Mdot
.886 .14987 Mdot
.886 .14987 Mdot
.886 .15073 Mdot
.886 .1508 Mdot
.886 .15097 Mdot
.886 .15201 Mdot
.886 .15261 Mdot
.886 .15269 Mdot
.886 .15328 Mdot
.886 .15443 Mdot
.886 .1547 Mdot
.886 .15529 Mdot
.886 .15538 Mdot
.886 .15545 Mdot
.886 .15547 Mdot
.886 .15581 Mdot
.886 .15585 Mdot
.886 .15601 Mdot
.886 .15641 Mdot
.886 .15655 Mdot
.886 .15707 Mdot
.886 .15731 Mdot
.886 .15834 Mdot
.886 .15836 Mdot
.886 .15837 Mdot
.886 .15873 Mdot
.886 .15991 Mdot
.886 .1602 Mdot
.886 .16044 Mdot
.886 .16093 Mdot
.886 .16154 Mdot
.886 .16163 Mdot
.886 .16263 Mdot
.886 .16357 Mdot
.886 .16422 Mdot
.886 .16448 Mdot
.886 .16481 Mdot
.886 .16508 Mdot
.886 .16529 Mdot
.886 .16547 Mdot
.886 .16667 Mdot
.886 .16671 Mdot
.886 .16707 Mdot
.886 .16722 Mdot
.886 .16744 Mdot
.886 .16747 Mdot
.886 .16755 Mdot
.886 .16792 Mdot
.886 .16811 Mdot
.886 .16902 Mdot
.886 .16952 Mdot
.886 .16959 Mdot
.886 .1708 Mdot
.886 .17102 Mdot
.886 .17134 Mdot
.886 .17185 Mdot
.886 .17263 Mdot
.886 .17269 Mdot
.886 .1733 Mdot
.886 .17363 Mdot
.886 .17381 Mdot
.886 .17383 Mdot
.886 .17549 Mdot
.886 .1756 Mdot
.886 .17573 Mdot
.886 .17582 Mdot
.886 .17595 Mdot
.886 .17602 Mdot
.886 .1768 Mdot
.886 .17756 Mdot
.886 .17833 Mdot
.886 .17986 Mdot
.886 .17991 Mdot
.886 .17993 Mdot
.886 .18021 Mdot
.886 .18081 Mdot
.886 .18207 Mdot
.886 .1824 Mdot
.886 .18249 Mdot
.886 .18259 Mdot
.886 .18295 Mdot
.886 .18333 Mdot
.886 .18353 Mdot
.886 .18354 Mdot
.886 .18361 Mdot
.886 .18426 Mdot
.886 .18436 Mdot
.886 .18527 Mdot
.886 .18592 Mdot
.886 .18641 Mdot
.886 .18656 Mdot
.886 .18759 Mdot
.886 .18798 Mdot
.886 .18819 Mdot
.886 .18842 Mdot
.886 .18875 Mdot
.886 .18947 Mdot
.886 .18974 Mdot
.886 .19062 Mdot
.886 .19068 Mdot
.886 .19108 Mdot
.886 .19128 Mdot
.886 .19258 Mdot
.886 .19283 Mdot
.886 .19386 Mdot
.886 .19421 Mdot
.886 .19429 Mdot
.886 .19445 Mdot
.886 .19478 Mdot
.886 .19529 Mdot
.886 .19596 Mdot
.886 .19668 Mdot
.886 .1968 Mdot
.886 .19703 Mdot
.886 .19729 Mdot
.886 .19741 Mdot
.886 .19794 Mdot
.886 .19901 Mdot
.886 .19996 Mdot
.886 .20003 Mdot
.886 .20005 Mdot
.886 .20052 Mdot
.886 .20075 Mdot
.886 .20103 Mdot
.886 .20151 Mdot
.886 .2032 Mdot
.886 .20328 Mdot
.886 .2037 Mdot
.886 .20374 Mdot
.886 .20396 Mdot
.886 .20431 Mdot
.886 .20478 Mdot
.886 .20485 Mdot
.886 .20537 Mdot
.886 .20567 Mdot
.886 .20648 Mdot
.886 .20684 Mdot
.886 .20686 Mdot
.886 .20687 Mdot
.886 .20905 Mdot
.886 .21126 Mdot
.886 .21127 Mdot
.886 .21127 Mdot
.886 .21132 Mdot
.886 .21166 Mdot
.886 .21181 Mdot
.886 .21192 Mdot
.886 .21286 Mdot
.886 .2132 Mdot
.886 .21359 Mdot
.886 .21439 Mdot
.886 .21497 Mdot
.886 .21565 Mdot
.886 .21584 Mdot
.886 .21725 Mdot
.886 .21732 Mdot
.886 .21746 Mdot
.886 .21926 Mdot
.886 .21936 Mdot
.886 .22064 Mdot
.886 .22093 Mdot
.886 .22148 Mdot
.886 .22184 Mdot
.886 .22308 Mdot
.886 .22439 Mdot
.886 .22492 Mdot
.886 .22616 Mdot
.886 .22651 Mdot
.886 .22652 Mdot
.886 .22671 Mdot
.886 .22733 Mdot
.886 .22791 Mdot
.886 .22814 Mdot
.886 .22868 Mdot
.886 .22928 Mdot
.886 .22959 Mdot
.886 .23088 Mdot
.886 .23146 Mdot
.886 .23208 Mdot
.886 .23282 Mdot
.886 .2332 Mdot
.886 .23368 Mdot
.886 .23504 Mdot
.886 .23534 Mdot
.886 .23537 Mdot
.886 .2356 Mdot
.886 .23663 Mdot
.886 .23676 Mdot
.886 .23682 Mdot
.886 .2369 Mdot
.886 .23874 Mdot
.886 .23877 Mdot
.886 .23882 Mdot
.886 .23892 Mdot
.886 .23964 Mdot
.886 .24027 Mdot
.886 .24211 Mdot
.886 .24277 Mdot
.886 .24277 Mdot
.886 .24347 Mdot
.886 .24417 Mdot
.886 .24419 Mdot
.886 .24438 Mdot
.886 .24535 Mdot
.886 .24557 Mdot
.886 .24563 Mdot
.886 .24672 Mdot
.886 .24754 Mdot
.886 .24794 Mdot
.886 .24892 Mdot
.886 .24903 Mdot
.886 .24909 Mdot
.886 .24929 Mdot
.886 .25001 Mdot
.886 .25042 Mdot
.886 .25193 Mdot
.886 .25225 Mdot
.886 .25293 Mdot
.886 .25298 Mdot
.886 .254 Mdot
.886 .25421 Mdot
.886 .25421 Mdot
.886 .25466 Mdot
.886 .25472 Mdot
.886 .25573 Mdot
.886 .25585 Mdot
.886 .25616 Mdot
.886 .2562 Mdot
.886 .25799 Mdot
.886 .25801 Mdot
.886 .25849 Mdot
.886 .25906 Mdot
.886 .25921 Mdot
.886 .26026 Mdot
.886 .26177 Mdot
.886 .26229 Mdot
.886 .26277 Mdot
.886 .26381 Mdot
.886 .26396 Mdot
.886 .26409 Mdot
.886 .26413 Mdot
.886 .26473 Mdot
.886 .2648 Mdot
.886 .26509 Mdot
.886 .26581 Mdot
.886 .26605 Mdot
.886 .26651 Mdot
.886 .26698 Mdot
.886 .26739 Mdot
.886 .26815 Mdot
.886 .26922 Mdot
.886 .26926 Mdot
.886 .26927 Mdot
.886 .26964 Mdot
.886 .26991 Mdot
.886 .27199 Mdot
.886 .27251 Mdot
.886 .27293 Mdot
.886 .27293 Mdot
.886 .27341 Mdot
.886 .2738 Mdot
.886 .27382 Mdot
.886 .27394 Mdot
.886 .27489 Mdot
.886 .27504 Mdot
.886 .27581 Mdot
.886 .27603 Mdot
.886 .27682 Mdot
.886 .27694 Mdot
.886 .27849 Mdot
.886 .27919 Mdot
.886 .27963 Mdot
.886 .27995 Mdot
.886 .28011 Mdot
.886 .28068 Mdot
.886 .28116 Mdot
.886 .28139 Mdot
.886 .28153 Mdot
.886 .28186 Mdot
.886 .28286 Mdot
.886 .28399 Mdot
.886 .28405 Mdot
.886 .28415 Mdot
.886 .28469 Mdot
.886 .28496 Mdot
.886 .28535 Mdot
.886 .2854 Mdot
.886 .28554 Mdot
.886 .2862 Mdot
.886 .28653 Mdot
.886 .28654 Mdot
.886 .28815 Mdot
.886 .28902 Mdot
.886 .28916 Mdot
.886 .28991 Mdot
.886 .29002 Mdot
.886 .29008 Mdot
.886 .29123 Mdot
.886 .2913 Mdot
.886 .29168 Mdot
.886 .29208 Mdot
.886 .29226 Mdot
.886 .29316 Mdot
.886 .29454 Mdot
.886 .29464 Mdot
.886 .29572 Mdot
.886 .29631 Mdot
.886 .29663 Mdot
.886 .29666 Mdot
.886 .29862 Mdot
.886 .29961 Mdot
.886 .2998 Mdot
.886 .30003 Mdot
.886 .30019 Mdot
.886 .30023 Mdot
.886 .30042 Mdot
.886 .30054 Mdot
.886 .30156 Mdot
.886 .30156 Mdot
.886 .30193 Mdot
.886 .30306 Mdot
.886 .30328 Mdot
.886 .30431 Mdot
.886 .30434 Mdot
.886 .30464 Mdot
.886 .30472 Mdot
.886 .30736 Mdot
.886 .30744 Mdot
.886 .30748 Mdot
.886 .30771 Mdot
.886 .30797 Mdot
.886 .3082 Mdot
.886 .30904 Mdot
.886 .31061 Mdot
.886 .31127 Mdot
.886 .31128 Mdot
.886 .31186 Mdot
.886 .31202 Mdot
.886 .3122 Mdot
.886 .31282 Mdot
.886 .31351 Mdot
.886 .31377 Mdot
.886 .31386 Mdot
.886 .31388 Mdot
.886 .31399 Mdot
.886 .31417 Mdot
.886 .31514 Mdot
.886 .31532 Mdot
.886 .31694 Mdot
.886 .31809 Mdot
.886 .31895 Mdot
.886 .319 Mdot
.886 .31923 Mdot
.886 .32104 Mdot
.886 .32121 Mdot
.886 .32174 Mdot
.886 .32211 Mdot
.886 .32252 Mdot
.886 .32261 Mdot
.886 .32311 Mdot
.886 .32361 Mdot
.886 .32409 Mdot
.886 .32438 Mdot
.886 .32486 Mdot
.886 .32589 Mdot
.886 .32642 Mdot
.886 .32653 Mdot
.886 .32724 Mdot
.886 .3274 Mdot
.886 .32759 Mdot
.886 .32812 Mdot
.886 .32857 Mdot
.886 .32959 Mdot
.886 .32989 Mdot
.886 .33033 Mdot
.886 .33216 Mdot
.886 .33274 Mdot
.886 .33277 Mdot
.886 .33292 Mdot
.886 .33321 Mdot
.886 .33379 Mdot
.886 .33469 Mdot
.886 .33589 Mdot
.886 .33628 Mdot
.886 .33649 Mdot
.886 .33678 Mdot
.886 .33715 Mdot
.886 .33737 Mdot
.886 .33778 Mdot
.886 .33823 Mdot
.886 .33845 Mdot
.886 .33849 Mdot
.886 .33933 Mdot
.886 .33939 Mdot
.886 .34055 Mdot
.886 .3407 Mdot
.886 .34117 Mdot
.886 .34128 Mdot
.886 .34297 Mdot
.886 .3431 Mdot
.886 .34312 Mdot
.886 .34323 Mdot
.886 .34397 Mdot
.886 .34427 Mdot
.886 .34429 Mdot
.886 .34437 Mdot
.886 .34486 Mdot
.886 .34572 Mdot
.886 .34871 Mdot
.886 .34885 Mdot
.886 .34935 Mdot
.886 .34959 Mdot
.886 .34966 Mdot
.886 .35005 Mdot
.886 .35067 Mdot
.886 .35151 Mdot
.886 .35164 Mdot
.886 .35209 Mdot
.886 .35252 Mdot
.886 .35255 Mdot
.886 .35309 Mdot
.886 .35453 Mdot
.886 .35489 Mdot
.886 .35517 Mdot
.886 .35519 Mdot
.886 .35522 Mdot
.886 .35522 Mdot
.886 .35539 Mdot
.886 .35904 Mdot
.886 .35907 Mdot
.886 .35925 Mdot
.886 .36044 Mdot
.886 .3617 Mdot
.886 .36226 Mdot
.886 .36299 Mdot
.886 .36301 Mdot
.886 .36301 Mdot
.886 .3631 Mdot
.886 .36369 Mdot
.886 .36397 Mdot
.886 .36416 Mdot
.886 .36508 Mdot
.886 .36582 Mdot
.886 .36644 Mdot
.886 .36712 Mdot
.886 .36854 Mdot
.886 .36941 Mdot
.886 .36957 Mdot
.886 .36973 Mdot
.886 .37078 Mdot
.886 .37111 Mdot
.886 .37312 Mdot
.886 .37361 Mdot
.886 .37373 Mdot
.886 .37399 Mdot
.886 .37497 Mdot
.886 .37598 Mdot
.886 .37607 Mdot
.886 .37717 Mdot
.886 .37734 Mdot
.886 .37962 Mdot
.886 .38013 Mdot
.886 .38111 Mdot
.886 .38174 Mdot
.886 .38223 Mdot
.886 .38394 Mdot
.886 .38533 Mdot
.886 .38594 Mdot
.886 .38626 Mdot
.886 .38667 Mdot
.886 .38715 Mdot
.886 .38719 Mdot
.886 .38729 Mdot
.886 .38787 Mdot
.886 .38826 Mdot
.886 .38939 Mdot
.886 .39002 Mdot
.886 .39004 Mdot
.886 .39036 Mdot
.886 .39145 Mdot
.886 .39146 Mdot
.886 .39147 Mdot
.886 .3925 Mdot
.886 .39263 Mdot
.886 .39291 Mdot
.886 .39387 Mdot
.886 .39492 Mdot
.886 .39547 Mdot
.886 .39617 Mdot
.886 .39686 Mdot
.886 .39776 Mdot
.886 .39879 Mdot
.886 .39989 Mdot
.886 .40008 Mdot
.886 .40019 Mdot
.886 .40113 Mdot
.886 .40119 Mdot
.886 .40139 Mdot
.886 .40187 Mdot
.886 .40273 Mdot
.886 .40514 Mdot
.886 .40567 Mdot
.886 .40571 Mdot
.886 .40613 Mdot
.886 .40795 Mdot
.886 .40817 Mdot
.886 .40829 Mdot
.886 .40842 Mdot
.886 .40967 Mdot
.886 .40993 Mdot
.886 .41004 Mdot
.886 .41077 Mdot
.886 .41169 Mdot
.886 .41174 Mdot
.886 .41183 Mdot
.886 .41201 Mdot
.886 .4123 Mdot
.886 .41328 Mdot
.886 .4138 Mdot
.886 .4144 Mdot
.886 .41494 Mdot
.886 .41766 Mdot
.886 .41882 Mdot
.886 .41883 Mdot
.886 .42006 Mdot
.886 .42131 Mdot
.886 .42135 Mdot
.886 .42169 Mdot
.886 .42341 Mdot
.886 .42379 Mdot
.886 .4239 Mdot
.886 .42583 Mdot
.886 .42728 Mdot
.886 .42798 Mdot
.886 .42972 Mdot
.886 .42993 Mdot
.886 .43003 Mdot
.886 .43038 Mdot
.886 .43166 Mdot
.886 .43238 Mdot
.886 .43505 Mdot
.886 .43563 Mdot
.886 .43684 Mdot
.886 .43692 Mdot
.886 .43872 Mdot
.886 .43909 Mdot
.886 .4391 Mdot
.886 .4399 Mdot
.886 .44001 Mdot
.886 .44179 Mdot
.886 .44201 Mdot
.886 .44256 Mdot
.886 .44263 Mdot
.886 .44581 Mdot
.886 .44584 Mdot
.886 .44668 Mdot
.886 .4477 Mdot
.886 .44796 Mdot
.886 .44982 Mdot
.886 .45249 Mdot
.886 .45342 Mdot
.886 .45426 Mdot
.886 .45612 Mdot
.886 .45639 Mdot
.886 .45661 Mdot
.886 .45668 Mdot
.886 .45774 Mdot
.886 .45786 Mdot
.886 .45838 Mdot
.886 .45965 Mdot
.886 .46008 Mdot
.886 .46089 Mdot
.886 .46172 Mdot
.886 .46245 Mdot
.886 .46379 Mdot
.886 .4657 Mdot
.886 .46576 Mdot
.886 .46579 Mdot
.886 .46645 Mdot
.886 .46693 Mdot
.886 .47061 Mdot
.886 .47152 Mdot
.886 .47227 Mdot
.886 .47227 Mdot
.886 .47312 Mdot
.886 .47382 Mdot
.886 .47384 Mdot
.886 .47406 Mdot
.886 .47574 Mdot
.886 .47602 Mdot
.886 .47738 Mdot
.886 .47776 Mdot
.886 .47917 Mdot
.886 .47939 Mdot
.886 .48212 Mdot
.886 .48336 Mdot
.886 .48415 Mdot
.886 .48472 Mdot
.886 .48499 Mdot
.886 .486 Mdot
.886 .48686 Mdot
.886 .48726 Mdot
.886 .48751 Mdot
.886 .48809 Mdot
.886 .48987 Mdot
.886 .49187 Mdot
.886 .49199 Mdot
.886 .49215 Mdot
.886 .49311 Mdot
.886 .49359 Mdot
.886 .49428 Mdot
.886 .49436 Mdot
.886 .49462 Mdot
.886 .49579 Mdot
.886 .49638 Mdot
.886 .49638 Mdot
.886 .49924 Mdot
.886 .50079 Mdot
.886 .50103 Mdot
.886 .50237 Mdot
.886 .50256 Mdot
.886 .50265 Mdot
.886 .50471 Mdot
.886 .50483 Mdot
.886 .5055 Mdot
.886 .50621 Mdot
.886 .50653 Mdot
.886 .50812 Mdot
.886 .51057 Mdot
.886 .51074 Mdot
.886 .51265 Mdot
.886 .5137 Mdot
.886 .51427 Mdot
.886 .51432 Mdot
.886 .5178 Mdot
.886 .51955 Mdot
.886 .51989 Mdot
.886 .5203 Mdot
.886 .52057 Mdot
.886 .52065 Mdot
.886 .52098 Mdot
.886 .5212 Mdot
.886 .523 Mdot
.886 .52301 Mdot
.886 .52367 Mdot
.886 .52567 Mdot
.886 .52605 Mdot
.886 .52787 Mdot
.886 .52793 Mdot
.886 .52846 Mdot
.886 .52861 Mdot
.886 .53328 Mdot
.886 .53343 Mdot
.886 .53349 Mdot
.886 .5339 Mdot
.886 .53477 Mdot
.886 .53625 Mdot
.888 .01476 Mdot
.888 .0148 Mdot
.888 .01487 Mdot
.888 .01499 Mdot
.888 .01516 Mdot
.888 .01521 Mdot
.888 .01536 Mdot
.888 .01551 Mdot
.888 .01559 Mdot
.888 .01587 Mdot
.888 .01612 Mdot
.888 .01626 Mdot
.888 .01642 Mdot
.888 .01676 Mdot
.888 .01722 Mdot
.888 .01747 Mdot
.888 .01775 Mdot
.888 .01804 Mdot
.888 .01834 Mdot
.888 .01916 Mdot
.888 .01922 Mdot
.888 .01948 Mdot
.888 .0196 Mdot
.888 .0201 Mdot
.888 .02062 Mdot
.888 .02116 Mdot
.888 .02145 Mdot
.888 .02239 Mdot
.888 .02239 Mdot
.888 .0226 Mdot
.888 .02264 Mdot
.888 .02272 Mdot
.888 .02317 Mdot
.888 .02339 Mdot
.888 .02428 Mdot
.888 .02499 Mdot
.888 .02502 Mdot
.888 .02521 Mdot
.888 .02568 Mdot
.888 .02616 Mdot
.888 .02668 Mdot
.888 .02673 Mdot
.888 .02741 Mdot
.888 .02743 Mdot
.888 .02834 Mdot
.888 .02835 Mdot
.888 .02872 Mdot
.888 .02879 Mdot
.888 .02893 Mdot
.888 .02971 Mdot
.888 .02973 Mdot
.888 .03013 Mdot
.888 .03075 Mdot
.888 .03136 Mdot
.888 .03138 Mdot
.888 .03169 Mdot
.888 .03297 Mdot
.888 .03303 Mdot
.888 .03335 Mdot
.888 .03412 Mdot
.888 .03418 Mdot
.888 .03498 Mdot
.888 .03504 Mdot
.888 .03569 Mdot
.888 .03576 Mdot
.888 .03597 Mdot
.888 .03606 Mdot
.888 .03634 Mdot
.888 .03726 Mdot
.888 .0373 Mdot
.888 .03815 Mdot
.888 .03891 Mdot
.888 .03892 Mdot
.888 .039 Mdot
.888 .03959 Mdot
.888 .03971 Mdot
.888 .03996 Mdot
.888 .04003 Mdot
.888 .04072 Mdot
.888 .0409 Mdot
.888 .04134 Mdot
.888 .04138 Mdot
.888 .04209 Mdot
.888 .04306 Mdot
.888 .04319 Mdot
.888 .04326 Mdot
.888 .04377 Mdot
.888 .04427 Mdot
.888 .04432 Mdot
.888 .04487 Mdot
.888 .04713 Mdot
.888 .04723 Mdot
.888 .04782 Mdot
.888 .04837 Mdot
.888 .04886 Mdot
.888 .04917 Mdot
.888 .04929 Mdot
.888 .0503 Mdot
.888 .05071 Mdot
.888 .0508 Mdot
.888 .05171 Mdot
.888 .05197 Mdot
.888 .0521 Mdot
.888 .05246 Mdot
.888 .05254 Mdot
.888 .05259 Mdot
.888 .05262 Mdot
.888 .05312 Mdot
.888 .05392 Mdot
.888 .05475 Mdot
.888 .05483 Mdot
.888 .05515 Mdot
.888 .05539 Mdot
.888 .05615 Mdot
.888 .05633 Mdot
.888 .05768 Mdot
.888 .05771 Mdot
.888 .05784 Mdot
.888 .0582 Mdot
.888 .05835 Mdot
.888 .05858 Mdot
.888 .05889 Mdot
.888 .0591 Mdot
.888 .05955 Mdot
.888 .05967 Mdot
.888 .0609 Mdot
.888 .06122 Mdot
.888 .062 Mdot
.888 .06208 Mdot
.888 .0621 Mdot
.888 .0623 Mdot
.888 .06242 Mdot
.888 .06281 Mdot
.888 .06333 Mdot
.888 .06416 Mdot
.888 .06422 Mdot
.888 .06506 Mdot
.888 .06528 Mdot
.888 .06529 Mdot
.888 .06541 Mdot
.888 .06598 Mdot
.888 .06621 Mdot
.888 .06632 Mdot
.888 .06721 Mdot
.888 .06729 Mdot
.888 .06738 Mdot
.888 .06798 Mdot
.888 .06827 Mdot
.888 .06871 Mdot
.888 .07004 Mdot
.888 .07093 Mdot
.888 .07228 Mdot
.888 .07247 Mdot
.888 .07265 Mdot
.888 .0735 Mdot
.888 .07386 Mdot
.888 .07445 Mdot
.888 .07449 Mdot
.888 .07488 Mdot
.888 .07535 Mdot
.888 .07591 Mdot
.888 .07612 Mdot
.888 .07791 Mdot
.888 .078 Mdot
.888 .07864 Mdot
.888 .07881 Mdot
.888 .07913 Mdot
.888 .08042 Mdot
.888 .08087 Mdot
.888 .0811 Mdot
.888 .08176 Mdot
.888 .08189 Mdot
.888 .08197 Mdot
.888 .08203 Mdot
.888 .08257 Mdot
.888 .08261 Mdot
.888 .08292 Mdot
.888 .08371 Mdot
.888 .0839 Mdot
.888 .08425 Mdot
.888 .08434 Mdot
.888 .08476 Mdot
.888 .08581 Mdot
.888 .08595 Mdot
.888 .08602 Mdot
.888 .0865 Mdot
.888 .08652 Mdot
.888 .08656 Mdot
.888 .08695 Mdot
.888 .08718 Mdot
.888 .08783 Mdot
.888 .0882 Mdot
.888 .08831 Mdot
.888 .08863 Mdot
.888 .09103 Mdot
.888 .09107 Mdot
.888 .09131 Mdot
.888 .09135 Mdot
.888 .09195 Mdot
.888 .09221 Mdot
.888 .09262 Mdot
.888 .09267 Mdot
.888 .09286 Mdot
.888 .093 Mdot
.888 .09317 Mdot
.888 .09355 Mdot
.888 .09366 Mdot
.888 .09433 Mdot
.888 .09456 Mdot
.888 .09532 Mdot
.888 .09569 Mdot
.888 .09673 Mdot
.888 .09731 Mdot
.888 .09837 Mdot
.888 .09854 Mdot
.888 .09869 Mdot
.888 .09883 Mdot
.888 .09886 Mdot
.888 .09923 Mdot
.888 .09944 Mdot
.888 .0999 Mdot
.888 .10013 Mdot
.888 .1005 Mdot
.888 .10106 Mdot
.888 .10156 Mdot
.888 .10252 Mdot
.888 .10263 Mdot
.888 .10412 Mdot
.888 .1042 Mdot
.888 .10435 Mdot
.888 .10436 Mdot
.888 .10452 Mdot
.888 .10453 Mdot
.888 .10475 Mdot
.888 .10576 Mdot
.888 .10617 Mdot
.888 .10636 Mdot
.888 .10708 Mdot
.888 .10742 Mdot
.888 .10794 Mdot
.888 .10809 Mdot
.888 .10825 Mdot
.888 .10847 Mdot
.888 .10926 Mdot
.888 .10931 Mdot
.888 .10983 Mdot
.888 .11029 Mdot
.888 .1106 Mdot
.888 .11072 Mdot
.888 .11073 Mdot
.888 .1122 Mdot
.888 .11298 Mdot
.888 .11455 Mdot
.888 .11568 Mdot
.888 .11695 Mdot
.888 .11704 Mdot
.888 .11728 Mdot
.888 .11761 Mdot
.888 .11833 Mdot
.888 .11912 Mdot
.888 .1192 Mdot
.888 .11976 Mdot
.888 .11996 Mdot
.888 .12081 Mdot
.888 .12087 Mdot
.888 .12158 Mdot
.888 .12241 Mdot
.888 .12339 Mdot
.888 .12377 Mdot
.888 .12396 Mdot
.888 .12446 Mdot
.888 .1256 Mdot
.888 .12648 Mdot
.888 .12696 Mdot
.888 .12711 Mdot
.888 .12724 Mdot
.888 .12796 Mdot
.888 .12805 Mdot
.888 .12825 Mdot
.888 .12841 Mdot
.888 .12855 Mdot
.888 .12912 Mdot
.888 .13047 Mdot
.888 .13048 Mdot
.888 .13118 Mdot
.888 .1314 Mdot
.888 .13221 Mdot
.888 .13262 Mdot
.888 .13335 Mdot
.888 .1337 Mdot
.888 .13378 Mdot
.888 .13402 Mdot
.888 .13413 Mdot
.888 .13416 Mdot
.888 .13427 Mdot
.888 .13522 Mdot
.888 .13529 Mdot
.888 .13585 Mdot
.888 .13674 Mdot
.888 .13726 Mdot
.888 .13759 Mdot
.888 .138 Mdot
.888 .13805 Mdot
.888 .13806 Mdot
.888 .13815 Mdot
.888 .13821 Mdot
.888 .13837 Mdot
.888 .13912 Mdot
.888 .13928 Mdot
.888 .14064 Mdot
.888 .14088 Mdot
.888 .14098 Mdot
.888 .14123 Mdot
.888 .14136 Mdot
.888 .14202 Mdot
.888 .14221 Mdot
.888 .14224 Mdot
.888 .14232 Mdot
.888 .14265 Mdot
.888 .143 Mdot
.888 .14324 Mdot
.888 .14341 Mdot
.888 .1437 Mdot
.888 .14397 Mdot
.888 .14457 Mdot
.888 .14523 Mdot
.888 .14542 Mdot
.888 .14598 Mdot
.888 .1478 Mdot
.888 .14787 Mdot
.888 .15008 Mdot
.888 .15025 Mdot
.888 .15033 Mdot
.888 .15075 Mdot
.888 .15082 Mdot
.888 .15188 Mdot
.888 .15204 Mdot
.888 .15234 Mdot
.888 .15265 Mdot
.888 .15297 Mdot
.888 .15307 Mdot
.888 .15317 Mdot
.888 .1535 Mdot
.888 .15375 Mdot
.888 .15405 Mdot
.888 .15415 Mdot
.888 .15472 Mdot
.888 .15493 Mdot
.888 .15609 Mdot
.888 .15612 Mdot
.888 .15652 Mdot
.888 .15659 Mdot
.888 .15787 Mdot
.888 .15793 Mdot
.888 .15852 Mdot
.888 .15852 Mdot
.888 .15872 Mdot
.888 .15929 Mdot
.888 .16038 Mdot
.888 .16141 Mdot
.888 .16201 Mdot
.888 .16204 Mdot
.888 .16228 Mdot
.888 .16328 Mdot
.888 .16336 Mdot
.888 .1636 Mdot
.888 .16385 Mdot
.888 .16411 Mdot
.888 .16416 Mdot
.888 .16462 Mdot
.888 .16482 Mdot
.888 .16504 Mdot
.888 .16518 Mdot
.888 .16565 Mdot
.888 .166 Mdot
.888 .16642 Mdot
.888 .16659 Mdot
.888 .16706 Mdot
.888 .16807 Mdot
.888 .16818 Mdot
.888 .16894 Mdot
.888 .17066 Mdot
.888 .17085 Mdot
.888 .17295 Mdot
.888 .17317 Mdot
.888 .17351 Mdot
.888 .17363 Mdot
.888 .1739 Mdot
.888 .17392 Mdot
.888 .17421 Mdot
.888 .17423 Mdot
.888 .17462 Mdot
.888 .17605 Mdot
.888 .17618 Mdot
.888 .17641 Mdot
.888 .17715 Mdot
.888 .17747 Mdot
.888 .1779 Mdot
.888 .17875 Mdot
.888 .17937 Mdot
.888 .18021 Mdot
.888 .18028 Mdot
.888 .18046 Mdot
.888 .18047 Mdot
.888 .18054 Mdot
.888 .18056 Mdot
.888 .18083 Mdot
.888 .18103 Mdot
.888 .18122 Mdot
.888 .18141 Mdot
.888 .18226 Mdot
.888 .18263 Mdot
.888 .18271 Mdot
.888 .18363 Mdot
.888 .18446 Mdot
.888 .18468 Mdot
.888 .18501 Mdot
.888 .18523 Mdot
.888 .18523 Mdot
.888 .18595 Mdot
.888 .18629 Mdot
.888 .18648 Mdot
.888 .18735 Mdot
.888 .18785 Mdot
.888 .1889 Mdot
.888 .18923 Mdot
.888 .19019 Mdot
.888 .19203 Mdot
.888 .19402 Mdot
.888 .1941 Mdot
.888 .19434 Mdot
.888 .19499 Mdot
.888 .19504 Mdot
.888 .19629 Mdot
.888 .19633 Mdot
.888 .19645 Mdot
.888 .19688 Mdot
.888 .1969 Mdot
.888 .19746 Mdot
.888 .19832 Mdot
.888 .19874 Mdot
.888 .19902 Mdot
.888 .20014 Mdot
.888 .20028 Mdot
.888 .20127 Mdot
.888 .20163 Mdot
.888 .20271 Mdot
.888 .20314 Mdot
.888 .20325 Mdot
.888 .20341 Mdot
.888 .20381 Mdot
.888 .20396 Mdot
.888 .20398 Mdot
.888 .20418 Mdot
.888 .20438 Mdot
.888 .2045 Mdot
.888 .20592 Mdot
.888 .20598 Mdot
.888 .20602 Mdot
.888 .20623 Mdot
.888 .20676 Mdot
.888 .20687 Mdot
.888 .20772 Mdot
.888 .20821 Mdot
.888 .2084 Mdot
.888 .20873 Mdot
.888 .20957 Mdot
.888 .20962 Mdot
.888 .20962 Mdot
.888 .21048 Mdot
.888 .21164 Mdot
.888 .21164 Mdot
.888 .21211 Mdot
.888 .21321 Mdot
.888 .21364 Mdot
.888 .21405 Mdot
.888 .21433 Mdot
.888 .21457 Mdot
.888 .21584 Mdot
.888 .216 Mdot
.888 .21636 Mdot
.888 .21664 Mdot
.888 .21688 Mdot
.888 .2179 Mdot
.888 .2203 Mdot
.888 .22031 Mdot
.888 .22069 Mdot
.888 .22156 Mdot
.888 .22176 Mdot
.888 .22195 Mdot
.888 .22339 Mdot
.888 .22412 Mdot
.888 .22493 Mdot
.888 .22504 Mdot
.888 .22541 Mdot
.888 .22602 Mdot
.888 .22618 Mdot
.888 .22661 Mdot
.888 .22679 Mdot
.888 .22686 Mdot
.888 .22704 Mdot
.888 .22799 Mdot
.888 .22873 Mdot
.888 .22886 Mdot
.888 .22935 Mdot
.888 .22986 Mdot
.888 .23144 Mdot
.888 .23235 Mdot
.888 .23294 Mdot
.888 .23367 Mdot
.888 .23375 Mdot
.888 .23378 Mdot
.888 .23393 Mdot
.888 .23405 Mdot
.888 .23432 Mdot
.888 .23509 Mdot
.888 .23549 Mdot
.888 .23566 Mdot
.888 .23594 Mdot
.888 .23683 Mdot
.888 .23815 Mdot
.888 .23836 Mdot
.888 .23878 Mdot
.888 .23896 Mdot
.888 .23941 Mdot
.888 .23964 Mdot
.888 .24081 Mdot
.888 .24115 Mdot
.888 .2412 Mdot
.888 .24121 Mdot
.888 .24133 Mdot
.888 .24192 Mdot
.888 .24255 Mdot
.888 .24298 Mdot
.888 .24327 Mdot
.888 .24378 Mdot
.888 .24427 Mdot
.888 .24651 Mdot
.888 .24684 Mdot
.888 .24785 Mdot
.888 .24788 Mdot
.888 .24882 Mdot
.888 .24925 Mdot
.888 .25107 Mdot
.888 .2512 Mdot
.888 .25162 Mdot
.888 .25204 Mdot
.888 .25301 Mdot
.888 .25513 Mdot
.888 .25542 Mdot
.888 .25556 Mdot
.888 .25631 Mdot
.888 .25644 Mdot
.888 .25675 Mdot
.888 .25794 Mdot
.888 .25831 Mdot
.888 .25861 Mdot
.888 .25886 Mdot
.888 .25914 Mdot
.888 .25967 Mdot
.888 .25969 Mdot
.888 .26026 Mdot
.888 .26044 Mdot
.888 .26053 Mdot
.888 .26061 Mdot
.888 .2612 Mdot
.888 .26165 Mdot
.888 .26218 Mdot
.888 .26222 Mdot
.888 .26228 Mdot
.888 .26236 Mdot
.888 .26336 Mdot
.888 .26373 Mdot
.888 .26409 Mdot
.888 .26465 Mdot
.888 .26493 Mdot
.888 .26519 Mdot
.888 .2658 Mdot
.888 .26585 Mdot
.888 .26657 Mdot
.888 .26669 Mdot
.888 .26705 Mdot
.888 .26845 Mdot
.888 .26895 Mdot
.888 .26906 Mdot
.888 .27011 Mdot
.888 .27012 Mdot
.888 .27014 Mdot
.888 .27026 Mdot
.888 .27044 Mdot
.888 .27046 Mdot
.888 .27069 Mdot
.888 .27148 Mdot
.888 .27342 Mdot
.888 .27386 Mdot
.888 .27502 Mdot
.888 .27525 Mdot
.888 .27615 Mdot
.888 .27631 Mdot
.888 .27636 Mdot
.888 .27679 Mdot
.888 .27792 Mdot
.888 .27856 Mdot
.888 .2787 Mdot
.888 .27881 Mdot
.888 .27913 Mdot
.888 .27959 Mdot
.888 .27962 Mdot
.888 .28004 Mdot
.888 .28013 Mdot
.888 .28095 Mdot
.888 .2813 Mdot
.888 .28155 Mdot
.888 .2817 Mdot
.888 .28171 Mdot
.888 .28194 Mdot
.888 .28278 Mdot
.888 .2834 Mdot
.888 .28397 Mdot
.888 .28414 Mdot
.888 .28435 Mdot
.888 .28445 Mdot
.888 .28529 Mdot
.888 .2855 Mdot
.888 .28706 Mdot
.888 .28726 Mdot
.888 .28863 Mdot
.888 .28991 Mdot
.888 .29149 Mdot
.888 .29168 Mdot
.888 .29182 Mdot
.888 .29201 Mdot
.888 .29516 Mdot
.888 .29518 Mdot
.888 .29524 Mdot
.888 .29561 Mdot
.888 .29574 Mdot
.888 .29612 Mdot
.888 .29618 Mdot
.888 .29626 Mdot
.888 .29673 Mdot
.888 .29695 Mdot
.888 .29698 Mdot
.888 .29742 Mdot
.888 .29747 Mdot
.888 .29797 Mdot
.888 .29802 Mdot
.888 .29871 Mdot
.888 .29946 Mdot
.888 .30124 Mdot
.888 .30124 Mdot
.888 .30148 Mdot
.888 .30189 Mdot
.888 .30319 Mdot
.888 .30377 Mdot
.888 .30453 Mdot
.888 .30557 Mdot
.888 .30604 Mdot
.888 .30697 Mdot
.888 .30713 Mdot
.888 .30863 Mdot
.888 .30877 Mdot
.888 .30908 Mdot
.888 .3091 Mdot
.888 .30923 Mdot
.888 .30925 Mdot
.888 .30974 Mdot
.888 .3101 Mdot
.888 .31042 Mdot
.888 .31065 Mdot
.888 .31076 Mdot
.888 .31136 Mdot
.888 .31227 Mdot
.888 .31293 Mdot
.888 .31308 Mdot
.888 .31419 Mdot
.888 .31472 Mdot
.888 .31472 Mdot
.888 .31486 Mdot
.888 .31618 Mdot
.888 .3162 Mdot
.888 .31657 Mdot
.888 .31716 Mdot
.888 .31754 Mdot
.888 .31756 Mdot
.888 .31884 Mdot
.888 .31942 Mdot
.888 .31977 Mdot
.888 .31978 Mdot
.888 .32132 Mdot
.888 .32181 Mdot
.888 .32221 Mdot
.888 .32225 Mdot
.888 .32257 Mdot
.888 .32359 Mdot
.888 .32407 Mdot
.888 .32465 Mdot
.888 .32504 Mdot
.888 .32514 Mdot
.888 .32636 Mdot
.888 .32647 Mdot
.888 .32676 Mdot
.888 .32935 Mdot
.888 .32962 Mdot
.888 .33043 Mdot
.888 .33123 Mdot
.888 .33169 Mdot
.888 .33172 Mdot
.888 .33247 Mdot
.888 .33316 Mdot
.888 .3333 Mdot
.888 .33373 Mdot
.888 .33488 Mdot
.888 .33496 Mdot
.888 .3351 Mdot
.888 .33707 Mdot
.888 .33719 Mdot
.888 .33726 Mdot
.888 .33748 Mdot
.888 .33824 Mdot
.888 .33827 Mdot
.888 .33887 Mdot
.888 .33926 Mdot
.888 .33939 Mdot
.888 .34005 Mdot
.888 .34039 Mdot
.888 .3408 Mdot
.888 .34155 Mdot
.888 .34205 Mdot
.888 .34302 Mdot
.888 .3437 Mdot
.888 .34403 Mdot
.888 .34428 Mdot
.888 .34603 Mdot
.888 .34667 Mdot
.888 .3486 Mdot
.888 .34862 Mdot
.888 .34925 Mdot
.888 .34935 Mdot
.888 .34955 Mdot
.888 .34984 Mdot
.888 .35055 Mdot
.888 .35082 Mdot
.888 .35085 Mdot
.888 .3512 Mdot
.888 .35157 Mdot
.888 .35177 Mdot
.888 .35355 Mdot
.888 .35429 Mdot
.888 .3544 Mdot
.888 .35448 Mdot
.888 .35485 Mdot
.888 .35578 Mdot
.888 .35599 Mdot
.888 .3575 Mdot
.888 .3576 Mdot
.888 .35836 Mdot
.888 .3587 Mdot
.888 .35929 Mdot
.888 .36078 Mdot
.888 .36086 Mdot
.888 .36087 Mdot
.888 .3624 Mdot
.888 .3626 Mdot
.888 .36318 Mdot
.888 .36363 Mdot
.888 .36421 Mdot
.888 .36445 Mdot
.888 .36446 Mdot
.888 .36529 Mdot
.888 .36724 Mdot
.888 .36801 Mdot
.888 .36874 Mdot
.888 .36923 Mdot
.888 .36965 Mdot
.888 .37191 Mdot
.888 .37219 Mdot
.888 .37283 Mdot
.888 .37333 Mdot
.888 .37376 Mdot
.888 .37416 Mdot
.888 .37421 Mdot
.888 .37441 Mdot
.888 .37558 Mdot
.888 .37558 Mdot
.888 .37597 Mdot
.888 .37719 Mdot
.888 .37739 Mdot
.888 .37763 Mdot
.888 .37911 Mdot
.888 .37981 Mdot
.888 .37984 Mdot
.888 .37985 Mdot
.888 .3799 Mdot
.888 .38053 Mdot
.888 .3813 Mdot
.888 .38143 Mdot
.888 .38208 Mdot
.888 .38243 Mdot
.888 .38277 Mdot
.888 .38302 Mdot
.888 .38317 Mdot
.888 .38533 Mdot
.888 .38537 Mdot
.888 .38662 Mdot
.888 .38772 Mdot
.888 .38806 Mdot
.888 .38824 Mdot
.888 .38891 Mdot
.888 .39 Mdot
.888 .39028 Mdot
.888 .39103 Mdot
.888 .39137 Mdot
.888 .39148 Mdot
.888 .3918 Mdot
.888 .39333 Mdot
.888 .39335 Mdot
.888 .39348 Mdot
.888 .39409 Mdot
.888 .3948 Mdot
.888 .39504 Mdot
.888 .39538 Mdot
.888 .39591 Mdot
.888 .3968 Mdot
.888 .39949 Mdot
.888 .39961 Mdot
.888 .40124 Mdot
.888 .40131 Mdot
.888 .40228 Mdot
.888 .40358 Mdot
.888 .40372 Mdot
.888 .40373 Mdot
.888 .40377 Mdot
.888 .40404 Mdot
.888 .40425 Mdot
.888 .40473 Mdot
.888 .4061 Mdot
.888 .40681 Mdot
.888 .407 Mdot
.888 .40711 Mdot
.888 .4076 Mdot
.888 .40847 Mdot
.888 .4092 Mdot
.888 .4114 Mdot
.888 .41154 Mdot
.888 .4119 Mdot
.888 .41193 Mdot
.888 .41265 Mdot
.888 .41298 Mdot
.888 .41378 Mdot
.888 .41417 Mdot
.888 .41625 Mdot
.888 .41664 Mdot
.888 .41687 Mdot
.888 .41695 Mdot
.888 .41696 Mdot
.888 .41707 Mdot
.888 .41719 Mdot
.888 .41806 Mdot
.888 .41811 Mdot
.888 .41823 Mdot
.888 .41853 Mdot
.888 .41859 Mdot
.888 .41935 Mdot
.888 .42011 Mdot
.888 .42014 Mdot
.888 .42063 Mdot
.888 .42128 Mdot
.888 .42154 Mdot
.888 .42241 Mdot
.888 .42637 Mdot
.888 .42698 Mdot
.888 .42876 Mdot
.888 .42882 Mdot
.888 .43048 Mdot
.888 .43125 Mdot
.888 .43448 Mdot
.888 .43471 Mdot
.888 .43546 Mdot
.888 .4362 Mdot
.888 .43793 Mdot
.888 .44168 Mdot
.888 .44221 Mdot
.888 .44245 Mdot
.888 .44379 Mdot
.888 .44403 Mdot
.888 .44457 Mdot
.888 .44668 Mdot
.888 .44735 Mdot
.888 .44787 Mdot
.888 .44832 Mdot
.888 .44881 Mdot
.888 .44976 Mdot
.888 .44979 Mdot
.888 .45081 Mdot
.888 .45112 Mdot
.888 .45128 Mdot
.888 .45143 Mdot
.888 .45248 Mdot
.888 .45326 Mdot
.888 .45422 Mdot
.888 .45428 Mdot
.888 .45438 Mdot
.888 .45453 Mdot
.888 .45631 Mdot
.888 .45697 Mdot
.888 .4576 Mdot
.888 .4586 Mdot
.888 .4591 Mdot
.888 .45955 Mdot
.888 .46064 Mdot
.888 .46073 Mdot
.888 .462 Mdot
.888 .46222 Mdot
.888 .46287 Mdot
.888 .46535 Mdot
.888 .46624 Mdot
.888 .46643 Mdot
.888 .4683 Mdot
.888 .46831 Mdot
.888 .46835 Mdot
.888 .46856 Mdot
.888 .46888 Mdot
.888 .46892 Mdot
.888 .46933 Mdot
.888 .47073 Mdot
.888 .47417 Mdot
.888 .47495 Mdot
.888 .47702 Mdot
.888 .47742 Mdot
.888 .47902 Mdot
.888 .47932 Mdot
.888 .4794 Mdot
.888 .48015 Mdot
.888 .48217 Mdot
.888 .48331 Mdot
.888 .48356 Mdot
.888 .48374 Mdot
.888 .48431 Mdot
.888 .48513 Mdot
.888 .48519 Mdot
.888 .48593 Mdot
.888 .48609 Mdot
.888 .48755 Mdot
.888 .48816 Mdot
.888 .48861 Mdot
.888 .48888 Mdot
.888 .48889 Mdot
.888 .48931 Mdot
.888 .49079 Mdot
.888 .4919 Mdot
.888 .49291 Mdot
.888 .49321 Mdot
.888 .49358 Mdot
.888 .49377 Mdot
.888 .49525 Mdot
.888 .49563 Mdot
.888 .49841 Mdot
.888 .49876 Mdot
.888 .50118 Mdot
.888 .50346 Mdot
.888 .50628 Mdot
.888 .50661 Mdot
.888 .50686 Mdot
.888 .50719 Mdot
.888 .51279 Mdot
.888 .51281 Mdot
.888 .51293 Mdot
.888 .51358 Mdot
.888 .51381 Mdot
.888 .5145 Mdot
.888 .5146 Mdot
.888 .51474 Mdot
.888 .51557 Mdot
.888 .51597 Mdot
.888 .51602 Mdot
.888 .51681 Mdot
.888 .51688 Mdot
.888 .51778 Mdot
.888 .51786 Mdot
.888 .5191 Mdot
.888 .52042 Mdot
.888 .52358 Mdot
.888 .52359 Mdot
.888 .52401 Mdot
.888 .52474 Mdot
.888 .52705 Mdot
.888 .52807 Mdot
.888 .52943 Mdot
.888 .53128 Mdot
.888 .53211 Mdot
.888 .53375 Mdot
.888 .53405 Mdot
.888 .53671 Mdot
.888 .53695 Mdot
.888 .5375 Mdot
.888 .53754 Mdot
.888 .53777 Mdot
.888 .53781 Mdot
.888 .53868 Mdot
.888 .53932 Mdot
.89 .01514 Mdot
.89 .01547 Mdot
.89 .01607 Mdot
.89 .01611 Mdot
.89 .01668 Mdot
.89 .01712 Mdot
.89 .01719 Mdot
.89 .01821 Mdot
.89 .01899 Mdot
.89 .01912 Mdot
.89 .02093 Mdot
.89 .02111 Mdot
.89 .02113 Mdot
.89 .02133 Mdot
.89 .02233 Mdot
.89 .02256 Mdot
.89 .02265 Mdot
.89 .02284 Mdot
.89 .02287 Mdot
.89 .02312 Mdot
.89 .02444 Mdot
.89 .02459 Mdot
.89 .02568 Mdot
.89 .02578 Mdot
.89 .02611 Mdot
.89 .02614 Mdot
.89 .02649 Mdot
.89 .02732 Mdot
.89 .0276 Mdot
.89 .02787 Mdot
.89 .02806 Mdot
.89 .02827 Mdot
.89 .02863 Mdot
.89 .02867 Mdot
.89 .02884 Mdot
.89 .02917 Mdot
.89 .02923 Mdot
.89 .0294 Mdot
.89 .02963 Mdot
.89 .02968 Mdot
.89 .03112 Mdot
.89 .03172 Mdot
.89 .0319 Mdot
.89 .03202 Mdot
.89 .03229 Mdot
.89 .03274 Mdot
.89 .03342 Mdot
.89 .03424 Mdot
.89 .03437 Mdot
.89 .03442 Mdot
.89 .03499 Mdot
.89 .03505 Mdot
.89 .0351 Mdot
.89 .03568 Mdot
.89 .0364 Mdot
.89 .03686 Mdot
.89 .03716 Mdot
.89 .03766 Mdot
.89 .03813 Mdot
.89 .03846 Mdot
.89 .03882 Mdot
.89 .03884 Mdot
.89 .03949 Mdot
.89 .03956 Mdot
.89 .03985 Mdot
.89 .03992 Mdot
.89 .04045 Mdot
.89 .04055 Mdot
.89 .04086 Mdot
.89 .04127 Mdot
.89 .04136 Mdot
.89 .04154 Mdot
.89 .04261 Mdot
.89 .04392 Mdot
.89 .04462 Mdot
.89 .04499 Mdot
.89 .04522 Mdot
.89 .04531 Mdot
.89 .04552 Mdot
.89 .04584 Mdot
.89 .04599 Mdot
.89 .04612 Mdot
.89 .04662 Mdot
.89 .0468 Mdot
.89 .04728 Mdot
.89 .04734 Mdot
.89 .04802 Mdot
.89 .04947 Mdot
.89 .04966 Mdot
.89 .04969 Mdot
.89 .04978 Mdot
.89 .05081 Mdot
.89 .05091 Mdot
.89 .05092 Mdot
.89 .051 Mdot
.89 .05171 Mdot
.89 .05203 Mdot
.89 .05256 Mdot
.89 .05281 Mdot
.89 .05332 Mdot
.89 .05364 Mdot
.89 .05413 Mdot
.89 .0543 Mdot
.89 .05466 Mdot
.89 .05505 Mdot
.89 .05555 Mdot
.89 .05625 Mdot
.89 .05639 Mdot
.89 .05645 Mdot
.89 .05698 Mdot
.89 .05716 Mdot
.89 .05763 Mdot
.89 .05766 Mdot
.89 .05796 Mdot
.89 .05843 Mdot
.89 .05881 Mdot
.89 .05894 Mdot
.89 .05914 Mdot
.89 .05946 Mdot
.89 .05958 Mdot
.89 .05987 Mdot
.89 .06028 Mdot
.89 .06053 Mdot
.89 .06071 Mdot
.89 .06126 Mdot
.89 .0617 Mdot
.89 .06198 Mdot
.89 .06203 Mdot
.89 .06214 Mdot
.89 .06246 Mdot
.89 .06437 Mdot
.89 .06467 Mdot
.89 .06493 Mdot
.89 .06502 Mdot
.89 .06583 Mdot
.89 .0667 Mdot
.89 .0678 Mdot
.89 .06795 Mdot
.89 .06845 Mdot
.89 .06861 Mdot
.89 .06901 Mdot
.89 .06917 Mdot
.89 .06935 Mdot
.89 .06954 Mdot
.89 .07012 Mdot
.89 .07024 Mdot
.89 .07032 Mdot
.89 .07039 Mdot
.89 .07039 Mdot
.89 .07062 Mdot
.89 .07145 Mdot
.89 .0715 Mdot
.89 .07157 Mdot
.89 .07182 Mdot
.89 .07243 Mdot
.89 .0725 Mdot
.89 .07269 Mdot
.89 .07279 Mdot
.89 .07383 Mdot
.89 .07399 Mdot
.89 .07582 Mdot
.89 .07592 Mdot
.89 .07658 Mdot
.89 .07661 Mdot
.89 .07679 Mdot
.89 .07691 Mdot
.89 .07698 Mdot
.89 .07714 Mdot
.89 .07896 Mdot
.89 .07914 Mdot
.89 .07917 Mdot
.89 .07931 Mdot
.89 .07997 Mdot
.89 .08057 Mdot
.89 .08114 Mdot
.89 .08184 Mdot
.89 .08208 Mdot
.89 .08253 Mdot
.89 .08256 Mdot
.89 .08342 Mdot
.89 .0835 Mdot
.89 .084 Mdot
.89 .08488 Mdot
.89 .08518 Mdot
.89 .08541 Mdot
.89 .08551 Mdot
.89 .08582 Mdot
.89 .0865 Mdot
.89 .0874 Mdot
.89 .08747 Mdot
.89 .08781 Mdot
.89 .08864 Mdot
.89 .08889 Mdot
.89 .089 Mdot
.89 .08995 Mdot
.89 .09027 Mdot
.89 .0911 Mdot
.89 .09115 Mdot
.89 .09136 Mdot
.89 .09169 Mdot
.89 .09213 Mdot
.89 .09252 Mdot
.89 .09321 Mdot
.89 .09343 Mdot
.89 .09379 Mdot
.89 .09435 Mdot
.89 .09457 Mdot
.89 .09509 Mdot
.89 .09582 Mdot
.89 .09626 Mdot
.89 .09659 Mdot
.89 .09756 Mdot
.89 .09835 Mdot
.89 .09885 Mdot
.89 .09893 Mdot
.89 .09912 Mdot
.89 .09971 Mdot
.89 .10002 Mdot
.89 .10182 Mdot
.89 .10184 Mdot
.89 .10193 Mdot
.89 .10281 Mdot
.89 .1031 Mdot
.89 .10364 Mdot
.89 .1041 Mdot
.89 .10423 Mdot
.89 .10425 Mdot
.89 .10427 Mdot
.89 .1051 Mdot
.89 .10569 Mdot
.89 .10725 Mdot
.89 .10811 Mdot
.89 .10838 Mdot
.89 .10921 Mdot
.89 .10944 Mdot
.89 .10948 Mdot
.89 .10979 Mdot
.89 .10998 Mdot
.89 .11037 Mdot
.89 .11064 Mdot
.89 .11135 Mdot
.89 .11152 Mdot
.89 .11165 Mdot
.89 .11196 Mdot
.89 .11231 Mdot
.89 .11334 Mdot
.89 .11345 Mdot
.89 .11356 Mdot
.89 .11369 Mdot
.89 .11381 Mdot
.89 .11382 Mdot
.89 .11423 Mdot
.89 .11494 Mdot
.89 .11506 Mdot
.89 .1157 Mdot
.89 .11579 Mdot
.89 .11591 Mdot
.89 .11637 Mdot
.89 .11694 Mdot
.89 .1171 Mdot
.89 .11745 Mdot
.89 .11757 Mdot
.89 .11791 Mdot
.89 .1181 Mdot
.89 .11961 Mdot
.89 .11994 Mdot
.89 .12023 Mdot
.89 .12094 Mdot
.89 .12316 Mdot
.89 .12349 Mdot
.89 .12366 Mdot
.89 .12483 Mdot
.89 .12489 Mdot
.89 .1252 Mdot
.89 .12554 Mdot
.89 .12581 Mdot
.89 .12583 Mdot
.89 .12727 Mdot
.89 .12907 Mdot
.89 .12925 Mdot
.89 .12939 Mdot
.89 .12944 Mdot
.89 .12969 Mdot
.89 .13086 Mdot
.89 .13092 Mdot
.89 .13189 Mdot
.89 .13192 Mdot
.89 .13193 Mdot
.89 .13264 Mdot
.89 .13286 Mdot
.89 .13295 Mdot
.89 .13331 Mdot
.89 .13402 Mdot
.89 .13414 Mdot
.89 .1342 Mdot
.89 .13435 Mdot
.89 .13463 Mdot
.89 .13476 Mdot
.89 .1349 Mdot
.89 .13513 Mdot
.89 .13542 Mdot
.89 .13542 Mdot
.89 .13548 Mdot
.89 .13595 Mdot
.89 .13685 Mdot
.89 .13702 Mdot
.89 .13714 Mdot
.89 .13722 Mdot
.89 .13803 Mdot
.89 .13961 Mdot
.89 .14014 Mdot
.89 .14055 Mdot
.89 .1406 Mdot
.89 .14072 Mdot
.89 .14129 Mdot
.89 .1425 Mdot
.89 .14344 Mdot
.89 .14379 Mdot
.89 .14409 Mdot
.89 .14422 Mdot
.89 .14482 Mdot
.89 .14566 Mdot
.89 .14631 Mdot
.89 .14675 Mdot
.89 .14694 Mdot
.89 .14864 Mdot
.89 .14886 Mdot
.89 .14921 Mdot
.89 .14924 Mdot
.89 .14938 Mdot
.89 .14947 Mdot
.89 .15067 Mdot
.89 .15077 Mdot
.89 .15103 Mdot
.89 .15114 Mdot
.89 .15155 Mdot
.89 .15173 Mdot
.89 .15175 Mdot
.89 .15191 Mdot
.89 .15251 Mdot
.89 .15321 Mdot
.89 .1535 Mdot
.89 .15362 Mdot
.89 .15443 Mdot
.89 .15472 Mdot
.89 .15483 Mdot
.89 .1552 Mdot
.89 .15547 Mdot
.89 .15647 Mdot
.89 .15685 Mdot
.89 .15725 Mdot
.89 .15779 Mdot
.89 .15908 Mdot
.89 .15987 Mdot
.89 .16045 Mdot
.89 .1606 Mdot
.89 .16128 Mdot
.89 .16179 Mdot
.89 .16195 Mdot
.89 .16216 Mdot
.89 .16218 Mdot
.89 .16226 Mdot
.89 .16314 Mdot
.89 .16359 Mdot
.89 .16448 Mdot
.89 .1646 Mdot
.89 .16462 Mdot
.89 .16469 Mdot
.89 .16496 Mdot
.89 .16544 Mdot
.89 .166 Mdot
.89 .16621 Mdot
.89 .16655 Mdot
.89 .16663 Mdot
.89 .16665 Mdot
.89 .16752 Mdot
.89 .16914 Mdot
.89 .16915 Mdot
.89 .16947 Mdot
.89 .16977 Mdot
.89 .1698 Mdot
.89 .16995 Mdot
.89 .17153 Mdot
.89 .17204 Mdot
.89 .17214 Mdot
.89 .17223 Mdot
.89 .173 Mdot
.89 .17383 Mdot
.89 .17404 Mdot
.89 .1741 Mdot
.89 .17412 Mdot
.89 .17515 Mdot
.89 .1756 Mdot
.89 .17665 Mdot
.89 .17672 Mdot
.89 .17721 Mdot
.89 .17721 Mdot
.89 .17789 Mdot
.89 .17815 Mdot
.89 .17887 Mdot
.89 .17931 Mdot
.89 .17942 Mdot
.89 .18023 Mdot
.89 .18096 Mdot
.89 .18145 Mdot
.89 .18285 Mdot
.89 .18285 Mdot
.89 .18292 Mdot
.89 .18333 Mdot
.89 .18339 Mdot
.89 .18348 Mdot
.89 .1839 Mdot
.89 .18394 Mdot
.89 .18429 Mdot
.89 .1849 Mdot
.89 .18498 Mdot
.89 .18522 Mdot
.89 .18546 Mdot
.89 .18601 Mdot
.89 .18673 Mdot
.89 .18703 Mdot
.89 .18726 Mdot
.89 .18782 Mdot
.89 .18844 Mdot
.89 .18963 Mdot
.89 .19027 Mdot
.89 .19045 Mdot
.89 .19065 Mdot
.89 .1909 Mdot
.89 .19111 Mdot
.89 .19113 Mdot
.89 .19186 Mdot
.89 .19226 Mdot
.89 .19277 Mdot
.89 .19311 Mdot
.89 .19332 Mdot
.89 .19448 Mdot
.89 .19462 Mdot
.89 .19485 Mdot
.89 .19566 Mdot
.89 .19576 Mdot
.89 .19668 Mdot
.89 .19696 Mdot
.89 .19758 Mdot
.89 .19779 Mdot
.89 .19807 Mdot
.89 .19835 Mdot
.89 .1984 Mdot
.89 .19873 Mdot
.89 .19906 Mdot
.89 .19949 Mdot
.89 .20015 Mdot
.89 .20142 Mdot
.89 .20201 Mdot
.89 .20224 Mdot
.89 .20254 Mdot
.89 .20314 Mdot
.89 .20379 Mdot
.89 .2039 Mdot
.89 .20502 Mdot
.89 .20775 Mdot
.89 .20833 Mdot
.89 .20863 Mdot
.89 .20908 Mdot
.89 .21073 Mdot
.89 .21083 Mdot
.89 .21138 Mdot
.89 .21199 Mdot
.89 .21246 Mdot
.89 .2125 Mdot
.89 .21314 Mdot
.89 .21393 Mdot
.89 .21435 Mdot
.89 .21506 Mdot
.89 .21635 Mdot
.89 .21782 Mdot
.89 .21805 Mdot
.89 .21826 Mdot
.89 .21852 Mdot
.89 .21859 Mdot
.89 .21876 Mdot
.89 .21883 Mdot
.89 .21892 Mdot
.89 .21938 Mdot
.89 .22145 Mdot
.89 .22157 Mdot
.89 .22215 Mdot
.89 .22329 Mdot
.89 .22333 Mdot
.89 .22336 Mdot
.89 .22413 Mdot
.89 .22463 Mdot
.89 .22467 Mdot
.89 .22502 Mdot
.89 .22517 Mdot
.89 .22582 Mdot
.89 .22687 Mdot
.89 .22709 Mdot
.89 .22725 Mdot
.89 .2273 Mdot
.89 .2274 Mdot
.89 .22767 Mdot
.89 .22816 Mdot
.89 .2284 Mdot
.89 .22864 Mdot
.89 .22878 Mdot
.89 .22905 Mdot
.89 .22957 Mdot
.89 .22957 Mdot
.89 .22967 Mdot
.89 .23051 Mdot
.89 .23054 Mdot
.89 .23212 Mdot
.89 .23241 Mdot
.89 .23264 Mdot
.89 .23278 Mdot
.89 .23307 Mdot
.89 .23409 Mdot
.89 .23422 Mdot
.89 .23454 Mdot
.89 .23464 Mdot
.89 .23703 Mdot
.89 .23797 Mdot
.89 .2387 Mdot
.89 .23879 Mdot
.89 .23901 Mdot
.89 .24001 Mdot
.89 .2403 Mdot
.89 .24217 Mdot
.89 .2437 Mdot
.89 .24384 Mdot
.89 .24447 Mdot
.89 .24493 Mdot
.89 .245 Mdot
.89 .24523 Mdot
.89 .2463 Mdot
.89 .24692 Mdot
.89 .24709 Mdot
.89 .24779 Mdot
.89 .24791 Mdot
.89 .24839 Mdot
.89 .24895 Mdot
.89 .24974 Mdot
.89 .25007 Mdot
.89 .25021 Mdot
.89 .25024 Mdot
.89 .25203 Mdot
.89 .2531 Mdot
.89 .25349 Mdot
.89 .25412 Mdot
.89 .25417 Mdot
.89 .25443 Mdot
.89 .25458 Mdot
.89 .25515 Mdot
.89 .25516 Mdot
.89 .25573 Mdot
.89 .25671 Mdot
.89 .25672 Mdot
.89 .2569 Mdot
.89 .25721 Mdot
.89 .25736 Mdot
.89 .25755 Mdot
.89 .25781 Mdot
.89 .25828 Mdot
.89 .2586 Mdot
.89 .25863 Mdot
.89 .25864 Mdot
.89 .25891 Mdot
.89 .25999 Mdot
.89 .2601 Mdot
.89 .26112 Mdot
.89 .26122 Mdot
.89 .26124 Mdot
.89 .26126 Mdot
.89 .26175 Mdot
.89 .26196 Mdot
.89 .26212 Mdot
.89 .26342 Mdot
.89 .26392 Mdot
.89 .26412 Mdot
.89 .26478 Mdot
.89 .26526 Mdot
.89 .26553 Mdot
.89 .26589 Mdot
.89 .26704 Mdot
.89 .26772 Mdot
.89 .26843 Mdot
.89 .26912 Mdot
.89 .26939 Mdot
.89 .26943 Mdot
.89 .26949 Mdot
.89 .26957 Mdot
.89 .2711 Mdot
.89 .27169 Mdot
.89 .27178 Mdot
.89 .2723 Mdot
.89 .27309 Mdot
.89 .27412 Mdot
.89 .2744 Mdot
.89 .2756 Mdot
.89 .27639 Mdot
.89 .27652 Mdot
.89 .2768 Mdot
.89 .27717 Mdot
.89 .2772 Mdot
.89 .27735 Mdot
.89 .278 Mdot
.89 .27862 Mdot
.89 .27891 Mdot
.89 .27972 Mdot
.89 .28071 Mdot
.89 .2813 Mdot
.89 .28151 Mdot
.89 .28155 Mdot
.89 .28168 Mdot
.89 .28216 Mdot
.89 .28223 Mdot
.89 .28301 Mdot
.89 .28307 Mdot
.89 .28401 Mdot
.89 .28423 Mdot
.89 .28438 Mdot
.89 .28498 Mdot
.89 .28513 Mdot
.89 .28516 Mdot
.89 .2867 Mdot
.89 .28788 Mdot
.89 .2896 Mdot
.89 .28961 Mdot
.89 .29003 Mdot
.89 .29018 Mdot
.89 .29071 Mdot
.89 .29076 Mdot
.89 .29104 Mdot
.89 .29228 Mdot
.89 .29385 Mdot
.89 .29446 Mdot
.89 .29476 Mdot
.89 .29493 Mdot
.89 .2951 Mdot
.89 .2953 Mdot
.89 .29544 Mdot
.89 .29565 Mdot
.89 .29587 Mdot
.89 .29647 Mdot
.89 .29794 Mdot
.89 .29832 Mdot
.89 .29841 Mdot
.89 .29845 Mdot
.89 .30029 Mdot
.89 .30073 Mdot
.89 .30109 Mdot
.89 .3026 Mdot
.89 .30288 Mdot
.89 .30296 Mdot
.89 .30308 Mdot
.89 .30396 Mdot
.89 .30396 Mdot
.89 .30452 Mdot
.89 .30517 Mdot
.89 .30563 Mdot
.89 .30691 Mdot
.89 .30703 Mdot
.89 .30769 Mdot
.89 .30789 Mdot
.89 .30933 Mdot
.89 .31029 Mdot
.89 .31064 Mdot
.89 .31118 Mdot
.89 .3115 Mdot
.89 .31399 Mdot
.89 .314 Mdot
.89 .31411 Mdot
.89 .31485 Mdot
.89 .31496 Mdot
.89 .31498 Mdot
.89 .31512 Mdot
.89 .31586 Mdot
.89 .31594 Mdot
.89 .31656 Mdot
.89 .31748 Mdot
.89 .31764 Mdot
.89 .31779 Mdot
.89 .31789 Mdot
.89 .31822 Mdot
.89 .31865 Mdot
.89 .31878 Mdot
.89 .31961 Mdot
.89 .31995 Mdot
.89 .32005 Mdot
.89 .32052 Mdot
.89 .32091 Mdot
.89 .32144 Mdot
.89 .32185 Mdot
.89 .32258 Mdot
.89 .32284 Mdot
.89 .32394 Mdot
.89 .32456 Mdot
.89 .32547 Mdot
.89 .32607 Mdot
.89 .3272 Mdot
.89 .32753 Mdot
.89 .32788 Mdot
.89 .32804 Mdot
.89 .32832 Mdot
.89 .32869 Mdot
.89 .32873 Mdot
.89 .33003 Mdot
.89 .33074 Mdot
.89 .33118 Mdot
.89 .33166 Mdot
.89 .3318 Mdot
.89 .33226 Mdot
.89 .33264 Mdot
.89 .33305 Mdot
.89 .33373 Mdot
.89 .33384 Mdot
.89 .33424 Mdot
.89 .33469 Mdot
.89 .33495 Mdot
.89 .33535 Mdot
.89 .33576 Mdot
.89 .33599 Mdot
.89 .33679 Mdot
.89 .33698 Mdot
.89 .33846 Mdot
.89 .33861 Mdot
.89 .33866 Mdot
.89 .33911 Mdot
.89 .34022 Mdot
.89 .34059 Mdot
.89 .34109 Mdot
.89 .34159 Mdot
.89 .34164 Mdot
.89 .34168 Mdot
.89 .34227 Mdot
.89 .34234 Mdot
.89 .34282 Mdot
.89 .34286 Mdot
.89 .34361 Mdot
.89 .34473 Mdot
.89 .34478 Mdot
.89 .34517 Mdot
.89 .34527 Mdot
.89 .34705 Mdot
.89 .34811 Mdot
.89 .34851 Mdot
.89 .34904 Mdot
.89 .35011 Mdot
.89 .35017 Mdot
.89 .35127 Mdot
.89 .35146 Mdot
.89 .35345 Mdot
.89 .35389 Mdot
.89 .35832 Mdot
.89 .35933 Mdot
.89 .35934 Mdot
.89 .35939 Mdot
.89 .35989 Mdot
.89 .36068 Mdot
.89 .3607 Mdot
.89 .36117 Mdot
.89 .36287 Mdot
.89 .36302 Mdot
.89 .36361 Mdot
.89 .36381 Mdot
.89 .36392 Mdot
.89 .36478 Mdot
.89 .36586 Mdot
.89 .3667 Mdot
.89 .36677 Mdot
.89 .36783 Mdot
.89 .36792 Mdot
.89 .36932 Mdot
.89 .37007 Mdot
.89 .37132 Mdot
.89 .37281 Mdot
.89 .37363 Mdot
.89 .37474 Mdot
.89 .37568 Mdot
.89 .37622 Mdot
.89 .37624 Mdot
.89 .37665 Mdot
.89 .37677 Mdot
.89 .37702 Mdot
.89 .37742 Mdot
.89 .37749 Mdot
.89 .37761 Mdot
.89 .37784 Mdot
.89 .37792 Mdot
.89 .37805 Mdot
.89 .37821 Mdot
.89 .37851 Mdot
.89 .37901 Mdot
.89 .37922 Mdot
.89 .38112 Mdot
.89 .38271 Mdot
.89 .38291 Mdot
.89 .38396 Mdot
.89 .38576 Mdot
.89 .38597 Mdot
.89 .38605 Mdot
.89 .3861 Mdot
.89 .38698 Mdot
.89 .38727 Mdot
.89 .38738 Mdot
.89 .38747 Mdot
.89 .38836 Mdot
.89 .38843 Mdot
.89 .38905 Mdot
.89 .38932 Mdot
.89 .39047 Mdot
.89 .39236 Mdot
.89 .39273 Mdot
.89 .39302 Mdot
.89 .39311 Mdot
.89 .39323 Mdot
.89 .39329 Mdot
.89 .39378 Mdot
.89 .3946 Mdot
.89 .39465 Mdot
.89 .39507 Mdot
.89 .39551 Mdot
.89 .39574 Mdot
.89 .39575 Mdot
.89 .39624 Mdot
.89 .39715 Mdot
.89 .39716 Mdot
.89 .39734 Mdot
.89 .39884 Mdot
.89 .39889 Mdot
.89 .40053 Mdot
.89 .40141 Mdot
.89 .40169 Mdot
.89 .40169 Mdot
.89 .40207 Mdot
.89 .40221 Mdot
.89 .40262 Mdot
.89 .40287 Mdot
.89 .40338 Mdot
.89 .40485 Mdot
.89 .40486 Mdot
.89 .40521 Mdot
.89 .40544 Mdot
.89 .406 Mdot
.89 .40619 Mdot
.89 .40663 Mdot
.89 .40866 Mdot
.89 .41014 Mdot
.89 .41043 Mdot
.89 .41211 Mdot
.89 .41341 Mdot
.89 .41356 Mdot
.89 .41396 Mdot
.89 .4142 Mdot
.89 .41457 Mdot
.89 .41575 Mdot
.89 .41625 Mdot
.89 .41668 Mdot
.89 .41731 Mdot
.89 .41959 Mdot
.89 .42187 Mdot
.89 .42232 Mdot
.89 .42255 Mdot
.89 .42367 Mdot
.89 .4245 Mdot
.89 .42463 Mdot
.89 .42489 Mdot
.89 .42503 Mdot
.89 .42694 Mdot
.89 .42804 Mdot
.89 .42835 Mdot
.89 .42959 Mdot
.89 .4298 Mdot
.89 .43066 Mdot
.89 .43165 Mdot
.89 .43307 Mdot
.89 .43364 Mdot
.89 .43389 Mdot
.89 .43395 Mdot
.89 .43713 Mdot
.89 .43904 Mdot
.89 .43973 Mdot
.89 .44085 Mdot
.89 .44095 Mdot
.89 .4414 Mdot
.89 .44167 Mdot
.89 .4427 Mdot
.89 .44271 Mdot
.89 .44372 Mdot
.89 .44547 Mdot
.89 .44548 Mdot
.89 .4458 Mdot
.89 .44635 Mdot
.89 .44663 Mdot
.89 .44697 Mdot
.89 .44743 Mdot
.89 .44825 Mdot
.89 .44883 Mdot
.89 .44888 Mdot
.89 .44891 Mdot
.89 .44939 Mdot
.89 .4513 Mdot
.89 .45151 Mdot
.89 .45332 Mdot
.89 .45349 Mdot
.89 .45353 Mdot
.89 .45357 Mdot
.89 .45443 Mdot
.89 .45481 Mdot
.89 .4551 Mdot
.89 .4574 Mdot
.89 .45831 Mdot
.89 .45866 Mdot
.89 .45983 Mdot
.89 .46068 Mdot
.89 .46116 Mdot
.89 .46181 Mdot
.89 .46386 Mdot
.89 .46507 Mdot
.89 .46633 Mdot
.89 .46756 Mdot
.89 .46803 Mdot
.89 .4681 Mdot
.89 .46822 Mdot
.89 .46835 Mdot
.89 .47108 Mdot
.89 .47213 Mdot
.89 .47228 Mdot
.89 .47321 Mdot
.89 .47462 Mdot
.89 .47645 Mdot
.89 .47695 Mdot
.89 .47908 Mdot
.89 .48049 Mdot
.89 .48072 Mdot
.89 .48122 Mdot
.89 .48188 Mdot
.89 .48193 Mdot
.89 .4822 Mdot
.89 .48335 Mdot
.89 .48446 Mdot
.89 .48498 Mdot
.89 .48642 Mdot
.89 .48819 Mdot
.89 .48924 Mdot
.89 .48962 Mdot
.89 .48968 Mdot
.89 .48991 Mdot
.89 .49076 Mdot
.89 .49089 Mdot
.89 .49228 Mdot
.89 .49239 Mdot
.89 .49406 Mdot
.89 .49445 Mdot
.89 .49473 Mdot
.89 .4958 Mdot
.89 .49605 Mdot
.89 .4961 Mdot
.89 .49885 Mdot
.89 .50094 Mdot
.89 .504 Mdot
.89 .50404 Mdot
.89 .50477 Mdot
.89 .50504 Mdot
.89 .50599 Mdot
.89 .50607 Mdot
.89 .50658 Mdot
.89 .50877 Mdot
.89 .51157 Mdot
.89 .51266 Mdot
.89 .51319 Mdot
.89 .51349 Mdot
.89 .5138 Mdot
.89 .51417 Mdot
.89 .5144 Mdot
.89 .51477 Mdot
.89 .51517 Mdot
.89 .51624 Mdot
.89 .51885 Mdot
.89 .51953 Mdot
.89 .5197 Mdot
.89 .51976 Mdot
.89 .52304 Mdot
.89 .52382 Mdot
.89 .52446 Mdot
.89 .52715 Mdot
.89 .52764 Mdot
.89 .5278 Mdot
.89 .52801 Mdot
.89 .52957 Mdot
.89 .52958 Mdot
.89 .53057 Mdot
.89 .53172 Mdot
.89 .53254 Mdot
.89 .53483 Mdot
.89 .53503 Mdot
.89 .53622 Mdot
.89 .53657 Mdot
.89 .53914 Mdot
.89 .54083 Mdot
.892 .01796 Mdot
.892 .01805 Mdot
.892 .0205 Mdot
.892 .02067 Mdot
.892 .02167 Mdot
.892 .02188 Mdot
.892 .02236 Mdot
.892 .02447 Mdot
.892 .02489 Mdot
.892 .02503 Mdot
.892 .02534 Mdot
.892 .02669 Mdot
.892 .02688 Mdot
.892 .02712 Mdot
.892 .02713 Mdot
.892 .02751 Mdot
.892 .02792 Mdot
.892 .02834 Mdot
.892 .02836 Mdot
.892 .03052 Mdot
.892 .03212 Mdot
.892 .03286 Mdot
.892 .03312 Mdot
.892 .03364 Mdot
.892 .03366 Mdot
.892 .03459 Mdot
.892 .03493 Mdot
.892 .03609 Mdot
.892 .03642 Mdot
.892 .03651 Mdot
.892 .03684 Mdot
.892 .03686 Mdot
.892 .03753 Mdot
.892 .03777 Mdot
.892 .03827 Mdot
.892 .03848 Mdot
.892 .03875 Mdot
.892 .03903 Mdot
.892 .03906 Mdot
.892 .03912 Mdot
.892 .03955 Mdot
.892 .04248 Mdot
.892 .04292 Mdot
.892 .04429 Mdot
.892 .04458 Mdot
.892 .04576 Mdot
.892 .04691 Mdot
.892 .04709 Mdot
.892 .04724 Mdot
.892 .0475 Mdot
.892 .04756 Mdot
.892 .04825 Mdot
.892 .04848 Mdot
.892 .04852 Mdot
.892 .04862 Mdot
.892 .04886 Mdot
.892 .05017 Mdot
.892 .05077 Mdot
.892 .05096 Mdot
.892 .05198 Mdot
.892 .05255 Mdot
.892 .05284 Mdot
.892 .05306 Mdot
.892 .05343 Mdot
.892 .05349 Mdot
.892 .0536 Mdot
.892 .05418 Mdot
.892 .05422 Mdot
.892 .05439 Mdot
.892 .05447 Mdot
.892 .05486 Mdot
.892 .05542 Mdot
.892 .05579 Mdot
.892 .05584 Mdot
.892 .05635 Mdot
.892 .05674 Mdot
.892 .05712 Mdot
.892 .0576 Mdot
.892 .05809 Mdot
.892 .05814 Mdot
.892 .05825 Mdot
.892 .05902 Mdot
.892 .05917 Mdot
.892 .06426 Mdot
.892 .06449 Mdot
.892 .06503 Mdot
.892 .06636 Mdot
.892 .06748 Mdot
.892 .06799 Mdot
.892 .06894 Mdot
.892 .06924 Mdot
.892 .06953 Mdot
.892 .06997 Mdot
.892 .07 Mdot
.892 .0701 Mdot
.892 .07016 Mdot
.892 .07058 Mdot
.892 .07214 Mdot
.892 .0722 Mdot
.892 .07247 Mdot
.892 .07274 Mdot
.892 .0728 Mdot
.892 .0732 Mdot
.892 .0733 Mdot
.892 .07384 Mdot
.892 .07439 Mdot
.892 .07455 Mdot
.892 .07495 Mdot
.892 .075 Mdot
.892 .07503 Mdot
.892 .0752 Mdot
.892 .07558 Mdot
.892 .07563 Mdot
.892 .07797 Mdot
.892 .07814 Mdot
.892 .07895 Mdot
.892 .07904 Mdot
.892 .07937 Mdot
.892 .07959 Mdot
.892 .08069 Mdot
.892 .0807 Mdot
.892 .0812 Mdot
.892 .08122 Mdot
.892 .08221 Mdot
.892 .08239 Mdot
.892 .08247 Mdot
.892 .08273 Mdot
.892 .08312 Mdot
.892 .08378 Mdot
.892 .08389 Mdot
.892 .08408 Mdot
.892 .08464 Mdot
.892 .08512 Mdot
.892 .0852 Mdot
.892 .08549 Mdot
.892 .08564 Mdot
.892 .086 Mdot
.892 .08612 Mdot
.892 .08633 Mdot
.892 .08665 Mdot
.892 .08704 Mdot
.892 .08734 Mdot
.892 .08798 Mdot
.892 .08809 Mdot
.892 .08868 Mdot
.892 .08899 Mdot
.892 .08933 Mdot
.892 .08969 Mdot
.892 .08969 Mdot
.892 .09003 Mdot
.892 .09018 Mdot
.892 .09037 Mdot
.892 .09122 Mdot
.892 .09172 Mdot
.892 .09184 Mdot
.892 .09187 Mdot
.892 .0921 Mdot
.892 .09218 Mdot
.892 .09238 Mdot
.892 .09329 Mdot
.892 .09376 Mdot
.892 .09403 Mdot
.892 .09473 Mdot
.892 .09708 Mdot
.892 .09731 Mdot
.892 .09786 Mdot
.892 .09813 Mdot
.892 .09985 Mdot
.892 .10087 Mdot
.892 .10149 Mdot
.892 .10187 Mdot
.892 .10305 Mdot
.892 .1031 Mdot
.892 .10344 Mdot
.892 .10351 Mdot
.892 .10371 Mdot
.892 .10396 Mdot
.892 .10423 Mdot
.892 .10448 Mdot
.892 .10613 Mdot
.892 .10641 Mdot
.892 .10645 Mdot
.892 .10666 Mdot
.892 .10684 Mdot
.892 .10884 Mdot
.892 .10976 Mdot
.892 .1104 Mdot
.892 .11146 Mdot
.892 .11168 Mdot
.892 .11192 Mdot
.892 .11199 Mdot
.892 .11251 Mdot
.892 .11283 Mdot
.892 .11329 Mdot
.892 .11335 Mdot
.892 .11339 Mdot
.892 .11353 Mdot
.892 .11363 Mdot
.892 .11418 Mdot
.892 .11437 Mdot
.892 .11461 Mdot
.892 .11717 Mdot
.892 .11722 Mdot
.892 .11727 Mdot
.892 .11774 Mdot
.892 .11785 Mdot
.892 .11824 Mdot
.892 .11834 Mdot
.892 .11893 Mdot
.892 .11905 Mdot
.892 .11924 Mdot
.892 .1202 Mdot
.892 .12065 Mdot
.892 .12118 Mdot
.892 .1212 Mdot
.892 .12146 Mdot
.892 .12217 Mdot
.892 .12226 Mdot
.892 .12231 Mdot
.892 .12261 Mdot
.892 .12325 Mdot
.892 .12329 Mdot
.892 .12338 Mdot
.892 .12377 Mdot
.892 .12381 Mdot
.892 .12597 Mdot
.892 .12673 Mdot
.892 .12735 Mdot
.892 .12757 Mdot
.892 .12766 Mdot
.892 .12786 Mdot
.892 .12799 Mdot
.892 .12852 Mdot
.892 .12876 Mdot
.892 .12931 Mdot
.892 .12948 Mdot
.892 .12966 Mdot
.892 .13007 Mdot
.892 .13039 Mdot
.892 .13046 Mdot
.892 .1315 Mdot
.892 .13242 Mdot
.892 .13243 Mdot
.892 .13332 Mdot
.892 .13336 Mdot
.892 .13339 Mdot
.892 .13474 Mdot
.892 .13512 Mdot
.892 .13544 Mdot
.892 .13559 Mdot
.892 .13564 Mdot
.892 .13605 Mdot
.892 .13675 Mdot
.892 .13786 Mdot
.892 .13793 Mdot
.892 .13813 Mdot
.892 .13846 Mdot
.892 .13882 Mdot
.892 .13947 Mdot
.892 .13987 Mdot
.892 .13987 Mdot
.892 .14011 Mdot
.892 .14032 Mdot
.892 .14046 Mdot
.892 .14099 Mdot
.892 .14124 Mdot
.892 .14175 Mdot
.892 .14189 Mdot
.892 .1421 Mdot
.892 .14218 Mdot
.892 .14248 Mdot
.892 .14252 Mdot
.892 .14304 Mdot
.892 .14327 Mdot
.892 .14375 Mdot
.892 .14402 Mdot
.892 .14427 Mdot
.892 .1444 Mdot
.892 .14508 Mdot
.892 .14537 Mdot
.892 .14543 Mdot
.892 .14561 Mdot
.892 .1462 Mdot
.892 .14667 Mdot
.892 .14716 Mdot
.892 .14722 Mdot
.892 .14782 Mdot
.892 .14847 Mdot
.892 .14847 Mdot
.892 .14908 Mdot
.892 .14934 Mdot
.892 .14955 Mdot
.892 .14962 Mdot
.892 .14968 Mdot
.892 .15032 Mdot
.892 .15083 Mdot
.892 .15119 Mdot
.892 .15182 Mdot
.892 .1521 Mdot
.892 .1523 Mdot
.892 .15236 Mdot
.892 .15276 Mdot
.892 .15278 Mdot
.892 .15292 Mdot
.892 .15307 Mdot
.892 .15328 Mdot
.892 .15445 Mdot
.892 .15477 Mdot
.892 .15489 Mdot
.892 .15551 Mdot
.892 .15557 Mdot
.892 .15573 Mdot
.892 .15622 Mdot
.892 .15728 Mdot
.892 .15745 Mdot
.892 .15765 Mdot
.892 .15787 Mdot
.892 .15801 Mdot
.892 .15897 Mdot
.892 .15904 Mdot
.892 .16066 Mdot
.892 .16088 Mdot
.892 .16104 Mdot
.892 .16166 Mdot
.892 .16207 Mdot
.892 .16304 Mdot
.892 .16343 Mdot
.892 .16352 Mdot
.892 .16381 Mdot
.892 .16408 Mdot
.892 .16626 Mdot
.892 .1666 Mdot
.892 .1682 Mdot
.892 .16842 Mdot
.892 .16872 Mdot
.892 .16944 Mdot
.892 .16951 Mdot
.892 .17021 Mdot
.892 .17046 Mdot
.892 .17068 Mdot
.892 .17085 Mdot
.892 .17231 Mdot
.892 .17239 Mdot
.892 .17268 Mdot
.892 .17301 Mdot
.892 .17313 Mdot
.892 .17349 Mdot
.892 .17352 Mdot
.892 .17377 Mdot
.892 .17384 Mdot
.892 .17394 Mdot
.892 .17441 Mdot
.892 .17485 Mdot
.892 .17616 Mdot
.892 .17779 Mdot
.892 .1783 Mdot
.892 .17837 Mdot
.892 .17875 Mdot
.892 .17907 Mdot
.892 .18011 Mdot
.892 .18147 Mdot
.892 .18264 Mdot
.892 .18286 Mdot
.892 .18428 Mdot
.892 .18436 Mdot
.892 .1846 Mdot
.892 .18542 Mdot
.892 .1864 Mdot
.892 .18681 Mdot
.892 .1873 Mdot
.892 .1877 Mdot
.892 .18792 Mdot
.892 .18812 Mdot
.892 .18826 Mdot
.892 .18918 Mdot
.892 .18975 Mdot
.892 .18984 Mdot
.892 .19057 Mdot
.892 .19068 Mdot
.892 .19076 Mdot
.892 .19099 Mdot
.892 .19118 Mdot
.892 .19184 Mdot
.892 .19216 Mdot
.892 .1925 Mdot
.892 .19292 Mdot
.892 .19295 Mdot
.892 .19307 Mdot
.892 .19749 Mdot
.892 .19759 Mdot
.892 .19768 Mdot
.892 .19782 Mdot
.892 .19783 Mdot
.892 .19801 Mdot
.892 .19852 Mdot
.892 .19871 Mdot
.892 .19903 Mdot
.892 .19921 Mdot
.892 .1994 Mdot
.892 .19958 Mdot
.892 .20038 Mdot
.892 .20064 Mdot
.892 .20084 Mdot
.892 .20119 Mdot
.892 .20119 Mdot
.892 .20172 Mdot
.892 .20174 Mdot
.892 .20285 Mdot
.892 .20289 Mdot
.892 .20318 Mdot
.892 .2037 Mdot
.892 .2039 Mdot
.892 .20401 Mdot
.892 .20417 Mdot
.892 .20465 Mdot
.892 .20469 Mdot
.892 .20514 Mdot
.892 .2056 Mdot
.892 .20641 Mdot
.892 .20658 Mdot
.892 .20666 Mdot
.892 .20721 Mdot
.892 .20772 Mdot
.892 .20784 Mdot
.892 .20833 Mdot
.892 .20842 Mdot
.892 .2085 Mdot
.892 .20858 Mdot
.892 .20927 Mdot
.892 .20928 Mdot
.892 .20935 Mdot
.892 .21052 Mdot
.892 .21092 Mdot
.892 .211 Mdot
.892 .21266 Mdot
.892 .21286 Mdot
.892 .2132 Mdot
.892 .21374 Mdot
.892 .21456 Mdot
.892 .21473 Mdot
.892 .21565 Mdot
.892 .21585 Mdot
.892 .21605 Mdot
.892 .21621 Mdot
.892 .21657 Mdot
.892 .2168 Mdot
.892 .21715 Mdot
.892 .21774 Mdot
.892 .21817 Mdot
.892 .21915 Mdot
.892 .21945 Mdot
.892 .21978 Mdot
.892 .21978 Mdot
.892 .21986 Mdot
.892 .2205 Mdot
.892 .22108 Mdot
.892 .2212 Mdot
.892 .22142 Mdot
.892 .22151 Mdot
.892 .22284 Mdot
.892 .22306 Mdot
.892 .22354 Mdot
.892 .22393 Mdot
.892 .22469 Mdot
.892 .22471 Mdot
.892 .22537 Mdot
.892 .22544 Mdot
.892 .22631 Mdot
.892 .22638 Mdot
.892 .22643 Mdot
.892 .22718 Mdot
.892 .22739 Mdot
.892 .22884 Mdot
.892 .22907 Mdot
.892 .22939 Mdot
.892 .22951 Mdot
.892 .23009 Mdot
.892 .23035 Mdot
.892 .23043 Mdot
.892 .23045 Mdot
.892 .23118 Mdot
.892 .23242 Mdot
.892 .23376 Mdot
.892 .2344 Mdot
.892 .23453 Mdot
.892 .23488 Mdot
.892 .23548 Mdot
.892 .23611 Mdot
.892 .23646 Mdot
.892 .23649 Mdot
.892 .23728 Mdot
.892 .23799 Mdot
.892 .23799 Mdot
.892 .23842 Mdot
.892 .23879 Mdot
.892 .23905 Mdot
.892 .23921 Mdot
.892 .23957 Mdot
.892 .23998 Mdot
.892 .24043 Mdot
.892 .24114 Mdot
.892 .24134 Mdot
.892 .24159 Mdot
.892 .24198 Mdot
.892 .2421 Mdot
.892 .24265 Mdot
.892 .24271 Mdot
.892 .24299 Mdot
.892 .24365 Mdot
.892 .24406 Mdot
.892 .24489 Mdot
.892 .24491 Mdot
.892 .2454 Mdot
.892 .24585 Mdot
.892 .24607 Mdot
.892 .24619 Mdot
.892 .24664 Mdot
.892 .24666 Mdot
.892 .24721 Mdot
.892 .24728 Mdot
.892 .24781 Mdot
.892 .24791 Mdot
.892 .24823 Mdot
.892 .24928 Mdot
.892 .25013 Mdot
.892 .25014 Mdot
.892 .25099 Mdot
.892 .25111 Mdot
.892 .2516 Mdot
.892 .25218 Mdot
.892 .25278 Mdot
.892 .25319 Mdot
.892 .25333 Mdot
.892 .25333 Mdot
.892 .25351 Mdot
.892 .25443 Mdot
.892 .25488 Mdot
.892 .25526 Mdot
.892 .25538 Mdot
.892 .25548 Mdot
.892 .25664 Mdot
.892 .25719 Mdot
.892 .25754 Mdot
.892 .25819 Mdot
.892 .25893 Mdot
.892 .25932 Mdot
.892 .2598 Mdot
.892 .26005 Mdot
.892 .26017 Mdot
.892 .26027 Mdot
.892 .26099 Mdot
.892 .26102 Mdot
.892 .26127 Mdot
.892 .26154 Mdot
.892 .26191 Mdot
.892 .26212 Mdot
.892 .264 Mdot
.892 .26448 Mdot
.892 .26458 Mdot
.892 .26479 Mdot
.892 .2657 Mdot
.892 .26589 Mdot
.892 .26599 Mdot
.892 .26628 Mdot
.892 .26715 Mdot
.892 .26725 Mdot
.892 .26803 Mdot
.892 .26841 Mdot
.892 .26875 Mdot
.892 .26905 Mdot
.892 .26936 Mdot
.892 .26971 Mdot
.892 .27011 Mdot
.892 .27035 Mdot
.892 .27103 Mdot
.892 .27112 Mdot
.892 .27192 Mdot
.892 .27207 Mdot
.892 .2722 Mdot
.892 .27279 Mdot
.892 .27395 Mdot
.892 .27462 Mdot
.892 .27508 Mdot
.892 .27515 Mdot
.892 .27547 Mdot
.892 .27576 Mdot
.892 .27686 Mdot
.892 .27759 Mdot
.892 .27933 Mdot
.892 .28002 Mdot
.892 .28019 Mdot
.892 .28059 Mdot
.892 .28069 Mdot
.892 .28119 Mdot
.892 .28213 Mdot
.892 .28245 Mdot
.892 .28312 Mdot
.892 .28507 Mdot
.892 .28568 Mdot
.892 .28603 Mdot
.892 .28662 Mdot
.892 .28695 Mdot
.892 .28787 Mdot
.892 .28853 Mdot
.892 .28892 Mdot
.892 .28946 Mdot
.892 .29064 Mdot
.892 .29074 Mdot
.892 .29088 Mdot
.892 .29095 Mdot
.892 .29211 Mdot
.892 .29257 Mdot
.892 .29295 Mdot
.892 .29325 Mdot
.892 .29345 Mdot
.892 .29466 Mdot
.892 .29573 Mdot
.892 .29587 Mdot
.892 .296 Mdot
.892 .29652 Mdot
.892 .29669 Mdot
.892 .29711 Mdot
.892 .29733 Mdot
.892 .29768 Mdot
.892 .29797 Mdot
.892 .29803 Mdot
.892 .29847 Mdot
.892 .2986 Mdot
.892 .29877 Mdot
.892 .29878 Mdot
.892 .29962 Mdot
.892 .30005 Mdot
.892 .30039 Mdot
.892 .30083 Mdot
.892 .30273 Mdot
.892 .30297 Mdot
.892 .30328 Mdot
.892 .30564 Mdot
.892 .30582 Mdot
.892 .3063 Mdot
.892 .30655 Mdot
.892 .30668 Mdot
.892 .3067 Mdot
.892 .30735 Mdot
.892 .30793 Mdot
.892 .30859 Mdot
.892 .30978 Mdot
.892 .31221 Mdot
.892 .31227 Mdot
.892 .31429 Mdot
.892 .31441 Mdot
.892 .31468 Mdot
.892 .31586 Mdot
.892 .3161 Mdot
.892 .31711 Mdot
.892 .31721 Mdot
.892 .31735 Mdot
.892 .3178 Mdot
.892 .31804 Mdot
.892 .31926 Mdot
.892 .321 Mdot
.892 .32154 Mdot
.892 .32173 Mdot
.892 .32261 Mdot
.892 .32332 Mdot
.892 .32372 Mdot
.892 .32387 Mdot
.892 .32408 Mdot
.892 .32432 Mdot
.892 .32596 Mdot
.892 .32697 Mdot
.892 .32714 Mdot
.892 .32844 Mdot
.892 .32863 Mdot
.892 .32877 Mdot
.892 .3292 Mdot
.892 .3294 Mdot
.892 .32954 Mdot
.892 .33071 Mdot
.892 .33129 Mdot
.892 .3316 Mdot
.892 .33189 Mdot
.892 .33213 Mdot
.892 .33264 Mdot
.892 .33268 Mdot
.892 .3329 Mdot
.892 .33342 Mdot
.892 .33373 Mdot
.892 .33532 Mdot
.892 .3383 Mdot
.892 .33934 Mdot
.892 .34079 Mdot
.892 .34096 Mdot
.892 .34112 Mdot
.892 .34137 Mdot
.892 .34139 Mdot
.892 .34148 Mdot
.892 .34171 Mdot
.892 .34262 Mdot
.892 .34295 Mdot
.892 .34354 Mdot
.892 .34385 Mdot
.892 .34419 Mdot
.892 .34451 Mdot
.892 .34595 Mdot
.892 .3464 Mdot
.892 .34676 Mdot
.892 .34738 Mdot
.892 .34738 Mdot
.892 .34768 Mdot
.892 .34833 Mdot
.892 .34837 Mdot
.892 .34959 Mdot
.892 .35035 Mdot
.892 .35042 Mdot
.892 .35072 Mdot
.892 .35094 Mdot
.892 .35186 Mdot
.892 .35222 Mdot
.892 .35242 Mdot
.892 .35261 Mdot
.892 .3527 Mdot
.892 .35356 Mdot
.892 .35363 Mdot
.892 .35364 Mdot
.892 .35444 Mdot
.892 .35525 Mdot
.892 .35657 Mdot
.892 .35669 Mdot
.892 .357 Mdot
.892 .35715 Mdot
.892 .35812 Mdot
.892 .35869 Mdot
.892 .35903 Mdot
.892 .35925 Mdot
.892 .35991 Mdot
.892 .36013 Mdot
.892 .36028 Mdot
.892 .36042 Mdot
.892 .36057 Mdot
.892 .36163 Mdot
.892 .3618 Mdot
.892 .36182 Mdot
.892 .36194 Mdot
.892 .36403 Mdot
.892 .36475 Mdot
.892 .36488 Mdot
.892 .36539 Mdot
.892 .36571 Mdot
.892 .36615 Mdot
.892 .36639 Mdot
.892 .36786 Mdot
.892 .36821 Mdot
.892 .36881 Mdot
.892 .36977 Mdot
.892 .37009 Mdot
.892 .37123 Mdot
.892 .37152 Mdot
.892 .37155 Mdot
.892 .37276 Mdot
.892 .37319 Mdot
.892 .37353 Mdot
.892 .37371 Mdot
.892 .37389 Mdot
.892 .37419 Mdot
.892 .37432 Mdot
.892 .37483 Mdot
.892 .37524 Mdot
.892 .37586 Mdot
.892 .37692 Mdot
.892 .37768 Mdot
.892 .37818 Mdot
.892 .37942 Mdot
.892 .37996 Mdot
.892 .38055 Mdot
.892 .38055 Mdot
.892 .38069 Mdot
.892 .3816 Mdot
.892 .38184 Mdot
.892 .38203 Mdot
.892 .38246 Mdot
.892 .38288 Mdot
.892 .38309 Mdot
.892 .38347 Mdot
.892 .38363 Mdot
.892 .3841 Mdot
.892 .38464 Mdot
.892 .38597 Mdot
.892 .38601 Mdot
.892 .38641 Mdot
.892 .38669 Mdot
.892 .38725 Mdot
.892 .38779 Mdot
.892 .38795 Mdot
.892 .38872 Mdot
.892 .3889 Mdot
.892 .38932 Mdot
.892 .38935 Mdot
.892 .39031 Mdot
.892 .39052 Mdot
.892 .39064 Mdot
.892 .39072 Mdot
.892 .39126 Mdot
.892 .3913 Mdot
.892 .3922 Mdot
.892 .39233 Mdot
.892 .39242 Mdot
.892 .39376 Mdot
.892 .39397 Mdot
.892 .39412 Mdot
.892 .39534 Mdot
.892 .39643 Mdot
.892 .39672 Mdot
.892 .39712 Mdot
.892 .3977 Mdot
.892 .39782 Mdot
.892 .39791 Mdot
.892 .39894 Mdot
.892 .39941 Mdot
.892 .39955 Mdot
.892 .39959 Mdot
.892 .40089 Mdot
.892 .40311 Mdot
.892 .40387 Mdot
.892 .40465 Mdot
.892 .40549 Mdot
.892 .40563 Mdot
.892 .40663 Mdot
.892 .40686 Mdot
.892 .40749 Mdot
.892 .40856 Mdot
.892 .40968 Mdot
.892 .4103 Mdot
.892 .41037 Mdot
.892 .41176 Mdot
.892 .41303 Mdot
.892 .41304 Mdot
.892 .41314 Mdot
.892 .41371 Mdot
.892 .41381 Mdot
.892 .41447 Mdot
.892 .41492 Mdot
.892 .41522 Mdot
.892 .41523 Mdot
.892 .41585 Mdot
.892 .41604 Mdot
.892 .41644 Mdot
.892 .4165 Mdot
.892 .41659 Mdot
.892 .41739 Mdot
.892 .41858 Mdot
.892 .41865 Mdot
.892 .41902 Mdot
.892 .41946 Mdot
.892 .42015 Mdot
.892 .42038 Mdot
.892 .42042 Mdot
.892 .42135 Mdot
.892 .42146 Mdot
.892 .42196 Mdot
.892 .42251 Mdot
.892 .42314 Mdot
.892 .42387 Mdot
.892 .42534 Mdot
.892 .42539 Mdot
.892 .42626 Mdot
.892 .42631 Mdot
.892 .42706 Mdot
.892 .42745 Mdot
.892 .42767 Mdot
.892 .42847 Mdot
.892 .42851 Mdot
.892 .42949 Mdot
.892 .42961 Mdot
.892 .43055 Mdot
.892 .43073 Mdot
.892 .43131 Mdot
.892 .43318 Mdot
.892 .43469 Mdot
.892 .43471 Mdot
.892 .43624 Mdot
.892 .43644 Mdot
.892 .43731 Mdot
.892 .43835 Mdot
.892 .43942 Mdot
.892 .44015 Mdot
.892 .4404 Mdot
.892 .44041 Mdot
.892 .44072 Mdot
.892 .44236 Mdot
.892 .44318 Mdot
.892 .44384 Mdot
.892 .44407 Mdot
.892 .44425 Mdot
.892 .44631 Mdot
.892 .44729 Mdot
.892 .44792 Mdot
.892 .44908 Mdot
.892 .4504 Mdot
.892 .45108 Mdot
.892 .45195 Mdot
.892 .45239 Mdot
.892 .4526 Mdot
.892 .45279 Mdot
.892 .45407 Mdot
.892 .45412 Mdot
.892 .45457 Mdot
.892 .45506 Mdot
.892 .45571 Mdot
.892 .45608 Mdot
.892 .45943 Mdot
.892 .46029 Mdot
.892 .46047 Mdot
.892 .46085 Mdot
.892 .46248 Mdot
.892 .46281 Mdot
.892 .46299 Mdot
.892 .46351 Mdot
.892 .46506 Mdot
.892 .46524 Mdot
.892 .46663 Mdot
.892 .46731 Mdot
.892 .46792 Mdot
.892 .46845 Mdot
.892 .46901 Mdot
.892 .46962 Mdot
.892 .47034 Mdot
.892 .47077 Mdot
.892 .47198 Mdot
.892 .47215 Mdot
.892 .47357 Mdot
.892 .47384 Mdot
.892 .47406 Mdot
.892 .47512 Mdot
.892 .47719 Mdot
.892 .47839 Mdot
.892 .4792 Mdot
.892 .47933 Mdot
.892 .4799 Mdot
.892 .48042 Mdot
.892 .48238 Mdot
.892 .48369 Mdot
.892 .48679 Mdot
.892 .48802 Mdot
.892 .48832 Mdot
.892 .48904 Mdot
.892 .48922 Mdot
.892 .49011 Mdot
.892 .49178 Mdot
.892 .49236 Mdot
.892 .49356 Mdot
.892 .49703 Mdot
.892 .49811 Mdot
.892 .49874 Mdot
.892 .4998 Mdot
.892 .50038 Mdot
.892 .50202 Mdot
.892 .50321 Mdot
.892 .50389 Mdot
.892 .50486 Mdot
.892 .50696 Mdot
.892 .50714 Mdot
.892 .50739 Mdot
.892 .50752 Mdot
.892 .5096 Mdot
.892 .5104 Mdot
.892 .51109 Mdot
.892 .51163 Mdot
.892 .51197 Mdot
.892 .51413 Mdot
.892 .51605 Mdot
.892 .51629 Mdot
.892 .51653 Mdot
.892 .51745 Mdot
.892 .51775 Mdot
.892 .5185 Mdot
.892 .5189 Mdot
.892 .51952 Mdot
.892 .52004 Mdot
.892 .52014 Mdot
.892 .52093 Mdot
.892 .52116 Mdot
.892 .52146 Mdot
.892 .52149 Mdot
.892 .52298 Mdot
.892 .52375 Mdot
.892 .52436 Mdot
.892 .52514 Mdot
.892 .52853 Mdot
.892 .52897 Mdot
.892 .52952 Mdot
.892 .53373 Mdot
.892 .53405 Mdot
.892 .5349 Mdot
.892 .53535 Mdot
.892 .53558 Mdot
.892 .53561 Mdot
.892 .53678 Mdot
.892 .53781 Mdot
.892 .53898 Mdot
.892 .54111 Mdot
.894 .01479 Mdot
.894 .01484 Mdot
.894 .01494 Mdot
.894 .01512 Mdot
.894 .01543 Mdot
.894 .016 Mdot
.894 .01654 Mdot
.894 .01663 Mdot
.894 .01665 Mdot
.894 .01678 Mdot
.894 .01701 Mdot
.894 .01798 Mdot
.894 .01807 Mdot
.894 .01814 Mdot
.894 .01818 Mdot
.894 .01842 Mdot
.894 .01882 Mdot
.894 .01949 Mdot
.894 .02029 Mdot
.894 .02056 Mdot
.894 .02071 Mdot
.894 .02084 Mdot
.894 .02091 Mdot
.894 .02103 Mdot
.894 .02133 Mdot
.894 .02136 Mdot
.894 .0217 Mdot
.894 .02186 Mdot
.894 .02206 Mdot
.894 .02252 Mdot
.894 .02256 Mdot
.894 .02325 Mdot
.894 .02342 Mdot
.894 .02442 Mdot
.894 .02468 Mdot
.894 .02517 Mdot
.894 .02544 Mdot
.894 .02567 Mdot
.894 .02579 Mdot
.894 .02601 Mdot
.894 .02655 Mdot
.894 .02659 Mdot
.894 .02721 Mdot
.894 .02748 Mdot
.894 .02784 Mdot
.894 .02862 Mdot
.894 .02866 Mdot
.894 .02875 Mdot
.894 .02878 Mdot
.894 .02903 Mdot
.894 .02986 Mdot
.894 .02998 Mdot
.894 .03027 Mdot
.894 .03096 Mdot
.894 .03116 Mdot
.894 .03207 Mdot
.894 .03254 Mdot
.894 .03257 Mdot
.894 .03261 Mdot
.894 .0334 Mdot
.894 .03357 Mdot
.894 .03381 Mdot
.894 .03389 Mdot
.894 .0343 Mdot
.894 .03452 Mdot
.894 .03455 Mdot
.894 .03491 Mdot
.894 .03587 Mdot
.894 .03587 Mdot
.894 .03594 Mdot
.894 .03595 Mdot
.894 .03705 Mdot
.894 .03707 Mdot
.894 .03755 Mdot
.894 .03818 Mdot
.894 .03852 Mdot
.894 .03958 Mdot
.894 .03966 Mdot
.894 .0398 Mdot
.894 .03986 Mdot
.894 .04031 Mdot
.894 .04073 Mdot
.894 .04106 Mdot
.894 .04125 Mdot
.894 .0418 Mdot
.894 .042 Mdot
.894 .04253 Mdot
.894 .04375 Mdot
.894 .04376 Mdot
.894 .04407 Mdot
.894 .04412 Mdot
.894 .04441 Mdot
.894 .04462 Mdot
.894 .0451 Mdot
.894 .04574 Mdot
.894 .04629 Mdot
.894 .04658 Mdot
.894 .04664 Mdot
.894 .04672 Mdot
.894 .04704 Mdot
.894 .04751 Mdot
.894 .04813 Mdot
.894 .04842 Mdot
.894 .04886 Mdot
.894 .04899 Mdot
.894 .04973 Mdot
.894 .05012 Mdot
.894 .05019 Mdot
.894 .05083 Mdot
.894 .05254 Mdot
.894 .05254 Mdot
.894 .05266 Mdot
.894 .05268 Mdot
.894 .05298 Mdot
.894 .05319 Mdot
.894 .05466 Mdot
.894 .05468 Mdot
.894 .0551 Mdot
.894 .05554 Mdot
.894 .05641 Mdot
.894 .05668 Mdot
.894 .05677 Mdot
.894 .05728 Mdot
.894 .05858 Mdot
.894 .05917 Mdot
.894 .05931 Mdot
.894 .05957 Mdot
.894 .05967 Mdot
.894 .05967 Mdot
.894 .06029 Mdot
.894 .06047 Mdot
.894 .06063 Mdot
.894 .06123 Mdot
.894 .06182 Mdot
.894 .06215 Mdot
.894 .06298 Mdot
.894 .06314 Mdot
.894 .0635 Mdot
.894 .0637 Mdot
.894 .06445 Mdot
.894 .06465 Mdot
.894 .06479 Mdot
.894 .06561 Mdot
.894 .06663 Mdot
.894 .06665 Mdot
.894 .06721 Mdot
.894 .06729 Mdot
.894 .0678 Mdot
.894 .06819 Mdot
.894 .06819 Mdot
.894 .06831 Mdot
.894 .06904 Mdot
.894 .06935 Mdot
.894 .07019 Mdot
.894 .0709 Mdot
.894 .07116 Mdot
.894 .07169 Mdot
.894 .07179 Mdot
.894 .07194 Mdot
.894 .07251 Mdot
.894 .07288 Mdot
.894 .07335 Mdot
.894 .07337 Mdot
.894 .07446 Mdot
.894 .0747 Mdot
.894 .07498 Mdot
.894 .07573 Mdot
.894 .07577 Mdot
.894 .07599 Mdot
.894 .076 Mdot
.894 .07668 Mdot
.894 .07672 Mdot
.894 .07719 Mdot
.894 .07732 Mdot
.894 .07781 Mdot
.894 .07802 Mdot
.894 .07814 Mdot
.894 .07929 Mdot
.894 .08003 Mdot
.894 .08052 Mdot
.894 .08234 Mdot
.894 .08235 Mdot
.894 .08256 Mdot
.894 .08258 Mdot
.894 .0826 Mdot
.894 .08283 Mdot
.894 .08284 Mdot
.894 .08313 Mdot
.894 .08351 Mdot
.894 .08386 Mdot
.894 .08556 Mdot
.894 .08597 Mdot
.894 .08613 Mdot
.894 .08618 Mdot
.894 .08625 Mdot
.894 .08638 Mdot
.894 .08651 Mdot
.894 .08692 Mdot
.894 .0877 Mdot
.894 .08926 Mdot
.894 .08974 Mdot
.894 .0899 Mdot
.894 .09023 Mdot
.894 .09078 Mdot
.894 .09083 Mdot
.894 .09272 Mdot
.894 .09315 Mdot
.894 .0936 Mdot
.894 .09419 Mdot
.894 .09445 Mdot
.894 .09492 Mdot
.894 .09509 Mdot
.894 .09509 Mdot
.894 .09513 Mdot
.894 .0962 Mdot
.894 .09653 Mdot
.894 .09668 Mdot
.894 .0968 Mdot
.894 .09681 Mdot
.894 .09789 Mdot
.894 .09883 Mdot
.894 .09895 Mdot
.894 .0991 Mdot
.894 .09954 Mdot
.894 .10101 Mdot
.894 .10124 Mdot
.894 .1013 Mdot
.894 .10195 Mdot
.894 .10199 Mdot
.894 .1023 Mdot
.894 .10296 Mdot
.894 .10365 Mdot
.894 .104 Mdot
.894 .10425 Mdot
.894 .10479 Mdot
.894 .10558 Mdot
.894 .10571 Mdot
.894 .10752 Mdot
.894 .10754 Mdot
.894 .10757 Mdot
.894 .10779 Mdot
.894 .10818 Mdot
.894 .10857 Mdot
.894 .10858 Mdot
.894 .10873 Mdot
.894 .10964 Mdot
.894 .10966 Mdot
.894 .11005 Mdot
.894 .11033 Mdot
.894 .11034 Mdot
.894 .1105 Mdot
.894 .11054 Mdot
.894 .11067 Mdot
.894 .11185 Mdot
.894 .11234 Mdot
.894 .1124 Mdot
.894 .11244 Mdot
.894 .1139 Mdot
.894 .11393 Mdot
.894 .1145 Mdot
.894 .11518 Mdot
.894 .11565 Mdot
.894 .11611 Mdot
.894 .11658 Mdot
.894 .11676 Mdot
.894 .11703 Mdot
.894 .1177 Mdot
.894 .11805 Mdot
.894 .11872 Mdot
.894 .1193 Mdot
.894 .1196 Mdot
.894 .11976 Mdot
.894 .12127 Mdot
.894 .12154 Mdot
.894 .12156 Mdot
.894 .12192 Mdot
.894 .12197 Mdot
.894 .12247 Mdot
.894 .12264 Mdot
.894 .1231 Mdot
.894 .12362 Mdot
.894 .12381 Mdot
.894 .12388 Mdot
.894 .12396 Mdot
.894 .12428 Mdot
.894 .1243 Mdot
.894 .12456 Mdot
.894 .12494 Mdot
.894 .1255 Mdot
.894 .12558 Mdot
.894 .12585 Mdot
.894 .12642 Mdot
.894 .12665 Mdot
.894 .12748 Mdot
.894 .12753 Mdot
.894 .1279 Mdot
.894 .12812 Mdot
.894 .12931 Mdot
.894 .13018 Mdot
.894 .13064 Mdot
.894 .1309 Mdot
.894 .13091 Mdot
.894 .13128 Mdot
.894 .1315 Mdot
.894 .13238 Mdot
.894 .13299 Mdot
.894 .13335 Mdot
.894 .13428 Mdot
.894 .13492 Mdot
.894 .13563 Mdot
.894 .13565 Mdot
.894 .13569 Mdot
.894 .13602 Mdot
.894 .13606 Mdot
.894 .13609 Mdot
.894 .13648 Mdot
.894 .1365 Mdot
.894 .13652 Mdot
.894 .13703 Mdot
.894 .13736 Mdot
.894 .13772 Mdot
.894 .13834 Mdot
.894 .14106 Mdot
.894 .14125 Mdot
.894 .14139 Mdot
.894 .14159 Mdot
.894 .14211 Mdot
.894 .1424 Mdot
.894 .14249 Mdot
.894 .14263 Mdot
.894 .14285 Mdot
.894 .14308 Mdot
.894 .14382 Mdot
.894 .14522 Mdot
.894 .1453 Mdot
.894 .1457 Mdot
.894 .14604 Mdot
.894 .148 Mdot
.894 .14867 Mdot
.894 .14886 Mdot
.894 .14915 Mdot
.894 .14974 Mdot
.894 .15015 Mdot
.894 .15025 Mdot
.894 .15072 Mdot
.894 .15081 Mdot
.894 .15149 Mdot
.894 .15231 Mdot
.894 .15328 Mdot
.894 .1536 Mdot
.894 .15418 Mdot
.894 .15496 Mdot
.894 .15515 Mdot
.894 .15516 Mdot
.894 .15577 Mdot
.894 .15682 Mdot
.894 .15728 Mdot
.894 .15742 Mdot
.894 .15812 Mdot
.894 .15842 Mdot
.894 .15843 Mdot
.894 .15849 Mdot
.894 .15863 Mdot
.894 .15988 Mdot
.894 .16041 Mdot
.894 .161 Mdot
.894 .16126 Mdot
.894 .16148 Mdot
.894 .16151 Mdot
.894 .16209 Mdot
.894 .16214 Mdot
.894 .16322 Mdot
.894 .16342 Mdot
.894 .16416 Mdot
.894 .16462 Mdot
.894 .1651 Mdot
.894 .16532 Mdot
.894 .1656 Mdot
.894 .16593 Mdot
.894 .16594 Mdot
.894 .16637 Mdot
.894 .16901 Mdot
.894 .16939 Mdot
.894 .16942 Mdot
.894 .16949 Mdot
.894 .16954 Mdot
.894 .17069 Mdot
.894 .17077 Mdot
.894 .17131 Mdot
.894 .17231 Mdot
.894 .17249 Mdot
.894 .17313 Mdot
.894 .1736 Mdot
.894 .17373 Mdot
.894 .17435 Mdot
.894 .17481 Mdot
.894 .17576 Mdot
.894 .17649 Mdot
.894 .17701 Mdot
.894 .17702 Mdot
.894 .17719 Mdot
.894 .1772 Mdot
.894 .17729 Mdot
.894 .17742 Mdot
.894 .17753 Mdot
.894 .17941 Mdot
.894 .17948 Mdot
.894 .17966 Mdot
.894 .17985 Mdot
.894 .18066 Mdot
.894 .18068 Mdot
.894 .18069 Mdot
.894 .18073 Mdot
.894 .18113 Mdot
.894 .18158 Mdot
.894 .18183 Mdot
.894 .18206 Mdot
.894 .18216 Mdot
.894 .18227 Mdot
.894 .18232 Mdot
.894 .18253 Mdot
.894 .18254 Mdot
.894 .18281 Mdot
.894 .18443 Mdot
.894 .18448 Mdot
.894 .18517 Mdot
.894 .18523 Mdot
.894 .18567 Mdot
.894 .18568 Mdot
.894 .18598 Mdot
.894 .18606 Mdot
.894 .18629 Mdot
.894 .18672 Mdot
.894 .18708 Mdot
.894 .18838 Mdot
.894 .18917 Mdot
.894 .18927 Mdot
.894 .18937 Mdot
.894 .18944 Mdot
.894 .18959 Mdot
.894 .19205 Mdot
.894 .19212 Mdot
.894 .19272 Mdot
.894 .19313 Mdot
.894 .19415 Mdot
.894 .19434 Mdot
.894 .19518 Mdot
.894 .19575 Mdot
.894 .196 Mdot
.894 .19685 Mdot
.894 .19717 Mdot
.894 .19766 Mdot
.894 .19885 Mdot
.894 .19925 Mdot
.894 .19947 Mdot
.894 .19948 Mdot
.894 .19963 Mdot
.894 .20067 Mdot
.894 .20131 Mdot
.894 .20139 Mdot
.894 .20171 Mdot
.894 .20224 Mdot
.894 .20237 Mdot
.894 .20254 Mdot
.894 .20371 Mdot
.894 .20448 Mdot
.894 .20476 Mdot
.894 .20524 Mdot
.894 .20572 Mdot
.894 .20576 Mdot
.894 .20639 Mdot
.894 .20648 Mdot
.894 .20739 Mdot
.894 .20769 Mdot
.894 .20826 Mdot
.894 .20851 Mdot
.894 .20932 Mdot
.894 .20944 Mdot
.894 .20978 Mdot
.894 .2099 Mdot
.894 .21005 Mdot
.894 .2101 Mdot
.894 .21062 Mdot
.894 .21065 Mdot
.894 .21112 Mdot
.894 .2113 Mdot
.894 .2118 Mdot
.894 .2128 Mdot
.894 .21294 Mdot
.894 .21342 Mdot
.894 .21415 Mdot
.894 .21426 Mdot
.894 .21444 Mdot
.894 .21456 Mdot
.894 .21485 Mdot
.894 .21593 Mdot
.894 .21635 Mdot
.894 .21643 Mdot
.894 .21643 Mdot
.894 .21654 Mdot
.894 .21708 Mdot
.894 .21719 Mdot
.894 .21748 Mdot
.894 .21817 Mdot
.894 .21845 Mdot
.894 .21961 Mdot
.894 .21977 Mdot
.894 .22106 Mdot
.894 .22116 Mdot
.894 .22198 Mdot
.894 .22245 Mdot
.894 .22248 Mdot
.894 .22313 Mdot
.894 .22353 Mdot
.894 .22401 Mdot
.894 .22402 Mdot
.894 .22472 Mdot
.894 .2251 Mdot
.894 .2262 Mdot
.894 .22654 Mdot
.894 .22683 Mdot
.894 .22739 Mdot
.894 .22847 Mdot
.894 .2285 Mdot
.894 .22964 Mdot
.894 .22978 Mdot
.894 .23069 Mdot
.894 .23091 Mdot
.894 .23094 Mdot
.894 .23101 Mdot
.894 .2316 Mdot
.894 .23162 Mdot
.894 .23168 Mdot
.894 .23174 Mdot
.894 .232 Mdot
.894 .23243 Mdot
.894 .23246 Mdot
.894 .2325 Mdot
.894 .23251 Mdot
.894 .23342 Mdot
.894 .234 Mdot
.894 .23465 Mdot
.894 .23478 Mdot
.894 .23576 Mdot
.894 .23671 Mdot
.894 .24063 Mdot
.894 .24096 Mdot
.894 .2412 Mdot
.894 .24158 Mdot
.894 .2425 Mdot
.894 .24302 Mdot
.894 .24318 Mdot
.894 .24342 Mdot
.894 .24373 Mdot
.894 .24381 Mdot
.894 .24423 Mdot
.894 .24555 Mdot
.894 .24661 Mdot
.894 .24736 Mdot
.894 .24793 Mdot
.894 .24805 Mdot
.894 .24821 Mdot
.894 .24892 Mdot
.894 .24953 Mdot
.894 .25172 Mdot
.894 .25262 Mdot
.894 .25286 Mdot
.894 .25304 Mdot
.894 .25422 Mdot
.894 .2545 Mdot
.894 .25457 Mdot
.894 .25509 Mdot
.894 .25615 Mdot
.894 .25687 Mdot
.894 .25704 Mdot
.894 .25788 Mdot
.894 .2579 Mdot
.894 .25805 Mdot
.894 .25928 Mdot
.894 .2602 Mdot
.894 .26074 Mdot
.894 .26075 Mdot
.894 .26247 Mdot
.894 .26304 Mdot
.894 .26342 Mdot
.894 .26348 Mdot
.894 .26395 Mdot
.894 .26408 Mdot
.894 .26548 Mdot
.894 .26582 Mdot
.894 .26584 Mdot
.894 .26691 Mdot
.894 .26789 Mdot
.894 .26881 Mdot
.894 .26962 Mdot
.894 .26987 Mdot
.894 .27084 Mdot
.894 .27113 Mdot
.894 .27166 Mdot
.894 .27168 Mdot
.894 .27179 Mdot
.894 .27203 Mdot
.894 .27256 Mdot
.894 .27259 Mdot
.894 .27427 Mdot
.894 .27522 Mdot
.894 .27627 Mdot
.894 .27674 Mdot
.894 .27712 Mdot
.894 .27718 Mdot
.894 .2781 Mdot
.894 .27823 Mdot
.894 .27831 Mdot
.894 .27993 Mdot
.894 .28025 Mdot
.894 .28061 Mdot
.894 .28114 Mdot
.894 .28131 Mdot
.894 .28193 Mdot
.894 .28275 Mdot
.894 .28284 Mdot
.894 .28325 Mdot
.894 .28361 Mdot
.894 .284 Mdot
.894 .28449 Mdot
.894 .28509 Mdot
.894 .28511 Mdot
.894 .28588 Mdot
.894 .28771 Mdot
.894 .28881 Mdot
.894 .28886 Mdot
.894 .29059 Mdot
.894 .29127 Mdot
.894 .29133 Mdot
.894 .29145 Mdot
.894 .29153 Mdot
.894 .2923 Mdot
.894 .2936 Mdot
.894 .29374 Mdot
.894 .29471 Mdot
.894 .29542 Mdot
.894 .2965 Mdot
.894 .29681 Mdot
.894 .29797 Mdot
.894 .29836 Mdot
.894 .2988 Mdot
.894 .29903 Mdot
.894 .30014 Mdot
.894 .30097 Mdot
.894 .30097 Mdot
.894 .30177 Mdot
.894 .30267 Mdot
.894 .30396 Mdot
.894 .30486 Mdot
.894 .30489 Mdot
.894 .30492 Mdot
.894 .30522 Mdot
.894 .30523 Mdot
.894 .3054 Mdot
.894 .30564 Mdot
.894 .30577 Mdot
.894 .30582 Mdot
.894 .30746 Mdot
.894 .30754 Mdot
.894 .30788 Mdot
.894 .30867 Mdot
.894 .30919 Mdot
.894 .30931 Mdot
.894 .30963 Mdot
.894 .30997 Mdot
.894 .31036 Mdot
.894 .31044 Mdot
.894 .31142 Mdot
.894 .31147 Mdot
.894 .31148 Mdot
.894 .31155 Mdot
.894 .31227 Mdot
.894 .31307 Mdot
.894 .31351 Mdot
.894 .31393 Mdot
.894 .31411 Mdot
.894 .3143 Mdot
.894 .31439 Mdot
.894 .31476 Mdot
.894 .31479 Mdot
.894 .31526 Mdot
.894 .31582 Mdot
.894 .31817 Mdot
.894 .31826 Mdot
.894 .31887 Mdot
.894 .31948 Mdot
.894 .31959 Mdot
.894 .32038 Mdot
.894 .32041 Mdot
.894 .32094 Mdot
.894 .32108 Mdot
.894 .32149 Mdot
.894 .32223 Mdot
.894 .32226 Mdot
.894 .3229 Mdot
.894 .32371 Mdot
.894 .32495 Mdot
.894 .32513 Mdot
.894 .32523 Mdot
.894 .32664 Mdot
.894 .32682 Mdot
.894 .327 Mdot
.894 .32712 Mdot
.894 .32739 Mdot
.894 .32805 Mdot
.894 .32847 Mdot
.894 .32874 Mdot
.894 .3318 Mdot
.894 .33192 Mdot
.894 .33298 Mdot
.894 .33371 Mdot
.894 .33392 Mdot
.894 .33493 Mdot
.894 .33554 Mdot
.894 .33589 Mdot
.894 .33608 Mdot
.894 .33739 Mdot
.894 .33779 Mdot
.894 .33832 Mdot
.894 .3384 Mdot
.894 .33886 Mdot
.894 .34031 Mdot
.894 .34037 Mdot
.894 .34095 Mdot
.894 .34182 Mdot
.894 .34293 Mdot
.894 .3432 Mdot
.894 .34394 Mdot
.894 .34452 Mdot
.894 .34467 Mdot
.894 .34505 Mdot
.894 .34507 Mdot
.894 .34534 Mdot
.894 .34568 Mdot
.894 .34693 Mdot
.894 .3472 Mdot
.894 .34835 Mdot
.894 .34849 Mdot
.894 .3485 Mdot
.894 .34907 Mdot
.894 .35002 Mdot
.894 .35025 Mdot
.894 .35041 Mdot
.894 .35048 Mdot
.894 .35055 Mdot
.894 .35263 Mdot
.894 .35294 Mdot
.894 .35402 Mdot
.894 .35452 Mdot
.894 .35537 Mdot
.894 .35624 Mdot
.894 .3563 Mdot
.894 .35744 Mdot
.894 .35759 Mdot
.894 .35879 Mdot
.894 .35921 Mdot
.894 .35975 Mdot
.894 .36077 Mdot
.894 .36122 Mdot
.894 .3623 Mdot
.894 .36245 Mdot
.894 .36267 Mdot
.894 .36289 Mdot
.894 .3635 Mdot
.894 .36371 Mdot
.894 .36397 Mdot
.894 .36406 Mdot
.894 .365 Mdot
.894 .36505 Mdot
.894 .36589 Mdot
.894 .3662 Mdot
.894 .3671 Mdot
.894 .36799 Mdot
.894 .36889 Mdot
.894 .36915 Mdot
.894 .36999 Mdot
.894 .37015 Mdot
.894 .37035 Mdot
.894 .37076 Mdot
.894 .37101 Mdot
.894 .37131 Mdot
.894 .3715 Mdot
.894 .37183 Mdot
.894 .37204 Mdot
.894 .37255 Mdot
.894 .37347 Mdot
.894 .37449 Mdot
.894 .37523 Mdot
.894 .37537 Mdot
.894 .37538 Mdot
.894 .37559 Mdot
.894 .37655 Mdot
.894 .37675 Mdot
.894 .37727 Mdot
.894 .37762 Mdot
.894 .37805 Mdot
.894 .3785 Mdot
.894 .37899 Mdot
.894 .38106 Mdot
.894 .38116 Mdot
.894 .38136 Mdot
.894 .38343 Mdot
.894 .38366 Mdot
.894 .38384 Mdot
.894 .38531 Mdot
.894 .38614 Mdot
.894 .3862 Mdot
.894 .38689 Mdot
.894 .38735 Mdot
.894 .38789 Mdot
.894 .38807 Mdot
.894 .38894 Mdot
.894 .38895 Mdot
.894 .39021 Mdot
.894 .39089 Mdot
.894 .39158 Mdot
.894 .39282 Mdot
.894 .39285 Mdot
.894 .39345 Mdot
.894 .39398 Mdot
.894 .39424 Mdot
.894 .39497 Mdot
.894 .39498 Mdot
.894 .3969 Mdot
.894 .39696 Mdot
.894 .39854 Mdot
.894 .399 Mdot
.894 .39926 Mdot
.894 .40087 Mdot
.894 .40116 Mdot
.894 .40117 Mdot
.894 .40127 Mdot
.894 .40132 Mdot
.894 .40145 Mdot
.894 .40251 Mdot
.894 .40255 Mdot
.894 .40265 Mdot
.894 .40275 Mdot
.894 .40322 Mdot
.894 .40372 Mdot
.894 .40399 Mdot
.894 .40405 Mdot
.894 .40411 Mdot
.894 .40413 Mdot
.894 .40576 Mdot
.894 .4066 Mdot
.894 .4068 Mdot
.894 .40796 Mdot
.894 .4082 Mdot
.894 .40995 Mdot
.894 .41075 Mdot
.894 .41165 Mdot
.894 .41361 Mdot
.894 .41372 Mdot
.894 .41381 Mdot
.894 .41476 Mdot
.894 .4148 Mdot
.894 .41535 Mdot
.894 .4161 Mdot
.894 .41653 Mdot
.894 .41669 Mdot
.894 .41864 Mdot
.894 .41924 Mdot
.894 .41967 Mdot
.894 .42034 Mdot
.894 .42194 Mdot
.894 .422 Mdot
.894 .42217 Mdot
.894 .42293 Mdot
.894 .42321 Mdot
.894 .42328 Mdot
.894 .42364 Mdot
.894 .42419 Mdot
.894 .42434 Mdot
.894 .42508 Mdot
.894 .4258 Mdot
.894 .42745 Mdot
.894 .42746 Mdot
.894 .42785 Mdot
.894 .42887 Mdot
.894 .42934 Mdot
.894 .42994 Mdot
.894 .43068 Mdot
.894 .43119 Mdot
.894 .43171 Mdot
.894 .43192 Mdot
.894 .4322 Mdot
.894 .43348 Mdot
.894 .43456 Mdot
.894 .43848 Mdot
.894 .44009 Mdot
.894 .44051 Mdot
.894 .44083 Mdot
.894 .44295 Mdot
.894 .44345 Mdot
.894 .44358 Mdot
.894 .4445 Mdot
.894 .44639 Mdot
.894 .44769 Mdot
.894 .448 Mdot
.894 .44949 Mdot
.894 .44952 Mdot
.894 .44979 Mdot
.894 .45199 Mdot
.894 .45364 Mdot
.894 .45461 Mdot
.894 .45462 Mdot
.894 .4577 Mdot
.894 .45873 Mdot
.894 .4594 Mdot
.894 .4595 Mdot
.894 .46035 Mdot
.894 .46058 Mdot
.894 .46308 Mdot
.894 .46369 Mdot
.894 .46372 Mdot
.894 .46565 Mdot
.894 .46739 Mdot
.894 .46903 Mdot
.894 .47049 Mdot
.894 .47094 Mdot
.894 .47267 Mdot
.894 .47318 Mdot
.894 .47413 Mdot
.894 .47417 Mdot
.894 .47436 Mdot
.894 .4748 Mdot
.894 .47574 Mdot
.894 .47579 Mdot
.894 .4788 Mdot
.894 .4805 Mdot
.894 .48238 Mdot
.894 .48321 Mdot
.894 .4839 Mdot
.894 .48401 Mdot
.894 .48564 Mdot
.894 .48588 Mdot
.894 .48602 Mdot
.894 .48892 Mdot
.894 .48949 Mdot
.894 .49013 Mdot
.894 .49109 Mdot
.894 .49139 Mdot
.894 .49249 Mdot
.894 .49396 Mdot
.894 .49411 Mdot
.894 .49485 Mdot
.894 .4955 Mdot
.894 .4962 Mdot
.894 .49707 Mdot
.894 .49814 Mdot
.894 .49818 Mdot
.894 .49956 Mdot
.894 .50283 Mdot
.894 .5048 Mdot
.894 .50488 Mdot
.894 .50798 Mdot
.894 .50919 Mdot
.894 .5093 Mdot
.894 .50952 Mdot
.894 .50967 Mdot
.894 .51104 Mdot
.894 .51337 Mdot
.894 .51361 Mdot
.894 .51535 Mdot
.894 .51661 Mdot
.894 .51855 Mdot
.894 .51911 Mdot
.894 .52117 Mdot
.894 .52187 Mdot
.894 .52266 Mdot
.894 .52307 Mdot
.894 .52506 Mdot
.894 .52653 Mdot
.894 .52654 Mdot
.894 .52796 Mdot
.894 .52957 Mdot
.894 .53189 Mdot
.894 .53349 Mdot
.894 .53356 Mdot
.894 .53361 Mdot
.894 .53413 Mdot
.894 .53416 Mdot
.894 .53446 Mdot
.894 .53488 Mdot
.894 .53513 Mdot
.894 .53521 Mdot
.894 .53815 Mdot
.894 .53828 Mdot
.894 .5389 Mdot
.894 .54031 Mdot
.894 .54124 Mdot
.894 .54146 Mdot
.894 .54202 Mdot
.894 .54263 Mdot
.894 .54332 Mdot
.896 .01474 Mdot
.896 .01477 Mdot
.896 .01478 Mdot
.896 .01481 Mdot
.896 .01483 Mdot
.896 .01489 Mdot
.896 .01492 Mdot
.896 .01502 Mdot
.896 .01508 Mdot
.896 .01526 Mdot
.896 .01535 Mdot
.896 .01536 Mdot
.896 .01569 Mdot
.896 .01572 Mdot
.896 .01585 Mdot
.896 .01588 Mdot
.896 .01639 Mdot
.896 .01647 Mdot
.896 .01652 Mdot
.896 .01675 Mdot
.896 .0168 Mdot
.896 .0175 Mdot
.896 .01772 Mdot
.896 .01786 Mdot
.896 .01794 Mdot
.896 .01835 Mdot
.896 .01845 Mdot
.896 .0197 Mdot
.896 .0201 Mdot
.896 .02035 Mdot
.896 .0205 Mdot
.896 .02104 Mdot
.896 .02124 Mdot
.896 .02141 Mdot
.896 .02364 Mdot
.896 .02436 Mdot
.896 .02482 Mdot
.896 .02509 Mdot
.896 .02584 Mdot
.896 .02605 Mdot
.896 .0262 Mdot
.896 .02633 Mdot
.896 .0264 Mdot
.896 .02671 Mdot
.896 .02792 Mdot
.896 .02905 Mdot
.896 .02967 Mdot
.896 .02973 Mdot
.896 .03072 Mdot
.896 .03134 Mdot
.896 .03201 Mdot
.896 .03201 Mdot
.896 .03282 Mdot
.896 .0333 Mdot
.896 .03331 Mdot
.896 .03465 Mdot
.896 .03497 Mdot
.896 .03503 Mdot
.896 .03529 Mdot
.896 .03542 Mdot
.896 .03546 Mdot
.896 .0355 Mdot
.896 .03553 Mdot
.896 .03565 Mdot
.896 .03622 Mdot
.896 .03837 Mdot
.896 .03906 Mdot
.896 .03917 Mdot
.896 .0404 Mdot
.896 .04057 Mdot
.896 .0409 Mdot
.896 .04104 Mdot
.896 .04129 Mdot
.896 .04142 Mdot
.896 .04152 Mdot
.896 .04162 Mdot
.896 .04266 Mdot
.896 .04287 Mdot
.896 .04339 Mdot
.896 .0442 Mdot
.896 .04451 Mdot
.896 .04471 Mdot
.896 .0457 Mdot
.896 .04571 Mdot
.896 .04708 Mdot
.896 .04716 Mdot
.896 .04754 Mdot
.896 .04802 Mdot
.896 .04804 Mdot
.896 .04848 Mdot
.896 .04928 Mdot
.896 .04989 Mdot
.896 .05026 Mdot
.896 .0503 Mdot
.896 .05044 Mdot
.896 .05077 Mdot
.896 .05101 Mdot
.896 .05111 Mdot
.896 .05158 Mdot
.896 .05182 Mdot
.896 .05189 Mdot
.896 .05197 Mdot
.896 .05201 Mdot
.896 .05222 Mdot
.896 .05224 Mdot
.896 .05324 Mdot
.896 .0544 Mdot
.896 .0551 Mdot
.896 .05711 Mdot
.896 .05744 Mdot
.896 .05755 Mdot
.896 .05834 Mdot
.896 .05853 Mdot
.896 .05864 Mdot
.896 .05901 Mdot
.896 .05939 Mdot
.896 .05944 Mdot
.896 .05974 Mdot
.896 .06075 Mdot
.896 .06104 Mdot
.896 .06104 Mdot
.896 .06134 Mdot
.896 .06163 Mdot
.896 .06188 Mdot
.896 .06235 Mdot
.896 .06257 Mdot
.896 .06274 Mdot
.896 .06292 Mdot
.896 .06479 Mdot
.896 .06516 Mdot
.896 .0661 Mdot
.896 .06755 Mdot
.896 .06771 Mdot
.896 .06806 Mdot
.896 .06811 Mdot
.896 .06811 Mdot
.896 .06846 Mdot
.896 .06847 Mdot
.896 .06928 Mdot
.896 .06945 Mdot
.896 .06951 Mdot
.896 .06973 Mdot
.896 .07024 Mdot
.896 .07025 Mdot
.896 .07127 Mdot
.896 .07179 Mdot
.896 .07272 Mdot
.896 .07285 Mdot
.896 .07322 Mdot
.896 .07347 Mdot
.896 .07354 Mdot
.896 .07366 Mdot
.896 .0744 Mdot
.896 .07443 Mdot
.896 .07521 Mdot
.896 .07525 Mdot
.896 .07665 Mdot
.896 .07775 Mdot
.896 .07841 Mdot
.896 .07841 Mdot
.896 .07849 Mdot
.896 .07874 Mdot
.896 .07922 Mdot
.896 .07933 Mdot
.896 .07976 Mdot
.896 .07994 Mdot
.896 .08078 Mdot
.896 .08119 Mdot
.896 .08121 Mdot
.896 .08133 Mdot
.896 .08147 Mdot
.896 .08155 Mdot
.896 .08192 Mdot
.896 .08195 Mdot
.896 .083 Mdot
.896 .08376 Mdot
.896 .0844 Mdot
.896 .08574 Mdot
.896 .08584 Mdot
.896 .08623 Mdot
.896 .08709 Mdot
.896 .08733 Mdot
.896 .08818 Mdot
.896 .08908 Mdot
.896 .09018 Mdot
.896 .09032 Mdot
.896 .09068 Mdot
.896 .09079 Mdot
.896 .09101 Mdot
.896 .09128 Mdot
.896 .09147 Mdot
.896 .09148 Mdot
.896 .09275 Mdot
.896 .09289 Mdot
.896 .09323 Mdot
.896 .09343 Mdot
.896 .09404 Mdot
.896 .09409 Mdot
.896 .09477 Mdot
.896 .09486 Mdot
.896 .09539 Mdot
.896 .09571 Mdot
.896 .09669 Mdot
.896 .09721 Mdot
.896 .09728 Mdot
.896 .09729 Mdot
.896 .09773 Mdot
.896 .09773 Mdot
.896 .09826 Mdot
.896 .09864 Mdot
.896 .09879 Mdot
.896 .09924 Mdot
.896 .10006 Mdot
.896 .10007 Mdot
.896 .10035 Mdot
.896 .10046 Mdot
.896 .10067 Mdot
.896 .10078 Mdot
.896 .1011 Mdot
.896 .10141 Mdot
.896 .10202 Mdot
.896 .10291 Mdot
.896 .10349 Mdot
.896 .10445 Mdot
.896 .10468 Mdot
.896 .10511 Mdot
.896 .1068 Mdot
.896 .10872 Mdot
.896 .10881 Mdot
.896 .10909 Mdot
.896 .10939 Mdot
.896 .10968 Mdot
.896 .11031 Mdot
.896 .1104 Mdot
.896 .1104 Mdot
.896 .11102 Mdot
.896 .11104 Mdot
.896 .11128 Mdot
.896 .11191 Mdot
.896 .11242 Mdot
.896 .1125 Mdot
.896 .11266 Mdot
.896 .1128 Mdot
.896 .1129 Mdot
.896 .11331 Mdot
.896 .11422 Mdot
.896 .11424 Mdot
.896 .11442 Mdot
.896 .11606 Mdot
.896 .11607 Mdot
.896 .11671 Mdot
.896 .117 Mdot
.896 .11704 Mdot
.896 .11786 Mdot
.896 .11866 Mdot
.896 .1189 Mdot
.896 .11956 Mdot
.896 .11993 Mdot
.896 .12001 Mdot
.896 .12013 Mdot
.896 .12035 Mdot
.896 .12167 Mdot
.896 .12173 Mdot
.896 .12222 Mdot
.896 .12243 Mdot
.896 .12313 Mdot
.896 .12314 Mdot
.896 .12319 Mdot
.896 .12357 Mdot
.896 .12368 Mdot
.896 .1244 Mdot
.896 .12547 Mdot
.896 .12551 Mdot
.896 .12563 Mdot
.896 .12571 Mdot
.896 .12585 Mdot
.896 .12767 Mdot
.896 .12886 Mdot
.896 .12886 Mdot
.896 .129 Mdot
.896 .12944 Mdot
.896 .12967 Mdot
.896 .13032 Mdot
.896 .1305 Mdot
.896 .13063 Mdot
.896 .13128 Mdot
.896 .1316 Mdot
.896 .13173 Mdot
.896 .13203 Mdot
.896 .1331 Mdot
.896 .13384 Mdot
.896 .13385 Mdot
.896 .13388 Mdot
.896 .13409 Mdot
.896 .13435 Mdot
.896 .13448 Mdot
.896 .13488 Mdot
.896 .13515 Mdot
.896 .13521 Mdot
.896 .13532 Mdot
.896 .13709 Mdot
.896 .13739 Mdot
.896 .13742 Mdot
.896 .13844 Mdot
.896 .13852 Mdot
.896 .13906 Mdot
.896 .13959 Mdot
.896 .13993 Mdot
.896 .14019 Mdot
.896 .14086 Mdot
.896 .14147 Mdot
.896 .14169 Mdot
.896 .14174 Mdot
.896 .14199 Mdot
.896 .14216 Mdot
.896 .14251 Mdot
.896 .14287 Mdot
.896 .14441 Mdot
.896 .14483 Mdot
.896 .14487 Mdot
.896 .14507 Mdot
.896 .14573 Mdot
.896 .14637 Mdot
.896 .1464 Mdot
.896 .14798 Mdot
.896 .14873 Mdot
.896 .14923 Mdot
.896 .1498 Mdot
.896 .14994 Mdot
.896 .15009 Mdot
.896 .1502 Mdot
.896 .15085 Mdot
.896 .15104 Mdot
.896 .15118 Mdot
.896 .15144 Mdot
.896 .15166 Mdot
.896 .1519 Mdot
.896 .15192 Mdot
.896 .15226 Mdot
.896 .15227 Mdot
.896 .15227 Mdot
.896 .15454 Mdot
.896 .15481 Mdot
.896 .15525 Mdot
.896 .15542 Mdot
.896 .15562 Mdot
.896 .15577 Mdot
.896 .15687 Mdot
.896 .15696 Mdot
.896 .15721 Mdot
.896 .15749 Mdot
.896 .15818 Mdot
.896 .15823 Mdot
.896 .15834 Mdot
.896 .15929 Mdot
.896 .15985 Mdot
.896 .15998 Mdot
.896 .16162 Mdot
.896 .16254 Mdot
.896 .16267 Mdot
.896 .16269 Mdot
.896 .16338 Mdot
.896 .16348 Mdot
.896 .16349 Mdot
.896 .16443 Mdot
.896 .16506 Mdot
.896 .16511 Mdot
.896 .16538 Mdot
.896 .16612 Mdot
.896 .16618 Mdot
.896 .16765 Mdot
.896 .16767 Mdot
.896 .1681 Mdot
.896 .16818 Mdot
.896 .16838 Mdot
.896 .16874 Mdot
.896 .16895 Mdot
.896 .16952 Mdot
.896 .17007 Mdot
.896 .17007 Mdot
.896 .17034 Mdot
.896 .17041 Mdot
.896 .17046 Mdot
.896 .1706 Mdot
.896 .17117 Mdot
.896 .17127 Mdot
.896 .1718 Mdot
.896 .17275 Mdot
.896 .17328 Mdot
.896 .17379 Mdot
.896 .17407 Mdot
.896 .17551 Mdot
.896 .17577 Mdot
.896 .17594 Mdot
.896 .17637 Mdot
.896 .17671 Mdot
.896 .17793 Mdot
.896 .17824 Mdot
.896 .17866 Mdot
.896 .17886 Mdot
.896 .17972 Mdot
.896 .18003 Mdot
.896 .18318 Mdot
.896 .18333 Mdot
.896 .18383 Mdot
.896 .18437 Mdot
.896 .18489 Mdot
.896 .18602 Mdot
.896 .18616 Mdot
.896 .18618 Mdot
.896 .18619 Mdot
.896 .1873 Mdot
.896 .18733 Mdot
.896 .18777 Mdot
.896 .18787 Mdot
.896 .18842 Mdot
.896 .18848 Mdot
.896 .1889 Mdot
.896 .18906 Mdot
.896 .1898 Mdot
.896 .18994 Mdot
.896 .19023 Mdot
.896 .19048 Mdot
.896 .19067 Mdot
.896 .1908 Mdot
.896 .19094 Mdot
.896 .19139 Mdot
.896 .19207 Mdot
.896 .19229 Mdot
.896 .19302 Mdot
.896 .19305 Mdot
.896 .19339 Mdot
.896 .19351 Mdot
.896 .19363 Mdot
.896 .19622 Mdot
.896 .19633 Mdot
.896 .19634 Mdot
.896 .19671 Mdot
.896 .19685 Mdot
.896 .19733 Mdot
.896 .19749 Mdot
.896 .19793 Mdot
.896 .19801 Mdot
.896 .19807 Mdot
.896 .19955 Mdot
.896 .20042 Mdot
.896 .20098 Mdot
.896 .20142 Mdot
.896 .20233 Mdot
.896 .20259 Mdot
.896 .20326 Mdot
.896 .20341 Mdot
.896 .20347 Mdot
.896 .20362 Mdot
.896 .20401 Mdot
.896 .20442 Mdot
.896 .20494 Mdot
.896 .20543 Mdot
.896 .20585 Mdot
.896 .20629 Mdot
.896 .20638 Mdot
.896 .20648 Mdot
.896 .2069 Mdot
.896 .20736 Mdot
.896 .20773 Mdot
.896 .20899 Mdot
.896 .20902 Mdot
.896 .2091 Mdot
.896 .20979 Mdot
.896 .20998 Mdot
.896 .21077 Mdot
.896 .21128 Mdot
.896 .21319 Mdot
.896 .21326 Mdot
.896 .21348 Mdot
.896 .21361 Mdot
.896 .21387 Mdot
.896 .21421 Mdot
.896 .21426 Mdot
.896 .21551 Mdot
.896 .21581 Mdot
.896 .21625 Mdot
.896 .21681 Mdot
.896 .21714 Mdot
.896 .21727 Mdot
.896 .21827 Mdot
.896 .21844 Mdot
.896 .21925 Mdot
.896 .21927 Mdot
.896 .21951 Mdot
.896 .22025 Mdot
.896 .22031 Mdot
.896 .22072 Mdot
.896 .2216 Mdot
.896 .22187 Mdot
.896 .22221 Mdot
.896 .22236 Mdot
.896 .22243 Mdot
.896 .22359 Mdot
.896 .22418 Mdot
.896 .22441 Mdot
.896 .22495 Mdot
.896 .22601 Mdot
.896 .22686 Mdot
.896 .22748 Mdot
.896 .22809 Mdot
.896 .22818 Mdot
.896 .2282 Mdot
.896 .22826 Mdot
.896 .22863 Mdot
.896 .22909 Mdot
.896 .22934 Mdot
.896 .23005 Mdot
.896 .23054 Mdot
.896 .23064 Mdot
.896 .23083 Mdot
.896 .2312 Mdot
.896 .23364 Mdot
.896 .23381 Mdot
.896 .23383 Mdot
.896 .23401 Mdot
.896 .23455 Mdot
.896 .23459 Mdot
.896 .23501 Mdot
.896 .23643 Mdot
.896 .23658 Mdot
.896 .23754 Mdot
.896 .2385 Mdot
.896 .23879 Mdot
.896 .2391 Mdot
.896 .23956 Mdot
.896 .24077 Mdot
.896 .24185 Mdot
.896 .24225 Mdot
.896 .24234 Mdot
.896 .24247 Mdot
.896 .24265 Mdot
.896 .24279 Mdot
.896 .2431 Mdot
.896 .24372 Mdot
.896 .24438 Mdot
.896 .24597 Mdot
.896 .24713 Mdot
.896 .24789 Mdot
.896 .24795 Mdot
.896 .24832 Mdot
.896 .24949 Mdot
.896 .25064 Mdot
.896 .2507 Mdot
.896 .25173 Mdot
.896 .25352 Mdot
.896 .25488 Mdot
.896 .25576 Mdot
.896 .25607 Mdot
.896 .25678 Mdot
.896 .25705 Mdot
.896 .2573 Mdot
.896 .25751 Mdot
.896 .25867 Mdot
.896 .25892 Mdot
.896 .25902 Mdot
.896 .25926 Mdot
.896 .25972 Mdot
.896 .25992 Mdot
.896 .26011 Mdot
.896 .26055 Mdot
.896 .26058 Mdot
.896 .26119 Mdot
.896 .26121 Mdot
.896 .26122 Mdot
.896 .26219 Mdot
.896 .26305 Mdot
.896 .26385 Mdot
.896 .26454 Mdot
.896 .26529 Mdot
.896 .26577 Mdot
.896 .26655 Mdot
.896 .26686 Mdot
.896 .26721 Mdot
.896 .26748 Mdot
.896 .26824 Mdot
.896 .26905 Mdot
.896 .26937 Mdot
.896 .26945 Mdot
.896 .26962 Mdot
.896 .27006 Mdot
.896 .27014 Mdot
.896 .27057 Mdot
.896 .27163 Mdot
.896 .2718 Mdot
.896 .2719 Mdot
.896 .27208 Mdot
.896 .27228 Mdot
.896 .27289 Mdot
.896 .27379 Mdot
.896 .27428 Mdot
.896 .2744 Mdot
.896 .2748 Mdot
.896 .27502 Mdot
.896 .27637 Mdot
.896 .27641 Mdot
.896 .27643 Mdot
.896 .27797 Mdot
.896 .27956 Mdot
.896 .27962 Mdot
.896 .27984 Mdot
.896 .27989 Mdot
.896 .28113 Mdot
.896 .2813 Mdot
.896 .28131 Mdot
.896 .28231 Mdot
.896 .283 Mdot
.896 .28413 Mdot
.896 .28422 Mdot
.896 .28471 Mdot
.896 .28491 Mdot
.896 .28604 Mdot
.896 .28614 Mdot
.896 .28712 Mdot
.896 .28877 Mdot
.896 .28881 Mdot
.896 .28952 Mdot
.896 .28957 Mdot
.896 .28972 Mdot
.896 .29008 Mdot
.896 .29073 Mdot
.896 .29104 Mdot
.896 .2911 Mdot
.896 .29213 Mdot
.896 .29311 Mdot
.896 .29311 Mdot
.896 .29355 Mdot
.896 .2936 Mdot
.896 .29371 Mdot
.896 .29382 Mdot
.896 .29406 Mdot
.896 .29456 Mdot
.896 .29508 Mdot
.896 .29527 Mdot
.896 .29569 Mdot
.896 .29621 Mdot
.896 .29655 Mdot
.896 .29792 Mdot
.896 .29886 Mdot
.896 .299 Mdot
.896 .29978 Mdot
.896 .30028 Mdot
.896 .30159 Mdot
.896 .30261 Mdot
.896 .30286 Mdot
.896 .30288 Mdot
.896 .30333 Mdot
.896 .30342 Mdot
.896 .30363 Mdot
.896 .30439 Mdot
.896 .30485 Mdot
.896 .30501 Mdot
.896 .30508 Mdot
.896 .30646 Mdot
.896 .30719 Mdot
.896 .30774 Mdot
.896 .30851 Mdot
.896 .30887 Mdot
.896 .30986 Mdot
.896 .31041 Mdot
.896 .31043 Mdot
.896 .31075 Mdot
.896 .31096 Mdot
.896 .31133 Mdot
.896 .31195 Mdot
.896 .31393 Mdot
.896 .3166 Mdot
.896 .3168 Mdot
.896 .31688 Mdot
.896 .31776 Mdot
.896 .3184 Mdot
.896 .31874 Mdot
.896 .31877 Mdot
.896 .31968 Mdot
.896 .32005 Mdot
.896 .32077 Mdot
.896 .3217 Mdot
.896 .32195 Mdot
.896 .32197 Mdot
.896 .322 Mdot
.896 .32398 Mdot
.896 .32404 Mdot
.896 .32482 Mdot
.896 .32501 Mdot
.896 .32508 Mdot
.896 .32523 Mdot
.896 .3253 Mdot
.896 .32599 Mdot
.896 .3261 Mdot
.896 .32685 Mdot
.896 .32714 Mdot
.896 .32846 Mdot
.896 .32871 Mdot
.896 .32924 Mdot
.896 .32968 Mdot
.896 .33003 Mdot
.896 .33023 Mdot
.896 .33026 Mdot
.896 .33052 Mdot
.896 .33133 Mdot
.896 .33254 Mdot
.896 .33293 Mdot
.896 .33424 Mdot
.896 .3343 Mdot
.896 .33491 Mdot
.896 .33511 Mdot
.896 .33533 Mdot
.896 .33535 Mdot
.896 .33552 Mdot
.896 .33625 Mdot
.896 .33641 Mdot
.896 .33997 Mdot
.896 .34017 Mdot
.896 .34019 Mdot
.896 .34039 Mdot
.896 .34085 Mdot
.896 .34094 Mdot
.896 .34097 Mdot
.896 .3411 Mdot
.896 .34196 Mdot
.896 .34225 Mdot
.896 .34304 Mdot
.896 .34319 Mdot
.896 .34329 Mdot
.896 .34418 Mdot
.896 .34594 Mdot
.896 .34639 Mdot
.896 .34749 Mdot
.896 .3485 Mdot
.896 .34928 Mdot
.896 .35003 Mdot
.896 .35031 Mdot
.896 .35092 Mdot
.896 .35139 Mdot
.896 .35189 Mdot
.896 .35251 Mdot
.896 .35259 Mdot
.896 .35285 Mdot
.896 .35297 Mdot
.896 .35323 Mdot
.896 .35394 Mdot
.896 .35466 Mdot
.896 .35559 Mdot
.896 .35614 Mdot
.896 .35647 Mdot
.896 .35648 Mdot
.896 .35723 Mdot
.896 .35802 Mdot
.896 .35818 Mdot
.896 .35836 Mdot
.896 .35912 Mdot
.896 .35961 Mdot
.896 .35993 Mdot
.896 .3606 Mdot
.896 .36286 Mdot
.896 .3629 Mdot
.896 .36306 Mdot
.896 .36428 Mdot
.896 .36464 Mdot
.896 .36492 Mdot
.896 .36505 Mdot
.896 .36604 Mdot
.896 .36696 Mdot
.896 .36731 Mdot
.896 .36749 Mdot
.896 .36796 Mdot
.896 .36911 Mdot
.896 .37039 Mdot
.896 .3705 Mdot
.896 .3709 Mdot
.896 .37114 Mdot
.896 .3712 Mdot
.896 .37161 Mdot
.896 .3722 Mdot
.896 .37222 Mdot
.896 .37229 Mdot
.896 .37241 Mdot
.896 .37455 Mdot
.896 .37508 Mdot
.896 .3757 Mdot
.896 .37586 Mdot
.896 .37688 Mdot
.896 .37745 Mdot
.896 .3777 Mdot
.896 .37885 Mdot
.896 .37887 Mdot
.896 .37949 Mdot
.896 .37979 Mdot
.896 .38027 Mdot
.896 .38041 Mdot
.896 .38079 Mdot
.896 .38113 Mdot
.896 .38125 Mdot
.896 .38128 Mdot
.896 .38171 Mdot
.896 .38303 Mdot
.896 .38314 Mdot
.896 .38351 Mdot
.896 .38388 Mdot
.896 .38518 Mdot
.896 .38546 Mdot
.896 .38578 Mdot
.896 .38594 Mdot
.896 .38655 Mdot
.896 .38681 Mdot
.896 .38695 Mdot
.896 .38715 Mdot
.896 .38882 Mdot
.896 .38903 Mdot
.896 .38991 Mdot
.896 .39007 Mdot
.896 .39049 Mdot
.896 .39146 Mdot
.896 .39336 Mdot
.896 .39429 Mdot
.896 .39489 Mdot
.896 .39599 Mdot
.896 .39709 Mdot
.896 .39724 Mdot
.896 .39728 Mdot
.896 .39731 Mdot
.896 .39739 Mdot
.896 .39776 Mdot
.896 .39806 Mdot
.896 .39888 Mdot
.896 .39932 Mdot
.896 .40027 Mdot
.896 .4006 Mdot
.896 .40148 Mdot
.896 .40165 Mdot
.896 .40188 Mdot
.896 .402 Mdot
.896 .40265 Mdot
.896 .40607 Mdot
.896 .40702 Mdot
.896 .40733 Mdot
.896 .40736 Mdot
.896 .40768 Mdot
.896 .40866 Mdot
.896 .40874 Mdot
.896 .40937 Mdot
.896 .40949 Mdot
.896 .41017 Mdot
.896 .41024 Mdot
.896 .41168 Mdot
.896 .41195 Mdot
.896 .41203 Mdot
.896 .4123 Mdot
.896 .41264 Mdot
.896 .41402 Mdot
.896 .41509 Mdot
.896 .41573 Mdot
.896 .41626 Mdot
.896 .41655 Mdot
.896 .41682 Mdot
.896 .41706 Mdot
.896 .4173 Mdot
.896 .41764 Mdot
.896 .4198 Mdot
.896 .42172 Mdot
.896 .42175 Mdot
.896 .42245 Mdot
.896 .42262 Mdot
.896 .42286 Mdot
.896 .42317 Mdot
.896 .42343 Mdot
.896 .42399 Mdot
.896 .42408 Mdot
.896 .42509 Mdot
.896 .42585 Mdot
.896 .42627 Mdot
.896 .42831 Mdot
.896 .42913 Mdot
.896 .42947 Mdot
.896 .4312 Mdot
.896 .43256 Mdot
.896 .43266 Mdot
.896 .43267 Mdot
.896 .43333 Mdot
.896 .43544 Mdot
.896 .43749 Mdot
.896 .43759 Mdot
.896 .43945 Mdot
.896 .44266 Mdot
.896 .44508 Mdot
.896 .44667 Mdot
.896 .44723 Mdot
.896 .4485 Mdot
.896 .44897 Mdot
.896 .44942 Mdot
.896 .44981 Mdot
.896 .45187 Mdot
.896 .45232 Mdot
.896 .4525 Mdot
.896 .45293 Mdot
.896 .45376 Mdot
.896 .45412 Mdot
.896 .45447 Mdot
.896 .45524 Mdot
.896 .45531 Mdot
.896 .45641 Mdot
.896 .45643 Mdot
.896 .45644 Mdot
.896 .45819 Mdot
.896 .45972 Mdot
.896 .46117 Mdot
.896 .46241 Mdot
.896 .46374 Mdot
.896 .4646 Mdot
.896 .466 Mdot
.896 .46656 Mdot
.896 .46719 Mdot
.896 .46767 Mdot
.896 .46904 Mdot
.896 .47048 Mdot
.896 .47105 Mdot
.896 .4712 Mdot
.896 .4715 Mdot
.896 .4723 Mdot
.896 .47243 Mdot
.896 .4732 Mdot
.896 .4751 Mdot
.896 .47542 Mdot
.896 .47559 Mdot
.896 .47592 Mdot
.896 .47626 Mdot
.896 .47737 Mdot
.896 .47897 Mdot
.896 .47986 Mdot
.896 .48007 Mdot
.896 .48078 Mdot
.896 .48119 Mdot
.896 .48359 Mdot
.896 .48367 Mdot
.896 .48371 Mdot
.896 .48647 Mdot
.896 .48932 Mdot
.896 .48942 Mdot
.896 .48982 Mdot
.896 .48991 Mdot
.896 .49213 Mdot
.896 .49244 Mdot
.896 .49246 Mdot
.896 .49425 Mdot
.896 .49549 Mdot
.896 .49751 Mdot
.896 .49767 Mdot
.896 .49855 Mdot
.896 .4989 Mdot
.896 .50093 Mdot
.896 .50111 Mdot
.896 .50286 Mdot
.896 .50582 Mdot
.896 .5059 Mdot
.896 .50716 Mdot
.896 .50726 Mdot
.896 .50752 Mdot
.896 .50816 Mdot
.896 .50933 Mdot
.896 .5099 Mdot
.896 .51001 Mdot
.896 .51184 Mdot
.896 .5136 Mdot
.896 .51361 Mdot
.896 .51439 Mdot
.896 .51447 Mdot
.896 .51468 Mdot
.896 .51487 Mdot
.896 .5162 Mdot
.896 .51713 Mdot
.896 .51746 Mdot
.896 .51823 Mdot
.896 .51916 Mdot
.896 .51977 Mdot
.896 .52221 Mdot
.896 .5239 Mdot
.896 .52415 Mdot
.896 .52555 Mdot
.896 .52645 Mdot
.896 .52879 Mdot
.896 .53063 Mdot
.896 .53107 Mdot
.896 .53111 Mdot
.896 .53192 Mdot
.896 .53207 Mdot
.896 .53245 Mdot
.896 .53382 Mdot
.896 .53463 Mdot
.896 .53492 Mdot
.896 .53505 Mdot
.896 .53752 Mdot
.896 .53884 Mdot
.896 .53982 Mdot
.896 .5412 Mdot
.896 .54184 Mdot
.896 .54362 Mdot
.898 .01838 Mdot
.898 .01853 Mdot
.898 .02062 Mdot
.898 .02098 Mdot
.898 .02131 Mdot
.898 .0214 Mdot
.898 .02157 Mdot
.898 .02296 Mdot
.898 .02482 Mdot
.898 .02532 Mdot
.898 .02597 Mdot
.898 .02655 Mdot
.898 .02672 Mdot
.898 .02703 Mdot
.898 .02731 Mdot
.898 .02752 Mdot
.898 .02898 Mdot
.898 .02952 Mdot
.898 .0319 Mdot
.898 .03286 Mdot
.898 .03295 Mdot
.898 .033 Mdot
.898 .03377 Mdot
.898 .03485 Mdot
.898 .03492 Mdot
.898 .03527 Mdot
.898 .0353 Mdot
.898 .03568 Mdot
.898 .03597 Mdot
.898 .03627 Mdot
.898 .03642 Mdot
.898 .03683 Mdot
.898 .03734 Mdot
.898 .03756 Mdot
.898 .03772 Mdot
.898 .03816 Mdot
.898 .0386 Mdot
.898 .04001 Mdot
.898 .04016 Mdot
.898 .04033 Mdot
.898 .0413 Mdot
.898 .04141 Mdot
.898 .04239 Mdot
.898 .04252 Mdot
.898 .04276 Mdot
.898 .04439 Mdot
.898 .04534 Mdot
.898 .04558 Mdot
.898 .04722 Mdot
.898 .04731 Mdot
.898 .04744 Mdot
.898 .04746 Mdot
.898 .04756 Mdot
.898 .04893 Mdot
.898 .05031 Mdot
.898 .05088 Mdot
.898 .05099 Mdot
.898 .05101 Mdot
.898 .05162 Mdot
.898 .05167 Mdot
.898 .05169 Mdot
.898 .05237 Mdot
.898 .0529 Mdot
.898 .05344 Mdot
.898 .05348 Mdot
.898 .05353 Mdot
.898 .0537 Mdot
.898 .05439 Mdot
.898 .05443 Mdot
.898 .05464 Mdot
.898 .05535 Mdot
.898 .05575 Mdot
.898 .05588 Mdot
.898 .05588 Mdot
.898 .05603 Mdot
.898 .05609 Mdot
.898 .05682 Mdot
.898 .05761 Mdot
.898 .05773 Mdot
.898 .05785 Mdot
.898 .05916 Mdot
.898 .06014 Mdot
.898 .06035 Mdot
.898 .06041 Mdot
.898 .06041 Mdot
.898 .06072 Mdot
.898 .06078 Mdot
.898 .06133 Mdot
.898 .06175 Mdot
.898 .06247 Mdot
.898 .06265 Mdot
.898 .06286 Mdot
.898 .06327 Mdot
.898 .0634 Mdot
.898 .06353 Mdot
.898 .06363 Mdot
.898 .06372 Mdot
.898 .06442 Mdot
.898 .06462 Mdot
.898 .06466 Mdot
.898 .06508 Mdot
.898 .06773 Mdot
.898 .06801 Mdot
.898 .06841 Mdot
.898 .06971 Mdot
.898 .07014 Mdot
.898 .07186 Mdot
.898 .07223 Mdot
.898 .07228 Mdot
.898 .0731 Mdot
.898 .07325 Mdot
.898 .07349 Mdot
.898 .07353 Mdot
.898 .0737 Mdot
.898 .0738 Mdot
.898 .07485 Mdot
.898 .07494 Mdot
.898 .07511 Mdot
.898 .07584 Mdot
.898 .07592 Mdot
.898 .07616 Mdot
.898 .07671 Mdot
.898 .07783 Mdot
.898 .07806 Mdot
.898 .07826 Mdot
.898 .07864 Mdot
.898 .07966 Mdot
.898 .07987 Mdot
.898 .07989 Mdot
.898 .081 Mdot
.898 .08108 Mdot
.898 .08113 Mdot
.898 .08212 Mdot
.898 .08234 Mdot
.898 .08266 Mdot
.898 .08273 Mdot
.898 .08329 Mdot
.898 .08426 Mdot
.898 .08433 Mdot
.898 .08443 Mdot
.898 .08474 Mdot
.898 .0852 Mdot
.898 .08597 Mdot
.898 .08604 Mdot
.898 .08642 Mdot
.898 .08682 Mdot
.898 .08754 Mdot
.898 .08842 Mdot
.898 .08865 Mdot
.898 .08865 Mdot
.898 .08892 Mdot
.898 .08903 Mdot
.898 .08941 Mdot
.898 .08949 Mdot
.898 .09034 Mdot
.898 .0911 Mdot
.898 .09142 Mdot
.898 .09176 Mdot
.898 .09197 Mdot
.898 .09218 Mdot
.898 .09267 Mdot
.898 .09449 Mdot
.898 .09453 Mdot
.898 .09471 Mdot
.898 .09515 Mdot
.898 .0956 Mdot
.898 .0963 Mdot
.898 .09631 Mdot
.898 .09664 Mdot
.898 .09667 Mdot
.898 .09678 Mdot
.898 .09679 Mdot
.898 .09725 Mdot
.898 .09733 Mdot
.898 .09739 Mdot
.898 .09744 Mdot
.898 .09755 Mdot
.898 .09844 Mdot
.898 .09845 Mdot
.898 .09859 Mdot
.898 .09919 Mdot
.898 .09953 Mdot
.898 .10048 Mdot
.898 .10081 Mdot
.898 .10118 Mdot
.898 .10125 Mdot
.898 .10192 Mdot
.898 .10216 Mdot
.898 .1024 Mdot
.898 .10257 Mdot
.898 .10262 Mdot
.898 .10273 Mdot
.898 .10398 Mdot
.898 .10434 Mdot
.898 .10442 Mdot
.898 .10468 Mdot
.898 .10517 Mdot
.898 .10704 Mdot
.898 .10856 Mdot
.898 .10884 Mdot
.898 .10935 Mdot
.898 .10986 Mdot
.898 .10993 Mdot
.898 .11 Mdot
.898 .11033 Mdot
.898 .11043 Mdot
.898 .1105 Mdot
.898 .11116 Mdot
.898 .11118 Mdot
.898 .11203 Mdot
.898 .11349 Mdot
.898 .11405 Mdot
.898 .11426 Mdot
.898 .11481 Mdot
.898 .11553 Mdot
.898 .11695 Mdot
.898 .11735 Mdot
.898 .11802 Mdot
.898 .11811 Mdot
.898 .11855 Mdot
.898 .11883 Mdot
.898 .11957 Mdot
.898 .11962 Mdot
.898 .11984 Mdot
.898 .12027 Mdot
.898 .12034 Mdot
.898 .12052 Mdot
.898 .12065 Mdot
.898 .12084 Mdot
.898 .12086 Mdot
.898 .12263 Mdot
.898 .12272 Mdot
.898 .12289 Mdot
.898 .12303 Mdot
.898 .12318 Mdot
.898 .12449 Mdot
.898 .12465 Mdot
.898 .12508 Mdot
.898 .12601 Mdot
.898 .12607 Mdot
.898 .12807 Mdot
.898 .12822 Mdot
.898 .12828 Mdot
.898 .12842 Mdot
.898 .12848 Mdot
.898 .12865 Mdot
.898 .12875 Mdot
.898 .12884 Mdot
.898 .12953 Mdot
.898 .12962 Mdot
.898 .13053 Mdot
.898 .13136 Mdot
.898 .13173 Mdot
.898 .13177 Mdot
.898 .13259 Mdot
.898 .13377 Mdot
.898 .13391 Mdot
.898 .134 Mdot
.898 .13514 Mdot
.898 .13578 Mdot
.898 .13616 Mdot
.898 .13639 Mdot
.898 .13674 Mdot
.898 .13688 Mdot
.898 .13788 Mdot
.898 .1387 Mdot
.898 .13961 Mdot
.898 .13974 Mdot
.898 .13993 Mdot
.898 .1402 Mdot
.898 .14036 Mdot
.898 .14048 Mdot
.898 .141 Mdot
.898 .14124 Mdot
.898 .14131 Mdot
.898 .14156 Mdot
.898 .14238 Mdot
.898 .14269 Mdot
.898 .14273 Mdot
.898 .14282 Mdot
.898 .1435 Mdot
.898 .14356 Mdot
.898 .14375 Mdot
.898 .14422 Mdot
.898 .1443 Mdot
.898 .14485 Mdot
.898 .14552 Mdot
.898 .14569 Mdot
.898 .14632 Mdot
.898 .147 Mdot
.898 .14708 Mdot
.898 .1475 Mdot
.898 .14751 Mdot
.898 .14798 Mdot
.898 .14818 Mdot
.898 .14838 Mdot
.898 .1488 Mdot
.898 .14884 Mdot
.898 .14887 Mdot
.898 .14901 Mdot
.898 .14933 Mdot
.898 .15053 Mdot
.898 .1519 Mdot
.898 .15242 Mdot
.898 .15247 Mdot
.898 .15309 Mdot
.898 .15346 Mdot
.898 .15384 Mdot
.898 .15461 Mdot
.898 .15473 Mdot
.898 .15631 Mdot
.898 .15799 Mdot
.898 .15806 Mdot
.898 .15839 Mdot
.898 .15865 Mdot
.898 .15918 Mdot
.898 .1594 Mdot
.898 .15951 Mdot
.898 .15999 Mdot
.898 .16123 Mdot
.898 .16126 Mdot
.898 .16157 Mdot
.898 .16181 Mdot
.898 .16185 Mdot
.898 .1619 Mdot
.898 .16205 Mdot
.898 .1621 Mdot
.898 .16212 Mdot
.898 .16213 Mdot
.898 .16291 Mdot
.898 .16295 Mdot
.898 .1631 Mdot
.898 .1632 Mdot
.898 .1633 Mdot
.898 .16349 Mdot
.898 .16396 Mdot
.898 .16461 Mdot
.898 .16509 Mdot
.898 .16511 Mdot
.898 .16535 Mdot
.898 .16644 Mdot
.898 .16657 Mdot
.898 .16697 Mdot
.898 .16704 Mdot
.898 .16833 Mdot
.898 .16837 Mdot
.898 .16875 Mdot
.898 .16934 Mdot
.898 .17001 Mdot
.898 .17014 Mdot
.898 .17134 Mdot
.898 .17158 Mdot
.898 .17176 Mdot
.898 .17205 Mdot
.898 .17219 Mdot
.898 .1725 Mdot
.898 .17254 Mdot
.898 .17259 Mdot
.898 .17279 Mdot
.898 .17335 Mdot
.898 .17421 Mdot
.898 .17465 Mdot
.898 .17469 Mdot
.898 .17504 Mdot
.898 .17568 Mdot
.898 .17582 Mdot
.898 .17629 Mdot
.898 .17717 Mdot
.898 .17724 Mdot
.898 .17782 Mdot
.898 .17841 Mdot
.898 .18049 Mdot
.898 .18053 Mdot
.898 .18129 Mdot
.898 .1819 Mdot
.898 .18325 Mdot
.898 .18377 Mdot
.898 .18468 Mdot
.898 .185 Mdot
.898 .18559 Mdot
.898 .18572 Mdot
.898 .18585 Mdot
.898 .18643 Mdot
.898 .18662 Mdot
.898 .18675 Mdot
.898 .18719 Mdot
.898 .18724 Mdot
.898 .18793 Mdot
.898 .18797 Mdot
.898 .18804 Mdot
.898 .18855 Mdot
.898 .18943 Mdot
.898 .18949 Mdot
.898 .19059 Mdot
.898 .1908 Mdot
.898 .19138 Mdot
.898 .19211 Mdot
.898 .19218 Mdot
.898 .19313 Mdot
.898 .19349 Mdot
.898 .19393 Mdot
.898 .1944 Mdot
.898 .19448 Mdot
.898 .19482 Mdot
.898 .19578 Mdot
.898 .19718 Mdot
.898 .19807 Mdot
.898 .19832 Mdot
.898 .19905 Mdot
.898 .20025 Mdot
.898 .20041 Mdot
.898 .2012 Mdot
.898 .2017 Mdot
.898 .20193 Mdot
.898 .20251 Mdot
.898 .20303 Mdot
.898 .20313 Mdot
.898 .20352 Mdot
.898 .20428 Mdot
.898 .20442 Mdot
.898 .20464 Mdot
.898 .20475 Mdot
.898 .20498 Mdot
.898 .20531 Mdot
.898 .20535 Mdot
.898 .20564 Mdot
.898 .20618 Mdot
.898 .20724 Mdot
.898 .20797 Mdot
.898 .20853 Mdot
.898 .20869 Mdot
.898 .20899 Mdot
.898 .20904 Mdot
.898 .20925 Mdot
.898 .20952 Mdot
.898 .2106 Mdot
.898 .21104 Mdot
.898 .21154 Mdot
.898 .21163 Mdot
.898 .21187 Mdot
.898 .21215 Mdot
.898 .21225 Mdot
.898 .21293 Mdot
.898 .21455 Mdot
.898 .2146 Mdot
.898 .2147 Mdot
.898 .21497 Mdot
.898 .21525 Mdot
.898 .21668 Mdot
.898 .21707 Mdot
.898 .21825 Mdot
.898 .2183 Mdot
.898 .2185 Mdot
.898 .21857 Mdot
.898 .21867 Mdot
.898 .21893 Mdot
.898 .21904 Mdot
.898 .21929 Mdot
.898 .21935 Mdot
.898 .21952 Mdot
.898 .21969 Mdot
.898 .22015 Mdot
.898 .22092 Mdot
.898 .22093 Mdot
.898 .22108 Mdot
.898 .22272 Mdot
.898 .22325 Mdot
.898 .22397 Mdot
.898 .2242 Mdot
.898 .22487 Mdot
.898 .22495 Mdot
.898 .22505 Mdot
.898 .22529 Mdot
.898 .22582 Mdot
.898 .22642 Mdot
.898 .22697 Mdot
.898 .22853 Mdot
.898 .2288 Mdot
.898 .22894 Mdot
.898 .22973 Mdot
.898 .22991 Mdot
.898 .2301 Mdot
.898 .23099 Mdot
.898 .23118 Mdot
.898 .23214 Mdot
.898 .23282 Mdot
.898 .23283 Mdot
.898 .23308 Mdot
.898 .23324 Mdot
.898 .23387 Mdot
.898 .23394 Mdot
.898 .23412 Mdot
.898 .23436 Mdot
.898 .23592 Mdot
.898 .23739 Mdot
.898 .23757 Mdot
.898 .23903 Mdot
.898 .23926 Mdot
.898 .23959 Mdot
.898 .24008 Mdot
.898 .24037 Mdot
.898 .24039 Mdot
.898 .24059 Mdot
.898 .2413 Mdot
.898 .24143 Mdot
.898 .24152 Mdot
.898 .24196 Mdot
.898 .24208 Mdot
.898 .24245 Mdot
.898 .24252 Mdot
.898 .24277 Mdot
.898 .244 Mdot
.898 .24422 Mdot
.898 .24456 Mdot
.898 .24463 Mdot
.898 .24479 Mdot
.898 .24601 Mdot
.898 .24606 Mdot
.898 .24612 Mdot
.898 .24646 Mdot
.898 .24731 Mdot
.898 .24744 Mdot
.898 .24844 Mdot
.898 .24931 Mdot
.898 .24959 Mdot
.898 .24963 Mdot
.898 .24995 Mdot
.898 .25005 Mdot
.898 .2505 Mdot
.898 .25107 Mdot
.898 .25208 Mdot
.898 .25217 Mdot
.898 .25231 Mdot
.898 .25245 Mdot
.898 .25293 Mdot
.898 .25296 Mdot
.898 .2532 Mdot
.898 .25321 Mdot
.898 .25406 Mdot
.898 .25442 Mdot
.898 .25477 Mdot
.898 .25553 Mdot
.898 .25561 Mdot
.898 .25566 Mdot
.898 .2557 Mdot
.898 .25591 Mdot
.898 .25648 Mdot
.898 .25687 Mdot
.898 .25801 Mdot
.898 .25864 Mdot
.898 .26044 Mdot
.898 .26071 Mdot
.898 .26088 Mdot
.898 .26101 Mdot
.898 .26111 Mdot
.898 .26168 Mdot
.898 .26203 Mdot
.898 .26212 Mdot
.898 .26324 Mdot
.898 .26351 Mdot
.898 .2639 Mdot
.898 .26458 Mdot
.898 .26476 Mdot
.898 .26596 Mdot
.898 .26617 Mdot
.898 .26844 Mdot
.898 .26902 Mdot
.898 .27048 Mdot
.898 .27203 Mdot
.898 .27217 Mdot
.898 .27276 Mdot
.898 .27323 Mdot
.898 .27417 Mdot
.898 .27457 Mdot
.898 .27476 Mdot
.898 .27562 Mdot
.898 .2763 Mdot
.898 .27716 Mdot
.898 .27771 Mdot
.898 .27786 Mdot
.898 .27791 Mdot
.898 .27812 Mdot
.898 .27844 Mdot
.898 .27846 Mdot
.898 .2789 Mdot
.898 .27897 Mdot
.898 .27906 Mdot
.898 .27933 Mdot
.898 .27942 Mdot
.898 .27946 Mdot
.898 .27947 Mdot
.898 .28028 Mdot
.898 .28088 Mdot
.898 .28095 Mdot
.898 .28121 Mdot
.898 .28139 Mdot
.898 .28141 Mdot
.898 .28157 Mdot
.898 .28172 Mdot
.898 .28191 Mdot
.898 .28276 Mdot
.898 .28392 Mdot
.898 .28478 Mdot
.898 .28482 Mdot
.898 .28526 Mdot
.898 .28531 Mdot
.898 .28619 Mdot
.898 .28721 Mdot
.898 .28744 Mdot
.898 .28746 Mdot
.898 .28816 Mdot
.898 .28829 Mdot
.898 .28964 Mdot
.898 .29023 Mdot
.898 .29061 Mdot
.898 .29068 Mdot
.898 .29136 Mdot
.898 .29242 Mdot
.898 .29362 Mdot
.898 .29385 Mdot
.898 .29409 Mdot
.898 .29478 Mdot
.898 .29601 Mdot
.898 .29645 Mdot
.898 .29678 Mdot
.898 .2973 Mdot
.898 .29754 Mdot
.898 .29809 Mdot
.898 .29817 Mdot
.898 .29826 Mdot
.898 .29862 Mdot
.898 .29963 Mdot
.898 .30117 Mdot
.898 .30195 Mdot
.898 .30203 Mdot
.898 .3021 Mdot
.898 .30266 Mdot
.898 .3038 Mdot
.898 .30397 Mdot
.898 .30406 Mdot
.898 .3049 Mdot
.898 .30648 Mdot
.898 .30661 Mdot
.898 .30765 Mdot
.898 .30866 Mdot
.898 .30871 Mdot
.898 .31244 Mdot
.898 .31252 Mdot
.898 .31368 Mdot
.898 .31388 Mdot
.898 .31412 Mdot
.898 .31499 Mdot
.898 .31602 Mdot
.898 .31741 Mdot
.898 .31753 Mdot
.898 .31834 Mdot
.898 .31996 Mdot
.898 .32055 Mdot
.898 .32058 Mdot
.898 .32161 Mdot
.898 .32184 Mdot
.898 .32186 Mdot
.898 .32207 Mdot
.898 .32248 Mdot
.898 .32312 Mdot
.898 .32345 Mdot
.898 .3237 Mdot
.898 .32448 Mdot
.898 .32456 Mdot
.898 .32526 Mdot
.898 .32581 Mdot
.898 .32588 Mdot
.898 .32601 Mdot
.898 .32692 Mdot
.898 .32745 Mdot
.898 .3285 Mdot
.898 .32862 Mdot
.898 .33021 Mdot
.898 .33059 Mdot
.898 .33097 Mdot
.898 .33198 Mdot
.898 .33201 Mdot
.898 .33249 Mdot
.898 .33263 Mdot
.898 .33332 Mdot
.898 .33332 Mdot
.898 .33343 Mdot
.898 .33435 Mdot
.898 .33441 Mdot
.898 .33514 Mdot
.898 .3358 Mdot
.898 .33584 Mdot
.898 .33604 Mdot
.898 .33635 Mdot
.898 .33659 Mdot
.898 .3372 Mdot
.898 .33743 Mdot
.898 .33751 Mdot
.898 .33758 Mdot
.898 .33763 Mdot
.898 .33768 Mdot
.898 .33818 Mdot
.898 .33991 Mdot
.898 .3403 Mdot
.898 .34222 Mdot
.898 .34242 Mdot
.898 .34245 Mdot
.898 .3433 Mdot
.898 .34388 Mdot
.898 .34393 Mdot
.898 .34402 Mdot
.898 .34443 Mdot
.898 .34448 Mdot
.898 .34492 Mdot
.898 .34554 Mdot
.898 .34567 Mdot
.898 .34578 Mdot
.898 .34793 Mdot
.898 .34823 Mdot
.898 .34827 Mdot
.898 .34964 Mdot
.898 .35055 Mdot
.898 .35095 Mdot
.898 .35199 Mdot
.898 .35203 Mdot
.898 .35293 Mdot
.898 .3531 Mdot
.898 .3538 Mdot
.898 .35481 Mdot
.898 .35494 Mdot
.898 .35518 Mdot
.898 .35543 Mdot
.898 .35583 Mdot
.898 .35601 Mdot
.898 .35635 Mdot
.898 .35643 Mdot
.898 .35652 Mdot
.898 .35702 Mdot
.898 .3571 Mdot
.898 .35762 Mdot
.898 .35858 Mdot
.898 .35934 Mdot
.898 .36049 Mdot
.898 .3618 Mdot
.898 .36265 Mdot
.898 .36281 Mdot
.898 .36309 Mdot
.898 .36337 Mdot
.898 .36345 Mdot
.898 .36363 Mdot
.898 .36373 Mdot
.898 .36411 Mdot
.898 .36458 Mdot
.898 .36571 Mdot
.898 .36613 Mdot
.898 .36653 Mdot
.898 .36732 Mdot
.898 .36821 Mdot
.898 .36837 Mdot
.898 .36881 Mdot
.898 .36931 Mdot
.898 .3695 Mdot
.898 .37048 Mdot
.898 .37071 Mdot
.898 .37236 Mdot
.898 .3736 Mdot
.898 .37363 Mdot
.898 .37371 Mdot
.898 .37384 Mdot
.898 .37389 Mdot
.898 .37437 Mdot
.898 .37488 Mdot
.898 .37603 Mdot
.898 .37745 Mdot
.898 .37814 Mdot
.898 .37943 Mdot
.898 .38026 Mdot
.898 .38035 Mdot
.898 .38071 Mdot
.898 .38085 Mdot
.898 .38102 Mdot
.898 .38148 Mdot
.898 .38167 Mdot
.898 .38214 Mdot
.898 .38224 Mdot
.898 .38255 Mdot
.898 .38285 Mdot
.898 .38332 Mdot
.898 .38367 Mdot
.898 .38405 Mdot
.898 .38482 Mdot
.898 .38505 Mdot
.898 .38508 Mdot
.898 .38535 Mdot
.898 .38707 Mdot
.898 .38829 Mdot
.898 .38924 Mdot
.898 .39054 Mdot
.898 .39096 Mdot
.898 .39102 Mdot
.898 .39216 Mdot
.898 .3923 Mdot
.898 .39243 Mdot
.898 .39248 Mdot
.898 .39291 Mdot
.898 .39349 Mdot
.898 .39386 Mdot
.898 .39495 Mdot
.898 .39517 Mdot
.898 .39593 Mdot
.898 .39595 Mdot
.898 .39774 Mdot
.898 .398 Mdot
.898 .39827 Mdot
.898 .39872 Mdot
.898 .3992 Mdot
.898 .39944 Mdot
.898 .39947 Mdot
.898 .40089 Mdot
.898 .40121 Mdot
.898 .40154 Mdot
.898 .4027 Mdot
.898 .40314 Mdot
.898 .40349 Mdot
.898 .40521 Mdot
.898 .40643 Mdot
.898 .40645 Mdot
.898 .4069 Mdot
.898 .40718 Mdot
.898 .40767 Mdot
.898 .40832 Mdot
.898 .40844 Mdot
.898 .40876 Mdot
.898 .4092 Mdot
.898 .41018 Mdot
.898 .41044 Mdot
.898 .41068 Mdot
.898 .41199 Mdot
.898 .41249 Mdot
.898 .41463 Mdot
.898 .41496 Mdot
.898 .41615 Mdot
.898 .4167 Mdot
.898 .417 Mdot
.898 .41759 Mdot
.898 .418 Mdot
.898 .4186 Mdot
.898 .41947 Mdot
.898 .41971 Mdot
.898 .41999 Mdot
.898 .42003 Mdot
.898 .42038 Mdot
.898 .42167 Mdot
.898 .4219 Mdot
.898 .42205 Mdot
.898 .42285 Mdot
.898 .42307 Mdot
.898 .42372 Mdot
.898 .42386 Mdot
.898 .4243 Mdot
.898 .42478 Mdot
.898 .42522 Mdot
.898 .4265 Mdot
.898 .42691 Mdot
.898 .42751 Mdot
.898 .42764 Mdot
.898 .42794 Mdot
.898 .42858 Mdot
.898 .43012 Mdot
.898 .43022 Mdot
.898 .43032 Mdot
.898 .43092 Mdot
.898 .43183 Mdot
.898 .43198 Mdot
.898 .43246 Mdot
.898 .4327 Mdot
.898 .43448 Mdot
.898 .43605 Mdot
.898 .43656 Mdot
.898 .43663 Mdot
.898 .4372 Mdot
.898 .43738 Mdot
.898 .43818 Mdot
.898 .43921 Mdot
.898 .44102 Mdot
.898 .44118 Mdot
.898 .44143 Mdot
.898 .44168 Mdot
.898 .44256 Mdot
.898 .44261 Mdot
.898 .44304 Mdot
.898 .44305 Mdot
.898 .44458 Mdot
.898 .44522 Mdot
.898 .44586 Mdot
.898 .44722 Mdot
.898 .44736 Mdot
.898 .44746 Mdot
.898 .44753 Mdot
.898 .4479 Mdot
.898 .44892 Mdot
.898 .44962 Mdot
.898 .45167 Mdot
.898 .4528 Mdot
.898 .45605 Mdot
.898 .45652 Mdot
.898 .45683 Mdot
.898 .45706 Mdot
.898 .45724 Mdot
.898 .45826 Mdot
.898 .45889 Mdot
.898 .45906 Mdot
.898 .46106 Mdot
.898 .46155 Mdot
.898 .46226 Mdot
.898 .46347 Mdot
.898 .4638 Mdot
.898 .46595 Mdot
.898 .46634 Mdot
.898 .47041 Mdot
.898 .47145 Mdot
.898 .47406 Mdot
.898 .47686 Mdot
.898 .4771 Mdot
.898 .47816 Mdot
.898 .479 Mdot
.898 .4807 Mdot
.898 .48141 Mdot
.898 .48176 Mdot
.898 .4833 Mdot
.898 .48452 Mdot
.898 .48606 Mdot
.898 .48705 Mdot
.898 .48733 Mdot
.898 .48741 Mdot
.898 .48779 Mdot
.898 .48836 Mdot
.898 .4884 Mdot
.898 .4892 Mdot
.898 .48931 Mdot
.898 .48948 Mdot
.898 .48995 Mdot
.898 .49012 Mdot
.898 .49019 Mdot
.898 .49022 Mdot
.898 .49168 Mdot
.898 .49275 Mdot
.898 .49288 Mdot
.898 .49335 Mdot
.898 .49367 Mdot
.898 .4937 Mdot
.898 .49398 Mdot
.898 .49425 Mdot
.898 .4946 Mdot
.898 .49467 Mdot
.898 .49612 Mdot
.898 .49821 Mdot
.898 .49976 Mdot
.898 .49983 Mdot
.898 .50062 Mdot
.898 .50071 Mdot
.898 .50228 Mdot
.898 .50412 Mdot
.898 .50453 Mdot
.898 .50457 Mdot
.898 .50583 Mdot
.898 .50606 Mdot
.898 .50848 Mdot
.898 .50953 Mdot
.898 .51022 Mdot
.898 .51035 Mdot
.898 .51157 Mdot
.898 .51347 Mdot
.898 .51563 Mdot
.898 .51604 Mdot
.898 .51647 Mdot
.898 .51772 Mdot
.898 .51992 Mdot
.898 .52071 Mdot
.898 .5213 Mdot
.898 .52223 Mdot
.898 .52267 Mdot
.898 .52366 Mdot
.898 .52381 Mdot
.898 .52396 Mdot
.898 .52461 Mdot
.898 .52642 Mdot
.898 .52919 Mdot
.898 .53059 Mdot
.898 .53074 Mdot
.898 .53086 Mdot
.898 .53187 Mdot
.898 .53391 Mdot
.898 .53422 Mdot
.898 .53439 Mdot
.898 .53589 Mdot
.898 .53872 Mdot
.898 .53896 Mdot
.898 .54083 Mdot
.898 .54265 Mdot
.898 .54273 Mdot
.9 .01505 Mdot
.9 .01516 Mdot
.9 .01531 Mdot
.9 .01552 Mdot
.9 .01579 Mdot
.9 .01617 Mdot
.9 .01647 Mdot
.9 .01666 Mdot
.9 .01712 Mdot
.9 .01733 Mdot
.9 .01787 Mdot
.9 .01821 Mdot
.9 .01882 Mdot
.9 .01905 Mdot
.9 .01943 Mdot
.9 .01986 Mdot
.9 .0204 Mdot
.9 .02101 Mdot
.9 .0221 Mdot
.9 .02238 Mdot
.9 .02252 Mdot
.9 .0232 Mdot
.9 .02398 Mdot
.9 .02481 Mdot
.9 .02494 Mdot
.9 .02605 Mdot
.9 .02624 Mdot
.9 .02723 Mdot
.9 .02801 Mdot
.9 .0285 Mdot
.9 .02876 Mdot
.9 .02925 Mdot
.9 .02999 Mdot
.9 .03036 Mdot
.9 .03038 Mdot
.9 .0314 Mdot
.9 .03189 Mdot
.9 .03242 Mdot
.9 .03289 Mdot
.9 .03312 Mdot
.9 .03388 Mdot
.9 .0343 Mdot
.9 .03484 Mdot
.9 .03509 Mdot
.9 .03512 Mdot
.9 .03519 Mdot
.9 .03547 Mdot
.9 .03578 Mdot
.9 .03628 Mdot
.9 .03723 Mdot
.9 .03832 Mdot
.9 .03864 Mdot
.9 .03871 Mdot
.9 .03953 Mdot
.9 .03999 Mdot
.9 .04088 Mdot
.9 .04222 Mdot
.9 .04281 Mdot
.9 .04287 Mdot
.9 .04291 Mdot
.9 .04329 Mdot
.9 .04354 Mdot
.9 .04395 Mdot
.9 .044 Mdot
.9 .04474 Mdot
.9 .04483 Mdot
.9 .045 Mdot
.9 .04502 Mdot
.9 .04562 Mdot
.9 .04611 Mdot
.9 .04659 Mdot
.9 .04743 Mdot
.9 .04784 Mdot
.9 .04921 Mdot
.9 .04937 Mdot
.9 .04991 Mdot
.9 .04994 Mdot
.9 .04998 Mdot
.9 .05095 Mdot
.9 .05139 Mdot
.9 .05144 Mdot
.9 .05156 Mdot
.9 .0516 Mdot
.9 .05207 Mdot
.9 .05264 Mdot
.9 .05354 Mdot
.9 .0542 Mdot
.9 .05476 Mdot
.9 .05501 Mdot
.9 .05504 Mdot
.9 .05519 Mdot
.9 .05525 Mdot
.9 .05578 Mdot
.9 .0572 Mdot
.9 .05727 Mdot
.9 .05778 Mdot
.9 .05791 Mdot
.9 .05848 Mdot
.9 .0586 Mdot
.9 .05939 Mdot
.9 .05969 Mdot
.9 .06022 Mdot
.9 .06118 Mdot
.9 .06181 Mdot
.9 .06187 Mdot
.9 .06422 Mdot
.9 .06528 Mdot
.9 .0654 Mdot
.9 .06546 Mdot
.9 .06614 Mdot
.9 .06651 Mdot
.9 .06661 Mdot
.9 .06733 Mdot
.9 .06742 Mdot
.9 .0677 Mdot
.9 .06814 Mdot
.9 .06877 Mdot
.9 .06893 Mdot
.9 .06923 Mdot
.9 .06926 Mdot
.9 .07035 Mdot
.9 .07123 Mdot
.9 .07208 Mdot
.9 .07214 Mdot
.9 .07359 Mdot
.9 .07435 Mdot
.9 .07487 Mdot
.9 .07565 Mdot
.9 .07579 Mdot
.9 .07663 Mdot
.9 .07681 Mdot
.9 .07709 Mdot
.9 .07806 Mdot
.9 .07812 Mdot
.9 .07813 Mdot
.9 .07818 Mdot
.9 .07949 Mdot
.9 .07991 Mdot
.9 .07994 Mdot
.9 .08043 Mdot
.9 .08073 Mdot
.9 .08077 Mdot
.9 .08082 Mdot
.9 .08099 Mdot
.9 .08104 Mdot
.9 .08111 Mdot
.9 .08163 Mdot
.9 .08176 Mdot
.9 .08195 Mdot
.9 .08235 Mdot
.9 .08298 Mdot
.9 .0846 Mdot
.9 .08473 Mdot
.9 .08534 Mdot
.9 .08579 Mdot
.9 .08679 Mdot
.9 .08725 Mdot
.9 .0873 Mdot
.9 .08757 Mdot
.9 .08768 Mdot
.9 .08863 Mdot
.9 .08974 Mdot
.9 .09025 Mdot
.9 .09098 Mdot
.9 .09119 Mdot
.9 .09131 Mdot
.9 .09223 Mdot
.9 .09247 Mdot
.9 .0935 Mdot
.9 .09371 Mdot
.9 .09466 Mdot
.9 .09513 Mdot
.9 .09567 Mdot
.9 .09571 Mdot
.9 .09641 Mdot
.9 .09662 Mdot
.9 .0981 Mdot
.9 .09836 Mdot
.9 .0991 Mdot
.9 .09948 Mdot
.9 .09959 Mdot
.9 .09973 Mdot
.9 .10009 Mdot
.9 .10024 Mdot
.9 .10057 Mdot
.9 .10275 Mdot
.9 .10277 Mdot
.9 .10382 Mdot
.9 .10492 Mdot
.9 .1051 Mdot
.9 .10573 Mdot
.9 .10595 Mdot
.9 .10603 Mdot
.9 .10605 Mdot
.9 .10729 Mdot
.9 .10795 Mdot
.9 .10812 Mdot
.9 .10847 Mdot
.9 .10892 Mdot
.9 .10901 Mdot
.9 .10933 Mdot
.9 .10943 Mdot
.9 .10959 Mdot
.9 .10967 Mdot
.9 .11009 Mdot
.9 .11087 Mdot
.9 .11201 Mdot
.9 .1123 Mdot
.9 .11284 Mdot
.9 .11289 Mdot
.9 .11291 Mdot
.9 .11327 Mdot
.9 .11394 Mdot
.9 .11486 Mdot
.9 .11645 Mdot
.9 .11659 Mdot
.9 .1173 Mdot
.9 .11745 Mdot
.9 .11747 Mdot
.9 .11757 Mdot
.9 .11798 Mdot
.9 .11808 Mdot
.9 .11905 Mdot
.9 .11986 Mdot
.9 .12044 Mdot
.9 .12055 Mdot
.9 .1207 Mdot
.9 .12147 Mdot
.9 .12205 Mdot
.9 .12214 Mdot
.9 .12299 Mdot
.9 .12359 Mdot
.9 .12359 Mdot
.9 .12412 Mdot
.9 .1244 Mdot
.9 .12464 Mdot
.9 .12464 Mdot
.9 .12613 Mdot
.9 .12617 Mdot
.9 .12649 Mdot
.9 .127 Mdot
.9 .12721 Mdot
.9 .12833 Mdot
.9 .12874 Mdot
.9 .12884 Mdot
.9 .12885 Mdot
.9 .12896 Mdot
.9 .13083 Mdot
.9 .13131 Mdot
.9 .13185 Mdot
.9 .13206 Mdot
.9 .13211 Mdot
.9 .13227 Mdot
.9 .1325 Mdot
.9 .13299 Mdot
.9 .13355 Mdot
.9 .13362 Mdot
.9 .1337 Mdot
.9 .13401 Mdot
.9 .13408 Mdot
.9 .1341 Mdot
.9 .13423 Mdot
.9 .13436 Mdot
.9 .13497 Mdot
.9 .13516 Mdot
.9 .13539 Mdot
.9 .13567 Mdot
.9 .13574 Mdot
.9 .13646 Mdot
.9 .13652 Mdot
.9 .13732 Mdot
.9 .1375 Mdot
.9 .13759 Mdot
.9 .13765 Mdot
.9 .13855 Mdot
.9 .13953 Mdot
.9 .14051 Mdot
.9 .14059 Mdot
.9 .14075 Mdot
.9 .14183 Mdot
.9 .14242 Mdot
.9 .14264 Mdot
.9 .14317 Mdot
.9 .14444 Mdot
.9 .14511 Mdot
.9 .14527 Mdot
.9 .14536 Mdot
.9 .14585 Mdot
.9 .14605 Mdot
.9 .14678 Mdot
.9 .14746 Mdot
.9 .14764 Mdot
.9 .14776 Mdot
.9 .14804 Mdot
.9 .14815 Mdot
.9 .14839 Mdot
.9 .14876 Mdot
.9 .14975 Mdot
.9 .15025 Mdot
.9 .15068 Mdot
.9 .152 Mdot
.9 .15238 Mdot
.9 .15258 Mdot
.9 .1529 Mdot
.9 .15385 Mdot
.9 .15413 Mdot
.9 .15424 Mdot
.9 .15467 Mdot
.9 .15652 Mdot
.9 .1569 Mdot
.9 .15862 Mdot
.9 .15946 Mdot
.9 .15967 Mdot
.9 .15998 Mdot
.9 .16003 Mdot
.9 .16044 Mdot
.9 .16051 Mdot
.9 .16176 Mdot
.9 .16214 Mdot
.9 .1624 Mdot
.9 .16248 Mdot
.9 .16284 Mdot
.9 .16387 Mdot
.9 .16446 Mdot
.9 .16481 Mdot
.9 .16482 Mdot
.9 .16527 Mdot
.9 .16565 Mdot
.9 .16603 Mdot
.9 .16661 Mdot
.9 .16684 Mdot
.9 .16715 Mdot
.9 .16729 Mdot
.9 .16739 Mdot
.9 .1675 Mdot
.9 .16774 Mdot
.9 .16804 Mdot
.9 .16839 Mdot
.9 .16867 Mdot
.9 .16884 Mdot
.9 .16926 Mdot
.9 .16934 Mdot
.9 .16941 Mdot
.9 .17122 Mdot
.9 .17229 Mdot
.9 .17318 Mdot
.9 .17321 Mdot
.9 .17491 Mdot
.9 .17501 Mdot
.9 .1751 Mdot
.9 .17535 Mdot
.9 .17554 Mdot
.9 .17593 Mdot
.9 .17641 Mdot
.9 .17659 Mdot
.9 .17674 Mdot
.9 .17709 Mdot
.9 .17741 Mdot
.9 .17758 Mdot
.9 .17822 Mdot
.9 .17855 Mdot
.9 .17861 Mdot
.9 .17863 Mdot
.9 .17877 Mdot
.9 .17893 Mdot
.9 .17909 Mdot
.9 .17912 Mdot
.9 .17952 Mdot
.9 .18025 Mdot
.9 .18057 Mdot
.9 .18135 Mdot
.9 .18254 Mdot
.9 .18284 Mdot
.9 .18347 Mdot
.9 .18381 Mdot
.9 .18428 Mdot
.9 .18445 Mdot
.9 .1849 Mdot
.9 .18503 Mdot
.9 .1852 Mdot
.9 .18527 Mdot
.9 .18549 Mdot
.9 .18564 Mdot
.9 .18627 Mdot
.9 .18639 Mdot
.9 .18765 Mdot
.9 .1878 Mdot
.9 .18788 Mdot
.9 .188 Mdot
.9 .18828 Mdot
.9 .18833 Mdot
.9 .18984 Mdot
.9 .19037 Mdot
.9 .19134 Mdot
.9 .19143 Mdot
.9 .19147 Mdot
.9 .19212 Mdot
.9 .19249 Mdot
.9 .19253 Mdot
.9 .19286 Mdot
.9 .19332 Mdot
.9 .19354 Mdot
.9 .19497 Mdot
.9 .19783 Mdot
.9 .19809 Mdot
.9 .19855 Mdot
.9 .1991 Mdot
.9 .19926 Mdot
.9 .19937 Mdot
.9 .19944 Mdot
.9 .19963 Mdot
.9 .19967 Mdot
.9 .19986 Mdot
.9 .20059 Mdot
.9 .20078 Mdot
.9 .20252 Mdot
.9 .20398 Mdot
.9 .20472 Mdot
.9 .20503 Mdot
.9 .20522 Mdot
.9 .20548 Mdot
.9 .20615 Mdot
.9 .20688 Mdot
.9 .20717 Mdot
.9 .20792 Mdot
.9 .20809 Mdot
.9 .20819 Mdot
.9 .2094 Mdot
.9 .20961 Mdot
.9 .21043 Mdot
.9 .21064 Mdot
.9 .21069 Mdot
.9 .2107 Mdot
.9 .21073 Mdot
.9 .21144 Mdot
.9 .21165 Mdot
.9 .21214 Mdot
.9 .21259 Mdot
.9 .21259 Mdot
.9 .21275 Mdot
.9 .21514 Mdot
.9 .21526 Mdot
.9 .21534 Mdot
.9 .21591 Mdot
.9 .2161 Mdot
.9 .21658 Mdot
.9 .21682 Mdot
.9 .21688 Mdot
.9 .2172 Mdot
.9 .21751 Mdot
.9 .21863 Mdot
.9 .21923 Mdot
.9 .21995 Mdot
.9 .22013 Mdot
.9 .22016 Mdot
.9 .22035 Mdot
.9 .22193 Mdot
.9 .22201 Mdot
.9 .22372 Mdot
.9 .22382 Mdot
.9 .22383 Mdot
.9 .22459 Mdot
.9 .2247 Mdot
.9 .22502 Mdot
.9 .22531 Mdot
.9 .22557 Mdot
.9 .22594 Mdot
.9 .22603 Mdot
.9 .22631 Mdot
.9 .22655 Mdot
.9 .22671 Mdot
.9 .22673 Mdot
.9 .22729 Mdot
.9 .22762 Mdot
.9 .22846 Mdot
.9 .22856 Mdot
.9 .22862 Mdot
.9 .22874 Mdot
.9 .22889 Mdot
.9 .22894 Mdot
.9 .22899 Mdot
.9 .22925 Mdot
.9 .22945 Mdot
.9 .22957 Mdot
.9 .22962 Mdot
.9 .22985 Mdot
.9 .23007 Mdot
.9 .23117 Mdot
.9 .23151 Mdot
.9 .23162 Mdot
.9 .23193 Mdot
.9 .23236 Mdot
.9 .23243 Mdot
.9 .23255 Mdot
.9 .23385 Mdot
.9 .23386 Mdot
.9 .23397 Mdot
.9 .23417 Mdot
.9 .2354 Mdot
.9 .23572 Mdot
.9 .23589 Mdot
.9 .23594 Mdot
.9 .236 Mdot
.9 .23763 Mdot
.9 .23907 Mdot
.9 .23939 Mdot
.9 .23945 Mdot
.9 .2397 Mdot
.9 .24084 Mdot
.9 .24114 Mdot
.9 .24129 Mdot
.9 .24157 Mdot
.9 .24192 Mdot
.9 .24296 Mdot
.9 .24352 Mdot
.9 .24379 Mdot
.9 .24389 Mdot
.9 .24436 Mdot
.9 .24441 Mdot
.9 .24459 Mdot
.9 .24495 Mdot
.9 .24498 Mdot
.9 .2451 Mdot
.9 .2452 Mdot
.9 .24593 Mdot
.9 .24662 Mdot
.9 .24726 Mdot
.9 .24823 Mdot
.9 .24835 Mdot
.9 .24842 Mdot
.9 .24943 Mdot
.9 .24972 Mdot
.9 .24988 Mdot
.9 .25076 Mdot
.9 .25111 Mdot
.9 .25244 Mdot
.9 .25271 Mdot
.9 .2536 Mdot
.9 .25365 Mdot
.9 .25399 Mdot
.9 .25419 Mdot
.9 .25469 Mdot
.9 .25489 Mdot
.9 .25533 Mdot
.9 .256 Mdot
.9 .25647 Mdot
.9 .25664 Mdot
.9 .25773 Mdot
.9 .25779 Mdot
.9 .25838 Mdot
.9 .25868 Mdot
.9 .25945 Mdot
.9 .26002 Mdot
.9 .26065 Mdot
.9 .26182 Mdot
.9 .26208 Mdot
.9 .26251 Mdot
.9 .26287 Mdot
.9 .26344 Mdot
.9 .26425 Mdot
.9 .26516 Mdot
.9 .26566 Mdot
.9 .26577 Mdot
.9 .26586 Mdot
.9 .26633 Mdot
.9 .26663 Mdot
.9 .26987 Mdot
.9 .26997 Mdot
.9 .27004 Mdot
.9 .27065 Mdot
.9 .27197 Mdot
.9 .27293 Mdot
.9 .27375 Mdot
.9 .27526 Mdot
.9 .27544 Mdot
.9 .27563 Mdot
.9 .27618 Mdot
.9 .27628 Mdot
.9 .27701 Mdot
.9 .27715 Mdot
.9 .27728 Mdot
.9 .27933 Mdot
.9 .2794 Mdot
.9 .28009 Mdot
.9 .28056 Mdot
.9 .28069 Mdot
.9 .28135 Mdot
.9 .28311 Mdot
.9 .28319 Mdot
.9 .28395 Mdot
.9 .28425 Mdot
.9 .28488 Mdot
.9 .28491 Mdot
.9 .28534 Mdot
.9 .28571 Mdot
.9 .28639 Mdot
.9 .28652 Mdot
.9 .28708 Mdot
.9 .28813 Mdot
.9 .28837 Mdot
.9 .28855 Mdot
.9 .28909 Mdot
.9 .28935 Mdot
.9 .28953 Mdot
.9 .28972 Mdot
.9 .29015 Mdot
.9 .29071 Mdot
.9 .29098 Mdot
.9 .29132 Mdot
.9 .29182 Mdot
.9 .29214 Mdot
.9 .29289 Mdot
.9 .29304 Mdot
.9 .29316 Mdot
.9 .29394 Mdot
.9 .29557 Mdot
.9 .29592 Mdot
.9 .29619 Mdot
.9 .29642 Mdot
.9 .29771 Mdot
.9 .29835 Mdot
.9 .29868 Mdot
.9 .29996 Mdot
.9 .30001 Mdot
.9 .30307 Mdot
.9 .30324 Mdot
.9 .30342 Mdot
.9 .30385 Mdot
.9 .3042 Mdot
.9 .30491 Mdot
.9 .30577 Mdot
.9 .3061 Mdot
.9 .30635 Mdot
.9 .30698 Mdot
.9 .30756 Mdot
.9 .30787 Mdot
.9 .30902 Mdot
.9 .3092 Mdot
.9 .30952 Mdot
.9 .30962 Mdot
.9 .30972 Mdot
.9 .30975 Mdot
.9 .30976 Mdot
.9 .31001 Mdot
.9 .3103 Mdot
.9 .31058 Mdot
.9 .31065 Mdot
.9 .31137 Mdot
.9 .31173 Mdot
.9 .31268 Mdot
.9 .31326 Mdot
.9 .31465 Mdot
.9 .316 Mdot
.9 .3168 Mdot
.9 .31735 Mdot
.9 .31847 Mdot
.9 .31909 Mdot
.9 .3191 Mdot
.9 .31994 Mdot
.9 .32023 Mdot
.9 .32104 Mdot
.9 .32128 Mdot
.9 .32158 Mdot
.9 .32172 Mdot
.9 .32177 Mdot
.9 .3221 Mdot
.9 .32238 Mdot
.9 .32351 Mdot
.9 .32373 Mdot
.9 .326 Mdot
.9 .32627 Mdot
.9 .32641 Mdot
.9 .32664 Mdot
.9 .32666 Mdot
.9 .32713 Mdot
.9 .32722 Mdot
.9 .32723 Mdot
.9 .32784 Mdot
.9 .32965 Mdot
.9 .32995 Mdot
.9 .32996 Mdot
.9 .33089 Mdot
.9 .33233 Mdot
.9 .33264 Mdot
.9 .33278 Mdot
.9 .3328 Mdot
.9 .33288 Mdot
.9 .33321 Mdot
.9 .33404 Mdot
.9 .33471 Mdot
.9 .33478 Mdot
.9 .33538 Mdot
.9 .33621 Mdot
.9 .33659 Mdot
.9 .33917 Mdot
.9 .33983 Mdot
.9 .34007 Mdot
.9 .3423 Mdot
.9 .34381 Mdot
.9 .34425 Mdot
.9 .34432 Mdot
.9 .3448 Mdot
.9 .34562 Mdot
.9 .34638 Mdot
.9 .34661 Mdot
.9 .3469 Mdot
.9 .34709 Mdot
.9 .34722 Mdot
.9 .34757 Mdot
.9 .34764 Mdot
.9 .34797 Mdot
.9 .34929 Mdot
.9 .34963 Mdot
.9 .35208 Mdot
.9 .35236 Mdot
.9 .35277 Mdot
.9 .35481 Mdot
.9 .3554 Mdot
.9 .35578 Mdot
.9 .35672 Mdot
.9 .35728 Mdot
.9 .35762 Mdot
.9 .35783 Mdot
.9 .35791 Mdot
.9 .35809 Mdot
.9 .35931 Mdot
.9 .35932 Mdot
.9 .36051 Mdot
.9 .36061 Mdot
.9 .36113 Mdot
.9 .36248 Mdot
.9 .36273 Mdot
.9 .36278 Mdot
.9 .36296 Mdot
.9 .36315 Mdot
.9 .36495 Mdot
.9 .36515 Mdot
.9 .36552 Mdot
.9 .36699 Mdot
.9 .36739 Mdot
.9 .36747 Mdot
.9 .36748 Mdot
.9 .36754 Mdot
.9 .36836 Mdot
.9 .36881 Mdot
.9 .36913 Mdot
.9 .36919 Mdot
.9 .36971 Mdot
.9 .37008 Mdot
.9 .37088 Mdot
.9 .37088 Mdot
.9 .37118 Mdot
.9 .37147 Mdot
.9 .37229 Mdot
.9 .37289 Mdot
.9 .37352 Mdot
.9 .3749 Mdot
.9 .37547 Mdot
.9 .3757 Mdot
.9 .37583 Mdot
.9 .37671 Mdot
.9 .37686 Mdot
.9 .3772 Mdot
.9 .37759 Mdot
.9 .37807 Mdot
.9 .37851 Mdot
.9 .37861 Mdot
.9 .37869 Mdot
.9 .3792 Mdot
.9 .37974 Mdot
.9 .38033 Mdot
.9 .38135 Mdot
.9 .38176 Mdot
.9 .38284 Mdot
.9 .38377 Mdot
.9 .38414 Mdot
.9 .38425 Mdot
.9 .38446 Mdot
.9 .38452 Mdot
.9 .38466 Mdot
.9 .38487 Mdot
.9 .38569 Mdot
.9 .38716 Mdot
.9 .38769 Mdot
.9 .38785 Mdot
.9 .39092 Mdot
.9 .3911 Mdot
.9 .39113 Mdot
.9 .39245 Mdot
.9 .39249 Mdot
.9 .39269 Mdot
.9 .39326 Mdot
.9 .39359 Mdot
.9 .39379 Mdot
.9 .39425 Mdot
.9 .39446 Mdot
.9 .39491 Mdot
.9 .39508 Mdot
.9 .39522 Mdot
.9 .39558 Mdot
.9 .39602 Mdot
.9 .3963 Mdot
.9 .39634 Mdot
.9 .39734 Mdot
.9 .39794 Mdot
.9 .39939 Mdot
.9 .39945 Mdot
.9 .39964 Mdot
.9 .39974 Mdot
.9 .39996 Mdot
.9 .40023 Mdot
.9 .40033 Mdot
.9 .40041 Mdot
.9 .40088 Mdot
.9 .40123 Mdot
.9 .40145 Mdot
.9 .40146 Mdot
.9 .40154 Mdot
.9 .40196 Mdot
.9 .40236 Mdot
.9 .40254 Mdot
.9 .40434 Mdot
.9 .40494 Mdot
.9 .40515 Mdot
.9 .4057 Mdot
.9 .40647 Mdot
.9 .4066 Mdot
.9 .40667 Mdot
.9 .40682 Mdot
.9 .40685 Mdot
.9 .40916 Mdot
.9 .40918 Mdot
.9 .40937 Mdot
.9 .40974 Mdot
.9 .41253 Mdot
.9 .41283 Mdot
.9 .41292 Mdot
.9 .41302 Mdot
.9 .41595 Mdot
.9 .41675 Mdot
.9 .41731 Mdot
.9 .41788 Mdot
.9 .41855 Mdot
.9 .41912 Mdot
.9 .41925 Mdot
.9 .41929 Mdot
.9 .41969 Mdot
.9 .42042 Mdot
.9 .42174 Mdot
.9 .42228 Mdot
.9 .42254 Mdot
.9 .42271 Mdot
.9 .42306 Mdot
.9 .42368 Mdot
.9 .42551 Mdot
.9 .42556 Mdot
.9 .42656 Mdot
.9 .42657 Mdot
.9 .42706 Mdot
.9 .42723 Mdot
.9 .42739 Mdot
.9 .42808 Mdot
.9 .42817 Mdot
.9 .42849 Mdot
.9 .42914 Mdot
.9 .4292 Mdot
.9 .42941 Mdot
.9 .42944 Mdot
.9 .42958 Mdot
.9 .4309 Mdot
.9 .43131 Mdot
.9 .43214 Mdot
.9 .43232 Mdot
.9 .4333 Mdot
.9 .43504 Mdot
.9 .43525 Mdot
.9 .43539 Mdot
.9 .43602 Mdot
.9 .43662 Mdot
.9 .4372 Mdot
.9 .43766 Mdot
.9 .43772 Mdot
.9 .43798 Mdot
.9 .43801 Mdot
.9 .43831 Mdot
.9 .43839 Mdot
.9 .43844 Mdot
.9 .43923 Mdot
.9 .43959 Mdot
.9 .44019 Mdot
.9 .44023 Mdot
.9 .44262 Mdot
.9 .44311 Mdot
.9 .4447 Mdot
.9 .4448 Mdot
.9 .44541 Mdot
.9 .44577 Mdot
.9 .44668 Mdot
.9 .44703 Mdot
.9 .44782 Mdot
.9 .44903 Mdot
.9 .44987 Mdot
.9 .45018 Mdot
.9 .45215 Mdot
.9 .45224 Mdot
.9 .45332 Mdot
.9 .45385 Mdot
.9 .45524 Mdot
.9 .45627 Mdot
.9 .4574 Mdot
.9 .4595 Mdot
.9 .45997 Mdot
.9 .46074 Mdot
.9 .4614 Mdot
.9 .46243 Mdot
.9 .46388 Mdot
.9 .46552 Mdot
.9 .46642 Mdot
.9 .46662 Mdot
.9 .46677 Mdot
.9 .46762 Mdot
.9 .46815 Mdot
.9 .474 Mdot
.9 .47418 Mdot
.9 .4743 Mdot
.9 .47541 Mdot
.9 .47778 Mdot
.9 .4795 Mdot
.9 .48098 Mdot
.9 .4837 Mdot
.9 .48402 Mdot
.9 .48435 Mdot
.9 .48536 Mdot
.9 .48553 Mdot
.9 .48685 Mdot
.9 .4871 Mdot
.9 .48734 Mdot
.9 .49102 Mdot
.9 .49115 Mdot
.9 .49239 Mdot
.9 .49323 Mdot
.9 .49347 Mdot
.9 .49466 Mdot
.9 .49782 Mdot
.9 .49798 Mdot
.9 .49934 Mdot
.9 .49988 Mdot
.9 .50101 Mdot
.9 .50106 Mdot
.9 .50184 Mdot
.9 .5025 Mdot
.9 .50374 Mdot
.9 .50397 Mdot
.9 .50497 Mdot
.9 .50687 Mdot
.9 .5073 Mdot
.9 .50761 Mdot
.9 .50859 Mdot
.9 .50905 Mdot
.9 .50938 Mdot
.9 .50973 Mdot
.9 .5105 Mdot
.9 .5115 Mdot
.9 .51199 Mdot
.9 .51261 Mdot
.9 .51351 Mdot
.9 .51408 Mdot
.9 .51543 Mdot
.9 .51569 Mdot
.9 .51592 Mdot
.9 .51731 Mdot
.9 .52025 Mdot
.9 .52088 Mdot
.9 .52137 Mdot
.9 .52179 Mdot
.9 .52411 Mdot
.9 .52525 Mdot
.9 .52585 Mdot
.9 .52815 Mdot
.9 .52825 Mdot
.9 .53375 Mdot
.9 .53406 Mdot
.9 .53438 Mdot
.9 .53516 Mdot
.9 .53579 Mdot
.9 .53706 Mdot
.9 .53862 Mdot
.9 .5392 Mdot
.9 .53966 Mdot
.9 .5408 Mdot
.9 .54184 Mdot
.9 .5424 Mdot
.9 .54446 Mdot
.9 .54479 Mdot
.9 .54537 Mdot
.9 .54554 Mdot
.9 .54572 Mdot
.9 .54577 Mdot
.9 .5458 Mdot
.9 .54624 Mdot
.9 .54677 Mdot
.902 .01486 Mdot
.902 .01498 Mdot
.902 .0152 Mdot
.902 .01558 Mdot
.902 .01628 Mdot
.902 .01719 Mdot
.902 .01753 Mdot
.902 .01778 Mdot
.902 .01897 Mdot
.902 .01913 Mdot
.902 .01918 Mdot
.902 .01926 Mdot
.902 .0194 Mdot
.902 .0198 Mdot
.902 .02025 Mdot
.902 .02101 Mdot
.902 .02224 Mdot
.902 .02239 Mdot
.902 .02268 Mdot
.902 .02277 Mdot
.902 .02292 Mdot
.902 .02316 Mdot
.902 .02333 Mdot
.902 .02389 Mdot
.902 .0247 Mdot
.902 .02477 Mdot
.902 .02607 Mdot
.902 .0277 Mdot
.902 .02829 Mdot
.902 .02853 Mdot
.902 .02856 Mdot
.902 .02909 Mdot
.902 .02924 Mdot
.902 .02952 Mdot
.902 .02995 Mdot
.902 .02995 Mdot
.902 .03026 Mdot
.902 .03092 Mdot
.902 .03126 Mdot
.902 .03228 Mdot
.902 .03269 Mdot
.902 .03273 Mdot
.902 .03286 Mdot
.902 .03352 Mdot
.902 .0352 Mdot
.902 .0356 Mdot
.902 .03592 Mdot
.902 .03614 Mdot
.902 .03772 Mdot
.902 .03814 Mdot
.902 .03859 Mdot
.902 .0392 Mdot
.902 .03963 Mdot
.902 .03969 Mdot
.902 .03978 Mdot
.902 .03984 Mdot
.902 .04032 Mdot
.902 .04048 Mdot
.902 .04065 Mdot
.902 .04092 Mdot
.902 .04143 Mdot
.902 .04161 Mdot
.902 .04219 Mdot
.902 .04221 Mdot
.902 .04236 Mdot
.902 .04243 Mdot
.902 .04257 Mdot
.902 .04276 Mdot
.902 .04362 Mdot
.902 .04375 Mdot
.902 .04384 Mdot
.902 .04395 Mdot
.902 .04455 Mdot
.902 .04457 Mdot
.902 .04641 Mdot
.902 .04677 Mdot
.902 .04715 Mdot
.902 .04722 Mdot
.902 .04744 Mdot
.902 .04773 Mdot
.902 .04774 Mdot
.902 .04782 Mdot
.902 .04812 Mdot
.902 .04855 Mdot
.902 .04857 Mdot
.902 .04864 Mdot
.902 .0506 Mdot
.902 .05128 Mdot
.902 .05135 Mdot
.902 .05168 Mdot
.902 .05174 Mdot
.902 .0524 Mdot
.902 .05275 Mdot
.902 .05284 Mdot
.902 .05296 Mdot
.902 .05337 Mdot
.902 .05356 Mdot
.902 .05366 Mdot
.902 .0546 Mdot
.902 .05546 Mdot
.902 .05622 Mdot
.902 .05698 Mdot
.902 .05779 Mdot
.902 .05824 Mdot
.902 .05889 Mdot
.902 .05966 Mdot
.902 .05977 Mdot
.902 .05993 Mdot
.902 .06004 Mdot
.902 .06091 Mdot
.902 .06119 Mdot
.902 .06151 Mdot
.902 .06199 Mdot
.902 .06265 Mdot
.902 .06289 Mdot
.902 .0629 Mdot
.902 .06323 Mdot
.902 .06417 Mdot
.902 .06428 Mdot
.902 .06431 Mdot
.902 .06459 Mdot
.902 .06472 Mdot
.902 .06492 Mdot
.902 .06496 Mdot
.902 .06531 Mdot
.902 .06678 Mdot
.902 .06685 Mdot
.902 .06705 Mdot
.902 .0671 Mdot
.902 .06725 Mdot
.902 .06733 Mdot
.902 .06744 Mdot
.902 .06745 Mdot
.902 .0682 Mdot
.902 .0682 Mdot
.902 .06853 Mdot
.902 .06857 Mdot
.902 .06875 Mdot
.902 .07005 Mdot
.902 .07188 Mdot
.902 .07189 Mdot
.902 .07249 Mdot
.902 .07254 Mdot
.902 .07322 Mdot
.902 .07336 Mdot
.902 .07376 Mdot
.902 .07427 Mdot
.902 .07428 Mdot
.902 .0743 Mdot
.902 .07443 Mdot
.902 .07469 Mdot
.902 .07497 Mdot
.902 .07575 Mdot
.902 .07579 Mdot
.902 .07592 Mdot
.902 .07637 Mdot
.902 .07751 Mdot
.902 .07758 Mdot
.902 .07886 Mdot
.902 .07896 Mdot
.902 .07945 Mdot
.902 .08068 Mdot
.902 .0808 Mdot
.902 .08136 Mdot
.902 .0814 Mdot
.902 .08151 Mdot
.902 .08154 Mdot
.902 .08269 Mdot
.902 .08333 Mdot
.902 .08348 Mdot
.902 .08372 Mdot
.902 .08445 Mdot
.902 .08479 Mdot
.902 .08497 Mdot
.902 .08614 Mdot
.902 .08666 Mdot
.902 .08679 Mdot
.902 .08685 Mdot
.902 .08685 Mdot
.902 .08821 Mdot
.902 .08839 Mdot
.902 .0896 Mdot
.902 .08961 Mdot
.902 .09096 Mdot
.902 .09242 Mdot
.902 .09323 Mdot
.902 .09324 Mdot
.902 .09372 Mdot
.902 .09384 Mdot
.902 .0944 Mdot
.902 .09527 Mdot
.902 .09579 Mdot
.902 .09599 Mdot
.902 .09628 Mdot
.902 .09636 Mdot
.902 .09648 Mdot
.902 .09805 Mdot
.902 .09856 Mdot
.902 .09912 Mdot
.902 .09984 Mdot
.902 .09999 Mdot
.902 .10099 Mdot
.902 .10119 Mdot
.902 .10162 Mdot
.902 .10164 Mdot
.902 .10209 Mdot
.902 .10223 Mdot
.902 .10242 Mdot
.902 .10254 Mdot
.902 .10393 Mdot
.902 .10414 Mdot
.902 .10418 Mdot
.902 .10447 Mdot
.902 .10468 Mdot
.902 .10492 Mdot
.902 .10528 Mdot
.902 .10535 Mdot
.902 .1056 Mdot
.902 .10599 Mdot
.902 .10664 Mdot
.902 .10728 Mdot
.902 .10778 Mdot
.902 .10863 Mdot
.902 .10877 Mdot
.902 .10913 Mdot
.902 .10922 Mdot
.902 .10949 Mdot
.902 .10964 Mdot
.902 .10984 Mdot
.902 .10985 Mdot
.902 .10993 Mdot
.902 .11029 Mdot
.902 .11119 Mdot
.902 .11121 Mdot
.902 .11126 Mdot
.902 .1118 Mdot
.902 .11188 Mdot
.902 .11205 Mdot
.902 .11206 Mdot
.902 .11219 Mdot
.902 .1122 Mdot
.902 .11236 Mdot
.902 .11378 Mdot
.902 .11453 Mdot
.902 .11572 Mdot
.902 .1165 Mdot
.902 .11785 Mdot
.902 .11786 Mdot
.902 .11894 Mdot
.902 .11903 Mdot
.902 .11948 Mdot
.902 .12007 Mdot
.902 .12026 Mdot
.902 .12051 Mdot
.902 .12105 Mdot
.902 .12123 Mdot
.902 .12134 Mdot
.902 .12215 Mdot
.902 .12218 Mdot
.902 .1222 Mdot
.902 .12244 Mdot
.902 .12291 Mdot
.902 .12341 Mdot
.902 .12373 Mdot
.902 .12443 Mdot
.902 .12477 Mdot
.902 .12482 Mdot
.902 .12489 Mdot
.902 .12513 Mdot
.902 .12543 Mdot
.902 .12594 Mdot
.902 .12741 Mdot
.902 .12776 Mdot
.902 .12799 Mdot
.902 .1281 Mdot
.902 .12813 Mdot
.902 .12817 Mdot
.902 .12955 Mdot
.902 .13043 Mdot
.902 .13062 Mdot
.902 .13119 Mdot
.902 .13132 Mdot
.902 .1315 Mdot
.902 .13182 Mdot
.902 .13211 Mdot
.902 .13294 Mdot
.902 .13372 Mdot
.902 .13394 Mdot
.902 .13429 Mdot
.902 .13493 Mdot
.902 .13501 Mdot
.902 .13522 Mdot
.902 .13526 Mdot
.902 .136 Mdot
.902 .13651 Mdot
.902 .13734 Mdot
.902 .1377 Mdot
.902 .13849 Mdot
.902 .13877 Mdot
.902 .13919 Mdot
.902 .14051 Mdot
.902 .14112 Mdot
.902 .14146 Mdot
.902 .14293 Mdot
.902 .14356 Mdot
.902 .1445 Mdot
.902 .14474 Mdot
.902 .14484 Mdot
.902 .14485 Mdot
.902 .14496 Mdot
.902 .14557 Mdot
.902 .14636 Mdot
.902 .14649 Mdot
.902 .14679 Mdot
.902 .14698 Mdot
.902 .14714 Mdot
.902 .1473 Mdot
.902 .14738 Mdot
.902 .14762 Mdot
.902 .14835 Mdot
.902 .1489 Mdot
.902 .1498 Mdot
.902 .14983 Mdot
.902 .15126 Mdot
.902 .15216 Mdot
.902 .15225 Mdot
.902 .15489 Mdot
.902 .1549 Mdot
.902 .15551 Mdot
.902 .15636 Mdot
.902 .15638 Mdot
.902 .15724 Mdot
.902 .15746 Mdot
.902 .15794 Mdot
.902 .15847 Mdot
.902 .16004 Mdot
.902 .1606 Mdot
.902 .16067 Mdot
.902 .16098 Mdot
.902 .16116 Mdot
.902 .16133 Mdot
.902 .16175 Mdot
.902 .16186 Mdot
.902 .162 Mdot
.902 .16223 Mdot
.902 .16505 Mdot
.902 .16513 Mdot
.902 .16588 Mdot
.902 .16597 Mdot
.902 .16629 Mdot
.902 .16693 Mdot
.902 .16699 Mdot
.902 .16702 Mdot
.902 .16738 Mdot
.902 .16829 Mdot
.902 .16855 Mdot
.902 .16883 Mdot
.902 .16917 Mdot
.902 .17035 Mdot
.902 .17052 Mdot
.902 .17072 Mdot
.902 .17133 Mdot
.902 .1715 Mdot
.902 .17153 Mdot
.902 .17234 Mdot
.902 .17259 Mdot
.902 .17293 Mdot
.902 .17315 Mdot
.902 .17335 Mdot
.902 .17396 Mdot
.902 .1754 Mdot
.902 .17566 Mdot
.902 .17603 Mdot
.902 .17611 Mdot
.902 .17663 Mdot
.902 .1768 Mdot
.902 .17701 Mdot
.902 .17744 Mdot
.902 .17783 Mdot
.902 .1781 Mdot
.902 .17822 Mdot
.902 .17866 Mdot
.902 .17938 Mdot
.902 .17956 Mdot
.902 .17993 Mdot
.902 .17998 Mdot
.902 .18055 Mdot
.902 .18093 Mdot
.902 .18127 Mdot
.902 .18171 Mdot
.902 .18261 Mdot
.902 .1833 Mdot
.902 .18414 Mdot
.902 .1844 Mdot
.902 .18504 Mdot
.902 .1852 Mdot
.902 .18569 Mdot
.902 .18595 Mdot
.902 .18632 Mdot
.902 .18634 Mdot
.902 .18649 Mdot
.902 .18653 Mdot
.902 .18711 Mdot
.902 .18713 Mdot
.902 .18718 Mdot
.902 .18754 Mdot
.902 .18757 Mdot
.902 .18847 Mdot
.902 .18876 Mdot
.902 .18876 Mdot
.902 .18879 Mdot
.902 .18888 Mdot
.902 .18901 Mdot
.902 .18902 Mdot
.902 .18985 Mdot
.902 .18987 Mdot
.902 .19 Mdot
.902 .1903 Mdot
.902 .19033 Mdot
.902 .19055 Mdot
.902 .19059 Mdot
.902 .19087 Mdot
.902 .19114 Mdot
.902 .19335 Mdot
.902 .19342 Mdot
.902 .19462 Mdot
.902 .1947 Mdot
.902 .19479 Mdot
.902 .19482 Mdot
.902 .19505 Mdot
.902 .19637 Mdot
.902 .19693 Mdot
.902 .19705 Mdot
.902 .19833 Mdot
.902 .19915 Mdot
.902 .20056 Mdot
.902 .20077 Mdot
.902 .20078 Mdot
.902 .20126 Mdot
.902 .20163 Mdot
.902 .20275 Mdot
.902 .20289 Mdot
.902 .20337 Mdot
.902 .20371 Mdot
.902 .20478 Mdot
.902 .20513 Mdot
.902 .20557 Mdot
.902 .2056 Mdot
.902 .20654 Mdot
.902 .20687 Mdot
.902 .20706 Mdot
.902 .20722 Mdot
.902 .20788 Mdot
.902 .20799 Mdot
.902 .20853 Mdot
.902 .20857 Mdot
.902 .20862 Mdot
.902 .20906 Mdot
.902 .20965 Mdot
.902 .20989 Mdot
.902 .21081 Mdot
.902 .21138 Mdot
.902 .21212 Mdot
.902 .21264 Mdot
.902 .21325 Mdot
.902 .21335 Mdot
.902 .21348 Mdot
.902 .2139 Mdot
.902 .21445 Mdot
.902 .21536 Mdot
.902 .21604 Mdot
.902 .21641 Mdot
.902 .21801 Mdot
.902 .21864 Mdot
.902 .21907 Mdot
.902 .21911 Mdot
.902 .2192 Mdot
.902 .21926 Mdot
.902 .21931 Mdot
.902 .21938 Mdot
.902 .21985 Mdot
.902 .22085 Mdot
.902 .22188 Mdot
.902 .22263 Mdot
.902 .22345 Mdot
.902 .22347 Mdot
.902 .22362 Mdot
.902 .2238 Mdot
.902 .22484 Mdot
.902 .22507 Mdot
.902 .22519 Mdot
.902 .22539 Mdot
.902 .22542 Mdot
.902 .22597 Mdot
.902 .22649 Mdot
.902 .22736 Mdot
.902 .22755 Mdot
.902 .22799 Mdot
.902 .22842 Mdot
.902 .2294 Mdot
.902 .22969 Mdot
.902 .2298 Mdot
.902 .23042 Mdot
.902 .23159 Mdot
.902 .23161 Mdot
.902 .23172 Mdot
.902 .23173 Mdot
.902 .2321 Mdot
.902 .23218 Mdot
.902 .23218 Mdot
.902 .23244 Mdot
.902 .23285 Mdot
.902 .23351 Mdot
.902 .2339 Mdot
.902 .23396 Mdot
.902 .23403 Mdot
.902 .23444 Mdot
.902 .23573 Mdot
.902 .23594 Mdot
.902 .23605 Mdot
.902 .23659 Mdot
.902 .23777 Mdot
.902 .23797 Mdot
.902 .23801 Mdot
.902 .23852 Mdot
.902 .23927 Mdot
.902 .24048 Mdot
.902 .24059 Mdot
.902 .24165 Mdot
.902 .2425 Mdot
.902 .24276 Mdot
.902 .24329 Mdot
.902 .24336 Mdot
.902 .24396 Mdot
.902 .24468 Mdot
.902 .24526 Mdot
.902 .2453 Mdot
.902 .24544 Mdot
.902 .24552 Mdot
.902 .24564 Mdot
.902 .24599 Mdot
.902 .24601 Mdot
.902 .24663 Mdot
.902 .24716 Mdot
.902 .24802 Mdot
.902 .24885 Mdot
.902 .24928 Mdot
.902 .24946 Mdot
.902 .24947 Mdot
.902 .24951 Mdot
.902 .24954 Mdot
.902 .24958 Mdot
.902 .24968 Mdot
.902 .25077 Mdot
.902 .25079 Mdot
.902 .2522 Mdot
.902 .25243 Mdot
.902 .25298 Mdot
.902 .25332 Mdot
.902 .25361 Mdot
.902 .2539 Mdot
.902 .25405 Mdot
.902 .2542 Mdot
.902 .25448 Mdot
.902 .25494 Mdot
.902 .2558 Mdot
.902 .25672 Mdot
.902 .25679 Mdot
.902 .25782 Mdot
.902 .25841 Mdot
.902 .25846 Mdot
.902 .25878 Mdot
.902 .25973 Mdot
.902 .26019 Mdot
.902 .26067 Mdot
.902 .26104 Mdot
.902 .2616 Mdot
.902 .26266 Mdot
.902 .26283 Mdot
.902 .26309 Mdot
.902 .26589 Mdot
.902 .2676 Mdot
.902 .2676 Mdot
.902 .26872 Mdot
.902 .2689 Mdot
.902 .26911 Mdot
.902 .27025 Mdot
.902 .27027 Mdot
.902 .27183 Mdot
.902 .27223 Mdot
.902 .27247 Mdot
.902 .27308 Mdot
.902 .27405 Mdot
.902 .2744 Mdot
.902 .27455 Mdot
.902 .27559 Mdot
.902 .27689 Mdot
.902 .2779 Mdot
.902 .27802 Mdot
.902 .27858 Mdot
.902 .27868 Mdot
.902 .2789 Mdot
.902 .27921 Mdot
.902 .27997 Mdot
.902 .28017 Mdot
.902 .28018 Mdot
.902 .28042 Mdot
.902 .28082 Mdot
.902 .28176 Mdot
.902 .28295 Mdot
.902 .28476 Mdot
.902 .28592 Mdot
.902 .28605 Mdot
.902 .28742 Mdot
.902 .28759 Mdot
.902 .28816 Mdot
.902 .28822 Mdot
.902 .28879 Mdot
.902 .28931 Mdot
.902 .28942 Mdot
.902 .28947 Mdot
.902 .28961 Mdot
.902 .29013 Mdot
.902 .29176 Mdot
.902 .29224 Mdot
.902 .29273 Mdot
.902 .29335 Mdot
.902 .29548 Mdot
.902 .29578 Mdot
.902 .29615 Mdot
.902 .29726 Mdot
.902 .29755 Mdot
.902 .29761 Mdot
.902 .29874 Mdot
.902 .29907 Mdot
.902 .29952 Mdot
.902 .30013 Mdot
.902 .30053 Mdot
.902 .30089 Mdot
.902 .30199 Mdot
.902 .30429 Mdot
.902 .3043 Mdot
.902 .30458 Mdot
.902 .30506 Mdot
.902 .30573 Mdot
.902 .30587 Mdot
.902 .30681 Mdot
.902 .30712 Mdot
.902 .3075 Mdot
.902 .30793 Mdot
.902 .30827 Mdot
.902 .30852 Mdot
.902 .30898 Mdot
.902 .30921 Mdot
.902 .30947 Mdot
.902 .30968 Mdot
.902 .31048 Mdot
.902 .31177 Mdot
.902 .3121 Mdot
.902 .31275 Mdot
.902 .31285 Mdot
.902 .31292 Mdot
.902 .31299 Mdot
.902 .31389 Mdot
.902 .31457 Mdot
.902 .31517 Mdot
.902 .31597 Mdot
.902 .31759 Mdot
.902 .31805 Mdot
.902 .31884 Mdot
.902 .31938 Mdot
.902 .32013 Mdot
.902 .32036 Mdot
.902 .32082 Mdot
.902 .32197 Mdot
.902 .32215 Mdot
.902 .32227 Mdot
.902 .32315 Mdot
.902 .32363 Mdot
.902 .32429 Mdot
.902 .32432 Mdot
.902 .32459 Mdot
.902 .32468 Mdot
.902 .3253 Mdot
.902 .32572 Mdot
.902 .32576 Mdot
.902 .32583 Mdot
.902 .32642 Mdot
.902 .32649 Mdot
.902 .32654 Mdot
.902 .32693 Mdot
.902 .32816 Mdot
.902 .3287 Mdot
.902 .3287 Mdot
.902 .32875 Mdot
.902 .32891 Mdot
.902 .32915 Mdot
.902 .32916 Mdot
.902 .33029 Mdot
.902 .33067 Mdot
.902 .3307 Mdot
.902 .33092 Mdot
.902 .33148 Mdot
.902 .33153 Mdot
.902 .33193 Mdot
.902 .33198 Mdot
.902 .3325 Mdot
.902 .33298 Mdot
.902 .33453 Mdot
.902 .33697 Mdot
.902 .3371 Mdot
.902 .33781 Mdot
.902 .33823 Mdot
.902 .33925 Mdot
.902 .33941 Mdot
.902 .33956 Mdot
.902 .33963 Mdot
.902 .34004 Mdot
.902 .34005 Mdot
.902 .34035 Mdot
.902 .34107 Mdot
.902 .34209 Mdot
.902 .34242 Mdot
.902 .34342 Mdot
.902 .34364 Mdot
.902 .34457 Mdot
.902 .3452 Mdot
.902 .34524 Mdot
.902 .34595 Mdot
.902 .34601 Mdot
.902 .34734 Mdot
.902 .34744 Mdot
.902 .34999 Mdot
.902 .35035 Mdot
.902 .35038 Mdot
.902 .35038 Mdot
.902 .35123 Mdot
.902 .35191 Mdot
.902 .35392 Mdot
.902 .35419 Mdot
.902 .35426 Mdot
.902 .35505 Mdot
.902 .35565 Mdot
.902 .35759 Mdot
.902 .35822 Mdot
.902 .35901 Mdot
.902 .35908 Mdot
.902 .36015 Mdot
.902 .36077 Mdot
.902 .36135 Mdot
.902 .36171 Mdot
.902 .36199 Mdot
.902 .36318 Mdot
.902 .36338 Mdot
.902 .36391 Mdot
.902 .36435 Mdot
.902 .36436 Mdot
.902 .36444 Mdot
.902 .36452 Mdot
.902 .36531 Mdot
.902 .36639 Mdot
.902 .36682 Mdot
.902 .36847 Mdot
.902 .3688 Mdot
.902 .36934 Mdot
.902 .3695 Mdot
.902 .37083 Mdot
.902 .37121 Mdot
.902 .3714 Mdot
.902 .37177 Mdot
.902 .37286 Mdot
.902 .37306 Mdot
.902 .37325 Mdot
.902 .37329 Mdot
.902 .37405 Mdot
.902 .37496 Mdot
.902 .37503 Mdot
.902 .37531 Mdot
.902 .37547 Mdot
.902 .37593 Mdot
.902 .37668 Mdot
.902 .37763 Mdot
.902 .37791 Mdot
.902 .37857 Mdot
.902 .38147 Mdot
.902 .3826 Mdot
.902 .38293 Mdot
.902 .38337 Mdot
.902 .38344 Mdot
.902 .38361 Mdot
.902 .38371 Mdot
.902 .3838 Mdot
.902 .38394 Mdot
.902 .38447 Mdot
.902 .38478 Mdot
.902 .38609 Mdot
.902 .38658 Mdot
.902 .3881 Mdot
.902 .38844 Mdot
.902 .38979 Mdot
.902 .39127 Mdot
.902 .3913 Mdot
.902 .39157 Mdot
.902 .3919 Mdot
.902 .39377 Mdot
.902 .39419 Mdot
.902 .39442 Mdot
.902 .39477 Mdot
.902 .39482 Mdot
.902 .39502 Mdot
.902 .39582 Mdot
.902 .39601 Mdot
.902 .39676 Mdot
.902 .39721 Mdot
.902 .39833 Mdot
.902 .39867 Mdot
.902 .39947 Mdot
.902 .40024 Mdot
.902 .40081 Mdot
.902 .40177 Mdot
.902 .40198 Mdot
.902 .402 Mdot
.902 .40253 Mdot
.902 .40272 Mdot
.902 .40385 Mdot
.902 .40564 Mdot
.902 .40596 Mdot
.902 .406 Mdot
.902 .4062 Mdot
.902 .40621 Mdot
.902 .40671 Mdot
.902 .40688 Mdot
.902 .40701 Mdot
.902 .40702 Mdot
.902 .40749 Mdot
.902 .40819 Mdot
.902 .40822 Mdot
.902 .40942 Mdot
.902 .41012 Mdot
.902 .41017 Mdot
.902 .41023 Mdot
.902 .41036 Mdot
.902 .41109 Mdot
.902 .41147 Mdot
.902 .41263 Mdot
.902 .41342 Mdot
.902 .4138 Mdot
.902 .41401 Mdot
.902 .41497 Mdot
.902 .41621 Mdot
.902 .4171 Mdot
.902 .41747 Mdot
.902 .41753 Mdot
.902 .41846 Mdot
.902 .41982 Mdot
.902 .422 Mdot
.902 .4222 Mdot
.902 .4237 Mdot
.902 .42375 Mdot
.902 .42411 Mdot
.902 .42466 Mdot
.902 .42565 Mdot
.902 .4261 Mdot
.902 .4262 Mdot
.902 .42707 Mdot
.902 .42719 Mdot
.902 .42827 Mdot
.902 .42838 Mdot
.902 .42886 Mdot
.902 .42956 Mdot
.902 .43063 Mdot
.902 .43069 Mdot
.902 .43094 Mdot
.902 .43109 Mdot
.902 .43131 Mdot
.902 .43189 Mdot
.902 .43193 Mdot
.902 .43197 Mdot
.902 .43291 Mdot
.902 .43309 Mdot
.902 .43404 Mdot
.902 .43415 Mdot
.902 .43554 Mdot
.902 .43561 Mdot
.902 .43666 Mdot
.902 .4371 Mdot
.902 .43747 Mdot
.902 .43787 Mdot
.902 .4382 Mdot
.902 .43822 Mdot
.902 .43829 Mdot
.902 .43834 Mdot
.902 .43841 Mdot
.902 .4386 Mdot
.902 .43895 Mdot
.902 .43973 Mdot
.902 .44055 Mdot
.902 .44056 Mdot
.902 .44059 Mdot
.902 .44126 Mdot
.902 .44315 Mdot
.902 .44356 Mdot
.902 .44455 Mdot
.902 .44515 Mdot
.902 .44569 Mdot
.902 .44621 Mdot
.902 .44647 Mdot
.902 .44674 Mdot
.902 .44725 Mdot
.902 .44807 Mdot
.902 .44963 Mdot
.902 .4513 Mdot
.902 .45141 Mdot
.902 .45327 Mdot
.902 .45434 Mdot
.902 .45443 Mdot
.902 .455 Mdot
.902 .45672 Mdot
.902 .45755 Mdot
.902 .45843 Mdot
.902 .45909 Mdot
.902 .46009 Mdot
.902 .46201 Mdot
.902 .46232 Mdot
.902 .46278 Mdot
.902 .46784 Mdot
.902 .47091 Mdot
.902 .47092 Mdot
.902 .47293 Mdot
.902 .47326 Mdot
.902 .47364 Mdot
.902 .4757 Mdot
.902 .47574 Mdot
.902 .47854 Mdot
.902 .47928 Mdot
.902 .4797 Mdot
.902 .48081 Mdot
.902 .48256 Mdot
.902 .48318 Mdot
.902 .48347 Mdot
.902 .48533 Mdot
.902 .48767 Mdot
.902 .4895 Mdot
.902 .48973 Mdot
.902 .49073 Mdot
.902 .4909 Mdot
.902 .4913 Mdot
.902 .49187 Mdot
.902 .49324 Mdot
.902 .49359 Mdot
.902 .49362 Mdot
.902 .49404 Mdot
.902 .49478 Mdot
.902 .49646 Mdot
.902 .49861 Mdot
.902 .50188 Mdot
.902 .50396 Mdot
.902 .50421 Mdot
.902 .50667 Mdot
.902 .50697 Mdot
.902 .50801 Mdot
.902 .50811 Mdot
.902 .50914 Mdot
.902 .51009 Mdot
.902 .51028 Mdot
.902 .51037 Mdot
.902 .51063 Mdot
.902 .51157 Mdot
.902 .51451 Mdot
.902 .51536 Mdot
.902 .51626 Mdot
.902 .51737 Mdot
.902 .52121 Mdot
.902 .52176 Mdot
.902 .52242 Mdot
.902 .52442 Mdot
.902 .52495 Mdot
.902 .52506 Mdot
.902 .52709 Mdot
.902 .52769 Mdot
.902 .52851 Mdot
.902 .5296 Mdot
.902 .53032 Mdot
.902 .53097 Mdot
.902 .53295 Mdot
.902 .5371 Mdot
.902 .53713 Mdot
.902 .53764 Mdot
.902 .53849 Mdot
.902 .5397 Mdot
.902 .53997 Mdot
.902 .54165 Mdot
.902 .54221 Mdot
.902 .5429 Mdot
.902 .54367 Mdot
.902 .54429 Mdot
.902 .54474 Mdot
.902 .54556 Mdot
.902 .54599 Mdot
.902 .54645 Mdot
.902 .54684 Mdot
.904 .01727 Mdot
.904 .01831 Mdot
.904 .01934 Mdot
.904 .01959 Mdot
.904 .02008 Mdot
.904 .02047 Mdot
.904 .02057 Mdot
.904 .02122 Mdot
.904 .02173 Mdot
.904 .02201 Mdot
.904 .02224 Mdot
.904 .02298 Mdot
.904 .02308 Mdot
.904 .02335 Mdot
.904 .02354 Mdot
.904 .02408 Mdot
.904 .02442 Mdot
.904 .02469 Mdot
.904 .02512 Mdot
.904 .0253 Mdot
.904 .02567 Mdot
.904 .02617 Mdot
.904 .02639 Mdot
.904 .02648 Mdot
.904 .0274 Mdot
.904 .02791 Mdot
.904 .02832 Mdot
.904 .02965 Mdot
.904 .02978 Mdot
.904 .02983 Mdot
.904 .03033 Mdot
.904 .03052 Mdot
.904 .03066 Mdot
.904 .03092 Mdot
.904 .03165 Mdot
.904 .03182 Mdot
.904 .03222 Mdot
.904 .03226 Mdot
.904 .03275 Mdot
.904 .03319 Mdot
.904 .03319 Mdot
.904 .03353 Mdot
.904 .03373 Mdot
.904 .03385 Mdot
.904 .03452 Mdot
.904 .03535 Mdot
.904 .03543 Mdot
.904 .03582 Mdot
.904 .03599 Mdot
.904 .03724 Mdot
.904 .03742 Mdot
.904 .03765 Mdot
.904 .03784 Mdot
.904 .03854 Mdot
.904 .03858 Mdot
.904 .03914 Mdot
.904 .0393 Mdot
.904 .03935 Mdot
.904 .04055 Mdot
.904 .04134 Mdot
.904 .04172 Mdot
.904 .04194 Mdot
.904 .04204 Mdot
.904 .04238 Mdot
.904 .04295 Mdot
.904 .04329 Mdot
.904 .04355 Mdot
.904 .04393 Mdot
.904 .04402 Mdot
.904 .0446 Mdot
.904 .04461 Mdot
.904 .04534 Mdot
.904 .04564 Mdot
.904 .0463 Mdot
.904 .04636 Mdot
.904 .04643 Mdot
.904 .04733 Mdot
.904 .04812 Mdot
.904 .04813 Mdot
.904 .04871 Mdot
.904 .04874 Mdot
.904 .0491 Mdot
.904 .04931 Mdot
.904 .05053 Mdot
.904 .05202 Mdot
.904 .05217 Mdot
.904 .05281 Mdot
.904 .05287 Mdot
.904 .05318 Mdot
.904 .05433 Mdot
.904 .05451 Mdot
.904 .05493 Mdot
.904 .05544 Mdot
.904 .0555 Mdot
.904 .05577 Mdot
.904 .05619 Mdot
.904 .0563 Mdot
.904 .05653 Mdot
.904 .0573 Mdot
.904 .05738 Mdot
.904 .0575 Mdot
.904 .05776 Mdot
.904 .05779 Mdot
.904 .05786 Mdot
.904 .05888 Mdot
.904 .05917 Mdot
.904 .05926 Mdot
.904 .05962 Mdot
.904 .06111 Mdot
.904 .06142 Mdot
.904 .06251 Mdot
.904 .06286 Mdot
.904 .06354 Mdot
.904 .06394 Mdot
.904 .06413 Mdot
.904 .06473 Mdot
.904 .0652 Mdot
.904 .06529 Mdot
.904 .0654 Mdot
.904 .06577 Mdot
.904 .06626 Mdot
.904 .06638 Mdot
.904 .06647 Mdot
.904 .06647 Mdot
.904 .06685 Mdot
.904 .06685 Mdot
.904 .06703 Mdot
.904 .06754 Mdot
.904 .0677 Mdot
.904 .06873 Mdot
.904 .06875 Mdot
.904 .06877 Mdot
.904 .06948 Mdot
.904 .06964 Mdot
.904 .06987 Mdot
.904 .07008 Mdot
.904 .07017 Mdot
.904 .07062 Mdot
.904 .07171 Mdot
.904 .07182 Mdot
.904 .07194 Mdot
.904 .07206 Mdot
.904 .07271 Mdot
.904 .07368 Mdot
.904 .07512 Mdot
.904 .07512 Mdot
.904 .07617 Mdot
.904 .07623 Mdot
.904 .07688 Mdot
.904 .07726 Mdot
.904 .07748 Mdot
.904 .07758 Mdot
.904 .07946 Mdot
.904 .0803 Mdot
.904 .08134 Mdot
.904 .082 Mdot
.904 .08216 Mdot
.904 .08243 Mdot
.904 .0827 Mdot
.904 .08284 Mdot
.904 .08359 Mdot
.904 .0837 Mdot
.904 .08389 Mdot
.904 .08426 Mdot
.904 .08496 Mdot
.904 .08551 Mdot
.904 .08635 Mdot
.904 .08667 Mdot
.904 .08742 Mdot
.904 .08835 Mdot
.904 .08846 Mdot
.904 .08846 Mdot
.904 .08879 Mdot
.904 .08894 Mdot
.904 .08915 Mdot
.904 .08969 Mdot
.904 .0897 Mdot
.904 .0899 Mdot
.904 .09032 Mdot
.904 .09036 Mdot
.904 .09095 Mdot
.904 .09158 Mdot
.904 .09171 Mdot
.904 .09186 Mdot
.904 .09207 Mdot
.904 .09212 Mdot
.904 .09255 Mdot
.904 .0926 Mdot
.904 .09271 Mdot
.904 .09284 Mdot
.904 .09457 Mdot
.904 .09508 Mdot
.904 .0951 Mdot
.904 .09526 Mdot
.904 .0959 Mdot
.904 .09719 Mdot
.904 .0977 Mdot
.904 .09859 Mdot
.904 .09916 Mdot
.904 .0996 Mdot
.904 .09985 Mdot
.904 .10069 Mdot
.904 .10113 Mdot
.904 .10175 Mdot
.904 .10246 Mdot
.904 .10281 Mdot
.904 .10299 Mdot
.904 .10372 Mdot
.904 .10387 Mdot
.904 .10405 Mdot
.904 .10513 Mdot
.904 .10599 Mdot
.904 .10616 Mdot
.904 .10636 Mdot
.904 .10644 Mdot
.904 .10686 Mdot
.904 .10702 Mdot
.904 .10711 Mdot
.904 .10714 Mdot
.904 .10772 Mdot
.904 .10791 Mdot
.904 .10813 Mdot
.904 .1083 Mdot
.904 .1083 Mdot
.904 .10897 Mdot
.904 .10898 Mdot
.904 .10901 Mdot
.904 .1093 Mdot
.904 .11023 Mdot
.904 .11023 Mdot
.904 .11051 Mdot
.904 .1119 Mdot
.904 .11207 Mdot
.904 .11237 Mdot
.904 .11241 Mdot
.904 .11245 Mdot
.904 .11373 Mdot
.904 .11402 Mdot
.904 .11443 Mdot
.904 .11455 Mdot
.904 .11481 Mdot
.904 .11498 Mdot
.904 .11579 Mdot
.904 .11644 Mdot
.904 .11687 Mdot
.904 .11776 Mdot
.904 .11797 Mdot
.904 .11817 Mdot
.904 .11839 Mdot
.904 .11957 Mdot
.904 .12069 Mdot
.904 .1209 Mdot
.904 .12133 Mdot
.904 .12377 Mdot
.904 .12392 Mdot
.904 .12393 Mdot
.904 .12464 Mdot
.904 .12556 Mdot
.904 .1256 Mdot
.904 .12583 Mdot
.904 .12593 Mdot
.904 .12711 Mdot
.904 .12779 Mdot
.904 .1282 Mdot
.904 .12837 Mdot
.904 .12863 Mdot
.904 .12976 Mdot
.904 .13015 Mdot
.904 .13094 Mdot
.904 .13165 Mdot
.904 .13177 Mdot
.904 .13329 Mdot
.904 .13404 Mdot
.904 .13407 Mdot
.904 .13489 Mdot
.904 .13516 Mdot
.904 .13524 Mdot
.904 .13545 Mdot
.904 .13623 Mdot
.904 .13637 Mdot
.904 .13666 Mdot
.904 .13685 Mdot
.904 .13714 Mdot
.904 .1374 Mdot
.904 .13762 Mdot
.904 .13788 Mdot
.904 .13848 Mdot
.904 .13925 Mdot
.904 .13938 Mdot
.904 .13943 Mdot
.904 .13977 Mdot
.904 .14045 Mdot
.904 .14109 Mdot
.904 .14127 Mdot
.904 .14171 Mdot
.904 .14177 Mdot
.904 .14206 Mdot
.904 .14272 Mdot
.904 .14403 Mdot
.904 .14422 Mdot
.904 .14441 Mdot
.904 .14481 Mdot
.904 .14506 Mdot
.904 .14617 Mdot
.904 .14773 Mdot
.904 .14784 Mdot
.904 .14804 Mdot
.904 .14805 Mdot
.904 .14841 Mdot
.904 .14863 Mdot
.904 .14869 Mdot
.904 .14891 Mdot
.904 .1493 Mdot
.904 .15027 Mdot
.904 .15029 Mdot
.904 .15066 Mdot
.904 .15084 Mdot
.904 .15141 Mdot
.904 .15147 Mdot
.904 .15185 Mdot
.904 .15254 Mdot
.904 .15338 Mdot
.904 .15353 Mdot
.904 .15368 Mdot
.904 .15392 Mdot
.904 .15419 Mdot
.904 .15458 Mdot
.904 .15466 Mdot
.904 .15544 Mdot
.904 .15554 Mdot
.904 .1557 Mdot
.904 .15574 Mdot
.904 .15597 Mdot
.904 .15838 Mdot
.904 .15909 Mdot
.904 .15919 Mdot
.904 .16002 Mdot
.904 .16004 Mdot
.904 .16008 Mdot
.904 .16034 Mdot
.904 .1615 Mdot
.904 .16182 Mdot
.904 .16233 Mdot
.904 .16382 Mdot
.904 .16476 Mdot
.904 .16514 Mdot
.904 .16637 Mdot
.904 .16704 Mdot
.904 .1674 Mdot
.904 .16819 Mdot
.904 .16839 Mdot
.904 .16864 Mdot
.904 .17017 Mdot
.904 .17071 Mdot
.904 .17096 Mdot
.904 .17121 Mdot
.904 .17195 Mdot
.904 .17205 Mdot
.904 .17208 Mdot
.904 .17336 Mdot
.904 .17398 Mdot
.904 .17414 Mdot
.904 .17431 Mdot
.904 .17464 Mdot
.904 .17564 Mdot
.904 .17591 Mdot
.904 .17623 Mdot
.904 .17758 Mdot
.904 .17819 Mdot
.904 .17975 Mdot
.904 .18005 Mdot
.904 .1804 Mdot
.904 .18049 Mdot
.904 .18056 Mdot
.904 .1809 Mdot
.904 .18131 Mdot
.904 .18161 Mdot
.904 .18176 Mdot
.904 .18183 Mdot
.904 .18286 Mdot
.904 .18309 Mdot
.904 .18321 Mdot
.904 .18361 Mdot
.904 .18391 Mdot
.904 .18391 Mdot
.904 .18513 Mdot
.904 .18515 Mdot
.904 .1852 Mdot
.904 .18533 Mdot
.904 .18554 Mdot
.904 .18573 Mdot
.904 .18579 Mdot
.904 .18616 Mdot
.904 .18672 Mdot
.904 .18719 Mdot
.904 .1874 Mdot
.904 .1874 Mdot
.904 .18792 Mdot
.904 .18991 Mdot
.904 .19038 Mdot
.904 .19043 Mdot
.904 .19073 Mdot
.904 .19128 Mdot
.904 .19134 Mdot
.904 .19143 Mdot
.904 .19199 Mdot
.904 .19245 Mdot
.904 .19288 Mdot
.904 .1937 Mdot
.904 .19373 Mdot
.904 .19376 Mdot
.904 .19409 Mdot
.904 .19426 Mdot
.904 .19478 Mdot
.904 .19501 Mdot
.904 .19513 Mdot
.904 .19522 Mdot
.904 .19569 Mdot
.904 .196 Mdot
.904 .19746 Mdot
.904 .19749 Mdot
.904 .19832 Mdot
.904 .19864 Mdot
.904 .19905 Mdot
.904 .1991 Mdot
.904 .19942 Mdot
.904 .20082 Mdot
.904 .20103 Mdot
.904 .2014 Mdot
.904 .20177 Mdot
.904 .20193 Mdot
.904 .20216 Mdot
.904 .20284 Mdot
.904 .20348 Mdot
.904 .20364 Mdot
.904 .20422 Mdot
.904 .2043 Mdot
.904 .2052 Mdot
.904 .20553 Mdot
.904 .20632 Mdot
.904 .20652 Mdot
.904 .20653 Mdot
.904 .20671 Mdot
.904 .20747 Mdot
.904 .20799 Mdot
.904 .20804 Mdot
.904 .2088 Mdot
.904 .20938 Mdot
.904 .21067 Mdot
.904 .21162 Mdot
.904 .21188 Mdot
.904 .21217 Mdot
.904 .21218 Mdot
.904 .21345 Mdot
.904 .21403 Mdot
.904 .21476 Mdot
.904 .21502 Mdot
.904 .21513 Mdot
.904 .21519 Mdot
.904 .21543 Mdot
.904 .21562 Mdot
.904 .21579 Mdot
.904 .21612 Mdot
.904 .21639 Mdot
.904 .21692 Mdot
.904 .21712 Mdot
.904 .21721 Mdot
.904 .21793 Mdot
.904 .21895 Mdot
.904 .21916 Mdot
.904 .21924 Mdot
.904 .2199 Mdot
.904 .22021 Mdot
.904 .22067 Mdot
.904 .22245 Mdot
.904 .22272 Mdot
.904 .22326 Mdot
.904 .22341 Mdot
.904 .22427 Mdot
.904 .22485 Mdot
.904 .22598 Mdot
.904 .22613 Mdot
.904 .22636 Mdot
.904 .22639 Mdot
.904 .22703 Mdot
.904 .22808 Mdot
.904 .22909 Mdot
.904 .23045 Mdot
.904 .23052 Mdot
.904 .2307 Mdot
.904 .23087 Mdot
.904 .23102 Mdot
.904 .23185 Mdot
.904 .23199 Mdot
.904 .23249 Mdot
.904 .23263 Mdot
.904 .23276 Mdot
.904 .23301 Mdot
.904 .23313 Mdot
.904 .23442 Mdot
.904 .23465 Mdot
.904 .23466 Mdot
.904 .23519 Mdot
.904 .23553 Mdot
.904 .236 Mdot
.904 .23605 Mdot
.904 .23623 Mdot
.904 .23653 Mdot
.904 .23663 Mdot
.904 .23693 Mdot
.904 .23694 Mdot
.904 .2374 Mdot
.904 .23781 Mdot
.904 .2382 Mdot
.904 .23849 Mdot
.904 .23945 Mdot
.904 .23953 Mdot
.904 .23987 Mdot
.904 .24011 Mdot
.904 .2402 Mdot
.904 .24082 Mdot
.904 .24205 Mdot
.904 .24236 Mdot
.904 .24321 Mdot
.904 .24353 Mdot
.904 .24433 Mdot
.904 .24438 Mdot
.904 .24443 Mdot
.904 .24468 Mdot
.904 .24496 Mdot
.904 .24554 Mdot
.904 .24602 Mdot
.904 .24614 Mdot
.904 .24624 Mdot
.904 .24662 Mdot
.904 .24851 Mdot
.904 .24861 Mdot
.904 .24887 Mdot
.904 .24902 Mdot
.904 .24908 Mdot
.904 .2492 Mdot
.904 .24981 Mdot
.904 .24993 Mdot
.904 .25038 Mdot
.904 .25049 Mdot
.904 .25083 Mdot
.904 .25194 Mdot
.904 .25238 Mdot
.904 .25388 Mdot
.904 .25521 Mdot
.904 .25541 Mdot
.904 .25559 Mdot
.904 .25577 Mdot
.904 .25578 Mdot
.904 .25644 Mdot
.904 .25684 Mdot
.904 .25694 Mdot
.904 .25702 Mdot
.904 .25733 Mdot
.904 .25804 Mdot
.904 .25979 Mdot
.904 .25984 Mdot
.904 .26041 Mdot
.904 .2605 Mdot
.904 .26084 Mdot
.904 .26185 Mdot
.904 .26193 Mdot
.904 .26197 Mdot
.904 .26265 Mdot
.904 .26391 Mdot
.904 .26542 Mdot
.904 .26569 Mdot
.904 .26596 Mdot
.904 .26627 Mdot
.904 .2664 Mdot
.904 .26689 Mdot
.904 .26691 Mdot
.904 .2675 Mdot
.904 .26759 Mdot
.904 .26774 Mdot
.904 .26809 Mdot
.904 .26813 Mdot
.904 .26914 Mdot
.904 .26932 Mdot
.904 .26962 Mdot
.904 .26968 Mdot
.904 .27011 Mdot
.904 .27029 Mdot
.904 .2716 Mdot
.904 .27193 Mdot
.904 .2722 Mdot
.904 .27321 Mdot
.904 .27446 Mdot
.904 .27551 Mdot
.904 .27575 Mdot
.904 .27593 Mdot
.904 .27743 Mdot
.904 .27747 Mdot
.904 .27753 Mdot
.904 .278 Mdot
.904 .28009 Mdot
.904 .28069 Mdot
.904 .28124 Mdot
.904 .28139 Mdot
.904 .28161 Mdot
.904 .28326 Mdot
.904 .28356 Mdot
.904 .2843 Mdot
.904 .28466 Mdot
.904 .28599 Mdot
.904 .28668 Mdot
.904 .28798 Mdot
.904 .28824 Mdot
.904 .28838 Mdot
.904 .2889 Mdot
.904 .29012 Mdot
.904 .29059 Mdot
.904 .29076 Mdot
.904 .2922 Mdot
.904 .29256 Mdot
.904 .29302 Mdot
.904 .29471 Mdot
.904 .29577 Mdot
.904 .29676 Mdot
.904 .2972 Mdot
.904 .29766 Mdot
.904 .299 Mdot
.904 .29918 Mdot
.904 .29924 Mdot
.904 .29963 Mdot
.904 .30054 Mdot
.904 .30141 Mdot
.904 .30155 Mdot
.904 .30243 Mdot
.904 .30267 Mdot
.904 .30283 Mdot
.904 .30296 Mdot
.904 .30327 Mdot
.904 .30386 Mdot
.904 .30446 Mdot
.904 .30452 Mdot
.904 .30567 Mdot
.904 .30615 Mdot
.904 .30646 Mdot
.904 .30674 Mdot
.904 .30675 Mdot
.904 .30723 Mdot
.904 .30836 Mdot
.904 .30849 Mdot
.904 .30918 Mdot
.904 .31028 Mdot
.904 .31181 Mdot
.904 .31239 Mdot
.904 .31309 Mdot
.904 .31336 Mdot
.904 .31358 Mdot
.904 .31363 Mdot
.904 .31428 Mdot
.904 .31443 Mdot
.904 .31456 Mdot
.904 .31497 Mdot
.904 .31517 Mdot
.904 .31558 Mdot
.904 .31591 Mdot
.904 .31646 Mdot
.904 .31673 Mdot
.904 .31685 Mdot
.904 .31873 Mdot
.904 .31914 Mdot
.904 .31936 Mdot
.904 .31986 Mdot
.904 .32008 Mdot
.904 .32062 Mdot
.904 .32062 Mdot
.904 .32091 Mdot
.904 .32181 Mdot
.904 .32285 Mdot
.904 .32295 Mdot
.904 .32319 Mdot
.904 .32357 Mdot
.904 .32391 Mdot
.904 .32402 Mdot
.904 .32468 Mdot
.904 .32512 Mdot
.904 .3257 Mdot
.904 .32656 Mdot
.904 .32693 Mdot
.904 .32693 Mdot
.904 .32787 Mdot
.904 .3292 Mdot
.904 .33147 Mdot
.904 .33231 Mdot
.904 .33241 Mdot
.904 .33264 Mdot
.904 .33295 Mdot
.904 .3334 Mdot
.904 .33395 Mdot
.904 .334 Mdot
.904 .33406 Mdot
.904 .33421 Mdot
.904 .33523 Mdot
.904 .33606 Mdot
.904 .33683 Mdot
.904 .33832 Mdot
.904 .33837 Mdot
.904 .33843 Mdot
.904 .33891 Mdot
.904 .33902 Mdot
.904 .33902 Mdot
.904 .33923 Mdot
.904 .33933 Mdot
.904 .34027 Mdot
.904 .34069 Mdot
.904 .34078 Mdot
.904 .3409 Mdot
.904 .34107 Mdot
.904 .34192 Mdot
.904 .34247 Mdot
.904 .34511 Mdot
.904 .34517 Mdot
.904 .34667 Mdot
.904 .34724 Mdot
.904 .34761 Mdot
.904 .348 Mdot
.904 .34807 Mdot
.904 .34865 Mdot
.904 .34955 Mdot
.904 .35118 Mdot
.904 .35136 Mdot
.904 .35157 Mdot
.904 .35186 Mdot
.904 .35223 Mdot
.904 .35256 Mdot
.904 .35291 Mdot
.904 .35321 Mdot
.904 .35361 Mdot
.904 .35485 Mdot
.904 .35601 Mdot
.904 .3563 Mdot
.904 .35735 Mdot
.904 .35749 Mdot
.904 .35795 Mdot
.904 .35893 Mdot
.904 .35912 Mdot
.904 .35971 Mdot
.904 .36113 Mdot
.904 .36136 Mdot
.904 .3615 Mdot
.904 .36152 Mdot
.904 .36184 Mdot
.904 .36255 Mdot
.904 .36322 Mdot
.904 .36415 Mdot
.904 .36424 Mdot
.904 .36562 Mdot
.904 .36666 Mdot
.904 .3669 Mdot
.904 .36901 Mdot
.904 .36913 Mdot
.904 .37071 Mdot
.904 .37119 Mdot
.904 .37171 Mdot
.904 .37173 Mdot
.904 .3734 Mdot
.904 .37403 Mdot
.904 .37424 Mdot
.904 .37468 Mdot
.904 .37507 Mdot
.904 .37639 Mdot
.904 .37641 Mdot
.904 .37687 Mdot
.904 .37706 Mdot
.904 .37718 Mdot
.904 .37761 Mdot
.904 .37795 Mdot
.904 .37825 Mdot
.904 .37885 Mdot
.904 .37935 Mdot
.904 .3803 Mdot
.904 .38039 Mdot
.904 .38067 Mdot
.904 .38083 Mdot
.904 .38192 Mdot
.904 .38213 Mdot
.904 .38249 Mdot
.904 .38397 Mdot
.904 .38434 Mdot
.904 .3845 Mdot
.904 .38569 Mdot
.904 .38624 Mdot
.904 .38709 Mdot
.904 .38717 Mdot
.904 .38837 Mdot
.904 .38986 Mdot
.904 .39031 Mdot
.904 .3908 Mdot
.904 .39176 Mdot
.904 .39204 Mdot
.904 .39359 Mdot
.904 .39465 Mdot
.904 .39539 Mdot
.904 .39668 Mdot
.904 .39695 Mdot
.904 .39736 Mdot
.904 .39742 Mdot
.904 .39857 Mdot
.904 .39885 Mdot
.904 .40048 Mdot
.904 .40209 Mdot
.904 .40231 Mdot
.904 .40352 Mdot
.904 .40476 Mdot
.904 .40488 Mdot
.904 .40502 Mdot
.904 .40522 Mdot
.904 .40553 Mdot
.904 .40579 Mdot
.904 .4073 Mdot
.904 .40755 Mdot
.904 .40845 Mdot
.904 .4087 Mdot
.904 .40894 Mdot
.904 .40939 Mdot
.904 .40943 Mdot
.904 .40961 Mdot
.904 .40999 Mdot
.904 .41018 Mdot
.904 .41149 Mdot
.904 .41195 Mdot
.904 .41235 Mdot
.904 .41238 Mdot
.904 .41333 Mdot
.904 .41395 Mdot
.904 .41445 Mdot
.904 .4148 Mdot
.904 .41489 Mdot
.904 .41521 Mdot
.904 .41575 Mdot
.904 .41594 Mdot
.904 .41648 Mdot
.904 .41649 Mdot
.904 .41729 Mdot
.904 .41732 Mdot
.904 .41774 Mdot
.904 .41806 Mdot
.904 .41878 Mdot
.904 .4193 Mdot
.904 .42064 Mdot
.904 .42104 Mdot
.904 .42118 Mdot
.904 .42141 Mdot
.904 .42179 Mdot
.904 .42194 Mdot
.904 .42223 Mdot
.904 .42235 Mdot
.904 .4224 Mdot
.904 .42336 Mdot
.904 .42352 Mdot
.904 .4253 Mdot
.904 .42574 Mdot
.904 .4263 Mdot
.904 .42724 Mdot
.904 .42747 Mdot
.904 .42783 Mdot
.904 .42841 Mdot
.904 .42986 Mdot
.904 .42995 Mdot
.904 .43003 Mdot
.904 .43049 Mdot
.904 .431 Mdot
.904 .4312 Mdot
.904 .43204 Mdot
.904 .43279 Mdot
.904 .43292 Mdot
.904 .43314 Mdot
.904 .4333 Mdot
.904 .43379 Mdot
.904 .43401 Mdot
.904 .4347 Mdot
.904 .43474 Mdot
.904 .43631 Mdot
.904 .43742 Mdot
.904 .43759 Mdot
.904 .43806 Mdot
.904 .43833 Mdot
.904 .43845 Mdot
.904 .43866 Mdot
.904 .43976 Mdot
.904 .43999 Mdot
.904 .44002 Mdot
.904 .44042 Mdot
.904 .4408 Mdot
.904 .44099 Mdot
.904 .44161 Mdot
.904 .44268 Mdot
.904 .44362 Mdot
.904 .44442 Mdot
.904 .44629 Mdot
.904 .44713 Mdot
.904 .44953 Mdot
.904 .44989 Mdot
.904 .45021 Mdot
.904 .45054 Mdot
.904 .45056 Mdot
.904 .45176 Mdot
.904 .45248 Mdot
.904 .45266 Mdot
.904 .45281 Mdot
.904 .45337 Mdot
.904 .45464 Mdot
.904 .45781 Mdot
.904 .4579 Mdot
.904 .45893 Mdot
.904 .45909 Mdot
.904 .4597 Mdot
.904 .46154 Mdot
.904 .46168 Mdot
.904 .46176 Mdot
.904 .46298 Mdot
.904 .46526 Mdot
.904 .46798 Mdot
.904 .46849 Mdot
.904 .46897 Mdot
.904 .46953 Mdot
.904 .46975 Mdot
.904 .47065 Mdot
.904 .47069 Mdot
.904 .47176 Mdot
.904 .47192 Mdot
.904 .47218 Mdot
.904 .47281 Mdot
.904 .47288 Mdot
.904 .47472 Mdot
.904 .47504 Mdot
.904 .47558 Mdot
.904 .4757 Mdot
.904 .47646 Mdot
.904 .4768 Mdot
.904 .47917 Mdot
.904 .47975 Mdot
.904 .48025 Mdot
.904 .48208 Mdot
.904 .48434 Mdot
.904 .48624 Mdot
.904 .48666 Mdot
.904 .48699 Mdot
.904 .48971 Mdot
.904 .48977 Mdot
.904 .48989 Mdot
.904 .49074 Mdot
.904 .49452 Mdot
.904 .49559 Mdot
.904 .4966 Mdot
.904 .49687 Mdot
.904 .49726 Mdot
.904 .50024 Mdot
.904 .50078 Mdot
.904 .50212 Mdot
.904 .50278 Mdot
.904 .50519 Mdot
.904 .50642 Mdot
.904 .50879 Mdot
.904 .50925 Mdot
.904 .50949 Mdot
.904 .51045 Mdot
.904 .51265 Mdot
.904 .5135 Mdot
.904 .51381 Mdot
.904 .5164 Mdot
.904 .51707 Mdot
.904 .51789 Mdot
.904 .52095 Mdot
.904 .52286 Mdot
.904 .52465 Mdot
.904 .52545 Mdot
.904 .52627 Mdot
.904 .52871 Mdot
.904 .52902 Mdot
.904 .52913 Mdot
.904 .52985 Mdot
.904 .53149 Mdot
.904 .53306 Mdot
.904 .53331 Mdot
.904 .53491 Mdot
.904 .53534 Mdot
.904 .53563 Mdot
.904 .53586 Mdot
.904 .53641 Mdot
.904 .53749 Mdot
.904 .53857 Mdot
.904 .53869 Mdot
.904 .54075 Mdot
.904 .54163 Mdot
.904 .54218 Mdot
.904 .54269 Mdot
.904 .54271 Mdot
.904 .54358 Mdot
.904 .54563 Mdot
.904 .54585 Mdot
.904 .5471 Mdot
.904 .5491 Mdot
.906 .016 Mdot
.906 .01651 Mdot
.906 .01704 Mdot
.906 .01774 Mdot
.906 .01788 Mdot
.906 .01796 Mdot
.906 .01796 Mdot
.906 .01824 Mdot
.906 .01861 Mdot
.906 .01893 Mdot
.906 .01969 Mdot
.906 .0201 Mdot
.906 .0202 Mdot
.906 .02043 Mdot
.906 .02045 Mdot
.906 .02059 Mdot
.906 .0206 Mdot
.906 .0211 Mdot
.906 .02178 Mdot
.906 .02179 Mdot
.906 .02197 Mdot
.906 .02236 Mdot
.906 .02312 Mdot
.906 .02373 Mdot
.906 .02378 Mdot
.906 .02441 Mdot
.906 .02448 Mdot
.906 .02466 Mdot
.906 .02507 Mdot
.906 .0251 Mdot
.906 .02537 Mdot
.906 .02538 Mdot
.906 .02579 Mdot
.906 .02601 Mdot
.906 .02628 Mdot
.906 .02751 Mdot
.906 .02754 Mdot
.906 .02786 Mdot
.906 .02857 Mdot
.906 .02885 Mdot
.906 .02944 Mdot
.906 .02965 Mdot
.906 .02995 Mdot
.906 .03027 Mdot
.906 .03088 Mdot
.906 .03105 Mdot
.906 .03114 Mdot
.906 .03182 Mdot
.906 .03228 Mdot
.906 .03241 Mdot
.906 .03274 Mdot
.906 .03348 Mdot
.906 .03353 Mdot
.906 .03388 Mdot
.906 .03402 Mdot
.906 .03404 Mdot
.906 .03475 Mdot
.906 .03478 Mdot
.906 .03519 Mdot
.906 .03525 Mdot
.906 .03568 Mdot
.906 .03592 Mdot
.906 .03614 Mdot
.906 .0368 Mdot
.906 .03716 Mdot
.906 .0379 Mdot
.906 .03796 Mdot
.906 .03823 Mdot
.906 .03854 Mdot
.906 .03872 Mdot
.906 .03981 Mdot
.906 .0402 Mdot
.906 .04033 Mdot
.906 .04073 Mdot
.906 .04139 Mdot
.906 .04177 Mdot
.906 .04232 Mdot
.906 .04264 Mdot
.906 .04291 Mdot
.906 .04335 Mdot
.906 .04401 Mdot
.906 .04431 Mdot
.906 .04448 Mdot
.906 .04474 Mdot
.906 .04571 Mdot
.906 .04678 Mdot
.906 .04731 Mdot
.906 .04738 Mdot
.906 .04765 Mdot
.906 .04789 Mdot
.906 .04803 Mdot
.906 .04847 Mdot
.906 .04871 Mdot
.906 .0488 Mdot
.906 .04943 Mdot
.906 .04969 Mdot
.906 .04974 Mdot
.906 .05102 Mdot
.906 .05107 Mdot
.906 .05117 Mdot
.906 .05168 Mdot
.906 .05181 Mdot
.906 .05192 Mdot
.906 .0526 Mdot
.906 .0527 Mdot
.906 .05313 Mdot
.906 .05323 Mdot
.906 .05354 Mdot
.906 .05382 Mdot
.906 .05473 Mdot
.906 .05539 Mdot
.906 .05605 Mdot
.906 .05672 Mdot
.906 .05683 Mdot
.906 .05706 Mdot
.906 .05733 Mdot
.906 .0577 Mdot
.906 .05788 Mdot
.906 .05821 Mdot
.906 .0602 Mdot
.906 .06045 Mdot
.906 .06089 Mdot
.906 .06112 Mdot
.906 .06166 Mdot
.906 .06186 Mdot
.906 .06306 Mdot
.906 .06374 Mdot
.906 .06474 Mdot
.906 .06531 Mdot
.906 .06544 Mdot
.906 .0658 Mdot
.906 .0666 Mdot
.906 .0672 Mdot
.906 .0678 Mdot
.906 .06799 Mdot
.906 .06834 Mdot
.906 .06866 Mdot
.906 .06912 Mdot
.906 .07044 Mdot
.906 .07088 Mdot
.906 .07195 Mdot
.906 .07205 Mdot
.906 .07282 Mdot
.906 .07378 Mdot
.906 .0739 Mdot
.906 .07439 Mdot
.906 .07483 Mdot
.906 .07507 Mdot
.906 .07587 Mdot
.906 .07632 Mdot
.906 .07649 Mdot
.906 .07762 Mdot
.906 .07809 Mdot
.906 .07818 Mdot
.906 .0791 Mdot
.906 .07931 Mdot
.906 .07964 Mdot
.906 .07964 Mdot
.906 .0805 Mdot
.906 .0806 Mdot
.906 .08077 Mdot
.906 .08169 Mdot
.906 .08194 Mdot
.906 .08213 Mdot
.906 .0826 Mdot
.906 .08307 Mdot
.906 .08336 Mdot
.906 .08354 Mdot
.906 .08396 Mdot
.906 .08433 Mdot
.906 .08439 Mdot
.906 .0845 Mdot
.906 .08507 Mdot
.906 .08558 Mdot
.906 .08564 Mdot
.906 .08637 Mdot
.906 .08713 Mdot
.906 .08723 Mdot
.906 .08842 Mdot
.906 .08961 Mdot
.906 .09006 Mdot
.906 .09043 Mdot
.906 .09049 Mdot
.906 .09083 Mdot
.906 .09103 Mdot
.906 .09144 Mdot
.906 .09193 Mdot
.906 .0926 Mdot
.906 .09289 Mdot
.906 .09293 Mdot
.906 .09351 Mdot
.906 .09353 Mdot
.906 .09457 Mdot
.906 .09469 Mdot
.906 .09517 Mdot
.906 .09594 Mdot
.906 .09649 Mdot
.906 .09701 Mdot
.906 .09704 Mdot
.906 .09712 Mdot
.906 .09733 Mdot
.906 .09759 Mdot
.906 .09838 Mdot
.906 .09881 Mdot
.906 .09911 Mdot
.906 .09978 Mdot
.906 .10014 Mdot
.906 .10229 Mdot
.906 .10231 Mdot
.906 .10355 Mdot
.906 .10473 Mdot
.906 .10499 Mdot
.906 .10528 Mdot
.906 .10536 Mdot
.906 .10542 Mdot
.906 .10573 Mdot
.906 .10599 Mdot
.906 .1064 Mdot
.906 .10663 Mdot
.906 .10728 Mdot
.906 .10765 Mdot
.906 .10837 Mdot
.906 .10848 Mdot
.906 .10872 Mdot
.906 .10905 Mdot
.906 .10982 Mdot
.906 .1109 Mdot
.906 .11124 Mdot
.906 .11189 Mdot
.906 .11246 Mdot
.906 .11266 Mdot
.906 .1133 Mdot
.906 .11359 Mdot
.906 .11559 Mdot
.906 .11563 Mdot
.906 .11568 Mdot
.906 .11626 Mdot
.906 .11648 Mdot
.906 .11669 Mdot
.906 .11694 Mdot
.906 .11791 Mdot
.906 .11842 Mdot
.906 .11861 Mdot
.906 .11866 Mdot
.906 .1199 Mdot
.906 .11999 Mdot
.906 .12051 Mdot
.906 .12063 Mdot
.906 .12173 Mdot
.906 .12191 Mdot
.906 .12195 Mdot
.906 .12224 Mdot
.906 .12255 Mdot
.906 .12284 Mdot
.906 .12365 Mdot
.906 .12408 Mdot
.906 .12426 Mdot
.906 .12521 Mdot
.906 .12553 Mdot
.906 .12634 Mdot
.906 .12664 Mdot
.906 .12703 Mdot
.906 .12704 Mdot
.906 .12871 Mdot
.906 .12954 Mdot
.906 .12963 Mdot
.906 .12971 Mdot
.906 .1298 Mdot
.906 .13065 Mdot
.906 .13138 Mdot
.906 .13177 Mdot
.906 .13178 Mdot
.906 .13236 Mdot
.906 .13236 Mdot
.906 .13256 Mdot
.906 .13278 Mdot
.906 .13393 Mdot
.906 .13409 Mdot
.906 .13414 Mdot
.906 .1344 Mdot
.906 .13607 Mdot
.906 .13608 Mdot
.906 .13623 Mdot
.906 .13632 Mdot
.906 .13652 Mdot
.906 .13686 Mdot
.906 .13687 Mdot
.906 .137 Mdot
.906 .13772 Mdot
.906 .13824 Mdot
.906 .13857 Mdot
.906 .13911 Mdot
.906 .13927 Mdot
.906 .13943 Mdot
.906 .14019 Mdot
.906 .14085 Mdot
.906 .14096 Mdot
.906 .14116 Mdot
.906 .1422 Mdot
.906 .14241 Mdot
.906 .14304 Mdot
.906 .14312 Mdot
.906 .14323 Mdot
.906 .14455 Mdot
.906 .14485 Mdot
.906 .14545 Mdot
.906 .14565 Mdot
.906 .14594 Mdot
.906 .14611 Mdot
.906 .14687 Mdot
.906 .14713 Mdot
.906 .14722 Mdot
.906 .14828 Mdot
.906 .14895 Mdot
.906 .14946 Mdot
.906 .14964 Mdot
.906 .1501 Mdot
.906 .15031 Mdot
.906 .15043 Mdot
.906 .15079 Mdot
.906 .15124 Mdot
.906 .15191 Mdot
.906 .15202 Mdot
.906 .15263 Mdot
.906 .15295 Mdot
.906 .15296 Mdot
.906 .15299 Mdot
.906 .15373 Mdot
.906 .15464 Mdot
.906 .15583 Mdot
.906 .15597 Mdot
.906 .15637 Mdot
.906 .15644 Mdot
.906 .1567 Mdot
.906 .15713 Mdot
.906 .15749 Mdot
.906 .15752 Mdot
.906 .15941 Mdot
.906 .15964 Mdot
.906 .16049 Mdot
.906 .16089 Mdot
.906 .16112 Mdot
.906 .16189 Mdot
.906 .1621 Mdot
.906 .16259 Mdot
.906 .16288 Mdot
.906 .16309 Mdot
.906 .16364 Mdot
.906 .16383 Mdot
.906 .16389 Mdot
.906 .16404 Mdot
.906 .16441 Mdot
.906 .16489 Mdot
.906 .16631 Mdot
.906 .16709 Mdot
.906 .16764 Mdot
.906 .16805 Mdot
.906 .16869 Mdot
.906 .16885 Mdot
.906 .1695 Mdot
.906 .16975 Mdot
.906 .17077 Mdot
.906 .17304 Mdot
.906 .1734 Mdot
.906 .17344 Mdot
.906 .17435 Mdot
.906 .17534 Mdot
.906 .17538 Mdot
.906 .17568 Mdot
.906 .17672 Mdot
.906 .1768 Mdot
.906 .17783 Mdot
.906 .17829 Mdot
.906 .17882 Mdot
.906 .17886 Mdot
.906 .17888 Mdot
.906 .17897 Mdot
.906 .17908 Mdot
.906 .17941 Mdot
.906 .17954 Mdot
.906 .17963 Mdot
.906 .18005 Mdot
.906 .1801 Mdot
.906 .18066 Mdot
.906 .18085 Mdot
.906 .18127 Mdot
.906 .18134 Mdot
.906 .1822 Mdot
.906 .18244 Mdot
.906 .18263 Mdot
.906 .1831 Mdot
.906 .18373 Mdot
.906 .18442 Mdot
.906 .18462 Mdot
.906 .18473 Mdot
.906 .18506 Mdot
.906 .18566 Mdot
.906 .18582 Mdot
.906 .1864 Mdot
.906 .18704 Mdot
.906 .18817 Mdot
.906 .189 Mdot
.906 .18915 Mdot
.906 .18943 Mdot
.906 .18962 Mdot
.906 .18981 Mdot
.906 .19048 Mdot
.906 .19079 Mdot
.906 .19098 Mdot
.906 .19182 Mdot
.906 .19219 Mdot
.906 .19334 Mdot
.906 .19388 Mdot
.906 .1975 Mdot
.906 .19757 Mdot
.906 .19767 Mdot
.906 .19871 Mdot
.906 .19911 Mdot
.906 .1995 Mdot
.906 .19995 Mdot
.906 .20096 Mdot
.906 .20097 Mdot
.906 .2017 Mdot
.906 .20189 Mdot
.906 .20222 Mdot
.906 .2024 Mdot
.906 .20263 Mdot
.906 .20297 Mdot
.906 .20306 Mdot
.906 .2036 Mdot
.906 .20531 Mdot
.906 .20548 Mdot
.906 .20561 Mdot
.906 .20569 Mdot
.906 .20642 Mdot
.906 .20645 Mdot
.906 .20663 Mdot
.906 .20863 Mdot
.906 .20895 Mdot
.906 .20903 Mdot
.906 .20955 Mdot
.906 .21012 Mdot
.906 .21015 Mdot
.906 .21064 Mdot
.906 .21074 Mdot
.906 .21211 Mdot
.906 .21289 Mdot
.906 .21295 Mdot
.906 .2132 Mdot
.906 .21355 Mdot
.906 .21379 Mdot
.906 .21385 Mdot
.906 .21427 Mdot
.906 .21486 Mdot
.906 .2149 Mdot
.906 .21493 Mdot
.906 .21514 Mdot
.906 .21552 Mdot
.906 .21583 Mdot
.906 .21698 Mdot
.906 .21753 Mdot
.906 .21771 Mdot
.906 .21777 Mdot
.906 .21814 Mdot
.906 .21822 Mdot
.906 .21825 Mdot
.906 .21878 Mdot
.906 .21899 Mdot
.906 .21913 Mdot
.906 .21919 Mdot
.906 .22 Mdot
.906 .22092 Mdot
.906 .22127 Mdot
.906 .22242 Mdot
.906 .22278 Mdot
.906 .22293 Mdot
.906 .22308 Mdot
.906 .22325 Mdot
.906 .22479 Mdot
.906 .22542 Mdot
.906 .22611 Mdot
.906 .22651 Mdot
.906 .22682 Mdot
.906 .22683 Mdot
.906 .22789 Mdot
.906 .22789 Mdot
.906 .22809 Mdot
.906 .22825 Mdot
.906 .22864 Mdot
.906 .2289 Mdot
.906 .22904 Mdot
.906 .22937 Mdot
.906 .22968 Mdot
.906 .23001 Mdot
.906 .23018 Mdot
.906 .23072 Mdot
.906 .23102 Mdot
.906 .23111 Mdot
.906 .23122 Mdot
.906 .23158 Mdot
.906 .23462 Mdot
.906 .23462 Mdot
.906 .2349 Mdot
.906 .23506 Mdot
.906 .23542 Mdot
.906 .23604 Mdot
.906 .23606 Mdot
.906 .23629 Mdot
.906 .23742 Mdot
.906 .2376 Mdot
.906 .23855 Mdot
.906 .23867 Mdot
.906 .23915 Mdot
.906 .23972 Mdot
.906 .23974 Mdot
.906 .23985 Mdot
.906 .24011 Mdot
.906 .24015 Mdot
.906 .24042 Mdot
.906 .2407 Mdot
.906 .24115 Mdot
.906 .24207 Mdot
.906 .2424 Mdot
.906 .24288 Mdot
.906 .24313 Mdot
.906 .24327 Mdot
.906 .24336 Mdot
.906 .24347 Mdot
.906 .24352 Mdot
.906 .24384 Mdot
.906 .24572 Mdot
.906 .2461 Mdot
.906 .24724 Mdot
.906 .24739 Mdot
.906 .24758 Mdot
.906 .24998 Mdot
.906 .25052 Mdot
.906 .2514 Mdot
.906 .2516 Mdot
.906 .25198 Mdot
.906 .25249 Mdot
.906 .25281 Mdot
.906 .25318 Mdot
.906 .25417 Mdot
.906 .25421 Mdot
.906 .25459 Mdot
.906 .25465 Mdot
.906 .25482 Mdot
.906 .25545 Mdot
.906 .25605 Mdot
.906 .25672 Mdot
.906 .25673 Mdot
.906 .25795 Mdot
.906 .25796 Mdot
.906 .25888 Mdot
.906 .25921 Mdot
.906 .25964 Mdot
.906 .26004 Mdot
.906 .26041 Mdot
.906 .26063 Mdot
.906 .26068 Mdot
.906 .26127 Mdot
.906 .26192 Mdot
.906 .2621 Mdot
.906 .26332 Mdot
.906 .26352 Mdot
.906 .26462 Mdot
.906 .26517 Mdot
.906 .2652 Mdot
.906 .26521 Mdot
.906 .26527 Mdot
.906 .26528 Mdot
.906 .26654 Mdot
.906 .26655 Mdot
.906 .26661 Mdot
.906 .26671 Mdot
.906 .26728 Mdot
.906 .26825 Mdot
.906 .26936 Mdot
.906 .27042 Mdot
.906 .27067 Mdot
.906 .27132 Mdot
.906 .2714 Mdot
.906 .27151 Mdot
.906 .27198 Mdot
.906 .27276 Mdot
.906 .27343 Mdot
.906 .27348 Mdot
.906 .27353 Mdot
.906 .27355 Mdot
.906 .2769 Mdot
.906 .27732 Mdot
.906 .27757 Mdot
.906 .27759 Mdot
.906 .27886 Mdot
.906 .27959 Mdot
.906 .27999 Mdot
.906 .28061 Mdot
.906 .28139 Mdot
.906 .28169 Mdot
.906 .28178 Mdot
.906 .28267 Mdot
.906 .28312 Mdot
.906 .2832 Mdot
.906 .28357 Mdot
.906 .28441 Mdot
.906 .28457 Mdot
.906 .28491 Mdot
.906 .28502 Mdot
.906 .28529 Mdot
.906 .28563 Mdot
.906 .28597 Mdot
.906 .28636 Mdot
.906 .28652 Mdot
.906 .28683 Mdot
.906 .28848 Mdot
.906 .28941 Mdot
.906 .2906 Mdot
.906 .29082 Mdot
.906 .29118 Mdot
.906 .29181 Mdot
.906 .29256 Mdot
.906 .29372 Mdot
.906 .29401 Mdot
.906 .29518 Mdot
.906 .29519 Mdot
.906 .29563 Mdot
.906 .29584 Mdot
.906 .29749 Mdot
.906 .29947 Mdot
.906 .30127 Mdot
.906 .30137 Mdot
.906 .30141 Mdot
.906 .30159 Mdot
.906 .3016 Mdot
.906 .30164 Mdot
.906 .30225 Mdot
.906 .30232 Mdot
.906 .30397 Mdot
.906 .30577 Mdot
.906 .30577 Mdot
.906 .30579 Mdot
.906 .30584 Mdot
.906 .30601 Mdot
.906 .30634 Mdot
.906 .30638 Mdot
.906 .3082 Mdot
.906 .30827 Mdot
.906 .30841 Mdot
.906 .31028 Mdot
.906 .31111 Mdot
.906 .31139 Mdot
.906 .31207 Mdot
.906 .31214 Mdot
.906 .31219 Mdot
.906 .31234 Mdot
.906 .31255 Mdot
.906 .31314 Mdot
.906 .31337 Mdot
.906 .31355 Mdot
.906 .3143 Mdot
.906 .3144 Mdot
.906 .31504 Mdot
.906 .3154 Mdot
.906 .31575 Mdot
.906 .31651 Mdot
.906 .31663 Mdot
.906 .3182 Mdot
.906 .31852 Mdot
.906 .31864 Mdot
.906 .31898 Mdot
.906 .31932 Mdot
.906 .31984 Mdot
.906 .32097 Mdot
.906 .32145 Mdot
.906 .32173 Mdot
.906 .3221 Mdot
.906 .32222 Mdot
.906 .32258 Mdot
.906 .32279 Mdot
.906 .32338 Mdot
.906 .32364 Mdot
.906 .32446 Mdot
.906 .32475 Mdot
.906 .32581 Mdot
.906 .3262 Mdot
.906 .32697 Mdot
.906 .32838 Mdot
.906 .32857 Mdot
.906 .32871 Mdot
.906 .32878 Mdot
.906 .32902 Mdot
.906 .33051 Mdot
.906 .3308 Mdot
.906 .3313 Mdot
.906 .33165 Mdot
.906 .33198 Mdot
.906 .33321 Mdot
.906 .33376 Mdot
.906 .33412 Mdot
.906 .33564 Mdot
.906 .3363 Mdot
.906 .33839 Mdot
.906 .33936 Mdot
.906 .3398 Mdot
.906 .34115 Mdot
.906 .34198 Mdot
.906 .34204 Mdot
.906 .34593 Mdot
.906 .34605 Mdot
.906 .34623 Mdot
.906 .34623 Mdot
.906 .34812 Mdot
.906 .34861 Mdot
.906 .34885 Mdot
.906 .34954 Mdot
.906 .34994 Mdot
.906 .35036 Mdot
.906 .35198 Mdot
.906 .35218 Mdot
.906 .35222 Mdot
.906 .35354 Mdot
.906 .35388 Mdot
.906 .35447 Mdot
.906 .35453 Mdot
.906 .3548 Mdot
.906 .35522 Mdot
.906 .35552 Mdot
.906 .35581 Mdot
.906 .35583 Mdot
.906 .35599 Mdot
.906 .35697 Mdot
.906 .35873 Mdot
.906 .36008 Mdot
.906 .36021 Mdot
.906 .36038 Mdot
.906 .36046 Mdot
.906 .36063 Mdot
.906 .36077 Mdot
.906 .36168 Mdot
.906 .36208 Mdot
.906 .36214 Mdot
.906 .36246 Mdot
.906 .36445 Mdot
.906 .36496 Mdot
.906 .36607 Mdot
.906 .36609 Mdot
.906 .36644 Mdot
.906 .36667 Mdot
.906 .36681 Mdot
.906 .36735 Mdot
.906 .36776 Mdot
.906 .36845 Mdot
.906 .36878 Mdot
.906 .36885 Mdot
.906 .36955 Mdot
.906 .36974 Mdot
.906 .36991 Mdot
.906 .37085 Mdot
.906 .37138 Mdot
.906 .37238 Mdot
.906 .37239 Mdot
.906 .37381 Mdot
.906 .37391 Mdot
.906 .37438 Mdot
.906 .375 Mdot
.906 .37543 Mdot
.906 .37555 Mdot
.906 .3763 Mdot
.906 .37737 Mdot
.906 .37746 Mdot
.906 .3775 Mdot
.906 .3778 Mdot
.906 .37788 Mdot
.906 .37857 Mdot
.906 .37914 Mdot
.906 .38087 Mdot
.906 .38122 Mdot
.906 .38222 Mdot
.906 .38254 Mdot
.906 .38266 Mdot
.906 .38333 Mdot
.906 .38347 Mdot
.906 .38352 Mdot
.906 .38448 Mdot
.906 .38476 Mdot
.906 .38486 Mdot
.906 .38511 Mdot
.906 .38523 Mdot
.906 .38549 Mdot
.906 .38669 Mdot
.906 .38669 Mdot
.906 .38835 Mdot
.906 .38875 Mdot
.906 .38899 Mdot
.906 .39107 Mdot
.906 .39119 Mdot
.906 .39174 Mdot
.906 .39201 Mdot
.906 .39228 Mdot
.906 .39258 Mdot
.906 .39502 Mdot
.906 .39537 Mdot
.906 .39595 Mdot
.906 .39652 Mdot
.906 .39777 Mdot
.906 .39849 Mdot
.906 .39904 Mdot
.906 .39906 Mdot
.906 .3998 Mdot
.906 .39985 Mdot
.906 .40098 Mdot
.906 .401 Mdot
.906 .40129 Mdot
.906 .40136 Mdot
.906 .40164 Mdot
.906 .40197 Mdot
.906 .40235 Mdot
.906 .40283 Mdot
.906 .40307 Mdot
.906 .40367 Mdot
.906 .40422 Mdot
.906 .40482 Mdot
.906 .40514 Mdot
.906 .40612 Mdot
.906 .40666 Mdot
.906 .40682 Mdot
.906 .40702 Mdot
.906 .4074 Mdot
.906 .40768 Mdot
.906 .41318 Mdot
.906 .41319 Mdot
.906 .4137 Mdot
.906 .41387 Mdot
.906 .41397 Mdot
.906 .41464 Mdot
.906 .41575 Mdot
.906 .41579 Mdot
.906 .41621 Mdot
.906 .41825 Mdot
.906 .41858 Mdot
.906 .4198 Mdot
.906 .42013 Mdot
.906 .42026 Mdot
.906 .4203 Mdot
.906 .42052 Mdot
.906 .42085 Mdot
.906 .42088 Mdot
.906 .421 Mdot
.906 .42139 Mdot
.906 .42242 Mdot
.906 .42246 Mdot
.906 .42266 Mdot
.906 .42301 Mdot
.906 .42313 Mdot
.906 .42321 Mdot
.906 .42324 Mdot
.906 .42369 Mdot
.906 .42419 Mdot
.906 .42502 Mdot
.906 .42668 Mdot
.906 .42728 Mdot
.906 .42815 Mdot
.906 .4286 Mdot
.906 .42868 Mdot
.906 .42886 Mdot
.906 .42903 Mdot
.906 .42921 Mdot
.906 .42931 Mdot
.906 .42988 Mdot
.906 .4333 Mdot
.906 .43399 Mdot
.906 .43457 Mdot
.906 .43458 Mdot
.906 .43464 Mdot
.906 .43481 Mdot
.906 .43536 Mdot
.906 .43605 Mdot
.906 .43632 Mdot
.906 .43645 Mdot
.906 .43658 Mdot
.906 .43667 Mdot
.906 .44101 Mdot
.906 .442 Mdot
.906 .44257 Mdot
.906 .44278 Mdot
.906 .44325 Mdot
.906 .44358 Mdot
.906 .44395 Mdot
.906 .44464 Mdot
.906 .44557 Mdot
.906 .44614 Mdot
.906 .44682 Mdot
.906 .44862 Mdot
.906 .44868 Mdot
.906 .44937 Mdot
.906 .44938 Mdot
.906 .44947 Mdot
.906 .44978 Mdot
.906 .45093 Mdot
.906 .45201 Mdot
.906 .45323 Mdot
.906 .45324 Mdot
.906 .45546 Mdot
.906 .45547 Mdot
.906 .45714 Mdot
.906 .45774 Mdot
.906 .45852 Mdot
.906 .45924 Mdot
.906 .45991 Mdot
.906 .46031 Mdot
.906 .4604 Mdot
.906 .46148 Mdot
.906 .46265 Mdot
.906 .46297 Mdot
.906 .46519 Mdot
.906 .46554 Mdot
.906 .46754 Mdot
.906 .46854 Mdot
.906 .46859 Mdot
.906 .46862 Mdot
.906 .46872 Mdot
.906 .46874 Mdot
.906 .47102 Mdot
.906 .47103 Mdot
.906 .47115 Mdot
.906 .47134 Mdot
.906 .47237 Mdot
.906 .47412 Mdot
.906 .47614 Mdot
.906 .47806 Mdot
.906 .4785 Mdot
.906 .47968 Mdot
.906 .47983 Mdot
.906 .48003 Mdot
.906 .48089 Mdot
.906 .4823 Mdot
.906 .4835 Mdot
.906 .48361 Mdot
.906 .48368 Mdot
.906 .48372 Mdot
.906 .4898 Mdot
.906 .49055 Mdot
.906 .49101 Mdot
.906 .49104 Mdot
.906 .49335 Mdot
.906 .49467 Mdot
.906 .4954 Mdot
.906 .49652 Mdot
.906 .49793 Mdot
.906 .49848 Mdot
.906 .49864 Mdot
.906 .50025 Mdot
.906 .50107 Mdot
.906 .5012 Mdot
.906 .50188 Mdot
.906 .50341 Mdot
.906 .50369 Mdot
.906 .5043 Mdot
.906 .5045 Mdot
.906 .50501 Mdot
.906 .50561 Mdot
.906 .50622 Mdot
.906 .50694 Mdot
.906 .50723 Mdot
.906 .50778 Mdot
.906 .51078 Mdot
.906 .51247 Mdot
.906 .51462 Mdot
.906 .51502 Mdot
.906 .51568 Mdot
.906 .51682 Mdot
.906 .51816 Mdot
.906 .52028 Mdot
.906 .52079 Mdot
.906 .52292 Mdot
.906 .52294 Mdot
.906 .52374 Mdot
.906 .52412 Mdot
.906 .52711 Mdot
.906 .53068 Mdot
.906 .53395 Mdot
.906 .53413 Mdot
.906 .53421 Mdot
.906 .53453 Mdot
.906 .53455 Mdot
.906 .53462 Mdot
.906 .53573 Mdot
.906 .53585 Mdot
.906 .53885 Mdot
.906 .5421 Mdot
.906 .54211 Mdot
.906 .54214 Mdot
.906 .54224 Mdot
.906 .54254 Mdot
.906 .54314 Mdot
.906 .54321 Mdot
.906 .54652 Mdot
.906 .54663 Mdot
.906 .5469 Mdot
.906 .55028 Mdot
.908 .01486 Mdot
.908 .01498 Mdot
.908 .0152 Mdot
.908 .01559 Mdot
.908 .01631 Mdot
.908 .01645 Mdot
.908 .01758 Mdot
.908 .01761 Mdot
.908 .01787 Mdot
.908 .01794 Mdot
.908 .01902 Mdot
.908 .01931 Mdot
.908 .01991 Mdot
.908 .01997 Mdot
.908 .02044 Mdot
.908 .02058 Mdot
.908 .02072 Mdot
.908 .02083 Mdot
.908 .02096 Mdot
.908 .02253 Mdot
.908 .02253 Mdot
.908 .02296 Mdot
.908 .02305 Mdot
.908 .02305 Mdot
.908 .02413 Mdot
.908 .02415 Mdot
.908 .02427 Mdot
.908 .02429 Mdot
.908 .02457 Mdot
.908 .02482 Mdot
.908 .02485 Mdot
.908 .02512 Mdot
.908 .0253 Mdot
.908 .02537 Mdot
.908 .02561 Mdot
.908 .02582 Mdot
.908 .02606 Mdot
.908 .02654 Mdot
.908 .02732 Mdot
.908 .02733 Mdot
.908 .02748 Mdot
.908 .02758 Mdot
.908 .0289 Mdot
.908 .02891 Mdot
.908 .02891 Mdot
.908 .02969 Mdot
.908 .02985 Mdot
.908 .02986 Mdot
.908 .03004 Mdot
.908 .03014 Mdot
.908 .03097 Mdot
.908 .03107 Mdot
.908 .03143 Mdot
.908 .03181 Mdot
.908 .03184 Mdot
.908 .03206 Mdot
.908 .0321 Mdot
.908 .03255 Mdot
.908 .03261 Mdot
.908 .03265 Mdot
.908 .03307 Mdot
.908 .03312 Mdot
.908 .0336 Mdot
.908 .03394 Mdot
.908 .03406 Mdot
.908 .03451 Mdot
.908 .03488 Mdot
.908 .03532 Mdot
.908 .03581 Mdot
.908 .03619 Mdot
.908 .0376 Mdot
.908 .03763 Mdot
.908 .03789 Mdot
.908 .03808 Mdot
.908 .03893 Mdot
.908 .04047 Mdot
.908 .04048 Mdot
.908 .0405 Mdot
.908 .04053 Mdot
.908 .04129 Mdot
.908 .04191 Mdot
.908 .04221 Mdot
.908 .04221 Mdot
.908 .04254 Mdot
.908 .04273 Mdot
.908 .04424 Mdot
.908 .04442 Mdot
.908 .04507 Mdot
.908 .04574 Mdot
.908 .04575 Mdot
.908 .04582 Mdot
.908 .0461 Mdot
.908 .0462 Mdot
.908 .04621 Mdot
.908 .04629 Mdot
.908 .04711 Mdot
.908 .04721 Mdot
.908 .04729 Mdot
.908 .04794 Mdot
.908 .04804 Mdot
.908 .04815 Mdot
.908 .04819 Mdot
.908 .04845 Mdot
.908 .04847 Mdot
.908 .04861 Mdot
.908 .04901 Mdot
.908 .04928 Mdot
.908 .04963 Mdot
.908 .04984 Mdot
.908 .05066 Mdot
.908 .05134 Mdot
.908 .05214 Mdot
.908 .05233 Mdot
.908 .05302 Mdot
.908 .05349 Mdot
.908 .05371 Mdot
.908 .05628 Mdot
.908 .05633 Mdot
.908 .05655 Mdot
.908 .0568 Mdot
.908 .05715 Mdot
.908 .05869 Mdot
.908 .05892 Mdot
.908 .05912 Mdot
.908 .05971 Mdot
.908 .06083 Mdot
.908 .06149 Mdot
.908 .06151 Mdot
.908 .06154 Mdot
.908 .06159 Mdot
.908 .06296 Mdot
.908 .06298 Mdot
.908 .06335 Mdot
.908 .06368 Mdot
.908 .0641 Mdot
.908 .06451 Mdot
.908 .06464 Mdot
.908 .06465 Mdot
.908 .06502 Mdot
.908 .06525 Mdot
.908 .06558 Mdot
.908 .06716 Mdot
.908 .06833 Mdot
.908 .06866 Mdot
.908 .06923 Mdot
.908 .06985 Mdot
.908 .07021 Mdot
.908 .07062 Mdot
.908 .07106 Mdot
.908 .07108 Mdot
.908 .0712 Mdot
.908 .07171 Mdot
.908 .07189 Mdot
.908 .07191 Mdot
.908 .07206 Mdot
.908 .07281 Mdot
.908 .07355 Mdot
.908 .07359 Mdot
.908 .07373 Mdot
.908 .07387 Mdot
.908 .0744 Mdot
.908 .07506 Mdot
.908 .07524 Mdot
.908 .07543 Mdot
.908 .0755 Mdot
.908 .0756 Mdot
.908 .07598 Mdot
.908 .07602 Mdot
.908 .07627 Mdot
.908 .07694 Mdot
.908 .07699 Mdot
.908 .077 Mdot
.908 .07716 Mdot
.908 .07737 Mdot
.908 .07749 Mdot
.908 .07785 Mdot
.908 .07813 Mdot
.908 .0785 Mdot
.908 .0798 Mdot
.908 .07998 Mdot
.908 .08122 Mdot
.908 .08134 Mdot
.908 .08191 Mdot
.908 .08267 Mdot
.908 .08302 Mdot
.908 .08427 Mdot
.908 .08513 Mdot
.908 .08552 Mdot
.908 .08579 Mdot
.908 .08749 Mdot
.908 .08819 Mdot
.908 .08826 Mdot
.908 .08998 Mdot
.908 .08998 Mdot
.908 .0902 Mdot
.908 .09029 Mdot
.908 .09068 Mdot
.908 .09081 Mdot
.908 .09114 Mdot
.908 .09142 Mdot
.908 .09177 Mdot
.908 .09192 Mdot
.908 .0921 Mdot
.908 .09218 Mdot
.908 .09355 Mdot
.908 .09403 Mdot
.908 .0943 Mdot
.908 .09457 Mdot
.908 .095 Mdot
.908 .09527 Mdot
.908 .09535 Mdot
.908 .09643 Mdot
.908 .09669 Mdot
.908 .09707 Mdot
.908 .09767 Mdot
.908 .09846 Mdot
.908 .09938 Mdot
.908 .09958 Mdot
.908 .09965 Mdot
.908 .09966 Mdot
.908 .0997 Mdot
.908 .09975 Mdot
.908 .09979 Mdot
.908 .09984 Mdot
.908 .1002 Mdot
.908 .10032 Mdot
.908 .10147 Mdot
.908 .10233 Mdot
.908 .10237 Mdot
.908 .1028 Mdot
.908 .10304 Mdot
.908 .10363 Mdot
.908 .1044 Mdot
.908 .10491 Mdot
.908 .10514 Mdot
.908 .10538 Mdot
.908 .10539 Mdot
.908 .10575 Mdot
.908 .10595 Mdot
.908 .10607 Mdot
.908 .10648 Mdot
.908 .10709 Mdot
.908 .10961 Mdot
.908 .10963 Mdot
.908 .10996 Mdot
.908 .11015 Mdot
.908 .11207 Mdot
.908 .11269 Mdot
.908 .11364 Mdot
.908 .11371 Mdot
.908 .11454 Mdot
.908 .1148 Mdot
.908 .11484 Mdot
.908 .11492 Mdot
.908 .1155 Mdot
.908 .11624 Mdot
.908 .11664 Mdot
.908 .11703 Mdot
.908 .11708 Mdot
.908 .11718 Mdot
.908 .1173 Mdot
.908 .11762 Mdot
.908 .11812 Mdot
.908 .11822 Mdot
.908 .11854 Mdot
.908 .11855 Mdot
.908 .11858 Mdot
.908 .11886 Mdot
.908 .11943 Mdot
.908 .11957 Mdot
.908 .12022 Mdot
.908 .12022 Mdot
.908 .12031 Mdot
.908 .1211 Mdot
.908 .12156 Mdot
.908 .12164 Mdot
.908 .12171 Mdot
.908 .12188 Mdot
.908 .12214 Mdot
.908 .1231 Mdot
.908 .1243 Mdot
.908 .12463 Mdot
.908 .12497 Mdot
.908 .12503 Mdot
.908 .1251 Mdot
.908 .12529 Mdot
.908 .12598 Mdot
.908 .12604 Mdot
.908 .1265 Mdot
.908 .12685 Mdot
.908 .12771 Mdot
.908 .12781 Mdot
.908 .12783 Mdot
.908 .12811 Mdot
.908 .12849 Mdot
.908 .12871 Mdot
.908 .12911 Mdot
.908 .12936 Mdot
.908 .12987 Mdot
.908 .13028 Mdot
.908 .13055 Mdot
.908 .13291 Mdot
.908 .13324 Mdot
.908 .13404 Mdot
.908 .13548 Mdot
.908 .13571 Mdot
.908 .13602 Mdot
.908 .13675 Mdot
.908 .13806 Mdot
.908 .13812 Mdot
.908 .13842 Mdot
.908 .13876 Mdot
.908 .13882 Mdot
.908 .13996 Mdot
.908 .14096 Mdot
.908 .14103 Mdot
.908 .14213 Mdot
.908 .14259 Mdot
.908 .14311 Mdot
.908 .1433 Mdot
.908 .14379 Mdot
.908 .1441 Mdot
.908 .14421 Mdot
.908 .14436 Mdot
.908 .14445 Mdot
.908 .14688 Mdot
.908 .14725 Mdot
.908 .14815 Mdot
.908 .14827 Mdot
.908 .14891 Mdot
.908 .14932 Mdot
.908 .14961 Mdot
.908 .15014 Mdot
.908 .15139 Mdot
.908 .1514 Mdot
.908 .15179 Mdot
.908 .15196 Mdot
.908 .15267 Mdot
.908 .1529 Mdot
.908 .1535 Mdot
.908 .15401 Mdot
.908 .15432 Mdot
.908 .15446 Mdot
.908 .15465 Mdot
.908 .15493 Mdot
.908 .15505 Mdot
.908 .15516 Mdot
.908 .15525 Mdot
.908 .15539 Mdot
.908 .1566 Mdot
.908 .15685 Mdot
.908 .15685 Mdot
.908 .15788 Mdot
.908 .15818 Mdot
.908 .15837 Mdot
.908 .15876 Mdot
.908 .15916 Mdot
.908 .15923 Mdot
.908 .15973 Mdot
.908 .16044 Mdot
.908 .16051 Mdot
.908 .16099 Mdot
.908 .16115 Mdot
.908 .16284 Mdot
.908 .16312 Mdot
.908 .16337 Mdot
.908 .16358 Mdot
.908 .16426 Mdot
.908 .16437 Mdot
.908 .16535 Mdot
.908 .16615 Mdot
.908 .16679 Mdot
.908 .16741 Mdot
.908 .16847 Mdot
.908 .16884 Mdot
.908 .16895 Mdot
.908 .16898 Mdot
.908 .16905 Mdot
.908 .16914 Mdot
.908 .16922 Mdot
.908 .1693 Mdot
.908 .16988 Mdot
.908 .16995 Mdot
.908 .17018 Mdot
.908 .1715 Mdot
.908 .17227 Mdot
.908 .17382 Mdot
.908 .17389 Mdot
.908 .17467 Mdot
.908 .1749 Mdot
.908 .17511 Mdot
.908 .17618 Mdot
.908 .17653 Mdot
.908 .17758 Mdot
.908 .17851 Mdot
.908 .17884 Mdot
.908 .17893 Mdot
.908 .17935 Mdot
.908 .17939 Mdot
.908 .18004 Mdot
.908 .18006 Mdot
.908 .18039 Mdot
.908 .18044 Mdot
.908 .1806 Mdot
.908 .18061 Mdot
.908 .18075 Mdot
.908 .18112 Mdot
.908 .18136 Mdot
.908 .18218 Mdot
.908 .18246 Mdot
.908 .1826 Mdot
.908 .18297 Mdot
.908 .18393 Mdot
.908 .18488 Mdot
.908 .18559 Mdot
.908 .18705 Mdot
.908 .18708 Mdot
.908 .18761 Mdot
.908 .18768 Mdot
.908 .18781 Mdot
.908 .18802 Mdot
.908 .18894 Mdot
.908 .18929 Mdot
.908 .19022 Mdot
.908 .19094 Mdot
.908 .19152 Mdot
.908 .19228 Mdot
.908 .19238 Mdot
.908 .19263 Mdot
.908 .19344 Mdot
.908 .19436 Mdot
.908 .19449 Mdot
.908 .196 Mdot
.908 .19642 Mdot
.908 .19647 Mdot
.908 .19653 Mdot
.908 .19668 Mdot
.908 .19774 Mdot
.908 .19791 Mdot
.908 .19909 Mdot
.908 .19982 Mdot
.908 .20036 Mdot
.908 .20036 Mdot
.908 .20052 Mdot
.908 .20061 Mdot
.908 .20079 Mdot
.908 .20095 Mdot
.908 .201 Mdot
.908 .20102 Mdot
.908 .20159 Mdot
.908 .20167 Mdot
.908 .20239 Mdot
.908 .20251 Mdot
.908 .20269 Mdot
.908 .20321 Mdot
.908 .20327 Mdot
.908 .20329 Mdot
.908 .20333 Mdot
.908 .20349 Mdot
.908 .20384 Mdot
.908 .20424 Mdot
.908 .20489 Mdot
.908 .20514 Mdot
.908 .20631 Mdot
.908 .20632 Mdot
.908 .20647 Mdot
.908 .2078 Mdot
.908 .20792 Mdot
.908 .20861 Mdot
.908 .20874 Mdot
.908 .20889 Mdot
.908 .20902 Mdot
.908 .20933 Mdot
.908 .20953 Mdot
.908 .20955 Mdot
.908 .2098 Mdot
.908 .21154 Mdot
.908 .21372 Mdot
.908 .21432 Mdot
.908 .21494 Mdot
.908 .21504 Mdot
.908 .21517 Mdot
.908 .21551 Mdot
.908 .21617 Mdot
.908 .21647 Mdot
.908 .21677 Mdot
.908 .21685 Mdot
.908 .21687 Mdot
.908 .21772 Mdot
.908 .21823 Mdot
.908 .21835 Mdot
.908 .2186 Mdot
.908 .21987 Mdot
.908 .21991 Mdot
.908 .22009 Mdot
.908 .22012 Mdot
.908 .22063 Mdot
.908 .22063 Mdot
.908 .22104 Mdot
.908 .2211 Mdot
.908 .22133 Mdot
.908 .22172 Mdot
.908 .22245 Mdot
.908 .22291 Mdot
.908 .22345 Mdot
.908 .22384 Mdot
.908 .22459 Mdot
.908 .22508 Mdot
.908 .22784 Mdot
.908 .22844 Mdot
.908 .22913 Mdot
.908 .22935 Mdot
.908 .22996 Mdot
.908 .23002 Mdot
.908 .23138 Mdot
.908 .23141 Mdot
.908 .23263 Mdot
.908 .23309 Mdot
.908 .23383 Mdot
.908 .23383 Mdot
.908 .23401 Mdot
.908 .23403 Mdot
.908 .23422 Mdot
.908 .23444 Mdot
.908 .23478 Mdot
.908 .23501 Mdot
.908 .23633 Mdot
.908 .23662 Mdot
.908 .23871 Mdot
.908 .23883 Mdot
.908 .23936 Mdot
.908 .23998 Mdot
.908 .2401 Mdot
.908 .24083 Mdot
.908 .24216 Mdot
.908 .24234 Mdot
.908 .24255 Mdot
.908 .24282 Mdot
.908 .24323 Mdot
.908 .24361 Mdot
.908 .24398 Mdot
.908 .24403 Mdot
.908 .2441 Mdot
.908 .24482 Mdot
.908 .2461 Mdot
.908 .24662 Mdot
.908 .2467 Mdot
.908 .24694 Mdot
.908 .24707 Mdot
.908 .24786 Mdot
.908 .24788 Mdot
.908 .24823 Mdot
.908 .24912 Mdot
.908 .24967 Mdot
.908 .24987 Mdot
.908 .25015 Mdot
.908 .25032 Mdot
.908 .2508 Mdot
.908 .25261 Mdot
.908 .25327 Mdot
.908 .25418 Mdot
.908 .25473 Mdot
.908 .25474 Mdot
.908 .2554 Mdot
.908 .25634 Mdot
.908 .25704 Mdot
.908 .25724 Mdot
.908 .25842 Mdot
.908 .25871 Mdot
.908 .25916 Mdot
.908 .25968 Mdot
.908 .26065 Mdot
.908 .26229 Mdot
.908 .2625 Mdot
.908 .26291 Mdot
.908 .26293 Mdot
.908 .26364 Mdot
.908 .26396 Mdot
.908 .26448 Mdot
.908 .26454 Mdot
.908 .26524 Mdot
.908 .26566 Mdot
.908 .26674 Mdot
.908 .26748 Mdot
.908 .26767 Mdot
.908 .26824 Mdot
.908 .2685 Mdot
.908 .26884 Mdot
.908 .2693 Mdot
.908 .26932 Mdot
.908 .26934 Mdot
.908 .26956 Mdot
.908 .26977 Mdot
.908 .26993 Mdot
.908 .27017 Mdot
.908 .2715 Mdot
.908 .27237 Mdot
.908 .27283 Mdot
.908 .27283 Mdot
.908 .27461 Mdot
.908 .27471 Mdot
.908 .27525 Mdot
.908 .27559 Mdot
.908 .2763 Mdot
.908 .27689 Mdot
.908 .27703 Mdot
.908 .27716 Mdot
.908 .27758 Mdot
.908 .27806 Mdot
.908 .27935 Mdot
.908 .27947 Mdot
.908 .28036 Mdot
.908 .28064 Mdot
.908 .28147 Mdot
.908 .28243 Mdot
.908 .28371 Mdot
.908 .28391 Mdot
.908 .28421 Mdot
.908 .28468 Mdot
.908 .28506 Mdot
.908 .28561 Mdot
.908 .28629 Mdot
.908 .28649 Mdot
.908 .28827 Mdot
.908 .28882 Mdot
.908 .28972 Mdot
.908 .29088 Mdot
.908 .29202 Mdot
.908 .29394 Mdot
.908 .29421 Mdot
.908 .2946 Mdot
.908 .2948 Mdot
.908 .29487 Mdot
.908 .29492 Mdot
.908 .29498 Mdot
.908 .29516 Mdot
.908 .29529 Mdot
.908 .29545 Mdot
.908 .29628 Mdot
.908 .29634 Mdot
.908 .2965 Mdot
.908 .29662 Mdot
.908 .29704 Mdot
.908 .29867 Mdot
.908 .29943 Mdot
.908 .29972 Mdot
.908 .30083 Mdot
.908 .30145 Mdot
.908 .30165 Mdot
.908 .30366 Mdot
.908 .30378 Mdot
.908 .30394 Mdot
.908 .3052 Mdot
.908 .30535 Mdot
.908 .30562 Mdot
.908 .30599 Mdot
.908 .30794 Mdot
.908 .30857 Mdot
.908 .30891 Mdot
.908 .31048 Mdot
.908 .31135 Mdot
.908 .31197 Mdot
.908 .31217 Mdot
.908 .31276 Mdot
.908 .31292 Mdot
.908 .3137 Mdot
.908 .31376 Mdot
.908 .31384 Mdot
.908 .3147 Mdot
.908 .31494 Mdot
.908 .31499 Mdot
.908 .31558 Mdot
.908 .31567 Mdot
.908 .31582 Mdot
.908 .31596 Mdot
.908 .31598 Mdot
.908 .31623 Mdot
.908 .31691 Mdot
.908 .31734 Mdot
.908 .31735 Mdot
.908 .31742 Mdot
.908 .31748 Mdot
.908 .31821 Mdot
.908 .31883 Mdot
.908 .31889 Mdot
.908 .31935 Mdot
.908 .3194 Mdot
.908 .3196 Mdot
.908 .32022 Mdot
.908 .32027 Mdot
.908 .32201 Mdot
.908 .32373 Mdot
.908 .32461 Mdot
.908 .32503 Mdot
.908 .32748 Mdot
.908 .32768 Mdot
.908 .32773 Mdot
.908 .32869 Mdot
.908 .32883 Mdot
.908 .32897 Mdot
.908 .32898 Mdot
.908 .32906 Mdot
.908 .32943 Mdot
.908 .33111 Mdot
.908 .33175 Mdot
.908 .33343 Mdot
.908 .33474 Mdot
.908 .33485 Mdot
.908 .33518 Mdot
.908 .33579 Mdot
.908 .33696 Mdot
.908 .33718 Mdot
.908 .33736 Mdot
.908 .33782 Mdot
.908 .3381 Mdot
.908 .33928 Mdot
.908 .34041 Mdot
.908 .34096 Mdot
.908 .34118 Mdot
.908 .34239 Mdot
.908 .34282 Mdot
.908 .34326 Mdot
.908 .34392 Mdot
.908 .34466 Mdot
.908 .34469 Mdot
.908 .34478 Mdot
.908 .3449 Mdot
.908 .34516 Mdot
.908 .34623 Mdot
.908 .34709 Mdot
.908 .3474 Mdot
.908 .34954 Mdot
.908 .35047 Mdot
.908 .35086 Mdot
.908 .35089 Mdot
.908 .35184 Mdot
.908 .35184 Mdot
.908 .35214 Mdot
.908 .3523 Mdot
.908 .35263 Mdot
.908 .35291 Mdot
.908 .35301 Mdot
.908 .35305 Mdot
.908 .35381 Mdot
.908 .35407 Mdot
.908 .35422 Mdot
.908 .35475 Mdot
.908 .35554 Mdot
.908 .35574 Mdot
.908 .35607 Mdot
.908 .35702 Mdot
.908 .35713 Mdot
.908 .35716 Mdot
.908 .35725 Mdot
.908 .35747 Mdot
.908 .35754 Mdot
.908 .35817 Mdot
.908 .3589 Mdot
.908 .36006 Mdot
.908 .36053 Mdot
.908 .36063 Mdot
.908 .36265 Mdot
.908 .36266 Mdot
.908 .36295 Mdot
.908 .36487 Mdot
.908 .36537 Mdot
.908 .36551 Mdot
.908 .36557 Mdot
.908 .36652 Mdot
.908 .36682 Mdot
.908 .36706 Mdot
.908 .36734 Mdot
.908 .36758 Mdot
.908 .36806 Mdot
.908 .36814 Mdot
.908 .36849 Mdot
.908 .36854 Mdot
.908 .36898 Mdot
.908 .36932 Mdot
.908 .37114 Mdot
.908 .37214 Mdot
.908 .37339 Mdot
.908 .37403 Mdot
.908 .3761 Mdot
.908 .37719 Mdot
.908 .37832 Mdot
.908 .37851 Mdot
.908 .37874 Mdot
.908 .37936 Mdot
.908 .37991 Mdot
.908 .38056 Mdot
.908 .3811 Mdot
.908 .38164 Mdot
.908 .3817 Mdot
.908 .38179 Mdot
.908 .38184 Mdot
.908 .38338 Mdot
.908 .38429 Mdot
.908 .38452 Mdot
.908 .38468 Mdot
.908 .38497 Mdot
.908 .38727 Mdot
.908 .38735 Mdot
.908 .38767 Mdot
.908 .38774 Mdot
.908 .38853 Mdot
.908 .38866 Mdot
.908 .38866 Mdot
.908 .3894 Mdot
.908 .3895 Mdot
.908 .38994 Mdot
.908 .39064 Mdot
.908 .39196 Mdot
.908 .39226 Mdot
.908 .39281 Mdot
.908 .39378 Mdot
.908 .39448 Mdot
.908 .39584 Mdot
.908 .39673 Mdot
.908 .39861 Mdot
.908 .3995 Mdot
.908 .40077 Mdot
.908 .40145 Mdot
.908 .40165 Mdot
.908 .40174 Mdot
.908 .40182 Mdot
.908 .40203 Mdot
.908 .40261 Mdot
.908 .40285 Mdot
.908 .40305 Mdot
.908 .40358 Mdot
.908 .4041 Mdot
.908 .40449 Mdot
.908 .4056 Mdot
.908 .40571 Mdot
.908 .40634 Mdot
.908 .40653 Mdot
.908 .40704 Mdot
.908 .40744 Mdot
.908 .40818 Mdot
.908 .40823 Mdot
.908 .40881 Mdot
.908 .41045 Mdot
.908 .41128 Mdot
.908 .41262 Mdot
.908 .41262 Mdot
.908 .41295 Mdot
.908 .41299 Mdot
.908 .41334 Mdot
.908 .41374 Mdot
.908 .41419 Mdot
.908 .41435 Mdot
.908 .41476 Mdot
.908 .41672 Mdot
.908 .41716 Mdot
.908 .41767 Mdot
.908 .41769 Mdot
.908 .42133 Mdot
.908 .42149 Mdot
.908 .4217 Mdot
.908 .42267 Mdot
.908 .42337 Mdot
.908 .42379 Mdot
.908 .42401 Mdot
.908 .42404 Mdot
.908 .42534 Mdot
.908 .42775 Mdot
.908 .42809 Mdot
.908 .42847 Mdot
.908 .42896 Mdot
.908 .4297 Mdot
.908 .43039 Mdot
.908 .43064 Mdot
.908 .43105 Mdot
.908 .43105 Mdot
.908 .43115 Mdot
.908 .43127 Mdot
.908 .43158 Mdot
.908 .43259 Mdot
.908 .43491 Mdot
.908 .43574 Mdot
.908 .43586 Mdot
.908 .43601 Mdot
.908 .43623 Mdot
.908 .43644 Mdot
.908 .43667 Mdot
.908 .43711 Mdot
.908 .4381 Mdot
.908 .43814 Mdot
.908 .43834 Mdot
.908 .43878 Mdot
.908 .4404 Mdot
.908 .44139 Mdot
.908 .44176 Mdot
.908 .44226 Mdot
.908 .44257 Mdot
.908 .44345 Mdot
.908 .44476 Mdot
.908 .44672 Mdot
.908 .44684 Mdot
.908 .44793 Mdot
.908 .44797 Mdot
.908 .44959 Mdot
.908 .45059 Mdot
.908 .4506 Mdot
.908 .4518 Mdot
.908 .45351 Mdot
.908 .45477 Mdot
.908 .45515 Mdot
.908 .45729 Mdot
.908 .45781 Mdot
.908 .45863 Mdot
.908 .45957 Mdot
.908 .46133 Mdot
.908 .4643 Mdot
.908 .46469 Mdot
.908 .46545 Mdot
.908 .46548 Mdot
.908 .46676 Mdot
.908 .46734 Mdot
.908 .46829 Mdot
.908 .4684 Mdot
.908 .46966 Mdot
.908 .47044 Mdot
.908 .4724 Mdot
.908 .47374 Mdot
.908 .47408 Mdot
.908 .47511 Mdot
.908 .47559 Mdot
.908 .4762 Mdot
.908 .47704 Mdot
.908 .47709 Mdot
.908 .47712 Mdot
.908 .47752 Mdot
.908 .47789 Mdot
.908 .47818 Mdot
.908 .47863 Mdot
.908 .48104 Mdot
.908 .48262 Mdot
.908 .48345 Mdot
.908 .48345 Mdot
.908 .48668 Mdot
.908 .48686 Mdot
.908 .48785 Mdot
.908 .48847 Mdot
.908 .48975 Mdot
.908 .49083 Mdot
.908 .49107 Mdot
.908 .49131 Mdot
.908 .49208 Mdot
.908 .49295 Mdot
.908 .49528 Mdot
.908 .49552 Mdot
.908 .49712 Mdot
.908 .49764 Mdot
.908 .49914 Mdot
.908 .50088 Mdot
.908 .50321 Mdot
.908 .50356 Mdot
.908 .50412 Mdot
.908 .50497 Mdot
.908 .50566 Mdot
.908 .50667 Mdot
.908 .5079 Mdot
.908 .50826 Mdot
.908 .5115 Mdot
.908 .51248 Mdot
.908 .51412 Mdot
.908 .51624 Mdot
.908 .51829 Mdot
.908 .52179 Mdot
.908 .52228 Mdot
.908 .52298 Mdot
.908 .52335 Mdot
.908 .52347 Mdot
.908 .52356 Mdot
.908 .52367 Mdot
.908 .524 Mdot
.908 .52424 Mdot
.908 .52453 Mdot
.908 .52605 Mdot
.908 .52615 Mdot
.908 .52643 Mdot
.908 .52665 Mdot
.908 .52741 Mdot
.908 .53037 Mdot
.908 .53177 Mdot
.908 .53229 Mdot
.908 .5343 Mdot
.908 .53542 Mdot
.908 .5358 Mdot
.908 .53943 Mdot
.908 .53966 Mdot
.908 .53995 Mdot
.908 .54224 Mdot
.908 .54251 Mdot
.908 .54299 Mdot
.908 .54367 Mdot
.908 .5472 Mdot
.908 .54835 Mdot
.908 .54897 Mdot
.91 .01494 Mdot
.91 .01513 Mdot
.91 .01547 Mdot
.91 .01608 Mdot
.91 .01721 Mdot
.91 .0174 Mdot
.91 .01836 Mdot
.91 .01861 Mdot
.91 .01865 Mdot
.91 .019 Mdot
.91 .01918 Mdot
.91 .01925 Mdot
.91 .0196 Mdot
.91 .02069 Mdot
.91 .0211 Mdot
.91 .02122 Mdot
.91 .02136 Mdot
.91 .02181 Mdot
.91 .02184 Mdot
.91 .02187 Mdot
.91 .02252 Mdot
.91 .02254 Mdot
.91 .0227 Mdot
.91 .02284 Mdot
.91 .02289 Mdot
.91 .02297 Mdot
.91 .02306 Mdot
.91 .02313 Mdot
.91 .02361 Mdot
.91 .02377 Mdot
.91 .0238 Mdot
.91 .02485 Mdot
.91 .02558 Mdot
.91 .02585 Mdot
.91 .02616 Mdot
.91 .02633 Mdot
.91 .02655 Mdot
.91 .02676 Mdot
.91 .0268 Mdot
.91 .02711 Mdot
.91 .02756 Mdot
.91 .02756 Mdot
.91 .02762 Mdot
.91 .02769 Mdot
.91 .02774 Mdot
.91 .02845 Mdot
.91 .02861 Mdot
.91 .02892 Mdot
.91 .02895 Mdot
.91 .02925 Mdot
.91 .0295 Mdot
.91 .0296 Mdot
.91 .02963 Mdot
.91 .02974 Mdot
.91 .0299 Mdot
.91 .03004 Mdot
.91 .0309 Mdot
.91 .0312 Mdot
.91 .03126 Mdot
.91 .032 Mdot
.91 .03317 Mdot
.91 .03349 Mdot
.91 .03449 Mdot
.91 .03498 Mdot
.91 .03549 Mdot
.91 .03555 Mdot
.91 .03585 Mdot
.91 .03625 Mdot
.91 .03664 Mdot
.91 .03671 Mdot
.91 .03708 Mdot
.91 .03728 Mdot
.91 .03788 Mdot
.91 .0381 Mdot
.91 .0381 Mdot
.91 .0382 Mdot
.91 .03833 Mdot
.91 .03842 Mdot
.91 .03902 Mdot
.91 .03972 Mdot
.91 .04001 Mdot
.91 .04002 Mdot
.91 .04057 Mdot
.91 .04063 Mdot
.91 .04117 Mdot
.91 .04163 Mdot
.91 .0418 Mdot
.91 .04186 Mdot
.91 .04206 Mdot
.91 .04236 Mdot
.91 .0426 Mdot
.91 .04313 Mdot
.91 .04342 Mdot
.91 .04392 Mdot
.91 .04394 Mdot
.91 .04401 Mdot
.91 .04417 Mdot
.91 .04472 Mdot
.91 .04482 Mdot
.91 .04587 Mdot
.91 .04617 Mdot
.91 .04792 Mdot
.91 .04824 Mdot
.91 .0483 Mdot
.91 .04848 Mdot
.91 .04889 Mdot
.91 .04987 Mdot
.91 .05014 Mdot
.91 .05062 Mdot
.91 .05071 Mdot
.91 .05159 Mdot
.91 .05171 Mdot
.91 .05252 Mdot
.91 .05264 Mdot
.91 .05319 Mdot
.91 .0538 Mdot
.91 .05392 Mdot
.91 .05462 Mdot
.91 .05475 Mdot
.91 .05541 Mdot
.91 .05578 Mdot
.91 .05665 Mdot
.91 .05688 Mdot
.91 .05727 Mdot
.91 .05727 Mdot
.91 .05746 Mdot
.91 .0577 Mdot
.91 .05785 Mdot
.91 .05835 Mdot
.91 .05894 Mdot
.91 .05929 Mdot
.91 .05965 Mdot
.91 .0598 Mdot
.91 .06008 Mdot
.91 .06022 Mdot
.91 .06074 Mdot
.91 .06077 Mdot
.91 .06127 Mdot
.91 .06158 Mdot
.91 .06178 Mdot
.91 .06187 Mdot
.91 .06287 Mdot
.91 .06317 Mdot
.91 .0637 Mdot
.91 .06401 Mdot
.91 .06412 Mdot
.91 .06434 Mdot
.91 .06449 Mdot
.91 .06481 Mdot
.91 .06489 Mdot
.91 .06503 Mdot
.91 .06547 Mdot
.91 .06638 Mdot
.91 .06643 Mdot
.91 .06697 Mdot
.91 .06786 Mdot
.91 .06787 Mdot
.91 .0679 Mdot
.91 .06803 Mdot
.91 .06833 Mdot
.91 .06901 Mdot
.91 .06933 Mdot
.91 .06951 Mdot
.91 .07013 Mdot
.91 .07133 Mdot
.91 .07142 Mdot
.91 .07196 Mdot
.91 .07208 Mdot
.91 .07233 Mdot
.91 .07246 Mdot
.91 .07415 Mdot
.91 .07498 Mdot
.91 .07514 Mdot
.91 .07531 Mdot
.91 .07574 Mdot
.91 .07578 Mdot
.91 .07584 Mdot
.91 .07608 Mdot
.91 .07617 Mdot
.91 .07691 Mdot
.91 .0778 Mdot
.91 .0782 Mdot
.91 .07869 Mdot
.91 .07918 Mdot
.91 .07926 Mdot
.91 .07977 Mdot
.91 .08006 Mdot
.91 .08023 Mdot
.91 .08054 Mdot
.91 .08135 Mdot
.91 .08183 Mdot
.91 .08205 Mdot
.91 .08311 Mdot
.91 .08352 Mdot
.91 .08374 Mdot
.91 .08454 Mdot
.91 .08474 Mdot
.91 .08514 Mdot
.91 .08575 Mdot
.91 .08585 Mdot
.91 .08606 Mdot
.91 .08734 Mdot
.91 .08758 Mdot
.91 .08878 Mdot
.91 .08919 Mdot
.91 .08921 Mdot
.91 .08946 Mdot
.91 .08946 Mdot
.91 .09093 Mdot
.91 .09104 Mdot
.91 .09135 Mdot
.91 .09146 Mdot
.91 .09158 Mdot
.91 .09217 Mdot
.91 .09217 Mdot
.91 .09237 Mdot
.91 .09251 Mdot
.91 .09294 Mdot
.91 .09304 Mdot
.91 .09322 Mdot
.91 .09378 Mdot
.91 .09389 Mdot
.91 .09414 Mdot
.91 .09521 Mdot
.91 .09584 Mdot
.91 .09649 Mdot
.91 .09678 Mdot
.91 .09728 Mdot
.91 .09753 Mdot
.91 .09773 Mdot
.91 .09849 Mdot
.91 .09853 Mdot
.91 .09877 Mdot
.91 .09897 Mdot
.91 .09944 Mdot
.91 .1 Mdot
.91 .10037 Mdot
.91 .10054 Mdot
.91 .10235 Mdot
.91 .10291 Mdot
.91 .10387 Mdot
.91 .10402 Mdot
.91 .10443 Mdot
.91 .10459 Mdot
.91 .10463 Mdot
.91 .10463 Mdot
.91 .10504 Mdot
.91 .1053 Mdot
.91 .10538 Mdot
.91 .10588 Mdot
.91 .10598 Mdot
.91 .10604 Mdot
.91 .10628 Mdot
.91 .10709 Mdot
.91 .10869 Mdot
.91 .10874 Mdot
.91 .10884 Mdot
.91 .10981 Mdot
.91 .11012 Mdot
.91 .11143 Mdot
.91 .11146 Mdot
.91 .11151 Mdot
.91 .11175 Mdot
.91 .11229 Mdot
.91 .11255 Mdot
.91 .1128 Mdot
.91 .11354 Mdot
.91 .11411 Mdot
.91 .11444 Mdot
.91 .11556 Mdot
.91 .11566 Mdot
.91 .11576 Mdot
.91 .11633 Mdot
.91 .11673 Mdot
.91 .11711 Mdot
.91 .11775 Mdot
.91 .11792 Mdot
.91 .11889 Mdot
.91 .11902 Mdot
.91 .11912 Mdot
.91 .11957 Mdot
.91 .1198 Mdot
.91 .12289 Mdot
.91 .12388 Mdot
.91 .12441 Mdot
.91 .12469 Mdot
.91 .12501 Mdot
.91 .12578 Mdot
.91 .12586 Mdot
.91 .12597 Mdot
.91 .1264 Mdot
.91 .12656 Mdot
.91 .12706 Mdot
.91 .12729 Mdot
.91 .12791 Mdot
.91 .12871 Mdot
.91 .12953 Mdot
.91 .13019 Mdot
.91 .13026 Mdot
.91 .13115 Mdot
.91 .13205 Mdot
.91 .1322 Mdot
.91 .1327 Mdot
.91 .13311 Mdot
.91 .13341 Mdot
.91 .13365 Mdot
.91 .13395 Mdot
.91 .13452 Mdot
.91 .13467 Mdot
.91 .13583 Mdot
.91 .13599 Mdot
.91 .13604 Mdot
.91 .13687 Mdot
.91 .13726 Mdot
.91 .13785 Mdot
.91 .13893 Mdot
.91 .13894 Mdot
.91 .1392 Mdot
.91 .13957 Mdot
.91 .13993 Mdot
.91 .14022 Mdot
.91 .14034 Mdot
.91 .1411 Mdot
.91 .14148 Mdot
.91 .1418 Mdot
.91 .14216 Mdot
.91 .14289 Mdot
.91 .144 Mdot
.91 .14418 Mdot
.91 .14457 Mdot
.91 .14596 Mdot
.91 .14611 Mdot
.91 .14659 Mdot
.91 .14689 Mdot
.91 .14726 Mdot
.91 .14732 Mdot
.91 .14907 Mdot
.91 .14951 Mdot
.91 .14985 Mdot
.91 .15027 Mdot
.91 .15029 Mdot
.91 .15074 Mdot
.91 .15075 Mdot
.91 .15082 Mdot
.91 .15086 Mdot
.91 .15207 Mdot
.91 .15293 Mdot
.91 .15342 Mdot
.91 .15362 Mdot
.91 .15386 Mdot
.91 .15404 Mdot
.91 .1542 Mdot
.91 .1542 Mdot
.91 .15439 Mdot
.91 .1546 Mdot
.91 .15492 Mdot
.91 .15524 Mdot
.91 .15569 Mdot
.91 .15569 Mdot
.91 .15605 Mdot
.91 .1563 Mdot
.91 .15709 Mdot
.91 .15727 Mdot
.91 .1576 Mdot
.91 .15862 Mdot
.91 .15881 Mdot
.91 .15896 Mdot
.91 .15926 Mdot
.91 .16117 Mdot
.91 .16122 Mdot
.91 .16236 Mdot
.91 .16355 Mdot
.91 .16378 Mdot
.91 .16407 Mdot
.91 .16435 Mdot
.91 .16499 Mdot
.91 .16544 Mdot
.91 .16581 Mdot
.91 .16718 Mdot
.91 .16726 Mdot
.91 .1677 Mdot
.91 .16806 Mdot
.91 .16876 Mdot
.91 .16891 Mdot
.91 .16994 Mdot
.91 .16999 Mdot
.91 .17061 Mdot
.91 .17092 Mdot
.91 .17093 Mdot
.91 .17271 Mdot
.91 .17317 Mdot
.91 .17421 Mdot
.91 .17425 Mdot
.91 .17453 Mdot
.91 .17479 Mdot
.91 .17522 Mdot
.91 .1757 Mdot
.91 .17698 Mdot
.91 .17725 Mdot
.91 .17799 Mdot
.91 .17828 Mdot
.91 .17835 Mdot
.91 .17836 Mdot
.91 .17853 Mdot
.91 .1791 Mdot
.91 .17933 Mdot
.91 .17959 Mdot
.91 .1797 Mdot
.91 .17972 Mdot
.91 .17991 Mdot
.91 .18024 Mdot
.91 .18063 Mdot
.91 .18081 Mdot
.91 .18092 Mdot
.91 .18137 Mdot
.91 .18285 Mdot
.91 .18393 Mdot
.91 .18482 Mdot
.91 .18576 Mdot
.91 .18584 Mdot
.91 .18602 Mdot
.91 .1873 Mdot
.91 .18737 Mdot
.91 .18779 Mdot
.91 .18787 Mdot
.91 .18835 Mdot
.91 .18898 Mdot
.91 .19035 Mdot
.91 .19074 Mdot
.91 .19079 Mdot
.91 .19087 Mdot
.91 .19132 Mdot
.91 .19181 Mdot
.91 .19216 Mdot
.91 .1923 Mdot
.91 .19277 Mdot
.91 .19322 Mdot
.91 .19357 Mdot
.91 .1945 Mdot
.91 .19457 Mdot
.91 .19537 Mdot
.91 .19547 Mdot
.91 .19561 Mdot
.91 .19622 Mdot
.91 .19666 Mdot
.91 .19705 Mdot
.91 .19826 Mdot
.91 .19844 Mdot
.91 .19862 Mdot
.91 .19966 Mdot
.91 .19967 Mdot
.91 .19974 Mdot
.91 .20018 Mdot
.91 .20031 Mdot
.91 .20038 Mdot
.91 .20082 Mdot
.91 .20105 Mdot
.91 .20108 Mdot
.91 .20224 Mdot
.91 .20255 Mdot
.91 .20261 Mdot
.91 .20432 Mdot
.91 .20455 Mdot
.91 .20473 Mdot
.91 .20555 Mdot
.91 .20598 Mdot
.91 .20671 Mdot
.91 .20765 Mdot
.91 .20768 Mdot
.91 .20797 Mdot
.91 .20867 Mdot
.91 .21013 Mdot
.91 .21109 Mdot
.91 .21116 Mdot
.91 .21159 Mdot
.91 .21301 Mdot
.91 .21339 Mdot
.91 .21435 Mdot
.91 .21487 Mdot
.91 .21533 Mdot
.91 .21545 Mdot
.91 .21685 Mdot
.91 .21699 Mdot
.91 .21719 Mdot
.91 .21774 Mdot
.91 .21797 Mdot
.91 .21827 Mdot
.91 .2189 Mdot
.91 .21918 Mdot
.91 .21924 Mdot
.91 .21929 Mdot
.91 .2196 Mdot
.91 .22072 Mdot
.91 .22139 Mdot
.91 .22218 Mdot
.91 .22368 Mdot
.91 .22487 Mdot
.91 .22501 Mdot
.91 .22534 Mdot
.91 .22542 Mdot
.91 .2255 Mdot
.91 .22663 Mdot
.91 .22705 Mdot
.91 .22826 Mdot
.91 .22853 Mdot
.91 .2293 Mdot
.91 .22945 Mdot
.91 .2302 Mdot
.91 .23064 Mdot
.91 .23075 Mdot
.91 .23117 Mdot
.91 .23145 Mdot
.91 .23172 Mdot
.91 .23175 Mdot
.91 .23304 Mdot
.91 .23317 Mdot
.91 .2339 Mdot
.91 .23514 Mdot
.91 .23543 Mdot
.91 .23552 Mdot
.91 .23573 Mdot
.91 .23617 Mdot
.91 .23704 Mdot
.91 .23774 Mdot
.91 .23847 Mdot
.91 .23882 Mdot
.91 .23892 Mdot
.91 .23894 Mdot
.91 .24076 Mdot
.91 .24079 Mdot
.91 .24081 Mdot
.91 .24128 Mdot
.91 .24196 Mdot
.91 .24261 Mdot
.91 .2427 Mdot
.91 .24313 Mdot
.91 .24335 Mdot
.91 .24403 Mdot
.91 .24473 Mdot
.91 .24486 Mdot
.91 .24487 Mdot
.91 .24542 Mdot
.91 .246 Mdot
.91 .24641 Mdot
.91 .24666 Mdot
.91 .24712 Mdot
.91 .24762 Mdot
.91 .24799 Mdot
.91 .24806 Mdot
.91 .24928 Mdot
.91 .24952 Mdot
.91 .25002 Mdot
.91 .25034 Mdot
.91 .25065 Mdot
.91 .25104 Mdot
.91 .25347 Mdot
.91 .25356 Mdot
.91 .25358 Mdot
.91 .25386 Mdot
.91 .25433 Mdot
.91 .25473 Mdot
.91 .25527 Mdot
.91 .25595 Mdot
.91 .25601 Mdot
.91 .25606 Mdot
.91 .25706 Mdot
.91 .25808 Mdot
.91 .25826 Mdot
.91 .25925 Mdot
.91 .25939 Mdot
.91 .26005 Mdot
.91 .26067 Mdot
.91 .26142 Mdot
.91 .26146 Mdot
.91 .26228 Mdot
.91 .2623 Mdot
.91 .26243 Mdot
.91 .2625 Mdot
.91 .26352 Mdot
.91 .2647 Mdot
.91 .26627 Mdot
.91 .26715 Mdot
.91 .26743 Mdot
.91 .26752 Mdot
.91 .26774 Mdot
.91 .2678 Mdot
.91 .26795 Mdot
.91 .26829 Mdot
.91 .26857 Mdot
.91 .26857 Mdot
.91 .26872 Mdot
.91 .26892 Mdot
.91 .26931 Mdot
.91 .26989 Mdot
.91 .27029 Mdot
.91 .27047 Mdot
.91 .27129 Mdot
.91 .27129 Mdot
.91 .27161 Mdot
.91 .27195 Mdot
.91 .2724 Mdot
.91 .2734 Mdot
.91 .27384 Mdot
.91 .27416 Mdot
.91 .27477 Mdot
.91 .27563 Mdot
.91 .27583 Mdot
.91 .27602 Mdot
.91 .2763 Mdot
.91 .27662 Mdot
.91 .27697 Mdot
.91 .27723 Mdot
.91 .2775 Mdot
.91 .27779 Mdot
.91 .27932 Mdot
.91 .28126 Mdot
.91 .28135 Mdot
.91 .28271 Mdot
.91 .2833 Mdot
.91 .28343 Mdot
.91 .2856 Mdot
.91 .28601 Mdot
.91 .28653 Mdot
.91 .28657 Mdot
.91 .28705 Mdot
.91 .28705 Mdot
.91 .28821 Mdot
.91 .28903 Mdot
.91 .28923 Mdot
.91 .2897 Mdot
.91 .29126 Mdot
.91 .2922 Mdot
.91 .29235 Mdot
.91 .29315 Mdot
.91 .29375 Mdot
.91 .29381 Mdot
.91 .2939 Mdot
.91 .29507 Mdot
.91 .29535 Mdot
.91 .29662 Mdot
.91 .29669 Mdot
.91 .29712 Mdot
.91 .29723 Mdot
.91 .29731 Mdot
.91 .29735 Mdot
.91 .29845 Mdot
.91 .29902 Mdot
.91 .29903 Mdot
.91 .30072 Mdot
.91 .30226 Mdot
.91 .3031 Mdot
.91 .30462 Mdot
.91 .30499 Mdot
.91 .30508 Mdot
.91 .30558 Mdot
.91 .30605 Mdot
.91 .30684 Mdot
.91 .30771 Mdot
.91 .30983 Mdot
.91 .31003 Mdot
.91 .31052 Mdot
.91 .31187 Mdot
.91 .3124 Mdot
.91 .31254 Mdot
.91 .31256 Mdot
.91 .31275 Mdot
.91 .31285 Mdot
.91 .31368 Mdot
.91 .3139 Mdot
.91 .31397 Mdot
.91 .31431 Mdot
.91 .31469 Mdot
.91 .31478 Mdot
.91 .31489 Mdot
.91 .31498 Mdot
.91 .31502 Mdot
.91 .31537 Mdot
.91 .31539 Mdot
.91 .31597 Mdot
.91 .31651 Mdot
.91 .31669 Mdot
.91 .31702 Mdot
.91 .31721 Mdot
.91 .31746 Mdot
.91 .31746 Mdot
.91 .31794 Mdot
.91 .31803 Mdot
.91 .31859 Mdot
.91 .31989 Mdot
.91 .32071 Mdot
.91 .32181 Mdot
.91 .32268 Mdot
.91 .32313 Mdot
.91 .32375 Mdot
.91 .3243 Mdot
.91 .32601 Mdot
.91 .32617 Mdot
.91 .32644 Mdot
.91 .32645 Mdot
.91 .32649 Mdot
.91 .32752 Mdot
.91 .32864 Mdot
.91 .32882 Mdot
.91 .32895 Mdot
.91 .32971 Mdot
.91 .32986 Mdot
.91 .33012 Mdot
.91 .33072 Mdot
.91 .33187 Mdot
.91 .33344 Mdot
.91 .33437 Mdot
.91 .33489 Mdot
.91 .33508 Mdot
.91 .33517 Mdot
.91 .33532 Mdot
.91 .33597 Mdot
.91 .33614 Mdot
.91 .33702 Mdot
.91 .33766 Mdot
.91 .33792 Mdot
.91 .33797 Mdot
.91 .33878 Mdot
.91 .33959 Mdot
.91 .34023 Mdot
.91 .34084 Mdot
.91 .3415 Mdot
.91 .34192 Mdot
.91 .34205 Mdot
.91 .34212 Mdot
.91 .34305 Mdot
.91 .34351 Mdot
.91 .34369 Mdot
.91 .34395 Mdot
.91 .34411 Mdot
.91 .34506 Mdot
.91 .34528 Mdot
.91 .34586 Mdot
.91 .34614 Mdot
.91 .34656 Mdot
.91 .34701 Mdot
.91 .34798 Mdot
.91 .34876 Mdot
.91 .34909 Mdot
.91 .34943 Mdot
.91 .35132 Mdot
.91 .35133 Mdot
.91 .35146 Mdot
.91 .35227 Mdot
.91 .35251 Mdot
.91 .35263 Mdot
.91 .35307 Mdot
.91 .35343 Mdot
.91 .35384 Mdot
.91 .3539 Mdot
.91 .35601 Mdot
.91 .35658 Mdot
.91 .35669 Mdot
.91 .35946 Mdot
.91 .35978 Mdot
.91 .3598 Mdot
.91 .36021 Mdot
.91 .36054 Mdot
.91 .36203 Mdot
.91 .36281 Mdot
.91 .36415 Mdot
.91 .36429 Mdot
.91 .36586 Mdot
.91 .36592 Mdot
.91 .36623 Mdot
.91 .36645 Mdot
.91 .36666 Mdot
.91 .36771 Mdot
.91 .37038 Mdot
.91 .37212 Mdot
.91 .37225 Mdot
.91 .37303 Mdot
.91 .37384 Mdot
.91 .37522 Mdot
.91 .37562 Mdot
.91 .37631 Mdot
.91 .37694 Mdot
.91 .37706 Mdot
.91 .37805 Mdot
.91 .37865 Mdot
.91 .37865 Mdot
.91 .379 Mdot
.91 .37984 Mdot
.91 .38005 Mdot
.91 .38251 Mdot
.91 .38259 Mdot
.91 .38286 Mdot
.91 .38322 Mdot
.91 .38422 Mdot
.91 .38465 Mdot
.91 .38518 Mdot
.91 .3852 Mdot
.91 .38586 Mdot
.91 .38634 Mdot
.91 .38685 Mdot
.91 .38695 Mdot
.91 .38703 Mdot
.91 .38743 Mdot
.91 .38761 Mdot
.91 .38965 Mdot
.91 .39086 Mdot
.91 .3923 Mdot
.91 .39261 Mdot
.91 .39503 Mdot
.91 .39571 Mdot
.91 .39623 Mdot
.91 .3972 Mdot
.91 .39746 Mdot
.91 .39806 Mdot
.91 .39821 Mdot
.91 .39835 Mdot
.91 .39885 Mdot
.91 .4004 Mdot
.91 .40084 Mdot
.91 .40105 Mdot
.91 .40116 Mdot
.91 .40134 Mdot
.91 .40337 Mdot
.91 .40386 Mdot
.91 .40522 Mdot
.91 .40526 Mdot
.91 .40554 Mdot
.91 .40614 Mdot
.91 .4069 Mdot
.91 .4077 Mdot
.91 .40789 Mdot
.91 .40867 Mdot
.91 .40918 Mdot
.91 .40966 Mdot
.91 .40971 Mdot
.91 .41037 Mdot
.91 .41058 Mdot
.91 .41202 Mdot
.91 .41206 Mdot
.91 .4123 Mdot
.91 .41237 Mdot
.91 .41265 Mdot
.91 .41278 Mdot
.91 .41364 Mdot
.91 .41589 Mdot
.91 .41641 Mdot
.91 .41642 Mdot
.91 .41658 Mdot
.91 .41696 Mdot
.91 .41777 Mdot
.91 .4183 Mdot
.91 .41833 Mdot
.91 .41935 Mdot
.91 .42062 Mdot
.91 .42195 Mdot
.91 .42259 Mdot
.91 .42277 Mdot
.91 .4228 Mdot
.91 .42395 Mdot
.91 .42612 Mdot
.91 .42617 Mdot
.91 .42621 Mdot
.91 .42706 Mdot
.91 .4283 Mdot
.91 .42904 Mdot
.91 .42948 Mdot
.91 .42964 Mdot
.91 .43043 Mdot
.91 .43083 Mdot
.91 .43183 Mdot
.91 .43208 Mdot
.91 .43334 Mdot
.91 .43359 Mdot
.91 .43359 Mdot
.91 .4346 Mdot
.91 .43566 Mdot
.91 .4364 Mdot
.91 .43685 Mdot
.91 .43685 Mdot
.91 .4377 Mdot
.91 .43809 Mdot
.91 .43837 Mdot
.91 .43861 Mdot
.91 .43928 Mdot
.91 .43941 Mdot
.91 .44003 Mdot
.91 .44158 Mdot
.91 .44163 Mdot
.91 .44205 Mdot
.91 .44297 Mdot
.91 .44355 Mdot
.91 .44412 Mdot
.91 .44421 Mdot
.91 .44483 Mdot
.91 .4471 Mdot
.91 .44925 Mdot
.91 .44942 Mdot
.91 .44945 Mdot
.91 .44996 Mdot
.91 .45082 Mdot
.91 .45155 Mdot
.91 .45253 Mdot
.91 .45376 Mdot
.91 .45387 Mdot
.91 .45397 Mdot
.91 .45412 Mdot
.91 .45478 Mdot
.91 .45579 Mdot
.91 .45765 Mdot
.91 .45797 Mdot
.91 .45977 Mdot
.91 .46003 Mdot
.91 .46123 Mdot
.91 .46235 Mdot
.91 .46371 Mdot
.91 .46379 Mdot
.91 .46529 Mdot
.91 .46533 Mdot
.91 .46556 Mdot
.91 .46569 Mdot
.91 .46754 Mdot
.91 .46968 Mdot
.91 .47255 Mdot
.91 .47415 Mdot
.91 .47466 Mdot
.91 .47482 Mdot
.91 .47522 Mdot
.91 .47533 Mdot
.91 .4756 Mdot
.91 .47622 Mdot
.91 .47674 Mdot
.91 .47674 Mdot
.91 .47701 Mdot
.91 .47736 Mdot
.91 .47808 Mdot
.91 .47913 Mdot
.91 .47985 Mdot
.91 .48019 Mdot
.91 .48168 Mdot
.91 .48168 Mdot
.91 .48226 Mdot
.91 .48288 Mdot
.91 .4837 Mdot
.91 .48552 Mdot
.91 .48631 Mdot
.91 .48691 Mdot
.91 .48801 Mdot
.91 .48959 Mdot
.91 .48995 Mdot
.91 .49029 Mdot
.91 .4908 Mdot
.91 .49138 Mdot
.91 .49203 Mdot
.91 .4925 Mdot
.91 .49297 Mdot
.91 .49351 Mdot
.91 .4963 Mdot
.91 .49982 Mdot
.91 .49999 Mdot
.91 .50247 Mdot
.91 .50354 Mdot
.91 .50377 Mdot
.91 .50772 Mdot
.91 .50848 Mdot
.91 .50942 Mdot
.91 .50948 Mdot
.91 .51036 Mdot
.91 .51036 Mdot
.91 .51248 Mdot
.91 .51396 Mdot
.91 .51432 Mdot
.91 .51519 Mdot
.91 .51803 Mdot
.91 .51973 Mdot
.91 .52002 Mdot
.91 .52146 Mdot
.91 .52255 Mdot
.91 .52267 Mdot
.91 .52283 Mdot
.91 .52496 Mdot
.91 .52547 Mdot
.91 .52779 Mdot
.91 .5279 Mdot
.91 .52869 Mdot
.91 .52889 Mdot
.91 .52904 Mdot
.91 .52911 Mdot
.91 .53111 Mdot
.91 .53214 Mdot
.91 .53217 Mdot
.91 .53525 Mdot
.91 .53805 Mdot
.91 .53958 Mdot
.91 .54234 Mdot
.91 .54302 Mdot
.91 .54317 Mdot
.91 .54409 Mdot
.91 .54494 Mdot
.91 .54638 Mdot
.91 .54797 Mdot
.91 .55183 Mdot
.91 .55219 Mdot
.912 .0158 Mdot
.912 .0167 Mdot
.912 .01687 Mdot
.912 .01708 Mdot
.912 .01727 Mdot
.912 .01834 Mdot
.912 .01865 Mdot
.912 .019 Mdot
.912 .01902 Mdot
.912 .01938 Mdot
.912 .01994 Mdot
.912 .0202 Mdot
.912 .02122 Mdot
.912 .02132 Mdot
.912 .02189 Mdot
.912 .02254 Mdot
.912 .02257 Mdot
.912 .02257 Mdot
.912 .02323 Mdot
.912 .02359 Mdot
.912 .02424 Mdot
.912 .02463 Mdot
.912 .02472 Mdot
.912 .02493 Mdot
.912 .02658 Mdot
.912 .02669 Mdot
.912 .02677 Mdot
.912 .0278 Mdot
.912 .02884 Mdot
.912 .02898 Mdot
.912 .02901 Mdot
.912 .02905 Mdot
.912 .02905 Mdot
.912 .02912 Mdot
.912 .0292 Mdot
.912 .02954 Mdot
.912 .0296 Mdot
.912 .03025 Mdot
.912 .0309 Mdot
.912 .03117 Mdot
.912 .03127 Mdot
.912 .03209 Mdot
.912 .03241 Mdot
.912 .03278 Mdot
.912 .0328 Mdot
.912 .03296 Mdot
.912 .03334 Mdot
.912 .03351 Mdot
.912 .03373 Mdot
.912 .0361 Mdot
.912 .03635 Mdot
.912 .03656 Mdot
.912 .0367 Mdot
.912 .03714 Mdot
.912 .03761 Mdot
.912 .03834 Mdot
.912 .03858 Mdot
.912 .04034 Mdot
.912 .04049 Mdot
.912 .04074 Mdot
.912 .04079 Mdot
.912 .04085 Mdot
.912 .04086 Mdot
.912 .04098 Mdot
.912 .04113 Mdot
.912 .04117 Mdot
.912 .04133 Mdot
.912 .04175 Mdot
.912 .04187 Mdot
.912 .04249 Mdot
.912 .04305 Mdot
.912 .04423 Mdot
.912 .04468 Mdot
.912 .04474 Mdot
.912 .04491 Mdot
.912 .04597 Mdot
.912 .0464 Mdot
.912 .04684 Mdot
.912 .04699 Mdot
.912 .04735 Mdot
.912 .04745 Mdot
.912 .0476 Mdot
.912 .04766 Mdot
.912 .04771 Mdot
.912 .04799 Mdot
.912 .0487 Mdot
.912 .04899 Mdot
.912 .0494 Mdot
.912 .05079 Mdot
.912 .05182 Mdot
.912 .05232 Mdot
.912 .05373 Mdot
.912 .05401 Mdot
.912 .05418 Mdot
.912 .05456 Mdot
.912 .05482 Mdot
.912 .05562 Mdot
.912 .05614 Mdot
.912 .05648 Mdot
.912 .05725 Mdot
.912 .05781 Mdot
.912 .05791 Mdot
.912 .05815 Mdot
.912 .05825 Mdot
.912 .05828 Mdot
.912 .05835 Mdot
.912 .06101 Mdot
.912 .06145 Mdot
.912 .06162 Mdot
.912 .06172 Mdot
.912 .06219 Mdot
.912 .06227 Mdot
.912 .06239 Mdot
.912 .0624 Mdot
.912 .06259 Mdot
.912 .06263 Mdot
.912 .0629 Mdot
.912 .06296 Mdot
.912 .06326 Mdot
.912 .06403 Mdot
.912 .06424 Mdot
.912 .06452 Mdot
.912 .06537 Mdot
.912 .06584 Mdot
.912 .06595 Mdot
.912 .06615 Mdot
.912 .0664 Mdot
.912 .06806 Mdot
.912 .06855 Mdot
.912 .06938 Mdot
.912 .06948 Mdot
.912 .0698 Mdot
.912 .0713 Mdot
.912 .07173 Mdot
.912 .07252 Mdot
.912 .07253 Mdot
.912 .07331 Mdot
.912 .0734 Mdot
.912 .07359 Mdot
.912 .07403 Mdot
.912 .07425 Mdot
.912 .07443 Mdot
.912 .0747 Mdot
.912 .07481 Mdot
.912 .07489 Mdot
.912 .07542 Mdot
.912 .0766 Mdot
.912 .0767 Mdot
.912 .07698 Mdot
.912 .07723 Mdot
.912 .07786 Mdot
.912 .07799 Mdot
.912 .07848 Mdot
.912 .07989 Mdot
.912 .08042 Mdot
.912 .08052 Mdot
.912 .08125 Mdot
.912 .08154 Mdot
.912 .0824 Mdot
.912 .08244 Mdot
.912 .08255 Mdot
.912 .08331 Mdot
.912 .08348 Mdot
.912 .08457 Mdot
.912 .08507 Mdot
.912 .0851 Mdot
.912 .08587 Mdot
.912 .08638 Mdot
.912 .08667 Mdot
.912 .0867 Mdot
.912 .08681 Mdot
.912 .08705 Mdot
.912 .08738 Mdot
.912 .08786 Mdot
.912 .08879 Mdot
.912 .08932 Mdot
.912 .09027 Mdot
.912 .09041 Mdot
.912 .09089 Mdot
.912 .09108 Mdot
.912 .09229 Mdot
.912 .0923 Mdot
.912 .09331 Mdot
.912 .09351 Mdot
.912 .09351 Mdot
.912 .09394 Mdot
.912 .09412 Mdot
.912 .09418 Mdot
.912 .0943 Mdot
.912 .09474 Mdot
.912 .09491 Mdot
.912 .09602 Mdot
.912 .0966 Mdot
.912 .09664 Mdot
.912 .0978 Mdot
.912 .09843 Mdot
.912 .09915 Mdot
.912 .09996 Mdot
.912 .09996 Mdot
.912 .10027 Mdot
.912 .10045 Mdot
.912 .1008 Mdot
.912 .10087 Mdot
.912 .10131 Mdot
.912 .10145 Mdot
.912 .10168 Mdot
.912 .10169 Mdot
.912 .10174 Mdot
.912 .10204 Mdot
.912 .1021 Mdot
.912 .1026 Mdot
.912 .10272 Mdot
.912 .10325 Mdot
.912 .10401 Mdot
.912 .1043 Mdot
.912 .10466 Mdot
.912 .10505 Mdot
.912 .10556 Mdot
.912 .1065 Mdot
.912 .10711 Mdot
.912 .10728 Mdot
.912 .10797 Mdot
.912 .10817 Mdot
.912 .10853 Mdot
.912 .10898 Mdot
.912 .1106 Mdot
.912 .11077 Mdot
.912 .11201 Mdot
.912 .11203 Mdot
.912 .11291 Mdot
.912 .11442 Mdot
.912 .1146 Mdot
.912 .11518 Mdot
.912 .11519 Mdot
.912 .11528 Mdot
.912 .11551 Mdot
.912 .11579 Mdot
.912 .11793 Mdot
.912 .11871 Mdot
.912 .12014 Mdot
.912 .12016 Mdot
.912 .12159 Mdot
.912 .12176 Mdot
.912 .1221 Mdot
.912 .1229 Mdot
.912 .1233 Mdot
.912 .12364 Mdot
.912 .12395 Mdot
.912 .12413 Mdot
.912 .12433 Mdot
.912 .12448 Mdot
.912 .12499 Mdot
.912 .12543 Mdot
.912 .12706 Mdot
.912 .12759 Mdot
.912 .12777 Mdot
.912 .12828 Mdot
.912 .12874 Mdot
.912 .12989 Mdot
.912 .13013 Mdot
.912 .13102 Mdot
.912 .13124 Mdot
.912 .13189 Mdot
.912 .13192 Mdot
.912 .13209 Mdot
.912 .13321 Mdot
.912 .1336 Mdot
.912 .13387 Mdot
.912 .1342 Mdot
.912 .13436 Mdot
.912 .13457 Mdot
.912 .13474 Mdot
.912 .13607 Mdot
.912 .13639 Mdot
.912 .1366 Mdot
.912 .13665 Mdot
.912 .13764 Mdot
.912 .13817 Mdot
.912 .13825 Mdot
.912 .13828 Mdot
.912 .1383 Mdot
.912 .13845 Mdot
.912 .13937 Mdot
.912 .13983 Mdot
.912 .14015 Mdot
.912 .1406 Mdot
.912 .14149 Mdot
.912 .14181 Mdot
.912 .14213 Mdot
.912 .14281 Mdot
.912 .14304 Mdot
.912 .14309 Mdot
.912 .14451 Mdot
.912 .14457 Mdot
.912 .14498 Mdot
.912 .14544 Mdot
.912 .14564 Mdot
.912 .14595 Mdot
.912 .14601 Mdot
.912 .14622 Mdot
.912 .14666 Mdot
.912 .14681 Mdot
.912 .14726 Mdot
.912 .14729 Mdot
.912 .14813 Mdot
.912 .14982 Mdot
.912 .15003 Mdot
.912 .15079 Mdot
.912 .15253 Mdot
.912 .15279 Mdot
.912 .15366 Mdot
.912 .15401 Mdot
.912 .15528 Mdot
.912 .15622 Mdot
.912 .15624 Mdot
.912 .15713 Mdot
.912 .15807 Mdot
.912 .15843 Mdot
.912 .15844 Mdot
.912 .15921 Mdot
.912 .15954 Mdot
.912 .15966 Mdot
.912 .15988 Mdot
.912 .16038 Mdot
.912 .16068 Mdot
.912 .16099 Mdot
.912 .16145 Mdot
.912 .16292 Mdot
.912 .16302 Mdot
.912 .16408 Mdot
.912 .16414 Mdot
.912 .16454 Mdot
.912 .16626 Mdot
.912 .16724 Mdot
.912 .16735 Mdot
.912 .16735 Mdot
.912 .16741 Mdot
.912 .16873 Mdot
.912 .16907 Mdot
.912 .17019 Mdot
.912 .1702 Mdot
.912 .17078 Mdot
.912 .1711 Mdot
.912 .17174 Mdot
.912 .17187 Mdot
.912 .17266 Mdot
.912 .17292 Mdot
.912 .17334 Mdot
.912 .17335 Mdot
.912 .17345 Mdot
.912 .17347 Mdot
.912 .17388 Mdot
.912 .174 Mdot
.912 .17411 Mdot
.912 .17433 Mdot
.912 .17502 Mdot
.912 .17521 Mdot
.912 .17523 Mdot
.912 .17575 Mdot
.912 .17587 Mdot
.912 .17591 Mdot
.912 .17618 Mdot
.912 .17621 Mdot
.912 .17759 Mdot
.912 .17811 Mdot
.912 .17878 Mdot
.912 .17918 Mdot
.912 .17949 Mdot
.912 .17989 Mdot
.912 .18042 Mdot
.912 .18107 Mdot
.912 .18112 Mdot
.912 .18115 Mdot
.912 .18117 Mdot
.912 .18177 Mdot
.912 .18214 Mdot
.912 .18254 Mdot
.912 .18325 Mdot
.912 .18356 Mdot
.912 .18482 Mdot
.912 .18517 Mdot
.912 .18583 Mdot
.912 .18648 Mdot
.912 .18663 Mdot
.912 .18666 Mdot
.912 .18766 Mdot
.912 .1896 Mdot
.912 .18992 Mdot
.912 .19074 Mdot
.912 .19121 Mdot
.912 .19219 Mdot
.912 .19222 Mdot
.912 .19383 Mdot
.912 .1942 Mdot
.912 .19446 Mdot
.912 .19553 Mdot
.912 .19641 Mdot
.912 .19657 Mdot
.912 .19682 Mdot
.912 .19691 Mdot
.912 .19782 Mdot
.912 .19797 Mdot
.912 .19798 Mdot
.912 .19845 Mdot
.912 .19849 Mdot
.912 .19856 Mdot
.912 .19908 Mdot
.912 .20014 Mdot
.912 .20051 Mdot
.912 .20143 Mdot
.912 .20179 Mdot
.912 .20272 Mdot
.912 .20298 Mdot
.912 .20375 Mdot
.912 .20441 Mdot
.912 .20564 Mdot
.912 .20702 Mdot
.912 .20705 Mdot
.912 .20712 Mdot
.912 .20966 Mdot
.912 .20997 Mdot
.912 .21059 Mdot
.912 .21185 Mdot
.912 .21205 Mdot
.912 .21264 Mdot
.912 .21274 Mdot
.912 .21278 Mdot
.912 .21339 Mdot
.912 .21347 Mdot
.912 .21377 Mdot
.912 .21397 Mdot
.912 .21429 Mdot
.912 .21466 Mdot
.912 .21493 Mdot
.912 .21502 Mdot
.912 .21532 Mdot
.912 .21585 Mdot
.912 .21667 Mdot
.912 .21907 Mdot
.912 .21963 Mdot
.912 .2206 Mdot
.912 .22092 Mdot
.912 .22137 Mdot
.912 .22185 Mdot
.912 .22266 Mdot
.912 .2227 Mdot
.912 .2227 Mdot
.912 .22454 Mdot
.912 .22466 Mdot
.912 .2248 Mdot
.912 .22506 Mdot
.912 .22522 Mdot
.912 .22526 Mdot
.912 .22527 Mdot
.912 .22535 Mdot
.912 .22626 Mdot
.912 .22682 Mdot
.912 .22685 Mdot
.912 .22726 Mdot
.912 .22845 Mdot
.912 .22849 Mdot
.912 .2288 Mdot
.912 .22973 Mdot
.912 .22987 Mdot
.912 .23085 Mdot
.912 .23117 Mdot
.912 .23156 Mdot
.912 .23186 Mdot
.912 .23205 Mdot
.912 .23206 Mdot
.912 .23266 Mdot
.912 .23294 Mdot
.912 .23333 Mdot
.912 .23364 Mdot
.912 .23421 Mdot
.912 .23465 Mdot
.912 .23607 Mdot
.912 .23656 Mdot
.912 .23665 Mdot
.912 .23703 Mdot
.912 .23712 Mdot
.912 .23893 Mdot
.912 .23933 Mdot
.912 .23989 Mdot
.912 .23993 Mdot
.912 .24005 Mdot
.912 .24011 Mdot
.912 .24011 Mdot
.912 .24013 Mdot
.912 .2404 Mdot
.912 .24057 Mdot
.912 .24209 Mdot
.912 .24279 Mdot
.912 .24293 Mdot
.912 .2435 Mdot
.912 .24433 Mdot
.912 .24471 Mdot
.912 .24595 Mdot
.912 .24654 Mdot
.912 .24667 Mdot
.912 .24711 Mdot
.912 .24712 Mdot
.912 .24744 Mdot
.912 .2476 Mdot
.912 .24837 Mdot
.912 .24856 Mdot
.912 .24861 Mdot
.912 .24869 Mdot
.912 .24878 Mdot
.912 .24884 Mdot
.912 .24887 Mdot
.912 .24967 Mdot
.912 .25019 Mdot
.912 .25146 Mdot
.912 .25158 Mdot
.912 .25231 Mdot
.912 .25275 Mdot
.912 .25315 Mdot
.912 .25339 Mdot
.912 .25343 Mdot
.912 .25353 Mdot
.912 .25357 Mdot
.912 .25381 Mdot
.912 .2541 Mdot
.912 .25412 Mdot
.912 .2542 Mdot
.912 .25431 Mdot
.912 .25442 Mdot
.912 .25458 Mdot
.912 .25473 Mdot
.912 .25539 Mdot
.912 .25566 Mdot
.912 .25601 Mdot
.912 .25648 Mdot
.912 .25652 Mdot
.912 .25708 Mdot
.912 .25806 Mdot
.912 .25838 Mdot
.912 .2588 Mdot
.912 .26115 Mdot
.912 .26152 Mdot
.912 .26292 Mdot
.912 .26302 Mdot
.912 .26342 Mdot
.912 .26587 Mdot
.912 .26605 Mdot
.912 .26608 Mdot
.912 .26656 Mdot
.912 .26733 Mdot
.912 .26814 Mdot
.912 .26815 Mdot
.912 .26842 Mdot
.912 .26867 Mdot
.912 .26879 Mdot
.912 .26947 Mdot
.912 .26959 Mdot
.912 .26992 Mdot
.912 .27005 Mdot
.912 .27085 Mdot
.912 .27111 Mdot
.912 .27181 Mdot
.912 .27189 Mdot
.912 .27217 Mdot
.912 .27252 Mdot
.912 .27281 Mdot
.912 .27285 Mdot
.912 .27288 Mdot
.912 .27342 Mdot
.912 .2739 Mdot
.912 .27417 Mdot
.912 .27449 Mdot
.912 .27547 Mdot
.912 .27589 Mdot
.912 .2761 Mdot
.912 .2762 Mdot
.912 .27686 Mdot
.912 .27687 Mdot
.912 .27703 Mdot
.912 .27817 Mdot
.912 .27828 Mdot
.912 .27888 Mdot
.912 .27891 Mdot
.912 .27909 Mdot
.912 .27919 Mdot
.912 .27949 Mdot
.912 .27974 Mdot
.912 .27988 Mdot
.912 .28041 Mdot
.912 .28095 Mdot
.912 .28152 Mdot
.912 .28173 Mdot
.912 .28235 Mdot
.912 .285 Mdot
.912 .28504 Mdot
.912 .28522 Mdot
.912 .28606 Mdot
.912 .28716 Mdot
.912 .28727 Mdot
.912 .28746 Mdot
.912 .28799 Mdot
.912 .29113 Mdot
.912 .29291 Mdot
.912 .29312 Mdot
.912 .29312 Mdot
.912 .29322 Mdot
.912 .29527 Mdot
.912 .29564 Mdot
.912 .29625 Mdot
.912 .29652 Mdot
.912 .29831 Mdot
.912 .29833 Mdot
.912 .29937 Mdot
.912 .29997 Mdot
.912 .30113 Mdot
.912 .30115 Mdot
.912 .30136 Mdot
.912 .30151 Mdot
.912 .30281 Mdot
.912 .30284 Mdot
.912 .30328 Mdot
.912 .30405 Mdot
.912 .30407 Mdot
.912 .30425 Mdot
.912 .30428 Mdot
.912 .30503 Mdot
.912 .30525 Mdot
.912 .30546 Mdot
.912 .30585 Mdot
.912 .30711 Mdot
.912 .30746 Mdot
.912 .3075 Mdot
.912 .30845 Mdot
.912 .30866 Mdot
.912 .30873 Mdot
.912 .30923 Mdot
.912 .30928 Mdot
.912 .31099 Mdot
.912 .31158 Mdot
.912 .31169 Mdot
.912 .3118 Mdot
.912 .31275 Mdot
.912 .31326 Mdot
.912 .31396 Mdot
.912 .3147 Mdot
.912 .31526 Mdot
.912 .31583 Mdot
.912 .316 Mdot
.912 .31696 Mdot
.912 .31814 Mdot
.912 .31823 Mdot
.912 .31829 Mdot
.912 .31834 Mdot
.912 .31852 Mdot
.912 .31856 Mdot
.912 .31942 Mdot
.912 .31947 Mdot
.912 .3201 Mdot
.912 .3203 Mdot
.912 .3207 Mdot
.912 .32082 Mdot
.912 .32212 Mdot
.912 .32269 Mdot
.912 .32295 Mdot
.912 .32335 Mdot
.912 .32444 Mdot
.912 .3249 Mdot
.912 .32499 Mdot
.912 .32562 Mdot
.912 .32683 Mdot
.912 .32753 Mdot
.912 .32801 Mdot
.912 .32829 Mdot
.912 .32835 Mdot
.912 .32843 Mdot
.912 .33017 Mdot
.912 .33074 Mdot
.912 .33101 Mdot
.912 .33194 Mdot
.912 .33311 Mdot
.912 .33371 Mdot
.912 .33408 Mdot
.912 .33421 Mdot
.912 .33428 Mdot
.912 .33432 Mdot
.912 .33578 Mdot
.912 .33611 Mdot
.912 .33664 Mdot
.912 .3377 Mdot
.912 .33843 Mdot
.912 .33848 Mdot
.912 .33859 Mdot
.912 .33964 Mdot
.912 .34142 Mdot
.912 .34209 Mdot
.912 .34257 Mdot
.912 .34291 Mdot
.912 .34432 Mdot
.912 .34453 Mdot
.912 .34501 Mdot
.912 .34535 Mdot
.912 .34613 Mdot
.912 .34642 Mdot
.912 .34687 Mdot
.912 .34703 Mdot
.912 .34753 Mdot
.912 .34759 Mdot
.912 .3481 Mdot
.912 .34869 Mdot
.912 .34897 Mdot
.912 .34898 Mdot
.912 .34984 Mdot
.912 .34992 Mdot
.912 .35006 Mdot
.912 .35101 Mdot
.912 .3519 Mdot
.912 .35226 Mdot
.912 .35293 Mdot
.912 .3536 Mdot
.912 .35427 Mdot
.912 .35436 Mdot
.912 .35497 Mdot
.912 .35529 Mdot
.912 .35531 Mdot
.912 .35595 Mdot
.912 .35629 Mdot
.912 .35713 Mdot
.912 .35759 Mdot
.912 .35763 Mdot
.912 .35811 Mdot
.912 .35935 Mdot
.912 .35951 Mdot
.912 .36072 Mdot
.912 .36115 Mdot
.912 .36296 Mdot
.912 .36306 Mdot
.912 .36375 Mdot
.912 .36548 Mdot
.912 .36553 Mdot
.912 .36566 Mdot
.912 .36581 Mdot
.912 .37029 Mdot
.912 .37085 Mdot
.912 .37199 Mdot
.912 .37428 Mdot
.912 .37464 Mdot
.912 .37465 Mdot
.912 .37475 Mdot
.912 .37536 Mdot
.912 .37572 Mdot
.912 .37591 Mdot
.912 .37599 Mdot
.912 .3771 Mdot
.912 .37724 Mdot
.912 .37779 Mdot
.912 .37814 Mdot
.912 .37815 Mdot
.912 .37874 Mdot
.912 .37941 Mdot
.912 .3799 Mdot
.912 .38008 Mdot
.912 .38063 Mdot
.912 .38159 Mdot
.912 .38181 Mdot
.912 .38218 Mdot
.912 .38282 Mdot
.912 .38308 Mdot
.912 .38458 Mdot
.912 .38746 Mdot
.912 .38848 Mdot
.912 .39026 Mdot
.912 .39084 Mdot
.912 .39165 Mdot
.912 .39254 Mdot
.912 .39402 Mdot
.912 .39408 Mdot
.912 .39408 Mdot
.912 .39502 Mdot
.912 .39743 Mdot
.912 .39766 Mdot
.912 .3979 Mdot
.912 .39839 Mdot
.912 .39868 Mdot
.912 .39875 Mdot
.912 .39877 Mdot
.912 .39892 Mdot
.912 .40056 Mdot
.912 .40095 Mdot
.912 .4016 Mdot
.912 .40163 Mdot
.912 .40164 Mdot
.912 .40166 Mdot
.912 .40198 Mdot
.912 .4024 Mdot
.912 .40456 Mdot
.912 .40465 Mdot
.912 .40521 Mdot
.912 .4069 Mdot
.912 .40716 Mdot
.912 .4088 Mdot
.912 .40894 Mdot
.912 .40953 Mdot
.912 .41001 Mdot
.912 .41023 Mdot
.912 .41078 Mdot
.912 .41113 Mdot
.912 .41115 Mdot
.912 .41206 Mdot
.912 .41225 Mdot
.912 .41276 Mdot
.912 .41296 Mdot
.912 .41347 Mdot
.912 .41403 Mdot
.912 .41507 Mdot
.912 .41588 Mdot
.912 .41847 Mdot
.912 .41891 Mdot
.912 .41896 Mdot
.912 .41936 Mdot
.912 .41953 Mdot
.912 .42021 Mdot
.912 .42038 Mdot
.912 .42243 Mdot
.912 .42369 Mdot
.912 .4244 Mdot
.912 .42442 Mdot
.912 .42543 Mdot
.912 .4255 Mdot
.912 .42572 Mdot
.912 .42583 Mdot
.912 .42583 Mdot
.912 .42588 Mdot
.912 .42637 Mdot
.912 .42668 Mdot
.912 .42828 Mdot
.912 .42835 Mdot
.912 .42907 Mdot
.912 .42944 Mdot
.912 .42955 Mdot
.912 .43073 Mdot
.912 .43098 Mdot
.912 .43202 Mdot
.912 .43354 Mdot
.912 .43387 Mdot
.912 .43397 Mdot
.912 .43422 Mdot
.912 .43544 Mdot
.912 .43649 Mdot
.912 .43757 Mdot
.912 .4378 Mdot
.912 .43799 Mdot
.912 .43807 Mdot
.912 .4386 Mdot
.912 .43863 Mdot
.912 .43867 Mdot
.912 .43875 Mdot
.912 .43921 Mdot
.912 .43949 Mdot
.912 .4409 Mdot
.912 .44125 Mdot
.912 .44127 Mdot
.912 .44135 Mdot
.912 .44148 Mdot
.912 .44165 Mdot
.912 .44175 Mdot
.912 .44181 Mdot
.912 .44198 Mdot
.912 .44268 Mdot
.912 .44327 Mdot
.912 .44398 Mdot
.912 .44422 Mdot
.912 .44653 Mdot
.912 .44675 Mdot
.912 .44809 Mdot
.912 .44819 Mdot
.912 .44889 Mdot
.912 .44933 Mdot
.912 .44949 Mdot
.912 .44963 Mdot
.912 .45006 Mdot
.912 .45013 Mdot
.912 .45031 Mdot
.912 .45038 Mdot
.912 .45082 Mdot
.912 .45135 Mdot
.912 .45139 Mdot
.912 .45154 Mdot
.912 .45174 Mdot
.912 .45194 Mdot
.912 .45223 Mdot
.912 .45249 Mdot
.912 .45264 Mdot
.912 .45335 Mdot
.912 .45359 Mdot
.912 .4537 Mdot
.912 .45421 Mdot
.912 .45483 Mdot
.912 .45524 Mdot
.912 .4554 Mdot
.912 .4557 Mdot
.912 .45577 Mdot
.912 .45679 Mdot
.912 .45858 Mdot
.912 .45916 Mdot
.912 .45993 Mdot
.912 .46421 Mdot
.912 .4649 Mdot
.912 .46743 Mdot
.912 .46763 Mdot
.912 .46836 Mdot
.912 .47283 Mdot
.912 .47315 Mdot
.912 .47321 Mdot
.912 .47407 Mdot
.912 .47548 Mdot
.912 .47696 Mdot
.912 .47698 Mdot
.912 .47748 Mdot
.912 .47793 Mdot
.912 .47815 Mdot
.912 .47938 Mdot
.912 .4796 Mdot
.912 .4802 Mdot
.912 .48045 Mdot
.912 .4819 Mdot
.912 .48239 Mdot
.912 .48365 Mdot
.912 .48381 Mdot
.912 .48431 Mdot
.912 .48495 Mdot
.912 .48549 Mdot
.912 .48556 Mdot
.912 .48562 Mdot
.912 .4866 Mdot
.912 .48747 Mdot
.912 .48796 Mdot
.912 .48854 Mdot
.912 .49033 Mdot
.912 .4911 Mdot
.912 .49148 Mdot
.912 .49167 Mdot
.912 .49286 Mdot
.912 .49289 Mdot
.912 .49317 Mdot
.912 .49525 Mdot
.912 .49546 Mdot
.912 .49655 Mdot
.912 .49661 Mdot
.912 .49694 Mdot
.912 .49713 Mdot
.912 .49766 Mdot
.912 .49812 Mdot
.912 .49838 Mdot
.912 .49934 Mdot
.912 .50033 Mdot
.912 .50137 Mdot
.912 .50175 Mdot
.912 .50288 Mdot
.912 .50772 Mdot
.912 .50778 Mdot
.912 .50812 Mdot
.912 .50964 Mdot
.912 .51166 Mdot
.912 .51186 Mdot
.912 .51221 Mdot
.912 .51317 Mdot
.912 .5189 Mdot
.912 .52215 Mdot
.912 .52252 Mdot
.912 .52253 Mdot
.912 .52271 Mdot
.912 .52645 Mdot
.912 .52712 Mdot
.912 .52824 Mdot
.912 .52873 Mdot
.912 .53199 Mdot
.912 .53202 Mdot
.912 .53393 Mdot
.912 .53502 Mdot
.912 .53713 Mdot
.912 .53717 Mdot
.912 .53756 Mdot
.912 .53783 Mdot
.912 .54019 Mdot
.912 .54025 Mdot
.912 .54106 Mdot
.912 .54245 Mdot
.912 .5425 Mdot
.912 .54283 Mdot
.912 .54287 Mdot
.912 .54425 Mdot
.912 .54464 Mdot
.912 .54503 Mdot
.912 .54574 Mdot
.912 .54805 Mdot
.912 .54867 Mdot
.912 .54876 Mdot
.912 .55049 Mdot
.912 .55088 Mdot
.912 .551 Mdot
.912 .55191 Mdot
.912 .552 Mdot
.914 .01541 Mdot
.914 .01599 Mdot
.914 .01698 Mdot
.914 .01705 Mdot
.914 .01786 Mdot
.914 .01823 Mdot
.914 .01886 Mdot
.914 .01899 Mdot
.914 .01932 Mdot
.914 .02046 Mdot
.914 .02067 Mdot
.914 .02097 Mdot
.914 .02114 Mdot
.914 .02175 Mdot
.914 .02229 Mdot
.914 .02252 Mdot
.914 .02278 Mdot
.914 .02314 Mdot
.914 .02338 Mdot
.914 .02397 Mdot
.914 .02522 Mdot
.914 .0256 Mdot
.914 .02614 Mdot
.914 .02645 Mdot
.914 .02679 Mdot
.914 .02757 Mdot
.914 .02771 Mdot
.914 .02857 Mdot
.914 .02899 Mdot
.914 .02945 Mdot
.914 .02983 Mdot
.914 .0299 Mdot
.914 .03011 Mdot
.914 .03033 Mdot
.914 .03055 Mdot
.914 .0314 Mdot
.914 .03163 Mdot
.914 .03171 Mdot
.914 .03376 Mdot
.914 .03392 Mdot
.914 .03394 Mdot
.914 .03407 Mdot
.914 .03448 Mdot
.914 .03459 Mdot
.914 .0346 Mdot
.914 .03559 Mdot
.914 .0356 Mdot
.914 .03565 Mdot
.914 .03581 Mdot
.914 .03603 Mdot
.914 .03605 Mdot
.914 .03617 Mdot
.914 .03679 Mdot
.914 .03744 Mdot
.914 .03821 Mdot
.914 .03822 Mdot
.914 .03822 Mdot
.914 .03847 Mdot
.914 .03902 Mdot
.914 .03956 Mdot
.914 .04004 Mdot
.914 .0408 Mdot
.914 .04086 Mdot
.914 .04154 Mdot
.914 .04165 Mdot
.914 .04235 Mdot
.914 .04248 Mdot
.914 .04286 Mdot
.914 .04302 Mdot
.914 .04326 Mdot
.914 .04366 Mdot
.914 .04367 Mdot
.914 .04427 Mdot
.914 .04521 Mdot
.914 .04563 Mdot
.914 .04569 Mdot
.914 .04578 Mdot
.914 .04621 Mdot
.914 .04787 Mdot
.914 .04809 Mdot
.914 .04822 Mdot
.914 .04874 Mdot
.914 .04953 Mdot
.914 .04972 Mdot
.914 .04983 Mdot
.914 .04985 Mdot
.914 .05009 Mdot
.914 .05085 Mdot
.914 .05104 Mdot
.914 .05107 Mdot
.914 .05193 Mdot
.914 .05287 Mdot
.914 .05289 Mdot
.914 .05299 Mdot
.914 .05327 Mdot
.914 .05367 Mdot
.914 .05371 Mdot
.914 .05394 Mdot
.914 .05506 Mdot
.914 .05574 Mdot
.914 .05625 Mdot
.914 .05684 Mdot
.914 .05727 Mdot
.914 .05766 Mdot
.914 .05767 Mdot
.914 .05768 Mdot
.914 .0578 Mdot
.914 .05787 Mdot
.914 .05793 Mdot
.914 .05814 Mdot
.914 .059 Mdot
.914 .05914 Mdot
.914 .06014 Mdot
.914 .061 Mdot
.914 .0624 Mdot
.914 .06251 Mdot
.914 .06318 Mdot
.914 .06375 Mdot
.914 .06395 Mdot
.914 .0642 Mdot
.914 .06461 Mdot
.914 .06501 Mdot
.914 .06516 Mdot
.914 .06522 Mdot
.914 .06546 Mdot
.914 .06617 Mdot
.914 .06645 Mdot
.914 .06689 Mdot
.914 .06693 Mdot
.914 .06762 Mdot
.914 .06764 Mdot
.914 .06874 Mdot
.914 .06881 Mdot
.914 .07035 Mdot
.914 .07047 Mdot
.914 .07089 Mdot
.914 .07124 Mdot
.914 .07134 Mdot
.914 .0715 Mdot
.914 .07229 Mdot
.914 .07412 Mdot
.914 .07532 Mdot
.914 .07554 Mdot
.914 .07557 Mdot
.914 .07573 Mdot
.914 .07596 Mdot
.914 .07648 Mdot
.914 .07691 Mdot
.914 .07741 Mdot
.914 .07827 Mdot
.914 .07836 Mdot
.914 .0784 Mdot
.914 .07871 Mdot
.914 .07891 Mdot
.914 .07893 Mdot
.914 .07894 Mdot
.914 .07938 Mdot
.914 .08063 Mdot
.914 .08076 Mdot
.914 .08082 Mdot
.914 .08112 Mdot
.914 .08118 Mdot
.914 .08275 Mdot
.914 .08446 Mdot
.914 .08451 Mdot
.914 .08467 Mdot
.914 .0851 Mdot
.914 .08519 Mdot
.914 .08592 Mdot
.914 .08599 Mdot
.914 .08642 Mdot
.914 .08675 Mdot
.914 .08847 Mdot
.914 .08857 Mdot
.914 .08883 Mdot
.914 .08906 Mdot
.914 .08947 Mdot
.914 .08971 Mdot
.914 .09064 Mdot
.914 .09075 Mdot
.914 .09171 Mdot
.914 .09172 Mdot
.914 .09216 Mdot
.914 .09251 Mdot
.914 .09322 Mdot
.914 .09324 Mdot
.914 .09326 Mdot
.914 .09347 Mdot
.914 .0936 Mdot
.914 .09363 Mdot
.914 .0937 Mdot
.914 .09392 Mdot
.914 .09409 Mdot
.914 .09517 Mdot
.914 .09542 Mdot
.914 .09567 Mdot
.914 .09592 Mdot
.914 .09628 Mdot
.914 .09674 Mdot
.914 .097 Mdot
.914 .09702 Mdot
.914 .09764 Mdot
.914 .09775 Mdot
.914 .09847 Mdot
.914 .09933 Mdot
.914 .09993 Mdot
.914 .10151 Mdot
.914 .10189 Mdot
.914 .10209 Mdot
.914 .10291 Mdot
.914 .10331 Mdot
.914 .10435 Mdot
.914 .10472 Mdot
.914 .10518 Mdot
.914 .10533 Mdot
.914 .10593 Mdot
.914 .10635 Mdot
.914 .10645 Mdot
.914 .10662 Mdot
.914 .10665 Mdot
.914 .10669 Mdot
.914 .10692 Mdot
.914 .10705 Mdot
.914 .10748 Mdot
.914 .10827 Mdot
.914 .10877 Mdot
.914 .10929 Mdot
.914 .1101 Mdot
.914 .11017 Mdot
.914 .11143 Mdot
.914 .11146 Mdot
.914 .11331 Mdot
.914 .11346 Mdot
.914 .11361 Mdot
.914 .11363 Mdot
.914 .11581 Mdot
.914 .11637 Mdot
.914 .11641 Mdot
.914 .11663 Mdot
.914 .11715 Mdot
.914 .11741 Mdot
.914 .11803 Mdot
.914 .11822 Mdot
.914 .11852 Mdot
.914 .11997 Mdot
.914 .12331 Mdot
.914 .12549 Mdot
.914 .1259 Mdot
.914 .12597 Mdot
.914 .12624 Mdot
.914 .12667 Mdot
.914 .12744 Mdot
.914 .12761 Mdot
.914 .12798 Mdot
.914 .12839 Mdot
.914 .12841 Mdot
.914 .12929 Mdot
.914 .12932 Mdot
.914 .1309 Mdot
.914 .13107 Mdot
.914 .13113 Mdot
.914 .13169 Mdot
.914 .13205 Mdot
.914 .1321 Mdot
.914 .13213 Mdot
.914 .13243 Mdot
.914 .13292 Mdot
.914 .13347 Mdot
.914 .13418 Mdot
.914 .13466 Mdot
.914 .1352 Mdot
.914 .13545 Mdot
.914 .13556 Mdot
.914 .1361 Mdot
.914 .13621 Mdot
.914 .13694 Mdot
.914 .13754 Mdot
.914 .13783 Mdot
.914 .13788 Mdot
.914 .13869 Mdot
.914 .13909 Mdot
.914 .13941 Mdot
.914 .14092 Mdot
.914 .14098 Mdot
.914 .14221 Mdot
.914 .1423 Mdot
.914 .1426 Mdot
.914 .14337 Mdot
.914 .14355 Mdot
.914 .14365 Mdot
.914 .14374 Mdot
.914 .14462 Mdot
.914 .14468 Mdot
.914 .14489 Mdot
.914 .14501 Mdot
.914 .1458 Mdot
.914 .1458 Mdot
.914 .14605 Mdot
.914 .14639 Mdot
.914 .14792 Mdot
.914 .14954 Mdot
.914 .14972 Mdot
.914 .1502 Mdot
.914 .15052 Mdot
.914 .15061 Mdot
.914 .15089 Mdot
.914 .15111 Mdot
.914 .15138 Mdot
.914 .15143 Mdot
.914 .15181 Mdot
.914 .15338 Mdot
.914 .15351 Mdot
.914 .15371 Mdot
.914 .15378 Mdot
.914 .15459 Mdot
.914 .15546 Mdot
.914 .15547 Mdot
.914 .15548 Mdot
.914 .15628 Mdot
.914 .15693 Mdot
.914 .15806 Mdot
.914 .15822 Mdot
.914 .15826 Mdot
.914 .1583 Mdot
.914 .15867 Mdot
.914 .15891 Mdot
.914 .15898 Mdot
.914 .15911 Mdot
.914 .1595 Mdot
.914 .15981 Mdot
.914 .16046 Mdot
.914 .16179 Mdot
.914 .16224 Mdot
.914 .1623 Mdot
.914 .16271 Mdot
.914 .16277 Mdot
.914 .16291 Mdot
.914 .16316 Mdot
.914 .16382 Mdot
.914 .16385 Mdot
.914 .16466 Mdot
.914 .16513 Mdot
.914 .16517 Mdot
.914 .1657 Mdot
.914 .16605 Mdot
.914 .16618 Mdot
.914 .16631 Mdot
.914 .1665 Mdot
.914 .16781 Mdot
.914 .16856 Mdot
.914 .16873 Mdot
.914 .16939 Mdot
.914 .1705 Mdot
.914 .17208 Mdot
.914 .17337 Mdot
.914 .17407 Mdot
.914 .17411 Mdot
.914 .17424 Mdot
.914 .17444 Mdot
.914 .17513 Mdot
.914 .17581 Mdot
.914 .17594 Mdot
.914 .17601 Mdot
.914 .17638 Mdot
.914 .17668 Mdot
.914 .17741 Mdot
.914 .17857 Mdot
.914 .17888 Mdot
.914 .17906 Mdot
.914 .17924 Mdot
.914 .18008 Mdot
.914 .18035 Mdot
.914 .18099 Mdot
.914 .18114 Mdot
.914 .18146 Mdot
.914 .18217 Mdot
.914 .18222 Mdot
.914 .18241 Mdot
.914 .18271 Mdot
.914 .18273 Mdot
.914 .18278 Mdot
.914 .18285 Mdot
.914 .18327 Mdot
.914 .1835 Mdot
.914 .1839 Mdot
.914 .18429 Mdot
.914 .18494 Mdot
.914 .18531 Mdot
.914 .18574 Mdot
.914 .18649 Mdot
.914 .18665 Mdot
.914 .1876 Mdot
.914 .18874 Mdot
.914 .18907 Mdot
.914 .1892 Mdot
.914 .19097 Mdot
.914 .19128 Mdot
.914 .1914 Mdot
.914 .19152 Mdot
.914 .19156 Mdot
.914 .19311 Mdot
.914 .19328 Mdot
.914 .19495 Mdot
.914 .19523 Mdot
.914 .19549 Mdot
.914 .19552 Mdot
.914 .19568 Mdot
.914 .19619 Mdot
.914 .19625 Mdot
.914 .19865 Mdot
.914 .19951 Mdot
.914 .19964 Mdot
.914 .20054 Mdot
.914 .20062 Mdot
.914 .20101 Mdot
.914 .20197 Mdot
.914 .20244 Mdot
.914 .20358 Mdot
.914 .20392 Mdot
.914 .20397 Mdot
.914 .20399 Mdot
.914 .20446 Mdot
.914 .20597 Mdot
.914 .20672 Mdot
.914 .20689 Mdot
.914 .20712 Mdot
.914 .2102 Mdot
.914 .21036 Mdot
.914 .21169 Mdot
.914 .21236 Mdot
.914 .21322 Mdot
.914 .21331 Mdot
.914 .21333 Mdot
.914 .21505 Mdot
.914 .21536 Mdot
.914 .21569 Mdot
.914 .21633 Mdot
.914 .21722 Mdot
.914 .21796 Mdot
.914 .21808 Mdot
.914 .21859 Mdot
.914 .21936 Mdot
.914 .22063 Mdot
.914 .22077 Mdot
.914 .22081 Mdot
.914 .2211 Mdot
.914 .22175 Mdot
.914 .22181 Mdot
.914 .2225 Mdot
.914 .22256 Mdot
.914 .22417 Mdot
.914 .22421 Mdot
.914 .22447 Mdot
.914 .22485 Mdot
.914 .22565 Mdot
.914 .22627 Mdot
.914 .22658 Mdot
.914 .22675 Mdot
.914 .2271 Mdot
.914 .22741 Mdot
.914 .22752 Mdot
.914 .22787 Mdot
.914 .22855 Mdot
.914 .22921 Mdot
.914 .2293 Mdot
.914 .22934 Mdot
.914 .2299 Mdot
.914 .23077 Mdot
.914 .23079 Mdot
.914 .23151 Mdot
.914 .23181 Mdot
.914 .2331 Mdot
.914 .23392 Mdot
.914 .23398 Mdot
.914 .23497 Mdot
.914 .23501 Mdot
.914 .23541 Mdot
.914 .23561 Mdot
.914 .2359 Mdot
.914 .23661 Mdot
.914 .2368 Mdot
.914 .23809 Mdot
.914 .23814 Mdot
.914 .23924 Mdot
.914 .23935 Mdot
.914 .23978 Mdot
.914 .23987 Mdot
.914 .23992 Mdot
.914 .24112 Mdot
.914 .24134 Mdot
.914 .24207 Mdot
.914 .24239 Mdot
.914 .24266 Mdot
.914 .24331 Mdot
.914 .24422 Mdot
.914 .2446 Mdot
.914 .24515 Mdot
.914 .24526 Mdot
.914 .24543 Mdot
.914 .24546 Mdot
.914 .24552 Mdot
.914 .24777 Mdot
.914 .24793 Mdot
.914 .24849 Mdot
.914 .2499 Mdot
.914 .25022 Mdot
.914 .25041 Mdot
.914 .25058 Mdot
.914 .25164 Mdot
.914 .25218 Mdot
.914 .2523 Mdot
.914 .25267 Mdot
.914 .25289 Mdot
.914 .25298 Mdot
.914 .25352 Mdot
.914 .25433 Mdot
.914 .25433 Mdot
.914 .2548 Mdot
.914 .25523 Mdot
.914 .25538 Mdot
.914 .25541 Mdot
.914 .25772 Mdot
.914 .2582 Mdot
.914 .26009 Mdot
.914 .26117 Mdot
.914 .26118 Mdot
.914 .2615 Mdot
.914 .26179 Mdot
.914 .26236 Mdot
.914 .26238 Mdot
.914 .26296 Mdot
.914 .26314 Mdot
.914 .26365 Mdot
.914 .26405 Mdot
.914 .26453 Mdot
.914 .26462 Mdot
.914 .26532 Mdot
.914 .26553 Mdot
.914 .26571 Mdot
.914 .26593 Mdot
.914 .26597 Mdot
.914 .26744 Mdot
.914 .26773 Mdot
.914 .26812 Mdot
.914 .26819 Mdot
.914 .26844 Mdot
.914 .2688 Mdot
.914 .26893 Mdot
.914 .26934 Mdot
.914 .26969 Mdot
.914 .27011 Mdot
.914 .27038 Mdot
.914 .27042 Mdot
.914 .27068 Mdot
.914 .272 Mdot
.914 .27202 Mdot
.914 .27203 Mdot
.914 .2722 Mdot
.914 .2735 Mdot
.914 .27381 Mdot
.914 .27468 Mdot
.914 .27491 Mdot
.914 .27491 Mdot
.914 .27647 Mdot
.914 .27674 Mdot
.914 .27704 Mdot
.914 .27712 Mdot
.914 .27719 Mdot
.914 .2774 Mdot
.914 .27787 Mdot
.914 .27792 Mdot
.914 .2783 Mdot
.914 .27842 Mdot
.914 .27843 Mdot
.914 .27853 Mdot
.914 .27866 Mdot
.914 .27939 Mdot
.914 .27995 Mdot
.914 .28114 Mdot
.914 .28356 Mdot
.914 .28371 Mdot
.914 .28439 Mdot
.914 .28451 Mdot
.914 .28496 Mdot
.914 .28525 Mdot
.914 .28537 Mdot
.914 .28561 Mdot
.914 .28562 Mdot
.914 .28607 Mdot
.914 .28622 Mdot
.914 .28645 Mdot
.914 .28718 Mdot
.914 .28728 Mdot
.914 .28733 Mdot
.914 .28785 Mdot
.914 .28881 Mdot
.914 .28967 Mdot
.914 .28975 Mdot
.914 .29071 Mdot
.914 .29132 Mdot
.914 .29136 Mdot
.914 .29159 Mdot
.914 .29183 Mdot
.914 .29217 Mdot
.914 .29416 Mdot
.914 .29458 Mdot
.914 .29594 Mdot
.914 .29626 Mdot
.914 .29747 Mdot
.914 .29775 Mdot
.914 .2978 Mdot
.914 .29885 Mdot
.914 .29948 Mdot
.914 .29985 Mdot
.914 .30173 Mdot
.914 .30182 Mdot
.914 .30237 Mdot
.914 .30374 Mdot
.914 .30433 Mdot
.914 .30473 Mdot
.914 .30601 Mdot
.914 .30604 Mdot
.914 .30608 Mdot
.914 .30632 Mdot
.914 .30669 Mdot
.914 .30686 Mdot
.914 .30737 Mdot
.914 .30796 Mdot
.914 .30899 Mdot
.914 .30919 Mdot
.914 .3093 Mdot
.914 .30944 Mdot
.914 .30956 Mdot
.914 .31023 Mdot
.914 .31078 Mdot
.914 .31164 Mdot
.914 .31212 Mdot
.914 .31232 Mdot
.914 .31292 Mdot
.914 .31365 Mdot
.914 .31382 Mdot
.914 .31424 Mdot
.914 .31481 Mdot
.914 .31514 Mdot
.914 .31546 Mdot
.914 .317 Mdot
.914 .3175 Mdot
.914 .31866 Mdot
.914 .3187 Mdot
.914 .31894 Mdot
.914 .31952 Mdot
.914 .31969 Mdot
.914 .32082 Mdot
.914 .32091 Mdot
.914 .32098 Mdot
.914 .32121 Mdot
.914 .32127 Mdot
.914 .32181 Mdot
.914 .32185 Mdot
.914 .32193 Mdot
.914 .32205 Mdot
.914 .32206 Mdot
.914 .32283 Mdot
.914 .32325 Mdot
.914 .32326 Mdot
.914 .32369 Mdot
.914 .32399 Mdot
.914 .3247 Mdot
.914 .32507 Mdot
.914 .32588 Mdot
.914 .32623 Mdot
.914 .32656 Mdot
.914 .32734 Mdot
.914 .32763 Mdot
.914 .32853 Mdot
.914 .32865 Mdot
.914 .32872 Mdot
.914 .32901 Mdot
.914 .32955 Mdot
.914 .33076 Mdot
.914 .33284 Mdot
.914 .33344 Mdot
.914 .33368 Mdot
.914 .33396 Mdot
.914 .334 Mdot
.914 .33403 Mdot
.914 .33462 Mdot
.914 .33691 Mdot
.914 .33747 Mdot
.914 .33769 Mdot
.914 .33791 Mdot
.914 .33799 Mdot
.914 .33896 Mdot
.914 .33999 Mdot
.914 .34083 Mdot
.914 .34113 Mdot
.914 .34289 Mdot
.914 .34367 Mdot
.914 .34369 Mdot
.914 .34418 Mdot
.914 .34469 Mdot
.914 .34516 Mdot
.914 .34523 Mdot
.914 .34553 Mdot
.914 .34645 Mdot
.914 .34656 Mdot
.914 .3489 Mdot
.914 .3498 Mdot
.914 .3508 Mdot
.914 .35094 Mdot
.914 .35106 Mdot
.914 .35129 Mdot
.914 .35199 Mdot
.914 .35252 Mdot
.914 .35276 Mdot
.914 .35357 Mdot
.914 .35373 Mdot
.914 .35441 Mdot
.914 .35454 Mdot
.914 .35502 Mdot
.914 .35527 Mdot
.914 .35541 Mdot
.914 .35542 Mdot
.914 .35576 Mdot
.914 .35621 Mdot
.914 .35702 Mdot
.914 .35787 Mdot
.914 .35864 Mdot
.914 .35997 Mdot
.914 .36052 Mdot
.914 .36058 Mdot
.914 .36067 Mdot
.914 .36071 Mdot
.914 .36158 Mdot
.914 .36433 Mdot
.914 .3645 Mdot
.914 .3657 Mdot
.914 .36601 Mdot
.914 .36643 Mdot
.914 .37206 Mdot
.914 .37235 Mdot
.914 .37258 Mdot
.914 .37308 Mdot
.914 .37479 Mdot
.914 .37536 Mdot
.914 .37575 Mdot
.914 .37601 Mdot
.914 .37726 Mdot
.914 .37759 Mdot
.914 .37775 Mdot
.914 .37778 Mdot
.914 .37822 Mdot
.914 .37861 Mdot
.914 .37944 Mdot
.914 .37947 Mdot
.914 .38093 Mdot
.914 .38098 Mdot
.914 .38146 Mdot
.914 .3815 Mdot
.914 .3821 Mdot
.914 .38224 Mdot
.914 .38326 Mdot
.914 .38469 Mdot
.914 .38489 Mdot
.914 .38501 Mdot
.914 .38518 Mdot
.914 .38625 Mdot
.914 .38647 Mdot
.914 .38692 Mdot
.914 .3874 Mdot
.914 .38881 Mdot
.914 .39013 Mdot
.914 .39113 Mdot
.914 .39139 Mdot
.914 .39146 Mdot
.914 .39198 Mdot
.914 .39299 Mdot
.914 .39318 Mdot
.914 .39325 Mdot
.914 .39455 Mdot
.914 .39465 Mdot
.914 .39648 Mdot
.914 .39759 Mdot
.914 .39766 Mdot
.914 .39815 Mdot
.914 .39852 Mdot
.914 .39863 Mdot
.914 .39883 Mdot
.914 .3994 Mdot
.914 .4002 Mdot
.914 .4003 Mdot
.914 .40136 Mdot
.914 .40144 Mdot
.914 .402 Mdot
.914 .40231 Mdot
.914 .40295 Mdot
.914 .40351 Mdot
.914 .40372 Mdot
.914 .40437 Mdot
.914 .4056 Mdot
.914 .40682 Mdot
.914 .40698 Mdot
.914 .40705 Mdot
.914 .40799 Mdot
.914 .40808 Mdot
.914 .40939 Mdot
.914 .40967 Mdot
.914 .4097 Mdot
.914 .41102 Mdot
.914 .41156 Mdot
.914 .41393 Mdot
.914 .41394 Mdot
.914 .41502 Mdot
.914 .41543 Mdot
.914 .41552 Mdot
.914 .41734 Mdot
.914 .41742 Mdot
.914 .41815 Mdot
.914 .41852 Mdot
.914 .41904 Mdot
.914 .41905 Mdot
.914 .41999 Mdot
.914 .42016 Mdot
.914 .42034 Mdot
.914 .42069 Mdot
.914 .42304 Mdot
.914 .42314 Mdot
.914 .42369 Mdot
.914 .42514 Mdot
.914 .42535 Mdot
.914 .42579 Mdot
.914 .42613 Mdot
.914 .42629 Mdot
.914 .42639 Mdot
.914 .427 Mdot
.914 .42859 Mdot
.914 .42899 Mdot
.914 .43031 Mdot
.914 .43091 Mdot
.914 .43139 Mdot
.914 .43259 Mdot
.914 .43328 Mdot
.914 .43359 Mdot
.914 .43425 Mdot
.914 .43495 Mdot
.914 .43545 Mdot
.914 .43595 Mdot
.914 .43615 Mdot
.914 .43645 Mdot
.914 .43652 Mdot
.914 .43662 Mdot
.914 .44001 Mdot
.914 .44074 Mdot
.914 .44103 Mdot
.914 .44197 Mdot
.914 .44205 Mdot
.914 .44333 Mdot
.914 .44463 Mdot
.914 .44522 Mdot
.914 .44556 Mdot
.914 .44587 Mdot
.914 .4476 Mdot
.914 .4477 Mdot
.914 .44782 Mdot
.914 .44785 Mdot
.914 .44865 Mdot
.914 .44881 Mdot
.914 .44902 Mdot
.914 .44969 Mdot
.914 .44988 Mdot
.914 .45011 Mdot
.914 .45026 Mdot
.914 .45042 Mdot
.914 .45125 Mdot
.914 .45213 Mdot
.914 .45273 Mdot
.914 .45274 Mdot
.914 .45359 Mdot
.914 .4541 Mdot
.914 .45438 Mdot
.914 .45466 Mdot
.914 .45471 Mdot
.914 .45755 Mdot
.914 .45823 Mdot
.914 .45859 Mdot
.914 .45892 Mdot
.914 .45905 Mdot
.914 .45945 Mdot
.914 .45981 Mdot
.914 .46171 Mdot
.914 .46326 Mdot
.914 .46523 Mdot
.914 .46526 Mdot
.914 .46583 Mdot
.914 .46638 Mdot
.914 .4674 Mdot
.914 .46746 Mdot
.914 .46851 Mdot
.914 .46883 Mdot
.914 .46976 Mdot
.914 .47049 Mdot
.914 .47138 Mdot
.914 .47155 Mdot
.914 .47283 Mdot
.914 .4732 Mdot
.914 .47353 Mdot
.914 .47393 Mdot
.914 .47402 Mdot
.914 .47669 Mdot
.914 .47723 Mdot
.914 .47794 Mdot
.914 .47806 Mdot
.914 .47852 Mdot
.914 .47918 Mdot
.914 .47942 Mdot
.914 .48017 Mdot
.914 .48081 Mdot
.914 .48157 Mdot
.914 .48207 Mdot
.914 .48214 Mdot
.914 .48262 Mdot
.914 .48504 Mdot
.914 .48506 Mdot
.914 .48508 Mdot
.914 .4854 Mdot
.914 .48777 Mdot
.914 .48834 Mdot
.914 .48992 Mdot
.914 .49035 Mdot
.914 .49036 Mdot
.914 .49321 Mdot
.914 .4937 Mdot
.914 .49425 Mdot
.914 .49439 Mdot
.914 .49452 Mdot
.914 .4949 Mdot
.914 .49576 Mdot
.914 .49585 Mdot
.914 .49656 Mdot
.914 .49677 Mdot
.914 .49678 Mdot
.914 .49696 Mdot
.914 .49721 Mdot
.914 .49854 Mdot
.914 .49957 Mdot
.914 .50175 Mdot
.914 .50616 Mdot
.914 .50644 Mdot
.914 .50769 Mdot
.914 .5079 Mdot
.914 .50872 Mdot
.914 .50925 Mdot
.914 .50946 Mdot
.914 .50992 Mdot
.914 .50993 Mdot
.914 .51076 Mdot
.914 .51102 Mdot
.914 .51145 Mdot
.914 .51279 Mdot
.914 .51296 Mdot
.914 .51306 Mdot
.914 .51401 Mdot
.914 .51576 Mdot
.914 .51733 Mdot
.914 .51747 Mdot
.914 .51924 Mdot
.914 .52036 Mdot
.914 .52042 Mdot
.914 .52083 Mdot
.914 .52127 Mdot
.914 .52191 Mdot
.914 .52554 Mdot
.914 .5263 Mdot
.914 .52879 Mdot
.914 .52938 Mdot
.914 .53158 Mdot
.914 .5321 Mdot
.914 .53219 Mdot
.914 .53412 Mdot
.914 .53527 Mdot
.914 .53594 Mdot
.914 .53937 Mdot
.914 .53954 Mdot
.914 .54056 Mdot
.914 .54305 Mdot
.914 .54412 Mdot
.914 .54487 Mdot
.914 .5472 Mdot
.914 .54726 Mdot
.914 .54734 Mdot
.914 .54778 Mdot
.914 .54845 Mdot
.914 .54875 Mdot
.914 .54968 Mdot
.914 .55076 Mdot
.914 .55265 Mdot
.914 .55302 Mdot
.914 .55322 Mdot
.914 .55347 Mdot
.914 .55369 Mdot
.914 .55492 Mdot
.916 .01477 Mdot
.916 .01482 Mdot
.916 .0149 Mdot
.916 .01506 Mdot
.916 .01534 Mdot
.916 .01557 Mdot
.916 .01586 Mdot
.916 .01628 Mdot
.916 .01652 Mdot
.916 .01682 Mdot
.916 .01759 Mdot
.916 .01802 Mdot
.916 .01803 Mdot
.916 .01857 Mdot
.916 .01993 Mdot
.916 .01998 Mdot
.916 .02071 Mdot
.916 .02078 Mdot
.916 .02078 Mdot
.916 .02081 Mdot
.916 .02085 Mdot
.916 .02119 Mdot
.916 .02178 Mdot
.916 .02254 Mdot
.916 .02263 Mdot
.916 .02339 Mdot
.916 .0235 Mdot
.916 .02355 Mdot
.916 .02406 Mdot
.916 .02427 Mdot
.916 .02436 Mdot
.916 .0257 Mdot
.916 .02582 Mdot
.916 .02583 Mdot
.916 .02589 Mdot
.916 .02596 Mdot
.916 .02596 Mdot
.916 .02657 Mdot
.916 .02661 Mdot
.916 .02767 Mdot
.916 .02904 Mdot
.916 .02921 Mdot
.916 .02927 Mdot
.916 .03061 Mdot
.916 .03081 Mdot
.916 .0309 Mdot
.916 .03184 Mdot
.916 .03222 Mdot
.916 .03238 Mdot
.916 .03243 Mdot
.916 .03386 Mdot
.916 .03485 Mdot
.916 .03506 Mdot
.916 .03507 Mdot
.916 .03513 Mdot
.916 .03518 Mdot
.916 .03531 Mdot
.916 .03532 Mdot
.916 .03626 Mdot
.916 .03644 Mdot
.916 .03651 Mdot
.916 .03695 Mdot
.916 .03761 Mdot
.916 .03844 Mdot
.916 .03937 Mdot
.916 .03994 Mdot
.916 .04094 Mdot
.916 .04097 Mdot
.916 .04128 Mdot
.916 .04135 Mdot
.916 .04139 Mdot
.916 .04201 Mdot
.916 .04338 Mdot
.916 .04384 Mdot
.916 .04421 Mdot
.916 .04426 Mdot
.916 .04437 Mdot
.916 .04544 Mdot
.916 .04608 Mdot
.916 .04678 Mdot
.916 .04708 Mdot
.916 .04716 Mdot
.916 .04835 Mdot
.916 .04979 Mdot
.916 .0516 Mdot
.916 .05199 Mdot
.916 .05201 Mdot
.916 .05212 Mdot
.916 .05221 Mdot
.916 .05244 Mdot
.916 .05246 Mdot
.916 .05337 Mdot
.916 .05418 Mdot
.916 .05443 Mdot
.916 .05451 Mdot
.916 .05464 Mdot
.916 .05476 Mdot
.916 .05495 Mdot
.916 .05499 Mdot
.916 .05512 Mdot
.916 .05545 Mdot
.916 .05568 Mdot
.916 .05576 Mdot
.916 .05664 Mdot
.916 .05667 Mdot
.916 .05669 Mdot
.916 .05804 Mdot
.916 .05818 Mdot
.916 .05988 Mdot
.916 .06093 Mdot
.916 .06137 Mdot
.916 .06206 Mdot
.916 .06276 Mdot
.916 .06281 Mdot
.916 .06338 Mdot
.916 .06351 Mdot
.916 .06357 Mdot
.916 .0645 Mdot
.916 .06472 Mdot
.916 .06579 Mdot
.916 .06665 Mdot
.916 .06722 Mdot
.916 .06769 Mdot
.916 .06807 Mdot
.916 .06874 Mdot
.916 .06883 Mdot
.916 .06904 Mdot
.916 .06927 Mdot
.916 .06973 Mdot
.916 .071 Mdot
.916 .07147 Mdot
.916 .07163 Mdot
.916 .07218 Mdot
.916 .07346 Mdot
.916 .07348 Mdot
.916 .074 Mdot
.916 .07405 Mdot
.916 .07409 Mdot
.916 .07415 Mdot
.916 .07441 Mdot
.916 .07634 Mdot
.916 .07737 Mdot
.916 .0787 Mdot
.916 .07897 Mdot
.916 .07988 Mdot
.916 .0816 Mdot
.916 .08229 Mdot
.916 .08263 Mdot
.916 .08276 Mdot
.916 .083 Mdot
.916 .08303 Mdot
.916 .08324 Mdot
.916 .0834 Mdot
.916 .08383 Mdot
.916 .08386 Mdot
.916 .08405 Mdot
.916 .08448 Mdot
.916 .08498 Mdot
.916 .08554 Mdot
.916 .08555 Mdot
.916 .08691 Mdot
.916 .08701 Mdot
.916 .08725 Mdot
.916 .08746 Mdot
.916 .08758 Mdot
.916 .08762 Mdot
.916 .08786 Mdot
.916 .08807 Mdot
.916 .08843 Mdot
.916 .0885 Mdot
.916 .08869 Mdot
.916 .08873 Mdot
.916 .08886 Mdot
.916 .08931 Mdot
.916 .08934 Mdot
.916 .08935 Mdot
.916 .08943 Mdot
.916 .08976 Mdot
.916 .08991 Mdot
.916 .09153 Mdot
.916 .09157 Mdot
.916 .09162 Mdot
.916 .0917 Mdot
.916 .09221 Mdot
.916 .09257 Mdot
.916 .09278 Mdot
.916 .09408 Mdot
.916 .09435 Mdot
.916 .09441 Mdot
.916 .09746 Mdot
.916 .09938 Mdot
.916 .10019 Mdot
.916 .10106 Mdot
.916 .10146 Mdot
.916 .10147 Mdot
.916 .10274 Mdot
.916 .10282 Mdot
.916 .10387 Mdot
.916 .1041 Mdot
.916 .10423 Mdot
.916 .10475 Mdot
.916 .10593 Mdot
.916 .10632 Mdot
.916 .10708 Mdot
.916 .10829 Mdot
.916 .10986 Mdot
.916 .11052 Mdot
.916 .11091 Mdot
.916 .11176 Mdot
.916 .11205 Mdot
.916 .11237 Mdot
.916 .11246 Mdot
.916 .11369 Mdot
.916 .11386 Mdot
.916 .11416 Mdot
.916 .11424 Mdot
.916 .11466 Mdot
.916 .11551 Mdot
.916 .11692 Mdot
.916 .11784 Mdot
.916 .1184 Mdot
.916 .11864 Mdot
.916 .1187 Mdot
.916 .11899 Mdot
.916 .12 Mdot
.916 .12037 Mdot
.916 .12234 Mdot
.916 .12237 Mdot
.916 .12267 Mdot
.916 .12327 Mdot
.916 .12333 Mdot
.916 .12342 Mdot
.916 .12349 Mdot
.916 .12361 Mdot
.916 .12391 Mdot
.916 .12409 Mdot
.916 .12421 Mdot
.916 .12428 Mdot
.916 .12535 Mdot
.916 .12691 Mdot
.916 .12762 Mdot
.916 .12922 Mdot
.916 .12949 Mdot
.916 .13194 Mdot
.916 .13242 Mdot
.916 .13268 Mdot
.916 .1341 Mdot
.916 .13478 Mdot
.916 .13493 Mdot
.916 .13567 Mdot
.916 .13679 Mdot
.916 .13718 Mdot
.916 .13724 Mdot
.916 .1385 Mdot
.916 .13913 Mdot
.916 .13938 Mdot
.916 .13981 Mdot
.916 .13988 Mdot
.916 .14026 Mdot
.916 .14033 Mdot
.916 .14051 Mdot
.916 .14055 Mdot
.916 .14074 Mdot
.916 .14087 Mdot
.916 .14133 Mdot
.916 .14139 Mdot
.916 .1414 Mdot
.916 .14174 Mdot
.916 .14186 Mdot
.916 .14252 Mdot
.916 .14257 Mdot
.916 .14267 Mdot
.916 .14344 Mdot
.916 .14444 Mdot
.916 .14446 Mdot
.916 .14448 Mdot
.916 .14463 Mdot
.916 .1455 Mdot
.916 .14626 Mdot
.916 .14673 Mdot
.916 .14697 Mdot
.916 .14716 Mdot
.916 .14759 Mdot
.916 .14784 Mdot
.916 .14799 Mdot
.916 .1482 Mdot
.916 .14828 Mdot
.916 .14872 Mdot
.916 .14876 Mdot
.916 .1491 Mdot
.916 .1493 Mdot
.916 .14977 Mdot
.916 .14989 Mdot
.916 .15003 Mdot
.916 .15024 Mdot
.916 .15031 Mdot
.916 .15055 Mdot
.916 .15098 Mdot
.916 .15137 Mdot
.916 .15144 Mdot
.916 .15144 Mdot
.916 .1516 Mdot
.916 .1519 Mdot
.916 .1522 Mdot
.916 .15248 Mdot
.916 .15327 Mdot
.916 .15333 Mdot
.916 .15449 Mdot
.916 .15544 Mdot
.916 .15551 Mdot
.916 .15561 Mdot
.916 .15575 Mdot
.916 .15669 Mdot
.916 .15719 Mdot
.916 .15734 Mdot
.916 .15774 Mdot
.916 .16011 Mdot
.916 .1606 Mdot
.916 .16073 Mdot
.916 .16285 Mdot
.916 .16479 Mdot
.916 .16631 Mdot
.916 .16721 Mdot
.916 .16847 Mdot
.916 .16982 Mdot
.916 .1704 Mdot
.916 .17115 Mdot
.916 .17131 Mdot
.916 .17141 Mdot
.916 .1729 Mdot
.916 .17347 Mdot
.916 .17363 Mdot
.916 .17366 Mdot
.916 .17412 Mdot
.916 .1743 Mdot
.916 .17598 Mdot
.916 .17613 Mdot
.916 .1771 Mdot
.916 .17794 Mdot
.916 .17804 Mdot
.916 .17847 Mdot
.916 .1787 Mdot
.916 .17875 Mdot
.916 .17966 Mdot
.916 .18182 Mdot
.916 .1822 Mdot
.916 .18253 Mdot
.916 .18294 Mdot
.916 .18346 Mdot
.916 .18393 Mdot
.916 .18614 Mdot
.916 .18763 Mdot
.916 .1881 Mdot
.916 .18832 Mdot
.916 .18862 Mdot
.916 .18902 Mdot
.916 .19022 Mdot
.916 .19095 Mdot
.916 .19251 Mdot
.916 .19302 Mdot
.916 .19362 Mdot
.916 .19379 Mdot
.916 .1938 Mdot
.916 .1939 Mdot
.916 .19478 Mdot
.916 .19604 Mdot
.916 .19635 Mdot
.916 .19639 Mdot
.916 .19677 Mdot
.916 .1969 Mdot
.916 .19705 Mdot
.916 .19762 Mdot
.916 .19782 Mdot
.916 .19835 Mdot
.916 .19838 Mdot
.916 .1992 Mdot
.916 .19931 Mdot
.916 .19937 Mdot
.916 .20196 Mdot
.916 .20363 Mdot
.916 .20466 Mdot
.916 .20511 Mdot
.916 .20521 Mdot
.916 .20574 Mdot
.916 .20657 Mdot
.916 .20708 Mdot
.916 .20759 Mdot
.916 .20828 Mdot
.916 .20954 Mdot
.916 .21023 Mdot
.916 .21126 Mdot
.916 .21189 Mdot
.916 .21193 Mdot
.916 .21215 Mdot
.916 .21249 Mdot
.916 .2126 Mdot
.916 .21359 Mdot
.916 .2137 Mdot
.916 .21386 Mdot
.916 .214 Mdot
.916 .21421 Mdot
.916 .21477 Mdot
.916 .21508 Mdot
.916 .21531 Mdot
.916 .21545 Mdot
.916 .21605 Mdot
.916 .21671 Mdot
.916 .21699 Mdot
.916 .2174 Mdot
.916 .21741 Mdot
.916 .21776 Mdot
.916 .22025 Mdot
.916 .22083 Mdot
.916 .22155 Mdot
.916 .22193 Mdot
.916 .2225 Mdot
.916 .2228 Mdot
.916 .22361 Mdot
.916 .22366 Mdot
.916 .2245 Mdot
.916 .22499 Mdot
.916 .22601 Mdot
.916 .22639 Mdot
.916 .22763 Mdot
.916 .22777 Mdot
.916 .22947 Mdot
.916 .22976 Mdot
.916 .23036 Mdot
.916 .23061 Mdot
.916 .23084 Mdot
.916 .23343 Mdot
.916 .23416 Mdot
.916 .23437 Mdot
.916 .23468 Mdot
.916 .23494 Mdot
.916 .2363 Mdot
.916 .23638 Mdot
.916 .23785 Mdot
.916 .23802 Mdot
.916 .23811 Mdot
.916 .23835 Mdot
.916 .23837 Mdot
.916 .23907 Mdot
.916 .23918 Mdot
.916 .23955 Mdot
.916 .24019 Mdot
.916 .2415 Mdot
.916 .24216 Mdot
.916 .2426 Mdot
.916 .24265 Mdot
.916 .24275 Mdot
.916 .2431 Mdot
.916 .24329 Mdot
.916 .24388 Mdot
.916 .24401 Mdot
.916 .24422 Mdot
.916 .24449 Mdot
.916 .24458 Mdot
.916 .24471 Mdot
.916 .24485 Mdot
.916 .24493 Mdot
.916 .24517 Mdot
.916 .24524 Mdot
.916 .24541 Mdot
.916 .2456 Mdot
.916 .24568 Mdot
.916 .2457 Mdot
.916 .24583 Mdot
.916 .24648 Mdot
.916 .24667 Mdot
.916 .24672 Mdot
.916 .24678 Mdot
.916 .2468 Mdot
.916 .24728 Mdot
.916 .24742 Mdot
.916 .24765 Mdot
.916 .24793 Mdot
.916 .2482 Mdot
.916 .24827 Mdot
.916 .24871 Mdot
.916 .24886 Mdot
.916 .24894 Mdot
.916 .24912 Mdot
.916 .25054 Mdot
.916 .25088 Mdot
.916 .25153 Mdot
.916 .25167 Mdot
.916 .25188 Mdot
.916 .25194 Mdot
.916 .25238 Mdot
.916 .2524 Mdot
.916 .25244 Mdot
.916 .25271 Mdot
.916 .25355 Mdot
.916 .25404 Mdot
.916 .25431 Mdot
.916 .25481 Mdot
.916 .25571 Mdot
.916 .25576 Mdot
.916 .25576 Mdot
.916 .25656 Mdot
.916 .25665 Mdot
.916 .2569 Mdot
.916 .25701 Mdot
.916 .25736 Mdot
.916 .25814 Mdot
.916 .25836 Mdot
.916 .2586 Mdot
.916 .25886 Mdot
.916 .25888 Mdot
.916 .25913 Mdot
.916 .25926 Mdot
.916 .25939 Mdot
.916 .2594 Mdot
.916 .25975 Mdot
.916 .26021 Mdot
.916 .26029 Mdot
.916 .26044 Mdot
.916 .26091 Mdot
.916 .26128 Mdot
.916 .26213 Mdot
.916 .26231 Mdot
.916 .26236 Mdot
.916 .26245 Mdot
.916 .26262 Mdot
.916 .26299 Mdot
.916 .26313 Mdot
.916 .26357 Mdot
.916 .26435 Mdot
.916 .26451 Mdot
.916 .26506 Mdot
.916 .26519 Mdot
.916 .2652 Mdot
.916 .26548 Mdot
.916 .26564 Mdot
.916 .26573 Mdot
.916 .26604 Mdot
.916 .26658 Mdot
.916 .26709 Mdot
.916 .26783 Mdot
.916 .26832 Mdot
.916 .26854 Mdot
.916 .26865 Mdot
.916 .26887 Mdot
.916 .26902 Mdot
.916 .26921 Mdot
.916 .27067 Mdot
.916 .27072 Mdot
.916 .27076 Mdot
.916 .27078 Mdot
.916 .27089 Mdot
.916 .27103 Mdot
.916 .2718 Mdot
.916 .27252 Mdot
.916 .27266 Mdot
.916 .27283 Mdot
.916 .27309 Mdot
.916 .27347 Mdot
.916 .27462 Mdot
.916 .27481 Mdot
.916 .27573 Mdot
.916 .27601 Mdot
.916 .27624 Mdot
.916 .27627 Mdot
.916 .27634 Mdot
.916 .27673 Mdot
.916 .27717 Mdot
.916 .27826 Mdot
.916 .27886 Mdot
.916 .28107 Mdot
.916 .28187 Mdot
.916 .28197 Mdot
.916 .28202 Mdot
.916 .28203 Mdot
.916 .28221 Mdot
.916 .28471 Mdot
.916 .28502 Mdot
.916 .28534 Mdot
.916 .28586 Mdot
.916 .2861 Mdot
.916 .28622 Mdot
.916 .28738 Mdot
.916 .28965 Mdot
.916 .29003 Mdot
.916 .29076 Mdot
.916 .29157 Mdot
.916 .29244 Mdot
.916 .29245 Mdot
.916 .2925 Mdot
.916 .29335 Mdot
.916 .29376 Mdot
.916 .29408 Mdot
.916 .29422 Mdot
.916 .29423 Mdot
.916 .29541 Mdot
.916 .2964 Mdot
.916 .29696 Mdot
.916 .29718 Mdot
.916 .29724 Mdot
.916 .29773 Mdot
.916 .29886 Mdot
.916 .29933 Mdot
.916 .29994 Mdot
.916 .30055 Mdot
.916 .3013 Mdot
.916 .3016 Mdot
.916 .30178 Mdot
.916 .30342 Mdot
.916 .30401 Mdot
.916 .30418 Mdot
.916 .30448 Mdot
.916 .3045 Mdot
.916 .30504 Mdot
.916 .30555 Mdot
.916 .30585 Mdot
.916 .3059 Mdot
.916 .3063 Mdot
.916 .30675 Mdot
.916 .30676 Mdot
.916 .30707 Mdot
.916 .30823 Mdot
.916 .31015 Mdot
.916 .31043 Mdot
.916 .31086 Mdot
.916 .31138 Mdot
.916 .3122 Mdot
.916 .31324 Mdot
.916 .31367 Mdot
.916 .31372 Mdot
.916 .31375 Mdot
.916 .31393 Mdot
.916 .31467 Mdot
.916 .31472 Mdot
.916 .31513 Mdot
.916 .31519 Mdot
.916 .31522 Mdot
.916 .3155 Mdot
.916 .31653 Mdot
.916 .31689 Mdot
.916 .31834 Mdot
.916 .32006 Mdot
.916 .32085 Mdot
.916 .32154 Mdot
.916 .32215 Mdot
.916 .32253 Mdot
.916 .3229 Mdot
.916 .32385 Mdot
.916 .32417 Mdot
.916 .32471 Mdot
.916 .32493 Mdot
.916 .32529 Mdot
.916 .32604 Mdot
.916 .32652 Mdot
.916 .32717 Mdot
.916 .32876 Mdot
.916 .3315 Mdot
.916 .33207 Mdot
.916 .33225 Mdot
.916 .33236 Mdot
.916 .33238 Mdot
.916 .33245 Mdot
.916 .33276 Mdot
.916 .3328 Mdot
.916 .33328 Mdot
.916 .33331 Mdot
.916 .33404 Mdot
.916 .33586 Mdot
.916 .33624 Mdot
.916 .33757 Mdot
.916 .33828 Mdot
.916 .33874 Mdot
.916 .33931 Mdot
.916 .34018 Mdot
.916 .34043 Mdot
.916 .34138 Mdot
.916 .34146 Mdot
.916 .34247 Mdot
.916 .34278 Mdot
.916 .34281 Mdot
.916 .34298 Mdot
.916 .34459 Mdot
.916 .34532 Mdot
.916 .34597 Mdot
.916 .3469 Mdot
.916 .34747 Mdot
.916 .34754 Mdot
.916 .34824 Mdot
.916 .34848 Mdot
.916 .34875 Mdot
.916 .34906 Mdot
.916 .3498 Mdot
.916 .34999 Mdot
.916 .35017 Mdot
.916 .35078 Mdot
.916 .35087 Mdot
.916 .35111 Mdot
.916 .35114 Mdot
.916 .35118 Mdot
.916 .35242 Mdot
.916 .3527 Mdot
.916 .35289 Mdot
.916 .35301 Mdot
.916 .3539 Mdot
.916 .35753 Mdot
.916 .35775 Mdot
.916 .35954 Mdot
.916 .36081 Mdot
.916 .36269 Mdot
.916 .36352 Mdot
.916 .3637 Mdot
.916 .36468 Mdot
.916 .36619 Mdot
.916 .36699 Mdot
.916 .36713 Mdot
.916 .36807 Mdot
.916 .36932 Mdot
.916 .36965 Mdot
.916 .37 Mdot
.916 .37016 Mdot
.916 .3702 Mdot
.916 .37079 Mdot
.916 .37164 Mdot
.916 .3729 Mdot
.916 .37479 Mdot
.916 .37593 Mdot
.916 .37601 Mdot
.916 .37642 Mdot
.916 .37703 Mdot
.916 .37724 Mdot
.916 .37897 Mdot
.916 .37906 Mdot
.916 .37919 Mdot
.916 .37926 Mdot
.916 .37955 Mdot
.916 .3798 Mdot
.916 .38018 Mdot
.916 .38024 Mdot
.916 .38121 Mdot
.916 .38131 Mdot
.916 .38179 Mdot
.916 .3822 Mdot
.916 .38245 Mdot
.916 .38306 Mdot
.916 .38357 Mdot
.916 .38386 Mdot
.916 .38426 Mdot
.916 .38478 Mdot
.916 .38528 Mdot
.916 .38603 Mdot
.916 .38606 Mdot
.916 .38669 Mdot
.916 .38817 Mdot
.916 .39126 Mdot
.916 .39232 Mdot
.916 .39363 Mdot
.916 .39432 Mdot
.916 .39538 Mdot
.916 .39579 Mdot
.916 .39593 Mdot
.916 .39705 Mdot
.916 .39741 Mdot
.916 .39751 Mdot
.916 .39903 Mdot
.916 .39949 Mdot
.916 .39993 Mdot
.916 .40182 Mdot
.916 .40222 Mdot
.916 .40251 Mdot
.916 .40478 Mdot
.916 .40504 Mdot
.916 .40516 Mdot
.916 .40532 Mdot
.916 .40815 Mdot
.916 .4082 Mdot
.916 .40868 Mdot
.916 .40956 Mdot
.916 .40977 Mdot
.916 .41024 Mdot
.916 .41063 Mdot
.916 .41065 Mdot
.916 .4111 Mdot
.916 .41116 Mdot
.916 .41512 Mdot
.916 .4154 Mdot
.916 .41674 Mdot
.916 .41712 Mdot
.916 .41768 Mdot
.916 .41817 Mdot
.916 .41841 Mdot
.916 .4203 Mdot
.916 .42066 Mdot
.916 .42081 Mdot
.916 .42104 Mdot
.916 .42123 Mdot
.916 .4229 Mdot
.916 .4235 Mdot
.916 .42382 Mdot
.916 .42398 Mdot
.916 .42442 Mdot
.916 .42445 Mdot
.916 .42573 Mdot
.916 .42594 Mdot
.916 .42662 Mdot
.916 .42669 Mdot
.916 .42778 Mdot
.916 .42824 Mdot
.916 .43018 Mdot
.916 .43029 Mdot
.916 .43139 Mdot
.916 .4322 Mdot
.916 .43229 Mdot
.916 .43234 Mdot
.916 .43248 Mdot
.916 .43312 Mdot
.916 .43347 Mdot
.916 .43455 Mdot
.916 .43479 Mdot
.916 .43487 Mdot
.916 .43517 Mdot
.916 .43567 Mdot
.916 .43582 Mdot
.916 .43587 Mdot
.916 .43606 Mdot
.916 .43632 Mdot
.916 .43647 Mdot
.916 .43648 Mdot
.916 .4369 Mdot
.916 .43703 Mdot
.916 .43734 Mdot
.916 .4377 Mdot
.916 .43784 Mdot
.916 .43788 Mdot
.916 .43812 Mdot
.916 .43931 Mdot
.916 .43966 Mdot
.916 .43974 Mdot
.916 .43985 Mdot
.916 .43989 Mdot
.916 .44077 Mdot
.916 .44103 Mdot
.916 .44145 Mdot
.916 .44197 Mdot
.916 .44197 Mdot
.916 .44246 Mdot
.916 .44259 Mdot
.916 .44339 Mdot
.916 .44367 Mdot
.916 .44381 Mdot
.916 .44395 Mdot
.916 .44415 Mdot
.916 .44453 Mdot
.916 .44555 Mdot
.916 .44562 Mdot
.916 .44674 Mdot
.916 .44736 Mdot
.916 .44741 Mdot
.916 .44856 Mdot
.916 .44882 Mdot
.916 .44913 Mdot
.916 .44921 Mdot
.916 .44931 Mdot
.916 .45011 Mdot
.916 .45014 Mdot
.916 .45016 Mdot
.916 .45023 Mdot
.916 .45031 Mdot
.916 .45073 Mdot
.916 .45164 Mdot
.916 .45227 Mdot
.916 .45315 Mdot
.916 .45317 Mdot
.916 .45321 Mdot
.916 .45366 Mdot
.916 .45425 Mdot
.916 .45458 Mdot
.916 .45622 Mdot
.916 .45631 Mdot
.916 .45631 Mdot
.916 .45777 Mdot
.916 .45794 Mdot
.916 .45812 Mdot
.916 .4584 Mdot
.916 .4586 Mdot
.916 .45923 Mdot
.916 .46068 Mdot
.916 .46108 Mdot
.916 .46152 Mdot
.916 .462 Mdot
.916 .46202 Mdot
.916 .46249 Mdot
.916 .46271 Mdot
.916 .46296 Mdot
.916 .46297 Mdot
.916 .46362 Mdot
.916 .46446 Mdot
.916 .46458 Mdot
.916 .46461 Mdot
.916 .46488 Mdot
.916 .46575 Mdot
.916 .46642 Mdot
.916 .46798 Mdot
.916 .46831 Mdot
.916 .4684 Mdot
.916 .46857 Mdot
.916 .46887 Mdot
.916 .46956 Mdot
.916 .46981 Mdot
.916 .47061 Mdot
.916 .47205 Mdot
.916 .47233 Mdot
.916 .47335 Mdot
.916 .47358 Mdot
.916 .47361 Mdot
.916 .47412 Mdot
.916 .47441 Mdot
.916 .47458 Mdot
.916 .47514 Mdot
.916 .47613 Mdot
.916 .47707 Mdot
.916 .47842 Mdot
.916 .47931 Mdot
.916 .47973 Mdot
.916 .47993 Mdot
.916 .48033 Mdot
.916 .4806 Mdot
.916 .48095 Mdot
.916 .48363 Mdot
.916 .48372 Mdot
.916 .48379 Mdot
.916 .48383 Mdot
.916 .48402 Mdot
.916 .48429 Mdot
.916 .4857 Mdot
.916 .48701 Mdot
.916 .48727 Mdot
.916 .48758 Mdot
.916 .48805 Mdot
.916 .48875 Mdot
.916 .49086 Mdot
.916 .49121 Mdot
.916 .4929 Mdot
.916 .4934 Mdot
.916 .49384 Mdot
.916 .49389 Mdot
.916 .49402 Mdot
.916 .49473 Mdot
.916 .49554 Mdot
.916 .49752 Mdot
.916 .49862 Mdot
.916 .50269 Mdot
.916 .50414 Mdot
.916 .50433 Mdot
.916 .50442 Mdot
.916 .50444 Mdot
.916 .50476 Mdot
.916 .50935 Mdot
.916 .50992 Mdot
.916 .5105 Mdot
.916 .51146 Mdot
.916 .51189 Mdot
.916 .51211 Mdot
.916 .51425 Mdot
.916 .5184 Mdot
.916 .51909 Mdot
.916 .52043 Mdot
.916 .52192 Mdot
.916 .52352 Mdot
.916 .52361 Mdot
.916 .52518 Mdot
.916 .52592 Mdot
.916 .52651 Mdot
.916 .52676 Mdot
.916 .52679 Mdot
.916 .52896 Mdot
.916 .53076 Mdot
.916 .53178 Mdot
.916 .53219 Mdot
.916 .53229 Mdot
.916 .53321 Mdot
.916 .53528 Mdot
.916 .53612 Mdot
.916 .53724 Mdot
.916 .53836 Mdot
.916 .53974 Mdot
.916 .54028 Mdot
.916 .54062 Mdot
.916 .54361 Mdot
.916 .5447 Mdot
.916 .54501 Mdot
.916 .54557 Mdot
.916 .54561 Mdot
.916 .54659 Mdot
.916 .54752 Mdot
.916 .54807 Mdot
.916 .54816 Mdot
.916 .54889 Mdot
.916 .54972 Mdot
.916 .54975 Mdot
.916 .55032 Mdot
.916 .55243 Mdot
.916 .55596 Mdot
.918 .01777 Mdot
.918 .02032 Mdot
.918 .02054 Mdot
.918 .02068 Mdot
.918 .02289 Mdot
.918 .02333 Mdot
.918 .02337 Mdot
.918 .02352 Mdot
.918 .02354 Mdot
.918 .02498 Mdot
.918 .02501 Mdot
.918 .0254 Mdot
.918 .02566 Mdot
.918 .02973 Mdot
.918 .02975 Mdot
.918 .03004 Mdot
.918 .03046 Mdot
.918 .03053 Mdot
.918 .03061 Mdot
.918 .03088 Mdot
.918 .03092 Mdot
.918 .03153 Mdot
.918 .03294 Mdot
.918 .03356 Mdot
.918 .03362 Mdot
.918 .03434 Mdot
.918 .03482 Mdot
.918 .0349 Mdot
.918 .03559 Mdot
.918 .03736 Mdot
.918 .03862 Mdot
.918 .03864 Mdot
.918 .04174 Mdot
.918 .04228 Mdot
.918 .04231 Mdot
.918 .04246 Mdot
.918 .04285 Mdot
.918 .04333 Mdot
.918 .04362 Mdot
.918 .04374 Mdot
.918 .04389 Mdot
.918 .04403 Mdot
.918 .04419 Mdot
.918 .04439 Mdot
.918 .04447 Mdot
.918 .04449 Mdot
.918 .04506 Mdot
.918 .04558 Mdot
.918 .04693 Mdot
.918 .04761 Mdot
.918 .04818 Mdot
.918 .04932 Mdot
.918 .04942 Mdot
.918 .04942 Mdot
.918 .04964 Mdot
.918 .04967 Mdot
.918 .04984 Mdot
.918 .05001 Mdot
.918 .05073 Mdot
.918 .05074 Mdot
.918 .05163 Mdot
.918 .05177 Mdot
.918 .05293 Mdot
.918 .05303 Mdot
.918 .0557 Mdot
.918 .05628 Mdot
.918 .05861 Mdot
.918 .05864 Mdot
.918 .05873 Mdot
.918 .05962 Mdot
.918 .06062 Mdot
.918 .06111 Mdot
.918 .06121 Mdot
.918 .06173 Mdot
.918 .06231 Mdot
.918 .06244 Mdot
.918 .06302 Mdot
.918 .06327 Mdot
.918 .06409 Mdot
.918 .06433 Mdot
.918 .06533 Mdot
.918 .06539 Mdot
.918 .06556 Mdot
.918 .06566 Mdot
.918 .06636 Mdot
.918 .06653 Mdot
.918 .06668 Mdot
.918 .06725 Mdot
.918 .06732 Mdot
.918 .06778 Mdot
.918 .06801 Mdot
.918 .06829 Mdot
.918 .06854 Mdot
.918 .06874 Mdot
.918 .06883 Mdot
.918 .0692 Mdot
.918 .06935 Mdot
.918 .06939 Mdot
.918 .06944 Mdot
.918 .06965 Mdot
.918 .0697 Mdot
.918 .07033 Mdot
.918 .07036 Mdot
.918 .07042 Mdot
.918 .0705 Mdot
.918 .07139 Mdot
.918 .07262 Mdot
.918 .07336 Mdot
.918 .07368 Mdot
.918 .07386 Mdot
.918 .07395 Mdot
.918 .07448 Mdot
.918 .07485 Mdot
.918 .07511 Mdot
.918 .07541 Mdot
.918 .0755 Mdot
.918 .07562 Mdot
.918 .07615 Mdot
.918 .07744 Mdot
.918 .07825 Mdot
.918 .07843 Mdot
.918 .07844 Mdot
.918 .07884 Mdot
.918 .07889 Mdot
.918 .0792 Mdot
.918 .07951 Mdot
.918 .08049 Mdot
.918 .0806 Mdot
.918 .08084 Mdot
.918 .08086 Mdot
.918 .08211 Mdot
.918 .08231 Mdot
.918 .08248 Mdot
.918 .08253 Mdot
.918 .08259 Mdot
.918 .08274 Mdot
.918 .08349 Mdot
.918 .0838 Mdot
.918 .08472 Mdot
.918 .08488 Mdot
.918 .08507 Mdot
.918 .08574 Mdot
.918 .08674 Mdot
.918 .08691 Mdot
.918 .08992 Mdot
.918 .08997 Mdot
.918 .09018 Mdot
.918 .09095 Mdot
.918 .091 Mdot
.918 .09103 Mdot
.918 .09261 Mdot
.918 .09308 Mdot
.918 .0933 Mdot
.918 .09371 Mdot
.918 .09428 Mdot
.918 .0953 Mdot
.918 .09535 Mdot
.918 .09552 Mdot
.918 .09603 Mdot
.918 .09662 Mdot
.918 .09708 Mdot
.918 .09717 Mdot
.918 .09758 Mdot
.918 .09797 Mdot
.918 .09862 Mdot
.918 .09899 Mdot
.918 .09989 Mdot
.918 .09999 Mdot
.918 .10008 Mdot
.918 .10022 Mdot
.918 .10103 Mdot
.918 .10116 Mdot
.918 .10209 Mdot
.918 .10233 Mdot
.918 .10339 Mdot
.918 .10382 Mdot
.918 .10383 Mdot
.918 .10386 Mdot
.918 .10409 Mdot
.918 .10486 Mdot
.918 .10497 Mdot
.918 .10538 Mdot
.918 .10569 Mdot
.918 .1058 Mdot
.918 .10764 Mdot
.918 .10775 Mdot
.918 .10807 Mdot
.918 .10825 Mdot
.918 .10861 Mdot
.918 .10954 Mdot
.918 .10969 Mdot
.918 .10985 Mdot
.918 .10993 Mdot
.918 .10994 Mdot
.918 .11003 Mdot
.918 .11012 Mdot
.918 .11116 Mdot
.918 .11131 Mdot
.918 .11191 Mdot
.918 .11215 Mdot
.918 .11257 Mdot
.918 .11308 Mdot
.918 .11354 Mdot
.918 .11391 Mdot
.918 .11407 Mdot
.918 .11462 Mdot
.918 .11475 Mdot
.918 .11502 Mdot
.918 .11509 Mdot
.918 .11519 Mdot
.918 .11529 Mdot
.918 .11557 Mdot
.918 .11566 Mdot
.918 .11582 Mdot
.918 .11683 Mdot
.918 .11687 Mdot
.918 .117 Mdot
.918 .11713 Mdot
.918 .11877 Mdot
.918 .12104 Mdot
.918 .12238 Mdot
.918 .12297 Mdot
.918 .12311 Mdot
.918 .1233 Mdot
.918 .12347 Mdot
.918 .12373 Mdot
.918 .12444 Mdot
.918 .12512 Mdot
.918 .12529 Mdot
.918 .12561 Mdot
.918 .12616 Mdot
.918 .12632 Mdot
.918 .12653 Mdot
.918 .12752 Mdot
.918 .12986 Mdot
.918 .12988 Mdot
.918 .13137 Mdot
.918 .13169 Mdot
.918 .13171 Mdot
.918 .13244 Mdot
.918 .13254 Mdot
.918 .13311 Mdot
.918 .13368 Mdot
.918 .13506 Mdot
.918 .13549 Mdot
.918 .13568 Mdot
.918 .13612 Mdot
.918 .13616 Mdot
.918 .13664 Mdot
.918 .13687 Mdot
.918 .137 Mdot
.918 .13818 Mdot
.918 .13845 Mdot
.918 .13882 Mdot
.918 .13914 Mdot
.918 .13923 Mdot
.918 .13934 Mdot
.918 .13961 Mdot
.918 .14084 Mdot
.918 .14099 Mdot
.918 .14156 Mdot
.918 .14182 Mdot
.918 .14234 Mdot
.918 .14271 Mdot
.918 .14325 Mdot
.918 .14354 Mdot
.918 .14354 Mdot
.918 .14355 Mdot
.918 .14387 Mdot
.918 .14389 Mdot
.918 .14495 Mdot
.918 .14511 Mdot
.918 .14654 Mdot
.918 .14696 Mdot
.918 .14726 Mdot
.918 .15093 Mdot
.918 .15098 Mdot
.918 .15265 Mdot
.918 .1528 Mdot
.918 .15288 Mdot
.918 .15326 Mdot
.918 .15468 Mdot
.918 .15477 Mdot
.918 .15484 Mdot
.918 .15505 Mdot
.918 .15512 Mdot
.918 .15614 Mdot
.918 .15617 Mdot
.918 .15629 Mdot
.918 .15637 Mdot
.918 .15746 Mdot
.918 .15773 Mdot
.918 .15815 Mdot
.918 .15859 Mdot
.918 .159 Mdot
.918 .15975 Mdot
.918 .1608 Mdot
.918 .16096 Mdot
.918 .16131 Mdot
.918 .16144 Mdot
.918 .16154 Mdot
.918 .16256 Mdot
.918 .16267 Mdot
.918 .16277 Mdot
.918 .16308 Mdot
.918 .16385 Mdot
.918 .164 Mdot
.918 .16478 Mdot
.918 .16508 Mdot
.918 .16545 Mdot
.918 .16592 Mdot
.918 .16594 Mdot
.918 .1661 Mdot
.918 .16686 Mdot
.918 .16701 Mdot
.918 .16756 Mdot
.918 .16876 Mdot
.918 .16944 Mdot
.918 .16972 Mdot
.918 .16997 Mdot
.918 .17109 Mdot
.918 .17128 Mdot
.918 .17145 Mdot
.918 .17147 Mdot
.918 .17171 Mdot
.918 .17317 Mdot
.918 .17318 Mdot
.918 .17343 Mdot
.918 .17435 Mdot
.918 .17462 Mdot
.918 .17493 Mdot
.918 .17508 Mdot
.918 .17514 Mdot
.918 .17543 Mdot
.918 .17558 Mdot
.918 .17749 Mdot
.918 .17753 Mdot
.918 .17832 Mdot
.918 .17833 Mdot
.918 .17838 Mdot
.918 .17881 Mdot
.918 .18022 Mdot
.918 .18031 Mdot
.918 .18043 Mdot
.918 .18075 Mdot
.918 .18117 Mdot
.918 .18175 Mdot
.918 .18195 Mdot
.918 .18248 Mdot
.918 .18285 Mdot
.918 .18378 Mdot
.918 .18446 Mdot
.918 .1846 Mdot
.918 .18532 Mdot
.918 .18552 Mdot
.918 .18612 Mdot
.918 .18645 Mdot
.918 .1871 Mdot
.918 .18792 Mdot
.918 .18882 Mdot
.918 .18908 Mdot
.918 .18938 Mdot
.918 .18952 Mdot
.918 .18955 Mdot
.918 .18971 Mdot
.918 .18988 Mdot
.918 .19016 Mdot
.918 .19041 Mdot
.918 .19179 Mdot
.918 .192 Mdot
.918 .19206 Mdot
.918 .19226 Mdot
.918 .19227 Mdot
.918 .19294 Mdot
.918 .19316 Mdot
.918 .19325 Mdot
.918 .19349 Mdot
.918 .1936 Mdot
.918 .19379 Mdot
.918 .19383 Mdot
.918 .19437 Mdot
.918 .19528 Mdot
.918 .19531 Mdot
.918 .19581 Mdot
.918 .1959 Mdot
.918 .19616 Mdot
.918 .19683 Mdot
.918 .19713 Mdot
.918 .19718 Mdot
.918 .19815 Mdot
.918 .19838 Mdot
.918 .19887 Mdot
.918 .19901 Mdot
.918 .1992 Mdot
.918 .19937 Mdot
.918 .19988 Mdot
.918 .20006 Mdot
.918 .20034 Mdot
.918 .20046 Mdot
.918 .20065 Mdot
.918 .20106 Mdot
.918 .20141 Mdot
.918 .2022 Mdot
.918 .20228 Mdot
.918 .2025 Mdot
.918 .20275 Mdot
.918 .20394 Mdot
.918 .20459 Mdot
.918 .2056 Mdot
.918 .20576 Mdot
.918 .2081 Mdot
.918 .20856 Mdot
.918 .20992 Mdot
.918 .21193 Mdot
.918 .21204 Mdot
.918 .21239 Mdot
.918 .21347 Mdot
.918 .21373 Mdot
.918 .21398 Mdot
.918 .21408 Mdot
.918 .2144 Mdot
.918 .21487 Mdot
.918 .21617 Mdot
.918 .21668 Mdot
.918 .21741 Mdot
.918 .21772 Mdot
.918 .21773 Mdot
.918 .21831 Mdot
.918 .21925 Mdot
.918 .21929 Mdot
.918 .21932 Mdot
.918 .21962 Mdot
.918 .22 Mdot
.918 .22048 Mdot
.918 .22182 Mdot
.918 .22312 Mdot
.918 .2232 Mdot
.918 .22329 Mdot
.918 .22333 Mdot
.918 .22344 Mdot
.918 .22405 Mdot
.918 .22553 Mdot
.918 .22612 Mdot
.918 .22616 Mdot
.918 .2264 Mdot
.918 .22781 Mdot
.918 .22788 Mdot
.918 .22835 Mdot
.918 .22863 Mdot
.918 .22889 Mdot
.918 .2289 Mdot
.918 .22949 Mdot
.918 .22951 Mdot
.918 .22989 Mdot
.918 .23086 Mdot
.918 .23092 Mdot
.918 .23104 Mdot
.918 .23209 Mdot
.918 .23313 Mdot
.918 .23327 Mdot
.918 .23568 Mdot
.918 .23598 Mdot
.918 .23644 Mdot
.918 .23645 Mdot
.918 .2368 Mdot
.918 .23759 Mdot
.918 .23761 Mdot
.918 .23764 Mdot
.918 .23765 Mdot
.918 .23768 Mdot
.918 .23856 Mdot
.918 .239 Mdot
.918 .23922 Mdot
.918 .2393 Mdot
.918 .23959 Mdot
.918 .2399 Mdot
.918 .2414 Mdot
.918 .24188 Mdot
.918 .24189 Mdot
.918 .2419 Mdot
.918 .24247 Mdot
.918 .24256 Mdot
.918 .24315 Mdot
.918 .24316 Mdot
.918 .24333 Mdot
.918 .24353 Mdot
.918 .24403 Mdot
.918 .24484 Mdot
.918 .24627 Mdot
.918 .24655 Mdot
.918 .24758 Mdot
.918 .24759 Mdot
.918 .24808 Mdot
.918 .24888 Mdot
.918 .24903 Mdot
.918 .2497 Mdot
.918 .25071 Mdot
.918 .25123 Mdot
.918 .25124 Mdot
.918 .25125 Mdot
.918 .25185 Mdot
.918 .25187 Mdot
.918 .25205 Mdot
.918 .2524 Mdot
.918 .25333 Mdot
.918 .25383 Mdot
.918 .25412 Mdot
.918 .25413 Mdot
.918 .25609 Mdot
.918 .25634 Mdot
.918 .25675 Mdot
.918 .25681 Mdot
.918 .25686 Mdot
.918 .25752 Mdot
.918 .25762 Mdot
.918 .25807 Mdot
.918 .25851 Mdot
.918 .25902 Mdot
.918 .25977 Mdot
.918 .2612 Mdot
.918 .2617 Mdot
.918 .26397 Mdot
.918 .2648 Mdot
.918 .2649 Mdot
.918 .26734 Mdot
.918 .26796 Mdot
.918 .2681 Mdot
.918 .26824 Mdot
.918 .26838 Mdot
.918 .26908 Mdot
.918 .26913 Mdot
.918 .26915 Mdot
.918 .26918 Mdot
.918 .27119 Mdot
.918 .27128 Mdot
.918 .27169 Mdot
.918 .27185 Mdot
.918 .27187 Mdot
.918 .27198 Mdot
.918 .27236 Mdot
.918 .27249 Mdot
.918 .27305 Mdot
.918 .27328 Mdot
.918 .27437 Mdot
.918 .27444 Mdot
.918 .27464 Mdot
.918 .27479 Mdot
.918 .27563 Mdot
.918 .2758 Mdot
.918 .27618 Mdot
.918 .27679 Mdot
.918 .27729 Mdot
.918 .27788 Mdot
.918 .27806 Mdot
.918 .27865 Mdot
.918 .27886 Mdot
.918 .27886 Mdot
.918 .27888 Mdot
.918 .27962 Mdot
.918 .28099 Mdot
.918 .28292 Mdot
.918 .28322 Mdot
.918 .28386 Mdot
.918 .2841 Mdot
.918 .28429 Mdot
.918 .28549 Mdot
.918 .28615 Mdot
.918 .28635 Mdot
.918 .28637 Mdot
.918 .28654 Mdot
.918 .28711 Mdot
.918 .28772 Mdot
.918 .28791 Mdot
.918 .28808 Mdot
.918 .28852 Mdot
.918 .28881 Mdot
.918 .28908 Mdot
.918 .29023 Mdot
.918 .2903 Mdot
.918 .29064 Mdot
.918 .29079 Mdot
.918 .29146 Mdot
.918 .29216 Mdot
.918 .29217 Mdot
.918 .29233 Mdot
.918 .29236 Mdot
.918 .29265 Mdot
.918 .29364 Mdot
.918 .29405 Mdot
.918 .29432 Mdot
.918 .29534 Mdot
.918 .29536 Mdot
.918 .29567 Mdot
.918 .2973 Mdot
.918 .29754 Mdot
.918 .29791 Mdot
.918 .298 Mdot
.918 .29879 Mdot
.918 .2993 Mdot
.918 .29976 Mdot
.918 .30131 Mdot
.918 .30183 Mdot
.918 .30216 Mdot
.918 .30248 Mdot
.918 .30252 Mdot
.918 .30273 Mdot
.918 .30295 Mdot
.918 .30307 Mdot
.918 .30442 Mdot
.918 .30564 Mdot
.918 .30566 Mdot
.918 .30612 Mdot
.918 .30781 Mdot
.918 .30831 Mdot
.918 .30887 Mdot
.918 .30914 Mdot
.918 .30925 Mdot
.918 .30979 Mdot
.918 .31007 Mdot
.918 .31206 Mdot
.918 .31357 Mdot
.918 .31364 Mdot
.918 .31485 Mdot
.918 .31509 Mdot
.918 .31511 Mdot
.918 .31519 Mdot
.918 .3152 Mdot
.918 .31599 Mdot
.918 .31858 Mdot
.918 .31874 Mdot
.918 .31897 Mdot
.918 .31955 Mdot
.918 .32032 Mdot
.918 .32139 Mdot
.918 .32176 Mdot
.918 .32273 Mdot
.918 .32342 Mdot
.918 .32343 Mdot
.918 .32511 Mdot
.918 .32551 Mdot
.918 .32598 Mdot
.918 .32636 Mdot
.918 .32645 Mdot
.918 .32661 Mdot
.918 .32692 Mdot
.918 .32794 Mdot
.918 .32831 Mdot
.918 .3293 Mdot
.918 .32942 Mdot
.918 .32943 Mdot
.918 .32953 Mdot
.918 .32962 Mdot
.918 .33001 Mdot
.918 .33121 Mdot
.918 .33272 Mdot
.918 .33437 Mdot
.918 .33486 Mdot
.918 .3354 Mdot
.918 .33566 Mdot
.918 .33572 Mdot
.918 .336 Mdot
.918 .33632 Mdot
.918 .33639 Mdot
.918 .3367 Mdot
.918 .33684 Mdot
.918 .33729 Mdot
.918 .33809 Mdot
.918 .33862 Mdot
.918 .3387 Mdot
.918 .33905 Mdot
.918 .33982 Mdot
.918 .3402 Mdot
.918 .34032 Mdot
.918 .34034 Mdot
.918 .34069 Mdot
.918 .3407 Mdot
.918 .34078 Mdot
.918 .34194 Mdot
.918 .34234 Mdot
.918 .34251 Mdot
.918 .34266 Mdot
.918 .34295 Mdot
.918 .34315 Mdot
.918 .34346 Mdot
.918 .3435 Mdot
.918 .34357 Mdot
.918 .34456 Mdot
.918 .34622 Mdot
.918 .34628 Mdot
.918 .3471 Mdot
.918 .34721 Mdot
.918 .34733 Mdot
.918 .34737 Mdot
.918 .34786 Mdot
.918 .34802 Mdot
.918 .34853 Mdot
.918 .34908 Mdot
.918 .34963 Mdot
.918 .34972 Mdot
.918 .35136 Mdot
.918 .3515 Mdot
.918 .35192 Mdot
.918 .35194 Mdot
.918 .35282 Mdot
.918 .35308 Mdot
.918 .3532 Mdot
.918 .35342 Mdot
.918 .35373 Mdot
.918 .35468 Mdot
.918 .355 Mdot
.918 .35526 Mdot
.918 .35553 Mdot
.918 .35574 Mdot
.918 .35609 Mdot
.918 .35684 Mdot
.918 .35697 Mdot
.918 .35748 Mdot
.918 .35893 Mdot
.918 .35893 Mdot
.918 .35908 Mdot
.918 .35949 Mdot
.918 .35956 Mdot
.918 .35995 Mdot
.918 .36154 Mdot
.918 .36212 Mdot
.918 .36225 Mdot
.918 .36226 Mdot
.918 .36231 Mdot
.918 .36333 Mdot
.918 .36481 Mdot
.918 .36517 Mdot
.918 .36546 Mdot
.918 .36944 Mdot
.918 .36977 Mdot
.918 .37062 Mdot
.918 .37311 Mdot
.918 .37595 Mdot
.918 .3768 Mdot
.918 .37693 Mdot
.918 .377 Mdot
.918 .37764 Mdot
.918 .37909 Mdot
.918 .37963 Mdot
.918 .37991 Mdot
.918 .38011 Mdot
.918 .38056 Mdot
.918 .38056 Mdot
.918 .38074 Mdot
.918 .38133 Mdot
.918 .3822 Mdot
.918 .38459 Mdot
.918 .38462 Mdot
.918 .38552 Mdot
.918 .38683 Mdot
.918 .38687 Mdot
.918 .38742 Mdot
.918 .38744 Mdot
.918 .3875 Mdot
.918 .38755 Mdot
.918 .38814 Mdot
.918 .38852 Mdot
.918 .39005 Mdot
.918 .39024 Mdot
.918 .39031 Mdot
.918 .39037 Mdot
.918 .39092 Mdot
.918 .39162 Mdot
.918 .39213 Mdot
.918 .3925 Mdot
.918 .39275 Mdot
.918 .39334 Mdot
.918 .39482 Mdot
.918 .39496 Mdot
.918 .39578 Mdot
.918 .3967 Mdot
.918 .39734 Mdot
.918 .39749 Mdot
.918 .39766 Mdot
.918 .39774 Mdot
.918 .39793 Mdot
.918 .39905 Mdot
.918 .40059 Mdot
.918 .40083 Mdot
.918 .40177 Mdot
.918 .40197 Mdot
.918 .40248 Mdot
.918 .40285 Mdot
.918 .40292 Mdot
.918 .40337 Mdot
.918 .40473 Mdot
.918 .40596 Mdot
.918 .40609 Mdot
.918 .40695 Mdot
.918 .4071 Mdot
.918 .4071 Mdot
.918 .40747 Mdot
.918 .40764 Mdot
.918 .40777 Mdot
.918 .40793 Mdot
.918 .40795 Mdot
.918 .40874 Mdot
.918 .40903 Mdot
.918 .40908 Mdot
.918 .40978 Mdot
.918 .41156 Mdot
.918 .41167 Mdot
.918 .41189 Mdot
.918 .41208 Mdot
.918 .41346 Mdot
.918 .41382 Mdot
.918 .41436 Mdot
.918 .41573 Mdot
.918 .41598 Mdot
.918 .41781 Mdot
.918 .41787 Mdot
.918 .41893 Mdot
.918 .4204 Mdot
.918 .42096 Mdot
.918 .4218 Mdot
.918 .42182 Mdot
.918 .42247 Mdot
.918 .42391 Mdot
.918 .42395 Mdot
.918 .424 Mdot
.918 .42402 Mdot
.918 .42408 Mdot
.918 .42441 Mdot
.918 .42522 Mdot
.918 .42569 Mdot
.918 .42646 Mdot
.918 .4265 Mdot
.918 .42676 Mdot
.918 .42691 Mdot
.918 .42705 Mdot
.918 .42759 Mdot
.918 .42816 Mdot
.918 .42943 Mdot
.918 .43091 Mdot
.918 .43116 Mdot
.918 .43179 Mdot
.918 .43181 Mdot
.918 .43182 Mdot
.918 .43272 Mdot
.918 .43288 Mdot
.918 .43305 Mdot
.918 .43412 Mdot
.918 .43413 Mdot
.918 .43445 Mdot
.918 .43482 Mdot
.918 .43574 Mdot
.918 .43723 Mdot
.918 .43794 Mdot
.918 .43966 Mdot
.918 .43985 Mdot
.918 .44036 Mdot
.918 .44079 Mdot
.918 .44186 Mdot
.918 .442 Mdot
.918 .44225 Mdot
.918 .44228 Mdot
.918 .4427 Mdot
.918 .44318 Mdot
.918 .44346 Mdot
.918 .44387 Mdot
.918 .44465 Mdot
.918 .44492 Mdot
.918 .44616 Mdot
.918 .44799 Mdot
.918 .44841 Mdot
.918 .44896 Mdot
.918 .44898 Mdot
.918 .44899 Mdot
.918 .45009 Mdot
.918 .45014 Mdot
.918 .45046 Mdot
.918 .4511 Mdot
.918 .45251 Mdot
.918 .4526 Mdot
.918 .4528 Mdot
.918 .45373 Mdot
.918 .45415 Mdot
.918 .45427 Mdot
.918 .45428 Mdot
.918 .45788 Mdot
.918 .45835 Mdot
.918 .45909 Mdot
.918 .45919 Mdot
.918 .45929 Mdot
.918 .45983 Mdot
.918 .4605 Mdot
.918 .46068 Mdot
.918 .46151 Mdot
.918 .46151 Mdot
.918 .46232 Mdot
.918 .46325 Mdot
.918 .46342 Mdot
.918 .46431 Mdot
.918 .46464 Mdot
.918 .46469 Mdot
.918 .4665 Mdot
.918 .46726 Mdot
.918 .46745 Mdot
.918 .46819 Mdot
.918 .47235 Mdot
.918 .47387 Mdot
.918 .47405 Mdot
.918 .47854 Mdot
.918 .47967 Mdot
.918 .47993 Mdot
.918 .48019 Mdot
.918 .48044 Mdot
.918 .48174 Mdot
.918 .48181 Mdot
.918 .48186 Mdot
.918 .48191 Mdot
.918 .4856 Mdot
.918 .48577 Mdot
.918 .48653 Mdot
.918 .48681 Mdot
.918 .48686 Mdot
.918 .48705 Mdot
.918 .48775 Mdot
.918 .48799 Mdot
.918 .48902 Mdot
.918 .48945 Mdot
.918 .49144 Mdot
.918 .49156 Mdot
.918 .49194 Mdot
.918 .49221 Mdot
.918 .49375 Mdot
.918 .49407 Mdot
.918 .49476 Mdot
.918 .49588 Mdot
.918 .49681 Mdot
.918 .49788 Mdot
.918 .49822 Mdot
.918 .4993 Mdot
.918 .49969 Mdot
.918 .49969 Mdot
.918 .49972 Mdot
.918 .50108 Mdot
.918 .5036 Mdot
.918 .50714 Mdot
.918 .50768 Mdot
.918 .50886 Mdot
.918 .5093 Mdot
.918 .50966 Mdot
.918 .51187 Mdot
.918 .51307 Mdot
.918 .51344 Mdot
.918 .51346 Mdot
.918 .51379 Mdot
.918 .51483 Mdot
.918 .51596 Mdot
.918 .5163 Mdot
.918 .51662 Mdot
.918 .51743 Mdot
.918 .51795 Mdot
.918 .51845 Mdot
.918 .52057 Mdot
.918 .5207 Mdot
.918 .52132 Mdot
.918 .5216 Mdot
.918 .52283 Mdot
.918 .52411 Mdot
.918 .52411 Mdot
.918 .52441 Mdot
.918 .52448 Mdot
.918 .52501 Mdot
.918 .52683 Mdot
.918 .52758 Mdot
.918 .52807 Mdot
.918 .52995 Mdot
.918 .52998 Mdot
.918 .53056 Mdot
.918 .53354 Mdot
.918 .53398 Mdot
.918 .53466 Mdot
.918 .53482 Mdot
.918 .53628 Mdot
.918 .53722 Mdot
.918 .53807 Mdot
.918 .54091 Mdot
.918 .54185 Mdot
.918 .54247 Mdot
.918 .54305 Mdot
.918 .54312 Mdot
.918 .5435 Mdot
.918 .54392 Mdot
.918 .54414 Mdot
.918 .54661 Mdot
.918 .54884 Mdot
.918 .5489 Mdot
.918 .54974 Mdot
.918 .55283 Mdot
.918 .55375 Mdot
.918 .55479 Mdot
.918 .55527 Mdot
.918 .55548 Mdot
.918 .55646 Mdot
.918 .55699 Mdot
.92 .01603 Mdot
.92 .01668 Mdot
.92 .01686 Mdot
.92 .01705 Mdot
.92 .01714 Mdot
.92 .01733 Mdot
.92 .01803 Mdot
.92 .01815 Mdot
.92 .01833 Mdot
.92 .01867 Mdot
.92 .01883 Mdot
.92 .01901 Mdot
.92 .01917 Mdot
.92 .01952 Mdot
.92 .02001 Mdot
.92 .02071 Mdot
.92 .02081 Mdot
.92 .02097 Mdot
.92 .02103 Mdot
.92 .02126 Mdot
.92 .02136 Mdot
.92 .02173 Mdot
.92 .02198 Mdot
.92 .02228 Mdot
.92 .02238 Mdot
.92 .02262 Mdot
.92 .02291 Mdot
.92 .02356 Mdot
.92 .02446 Mdot
.92 .02574 Mdot
.92 .02593 Mdot
.92 .02593 Mdot
.92 .02612 Mdot
.92 .02623 Mdot
.92 .02634 Mdot
.92 .02676 Mdot
.92 .02686 Mdot
.92 .02695 Mdot
.92 .0271 Mdot
.92 .02763 Mdot
.92 .02809 Mdot
.92 .02863 Mdot
.92 .02882 Mdot
.92 .02905 Mdot
.92 .02925 Mdot
.92 .0298 Mdot
.92 .031 Mdot
.92 .0316 Mdot
.92 .03264 Mdot
.92 .03271 Mdot
.92 .03291 Mdot
.92 .03329 Mdot
.92 .03405 Mdot
.92 .03484 Mdot
.92 .03501 Mdot
.92 .03534 Mdot
.92 .03535 Mdot
.92 .0357 Mdot
.92 .03576 Mdot
.92 .0359 Mdot
.92 .03611 Mdot
.92 .03689 Mdot
.92 .03705 Mdot
.92 .03722 Mdot
.92 .0375 Mdot
.92 .03777 Mdot
.92 .03848 Mdot
.92 .03918 Mdot
.92 .03933 Mdot
.92 .04033 Mdot
.92 .04067 Mdot
.92 .04109 Mdot
.92 .04147 Mdot
.92 .04202 Mdot
.92 .04247 Mdot
.92 .04351 Mdot
.92 .04468 Mdot
.92 .04578 Mdot
.92 .04656 Mdot
.92 .04764 Mdot
.92 .04769 Mdot
.92 .04782 Mdot
.92 .04819 Mdot
.92 .04861 Mdot
.92 .0489 Mdot
.92 .04909 Mdot
.92 .05028 Mdot
.92 .05096 Mdot
.92 .05105 Mdot
.92 .05174 Mdot
.92 .05205 Mdot
.92 .05209 Mdot
.92 .05267 Mdot
.92 .05268 Mdot
.92 .05276 Mdot
.92 .05298 Mdot
.92 .05332 Mdot
.92 .05343 Mdot
.92 .05361 Mdot
.92 .0537 Mdot
.92 .05408 Mdot
.92 .05516 Mdot
.92 .05551 Mdot
.92 .05562 Mdot
.92 .05582 Mdot
.92 .05605 Mdot
.92 .05613 Mdot
.92 .05664 Mdot
.92 .05686 Mdot
.92 .05713 Mdot
.92 .05844 Mdot
.92 .05944 Mdot
.92 .05974 Mdot
.92 .06 Mdot
.92 .06016 Mdot
.92 .06184 Mdot
.92 .06196 Mdot
.92 .06201 Mdot
.92 .06235 Mdot
.92 .06248 Mdot
.92 .06324 Mdot
.92 .06394 Mdot
.92 .06469 Mdot
.92 .06496 Mdot
.92 .06579 Mdot
.92 .06614 Mdot
.92 .06667 Mdot
.92 .06697 Mdot
.92 .0677 Mdot
.92 .06867 Mdot
.92 .06888 Mdot
.92 .06951 Mdot
.92 .0696 Mdot
.92 .06985 Mdot
.92 .07004 Mdot
.92 .07187 Mdot
.92 .0733 Mdot
.92 .07348 Mdot
.92 .0746 Mdot
.92 .0753 Mdot
.92 .07539 Mdot
.92 .07563 Mdot
.92 .07592 Mdot
.92 .07631 Mdot
.92 .07634 Mdot
.92 .07667 Mdot
.92 .07709 Mdot
.92 .07714 Mdot
.92 .07761 Mdot
.92 .07797 Mdot
.92 .07798 Mdot
.92 .0785 Mdot
.92 .0792 Mdot
.92 .08016 Mdot
.92 .08141 Mdot
.92 .08158 Mdot
.92 .08181 Mdot
.92 .08285 Mdot
.92 .0833 Mdot
.92 .08341 Mdot
.92 .08348 Mdot
.92 .08375 Mdot
.92 .08386 Mdot
.92 .08391 Mdot
.92 .08455 Mdot
.92 .08458 Mdot
.92 .08472 Mdot
.92 .08513 Mdot
.92 .08575 Mdot
.92 .08595 Mdot
.92 .08628 Mdot
.92 .08644 Mdot
.92 .08657 Mdot
.92 .08715 Mdot
.92 .08809 Mdot
.92 .08856 Mdot
.92 .08907 Mdot
.92 .08914 Mdot
.92 .08978 Mdot
.92 .08997 Mdot
.92 .09035 Mdot
.92 .09076 Mdot
.92 .09091 Mdot
.92 .09148 Mdot
.92 .09185 Mdot
.92 .09218 Mdot
.92 .09226 Mdot
.92 .09275 Mdot
.92 .09289 Mdot
.92 .09383 Mdot
.92 .09517 Mdot
.92 .09647 Mdot
.92 .09669 Mdot
.92 .09702 Mdot
.92 .09733 Mdot
.92 .09756 Mdot
.92 .09804 Mdot
.92 .09833 Mdot
.92 .09851 Mdot
.92 .09868 Mdot
.92 .09975 Mdot
.92 .10142 Mdot
.92 .10151 Mdot
.92 .10164 Mdot
.92 .10171 Mdot
.92 .10174 Mdot
.92 .10203 Mdot
.92 .10237 Mdot
.92 .10245 Mdot
.92 .10258 Mdot
.92 .1026 Mdot
.92 .10301 Mdot
.92 .10328 Mdot
.92 .10388 Mdot
.92 .104 Mdot
.92 .10476 Mdot
.92 .10494 Mdot
.92 .10503 Mdot
.92 .10515 Mdot
.92 .10528 Mdot
.92 .10667 Mdot
.92 .10716 Mdot
.92 .10734 Mdot
.92 .10805 Mdot
.92 .10829 Mdot
.92 .10862 Mdot
.92 .10868 Mdot
.92 .10923 Mdot
.92 .10934 Mdot
.92 .11031 Mdot
.92 .11086 Mdot
.92 .11221 Mdot
.92 .11229 Mdot
.92 .11399 Mdot
.92 .11437 Mdot
.92 .1155 Mdot
.92 .11553 Mdot
.92 .1157 Mdot
.92 .11613 Mdot
.92 .11615 Mdot
.92 .1165 Mdot
.92 .11692 Mdot
.92 .11712 Mdot
.92 .11846 Mdot
.92 .11988 Mdot
.92 .12252 Mdot
.92 .12285 Mdot
.92 .1248 Mdot
.92 .12491 Mdot
.92 .1258 Mdot
.92 .1259 Mdot
.92 .12619 Mdot
.92 .12636 Mdot
.92 .12679 Mdot
.92 .12732 Mdot
.92 .12804 Mdot
.92 .1281 Mdot
.92 .12871 Mdot
.92 .12948 Mdot
.92 .12957 Mdot
.92 .13044 Mdot
.92 .13103 Mdot
.92 .1311 Mdot
.92 .13113 Mdot
.92 .13176 Mdot
.92 .13207 Mdot
.92 .13336 Mdot
.92 .13513 Mdot
.92 .13585 Mdot
.92 .13594 Mdot
.92 .13744 Mdot
.92 .13774 Mdot
.92 .13818 Mdot
.92 .13822 Mdot
.92 .13879 Mdot
.92 .13886 Mdot
.92 .14008 Mdot
.92 .14092 Mdot
.92 .14112 Mdot
.92 .14125 Mdot
.92 .14174 Mdot
.92 .14193 Mdot
.92 .14203 Mdot
.92 .14223 Mdot
.92 .14291 Mdot
.92 .14321 Mdot
.92 .14326 Mdot
.92 .14353 Mdot
.92 .14427 Mdot
.92 .14428 Mdot
.92 .14542 Mdot
.92 .14579 Mdot
.92 .1464 Mdot
.92 .14669 Mdot
.92 .14693 Mdot
.92 .148 Mdot
.92 .14972 Mdot
.92 .15059 Mdot
.92 .15153 Mdot
.92 .15165 Mdot
.92 .15268 Mdot
.92 .15283 Mdot
.92 .15319 Mdot
.92 .15387 Mdot
.92 .15422 Mdot
.92 .15434 Mdot
.92 .15464 Mdot
.92 .15485 Mdot
.92 .15492 Mdot
.92 .15554 Mdot
.92 .15596 Mdot
.92 .15642 Mdot
.92 .15665 Mdot
.92 .15713 Mdot
.92 .15724 Mdot
.92 .1574 Mdot
.92 .15831 Mdot
.92 .15857 Mdot
.92 .16029 Mdot
.92 .16267 Mdot
.92 .16275 Mdot
.92 .16327 Mdot
.92 .16508 Mdot
.92 .16514 Mdot
.92 .16553 Mdot
.92 .16555 Mdot
.92 .16615 Mdot
.92 .16617 Mdot
.92 .16637 Mdot
.92 .16673 Mdot
.92 .16713 Mdot
.92 .16715 Mdot
.92 .16804 Mdot
.92 .16839 Mdot
.92 .16857 Mdot
.92 .16885 Mdot
.92 .1689 Mdot
.92 .16895 Mdot
.92 .16921 Mdot
.92 .16937 Mdot
.92 .17118 Mdot
.92 .17216 Mdot
.92 .17239 Mdot
.92 .17426 Mdot
.92 .17428 Mdot
.92 .17442 Mdot
.92 .17465 Mdot
.92 .17478 Mdot
.92 .17485 Mdot
.92 .1752 Mdot
.92 .17537 Mdot
.92 .17599 Mdot
.92 .17615 Mdot
.92 .17639 Mdot
.92 .17643 Mdot
.92 .17663 Mdot
.92 .17697 Mdot
.92 .17718 Mdot
.92 .17726 Mdot
.92 .17748 Mdot
.92 .17768 Mdot
.92 .17878 Mdot
.92 .179 Mdot
.92 .1804 Mdot
.92 .18073 Mdot
.92 .18078 Mdot
.92 .1809 Mdot
.92 .18112 Mdot
.92 .18136 Mdot
.92 .18163 Mdot
.92 .18348 Mdot
.92 .18392 Mdot
.92 .18482 Mdot
.92 .18514 Mdot
.92 .18542 Mdot
.92 .18556 Mdot
.92 .18614 Mdot
.92 .18645 Mdot
.92 .18671 Mdot
.92 .1869 Mdot
.92 .18749 Mdot
.92 .18762 Mdot
.92 .18862 Mdot
.92 .18883 Mdot
.92 .18936 Mdot
.92 .18948 Mdot
.92 .1906 Mdot
.92 .19076 Mdot
.92 .19159 Mdot
.92 .19162 Mdot
.92 .1931 Mdot
.92 .19385 Mdot
.92 .1941 Mdot
.92 .19425 Mdot
.92 .19523 Mdot
.92 .19567 Mdot
.92 .19585 Mdot
.92 .19737 Mdot
.92 .19808 Mdot
.92 .19829 Mdot
.92 .1985 Mdot
.92 .19962 Mdot
.92 .19981 Mdot
.92 .20016 Mdot
.92 .20021 Mdot
.92 .20053 Mdot
.92 .20133 Mdot
.92 .20136 Mdot
.92 .20175 Mdot
.92 .20201 Mdot
.92 .20206 Mdot
.92 .20209 Mdot
.92 .20277 Mdot
.92 .20315 Mdot
.92 .20333 Mdot
.92 .20537 Mdot
.92 .2056 Mdot
.92 .20566 Mdot
.92 .20793 Mdot
.92 .20822 Mdot
.92 .20825 Mdot
.92 .20977 Mdot
.92 .20998 Mdot
.92 .21119 Mdot
.92 .21122 Mdot
.92 .21206 Mdot
.92 .21208 Mdot
.92 .21308 Mdot
.92 .21328 Mdot
.92 .21368 Mdot
.92 .21662 Mdot
.92 .21665 Mdot
.92 .2168 Mdot
.92 .21701 Mdot
.92 .21727 Mdot
.92 .21748 Mdot
.92 .21911 Mdot
.92 .21929 Mdot
.92 .21982 Mdot
.92 .22015 Mdot
.92 .2208 Mdot
.92 .22094 Mdot
.92 .22097 Mdot
.92 .22109 Mdot
.92 .22192 Mdot
.92 .22254 Mdot
.92 .22281 Mdot
.92 .22323 Mdot
.92 .22334 Mdot
.92 .22342 Mdot
.92 .22349 Mdot
.92 .22446 Mdot
.92 .22471 Mdot
.92 .22526 Mdot
.92 .22583 Mdot
.92 .22587 Mdot
.92 .22605 Mdot
.92 .227 Mdot
.92 .22703 Mdot
.92 .22766 Mdot
.92 .22873 Mdot
.92 .22886 Mdot
.92 .22891 Mdot
.92 .23008 Mdot
.92 .23065 Mdot
.92 .23075 Mdot
.92 .23112 Mdot
.92 .23258 Mdot
.92 .23302 Mdot
.92 .23309 Mdot
.92 .23344 Mdot
.92 .23505 Mdot
.92 .23516 Mdot
.92 .23628 Mdot
.92 .23633 Mdot
.92 .23637 Mdot
.92 .2368 Mdot
.92 .23688 Mdot
.92 .23708 Mdot
.92 .23744 Mdot
.92 .2376 Mdot
.92 .23777 Mdot
.92 .23811 Mdot
.92 .23976 Mdot
.92 .24002 Mdot
.92 .24049 Mdot
.92 .24052 Mdot
.92 .24101 Mdot
.92 .24109 Mdot
.92 .24188 Mdot
.92 .24196 Mdot
.92 .24225 Mdot
.92 .24301 Mdot
.92 .24315 Mdot
.92 .24318 Mdot
.92 .24359 Mdot
.92 .24405 Mdot
.92 .24415 Mdot
.92 .24538 Mdot
.92 .24554 Mdot
.92 .24692 Mdot
.92 .2471 Mdot
.92 .2473 Mdot
.92 .24744 Mdot
.92 .24754 Mdot
.92 .24771 Mdot
.92 .24843 Mdot
.92 .2488 Mdot
.92 .24898 Mdot
.92 .24935 Mdot
.92 .25059 Mdot
.92 .25115 Mdot
.92 .25124 Mdot
.92 .25159 Mdot
.92 .25173 Mdot
.92 .25215 Mdot
.92 .2528 Mdot
.92 .2531 Mdot
.92 .25311 Mdot
.92 .25521 Mdot
.92 .2559 Mdot
.92 .25683 Mdot
.92 .25702 Mdot
.92 .25744 Mdot
.92 .25756 Mdot
.92 .25799 Mdot
.92 .25809 Mdot
.92 .25857 Mdot
.92 .25891 Mdot
.92 .2595 Mdot
.92 .25996 Mdot
.92 .26193 Mdot
.92 .26309 Mdot
.92 .26312 Mdot
.92 .26317 Mdot
.92 .2638 Mdot
.92 .26455 Mdot
.92 .26473 Mdot
.92 .26505 Mdot
.92 .26645 Mdot
.92 .26667 Mdot
.92 .26857 Mdot
.92 .26885 Mdot
.92 .26924 Mdot
.92 .26951 Mdot
.92 .27034 Mdot
.92 .27077 Mdot
.92 .27113 Mdot
.92 .27141 Mdot
.92 .27144 Mdot
.92 .27163 Mdot
.92 .27218 Mdot
.92 .27257 Mdot
.92 .27264 Mdot
.92 .27269 Mdot
.92 .2731 Mdot
.92 .27383 Mdot
.92 .27385 Mdot
.92 .27428 Mdot
.92 .27452 Mdot
.92 .2746 Mdot
.92 .27545 Mdot
.92 .27587 Mdot
.92 .27671 Mdot
.92 .27676 Mdot
.92 .27692 Mdot
.92 .27696 Mdot
.92 .27726 Mdot
.92 .27773 Mdot
.92 .27777 Mdot
.92 .27841 Mdot
.92 .27893 Mdot
.92 .2794 Mdot
.92 .28257 Mdot
.92 .28489 Mdot
.92 .28696 Mdot
.92 .28709 Mdot
.92 .28721 Mdot
.92 .28806 Mdot
.92 .29036 Mdot
.92 .29101 Mdot
.92 .29138 Mdot
.92 .2915 Mdot
.92 .29221 Mdot
.92 .29225 Mdot
.92 .29243 Mdot
.92 .29282 Mdot
.92 .29335 Mdot
.92 .2934 Mdot
.92 .29376 Mdot
.92 .29429 Mdot
.92 .29443 Mdot
.92 .29443 Mdot
.92 .29462 Mdot
.92 .29516 Mdot
.92 .29519 Mdot
.92 .29625 Mdot
.92 .29683 Mdot
.92 .29743 Mdot
.92 .29749 Mdot
.92 .2978 Mdot
.92 .29832 Mdot
.92 .29833 Mdot
.92 .29841 Mdot
.92 .2985 Mdot
.92 .29861 Mdot
.92 .29899 Mdot
.92 .29927 Mdot
.92 .29942 Mdot
.92 .30015 Mdot
.92 .30096 Mdot
.92 .30262 Mdot
.92 .30285 Mdot
.92 .30378 Mdot
.92 .30434 Mdot
.92 .30441 Mdot
.92 .30484 Mdot
.92 .30508 Mdot
.92 .30765 Mdot
.92 .30827 Mdot
.92 .30832 Mdot
.92 .30857 Mdot
.92 .309 Mdot
.92 .30915 Mdot
.92 .30924 Mdot
.92 .30936 Mdot
.92 .31001 Mdot
.92 .31033 Mdot
.92 .31111 Mdot
.92 .31146 Mdot
.92 .31156 Mdot
.92 .31166 Mdot
.92 .31182 Mdot
.92 .3122 Mdot
.92 .31226 Mdot
.92 .31263 Mdot
.92 .31327 Mdot
.92 .31365 Mdot
.92 .3138 Mdot
.92 .31396 Mdot
.92 .31421 Mdot
.92 .31456 Mdot
.92 .31649 Mdot
.92 .31659 Mdot
.92 .31699 Mdot
.92 .31713 Mdot
.92 .31819 Mdot
.92 .31957 Mdot
.92 .32017 Mdot
.92 .32028 Mdot
.92 .32049 Mdot
.92 .3209 Mdot
.92 .32133 Mdot
.92 .32183 Mdot
.92 .32292 Mdot
.92 .32369 Mdot
.92 .32524 Mdot
.92 .32605 Mdot
.92 .3277 Mdot
.92 .32829 Mdot
.92 .32882 Mdot
.92 .32908 Mdot
.92 .3301 Mdot
.92 .33015 Mdot
.92 .33071 Mdot
.92 .33107 Mdot
.92 .33119 Mdot
.92 .33154 Mdot
.92 .33238 Mdot
.92 .33263 Mdot
.92 .33286 Mdot
.92 .3333 Mdot
.92 .33471 Mdot
.92 .33509 Mdot
.92 .33607 Mdot
.92 .3361 Mdot
.92 .33629 Mdot
.92 .33756 Mdot
.92 .33835 Mdot
.92 .33863 Mdot
.92 .33879 Mdot
.92 .33972 Mdot
.92 .33983 Mdot
.92 .34017 Mdot
.92 .34022 Mdot
.92 .34046 Mdot
.92 .34233 Mdot
.92 .34294 Mdot
.92 .34366 Mdot
.92 .34389 Mdot
.92 .34407 Mdot
.92 .34432 Mdot
.92 .34478 Mdot
.92 .34506 Mdot
.92 .34544 Mdot
.92 .34686 Mdot
.92 .34767 Mdot
.92 .34791 Mdot
.92 .34797 Mdot
.92 .348 Mdot
.92 .34945 Mdot
.92 .35027 Mdot
.92 .35053 Mdot
.92 .35081 Mdot
.92 .35211 Mdot
.92 .35249 Mdot
.92 .35288 Mdot
.92 .35339 Mdot
.92 .35483 Mdot
.92 .35495 Mdot
.92 .3553 Mdot
.92 .35594 Mdot
.92 .35603 Mdot
.92 .35661 Mdot
.92 .35768 Mdot
.92 .35785 Mdot
.92 .35808 Mdot
.92 .35815 Mdot
.92 .35838 Mdot
.92 .35853 Mdot
.92 .35886 Mdot
.92 .35933 Mdot
.92 .35943 Mdot
.92 .35948 Mdot
.92 .35955 Mdot
.92 .36073 Mdot
.92 .36112 Mdot
.92 .36125 Mdot
.92 .36143 Mdot
.92 .36176 Mdot
.92 .36343 Mdot
.92 .36517 Mdot
.92 .36552 Mdot
.92 .36594 Mdot
.92 .36605 Mdot
.92 .36678 Mdot
.92 .37022 Mdot
.92 .37077 Mdot
.92 .37082 Mdot
.92 .37361 Mdot
.92 .37401 Mdot
.92 .37623 Mdot
.92 .37628 Mdot
.92 .37752 Mdot
.92 .37783 Mdot
.92 .37787 Mdot
.92 .3797 Mdot
.92 .38007 Mdot
.92 .38081 Mdot
.92 .38538 Mdot
.92 .38621 Mdot
.92 .38628 Mdot
.92 .38656 Mdot
.92 .38693 Mdot
.92 .38741 Mdot
.92 .3878 Mdot
.92 .39081 Mdot
.92 .39113 Mdot
.92 .39211 Mdot
.92 .39236 Mdot
.92 .39271 Mdot
.92 .39282 Mdot
.92 .39323 Mdot
.92 .39392 Mdot
.92 .39417 Mdot
.92 .39422 Mdot
.92 .39445 Mdot
.92 .39596 Mdot
.92 .39609 Mdot
.92 .39712 Mdot
.92 .39762 Mdot
.92 .39839 Mdot
.92 .39858 Mdot
.92 .39874 Mdot
.92 .39886 Mdot
.92 .40065 Mdot
.92 .40111 Mdot
.92 .40211 Mdot
.92 .40317 Mdot
.92 .40325 Mdot
.92 .40356 Mdot
.92 .40387 Mdot
.92 .40531 Mdot
.92 .40538 Mdot
.92 .40607 Mdot
.92 .40653 Mdot
.92 .40734 Mdot
.92 .40775 Mdot
.92 .4085 Mdot
.92 .40874 Mdot
.92 .40884 Mdot
.92 .41017 Mdot
.92 .41028 Mdot
.92 .41089 Mdot
.92 .41099 Mdot
.92 .41204 Mdot
.92 .41221 Mdot
.92 .41223 Mdot
.92 .4129 Mdot
.92 .41401 Mdot
.92 .41417 Mdot
.92 .4154 Mdot
.92 .41558 Mdot
.92 .4164 Mdot
.92 .41652 Mdot
.92 .41718 Mdot
.92 .41719 Mdot
.92 .41765 Mdot
.92 .41766 Mdot
.92 .41831 Mdot
.92 .42013 Mdot
.92 .42014 Mdot
.92 .42023 Mdot
.92 .42034 Mdot
.92 .4224 Mdot
.92 .42249 Mdot
.92 .42256 Mdot
.92 .42335 Mdot
.92 .42349 Mdot
.92 .42382 Mdot
.92 .42386 Mdot
.92 .42452 Mdot
.92 .42482 Mdot
.92 .42513 Mdot
.92 .42577 Mdot
.92 .42579 Mdot
.92 .4278 Mdot
.92 .42801 Mdot
.92 .4288 Mdot
.92 .42908 Mdot
.92 .42927 Mdot
.92 .43014 Mdot
.92 .4302 Mdot
.92 .43084 Mdot
.92 .43086 Mdot
.92 .43109 Mdot
.92 .43114 Mdot
.92 .43124 Mdot
.92 .43144 Mdot
.92 .43181 Mdot
.92 .4327 Mdot
.92 .43284 Mdot
.92 .4331 Mdot
.92 .43338 Mdot
.92 .43406 Mdot
.92 .43456 Mdot
.92 .43478 Mdot
.92 .43504 Mdot
.92 .43509 Mdot
.92 .43585 Mdot
.92 .43669 Mdot
.92 .43688 Mdot
.92 .43703 Mdot
.92 .43913 Mdot
.92 .43944 Mdot
.92 .43979 Mdot
.92 .44198 Mdot
.92 .44231 Mdot
.92 .44266 Mdot
.92 .44292 Mdot
.92 .44311 Mdot
.92 .44343 Mdot
.92 .44475 Mdot
.92 .44538 Mdot
.92 .44542 Mdot
.92 .44577 Mdot
.92 .44617 Mdot
.92 .44645 Mdot
.92 .44872 Mdot
.92 .44932 Mdot
.92 .44975 Mdot
.92 .44992 Mdot
.92 .45057 Mdot
.92 .45082 Mdot
.92 .45123 Mdot
.92 .45146 Mdot
.92 .4516 Mdot
.92 .45279 Mdot
.92 .4529 Mdot
.92 .45334 Mdot
.92 .45336 Mdot
.92 .45371 Mdot
.92 .45723 Mdot
.92 .45849 Mdot
.92 .4602 Mdot
.92 .46055 Mdot
.92 .46133 Mdot
.92 .46154 Mdot
.92 .46234 Mdot
.92 .46241 Mdot
.92 .46252 Mdot
.92 .4634 Mdot
.92 .46404 Mdot
.92 .46453 Mdot
.92 .46469 Mdot
.92 .46513 Mdot
.92 .46552 Mdot
.92 .46597 Mdot
.92 .46699 Mdot
.92 .4675 Mdot
.92 .4678 Mdot
.92 .4682 Mdot
.92 .4696 Mdot
.92 .47041 Mdot
.92 .47148 Mdot
.92 .47173 Mdot
.92 .47178 Mdot
.92 .47186 Mdot
.92 .47303 Mdot
.92 .4744 Mdot
.92 .47475 Mdot
.92 .47533 Mdot
.92 .4779 Mdot
.92 .47832 Mdot
.92 .4818 Mdot
.92 .48233 Mdot
.92 .48304 Mdot
.92 .48354 Mdot
.92 .48506 Mdot
.92 .48585 Mdot
.92 .48653 Mdot
.92 .48703 Mdot
.92 .48709 Mdot
.92 .48743 Mdot
.92 .48845 Mdot
.92 .48917 Mdot
.92 .48929 Mdot
.92 .48939 Mdot
.92 .49014 Mdot
.92 .49148 Mdot
.92 .49151 Mdot
.92 .49232 Mdot
.92 .49276 Mdot
.92 .4929 Mdot
.92 .49446 Mdot
.92 .49524 Mdot
.92 .49679 Mdot
.92 .49688 Mdot
.92 .49717 Mdot
.92 .49725 Mdot
.92 .4978 Mdot
.92 .49866 Mdot
.92 .49873 Mdot
.92 .49991 Mdot
.92 .50086 Mdot
.92 .50173 Mdot
.92 .50757 Mdot
.92 .51184 Mdot
.92 .51564 Mdot
.92 .51589 Mdot
.92 .51611 Mdot
.92 .51766 Mdot
.92 .5219 Mdot
.92 .52309 Mdot
.92 .52378 Mdot
.92 .524 Mdot
.92 .52531 Mdot
.92 .52538 Mdot
.92 .52571 Mdot
.92 .52644 Mdot
.92 .52741 Mdot
.92 .52749 Mdot
.92 .52816 Mdot
.92 .52913 Mdot
.92 .52938 Mdot
.92 .52939 Mdot
.92 .52974 Mdot
.92 .53074 Mdot
.92 .53078 Mdot
.92 .53274 Mdot
.92 .5338 Mdot
.92 .5349 Mdot
.92 .53501 Mdot
.92 .53559 Mdot
.92 .53655 Mdot
.92 .53656 Mdot
.92 .53671 Mdot
.92 .53688 Mdot
.92 .53708 Mdot
.92 .53778 Mdot
.92 .5383 Mdot
.92 .53857 Mdot
.92 .53991 Mdot
.92 .54141 Mdot
.92 .54445 Mdot
.92 .54488 Mdot
.92 .5466 Mdot
.92 .54763 Mdot
.92 .54776 Mdot
.92 .54854 Mdot
.92 .54898 Mdot
.92 .55371 Mdot
.92 .55486 Mdot
.92 .55495 Mdot
.92 .5554 Mdot
.92 .5562 Mdot
.92 .55647 Mdot
.92 .55664 Mdot
.92 .55686 Mdot
.92 .55806 Mdot
.92 .55864 Mdot
.922 .01477 Mdot
.922 .01481 Mdot
.922 .01489 Mdot
.922 .01503 Mdot
.922 .01514 Mdot
.922 .0153 Mdot
.922 .0155 Mdot
.922 .01579 Mdot
.922 .01616 Mdot
.922 .0167 Mdot
.922 .01738 Mdot
.922 .0176 Mdot
.922 .01838 Mdot
.922 .01867 Mdot
.922 .01887 Mdot
.922 .01932 Mdot
.922 .01962 Mdot
.922 .01988 Mdot
.922 .02004 Mdot
.922 .02052 Mdot
.922 .02148 Mdot
.922 .02181 Mdot
.922 .02201 Mdot
.922 .02211 Mdot
.922 .02238 Mdot
.922 .02321 Mdot
.922 .02376 Mdot
.922 .02405 Mdot
.922 .02425 Mdot
.922 .02449 Mdot
.922 .02454 Mdot
.922 .02486 Mdot
.922 .02507 Mdot
.922 .02542 Mdot
.922 .02666 Mdot
.922 .02693 Mdot
.922 .02718 Mdot
.922 .02779 Mdot
.922 .0278 Mdot
.922 .028 Mdot
.922 .02817 Mdot
.922 .02824 Mdot
.922 .02836 Mdot
.922 .02869 Mdot
.922 .02884 Mdot
.922 .03037 Mdot
.922 .0314 Mdot
.922 .03194 Mdot
.922 .03229 Mdot
.922 .03234 Mdot
.922 .03273 Mdot
.922 .03283 Mdot
.922 .03342 Mdot
.922 .03382 Mdot
.922 .03445 Mdot
.922 .03618 Mdot
.922 .03674 Mdot
.922 .0368 Mdot
.922 .0371 Mdot
.922 .03724 Mdot
.922 .0377 Mdot
.922 .03799 Mdot
.922 .03871 Mdot
.922 .03882 Mdot
.922 .03885 Mdot
.922 .03898 Mdot
.922 .03921 Mdot
.922 .03953 Mdot
.922 .03964 Mdot
.922 .03966 Mdot
.922 .03987 Mdot
.922 .04047 Mdot
.922 .04048 Mdot
.922 .04076 Mdot
.922 .04192 Mdot
.922 .04358 Mdot
.922 .04378 Mdot
.922 .04422 Mdot
.922 .04548 Mdot
.922 .04642 Mdot
.922 .04647 Mdot
.922 .04692 Mdot
.922 .04713 Mdot
.922 .04721 Mdot
.922 .04794 Mdot
.922 .04795 Mdot
.922 .04811 Mdot
.922 .04857 Mdot
.922 .04921 Mdot
.922 .04921 Mdot
.922 .04951 Mdot
.922 .04994 Mdot
.922 .05031 Mdot
.922 .05075 Mdot
.922 .0511 Mdot
.922 .05406 Mdot
.922 .0543 Mdot
.922 .05434 Mdot
.922 .05477 Mdot
.922 .05479 Mdot
.922 .05533 Mdot
.922 .05544 Mdot
.922 .05599 Mdot
.922 .05625 Mdot
.922 .05711 Mdot
.922 .05763 Mdot
.922 .05853 Mdot
.922 .05897 Mdot
.922 .05916 Mdot
.922 .05921 Mdot
.922 .05946 Mdot
.922 .05989 Mdot
.922 .06047 Mdot
.922 .06068 Mdot
.922 .06071 Mdot
.922 .06101 Mdot
.922 .06111 Mdot
.922 .06123 Mdot
.922 .06221 Mdot
.922 .06223 Mdot
.922 .06275 Mdot
.922 .06388 Mdot
.922 .06488 Mdot
.922 .0653 Mdot
.922 .06589 Mdot
.922 .06735 Mdot
.922 .06795 Mdot
.922 .0683 Mdot
.922 .0685 Mdot
.922 .06912 Mdot
.922 .06993 Mdot
.922 .0714 Mdot
.922 .07145 Mdot
.922 .07317 Mdot
.922 .07327 Mdot
.922 .07343 Mdot
.922 .0741 Mdot
.922 .07448 Mdot
.922 .07464 Mdot
.922 .07558 Mdot
.922 .07564 Mdot
.922 .07598 Mdot
.922 .076 Mdot
.922 .0763 Mdot
.922 .07714 Mdot
.922 .07801 Mdot
.922 .07833 Mdot
.922 .07833 Mdot
.922 .07887 Mdot
.922 .07952 Mdot
.922 .07966 Mdot
.922 .08036 Mdot
.922 .08077 Mdot
.922 .08117 Mdot
.922 .08182 Mdot
.922 .08298 Mdot
.922 .08314 Mdot
.922 .0841 Mdot
.922 .08481 Mdot
.922 .085 Mdot
.922 .08589 Mdot
.922 .08655 Mdot
.922 .08675 Mdot
.922 .08704 Mdot
.922 .08726 Mdot
.922 .08772 Mdot
.922 .08778 Mdot
.922 .08821 Mdot
.922 .08858 Mdot
.922 .08861 Mdot
.922 .08906 Mdot
.922 .08962 Mdot
.922 .08982 Mdot
.922 .09082 Mdot
.922 .0913 Mdot
.922 .09134 Mdot
.922 .09259 Mdot
.922 .09288 Mdot
.922 .09385 Mdot
.922 .09431 Mdot
.922 .09464 Mdot
.922 .09552 Mdot
.922 .09632 Mdot
.922 .09667 Mdot
.922 .09677 Mdot
.922 .09691 Mdot
.922 .09723 Mdot
.922 .09767 Mdot
.922 .09801 Mdot
.922 .0984 Mdot
.922 .09854 Mdot
.922 .09908 Mdot
.922 .09947 Mdot
.922 .09954 Mdot
.922 .10008 Mdot
.922 .10026 Mdot
.922 .10048 Mdot
.922 .1023 Mdot
.922 .10233 Mdot
.922 .10329 Mdot
.922 .10383 Mdot
.922 .10538 Mdot
.922 .10601 Mdot
.922 .10707 Mdot
.922 .10722 Mdot
.922 .10795 Mdot
.922 .10799 Mdot
.922 .10806 Mdot
.922 .10866 Mdot
.922 .10909 Mdot
.922 .11177 Mdot
.922 .11288 Mdot
.922 .11302 Mdot
.922 .11353 Mdot
.922 .11389 Mdot
.922 .11409 Mdot
.922 .11442 Mdot
.922 .11504 Mdot
.922 .11623 Mdot
.922 .11654 Mdot
.922 .11656 Mdot
.922 .11665 Mdot
.922 .11757 Mdot
.922 .11808 Mdot
.922 .11925 Mdot
.922 .11934 Mdot
.922 .12251 Mdot
.922 .12269 Mdot
.922 .12299 Mdot
.922 .12336 Mdot
.922 .12421 Mdot
.922 .12446 Mdot
.922 .12493 Mdot
.922 .12494 Mdot
.922 .12508 Mdot
.922 .12522 Mdot
.922 .12552 Mdot
.922 .12695 Mdot
.922 .12706 Mdot
.922 .1271 Mdot
.922 .12768 Mdot
.922 .12773 Mdot
.922 .12828 Mdot
.922 .12971 Mdot
.922 .12983 Mdot
.922 .13069 Mdot
.922 .13142 Mdot
.922 .13191 Mdot
.922 .13202 Mdot
.922 .13203 Mdot
.922 .13302 Mdot
.922 .13422 Mdot
.922 .13422 Mdot
.922 .13448 Mdot
.922 .13576 Mdot
.922 .13638 Mdot
.922 .13652 Mdot
.922 .1371 Mdot
.922 .13726 Mdot
.922 .13791 Mdot
.922 .13826 Mdot
.922 .13829 Mdot
.922 .13845 Mdot
.922 .14059 Mdot
.922 .14089 Mdot
.922 .14112 Mdot
.922 .14172 Mdot
.922 .14196 Mdot
.922 .14266 Mdot
.922 .14397 Mdot
.922 .14433 Mdot
.922 .14498 Mdot
.922 .14538 Mdot
.922 .14556 Mdot
.922 .14596 Mdot
.922 .14652 Mdot
.922 .14718 Mdot
.922 .14755 Mdot
.922 .14807 Mdot
.922 .14837 Mdot
.922 .14849 Mdot
.922 .14933 Mdot
.922 .14944 Mdot
.922 .14998 Mdot
.922 .15004 Mdot
.922 .15068 Mdot
.922 .15076 Mdot
.922 .15093 Mdot
.922 .15098 Mdot
.922 .15134 Mdot
.922 .15181 Mdot
.922 .15283 Mdot
.922 .1532 Mdot
.922 .15325 Mdot
.922 .15506 Mdot
.922 .15571 Mdot
.922 .15594 Mdot
.922 .156 Mdot
.922 .15607 Mdot
.922 .15682 Mdot
.922 .15761 Mdot
.922 .15832 Mdot
.922 .15886 Mdot
.922 .16009 Mdot
.922 .16053 Mdot
.922 .16059 Mdot
.922 .16064 Mdot
.922 .16112 Mdot
.922 .1614 Mdot
.922 .16149 Mdot
.922 .16151 Mdot
.922 .1621 Mdot
.922 .16236 Mdot
.922 .1635 Mdot
.922 .16352 Mdot
.922 .16371 Mdot
.922 .16425 Mdot
.922 .1652 Mdot
.922 .16584 Mdot
.922 .16602 Mdot
.922 .16628 Mdot
.922 .16656 Mdot
.922 .16663 Mdot
.922 .16677 Mdot
.922 .16687 Mdot
.922 .16768 Mdot
.922 .16812 Mdot
.922 .16831 Mdot
.922 .16892 Mdot
.922 .16904 Mdot
.922 .16928 Mdot
.922 .16948 Mdot
.922 .17029 Mdot
.922 .171 Mdot
.922 .17113 Mdot
.922 .17116 Mdot
.922 .17213 Mdot
.922 .17247 Mdot
.922 .17287 Mdot
.922 .17322 Mdot
.922 .17393 Mdot
.922 .17417 Mdot
.922 .17508 Mdot
.922 .17623 Mdot
.922 .17628 Mdot
.922 .17724 Mdot
.922 .17781 Mdot
.922 .17794 Mdot
.922 .17805 Mdot
.922 .17811 Mdot
.922 .17891 Mdot
.922 .17904 Mdot
.922 .18025 Mdot
.922 .18156 Mdot
.922 .18191 Mdot
.922 .18264 Mdot
.922 .18306 Mdot
.922 .18374 Mdot
.922 .18439 Mdot
.922 .18453 Mdot
.922 .18502 Mdot
.922 .18529 Mdot
.922 .18663 Mdot
.922 .18671 Mdot
.922 .18684 Mdot
.922 .18685 Mdot
.922 .18795 Mdot
.922 .18874 Mdot
.922 .18952 Mdot
.922 .19054 Mdot
.922 .1913 Mdot
.922 .19233 Mdot
.922 .19298 Mdot
.922 .19368 Mdot
.922 .19412 Mdot
.922 .19568 Mdot
.922 .19573 Mdot
.922 .19599 Mdot
.922 .19619 Mdot
.922 .19668 Mdot
.922 .19693 Mdot
.922 .1976 Mdot
.922 .19797 Mdot
.922 .19857 Mdot
.922 .19971 Mdot
.922 .20127 Mdot
.922 .20191 Mdot
.922 .20248 Mdot
.922 .20252 Mdot
.922 .20269 Mdot
.922 .20397 Mdot
.922 .20429 Mdot
.922 .20438 Mdot
.922 .20501 Mdot
.922 .20504 Mdot
.922 .20531 Mdot
.922 .20546 Mdot
.922 .20701 Mdot
.922 .20748 Mdot
.922 .20765 Mdot
.922 .20953 Mdot
.922 .21021 Mdot
.922 .21084 Mdot
.922 .21129 Mdot
.922 .21139 Mdot
.922 .21241 Mdot
.922 .21349 Mdot
.922 .21354 Mdot
.922 .21382 Mdot
.922 .21437 Mdot
.922 .21505 Mdot
.922 .21653 Mdot
.922 .21663 Mdot
.922 .21709 Mdot
.922 .21795 Mdot
.922 .21796 Mdot
.922 .21823 Mdot
.922 .21848 Mdot
.922 .21882 Mdot
.922 .21882 Mdot
.922 .21904 Mdot
.922 .21972 Mdot
.922 .21978 Mdot
.922 .22041 Mdot
.922 .22058 Mdot
.922 .22168 Mdot
.922 .22188 Mdot
.922 .22196 Mdot
.922 .22222 Mdot
.922 .22303 Mdot
.922 .22311 Mdot
.922 .22335 Mdot
.922 .22413 Mdot
.922 .22477 Mdot
.922 .22677 Mdot
.922 .22699 Mdot
.922 .2273 Mdot
.922 .22782 Mdot
.922 .22828 Mdot
.922 .22843 Mdot
.922 .22858 Mdot
.922 .22993 Mdot
.922 .23081 Mdot
.922 .23103 Mdot
.922 .23104 Mdot
.922 .23235 Mdot
.922 .23256 Mdot
.922 .23274 Mdot
.922 .23287 Mdot
.922 .2332 Mdot
.922 .23509 Mdot
.922 .23509 Mdot
.922 .23535 Mdot
.922 .23556 Mdot
.922 .23684 Mdot
.922 .23774 Mdot
.922 .23787 Mdot
.922 .23791 Mdot
.922 .23907 Mdot
.922 .23932 Mdot
.922 .23995 Mdot
.922 .24039 Mdot
.922 .24069 Mdot
.922 .24189 Mdot
.922 .24193 Mdot
.922 .2421 Mdot
.922 .24252 Mdot
.922 .2426 Mdot
.922 .24266 Mdot
.922 .24288 Mdot
.922 .24411 Mdot
.922 .24435 Mdot
.922 .24457 Mdot
.922 .24531 Mdot
.922 .24683 Mdot
.922 .24703 Mdot
.922 .24738 Mdot
.922 .24781 Mdot
.922 .24835 Mdot
.922 .24836 Mdot
.922 .24892 Mdot
.922 .24935 Mdot
.922 .24948 Mdot
.922 .25031 Mdot
.922 .25065 Mdot
.922 .25105 Mdot
.922 .25118 Mdot
.922 .25297 Mdot
.922 .25306 Mdot
.922 .25319 Mdot
.922 .25353 Mdot
.922 .25359 Mdot
.922 .25372 Mdot
.922 .25492 Mdot
.922 .25567 Mdot
.922 .25599 Mdot
.922 .25674 Mdot
.922 .25776 Mdot
.922 .25875 Mdot
.922 .25898 Mdot
.922 .25941 Mdot
.922 .25966 Mdot
.922 .26061 Mdot
.922 .26063 Mdot
.922 .26117 Mdot
.922 .26139 Mdot
.922 .26209 Mdot
.922 .26248 Mdot
.922 .26275 Mdot
.922 .26284 Mdot
.922 .26294 Mdot
.922 .26315 Mdot
.922 .26392 Mdot
.922 .26397 Mdot
.922 .26414 Mdot
.922 .26425 Mdot
.922 .26544 Mdot
.922 .26559 Mdot
.922 .26585 Mdot
.922 .26589 Mdot
.922 .26599 Mdot
.922 .26665 Mdot
.922 .26732 Mdot
.922 .26752 Mdot
.922 .2677 Mdot
.922 .26777 Mdot
.922 .2694 Mdot
.922 .27009 Mdot
.922 .27018 Mdot
.922 .2706 Mdot
.922 .27106 Mdot
.922 .27173 Mdot
.922 .27255 Mdot
.922 .27291 Mdot
.922 .27308 Mdot
.922 .27351 Mdot
.922 .27355 Mdot
.922 .27471 Mdot
.922 .27513 Mdot
.922 .27525 Mdot
.922 .27537 Mdot
.922 .27675 Mdot
.922 .27821 Mdot
.922 .27952 Mdot
.922 .27962 Mdot
.922 .27994 Mdot
.922 .28036 Mdot
.922 .28052 Mdot
.922 .28154 Mdot
.922 .28173 Mdot
.922 .28218 Mdot
.922 .28231 Mdot
.922 .28279 Mdot
.922 .28359 Mdot
.922 .2836 Mdot
.922 .28372 Mdot
.922 .28381 Mdot
.922 .28411 Mdot
.922 .28468 Mdot
.922 .2852 Mdot
.922 .28537 Mdot
.922 .28541 Mdot
.922 .28625 Mdot
.922 .28648 Mdot
.922 .28697 Mdot
.922 .28794 Mdot
.922 .28805 Mdot
.922 .28842 Mdot
.922 .2888 Mdot
.922 .28908 Mdot
.922 .2891 Mdot
.922 .28947 Mdot
.922 .2899 Mdot
.922 .29045 Mdot
.922 .2922 Mdot
.922 .29244 Mdot
.922 .29269 Mdot
.922 .29339 Mdot
.922 .29373 Mdot
.922 .29421 Mdot
.922 .29472 Mdot
.922 .29485 Mdot
.922 .29511 Mdot
.922 .29529 Mdot
.922 .29592 Mdot
.922 .29676 Mdot
.922 .29679 Mdot
.922 .29759 Mdot
.922 .29794 Mdot
.922 .29907 Mdot
.922 .29928 Mdot
.922 .29928 Mdot
.922 .29973 Mdot
.922 .30002 Mdot
.922 .30005 Mdot
.922 .30011 Mdot
.922 .30153 Mdot
.922 .30158 Mdot
.922 .30159 Mdot
.922 .30237 Mdot
.922 .3029 Mdot
.922 .30314 Mdot
.922 .3032 Mdot
.922 .3047 Mdot
.922 .3049 Mdot
.922 .30498 Mdot
.922 .30559 Mdot
.922 .30561 Mdot
.922 .30567 Mdot
.922 .30635 Mdot
.922 .307 Mdot
.922 .30752 Mdot
.922 .30777 Mdot
.922 .30827 Mdot
.922 .3083 Mdot
.922 .30876 Mdot
.922 .31042 Mdot
.922 .31063 Mdot
.922 .31196 Mdot
.922 .31254 Mdot
.922 .31265 Mdot
.922 .31289 Mdot
.922 .3132 Mdot
.922 .31354 Mdot
.922 .31424 Mdot
.922 .31441 Mdot
.922 .31546 Mdot
.922 .31569 Mdot
.922 .3159 Mdot
.922 .31601 Mdot
.922 .31687 Mdot
.922 .31702 Mdot
.922 .31748 Mdot
.922 .3176 Mdot
.922 .31773 Mdot
.922 .31797 Mdot
.922 .31995 Mdot
.922 .32204 Mdot
.922 .32237 Mdot
.922 .32253 Mdot
.922 .32302 Mdot
.922 .32341 Mdot
.922 .32356 Mdot
.922 .32391 Mdot
.922 .32436 Mdot
.922 .32515 Mdot
.922 .32616 Mdot
.922 .3264 Mdot
.922 .32759 Mdot
.922 .32786 Mdot
.922 .32842 Mdot
.922 .32876 Mdot
.922 .3291 Mdot
.922 .32926 Mdot
.922 .3297 Mdot
.922 .32994 Mdot
.922 .33173 Mdot
.922 .33188 Mdot
.922 .33212 Mdot
.922 .33213 Mdot
.922 .33416 Mdot
.922 .3355 Mdot
.922 .33562 Mdot
.922 .33706 Mdot
.922 .33783 Mdot
.922 .33815 Mdot
.922 .33894 Mdot
.922 .33956 Mdot
.922 .34034 Mdot
.922 .34114 Mdot
.922 .34224 Mdot
.922 .3434 Mdot
.922 .34344 Mdot
.922 .34472 Mdot
.922 .34554 Mdot
.922 .34622 Mdot
.922 .34741 Mdot
.922 .3475 Mdot
.922 .34802 Mdot
.922 .34841 Mdot
.922 .34851 Mdot
.922 .349 Mdot
.922 .34935 Mdot
.922 .34946 Mdot
.922 .34962 Mdot
.922 .35025 Mdot
.922 .35071 Mdot
.922 .35195 Mdot
.922 .35263 Mdot
.922 .35356 Mdot
.922 .35374 Mdot
.922 .35497 Mdot
.922 .35538 Mdot
.922 .35578 Mdot
.922 .35585 Mdot
.922 .35872 Mdot
.922 .35991 Mdot
.922 .36048 Mdot
.922 .36096 Mdot
.922 .36102 Mdot
.922 .36134 Mdot
.922 .36371 Mdot
.922 .36429 Mdot
.922 .36447 Mdot
.922 .36545 Mdot
.922 .36563 Mdot
.922 .36568 Mdot
.922 .36618 Mdot
.922 .36645 Mdot
.922 .36931 Mdot
.922 .36991 Mdot
.922 .37017 Mdot
.922 .37025 Mdot
.922 .37049 Mdot
.922 .37134 Mdot
.922 .37276 Mdot
.922 .37329 Mdot
.922 .37395 Mdot
.922 .37521 Mdot
.922 .37638 Mdot
.922 .37676 Mdot
.922 .3772 Mdot
.922 .37739 Mdot
.922 .37741 Mdot
.922 .37895 Mdot
.922 .37927 Mdot
.922 .3794 Mdot
.922 .38104 Mdot
.922 .38126 Mdot
.922 .38135 Mdot
.922 .38187 Mdot
.922 .38288 Mdot
.922 .38375 Mdot
.922 .38378 Mdot
.922 .38413 Mdot
.922 .38418 Mdot
.922 .38449 Mdot
.922 .38553 Mdot
.922 .38686 Mdot
.922 .38705 Mdot
.922 .38746 Mdot
.922 .38789 Mdot
.922 .38924 Mdot
.922 .38947 Mdot
.922 .38951 Mdot
.922 .38979 Mdot
.922 .38994 Mdot
.922 .39001 Mdot
.922 .39046 Mdot
.922 .39108 Mdot
.922 .39109 Mdot
.922 .39149 Mdot
.922 .39274 Mdot
.922 .39278 Mdot
.922 .39286 Mdot
.922 .39359 Mdot
.922 .39402 Mdot
.922 .39433 Mdot
.922 .39524 Mdot
.922 .39635 Mdot
.922 .39674 Mdot
.922 .39687 Mdot
.922 .39736 Mdot
.922 .39853 Mdot
.922 .39884 Mdot
.922 .39891 Mdot
.922 .399 Mdot
.922 .39944 Mdot
.922 .40016 Mdot
.922 .40088 Mdot
.922 .40146 Mdot
.922 .40206 Mdot
.922 .40241 Mdot
.922 .40249 Mdot
.922 .40374 Mdot
.922 .40519 Mdot
.922 .40575 Mdot
.922 .40616 Mdot
.922 .40672 Mdot
.922 .40707 Mdot
.922 .40769 Mdot
.922 .40853 Mdot
.922 .40881 Mdot
.922 .40907 Mdot
.922 .41156 Mdot
.922 .41303 Mdot
.922 .4132 Mdot
.922 .4136 Mdot
.922 .41361 Mdot
.922 .41384 Mdot
.922 .41468 Mdot
.922 .41604 Mdot
.922 .41641 Mdot
.922 .41676 Mdot
.922 .417 Mdot
.922 .41706 Mdot
.922 .41761 Mdot
.922 .41822 Mdot
.922 .41984 Mdot
.922 .42108 Mdot
.922 .42108 Mdot
.922 .42157 Mdot
.922 .4216 Mdot
.922 .42195 Mdot
.922 .42204 Mdot
.922 .42293 Mdot
.922 .42354 Mdot
.922 .42431 Mdot
.922 .42568 Mdot
.922 .42597 Mdot
.922 .42621 Mdot
.922 .42629 Mdot
.922 .42842 Mdot
.922 .42853 Mdot
.922 .42863 Mdot
.922 .42888 Mdot
.922 .43005 Mdot
.922 .43085 Mdot
.922 .43134 Mdot
.922 .43141 Mdot
.922 .43254 Mdot
.922 .43362 Mdot
.922 .43371 Mdot
.922 .43401 Mdot
.922 .43479 Mdot
.922 .43493 Mdot
.922 .43504 Mdot
.922 .43545 Mdot
.922 .43638 Mdot
.922 .4371 Mdot
.922 .4371 Mdot
.922 .43771 Mdot
.922 .43816 Mdot
.922 .43856 Mdot
.922 .43863 Mdot
.922 .4396 Mdot
.922 .43972 Mdot
.922 .43991 Mdot
.922 .43994 Mdot
.922 .44274 Mdot
.922 .4431 Mdot
.922 .44374 Mdot
.922 .44455 Mdot
.922 .44476 Mdot
.922 .44491 Mdot
.922 .44496 Mdot
.922 .44554 Mdot
.922 .44557 Mdot
.922 .44658 Mdot
.922 .44738 Mdot
.922 .44759 Mdot
.922 .44763 Mdot
.922 .44916 Mdot
.922 .44941 Mdot
.922 .44977 Mdot
.922 .45022 Mdot
.922 .45041 Mdot
.922 .45051 Mdot
.922 .45076 Mdot
.922 .45405 Mdot
.922 .45423 Mdot
.922 .45445 Mdot
.922 .45509 Mdot
.922 .4552 Mdot
.922 .45544 Mdot
.922 .45551 Mdot
.922 .45621 Mdot
.922 .45649 Mdot
.922 .45765 Mdot
.922 .45857 Mdot
.922 .45863 Mdot
.922 .45883 Mdot
.922 .45903 Mdot
.922 .45963 Mdot
.922 .46101 Mdot
.922 .46114 Mdot
.922 .46289 Mdot
.922 .46335 Mdot
.922 .46472 Mdot
.922 .46512 Mdot
.922 .46513 Mdot
.922 .46594 Mdot
.922 .46596 Mdot
.922 .46639 Mdot
.922 .46765 Mdot
.922 .46776 Mdot
.922 .46814 Mdot
.922 .46818 Mdot
.922 .46918 Mdot
.922 .46932 Mdot
.922 .46959 Mdot
.922 .47087 Mdot
.922 .47159 Mdot
.922 .4721 Mdot
.922 .47226 Mdot
.922 .47245 Mdot
.922 .47283 Mdot
.922 .47426 Mdot
.922 .47434 Mdot
.922 .47465 Mdot
.922 .47485 Mdot
.922 .47706 Mdot
.922 .47733 Mdot
.922 .4778 Mdot
.922 .47788 Mdot
.922 .47807 Mdot
.922 .47929 Mdot
.922 .48052 Mdot
.922 .48089 Mdot
.922 .48121 Mdot
.922 .48134 Mdot
.922 .48436 Mdot
.922 .48562 Mdot
.922 .48579 Mdot
.922 .48656 Mdot
.922 .48742 Mdot
.922 .48864 Mdot
.922 .49017 Mdot
.922 .49082 Mdot
.922 .49115 Mdot
.922 .49193 Mdot
.922 .49201 Mdot
.922 .49415 Mdot
.922 .49492 Mdot
.922 .49514 Mdot
.922 .49536 Mdot
.922 .4979 Mdot
.922 .5006 Mdot
.922 .50302 Mdot
.922 .5032 Mdot
.922 .5038 Mdot
.922 .50456 Mdot
.922 .50485 Mdot
.922 .50673 Mdot
.922 .50709 Mdot
.922 .50792 Mdot
.922 .50816 Mdot
.922 .50905 Mdot
.922 .51052 Mdot
.922 .51054 Mdot
.922 .51075 Mdot
.922 .51092 Mdot
.922 .51149 Mdot
.922 .51253 Mdot
.922 .5135 Mdot
.922 .5138 Mdot
.922 .51388 Mdot
.922 .51542 Mdot
.922 .51586 Mdot
.922 .51675 Mdot
.922 .51854 Mdot
.922 .51875 Mdot
.922 .51942 Mdot
.922 .52013 Mdot
.922 .52064 Mdot
.922 .52069 Mdot
.922 .52136 Mdot
.922 .52215 Mdot
.922 .52317 Mdot
.922 .5264 Mdot
.922 .52684 Mdot
.922 .5273 Mdot
.922 .52858 Mdot
.922 .52922 Mdot
.922 .53009 Mdot
.922 .53105 Mdot
.922 .53129 Mdot
.922 .53177 Mdot
.922 .5321 Mdot
.922 .53326 Mdot
.922 .53481 Mdot
.922 .53486 Mdot
.922 .53633 Mdot
.922 .53698 Mdot
.922 .53906 Mdot
.922 .53945 Mdot
.922 .53946 Mdot
.922 .54029 Mdot
.922 .54081 Mdot
.922 .54088 Mdot
.922 .54098 Mdot
.922 .54361 Mdot
.922 .54369 Mdot
.922 .54372 Mdot
.922 .54514 Mdot
.922 .54613 Mdot
.922 .54657 Mdot
.922 .54667 Mdot
.922 .54944 Mdot
.922 .54982 Mdot
.922 .54997 Mdot
.922 .5511 Mdot
.922 .55113 Mdot
.922 .55124 Mdot
.922 .55249 Mdot
.922 .55369 Mdot
.922 .55465 Mdot
.922 .55511 Mdot
.922 .55602 Mdot
.922 .55608 Mdot
.922 .55693 Mdot
.924 .01502 Mdot
.924 .01527 Mdot
.924 .01536 Mdot
.924 .01575 Mdot
.924 .0159 Mdot
.924 .01629 Mdot
.924 .01662 Mdot
.924 .01691 Mdot
.924 .01744 Mdot
.924 .01759 Mdot
.924 .01762 Mdot
.924 .01823 Mdot
.924 .01857 Mdot
.924 .01871 Mdot
.924 .01877 Mdot
.924 .01881 Mdot
.924 .01909 Mdot
.924 .01938 Mdot
.924 .0194 Mdot
.924 .01971 Mdot
.924 .01976 Mdot
.924 .01983 Mdot
.924 .0199 Mdot
.924 .02003 Mdot
.924 .02009 Mdot
.924 .02022 Mdot
.924 .02122 Mdot
.924 .02124 Mdot
.924 .02183 Mdot
.924 .02209 Mdot
.924 .02221 Mdot
.924 .02229 Mdot
.924 .0228 Mdot
.924 .02281 Mdot
.924 .02334 Mdot
.924 .02338 Mdot
.924 .02374 Mdot
.924 .02395 Mdot
.924 .02403 Mdot
.924 .02416 Mdot
.924 .0243 Mdot
.924 .02439 Mdot
.924 .02454 Mdot
.924 .02464 Mdot
.924 .02489 Mdot
.924 .02495 Mdot
.924 .0255 Mdot
.924 .02673 Mdot
.924 .02678 Mdot
.924 .02693 Mdot
.924 .02717 Mdot
.924 .02741 Mdot
.924 .02787 Mdot
.924 .02796 Mdot
.924 .02835 Mdot
.924 .02856 Mdot
.924 .0287 Mdot
.924 .02967 Mdot
.924 .02968 Mdot
.924 .03066 Mdot
.924 .03073 Mdot
.924 .0314 Mdot
.924 .03179 Mdot
.924 .03193 Mdot
.924 .03217 Mdot
.924 .03243 Mdot
.924 .0326 Mdot
.924 .03287 Mdot
.924 .03306 Mdot
.924 .03352 Mdot
.924 .03363 Mdot
.924 .03465 Mdot
.924 .03486 Mdot
.924 .03493 Mdot
.924 .0365 Mdot
.924 .03691 Mdot
.924 .03701 Mdot
.924 .03729 Mdot
.924 .03774 Mdot
.924 .03818 Mdot
.924 .03902 Mdot
.924 .0392 Mdot
.924 .03932 Mdot
.924 .0399 Mdot
.924 .03991 Mdot
.924 .04028 Mdot
.924 .0403 Mdot
.924 .04057 Mdot
.924 .04205 Mdot
.924 .04234 Mdot
.924 .04237 Mdot
.924 .04278 Mdot
.924 .04417 Mdot
.924 .04431 Mdot
.924 .04475 Mdot
.924 .04555 Mdot
.924 .04579 Mdot
.924 .04627 Mdot
.924 .04637 Mdot
.924 .04654 Mdot
.924 .04672 Mdot
.924 .04698 Mdot
.924 .04744 Mdot
.924 .04777 Mdot
.924 .04826 Mdot
.924 .04862 Mdot
.924 .04871 Mdot
.924 .04946 Mdot
.924 .04967 Mdot
.924 .05155 Mdot
.924 .05194 Mdot
.924 .05207 Mdot
.924 .05213 Mdot
.924 .05351 Mdot
.924 .0541 Mdot
.924 .05459 Mdot
.924 .05497 Mdot
.924 .05574 Mdot
.924 .05591 Mdot
.924 .05644 Mdot
.924 .05726 Mdot
.924 .05738 Mdot
.924 .05808 Mdot
.924 .05963 Mdot
.924 .05977 Mdot
.924 .05996 Mdot
.924 .06018 Mdot
.924 .06096 Mdot
.924 .06127 Mdot
.924 .06127 Mdot
.924 .06197 Mdot
.924 .06199 Mdot
.924 .062 Mdot
.924 .06249 Mdot
.924 .06373 Mdot
.924 .06376 Mdot
.924 .06428 Mdot
.924 .06494 Mdot
.924 .06522 Mdot
.924 .06577 Mdot
.924 .06577 Mdot
.924 .06582 Mdot
.924 .06587 Mdot
.924 .06594 Mdot
.924 .06658 Mdot
.924 .06916 Mdot
.924 .0694 Mdot
.924 .07012 Mdot
.924 .07022 Mdot
.924 .07097 Mdot
.924 .07137 Mdot
.924 .0717 Mdot
.924 .07209 Mdot
.924 .07215 Mdot
.924 .07303 Mdot
.924 .07321 Mdot
.924 .07324 Mdot
.924 .07352 Mdot
.924 .07387 Mdot
.924 .07387 Mdot
.924 .07408 Mdot
.924 .07434 Mdot
.924 .07495 Mdot
.924 .0752 Mdot
.924 .07579 Mdot
.924 .07671 Mdot
.924 .07737 Mdot
.924 .07755 Mdot
.924 .07892 Mdot
.924 .07931 Mdot
.924 .07991 Mdot
.924 .07993 Mdot
.924 .08011 Mdot
.924 .08097 Mdot
.924 .08278 Mdot
.924 .08351 Mdot
.924 .08374 Mdot
.924 .08385 Mdot
.924 .08448 Mdot
.924 .08538 Mdot
.924 .08562 Mdot
.924 .08641 Mdot
.924 .08644 Mdot
.924 .08751 Mdot
.924 .0884 Mdot
.924 .08911 Mdot
.924 .09053 Mdot
.924 .09078 Mdot
.924 .09085 Mdot
.924 .09135 Mdot
.924 .09182 Mdot
.924 .09254 Mdot
.924 .09335 Mdot
.924 .09356 Mdot
.924 .09485 Mdot
.924 .0972 Mdot
.924 .09757 Mdot
.924 .09768 Mdot
.924 .09771 Mdot
.924 .09782 Mdot
.924 .09797 Mdot
.924 .09801 Mdot
.924 .09832 Mdot
.924 .0987 Mdot
.924 .09874 Mdot
.924 .09892 Mdot
.924 .09949 Mdot
.924 .10017 Mdot
.924 .10073 Mdot
.924 .10074 Mdot
.924 .10075 Mdot
.924 .10204 Mdot
.924 .10209 Mdot
.924 .10211 Mdot
.924 .103 Mdot
.924 .10323 Mdot
.924 .10449 Mdot
.924 .10475 Mdot
.924 .10529 Mdot
.924 .10535 Mdot
.924 .10563 Mdot
.924 .10605 Mdot
.924 .10631 Mdot
.924 .10668 Mdot
.924 .10754 Mdot
.924 .10806 Mdot
.924 .10906 Mdot
.924 .10907 Mdot
.924 .10915 Mdot
.924 .10925 Mdot
.924 .10938 Mdot
.924 .11021 Mdot
.924 .11057 Mdot
.924 .11163 Mdot
.924 .11249 Mdot
.924 .11446 Mdot
.924 .11532 Mdot
.924 .1157 Mdot
.924 .11577 Mdot
.924 .1171 Mdot
.924 .1173 Mdot
.924 .11868 Mdot
.924 .11941 Mdot
.924 .12003 Mdot
.924 .1202 Mdot
.924 .12033 Mdot
.924 .12044 Mdot
.924 .12051 Mdot
.924 .1206 Mdot
.924 .12074 Mdot
.924 .12085 Mdot
.924 .12146 Mdot
.924 .12247 Mdot
.924 .12282 Mdot
.924 .12286 Mdot
.924 .12339 Mdot
.924 .12369 Mdot
.924 .12403 Mdot
.924 .12403 Mdot
.924 .1244 Mdot
.924 .12442 Mdot
.924 .12516 Mdot
.924 .12603 Mdot
.924 .12649 Mdot
.924 .1269 Mdot
.924 .12707 Mdot
.924 .12726 Mdot
.924 .12759 Mdot
.924 .12902 Mdot
.924 .12928 Mdot
.924 .1305 Mdot
.924 .13054 Mdot
.924 .13082 Mdot
.924 .13118 Mdot
.924 .13155 Mdot
.924 .13156 Mdot
.924 .13294 Mdot
.924 .13337 Mdot
.924 .13401 Mdot
.924 .13409 Mdot
.924 .13482 Mdot
.924 .13519 Mdot
.924 .13524 Mdot
.924 .13551 Mdot
.924 .13557 Mdot
.924 .13597 Mdot
.924 .13598 Mdot
.924 .13653 Mdot
.924 .13716 Mdot
.924 .13745 Mdot
.924 .13766 Mdot
.924 .13811 Mdot
.924 .13899 Mdot
.924 .1405 Mdot
.924 .14185 Mdot
.924 .142 Mdot
.924 .14228 Mdot
.924 .14248 Mdot
.924 .14305 Mdot
.924 .14365 Mdot
.924 .14524 Mdot
.924 .1453 Mdot
.924 .14534 Mdot
.924 .14575 Mdot
.924 .14605 Mdot
.924 .1472 Mdot
.924 .14727 Mdot
.924 .1482 Mdot
.924 .14838 Mdot
.924 .14924 Mdot
.924 .15026 Mdot
.924 .15055 Mdot
.924 .15081 Mdot
.924 .15089 Mdot
.924 .15147 Mdot
.924 .1522 Mdot
.924 .15324 Mdot
.924 .15413 Mdot
.924 .15423 Mdot
.924 .15482 Mdot
.924 .15525 Mdot
.924 .15529 Mdot
.924 .15542 Mdot
.924 .15603 Mdot
.924 .15633 Mdot
.924 .1572 Mdot
.924 .1578 Mdot
.924 .15816 Mdot
.924 .15816 Mdot
.924 .15854 Mdot
.924 .15915 Mdot
.924 .15959 Mdot
.924 .16002 Mdot
.924 .16041 Mdot
.924 .16053 Mdot
.924 .16069 Mdot
.924 .16097 Mdot
.924 .1628 Mdot
.924 .16287 Mdot
.924 .1643 Mdot
.924 .1653 Mdot
.924 .16716 Mdot
.924 .16783 Mdot
.924 .16804 Mdot
.924 .16809 Mdot
.924 .16828 Mdot
.924 .16858 Mdot
.924 .16865 Mdot
.924 .16891 Mdot
.924 .16922 Mdot
.924 .16992 Mdot
.924 .16998 Mdot
.924 .17033 Mdot
.924 .17081 Mdot
.924 .17138 Mdot
.924 .17264 Mdot
.924 .17338 Mdot
.924 .17368 Mdot
.924 .17369 Mdot
.924 .1737 Mdot
.924 .17372 Mdot
.924 .17518 Mdot
.924 .17608 Mdot
.924 .17618 Mdot
.924 .17621 Mdot
.924 .17633 Mdot
.924 .17663 Mdot
.924 .17736 Mdot
.924 .17787 Mdot
.924 .17829 Mdot
.924 .17859 Mdot
.924 .18061 Mdot
.924 .18063 Mdot
.924 .18109 Mdot
.924 .18209 Mdot
.924 .1822 Mdot
.924 .18272 Mdot
.924 .18351 Mdot
.924 .18398 Mdot
.924 .18467 Mdot
.924 .18567 Mdot
.924 .18625 Mdot
.924 .18639 Mdot
.924 .18721 Mdot
.924 .18791 Mdot
.924 .18907 Mdot
.924 .18908 Mdot
.924 .18923 Mdot
.924 .18942 Mdot
.924 .18966 Mdot
.924 .1897 Mdot
.924 .19094 Mdot
.924 .19119 Mdot
.924 .1913 Mdot
.924 .19185 Mdot
.924 .19381 Mdot
.924 .19412 Mdot
.924 .19541 Mdot
.924 .19572 Mdot
.924 .19887 Mdot
.924 .19901 Mdot
.924 .19905 Mdot
.924 .19931 Mdot
.924 .1999 Mdot
.924 .20063 Mdot
.924 .201 Mdot
.924 .20108 Mdot
.924 .20134 Mdot
.924 .20146 Mdot
.924 .20309 Mdot
.924 .20335 Mdot
.924 .20392 Mdot
.924 .20429 Mdot
.924 .2056 Mdot
.924 .20567 Mdot
.924 .20569 Mdot
.924 .20572 Mdot
.924 .20683 Mdot
.924 .20705 Mdot
.924 .20819 Mdot
.924 .20863 Mdot
.924 .20933 Mdot
.924 .20965 Mdot
.924 .20989 Mdot
.924 .21009 Mdot
.924 .21022 Mdot
.924 .21039 Mdot
.924 .21065 Mdot
.924 .21085 Mdot
.924 .21111 Mdot
.924 .21199 Mdot
.924 .21293 Mdot
.924 .21386 Mdot
.924 .2144 Mdot
.924 .21449 Mdot
.924 .21457 Mdot
.924 .21476 Mdot
.924 .21554 Mdot
.924 .21557 Mdot
.924 .21587 Mdot
.924 .2161 Mdot
.924 .21672 Mdot
.924 .21672 Mdot
.924 .21714 Mdot
.924 .21741 Mdot
.924 .21746 Mdot
.924 .21881 Mdot
.924 .22042 Mdot
.924 .22118 Mdot
.924 .22127 Mdot
.924 .2217 Mdot
.924 .22204 Mdot
.924 .22234 Mdot
.924 .2227 Mdot
.924 .2233 Mdot
.924 .22543 Mdot
.924 .22595 Mdot
.924 .22632 Mdot
.924 .22642 Mdot
.924 .22772 Mdot
.924 .22864 Mdot
.924 .22868 Mdot
.924 .22877 Mdot
.924 .22894 Mdot
.924 .22926 Mdot
.924 .22929 Mdot
.924 .22995 Mdot
.924 .23061 Mdot
.924 .23063 Mdot
.924 .23064 Mdot
.924 .23065 Mdot
.924 .23104 Mdot
.924 .23319 Mdot
.924 .23353 Mdot
.924 .23362 Mdot
.924 .23399 Mdot
.924 .23517 Mdot
.924 .23532 Mdot
.924 .23642 Mdot
.924 .23668 Mdot
.924 .23709 Mdot
.924 .23736 Mdot
.924 .23744 Mdot
.924 .23794 Mdot
.924 .23806 Mdot
.924 .23879 Mdot
.924 .23881 Mdot
.924 .23983 Mdot
.924 .24098 Mdot
.924 .24098 Mdot
.924 .24101 Mdot
.924 .24103 Mdot
.924 .24112 Mdot
.924 .24119 Mdot
.924 .24149 Mdot
.924 .24153 Mdot
.924 .24172 Mdot
.924 .24191 Mdot
.924 .24275 Mdot
.924 .24276 Mdot
.924 .24288 Mdot
.924 .24353 Mdot
.924 .24419 Mdot
.924 .24429 Mdot
.924 .24438 Mdot
.924 .24671 Mdot
.924 .24705 Mdot
.924 .2471 Mdot
.924 .24716 Mdot
.924 .24729 Mdot
.924 .2475 Mdot
.924 .24958 Mdot
.924 .24966 Mdot
.924 .24971 Mdot
.924 .24994 Mdot
.924 .25045 Mdot
.924 .25083 Mdot
.924 .25187 Mdot
.924 .25197 Mdot
.924 .25232 Mdot
.924 .25262 Mdot
.924 .25298 Mdot
.924 .25301 Mdot
.924 .25379 Mdot
.924 .25592 Mdot
.924 .25603 Mdot
.924 .25612 Mdot
.924 .25687 Mdot
.924 .25694 Mdot
.924 .25742 Mdot
.924 .25955 Mdot
.924 .25968 Mdot
.924 .26047 Mdot
.924 .26057 Mdot
.924 .26134 Mdot
.924 .2614 Mdot
.924 .26173 Mdot
.924 .26175 Mdot
.924 .26193 Mdot
.924 .26212 Mdot
.924 .26258 Mdot
.924 .26327 Mdot
.924 .26331 Mdot
.924 .26519 Mdot
.924 .26574 Mdot
.924 .26622 Mdot
.924 .26637 Mdot
.924 .26744 Mdot
.924 .26862 Mdot
.924 .26879 Mdot
.924 .26941 Mdot
.924 .27039 Mdot
.924 .27067 Mdot
.924 .2707 Mdot
.924 .27084 Mdot
.924 .27163 Mdot
.924 .27166 Mdot
.924 .27235 Mdot
.924 .27253 Mdot
.924 .27335 Mdot
.924 .27344 Mdot
.924 .27363 Mdot
.924 .27442 Mdot
.924 .27449 Mdot
.924 .27464 Mdot
.924 .27473 Mdot
.924 .27587 Mdot
.924 .27643 Mdot
.924 .27803 Mdot
.924 .27821 Mdot
.924 .27856 Mdot
.924 .27907 Mdot
.924 .27913 Mdot
.924 .27975 Mdot
.924 .27981 Mdot
.924 .27981 Mdot
.924 .28051 Mdot
.924 .28078 Mdot
.924 .28163 Mdot
.924 .28199 Mdot
.924 .28211 Mdot
.924 .28245 Mdot
.924 .28324 Mdot
.924 .28397 Mdot
.924 .28418 Mdot
.924 .28447 Mdot
.924 .28477 Mdot
.924 .285 Mdot
.924 .28573 Mdot
.924 .28695 Mdot
.924 .28838 Mdot
.924 .2885 Mdot
.924 .28972 Mdot
.924 .29114 Mdot
.924 .29202 Mdot
.924 .29241 Mdot
.924 .2927 Mdot
.924 .29299 Mdot
.924 .29529 Mdot
.924 .2955 Mdot
.924 .29642 Mdot
.924 .29715 Mdot
.924 .29767 Mdot
.924 .29806 Mdot
.924 .29815 Mdot
.924 .29851 Mdot
.924 .29905 Mdot
.924 .29918 Mdot
.924 .29968 Mdot
.924 .30024 Mdot
.924 .30037 Mdot
.924 .30153 Mdot
.924 .30165 Mdot
.924 .30201 Mdot
.924 .30229 Mdot
.924 .30318 Mdot
.924 .30424 Mdot
.924 .30443 Mdot
.924 .30487 Mdot
.924 .30656 Mdot
.924 .30682 Mdot
.924 .30758 Mdot
.924 .30792 Mdot
.924 .30793 Mdot
.924 .30848 Mdot
.924 .3085 Mdot
.924 .30852 Mdot
.924 .30855 Mdot
.924 .30898 Mdot
.924 .30902 Mdot
.924 .31056 Mdot
.924 .31074 Mdot
.924 .31125 Mdot
.924 .31187 Mdot
.924 .31195 Mdot
.924 .31248 Mdot
.924 .31256 Mdot
.924 .31261 Mdot
.924 .31276 Mdot
.924 .31292 Mdot
.924 .31293 Mdot
.924 .3131 Mdot
.924 .31316 Mdot
.924 .3132 Mdot
.924 .31338 Mdot
.924 .31393 Mdot
.924 .31478 Mdot
.924 .31528 Mdot
.924 .31563 Mdot
.924 .31593 Mdot
.924 .31623 Mdot
.924 .31701 Mdot
.924 .31714 Mdot
.924 .31727 Mdot
.924 .31756 Mdot
.924 .3213 Mdot
.924 .32133 Mdot
.924 .32218 Mdot
.924 .32371 Mdot
.924 .32403 Mdot
.924 .32423 Mdot
.924 .32519 Mdot
.924 .32558 Mdot
.924 .32665 Mdot
.924 .32721 Mdot
.924 .32753 Mdot
.924 .32772 Mdot
.924 .32879 Mdot
.924 .33064 Mdot
.924 .33139 Mdot
.924 .33171 Mdot
.924 .33197 Mdot
.924 .33348 Mdot
.924 .33478 Mdot
.924 .33542 Mdot
.924 .33599 Mdot
.924 .33692 Mdot
.924 .33693 Mdot
.924 .33722 Mdot
.924 .33758 Mdot
.924 .33802 Mdot
.924 .33808 Mdot
.924 .33812 Mdot
.924 .34038 Mdot
.924 .34084 Mdot
.924 .34105 Mdot
.924 .34144 Mdot
.924 .34206 Mdot
.924 .3424 Mdot
.924 .34252 Mdot
.924 .34299 Mdot
.924 .34567 Mdot
.924 .34569 Mdot
.924 .34578 Mdot
.924 .34625 Mdot
.924 .34815 Mdot
.924 .34863 Mdot
.924 .34877 Mdot
.924 .34921 Mdot
.924 .35156 Mdot
.924 .35186 Mdot
.924 .35251 Mdot
.924 .35503 Mdot
.924 .35523 Mdot
.924 .35529 Mdot
.924 .35536 Mdot
.924 .35547 Mdot
.924 .35584 Mdot
.924 .35596 Mdot
.924 .35627 Mdot
.924 .35694 Mdot
.924 .35829 Mdot
.924 .35897 Mdot
.924 .35911 Mdot
.924 .35959 Mdot
.924 .35982 Mdot
.924 .36016 Mdot
.924 .36207 Mdot
.924 .36284 Mdot
.924 .36331 Mdot
.924 .36437 Mdot
.924 .36504 Mdot
.924 .36748 Mdot
.924 .36755 Mdot
.924 .3676 Mdot
.924 .36764 Mdot
.924 .36769 Mdot
.924 .36816 Mdot
.924 .36936 Mdot
.924 .36975 Mdot
.924 .37016 Mdot
.924 .3711 Mdot
.924 .3713 Mdot
.924 .37225 Mdot
.924 .37307 Mdot
.924 .37342 Mdot
.924 .37362 Mdot
.924 .37362 Mdot
.924 .37437 Mdot
.924 .37495 Mdot
.924 .37539 Mdot
.924 .37576 Mdot
.924 .37601 Mdot
.924 .37602 Mdot
.924 .37631 Mdot
.924 .37681 Mdot
.924 .37692 Mdot
.924 .37717 Mdot
.924 .37765 Mdot
.924 .37927 Mdot
.924 .37984 Mdot
.924 .38102 Mdot
.924 .38108 Mdot
.924 .38146 Mdot
.924 .38263 Mdot
.924 .38273 Mdot
.924 .38374 Mdot
.924 .3839 Mdot
.924 .38404 Mdot
.924 .3844 Mdot
.924 .38535 Mdot
.924 .38584 Mdot
.924 .38589 Mdot
.924 .38644 Mdot
.924 .38687 Mdot
.924 .38782 Mdot
.924 .38802 Mdot
.924 .38802 Mdot
.924 .38855 Mdot
.924 .38879 Mdot
.924 .3893 Mdot
.924 .38939 Mdot
.924 .38954 Mdot
.924 .39056 Mdot
.924 .39134 Mdot
.924 .39188 Mdot
.924 .39384 Mdot
.924 .39486 Mdot
.924 .39625 Mdot
.924 .39643 Mdot
.924 .39723 Mdot
.924 .39785 Mdot
.924 .39801 Mdot
.924 .39841 Mdot
.924 .39908 Mdot
.924 .40018 Mdot
.924 .4029 Mdot
.924 .40329 Mdot
.924 .40412 Mdot
.924 .40508 Mdot
.924 .40576 Mdot
.924 .40595 Mdot
.924 .40747 Mdot
.924 .40834 Mdot
.924 .41005 Mdot
.924 .41012 Mdot
.924 .41028 Mdot
.924 .41061 Mdot
.924 .4112 Mdot
.924 .41124 Mdot
.924 .41233 Mdot
.924 .41247 Mdot
.924 .41369 Mdot
.924 .41373 Mdot
.924 .41374 Mdot
.924 .41375 Mdot
.924 .41448 Mdot
.924 .41533 Mdot
.924 .41667 Mdot
.924 .41766 Mdot
.924 .41845 Mdot
.924 .41865 Mdot
.924 .41908 Mdot
.924 .41924 Mdot
.924 .41993 Mdot
.924 .42212 Mdot
.924 .4224 Mdot
.924 .42442 Mdot
.924 .4249 Mdot
.924 .42566 Mdot
.924 .42616 Mdot
.924 .42632 Mdot
.924 .42649 Mdot
.924 .42722 Mdot
.924 .42724 Mdot
.924 .42745 Mdot
.924 .4288 Mdot
.924 .42885 Mdot
.924 .43036 Mdot
.924 .43073 Mdot
.924 .43283 Mdot
.924 .43285 Mdot
.924 .43286 Mdot
.924 .43291 Mdot
.924 .43294 Mdot
.924 .43311 Mdot
.924 .43323 Mdot
.924 .4338 Mdot
.924 .43386 Mdot
.924 .43421 Mdot
.924 .43457 Mdot
.924 .43463 Mdot
.924 .43593 Mdot
.924 .43612 Mdot
.924 .43615 Mdot
.924 .43625 Mdot
.924 .43636 Mdot
.924 .43749 Mdot
.924 .43756 Mdot
.924 .43878 Mdot
.924 .43897 Mdot
.924 .43913 Mdot
.924 .43934 Mdot
.924 .43977 Mdot
.924 .44147 Mdot
.924 .44338 Mdot
.924 .44344 Mdot
.924 .44385 Mdot
.924 .44407 Mdot
.924 .44417 Mdot
.924 .44427 Mdot
.924 .44452 Mdot
.924 .4449 Mdot
.924 .44779 Mdot
.924 .44822 Mdot
.924 .44875 Mdot
.924 .4489 Mdot
.924 .44899 Mdot
.924 .44942 Mdot
.924 .44943 Mdot
.924 .45035 Mdot
.924 .4504 Mdot
.924 .45105 Mdot
.924 .45298 Mdot
.924 .45317 Mdot
.924 .45345 Mdot
.924 .45381 Mdot
.924 .45437 Mdot
.924 .45503 Mdot
.924 .45509 Mdot
.924 .45653 Mdot
.924 .45705 Mdot
.924 .45771 Mdot
.924 .45921 Mdot
.924 .46045 Mdot
.924 .46067 Mdot
.924 .46082 Mdot
.924 .46222 Mdot
.924 .46234 Mdot
.924 .46323 Mdot
.924 .46497 Mdot
.924 .46586 Mdot
.924 .46717 Mdot
.924 .46741 Mdot
.924 .46846 Mdot
.924 .46887 Mdot
.924 .46906 Mdot
.924 .46963 Mdot
.924 .46965 Mdot
.924 .47049 Mdot
.924 .47058 Mdot
.924 .4712 Mdot
.924 .47124 Mdot
.924 .47152 Mdot
.924 .47157 Mdot
.924 .4716 Mdot
.924 .47168 Mdot
.924 .47177 Mdot
.924 .47192 Mdot
.924 .47277 Mdot
.924 .47323 Mdot
.924 .47339 Mdot
.924 .47404 Mdot
.924 .47411 Mdot
.924 .4776 Mdot
.924 .47862 Mdot
.924 .4795 Mdot
.924 .47977 Mdot
.924 .48176 Mdot
.924 .48394 Mdot
.924 .48424 Mdot
.924 .4854 Mdot
.924 .4872 Mdot
.924 .48772 Mdot
.924 .48778 Mdot
.924 .48803 Mdot
.924 .48949 Mdot
.924 .48955 Mdot
.924 .49083 Mdot
.924 .49116 Mdot
.924 .49267 Mdot
.924 .49284 Mdot
.924 .49319 Mdot
.924 .49466 Mdot
.924 .49479 Mdot
.924 .49505 Mdot
.924 .49522 Mdot
.924 .49733 Mdot
.924 .49836 Mdot
.924 .50132 Mdot
.924 .50165 Mdot
.924 .50231 Mdot
.924 .50325 Mdot
.924 .50335 Mdot
.924 .5045 Mdot
.924 .50461 Mdot
.924 .50461 Mdot
.924 .5059 Mdot
.924 .5064 Mdot
.924 .50797 Mdot
.924 .50865 Mdot
.924 .50885 Mdot
.924 .50948 Mdot
.924 .51096 Mdot
.924 .51229 Mdot
.924 .51269 Mdot
.924 .51322 Mdot
.924 .51378 Mdot
.924 .5142 Mdot
.924 .51555 Mdot
.924 .51781 Mdot
.924 .52046 Mdot
.924 .52067 Mdot
.924 .52293 Mdot
.924 .52556 Mdot
.924 .52718 Mdot
.924 .5279 Mdot
.924 .52844 Mdot
.924 .52897 Mdot
.924 .53322 Mdot
.924 .53361 Mdot
.924 .53531 Mdot
.924 .53665 Mdot
.924 .53762 Mdot
.924 .53833 Mdot
.924 .5385 Mdot
.924 .53917 Mdot
.924 .54017 Mdot
.924 .5404 Mdot
.924 .54132 Mdot
.924 .54236 Mdot
.924 .54261 Mdot
.924 .54475 Mdot
.924 .54498 Mdot
.924 .54563 Mdot
.924 .54616 Mdot
.924 .5478 Mdot
.924 .54975 Mdot
.924 .55011 Mdot
.924 .55092 Mdot
.924 .55404 Mdot
.924 .55452 Mdot
.924 .55593 Mdot
.924 .55656 Mdot
.924 .55658 Mdot
.924 .55759 Mdot
.924 .55763 Mdot
.924 .55767 Mdot
.924 .55772 Mdot
.924 .55851 Mdot
.924 .5586 Mdot
.926 .01499 Mdot
.926 .01522 Mdot
.926 .01527 Mdot
.926 .01558 Mdot
.926 .01565 Mdot
.926 .01575 Mdot
.926 .01631 Mdot
.926 .01633 Mdot
.926 .01644 Mdot
.926 .01663 Mdot
.926 .01755 Mdot
.926 .01766 Mdot
.926 .0177 Mdot
.926 .01779 Mdot
.926 .01791 Mdot
.926 .01827 Mdot
.926 .01971 Mdot
.926 .01997 Mdot
.926 .02017 Mdot
.926 .02024 Mdot
.926 .02042 Mdot
.926 .02063 Mdot
.926 .02129 Mdot
.926 .02263 Mdot
.926 .02365 Mdot
.926 .02389 Mdot
.926 .02397 Mdot
.926 .02445 Mdot
.926 .02447 Mdot
.926 .02481 Mdot
.926 .02494 Mdot
.926 .02526 Mdot
.926 .02528 Mdot
.926 .02567 Mdot
.926 .02579 Mdot
.926 .02615 Mdot
.926 .02675 Mdot
.926 .02689 Mdot
.926 .02825 Mdot
.926 .02836 Mdot
.926 .0288 Mdot
.926 .02938 Mdot
.926 .03077 Mdot
.926 .03127 Mdot
.926 .03135 Mdot
.926 .03171 Mdot
.926 .03185 Mdot
.926 .03274 Mdot
.926 .03277 Mdot
.926 .03303 Mdot
.926 .03342 Mdot
.926 .03352 Mdot
.926 .03366 Mdot
.926 .03425 Mdot
.926 .03428 Mdot
.926 .03501 Mdot
.926 .03515 Mdot
.926 .03522 Mdot
.926 .03529 Mdot
.926 .03539 Mdot
.926 .03574 Mdot
.926 .03583 Mdot
.926 .0359 Mdot
.926 .03701 Mdot
.926 .03727 Mdot
.926 .03799 Mdot
.926 .03956 Mdot
.926 .03978 Mdot
.926 .03989 Mdot
.926 .03998 Mdot
.926 .04079 Mdot
.926 .0408 Mdot
.926 .04122 Mdot
.926 .04166 Mdot
.926 .04187 Mdot
.926 .04355 Mdot
.926 .04444 Mdot
.926 .04454 Mdot
.926 .04456 Mdot
.926 .04537 Mdot
.926 .04551 Mdot
.926 .04619 Mdot
.926 .04646 Mdot
.926 .04802 Mdot
.926 .0481 Mdot
.926 .04816 Mdot
.926 .04822 Mdot
.926 .04863 Mdot
.926 .04887 Mdot
.926 .04936 Mdot
.926 .04954 Mdot
.926 .0498 Mdot
.926 .04993 Mdot
.926 .05011 Mdot
.926 .0509 Mdot
.926 .05094 Mdot
.926 .05112 Mdot
.926 .0523 Mdot
.926 .05255 Mdot
.926 .05264 Mdot
.926 .05269 Mdot
.926 .05282 Mdot
.926 .05301 Mdot
.926 .05366 Mdot
.926 .05382 Mdot
.926 .05395 Mdot
.926 .05407 Mdot
.926 .05511 Mdot
.926 .0552 Mdot
.926 .05601 Mdot
.926 .05648 Mdot
.926 .05739 Mdot
.926 .05783 Mdot
.926 .05882 Mdot
.926 .06067 Mdot
.926 .06072 Mdot
.926 .06073 Mdot
.926 .06113 Mdot
.926 .06121 Mdot
.926 .06134 Mdot
.926 .0615 Mdot
.926 .06301 Mdot
.926 .06302 Mdot
.926 .06355 Mdot
.926 .0638 Mdot
.926 .06461 Mdot
.926 .06501 Mdot
.926 .06541 Mdot
.926 .06723 Mdot
.926 .06812 Mdot
.926 .06887 Mdot
.926 .06977 Mdot
.926 .06996 Mdot
.926 .06999 Mdot
.926 .07018 Mdot
.926 .07042 Mdot
.926 .07148 Mdot
.926 .07158 Mdot
.926 .07175 Mdot
.926 .07265 Mdot
.926 .073 Mdot
.926 .0735 Mdot
.926 .07382 Mdot
.926 .07461 Mdot
.926 .07485 Mdot
.926 .0764 Mdot
.926 .07654 Mdot
.926 .07665 Mdot
.926 .07677 Mdot
.926 .07702 Mdot
.926 .07746 Mdot
.926 .07752 Mdot
.926 .07777 Mdot
.926 .07787 Mdot
.926 .07797 Mdot
.926 .07887 Mdot
.926 .07922 Mdot
.926 .07969 Mdot
.926 .07993 Mdot
.926 .08028 Mdot
.926 .08172 Mdot
.926 .08181 Mdot
.926 .08213 Mdot
.926 .08286 Mdot
.926 .08365 Mdot
.926 .08433 Mdot
.926 .08479 Mdot
.926 .08492 Mdot
.926 .08495 Mdot
.926 .08505 Mdot
.926 .08529 Mdot
.926 .08542 Mdot
.926 .08564 Mdot
.926 .08578 Mdot
.926 .08663 Mdot
.926 .08684 Mdot
.926 .08713 Mdot
.926 .08738 Mdot
.926 .08759 Mdot
.926 .08793 Mdot
.926 .08952 Mdot
.926 .0897 Mdot
.926 .09119 Mdot
.926 .0914 Mdot
.926 .09206 Mdot
.926 .09286 Mdot
.926 .09375 Mdot
.926 .09456 Mdot
.926 .09534 Mdot
.926 .09602 Mdot
.926 .09639 Mdot
.926 .09983 Mdot
.926 .09992 Mdot
.926 .09993 Mdot
.926 .10068 Mdot
.926 .10081 Mdot
.926 .10096 Mdot
.926 .10106 Mdot
.926 .10137 Mdot
.926 .10282 Mdot
.926 .10307 Mdot
.926 .10388 Mdot
.926 .10416 Mdot
.926 .10418 Mdot
.926 .10423 Mdot
.926 .10516 Mdot
.926 .10562 Mdot
.926 .10712 Mdot
.926 .10786 Mdot
.926 .10816 Mdot
.926 .10861 Mdot
.926 .10965 Mdot
.926 .10969 Mdot
.926 .10987 Mdot
.926 .11197 Mdot
.926 .11205 Mdot
.926 .11361 Mdot
.926 .1145 Mdot
.926 .11479 Mdot
.926 .11501 Mdot
.926 .11625 Mdot
.926 .11668 Mdot
.926 .11691 Mdot
.926 .11701 Mdot
.926 .11703 Mdot
.926 .11709 Mdot
.926 .11739 Mdot
.926 .11744 Mdot
.926 .11788 Mdot
.926 .11904 Mdot
.926 .11931 Mdot
.926 .11965 Mdot
.926 .11984 Mdot
.926 .12002 Mdot
.926 .12035 Mdot
.926 .12081 Mdot
.926 .122 Mdot
.926 .12231 Mdot
.926 .12244 Mdot
.926 .12266 Mdot
.926 .12326 Mdot
.926 .12358 Mdot
.926 .12382 Mdot
.926 .12417 Mdot
.926 .12482 Mdot
.926 .12531 Mdot
.926 .12565 Mdot
.926 .12585 Mdot
.926 .1259 Mdot
.926 .12608 Mdot
.926 .12712 Mdot
.926 .1278 Mdot
.926 .12895 Mdot
.926 .12922 Mdot
.926 .12932 Mdot
.926 .12942 Mdot
.926 .12964 Mdot
.926 .12979 Mdot
.926 .13011 Mdot
.926 .13093 Mdot
.926 .13104 Mdot
.926 .13149 Mdot
.926 .13155 Mdot
.926 .13168 Mdot
.926 .13186 Mdot
.926 .13306 Mdot
.926 .13353 Mdot
.926 .13367 Mdot
.926 .13417 Mdot
.926 .13441 Mdot
.926 .13492 Mdot
.926 .13504 Mdot
.926 .1355 Mdot
.926 .13565 Mdot
.926 .13569 Mdot
.926 .13604 Mdot
.926 .13613 Mdot
.926 .13724 Mdot
.926 .13814 Mdot
.926 .13814 Mdot
.926 .13852 Mdot
.926 .13881 Mdot
.926 .13898 Mdot
.926 .13957 Mdot
.926 .14093 Mdot
.926 .14106 Mdot
.926 .14111 Mdot
.926 .14119 Mdot
.926 .14238 Mdot
.926 .14364 Mdot
.926 .1445 Mdot
.926 .14473 Mdot
.926 .14479 Mdot
.926 .14497 Mdot
.926 .14542 Mdot
.926 .14566 Mdot
.926 .14607 Mdot
.926 .14633 Mdot
.926 .14645 Mdot
.926 .14789 Mdot
.926 .14825 Mdot
.926 .1483 Mdot
.926 .14862 Mdot
.926 .14867 Mdot
.926 .14883 Mdot
.926 .14929 Mdot
.926 .14969 Mdot
.926 .15032 Mdot
.926 .15056 Mdot
.926 .15091 Mdot
.926 .15142 Mdot
.926 .1528 Mdot
.926 .15326 Mdot
.926 .15358 Mdot
.926 .15554 Mdot
.926 .15634 Mdot
.926 .15662 Mdot
.926 .15674 Mdot
.926 .15692 Mdot
.926 .15796 Mdot
.926 .15867 Mdot
.926 .15944 Mdot
.926 .16015 Mdot
.926 .16108 Mdot
.926 .16238 Mdot
.926 .16259 Mdot
.926 .16384 Mdot
.926 .16404 Mdot
.926 .16529 Mdot
.926 .16587 Mdot
.926 .16598 Mdot
.926 .16655 Mdot
.926 .16721 Mdot
.926 .16962 Mdot
.926 .17137 Mdot
.926 .1716 Mdot
.926 .17179 Mdot
.926 .17235 Mdot
.926 .17252 Mdot
.926 .17254 Mdot
.926 .17301 Mdot
.926 .17309 Mdot
.926 .17337 Mdot
.926 .17344 Mdot
.926 .17393 Mdot
.926 .17417 Mdot
.926 .17445 Mdot
.926 .17453 Mdot
.926 .17462 Mdot
.926 .17483 Mdot
.926 .1752 Mdot
.926 .17668 Mdot
.926 .1776 Mdot
.926 .17771 Mdot
.926 .17788 Mdot
.926 .17835 Mdot
.926 .17985 Mdot
.926 .18037 Mdot
.926 .1804 Mdot
.926 .1805 Mdot
.926 .18053 Mdot
.926 .18116 Mdot
.926 .18171 Mdot
.926 .18222 Mdot
.926 .18307 Mdot
.926 .18408 Mdot
.926 .18469 Mdot
.926 .18543 Mdot
.926 .18584 Mdot
.926 .18615 Mdot
.926 .18681 Mdot
.926 .18723 Mdot
.926 .18777 Mdot
.926 .18778 Mdot
.926 .18861 Mdot
.926 .19016 Mdot
.926 .19054 Mdot
.926 .19061 Mdot
.926 .19095 Mdot
.926 .1916 Mdot
.926 .19254 Mdot
.926 .19275 Mdot
.926 .19447 Mdot
.926 .19484 Mdot
.926 .19498 Mdot
.926 .19509 Mdot
.926 .19572 Mdot
.926 .19673 Mdot
.926 .19715 Mdot
.926 .19788 Mdot
.926 .19807 Mdot
.926 .19952 Mdot
.926 .20006 Mdot
.926 .20013 Mdot
.926 .20047 Mdot
.926 .20206 Mdot
.926 .20211 Mdot
.926 .20275 Mdot
.926 .20355 Mdot
.926 .20397 Mdot
.926 .20416 Mdot
.926 .20419 Mdot
.926 .2043 Mdot
.926 .20487 Mdot
.926 .20496 Mdot
.926 .2053 Mdot
.926 .20578 Mdot
.926 .20602 Mdot
.926 .20714 Mdot
.926 .20734 Mdot
.926 .20778 Mdot
.926 .20792 Mdot
.926 .20843 Mdot
.926 .20887 Mdot
.926 .20905 Mdot
.926 .20927 Mdot
.926 .20942 Mdot
.926 .20963 Mdot
.926 .20964 Mdot
.926 .20974 Mdot
.926 .21009 Mdot
.926 .21035 Mdot
.926 .21047 Mdot
.926 .21121 Mdot
.926 .21122 Mdot
.926 .21124 Mdot
.926 .2133 Mdot
.926 .21341 Mdot
.926 .21342 Mdot
.926 .21398 Mdot
.926 .21408 Mdot
.926 .21423 Mdot
.926 .21463 Mdot
.926 .21574 Mdot
.926 .21634 Mdot
.926 .21677 Mdot
.926 .21742 Mdot
.926 .21844 Mdot
.926 .21864 Mdot
.926 .21883 Mdot
.926 .21953 Mdot
.926 .22011 Mdot
.926 .22016 Mdot
.926 .22052 Mdot
.926 .22054 Mdot
.926 .22063 Mdot
.926 .22065 Mdot
.926 .22097 Mdot
.926 .22186 Mdot
.926 .22271 Mdot
.926 .2229 Mdot
.926 .22306 Mdot
.926 .22375 Mdot
.926 .22393 Mdot
.926 .22414 Mdot
.926 .22435 Mdot
.926 .22455 Mdot
.926 .22594 Mdot
.926 .22628 Mdot
.926 .22678 Mdot
.926 .22696 Mdot
.926 .22714 Mdot
.926 .22744 Mdot
.926 .22756 Mdot
.926 .22783 Mdot
.926 .22843 Mdot
.926 .22899 Mdot
.926 .22994 Mdot
.926 .23014 Mdot
.926 .23047 Mdot
.926 .23066 Mdot
.926 .23098 Mdot
.926 .23109 Mdot
.926 .2312 Mdot
.926 .23133 Mdot
.926 .23144 Mdot
.926 .23167 Mdot
.926 .23227 Mdot
.926 .2323 Mdot
.926 .2325 Mdot
.926 .23388 Mdot
.926 .23425 Mdot
.926 .23437 Mdot
.926 .23476 Mdot
.926 .23501 Mdot
.926 .23531 Mdot
.926 .23537 Mdot
.926 .23555 Mdot
.926 .23595 Mdot
.926 .23639 Mdot
.926 .23684 Mdot
.926 .23733 Mdot
.926 .23756 Mdot
.926 .23781 Mdot
.926 .23838 Mdot
.926 .23841 Mdot
.926 .23869 Mdot
.926 .2387 Mdot
.926 .23875 Mdot
.926 .23913 Mdot
.926 .23941 Mdot
.926 .23958 Mdot
.926 .24126 Mdot
.926 .24163 Mdot
.926 .24329 Mdot
.926 .2433 Mdot
.926 .244 Mdot
.926 .24413 Mdot
.926 .24454 Mdot
.926 .24485 Mdot
.926 .24541 Mdot
.926 .24595 Mdot
.926 .24699 Mdot
.926 .24838 Mdot
.926 .24846 Mdot
.926 .24871 Mdot
.926 .2488 Mdot
.926 .24895 Mdot
.926 .25111 Mdot
.926 .25113 Mdot
.926 .25115 Mdot
.926 .25349 Mdot
.926 .25353 Mdot
.926 .254 Mdot
.926 .25507 Mdot
.926 .2554 Mdot
.926 .2555 Mdot
.926 .25561 Mdot
.926 .25595 Mdot
.926 .25604 Mdot
.926 .25645 Mdot
.926 .25678 Mdot
.926 .25722 Mdot
.926 .25798 Mdot
.926 .25806 Mdot
.926 .25836 Mdot
.926 .25847 Mdot
.926 .25869 Mdot
.926 .26024 Mdot
.926 .26136 Mdot
.926 .26202 Mdot
.926 .26211 Mdot
.926 .26271 Mdot
.926 .26279 Mdot
.926 .2631 Mdot
.926 .26379 Mdot
.926 .26468 Mdot
.926 .26585 Mdot
.926 .26631 Mdot
.926 .26695 Mdot
.926 .2679 Mdot
.926 .26856 Mdot
.926 .26884 Mdot
.926 .2697 Mdot
.926 .27001 Mdot
.926 .27004 Mdot
.926 .27046 Mdot
.926 .27052 Mdot
.926 .27131 Mdot
.926 .2719 Mdot
.926 .27461 Mdot
.926 .27529 Mdot
.926 .27552 Mdot
.926 .27629 Mdot
.926 .277 Mdot
.926 .27751 Mdot
.926 .27775 Mdot
.926 .27791 Mdot
.926 .27799 Mdot
.926 .27807 Mdot
.926 .27808 Mdot
.926 .28001 Mdot
.926 .28132 Mdot
.926 .28275 Mdot
.926 .28296 Mdot
.926 .28405 Mdot
.926 .28524 Mdot
.926 .28578 Mdot
.926 .28607 Mdot
.926 .28624 Mdot
.926 .28782 Mdot
.926 .2882 Mdot
.926 .28857 Mdot
.926 .29008 Mdot
.926 .2909 Mdot
.926 .29126 Mdot
.926 .29151 Mdot
.926 .29265 Mdot
.926 .293 Mdot
.926 .29338 Mdot
.926 .29358 Mdot
.926 .29454 Mdot
.926 .29466 Mdot
.926 .29483 Mdot
.926 .29486 Mdot
.926 .29584 Mdot
.926 .29591 Mdot
.926 .29624 Mdot
.926 .29714 Mdot
.926 .29736 Mdot
.926 .29857 Mdot
.926 .29889 Mdot
.926 .30077 Mdot
.926 .30149 Mdot
.926 .3016 Mdot
.926 .30175 Mdot
.926 .30281 Mdot
.926 .30316 Mdot
.926 .30393 Mdot
.926 .30483 Mdot
.926 .30526 Mdot
.926 .30561 Mdot
.926 .30665 Mdot
.926 .30696 Mdot
.926 .30701 Mdot
.926 .30739 Mdot
.926 .30788 Mdot
.926 .30802 Mdot
.926 .30854 Mdot
.926 .30868 Mdot
.926 .30924 Mdot
.926 .30938 Mdot
.926 .30958 Mdot
.926 .30966 Mdot
.926 .31003 Mdot
.926 .31054 Mdot
.926 .3107 Mdot
.926 .31087 Mdot
.926 .31125 Mdot
.926 .31193 Mdot
.926 .31206 Mdot
.926 .31309 Mdot
.926 .31467 Mdot
.926 .31522 Mdot
.926 .31535 Mdot
.926 .31566 Mdot
.926 .31609 Mdot
.926 .31637 Mdot
.926 .31657 Mdot
.926 .3169 Mdot
.926 .3177 Mdot
.926 .31776 Mdot
.926 .318 Mdot
.926 .31906 Mdot
.926 .31938 Mdot
.926 .32028 Mdot
.926 .32055 Mdot
.926 .32143 Mdot
.926 .32151 Mdot
.926 .32156 Mdot
.926 .32175 Mdot
.926 .3218 Mdot
.926 .32297 Mdot
.926 .32381 Mdot
.926 .32399 Mdot
.926 .32448 Mdot
.926 .32471 Mdot
.926 .32494 Mdot
.926 .32597 Mdot
.926 .3265 Mdot
.926 .32651 Mdot
.926 .32838 Mdot
.926 .32849 Mdot
.926 .32884 Mdot
.926 .32941 Mdot
.926 .32951 Mdot
.926 .33005 Mdot
.926 .33087 Mdot
.926 .33164 Mdot
.926 .33221 Mdot
.926 .33226 Mdot
.926 .33344 Mdot
.926 .33421 Mdot
.926 .33521 Mdot
.926 .33524 Mdot
.926 .3355 Mdot
.926 .33677 Mdot
.926 .33777 Mdot
.926 .33875 Mdot
.926 .33964 Mdot
.926 .34035 Mdot
.926 .34047 Mdot
.926 .3411 Mdot
.926 .34168 Mdot
.926 .34231 Mdot
.926 .34274 Mdot
.926 .34287 Mdot
.926 .34404 Mdot
.926 .34428 Mdot
.926 .34444 Mdot
.926 .3445 Mdot
.926 .34719 Mdot
.926 .34762 Mdot
.926 .3483 Mdot
.926 .34857 Mdot
.926 .34877 Mdot
.926 .34923 Mdot
.926 .34993 Mdot
.926 .35181 Mdot
.926 .35259 Mdot
.926 .35393 Mdot
.926 .3543 Mdot
.926 .35697 Mdot
.926 .35797 Mdot
.926 .3581 Mdot
.926 .35854 Mdot
.926 .35873 Mdot
.926 .36085 Mdot
.926 .36166 Mdot
.926 .36168 Mdot
.926 .36178 Mdot
.926 .36295 Mdot
.926 .36428 Mdot
.926 .36443 Mdot
.926 .36522 Mdot
.926 .36557 Mdot
.926 .36563 Mdot
.926 .36584 Mdot
.926 .36673 Mdot
.926 .36688 Mdot
.926 .36706 Mdot
.926 .36768 Mdot
.926 .36849 Mdot
.926 .36856 Mdot
.926 .36901 Mdot
.926 .36931 Mdot
.926 .36985 Mdot
.926 .37011 Mdot
.926 .37041 Mdot
.926 .37043 Mdot
.926 .37109 Mdot
.926 .37146 Mdot
.926 .37228 Mdot
.926 .37253 Mdot
.926 .37348 Mdot
.926 .37429 Mdot
.926 .37462 Mdot
.926 .37503 Mdot
.926 .3753 Mdot
.926 .3757 Mdot
.926 .37572 Mdot
.926 .37591 Mdot
.926 .37655 Mdot
.926 .37704 Mdot
.926 .37704 Mdot
.926 .37724 Mdot
.926 .37862 Mdot
.926 .37864 Mdot
.926 .37869 Mdot
.926 .38153 Mdot
.926 .3825 Mdot
.926 .3827 Mdot
.926 .38272 Mdot
.926 .38375 Mdot
.926 .38394 Mdot
.926 .38421 Mdot
.926 .38496 Mdot
.926 .38644 Mdot
.926 .38702 Mdot
.926 .38718 Mdot
.926 .38812 Mdot
.926 .38892 Mdot
.926 .39013 Mdot
.926 .39092 Mdot
.926 .39201 Mdot
.926 .39238 Mdot
.926 .39274 Mdot
.926 .39404 Mdot
.926 .39498 Mdot
.926 .39511 Mdot
.926 .39521 Mdot
.926 .39587 Mdot
.926 .39591 Mdot
.926 .39606 Mdot
.926 .3961 Mdot
.926 .39669 Mdot
.926 .39685 Mdot
.926 .39785 Mdot
.926 .39835 Mdot
.926 .3984 Mdot
.926 .39993 Mdot
.926 .40027 Mdot
.926 .40057 Mdot
.926 .40185 Mdot
.926 .40218 Mdot
.926 .40257 Mdot
.926 .40296 Mdot
.926 .40332 Mdot
.926 .40385 Mdot
.926 .40513 Mdot
.926 .40591 Mdot
.926 .40641 Mdot
.926 .40653 Mdot
.926 .40746 Mdot
.926 .40779 Mdot
.926 .40813 Mdot
.926 .40868 Mdot
.926 .40891 Mdot
.926 .4094 Mdot
.926 .41051 Mdot
.926 .41155 Mdot
.926 .41158 Mdot
.926 .41331 Mdot
.926 .41369 Mdot
.926 .4143 Mdot
.926 .4144 Mdot
.926 .41464 Mdot
.926 .41523 Mdot
.926 .41545 Mdot
.926 .41564 Mdot
.926 .41565 Mdot
.926 .41589 Mdot
.926 .41609 Mdot
.926 .4165 Mdot
.926 .41651 Mdot
.926 .41762 Mdot
.926 .41769 Mdot
.926 .41804 Mdot
.926 .4204 Mdot
.926 .42061 Mdot
.926 .4213 Mdot
.926 .42152 Mdot
.926 .42159 Mdot
.926 .42225 Mdot
.926 .42271 Mdot
.926 .42289 Mdot
.926 .42327 Mdot
.926 .42336 Mdot
.926 .42359 Mdot
.926 .4237 Mdot
.926 .42445 Mdot
.926 .42526 Mdot
.926 .4261 Mdot
.926 .4269 Mdot
.926 .427 Mdot
.926 .42729 Mdot
.926 .42742 Mdot
.926 .42787 Mdot
.926 .42788 Mdot
.926 .42799 Mdot
.926 .42894 Mdot
.926 .429 Mdot
.926 .42951 Mdot
.926 .42954 Mdot
.926 .42964 Mdot
.926 .43034 Mdot
.926 .43086 Mdot
.926 .43116 Mdot
.926 .43134 Mdot
.926 .43157 Mdot
.926 .43272 Mdot
.926 .43427 Mdot
.926 .43496 Mdot
.926 .43581 Mdot
.926 .43656 Mdot
.926 .43804 Mdot
.926 .43805 Mdot
.926 .43935 Mdot
.926 .4396 Mdot
.926 .44036 Mdot
.926 .4407 Mdot
.926 .44092 Mdot
.926 .44179 Mdot
.926 .44196 Mdot
.926 .44297 Mdot
.926 .44489 Mdot
.926 .44746 Mdot
.926 .44761 Mdot
.926 .44808 Mdot
.926 .44824 Mdot
.926 .44826 Mdot
.926 .44852 Mdot
.926 .45073 Mdot
.926 .45109 Mdot
.926 .45163 Mdot
.926 .45251 Mdot
.926 .45255 Mdot
.926 .4526 Mdot
.926 .45524 Mdot
.926 .45647 Mdot
.926 .45692 Mdot
.926 .45701 Mdot
.926 .45786 Mdot
.926 .45908 Mdot
.926 .45985 Mdot
.926 .46047 Mdot
.926 .46066 Mdot
.926 .46086 Mdot
.926 .46149 Mdot
.926 .46164 Mdot
.926 .46219 Mdot
.926 .46241 Mdot
.926 .46301 Mdot
.926 .46366 Mdot
.926 .46384 Mdot
.926 .46485 Mdot
.926 .46524 Mdot
.926 .46539 Mdot
.926 .46595 Mdot
.926 .46615 Mdot
.926 .46656 Mdot
.926 .46843 Mdot
.926 .46943 Mdot
.926 .4695 Mdot
.926 .46965 Mdot
.926 .47095 Mdot
.926 .47151 Mdot
.926 .47266 Mdot
.926 .47273 Mdot
.926 .47289 Mdot
.926 .47313 Mdot
.926 .474 Mdot
.926 .47416 Mdot
.926 .47473 Mdot
.926 .4749 Mdot
.926 .47539 Mdot
.926 .47601 Mdot
.926 .4773 Mdot
.926 .47766 Mdot
.926 .47778 Mdot
.926 .47846 Mdot
.926 .47875 Mdot
.926 .47982 Mdot
.926 .48001 Mdot
.926 .48066 Mdot
.926 .48186 Mdot
.926 .48361 Mdot
.926 .48483 Mdot
.926 .48536 Mdot
.926 .48694 Mdot
.926 .48752 Mdot
.926 .48758 Mdot
.926 .48835 Mdot
.926 .48846 Mdot
.926 .48992 Mdot
.926 .49102 Mdot
.926 .49605 Mdot
.926 .49729 Mdot
.926 .49773 Mdot
.926 .49914 Mdot
.926 .50047 Mdot
.926 .50142 Mdot
.926 .50186 Mdot
.926 .50215 Mdot
.926 .50229 Mdot
.926 .50245 Mdot
.926 .50247 Mdot
.926 .50603 Mdot
.926 .50846 Mdot
.926 .51111 Mdot
.926 .51151 Mdot
.926 .51353 Mdot
.926 .51572 Mdot
.926 .51673 Mdot
.926 .51727 Mdot
.926 .51757 Mdot
.926 .52051 Mdot
.926 .5212 Mdot
.926 .5219 Mdot
.926 .52469 Mdot
.926 .52621 Mdot
.926 .52688 Mdot
.926 .52734 Mdot
.926 .52945 Mdot
.926 .53009 Mdot
.926 .53079 Mdot
.926 .53117 Mdot
.926 .53296 Mdot
.926 .53317 Mdot
.926 .53348 Mdot
.926 .53355 Mdot
.926 .53536 Mdot
.926 .53548 Mdot
.926 .5361 Mdot
.926 .53777 Mdot
.926 .53818 Mdot
.926 .54041 Mdot
.926 .541 Mdot
.926 .54449 Mdot
.926 .54583 Mdot
.926 .54602 Mdot
.926 .54631 Mdot
.926 .54826 Mdot
.926 .54892 Mdot
.926 .55033 Mdot
.926 .55201 Mdot
.926 .55281 Mdot
.926 .55345 Mdot
.926 .55538 Mdot
.926 .55596 Mdot
.926 .55604 Mdot
.926 .55674 Mdot
.926 .55766 Mdot
.926 .55792 Mdot
.926 .55888 Mdot
.926 .55914 Mdot
.926 .56017 Mdot
.926 .56043 Mdot
.926 .5608 Mdot
.926 .56096 Mdot
.926 .56163 Mdot
.928 .01498 Mdot
.928 .0152 Mdot
.928 .01544 Mdot
.928 .01561 Mdot
.928 .01607 Mdot
.928 .01638 Mdot
.928 .01694 Mdot
.928 .01706 Mdot
.928 .01714 Mdot
.928 .01723 Mdot
.928 .01757 Mdot
.928 .01781 Mdot
.928 .01834 Mdot
.928 .01884 Mdot
.928 .01898 Mdot
.928 .01906 Mdot
.928 .01922 Mdot
.928 .01938 Mdot
.928 .02002 Mdot
.928 .02034 Mdot
.928 .02046 Mdot
.928 .02143 Mdot
.928 .02144 Mdot
.928 .02215 Mdot
.928 .02236 Mdot
.928 .02262 Mdot
.928 .02278 Mdot
.928 .02308 Mdot
.928 .02336 Mdot
.928 .02423 Mdot
.928 .02456 Mdot
.928 .02493 Mdot
.928 .02515 Mdot
.928 .02537 Mdot
.928 .02581 Mdot
.928 .02654 Mdot
.928 .02718 Mdot
.928 .02719 Mdot
.928 .02852 Mdot
.928 .02859 Mdot
.928 .02891 Mdot
.928 .0294 Mdot
.928 .02968 Mdot
.928 .03022 Mdot
.928 .03024 Mdot
.928 .03036 Mdot
.928 .03077 Mdot
.928 .031 Mdot
.928 .03109 Mdot
.928 .03196 Mdot
.928 .03237 Mdot
.928 .03254 Mdot
.928 .03286 Mdot
.928 .03298 Mdot
.928 .03301 Mdot
.928 .03316 Mdot
.928 .03322 Mdot
.928 .03367 Mdot
.928 .03409 Mdot
.928 .03446 Mdot
.928 .0345 Mdot
.928 .0353 Mdot
.928 .03666 Mdot
.928 .03722 Mdot
.928 .03785 Mdot
.928 .03787 Mdot
.928 .03976 Mdot
.928 .04034 Mdot
.928 .04047 Mdot
.928 .04106 Mdot
.928 .04152 Mdot
.928 .04187 Mdot
.928 .04196 Mdot
.928 .04232 Mdot
.928 .0425 Mdot
.928 .04278 Mdot
.928 .04279 Mdot
.928 .04349 Mdot
.928 .04353 Mdot
.928 .04376 Mdot
.928 .04425 Mdot
.928 .04451 Mdot
.928 .04495 Mdot
.928 .0451 Mdot
.928 .04523 Mdot
.928 .04612 Mdot
.928 .04619 Mdot
.928 .04672 Mdot
.928 .04678 Mdot
.928 .04748 Mdot
.928 .0478 Mdot
.928 .04783 Mdot
.928 .04838 Mdot
.928 .0486 Mdot
.928 .04861 Mdot
.928 .04866 Mdot
.928 .04896 Mdot
.928 .04905 Mdot
.928 .04989 Mdot
.928 .05 Mdot
.928 .05018 Mdot
.928 .05021 Mdot
.928 .05067 Mdot
.928 .05136 Mdot
.928 .05143 Mdot
.928 .05293 Mdot
.928 .05419 Mdot
.928 .05512 Mdot
.928 .05544 Mdot
.928 .05595 Mdot
.928 .0563 Mdot
.928 .05648 Mdot
.928 .05707 Mdot
.928 .05759 Mdot
.928 .05765 Mdot
.928 .05769 Mdot
.928 .05769 Mdot
.928 .05974 Mdot
.928 .06102 Mdot
.928 .06116 Mdot
.928 .0612 Mdot
.928 .06176 Mdot
.928 .06227 Mdot
.928 .06252 Mdot
.928 .06345 Mdot
.928 .06362 Mdot
.928 .06394 Mdot
.928 .06395 Mdot
.928 .06447 Mdot
.928 .06493 Mdot
.928 .06511 Mdot
.928 .06528 Mdot
.928 .06596 Mdot
.928 .06599 Mdot
.928 .06628 Mdot
.928 .0668 Mdot
.928 .06682 Mdot
.928 .06726 Mdot
.928 .06792 Mdot
.928 .06792 Mdot
.928 .06813 Mdot
.928 .0682 Mdot
.928 .06862 Mdot
.928 .06904 Mdot
.928 .06953 Mdot
.928 .06957 Mdot
.928 .07001 Mdot
.928 .07051 Mdot
.928 .07082 Mdot
.928 .07112 Mdot
.928 .07135 Mdot
.928 .073 Mdot
.928 .07313 Mdot
.928 .07399 Mdot
.928 .07411 Mdot
.928 .07423 Mdot
.928 .07437 Mdot
.928 .07444 Mdot
.928 .07552 Mdot
.928 .07613 Mdot
.928 .07617 Mdot
.928 .07658 Mdot
.928 .0772 Mdot
.928 .0776 Mdot
.928 .07761 Mdot
.928 .07763 Mdot
.928 .07772 Mdot
.928 .07782 Mdot
.928 .07827 Mdot
.928 .07845 Mdot
.928 .07859 Mdot
.928 .08 Mdot
.928 .08021 Mdot
.928 .08054 Mdot
.928 .08055 Mdot
.928 .08059 Mdot
.928 .08145 Mdot
.928 .08199 Mdot
.928 .08206 Mdot
.928 .08273 Mdot
.928 .08286 Mdot
.928 .084 Mdot
.928 .08423 Mdot
.928 .08464 Mdot
.928 .08564 Mdot
.928 .08581 Mdot
.928 .08599 Mdot
.928 .08713 Mdot
.928 .08772 Mdot
.928 .0878 Mdot
.928 .08798 Mdot
.928 .08938 Mdot
.928 .0897 Mdot
.928 .09029 Mdot
.928 .09125 Mdot
.928 .09184 Mdot
.928 .09189 Mdot
.928 .09207 Mdot
.928 .09222 Mdot
.928 .09332 Mdot
.928 .0942 Mdot
.928 .09429 Mdot
.928 .09441 Mdot
.928 .09448 Mdot
.928 .09448 Mdot
.928 .09686 Mdot
.928 .09723 Mdot
.928 .09725 Mdot
.928 .09818 Mdot
.928 .09829 Mdot
.928 .09858 Mdot
.928 .09894 Mdot
.928 .09974 Mdot
.928 .10059 Mdot
.928 .10066 Mdot
.928 .10092 Mdot
.928 .101 Mdot
.928 .10171 Mdot
.928 .10204 Mdot
.928 .10298 Mdot
.928 .10344 Mdot
.928 .10364 Mdot
.928 .10447 Mdot
.928 .10517 Mdot
.928 .10532 Mdot
.928 .10547 Mdot
.928 .10557 Mdot
.928 .10607 Mdot
.928 .1061 Mdot
.928 .10705 Mdot
.928 .10791 Mdot
.928 .10825 Mdot
.928 .10857 Mdot
.928 .10877 Mdot
.928 .10887 Mdot
.928 .10928 Mdot
.928 .10982 Mdot
.928 .10988 Mdot
.928 .10989 Mdot
.928 .11023 Mdot
.928 .11039 Mdot
.928 .11042 Mdot
.928 .11054 Mdot
.928 .11107 Mdot
.928 .11139 Mdot
.928 .11142 Mdot
.928 .11188 Mdot
.928 .11223 Mdot
.928 .11265 Mdot
.928 .11346 Mdot
.928 .11346 Mdot
.928 .11385 Mdot
.928 .11398 Mdot
.928 .11416 Mdot
.928 .11476 Mdot
.928 .11544 Mdot
.928 .11554 Mdot
.928 .11562 Mdot
.928 .1163 Mdot
.928 .11633 Mdot
.928 .11644 Mdot
.928 .11644 Mdot
.928 .11652 Mdot
.928 .11682 Mdot
.928 .11735 Mdot
.928 .11825 Mdot
.928 .11826 Mdot
.928 .11844 Mdot
.928 .11873 Mdot
.928 .11885 Mdot
.928 .1194 Mdot
.928 .11982 Mdot
.928 .12016 Mdot
.928 .1221 Mdot
.928 .12289 Mdot
.928 .12313 Mdot
.928 .12474 Mdot
.928 .12496 Mdot
.928 .12518 Mdot
.928 .12543 Mdot
.928 .12557 Mdot
.928 .12758 Mdot
.928 .12788 Mdot
.928 .12796 Mdot
.928 .1287 Mdot
.928 .12878 Mdot
.928 .12908 Mdot
.928 .12954 Mdot
.928 .12981 Mdot
.928 .13069 Mdot
.928 .13096 Mdot
.928 .13143 Mdot
.928 .13149 Mdot
.928 .13165 Mdot
.928 .13172 Mdot
.928 .13185 Mdot
.928 .13267 Mdot
.928 .13295 Mdot
.928 .133 Mdot
.928 .13327 Mdot
.928 .13521 Mdot
.928 .13556 Mdot
.928 .13589 Mdot
.928 .13628 Mdot
.928 .13688 Mdot
.928 .1369 Mdot
.928 .13699 Mdot
.928 .13794 Mdot
.928 .13857 Mdot
.928 .13958 Mdot
.928 .1397 Mdot
.928 .14009 Mdot
.928 .14095 Mdot
.928 .1412 Mdot
.928 .1423 Mdot
.928 .14331 Mdot
.928 .14374 Mdot
.928 .1445 Mdot
.928 .14592 Mdot
.928 .14603 Mdot
.928 .14634 Mdot
.928 .14667 Mdot
.928 .147 Mdot
.928 .14716 Mdot
.928 .14727 Mdot
.928 .14736 Mdot
.928 .14773 Mdot
.928 .14913 Mdot
.928 .1502 Mdot
.928 .15037 Mdot
.928 .1507 Mdot
.928 .15095 Mdot
.928 .15103 Mdot
.928 .15235 Mdot
.928 .15247 Mdot
.928 .1533 Mdot
.928 .15383 Mdot
.928 .1539 Mdot
.928 .15443 Mdot
.928 .15472 Mdot
.928 .15499 Mdot
.928 .15518 Mdot
.928 .15676 Mdot
.928 .15755 Mdot
.928 .15786 Mdot
.928 .15796 Mdot
.928 .15829 Mdot
.928 .15857 Mdot
.928 .1586 Mdot
.928 .15909 Mdot
.928 .16051 Mdot
.928 .16061 Mdot
.928 .16223 Mdot
.928 .1624 Mdot
.928 .16262 Mdot
.928 .16276 Mdot
.928 .16276 Mdot
.928 .16585 Mdot
.928 .16718 Mdot
.928 .16787 Mdot
.928 .1679 Mdot
.928 .16935 Mdot
.928 .16963 Mdot
.928 .16983 Mdot
.928 .17037 Mdot
.928 .17074 Mdot
.928 .17103 Mdot
.928 .17218 Mdot
.928 .17253 Mdot
.928 .17333 Mdot
.928 .17376 Mdot
.928 .1741 Mdot
.928 .17424 Mdot
.928 .17467 Mdot
.928 .17471 Mdot
.928 .17486 Mdot
.928 .17619 Mdot
.928 .17679 Mdot
.928 .17746 Mdot
.928 .17805 Mdot
.928 .17853 Mdot
.928 .17857 Mdot
.928 .17903 Mdot
.928 .17929 Mdot
.928 .17934 Mdot
.928 .17938 Mdot
.928 .1794 Mdot
.928 .17976 Mdot
.928 .18056 Mdot
.928 .1813 Mdot
.928 .18217 Mdot
.928 .1826 Mdot
.928 .18288 Mdot
.928 .18316 Mdot
.928 .18334 Mdot
.928 .18427 Mdot
.928 .18433 Mdot
.928 .1861 Mdot
.928 .18647 Mdot
.928 .18751 Mdot
.928 .18768 Mdot
.928 .18831 Mdot
.928 .18891 Mdot
.928 .18928 Mdot
.928 .18947 Mdot
.928 .18947 Mdot
.928 .18995 Mdot
.928 .19022 Mdot
.928 .19123 Mdot
.928 .19134 Mdot
.928 .19136 Mdot
.928 .19199 Mdot
.928 .19228 Mdot
.928 .19235 Mdot
.928 .19257 Mdot
.928 .19356 Mdot
.928 .19414 Mdot
.928 .19421 Mdot
.928 .19467 Mdot
.928 .19472 Mdot
.928 .19505 Mdot
.928 .19522 Mdot
.928 .19524 Mdot
.928 .1957 Mdot
.928 .19648 Mdot
.928 .1971 Mdot
.928 .19787 Mdot
.928 .19798 Mdot
.928 .19799 Mdot
.928 .19871 Mdot
.928 .19896 Mdot
.928 .19928 Mdot
.928 .19984 Mdot
.928 .20008 Mdot
.928 .2004 Mdot
.928 .20148 Mdot
.928 .20166 Mdot
.928 .20175 Mdot
.928 .2018 Mdot
.928 .20184 Mdot
.928 .202 Mdot
.928 .20246 Mdot
.928 .20327 Mdot
.928 .20332 Mdot
.928 .20352 Mdot
.928 .20353 Mdot
.928 .20356 Mdot
.928 .20367 Mdot
.928 .20408 Mdot
.928 .20414 Mdot
.928 .20422 Mdot
.928 .20464 Mdot
.928 .2052 Mdot
.928 .20688 Mdot
.928 .2069 Mdot
.928 .20723 Mdot
.928 .20744 Mdot
.928 .20777 Mdot
.928 .20799 Mdot
.928 .209 Mdot
.928 .20911 Mdot
.928 .2098 Mdot
.928 .21042 Mdot
.928 .21211 Mdot
.928 .21251 Mdot
.928 .21253 Mdot
.928 .21264 Mdot
.928 .21357 Mdot
.928 .21398 Mdot
.928 .21402 Mdot
.928 .2148 Mdot
.928 .21549 Mdot
.928 .21594 Mdot
.928 .21892 Mdot
.928 .21932 Mdot
.928 .21974 Mdot
.928 .22007 Mdot
.928 .2202 Mdot
.928 .22046 Mdot
.928 .22144 Mdot
.928 .22182 Mdot
.928 .22183 Mdot
.928 .22217 Mdot
.928 .22389 Mdot
.928 .22419 Mdot
.928 .22476 Mdot
.928 .2249 Mdot
.928 .22627 Mdot
.928 .22643 Mdot
.928 .22697 Mdot
.928 .22784 Mdot
.928 .22824 Mdot
.928 .22832 Mdot
.928 .22834 Mdot
.928 .22916 Mdot
.928 .22997 Mdot
.928 .23046 Mdot
.928 .23133 Mdot
.928 .23144 Mdot
.928 .23145 Mdot
.928 .23175 Mdot
.928 .23187 Mdot
.928 .23211 Mdot
.928 .23364 Mdot
.928 .23415 Mdot
.928 .23425 Mdot
.928 .23475 Mdot
.928 .23601 Mdot
.928 .23628 Mdot
.928 .23694 Mdot
.928 .23835 Mdot
.928 .23854 Mdot
.928 .239 Mdot
.928 .23961 Mdot
.928 .24034 Mdot
.928 .24064 Mdot
.928 .24076 Mdot
.928 .24145 Mdot
.928 .2415 Mdot
.928 .24165 Mdot
.928 .24314 Mdot
.928 .24342 Mdot
.928 .24366 Mdot
.928 .2442 Mdot
.928 .24459 Mdot
.928 .2446 Mdot
.928 .24647 Mdot
.928 .2467 Mdot
.928 .24698 Mdot
.928 .24714 Mdot
.928 .2474 Mdot
.928 .24766 Mdot
.928 .249 Mdot
.928 .24947 Mdot
.928 .25151 Mdot
.928 .2528 Mdot
.928 .25339 Mdot
.928 .25377 Mdot
.928 .25418 Mdot
.928 .25458 Mdot
.928 .25559 Mdot
.928 .25644 Mdot
.928 .25651 Mdot
.928 .25779 Mdot
.928 .25784 Mdot
.928 .25823 Mdot
.928 .25844 Mdot
.928 .25902 Mdot
.928 .25963 Mdot
.928 .26024 Mdot
.928 .26053 Mdot
.928 .26074 Mdot
.928 .26091 Mdot
.928 .2616 Mdot
.928 .26242 Mdot
.928 .26405 Mdot
.928 .26411 Mdot
.928 .26418 Mdot
.928 .26425 Mdot
.928 .26477 Mdot
.928 .26504 Mdot
.928 .26516 Mdot
.928 .26604 Mdot
.928 .26618 Mdot
.928 .26649 Mdot
.928 .26658 Mdot
.928 .2671 Mdot
.928 .26748 Mdot
.928 .26756 Mdot
.928 .26772 Mdot
.928 .26836 Mdot
.928 .27016 Mdot
.928 .27039 Mdot
.928 .27193 Mdot
.928 .27292 Mdot
.928 .27298 Mdot
.928 .27303 Mdot
.928 .27403 Mdot
.928 .27457 Mdot
.928 .27459 Mdot
.928 .27506 Mdot
.928 .27542 Mdot
.928 .27835 Mdot
.928 .27982 Mdot
.928 .2804 Mdot
.928 .28058 Mdot
.928 .28118 Mdot
.928 .28162 Mdot
.928 .28172 Mdot
.928 .28176 Mdot
.928 .28237 Mdot
.928 .28267 Mdot
.928 .2835 Mdot
.928 .28532 Mdot
.928 .28549 Mdot
.928 .28556 Mdot
.928 .2856 Mdot
.928 .28605 Mdot
.928 .28802 Mdot
.928 .2881 Mdot
.928 .28851 Mdot
.928 .28882 Mdot
.928 .28923 Mdot
.928 .2894 Mdot
.928 .28948 Mdot
.928 .28949 Mdot
.928 .29082 Mdot
.928 .2922 Mdot
.928 .29225 Mdot
.928 .29327 Mdot
.928 .29447 Mdot
.928 .29522 Mdot
.928 .29567 Mdot
.928 .29768 Mdot
.928 .29861 Mdot
.928 .29886 Mdot
.928 .29887 Mdot
.928 .29897 Mdot
.928 .29903 Mdot
.928 .30173 Mdot
.928 .3019 Mdot
.928 .30223 Mdot
.928 .30223 Mdot
.928 .30261 Mdot
.928 .30327 Mdot
.928 .30343 Mdot
.928 .30362 Mdot
.928 .30431 Mdot
.928 .30478 Mdot
.928 .30483 Mdot
.928 .30549 Mdot
.928 .30641 Mdot
.928 .30697 Mdot
.928 .30748 Mdot
.928 .30761 Mdot
.928 .3091 Mdot
.928 .30958 Mdot
.928 .3099 Mdot
.928 .31054 Mdot
.928 .31079 Mdot
.928 .31159 Mdot
.928 .31166 Mdot
.928 .3117 Mdot
.928 .31194 Mdot
.928 .31235 Mdot
.928 .31269 Mdot
.928 .31343 Mdot
.928 .31401 Mdot
.928 .3144 Mdot
.928 .31552 Mdot
.928 .3159 Mdot
.928 .31637 Mdot
.928 .31677 Mdot
.928 .31787 Mdot
.928 .31875 Mdot
.928 .31883 Mdot
.928 .31917 Mdot
.928 .31922 Mdot
.928 .31969 Mdot
.928 .32 Mdot
.928 .32017 Mdot
.928 .32025 Mdot
.928 .32034 Mdot
.928 .32036 Mdot
.928 .32103 Mdot
.928 .32252 Mdot
.928 .32389 Mdot
.928 .32484 Mdot
.928 .32503 Mdot
.928 .32527 Mdot
.928 .32552 Mdot
.928 .32552 Mdot
.928 .32631 Mdot
.928 .32684 Mdot
.928 .32732 Mdot
.928 .32735 Mdot
.928 .32767 Mdot
.928 .32824 Mdot
.928 .32865 Mdot
.928 .32941 Mdot
.928 .3295 Mdot
.928 .32952 Mdot
.928 .33167 Mdot
.928 .33217 Mdot
.928 .33261 Mdot
.928 .3328 Mdot
.928 .33322 Mdot
.928 .3335 Mdot
.928 .33355 Mdot
.928 .33466 Mdot
.928 .33535 Mdot
.928 .33542 Mdot
.928 .33575 Mdot
.928 .33665 Mdot
.928 .33692 Mdot
.928 .33693 Mdot
.928 .33745 Mdot
.928 .33802 Mdot
.928 .3387 Mdot
.928 .33906 Mdot
.928 .33906 Mdot
.928 .33967 Mdot
.928 .33995 Mdot
.928 .34046 Mdot
.928 .34234 Mdot
.928 .34254 Mdot
.928 .34258 Mdot
.928 .34373 Mdot
.928 .34428 Mdot
.928 .3444 Mdot
.928 .34481 Mdot
.928 .34587 Mdot
.928 .34664 Mdot
.928 .34668 Mdot
.928 .34773 Mdot
.928 .34785 Mdot
.928 .3487 Mdot
.928 .3488 Mdot
.928 .34942 Mdot
.928 .34973 Mdot
.928 .34978 Mdot
.928 .35063 Mdot
.928 .35195 Mdot
.928 .35207 Mdot
.928 .35322 Mdot
.928 .35466 Mdot
.928 .35486 Mdot
.928 .35487 Mdot
.928 .35537 Mdot
.928 .35558 Mdot
.928 .35577 Mdot
.928 .35621 Mdot
.928 .35667 Mdot
.928 .35727 Mdot
.928 .35831 Mdot
.928 .35875 Mdot
.928 .35922 Mdot
.928 .35935 Mdot
.928 .36107 Mdot
.928 .36113 Mdot
.928 .36135 Mdot
.928 .36168 Mdot
.928 .36186 Mdot
.928 .36194 Mdot
.928 .36203 Mdot
.928 .36231 Mdot
.928 .36275 Mdot
.928 .36316 Mdot
.928 .36398 Mdot
.928 .36466 Mdot
.928 .36476 Mdot
.928 .36513 Mdot
.928 .36515 Mdot
.928 .36521 Mdot
.928 .36541 Mdot
.928 .36618 Mdot
.928 .36628 Mdot
.928 .36644 Mdot
.928 .36721 Mdot
.928 .36825 Mdot
.928 .37137 Mdot
.928 .37141 Mdot
.928 .37201 Mdot
.928 .37241 Mdot
.928 .37303 Mdot
.928 .37344 Mdot
.928 .3741 Mdot
.928 .37532 Mdot
.928 .37551 Mdot
.928 .37679 Mdot
.928 .37795 Mdot
.928 .37914 Mdot
.928 .38109 Mdot
.928 .38115 Mdot
.928 .38176 Mdot
.928 .38182 Mdot
.928 .38187 Mdot
.928 .38207 Mdot
.928 .3838 Mdot
.928 .38384 Mdot
.928 .38455 Mdot
.928 .38462 Mdot
.928 .38535 Mdot
.928 .38568 Mdot
.928 .38583 Mdot
.928 .38608 Mdot
.928 .38735 Mdot
.928 .38792 Mdot
.928 .38818 Mdot
.928 .38895 Mdot
.928 .39183 Mdot
.928 .39371 Mdot
.928 .39446 Mdot
.928 .39524 Mdot
.928 .39585 Mdot
.928 .39609 Mdot
.928 .39658 Mdot
.928 .39808 Mdot
.928 .3984 Mdot
.928 .39868 Mdot
.928 .39893 Mdot
.928 .39907 Mdot
.928 .39909 Mdot
.928 .39913 Mdot
.928 .39975 Mdot
.928 .40062 Mdot
.928 .40294 Mdot
.928 .4035 Mdot
.928 .40455 Mdot
.928 .40481 Mdot
.928 .40735 Mdot
.928 .40738 Mdot
.928 .40765 Mdot
.928 .40766 Mdot
.928 .40866 Mdot
.928 .40908 Mdot
.928 .41014 Mdot
.928 .41027 Mdot
.928 .41102 Mdot
.928 .41117 Mdot
.928 .4112 Mdot
.928 .41155 Mdot
.928 .41214 Mdot
.928 .41243 Mdot
.928 .41246 Mdot
.928 .41272 Mdot
.928 .41423 Mdot
.928 .41513 Mdot
.928 .41675 Mdot
.928 .41697 Mdot
.928 .41698 Mdot
.928 .41704 Mdot
.928 .41754 Mdot
.928 .41776 Mdot
.928 .4182 Mdot
.928 .42104 Mdot
.928 .42178 Mdot
.928 .42198 Mdot
.928 .42199 Mdot
.928 .42217 Mdot
.928 .4231 Mdot
.928 .42544 Mdot
.928 .42549 Mdot
.928 .42594 Mdot
.928 .42717 Mdot
.928 .42963 Mdot
.928 .42977 Mdot
.928 .43013 Mdot
.928 .43099 Mdot
.928 .43213 Mdot
.928 .43219 Mdot
.928 .43347 Mdot
.928 .43375 Mdot
.928 .43404 Mdot
.928 .43426 Mdot
.928 .43554 Mdot
.928 .43563 Mdot
.928 .4359 Mdot
.928 .43867 Mdot
.928 .4392 Mdot
.928 .43963 Mdot
.928 .44064 Mdot
.928 .44068 Mdot
.928 .44137 Mdot
.928 .44139 Mdot
.928 .44386 Mdot
.928 .44474 Mdot
.928 .44477 Mdot
.928 .44485 Mdot
.928 .44513 Mdot
.928 .44527 Mdot
.928 .44533 Mdot
.928 .44581 Mdot
.928 .4461 Mdot
.928 .44659 Mdot
.928 .44706 Mdot
.928 .44955 Mdot
.928 .45041 Mdot
.928 .4542 Mdot
.928 .4546 Mdot
.928 .45522 Mdot
.928 .45633 Mdot
.928 .45635 Mdot
.928 .45659 Mdot
.928 .45765 Mdot
.928 .45769 Mdot
.928 .45839 Mdot
.928 .45916 Mdot
.928 .4599 Mdot
.928 .45993 Mdot
.928 .46048 Mdot
.928 .46113 Mdot
.928 .46177 Mdot
.928 .46335 Mdot
.928 .46349 Mdot
.928 .4635 Mdot
.928 .46513 Mdot
.928 .4653 Mdot
.928 .46587 Mdot
.928 .46595 Mdot
.928 .46668 Mdot
.928 .46706 Mdot
.928 .46756 Mdot
.928 .46814 Mdot
.928 .46927 Mdot
.928 .47041 Mdot
.928 .47076 Mdot
.928 .47094 Mdot
.928 .47134 Mdot
.928 .47166 Mdot
.928 .47267 Mdot
.928 .47293 Mdot
.928 .47444 Mdot
.928 .47446 Mdot
.928 .47488 Mdot
.928 .47749 Mdot
.928 .47759 Mdot
.928 .47772 Mdot
.928 .47786 Mdot
.928 .47882 Mdot
.928 .47932 Mdot
.928 .47954 Mdot
.928 .48 Mdot
.928 .48117 Mdot
.928 .48144 Mdot
.928 .48168 Mdot
.928 .482 Mdot
.928 .48218 Mdot
.928 .48278 Mdot
.928 .48315 Mdot
.928 .48386 Mdot
.928 .484 Mdot
.928 .48428 Mdot
.928 .48548 Mdot
.928 .48882 Mdot
.928 .48926 Mdot
.928 .4921 Mdot
.928 .49394 Mdot
.928 .49405 Mdot
.928 .49416 Mdot
.928 .49601 Mdot
.928 .49701 Mdot
.928 .49704 Mdot
.928 .49791 Mdot
.928 .49858 Mdot
.928 .50403 Mdot
.928 .50674 Mdot
.928 .50783 Mdot
.928 .50815 Mdot
.928 .50928 Mdot
.928 .51009 Mdot
.928 .51027 Mdot
.928 .51035 Mdot
.928 .51148 Mdot
.928 .51203 Mdot
.928 .51358 Mdot
.928 .51695 Mdot
.928 .51727 Mdot
.928 .51741 Mdot
.928 .51748 Mdot
.928 .51832 Mdot
.928 .52196 Mdot
.928 .52211 Mdot
.928 .52288 Mdot
.928 .52345 Mdot
.928 .52421 Mdot
.928 .52453 Mdot
.928 .52468 Mdot
.928 .5247 Mdot
.928 .52716 Mdot
.928 .52972 Mdot
.928 .52983 Mdot
.928 .53172 Mdot
.928 .53395 Mdot
.928 .53533 Mdot
.928 .53617 Mdot
.928 .5399 Mdot
.928 .54162 Mdot
.928 .54209 Mdot
.928 .54211 Mdot
.928 .5423 Mdot
.928 .54241 Mdot
.928 .54741 Mdot
.928 .54773 Mdot
.928 .54833 Mdot
.928 .54835 Mdot
.928 .54905 Mdot
.928 .55028 Mdot
.928 .55057 Mdot
.928 .55092 Mdot
.928 .5522 Mdot
.928 .55308 Mdot
.928 .55317 Mdot
.928 .55439 Mdot
.928 .55611 Mdot
.928 .55714 Mdot
.928 .55809 Mdot
.928 .55833 Mdot
.928 .56109 Mdot
.928 .56199 Mdot
.928 .56259 Mdot
.93 .01799 Mdot
.93 .01858 Mdot
.93 .0208 Mdot
.93 .02115 Mdot
.93 .02138 Mdot
.93 .0219 Mdot
.93 .02248 Mdot
.93 .02266 Mdot
.93 .02269 Mdot
.93 .02323 Mdot
.93 .0235 Mdot
.93 .02383 Mdot
.93 .02389 Mdot
.93 .0241 Mdot
.93 .0254 Mdot
.93 .02583 Mdot
.93 .02604 Mdot
.93 .02641 Mdot
.93 .02649 Mdot
.93 .0266 Mdot
.93 .02668 Mdot
.93 .02711 Mdot
.93 .0278 Mdot
.93 .02808 Mdot
.93 .02828 Mdot
.93 .02916 Mdot
.93 .02917 Mdot
.93 .02923 Mdot
.93 .0295 Mdot
.93 .02955 Mdot
.93 .03055 Mdot
.93 .03106 Mdot
.93 .03166 Mdot
.93 .03178 Mdot
.93 .03203 Mdot
.93 .03217 Mdot
.93 .03358 Mdot
.93 .03368 Mdot
.93 .03458 Mdot
.93 .03538 Mdot
.93 .03578 Mdot
.93 .03632 Mdot
.93 .03647 Mdot
.93 .03662 Mdot
.93 .03682 Mdot
.93 .03687 Mdot
.93 .03697 Mdot
.93 .03777 Mdot
.93 .03905 Mdot
.93 .03957 Mdot
.93 .03992 Mdot
.93 .03995 Mdot
.93 .041 Mdot
.93 .04159 Mdot
.93 .04159 Mdot
.93 .0417 Mdot
.93 .04175 Mdot
.93 .04205 Mdot
.93 .04209 Mdot
.93 .04222 Mdot
.93 .0423 Mdot
.93 .04385 Mdot
.93 .04417 Mdot
.93 .04451 Mdot
.93 .04511 Mdot
.93 .04623 Mdot
.93 .04646 Mdot
.93 .04654 Mdot
.93 .04661 Mdot
.93 .04692 Mdot
.93 .04718 Mdot
.93 .04742 Mdot
.93 .04765 Mdot
.93 .04929 Mdot
.93 .0498 Mdot
.93 .04991 Mdot
.93 .05 Mdot
.93 .05167 Mdot
.93 .05181 Mdot
.93 .05218 Mdot
.93 .05289 Mdot
.93 .05312 Mdot
.93 .05316 Mdot
.93 .05322 Mdot
.93 .05389 Mdot
.93 .05448 Mdot
.93 .0549 Mdot
.93 .05517 Mdot
.93 .05546 Mdot
.93 .05582 Mdot
.93 .05593 Mdot
.93 .05599 Mdot
.93 .05609 Mdot
.93 .0561 Mdot
.93 .05672 Mdot
.93 .05759 Mdot
.93 .05933 Mdot
.93 .05998 Mdot
.93 .06002 Mdot
.93 .06094 Mdot
.93 .06159 Mdot
.93 .06166 Mdot
.93 .06224 Mdot
.93 .06295 Mdot
.93 .0631 Mdot
.93 .06361 Mdot
.93 .06379 Mdot
.93 .06387 Mdot
.93 .0647 Mdot
.93 .06471 Mdot
.93 .06491 Mdot
.93 .06499 Mdot
.93 .06556 Mdot
.93 .06558 Mdot
.93 .06564 Mdot
.93 .06587 Mdot
.93 .06603 Mdot
.93 .06652 Mdot
.93 .06891 Mdot
.93 .06924 Mdot
.93 .06949 Mdot
.93 .07013 Mdot
.93 .07126 Mdot
.93 .07209 Mdot
.93 .07239 Mdot
.93 .07249 Mdot
.93 .07264 Mdot
.93 .07287 Mdot
.93 .07334 Mdot
.93 .07334 Mdot
.93 .07355 Mdot
.93 .07376 Mdot
.93 .07391 Mdot
.93 .07404 Mdot
.93 .07415 Mdot
.93 .07423 Mdot
.93 .07461 Mdot
.93 .07502 Mdot
.93 .07504 Mdot
.93 .07509 Mdot
.93 .07555 Mdot
.93 .07597 Mdot
.93 .07654 Mdot
.93 .07701 Mdot
.93 .07762 Mdot
.93 .07785 Mdot
.93 .07894 Mdot
.93 .07902 Mdot
.93 .07997 Mdot
.93 .08017 Mdot
.93 .08018 Mdot
.93 .08034 Mdot
.93 .08039 Mdot
.93 .08081 Mdot
.93 .08085 Mdot
.93 .08121 Mdot
.93 .0834 Mdot
.93 .08345 Mdot
.93 .08371 Mdot
.93 .08439 Mdot
.93 .08478 Mdot
.93 .08497 Mdot
.93 .08572 Mdot
.93 .08615 Mdot
.93 .08622 Mdot
.93 .08634 Mdot
.93 .08758 Mdot
.93 .08797 Mdot
.93 .08834 Mdot
.93 .08868 Mdot
.93 .08945 Mdot
.93 .08996 Mdot
.93 .0903 Mdot
.93 .0905 Mdot
.93 .09118 Mdot
.93 .09137 Mdot
.93 .09149 Mdot
.93 .09167 Mdot
.93 .0917 Mdot
.93 .09285 Mdot
.93 .09329 Mdot
.93 .09446 Mdot
.93 .09453 Mdot
.93 .09532 Mdot
.93 .0977 Mdot
.93 .09829 Mdot
.93 .09891 Mdot
.93 .09898 Mdot
.93 .09955 Mdot
.93 .09967 Mdot
.93 .10069 Mdot
.93 .10142 Mdot
.93 .10191 Mdot
.93 .10203 Mdot
.93 .10244 Mdot
.93 .10311 Mdot
.93 .10444 Mdot
.93 .10471 Mdot
.93 .10555 Mdot
.93 .10565 Mdot
.93 .106 Mdot
.93 .10615 Mdot
.93 .10617 Mdot
.93 .1066 Mdot
.93 .10768 Mdot
.93 .1077 Mdot
.93 .10781 Mdot
.93 .10809 Mdot
.93 .10823 Mdot
.93 .10929 Mdot
.93 .10932 Mdot
.93 .10943 Mdot
.93 .10986 Mdot
.93 .11016 Mdot
.93 .11107 Mdot
.93 .11193 Mdot
.93 .11338 Mdot
.93 .11465 Mdot
.93 .11552 Mdot
.93 .11612 Mdot
.93 .1166 Mdot
.93 .11698 Mdot
.93 .1173 Mdot
.93 .11778 Mdot
.93 .11834 Mdot
.93 .11939 Mdot
.93 .11988 Mdot
.93 .12037 Mdot
.93 .12135 Mdot
.93 .12142 Mdot
.93 .12199 Mdot
.93 .12218 Mdot
.93 .12229 Mdot
.93 .12245 Mdot
.93 .12279 Mdot
.93 .12289 Mdot
.93 .12375 Mdot
.93 .12376 Mdot
.93 .12414 Mdot
.93 .12453 Mdot
.93 .12454 Mdot
.93 .12482 Mdot
.93 .12488 Mdot
.93 .12506 Mdot
.93 .12527 Mdot
.93 .12542 Mdot
.93 .12611 Mdot
.93 .12689 Mdot
.93 .12692 Mdot
.93 .12702 Mdot
.93 .1275 Mdot
.93 .12787 Mdot
.93 .12797 Mdot
.93 .12864 Mdot
.93 .12883 Mdot
.93 .12972 Mdot
.93 .13058 Mdot
.93 .13159 Mdot
.93 .13172 Mdot
.93 .13214 Mdot
.93 .13417 Mdot
.93 .13432 Mdot
.93 .13609 Mdot
.93 .13629 Mdot
.93 .13646 Mdot
.93 .13647 Mdot
.93 .13678 Mdot
.93 .13688 Mdot
.93 .13765 Mdot
.93 .13773 Mdot
.93 .13832 Mdot
.93 .13839 Mdot
.93 .14146 Mdot
.93 .14147 Mdot
.93 .14247 Mdot
.93 .14257 Mdot
.93 .14305 Mdot
.93 .14399 Mdot
.93 .14432 Mdot
.93 .14461 Mdot
.93 .14475 Mdot
.93 .14504 Mdot
.93 .1454 Mdot
.93 .14572 Mdot
.93 .14585 Mdot
.93 .14678 Mdot
.93 .14758 Mdot
.93 .14772 Mdot
.93 .14794 Mdot
.93 .14824 Mdot
.93 .14862 Mdot
.93 .15024 Mdot
.93 .15093 Mdot
.93 .15095 Mdot
.93 .15097 Mdot
.93 .1511 Mdot
.93 .15141 Mdot
.93 .1516 Mdot
.93 .15166 Mdot
.93 .15228 Mdot
.93 .15372 Mdot
.93 .15468 Mdot
.93 .15479 Mdot
.93 .15488 Mdot
.93 .15504 Mdot
.93 .15531 Mdot
.93 .15555 Mdot
.93 .15567 Mdot
.93 .15629 Mdot
.93 .15693 Mdot
.93 .157 Mdot
.93 .15709 Mdot
.93 .15729 Mdot
.93 .15751 Mdot
.93 .15784 Mdot
.93 .1579 Mdot
.93 .15803 Mdot
.93 .15829 Mdot
.93 .15963 Mdot
.93 .15973 Mdot
.93 .16005 Mdot
.93 .1602 Mdot
.93 .16021 Mdot
.93 .16081 Mdot
.93 .16087 Mdot
.93 .1628 Mdot
.93 .16299 Mdot
.93 .16304 Mdot
.93 .16317 Mdot
.93 .16393 Mdot
.93 .16456 Mdot
.93 .16463 Mdot
.93 .16481 Mdot
.93 .16636 Mdot
.93 .16645 Mdot
.93 .16691 Mdot
.93 .16891 Mdot
.93 .16907 Mdot
.93 .17017 Mdot
.93 .17045 Mdot
.93 .17132 Mdot
.93 .17136 Mdot
.93 .17145 Mdot
.93 .17149 Mdot
.93 .1725 Mdot
.93 .17272 Mdot
.93 .17329 Mdot
.93 .17366 Mdot
.93 .17463 Mdot
.93 .1748 Mdot
.93 .17599 Mdot
.93 .17614 Mdot
.93 .17622 Mdot
.93 .17632 Mdot
.93 .1769 Mdot
.93 .17709 Mdot
.93 .17712 Mdot
.93 .17747 Mdot
.93 .17788 Mdot
.93 .17914 Mdot
.93 .18009 Mdot
.93 .18128 Mdot
.93 .18159 Mdot
.93 .1816 Mdot
.93 .18211 Mdot
.93 .18314 Mdot
.93 .1832 Mdot
.93 .18368 Mdot
.93 .18386 Mdot
.93 .18451 Mdot
.93 .18472 Mdot
.93 .18478 Mdot
.93 .18481 Mdot
.93 .18561 Mdot
.93 .18658 Mdot
.93 .18678 Mdot
.93 .18742 Mdot
.93 .18763 Mdot
.93 .18767 Mdot
.93 .18787 Mdot
.93 .18839 Mdot
.93 .18866 Mdot
.93 .19038 Mdot
.93 .19049 Mdot
.93 .19063 Mdot
.93 .19069 Mdot
.93 .19089 Mdot
.93 .19112 Mdot
.93 .19156 Mdot
.93 .19169 Mdot
.93 .19225 Mdot
.93 .19267 Mdot
.93 .1929 Mdot
.93 .19354 Mdot
.93 .19394 Mdot
.93 .19486 Mdot
.93 .19553 Mdot
.93 .1964 Mdot
.93 .19698 Mdot
.93 .19784 Mdot
.93 .19824 Mdot
.93 .19904 Mdot
.93 .20012 Mdot
.93 .20059 Mdot
.93 .20178 Mdot
.93 .2022 Mdot
.93 .20257 Mdot
.93 .20334 Mdot
.93 .20422 Mdot
.93 .20478 Mdot
.93 .20492 Mdot
.93 .20553 Mdot
.93 .20642 Mdot
.93 .20747 Mdot
.93 .20941 Mdot
.93 .21032 Mdot
.93 .21032 Mdot
.93 .21123 Mdot
.93 .21239 Mdot
.93 .21306 Mdot
.93 .21319 Mdot
.93 .21417 Mdot
.93 .21424 Mdot
.93 .21461 Mdot
.93 .21481 Mdot
.93 .21511 Mdot
.93 .2156 Mdot
.93 .21574 Mdot
.93 .21591 Mdot
.93 .21649 Mdot
.93 .21681 Mdot
.93 .217 Mdot
.93 .21707 Mdot
.93 .21752 Mdot
.93 .21754 Mdot
.93 .21767 Mdot
.93 .21825 Mdot
.93 .2187 Mdot
.93 .21896 Mdot
.93 .219 Mdot
.93 .21952 Mdot
.93 .21963 Mdot
.93 .21996 Mdot
.93 .22034 Mdot
.93 .22037 Mdot
.93 .22062 Mdot
.93 .22148 Mdot
.93 .22192 Mdot
.93 .22282 Mdot
.93 .22336 Mdot
.93 .22342 Mdot
.93 .2236 Mdot
.93 .22449 Mdot
.93 .2248 Mdot
.93 .22519 Mdot
.93 .22537 Mdot
.93 .22662 Mdot
.93 .22696 Mdot
.93 .22727 Mdot
.93 .22776 Mdot
.93 .22798 Mdot
.93 .22862 Mdot
.93 .23022 Mdot
.93 .23082 Mdot
.93 .23175 Mdot
.93 .2321 Mdot
.93 .23235 Mdot
.93 .23313 Mdot
.93 .23345 Mdot
.93 .23384 Mdot
.93 .23441 Mdot
.93 .23512 Mdot
.93 .23533 Mdot
.93 .23615 Mdot
.93 .23691 Mdot
.93 .23719 Mdot
.93 .23739 Mdot
.93 .23805 Mdot
.93 .23824 Mdot
.93 .24047 Mdot
.93 .24084 Mdot
.93 .24116 Mdot
.93 .24118 Mdot
.93 .24176 Mdot
.93 .24194 Mdot
.93 .24337 Mdot
.93 .24353 Mdot
.93 .24463 Mdot
.93 .24476 Mdot
.93 .24577 Mdot
.93 .24705 Mdot
.93 .24815 Mdot
.93 .24823 Mdot
.93 .25022 Mdot
.93 .25046 Mdot
.93 .25049 Mdot
.93 .25085 Mdot
.93 .25233 Mdot
.93 .25252 Mdot
.93 .25342 Mdot
.93 .25516 Mdot
.93 .2556 Mdot
.93 .25578 Mdot
.93 .25581 Mdot
.93 .25632 Mdot
.93 .25635 Mdot
.93 .25657 Mdot
.93 .25685 Mdot
.93 .25712 Mdot
.93 .25778 Mdot
.93 .25784 Mdot
.93 .25839 Mdot
.93 .25862 Mdot
.93 .26015 Mdot
.93 .26036 Mdot
.93 .26061 Mdot
.93 .26184 Mdot
.93 .2621 Mdot
.93 .26251 Mdot
.93 .26307 Mdot
.93 .26335 Mdot
.93 .26378 Mdot
.93 .2641 Mdot
.93 .26533 Mdot
.93 .26679 Mdot
.93 .26807 Mdot
.93 .26811 Mdot
.93 .26815 Mdot
.93 .26839 Mdot
.93 .26853 Mdot
.93 .26896 Mdot
.93 .26932 Mdot
.93 .26942 Mdot
.93 .26943 Mdot
.93 .27007 Mdot
.93 .27059 Mdot
.93 .27233 Mdot
.93 .27262 Mdot
.93 .27327 Mdot
.93 .27343 Mdot
.93 .27504 Mdot
.93 .27525 Mdot
.93 .27542 Mdot
.93 .27572 Mdot
.93 .27622 Mdot
.93 .27668 Mdot
.93 .27688 Mdot
.93 .27804 Mdot
.93 .27924 Mdot
.93 .27936 Mdot
.93 .27951 Mdot
.93 .27953 Mdot
.93 .2799 Mdot
.93 .28032 Mdot
.93 .28034 Mdot
.93 .28042 Mdot
.93 .28093 Mdot
.93 .28104 Mdot
.93 .28128 Mdot
.93 .28146 Mdot
.93 .28167 Mdot
.93 .28176 Mdot
.93 .28219 Mdot
.93 .28426 Mdot
.93 .28444 Mdot
.93 .28504 Mdot
.93 .28532 Mdot
.93 .28533 Mdot
.93 .28645 Mdot
.93 .28656 Mdot
.93 .2868 Mdot
.93 .28715 Mdot
.93 .28738 Mdot
.93 .28748 Mdot
.93 .29015 Mdot
.93 .29051 Mdot
.93 .29059 Mdot
.93 .2906 Mdot
.93 .29085 Mdot
.93 .29226 Mdot
.93 .29288 Mdot
.93 .2932 Mdot
.93 .29343 Mdot
.93 .29356 Mdot
.93 .29389 Mdot
.93 .29658 Mdot
.93 .29678 Mdot
.93 .29693 Mdot
.93 .29779 Mdot
.93 .2981 Mdot
.93 .29873 Mdot
.93 .29883 Mdot
.93 .29936 Mdot
.93 .3006 Mdot
.93 .30072 Mdot
.93 .30149 Mdot
.93 .30152 Mdot
.93 .30182 Mdot
.93 .30238 Mdot
.93 .30243 Mdot
.93 .30338 Mdot
.93 .30385 Mdot
.93 .30438 Mdot
.93 .30566 Mdot
.93 .30576 Mdot
.93 .30587 Mdot
.93 .30599 Mdot
.93 .30608 Mdot
.93 .30623 Mdot
.93 .30631 Mdot
.93 .30776 Mdot
.93 .3082 Mdot
.93 .30856 Mdot
.93 .30861 Mdot
.93 .30966 Mdot
.93 .31036 Mdot
.93 .31216 Mdot
.93 .31247 Mdot
.93 .31385 Mdot
.93 .31398 Mdot
.93 .31457 Mdot
.93 .31467 Mdot
.93 .31468 Mdot
.93 .31497 Mdot
.93 .31512 Mdot
.93 .31529 Mdot
.93 .31533 Mdot
.93 .31544 Mdot
.93 .31614 Mdot
.93 .31637 Mdot
.93 .31668 Mdot
.93 .31673 Mdot
.93 .31678 Mdot
.93 .31743 Mdot
.93 .31769 Mdot
.93 .31817 Mdot
.93 .3182 Mdot
.93 .3197 Mdot
.93 .32054 Mdot
.93 .32059 Mdot
.93 .32201 Mdot
.93 .32231 Mdot
.93 .32395 Mdot
.93 .32453 Mdot
.93 .32493 Mdot
.93 .32509 Mdot
.93 .32512 Mdot
.93 .32606 Mdot
.93 .32641 Mdot
.93 .32751 Mdot
.93 .32754 Mdot
.93 .32798 Mdot
.93 .3281 Mdot
.93 .32898 Mdot
.93 .32932 Mdot
.93 .33034 Mdot
.93 .33054 Mdot
.93 .33092 Mdot
.93 .33104 Mdot
.93 .3311 Mdot
.93 .33177 Mdot
.93 .33259 Mdot
.93 .33264 Mdot
.93 .33298 Mdot
.93 .33438 Mdot
.93 .33475 Mdot
.93 .33595 Mdot
.93 .33633 Mdot
.93 .33641 Mdot
.93 .33678 Mdot
.93 .33683 Mdot
.93 .33774 Mdot
.93 .33825 Mdot
.93 .33971 Mdot
.93 .34124 Mdot
.93 .3414 Mdot
.93 .34146 Mdot
.93 .34154 Mdot
.93 .34166 Mdot
.93 .34191 Mdot
.93 .34203 Mdot
.93 .34235 Mdot
.93 .34239 Mdot
.93 .34282 Mdot
.93 .34283 Mdot
.93 .34364 Mdot
.93 .34389 Mdot
.93 .34422 Mdot
.93 .34434 Mdot
.93 .34493 Mdot
.93 .34559 Mdot
.93 .34571 Mdot
.93 .34593 Mdot
.93 .34595 Mdot
.93 .34615 Mdot
.93 .34732 Mdot
.93 .34807 Mdot
.93 .34817 Mdot
.93 .34978 Mdot
.93 .34998 Mdot
.93 .35103 Mdot
.93 .35264 Mdot
.93 .35331 Mdot
.93 .35373 Mdot
.93 .35533 Mdot
.93 .356 Mdot
.93 .35607 Mdot
.93 .35701 Mdot
.93 .35756 Mdot
.93 .35923 Mdot
.93 .35956 Mdot
.93 .35979 Mdot
.93 .36045 Mdot
.93 .36266 Mdot
.93 .36344 Mdot
.93 .36412 Mdot
.93 .36538 Mdot
.93 .36555 Mdot
.93 .36611 Mdot
.93 .36667 Mdot
.93 .3672 Mdot
.93 .36773 Mdot
.93 .36823 Mdot
.93 .3685 Mdot
.93 .36943 Mdot
.93 .36963 Mdot
.93 .37103 Mdot
.93 .37129 Mdot
.93 .37175 Mdot
.93 .37323 Mdot
.93 .37576 Mdot
.93 .37685 Mdot
.93 .37854 Mdot
.93 .37855 Mdot
.93 .3799 Mdot
.93 .38023 Mdot
.93 .38031 Mdot
.93 .38083 Mdot
.93 .3809 Mdot
.93 .38218 Mdot
.93 .38239 Mdot
.93 .38363 Mdot
.93 .38364 Mdot
.93 .38372 Mdot
.93 .38389 Mdot
.93 .38399 Mdot
.93 .38571 Mdot
.93 .38575 Mdot
.93 .38584 Mdot
.93 .38612 Mdot
.93 .38651 Mdot
.93 .38689 Mdot
.93 .38694 Mdot
.93 .38745 Mdot
.93 .38759 Mdot
.93 .38831 Mdot
.93 .38836 Mdot
.93 .38862 Mdot
.93 .38862 Mdot
.93 .38894 Mdot
.93 .39001 Mdot
.93 .39011 Mdot
.93 .39062 Mdot
.93 .39096 Mdot
.93 .39109 Mdot
.93 .39193 Mdot
.93 .39197 Mdot
.93 .39222 Mdot
.93 .3933 Mdot
.93 .39412 Mdot
.93 .39461 Mdot
.93 .39468 Mdot
.93 .39565 Mdot
.93 .39585 Mdot
.93 .39646 Mdot
.93 .39719 Mdot
.93 .39723 Mdot
.93 .39728 Mdot
.93 .39769 Mdot
.93 .3979 Mdot
.93 .39931 Mdot
.93 .39995 Mdot
.93 .40011 Mdot
.93 .40095 Mdot
.93 .40098 Mdot
.93 .4018 Mdot
.93 .4028 Mdot
.93 .4029 Mdot
.93 .40325 Mdot
.93 .40484 Mdot
.93 .4049 Mdot
.93 .40524 Mdot
.93 .40547 Mdot
.93 .40607 Mdot
.93 .4062 Mdot
.93 .40654 Mdot
.93 .40725 Mdot
.93 .40807 Mdot
.93 .40839 Mdot
.93 .40885 Mdot
.93 .4095 Mdot
.93 .41007 Mdot
.93 .41097 Mdot
.93 .41139 Mdot
.93 .41258 Mdot
.93 .41556 Mdot
.93 .41667 Mdot
.93 .41763 Mdot
.93 .4184 Mdot
.93 .41888 Mdot
.93 .41905 Mdot
.93 .41915 Mdot
.93 .41919 Mdot
.93 .41951 Mdot
.93 .42006 Mdot
.93 .42096 Mdot
.93 .42156 Mdot
.93 .42228 Mdot
.93 .42334 Mdot
.93 .42468 Mdot
.93 .42493 Mdot
.93 .42506 Mdot
.93 .42658 Mdot
.93 .42708 Mdot
.93 .428 Mdot
.93 .4282 Mdot
.93 .42851 Mdot
.93 .4289 Mdot
.93 .42901 Mdot
.93 .42945 Mdot
.93 .43012 Mdot
.93 .43047 Mdot
.93 .43057 Mdot
.93 .43462 Mdot
.93 .43531 Mdot
.93 .4359 Mdot
.93 .43594 Mdot
.93 .43701 Mdot
.93 .43735 Mdot
.93 .4399 Mdot
.93 .44002 Mdot
.93 .44031 Mdot
.93 .44057 Mdot
.93 .44111 Mdot
.93 .44235 Mdot
.93 .4426 Mdot
.93 .44407 Mdot
.93 .44447 Mdot
.93 .44514 Mdot
.93 .44685 Mdot
.93 .44734 Mdot
.93 .44768 Mdot
.93 .4489 Mdot
.93 .44906 Mdot
.93 .44949 Mdot
.93 .45276 Mdot
.93 .45321 Mdot
.93 .45325 Mdot
.93 .45381 Mdot
.93 .45392 Mdot
.93 .4542 Mdot
.93 .45668 Mdot
.93 .45686 Mdot
.93 .45699 Mdot
.93 .45704 Mdot
.93 .458 Mdot
.93 .45871 Mdot
.93 .45995 Mdot
.93 .46012 Mdot
.93 .46194 Mdot
.93 .46275 Mdot
.93 .46309 Mdot
.93 .46315 Mdot
.93 .46343 Mdot
.93 .4641 Mdot
.93 .46416 Mdot
.93 .46457 Mdot
.93 .46505 Mdot
.93 .46508 Mdot
.93 .46559 Mdot
.93 .46682 Mdot
.93 .46687 Mdot
.93 .46693 Mdot
.93 .46795 Mdot
.93 .46838 Mdot
.93 .47122 Mdot
.93 .47129 Mdot
.93 .47161 Mdot
.93 .47166 Mdot
.93 .47202 Mdot
.93 .47208 Mdot
.93 .47245 Mdot
.93 .47274 Mdot
.93 .47329 Mdot
.93 .47354 Mdot
.93 .47437 Mdot
.93 .47485 Mdot
.93 .47561 Mdot
.93 .47665 Mdot
.93 .47718 Mdot
.93 .47798 Mdot
.93 .47856 Mdot
.93 .47858 Mdot
.93 .48009 Mdot
.93 .48086 Mdot
.93 .48132 Mdot
.93 .48151 Mdot
.93 .48357 Mdot
.93 .48512 Mdot
.93 .48595 Mdot
.93 .48604 Mdot
.93 .48611 Mdot
.93 .48654 Mdot
.93 .4868 Mdot
.93 .48755 Mdot
.93 .48761 Mdot
.93 .48828 Mdot
.93 .48847 Mdot
.93 .48848 Mdot
.93 .48967 Mdot
.93 .49065 Mdot
.93 .49389 Mdot
.93 .49443 Mdot
.93 .49562 Mdot
.93 .49592 Mdot
.93 .49892 Mdot
.93 .49932 Mdot
.93 .49962 Mdot
.93 .50019 Mdot
.93 .50111 Mdot
.93 .50196 Mdot
.93 .50235 Mdot
.93 .5045 Mdot
.93 .50673 Mdot
.93 .50695 Mdot
.93 .50723 Mdot
.93 .50727 Mdot
.93 .50796 Mdot
.93 .50874 Mdot
.93 .50879 Mdot
.93 .50893 Mdot
.93 .50988 Mdot
.93 .51007 Mdot
.93 .51052 Mdot
.93 .51086 Mdot
.93 .51125 Mdot
.93 .51142 Mdot
.93 .51222 Mdot
.93 .51608 Mdot
.93 .51641 Mdot
.93 .51751 Mdot
.93 .51805 Mdot
.93 .51807 Mdot
.93 .52014 Mdot
.93 .52035 Mdot
.93 .5208 Mdot
.93 .52143 Mdot
.93 .52188 Mdot
.93 .52205 Mdot
.93 .52702 Mdot
.93 .52769 Mdot
.93 .52783 Mdot
.93 .52785 Mdot
.93 .52833 Mdot
.93 .53094 Mdot
.93 .5321 Mdot
.93 .5327 Mdot
.93 .53313 Mdot
.93 .53337 Mdot
.93 .53397 Mdot
.93 .53899 Mdot
.93 .53935 Mdot
.93 .53964 Mdot
.93 .54123 Mdot
.93 .5418 Mdot
.93 .54299 Mdot
.93 .54317 Mdot
.93 .54415 Mdot
.93 .54647 Mdot
.93 .54668 Mdot
.93 .54811 Mdot
.93 .54818 Mdot
.93 .54872 Mdot
.93 .54977 Mdot
.93 .54986 Mdot
.93 .55164 Mdot
.93 .55251 Mdot
.93 .55349 Mdot
.93 .55587 Mdot
.93 .55607 Mdot
.93 .55626 Mdot
.93 .55649 Mdot
.93 .55665 Mdot
.93 .55694 Mdot
.93 .55708 Mdot
.93 .55979 Mdot
.93 .5606 Mdot
.93 .56126 Mdot
.93 .56136 Mdot
.93 .5633 Mdot
.93 .56461 Mdot
.932 .01493 Mdot
.932 .01511 Mdot
.932 .01546 Mdot
.932 .01595 Mdot
.932 .01599 Mdot
.932 .0161 Mdot
.932 .01616 Mdot
.932 .01655 Mdot
.932 .01656 Mdot
.932 .01687 Mdot
.932 .01702 Mdot
.932 .01709 Mdot
.932 .01729 Mdot
.932 .0174 Mdot
.932 .01746 Mdot
.932 .0179 Mdot
.932 .01814 Mdot
.932 .01816 Mdot
.932 .01873 Mdot
.932 .01901 Mdot
.932 .01914 Mdot
.932 .0195 Mdot
.932 .01952 Mdot
.932 .01967 Mdot
.932 .01972 Mdot
.932 .01983 Mdot
.932 .02065 Mdot
.932 .02111 Mdot
.932 .02113 Mdot
.932 .02219 Mdot
.932 .02262 Mdot
.932 .02271 Mdot
.932 .02296 Mdot
.932 .02363 Mdot
.932 .02366 Mdot
.932 .02394 Mdot
.932 .02404 Mdot
.932 .02425 Mdot
.932 .0245 Mdot
.932 .02577 Mdot
.932 .02608 Mdot
.932 .02663 Mdot
.932 .02667 Mdot
.932 .02703 Mdot
.932 .02809 Mdot
.932 .02846 Mdot
.932 .02865 Mdot
.932 .02893 Mdot
.932 .02893 Mdot
.932 .02898 Mdot
.932 .02916 Mdot
.932 .02938 Mdot
.932 .02946 Mdot
.932 .02963 Mdot
.932 .03008 Mdot
.932 .03015 Mdot
.932 .03083 Mdot
.932 .03134 Mdot
.932 .0314 Mdot
.932 .03192 Mdot
.932 .03195 Mdot
.932 .0321 Mdot
.932 .03248 Mdot
.932 .03296 Mdot
.932 .0344 Mdot
.932 .03465 Mdot
.932 .03532 Mdot
.932 .03549 Mdot
.932 .03589 Mdot
.932 .03693 Mdot
.932 .03701 Mdot
.932 .03767 Mdot
.932 .03821 Mdot
.932 .03906 Mdot
.932 .03964 Mdot
.932 .04025 Mdot
.932 .04034 Mdot
.932 .04069 Mdot
.932 .04121 Mdot
.932 .04122 Mdot
.932 .0413 Mdot
.932 .04164 Mdot
.932 .04205 Mdot
.932 .0422 Mdot
.932 .04251 Mdot
.932 .04292 Mdot
.932 .04335 Mdot
.932 .04349 Mdot
.932 .04464 Mdot
.932 .04475 Mdot
.932 .0457 Mdot
.932 .04581 Mdot
.932 .04678 Mdot
.932 .04685 Mdot
.932 .04712 Mdot
.932 .04757 Mdot
.932 .04784 Mdot
.932 .048 Mdot
.932 .04815 Mdot
.932 .04871 Mdot
.932 .04955 Mdot
.932 .05122 Mdot
.932 .05142 Mdot
.932 .05187 Mdot
.932 .05239 Mdot
.932 .05246 Mdot
.932 .05313 Mdot
.932 .05344 Mdot
.932 .05419 Mdot
.932 .05545 Mdot
.932 .05611 Mdot
.932 .05627 Mdot
.932 .05663 Mdot
.932 .05751 Mdot
.932 .05851 Mdot
.932 .05913 Mdot
.932 .05986 Mdot
.932 .05988 Mdot
.932 .06009 Mdot
.932 .06039 Mdot
.932 .06055 Mdot
.932 .0606 Mdot
.932 .06078 Mdot
.932 .06118 Mdot
.932 .06139 Mdot
.932 .06155 Mdot
.932 .06155 Mdot
.932 .06157 Mdot
.932 .0618 Mdot
.932 .06232 Mdot
.932 .06249 Mdot
.932 .06313 Mdot
.932 .06411 Mdot
.932 .06411 Mdot
.932 .06425 Mdot
.932 .06427 Mdot
.932 .06488 Mdot
.932 .0649 Mdot
.932 .06508 Mdot
.932 .06519 Mdot
.932 .06567 Mdot
.932 .06579 Mdot
.932 .06594 Mdot
.932 .06652 Mdot
.932 .0673 Mdot
.932 .06773 Mdot
.932 .06778 Mdot
.932 .0681 Mdot
.932 .06835 Mdot
.932 .06843 Mdot
.932 .06871 Mdot
.932 .06917 Mdot
.932 .06941 Mdot
.932 .0705 Mdot
.932 .07069 Mdot
.932 .07092 Mdot
.932 .07152 Mdot
.932 .07246 Mdot
.932 .07268 Mdot
.932 .07293 Mdot
.932 .07306 Mdot
.932 .07326 Mdot
.932 .07337 Mdot
.932 .07448 Mdot
.932 .07461 Mdot
.932 .07512 Mdot
.932 .07595 Mdot
.932 .07646 Mdot
.932 .07662 Mdot
.932 .07677 Mdot
.932 .07705 Mdot
.932 .07784 Mdot
.932 .07809 Mdot
.932 .07874 Mdot
.932 .07964 Mdot
.932 .08017 Mdot
.932 .08131 Mdot
.932 .08145 Mdot
.932 .08196 Mdot
.932 .08211 Mdot
.932 .08275 Mdot
.932 .08313 Mdot
.932 .08398 Mdot
.932 .08465 Mdot
.932 .08468 Mdot
.932 .08494 Mdot
.932 .085 Mdot
.932 .08508 Mdot
.932 .08632 Mdot
.932 .0869 Mdot
.932 .0869 Mdot
.932 .08736 Mdot
.932 .08746 Mdot
.932 .0883 Mdot
.932 .08872 Mdot
.932 .08875 Mdot
.932 .08896 Mdot
.932 .09003 Mdot
.932 .09064 Mdot
.932 .09161 Mdot
.932 .09188 Mdot
.932 .09209 Mdot
.932 .09209 Mdot
.932 .09217 Mdot
.932 .09284 Mdot
.932 .09288 Mdot
.932 .0941 Mdot
.932 .09425 Mdot
.932 .09449 Mdot
.932 .09592 Mdot
.932 .09635 Mdot
.932 .0975 Mdot
.932 .09834 Mdot
.932 .09872 Mdot
.932 .09887 Mdot
.932 .0989 Mdot
.932 .09929 Mdot
.932 .09985 Mdot
.932 .10001 Mdot
.932 .10015 Mdot
.932 .10024 Mdot
.932 .10058 Mdot
.932 .10133 Mdot
.932 .10157 Mdot
.932 .10172 Mdot
.932 .10188 Mdot
.932 .10201 Mdot
.932 .10201 Mdot
.932 .10205 Mdot
.932 .10208 Mdot
.932 .10248 Mdot
.932 .10286 Mdot
.932 .10344 Mdot
.932 .10357 Mdot
.932 .10376 Mdot
.932 .10417 Mdot
.932 .10496 Mdot
.932 .10679 Mdot
.932 .10679 Mdot
.932 .10702 Mdot
.932 .10705 Mdot
.932 .10705 Mdot
.932 .10709 Mdot
.932 .10759 Mdot
.932 .10801 Mdot
.932 .10822 Mdot
.932 .10826 Mdot
.932 .10859 Mdot
.932 .1088 Mdot
.932 .1097 Mdot
.932 .10992 Mdot
.932 .11012 Mdot
.932 .1102 Mdot
.932 .11067 Mdot
.932 .11103 Mdot
.932 .11128 Mdot
.932 .11207 Mdot
.932 .11273 Mdot
.932 .11354 Mdot
.932 .11363 Mdot
.932 .11422 Mdot
.932 .11469 Mdot
.932 .11485 Mdot
.932 .11537 Mdot
.932 .11543 Mdot
.932 .11581 Mdot
.932 .11622 Mdot
.932 .11667 Mdot
.932 .11711 Mdot
.932 .11833 Mdot
.932 .1187 Mdot
.932 .11905 Mdot
.932 .11948 Mdot
.932 .1206 Mdot
.932 .12095 Mdot
.932 .12183 Mdot
.932 .12187 Mdot
.932 .12236 Mdot
.932 .12276 Mdot
.932 .12323 Mdot
.932 .12348 Mdot
.932 .12384 Mdot
.932 .1239 Mdot
.932 .12405 Mdot
.932 .12413 Mdot
.932 .12612 Mdot
.932 .12636 Mdot
.932 .1267 Mdot
.932 .1273 Mdot
.932 .12844 Mdot
.932 .12886 Mdot
.932 .1298 Mdot
.932 .1301 Mdot
.932 .13038 Mdot
.932 .1309 Mdot
.932 .13102 Mdot
.932 .13106 Mdot
.932 .13238 Mdot
.932 .13273 Mdot
.932 .13285 Mdot
.932 .13405 Mdot
.932 .13461 Mdot
.932 .13574 Mdot
.932 .13587 Mdot
.932 .13672 Mdot
.932 .13702 Mdot
.932 .13748 Mdot
.932 .13828 Mdot
.932 .13885 Mdot
.932 .13912 Mdot
.932 .13931 Mdot
.932 .14006 Mdot
.932 .14034 Mdot
.932 .14153 Mdot
.932 .14163 Mdot
.932 .14204 Mdot
.932 .14223 Mdot
.932 .14371 Mdot
.932 .14382 Mdot
.932 .1447 Mdot
.932 .14508 Mdot
.932 .14513 Mdot
.932 .14515 Mdot
.932 .14531 Mdot
.932 .14562 Mdot
.932 .14573 Mdot
.932 .14587 Mdot
.932 .14819 Mdot
.932 .14927 Mdot
.932 .14927 Mdot
.932 .14935 Mdot
.932 .15013 Mdot
.932 .15032 Mdot
.932 .15126 Mdot
.932 .1516 Mdot
.932 .15188 Mdot
.932 .15266 Mdot
.932 .15271 Mdot
.932 .15312 Mdot
.932 .15511 Mdot
.932 .15624 Mdot
.932 .15731 Mdot
.932 .15757 Mdot
.932 .15761 Mdot
.932 .15806 Mdot
.932 .15856 Mdot
.932 .15894 Mdot
.932 .15895 Mdot
.932 .15909 Mdot
.932 .16034 Mdot
.932 .16041 Mdot
.932 .16061 Mdot
.932 .16071 Mdot
.932 .16081 Mdot
.932 .16132 Mdot
.932 .16268 Mdot
.932 .16298 Mdot
.932 .16305 Mdot
.932 .16329 Mdot
.932 .16341 Mdot
.932 .16348 Mdot
.932 .16568 Mdot
.932 .16609 Mdot
.932 .16631 Mdot
.932 .16634 Mdot
.932 .16665 Mdot
.932 .1667 Mdot
.932 .16688 Mdot
.932 .16796 Mdot
.932 .16903 Mdot
.932 .17031 Mdot
.932 .1706 Mdot
.932 .17068 Mdot
.932 .17129 Mdot
.932 .17159 Mdot
.932 .17164 Mdot
.932 .17164 Mdot
.932 .17219 Mdot
.932 .17236 Mdot
.932 .17271 Mdot
.932 .1734 Mdot
.932 .17371 Mdot
.932 .17387 Mdot
.932 .17396 Mdot
.932 .17413 Mdot
.932 .17477 Mdot
.932 .17616 Mdot
.932 .17661 Mdot
.932 .17689 Mdot
.932 .17719 Mdot
.932 .1773 Mdot
.932 .17743 Mdot
.932 .17743 Mdot
.932 .1775 Mdot
.932 .17756 Mdot
.932 .1783 Mdot
.932 .17901 Mdot
.932 .17908 Mdot
.932 .1801 Mdot
.932 .18035 Mdot
.932 .18069 Mdot
.932 .18146 Mdot
.932 .18292 Mdot
.932 .18507 Mdot
.932 .18541 Mdot
.932 .18613 Mdot
.932 .18634 Mdot
.932 .18634 Mdot
.932 .1866 Mdot
.932 .18678 Mdot
.932 .18682 Mdot
.932 .18683 Mdot
.932 .18689 Mdot
.932 .18784 Mdot
.932 .18861 Mdot
.932 .1888 Mdot
.932 .18902 Mdot
.932 .18909 Mdot
.932 .18969 Mdot
.932 .1901 Mdot
.932 .19014 Mdot
.932 .19177 Mdot
.932 .19218 Mdot
.932 .19255 Mdot
.932 .1927 Mdot
.932 .19274 Mdot
.932 .19357 Mdot
.932 .19425 Mdot
.932 .19428 Mdot
.932 .19465 Mdot
.932 .19471 Mdot
.932 .19502 Mdot
.932 .19547 Mdot
.932 .19619 Mdot
.932 .19623 Mdot
.932 .19741 Mdot
.932 .19752 Mdot
.932 .19789 Mdot
.932 .19871 Mdot
.932 .19892 Mdot
.932 .19909 Mdot
.932 .19992 Mdot
.932 .20007 Mdot
.932 .20019 Mdot
.932 .20096 Mdot
.932 .20106 Mdot
.932 .20136 Mdot
.932 .20233 Mdot
.932 .20244 Mdot
.932 .20281 Mdot
.932 .20316 Mdot
.932 .20392 Mdot
.932 .20417 Mdot
.932 .20477 Mdot
.932 .20557 Mdot
.932 .20607 Mdot
.932 .20682 Mdot
.932 .20731 Mdot
.932 .20785 Mdot
.932 .20854 Mdot
.932 .20891 Mdot
.932 .2092 Mdot
.932 .20987 Mdot
.932 .20999 Mdot
.932 .21088 Mdot
.932 .21093 Mdot
.932 .21209 Mdot
.932 .21264 Mdot
.932 .21274 Mdot
.932 .21438 Mdot
.932 .21446 Mdot
.932 .21533 Mdot
.932 .21536 Mdot
.932 .21603 Mdot
.932 .2161 Mdot
.932 .21616 Mdot
.932 .21679 Mdot
.932 .21698 Mdot
.932 .21708 Mdot
.932 .21745 Mdot
.932 .21813 Mdot
.932 .21823 Mdot
.932 .21851 Mdot
.932 .21867 Mdot
.932 .21915 Mdot
.932 .22237 Mdot
.932 .22247 Mdot
.932 .22281 Mdot
.932 .22345 Mdot
.932 .22458 Mdot
.932 .22537 Mdot
.932 .22559 Mdot
.932 .22606 Mdot
.932 .22669 Mdot
.932 .22695 Mdot
.932 .22748 Mdot
.932 .22787 Mdot
.932 .22863 Mdot
.932 .22923 Mdot
.932 .2298 Mdot
.932 .22981 Mdot
.932 .23031 Mdot
.932 .23128 Mdot
.932 .23132 Mdot
.932 .2315 Mdot
.932 .23159 Mdot
.932 .23218 Mdot
.932 .23397 Mdot
.932 .23403 Mdot
.932 .23469 Mdot
.932 .23491 Mdot
.932 .23645 Mdot
.932 .23716 Mdot
.932 .23819 Mdot
.932 .24004 Mdot
.932 .2403 Mdot
.932 .24056 Mdot
.932 .24212 Mdot
.932 .24269 Mdot
.932 .24354 Mdot
.932 .24441 Mdot
.932 .24504 Mdot
.932 .2461 Mdot
.932 .24645 Mdot
.932 .2466 Mdot
.932 .24696 Mdot
.932 .24736 Mdot
.932 .24825 Mdot
.932 .24835 Mdot
.932 .24887 Mdot
.932 .25111 Mdot
.932 .25129 Mdot
.932 .25205 Mdot
.932 .25241 Mdot
.932 .2537 Mdot
.932 .25516 Mdot
.932 .25536 Mdot
.932 .25566 Mdot
.932 .257 Mdot
.932 .25772 Mdot
.932 .25781 Mdot
.932 .25785 Mdot
.932 .25813 Mdot
.932 .25863 Mdot
.932 .25867 Mdot
.932 .25873 Mdot
.932 .25893 Mdot
.932 .25918 Mdot
.932 .26165 Mdot
.932 .26352 Mdot
.932 .26361 Mdot
.932 .26382 Mdot
.932 .26552 Mdot
.932 .26553 Mdot
.932 .26567 Mdot
.932 .26624 Mdot
.932 .26663 Mdot
.932 .26712 Mdot
.932 .26748 Mdot
.932 .2675 Mdot
.932 .26873 Mdot
.932 .26924 Mdot
.932 .26925 Mdot
.932 .26987 Mdot
.932 .27039 Mdot
.932 .27039 Mdot
.932 .27051 Mdot
.932 .27098 Mdot
.932 .27185 Mdot
.932 .2719 Mdot
.932 .27193 Mdot
.932 .2727 Mdot
.932 .27317 Mdot
.932 .27499 Mdot
.932 .27534 Mdot
.932 .27641 Mdot
.932 .27715 Mdot
.932 .2774 Mdot
.932 .27836 Mdot
.932 .27851 Mdot
.932 .28051 Mdot
.932 .281 Mdot
.932 .28108 Mdot
.932 .28185 Mdot
.932 .2819 Mdot
.932 .28284 Mdot
.932 .28355 Mdot
.932 .28356 Mdot
.932 .28382 Mdot
.932 .28491 Mdot
.932 .28553 Mdot
.932 .28617 Mdot
.932 .28623 Mdot
.932 .28628 Mdot
.932 .28667 Mdot
.932 .28685 Mdot
.932 .28704 Mdot
.932 .28799 Mdot
.932 .28818 Mdot
.932 .28858 Mdot
.932 .28942 Mdot
.932 .29052 Mdot
.932 .29108 Mdot
.932 .29121 Mdot
.932 .29166 Mdot
.932 .29189 Mdot
.932 .29202 Mdot
.932 .29391 Mdot
.932 .29611 Mdot
.932 .29687 Mdot
.932 .29728 Mdot
.932 .29734 Mdot
.932 .29792 Mdot
.932 .29801 Mdot
.932 .29835 Mdot
.932 .299 Mdot
.932 .29915 Mdot
.932 .29969 Mdot
.932 .30037 Mdot
.932 .30073 Mdot
.932 .30236 Mdot
.932 .30475 Mdot
.932 .30528 Mdot
.932 .30538 Mdot
.932 .30543 Mdot
.932 .30658 Mdot
.932 .30712 Mdot
.932 .30722 Mdot
.932 .30722 Mdot
.932 .30788 Mdot
.932 .3082 Mdot
.932 .30825 Mdot
.932 .30833 Mdot
.932 .30857 Mdot
.932 .30923 Mdot
.932 .30933 Mdot
.932 .31051 Mdot
.932 .31106 Mdot
.932 .31108 Mdot
.932 .31117 Mdot
.932 .31138 Mdot
.932 .31139 Mdot
.932 .31155 Mdot
.932 .31187 Mdot
.932 .3121 Mdot
.932 .31296 Mdot
.932 .31305 Mdot
.932 .31464 Mdot
.932 .31565 Mdot
.932 .31649 Mdot
.932 .317 Mdot
.932 .31757 Mdot
.932 .31777 Mdot
.932 .31802 Mdot
.932 .31802 Mdot
.932 .31805 Mdot
.932 .31815 Mdot
.932 .31826 Mdot
.932 .31868 Mdot
.932 .31904 Mdot
.932 .31964 Mdot
.932 .32096 Mdot
.932 .32109 Mdot
.932 .32154 Mdot
.932 .323 Mdot
.932 .32345 Mdot
.932 .3241 Mdot
.932 .32553 Mdot
.932 .32645 Mdot
.932 .32802 Mdot
.932 .32825 Mdot
.932 .32834 Mdot
.932 .32908 Mdot
.932 .32998 Mdot
.932 .33061 Mdot
.932 .33065 Mdot
.932 .33225 Mdot
.932 .33288 Mdot
.932 .33422 Mdot
.932 .33462 Mdot
.932 .33463 Mdot
.932 .3349 Mdot
.932 .33498 Mdot
.932 .33501 Mdot
.932 .33511 Mdot
.932 .33544 Mdot
.932 .33552 Mdot
.932 .33552 Mdot
.932 .33553 Mdot
.932 .33566 Mdot
.932 .33697 Mdot
.932 .33731 Mdot
.932 .33741 Mdot
.932 .33748 Mdot
.932 .3378 Mdot
.932 .33884 Mdot
.932 .33886 Mdot
.932 .33922 Mdot
.932 .33936 Mdot
.932 .33961 Mdot
.932 .33974 Mdot
.932 .34055 Mdot
.932 .34087 Mdot
.932 .34163 Mdot
.932 .3417 Mdot
.932 .3418 Mdot
.932 .34186 Mdot
.932 .34361 Mdot
.932 .34426 Mdot
.932 .34474 Mdot
.932 .34551 Mdot
.932 .34612 Mdot
.932 .3462 Mdot
.932 .34647 Mdot
.932 .34655 Mdot
.932 .34792 Mdot
.932 .34793 Mdot
.932 .3481 Mdot
.932 .34912 Mdot
.932 .34937 Mdot
.932 .34942 Mdot
.932 .3501 Mdot
.932 .35011 Mdot
.932 .35023 Mdot
.932 .3508 Mdot
.932 .35165 Mdot
.932 .35191 Mdot
.932 .35191 Mdot
.932 .35233 Mdot
.932 .35298 Mdot
.932 .35307 Mdot
.932 .35396 Mdot
.932 .35526 Mdot
.932 .35546 Mdot
.932 .35616 Mdot
.932 .35699 Mdot
.932 .35716 Mdot
.932 .35727 Mdot
.932 .35768 Mdot
.932 .35807 Mdot
.932 .35839 Mdot
.932 .35992 Mdot
.932 .35993 Mdot
.932 .36022 Mdot
.932 .36045 Mdot
.932 .36158 Mdot
.932 .36187 Mdot
.932 .36207 Mdot
.932 .36263 Mdot
.932 .36443 Mdot
.932 .36463 Mdot
.932 .36533 Mdot
.932 .36598 Mdot
.932 .36739 Mdot
.932 .36786 Mdot
.932 .36788 Mdot
.932 .36897 Mdot
.932 .3691 Mdot
.932 .37047 Mdot
.932 .37141 Mdot
.932 .37279 Mdot
.932 .37281 Mdot
.932 .37371 Mdot
.932 .37472 Mdot
.932 .3754 Mdot
.932 .37601 Mdot
.932 .37626 Mdot
.932 .37669 Mdot
.932 .37724 Mdot
.932 .37848 Mdot
.932 .3787 Mdot
.932 .3796 Mdot
.932 .38013 Mdot
.932 .38037 Mdot
.932 .38046 Mdot
.932 .38262 Mdot
.932 .38365 Mdot
.932 .38383 Mdot
.932 .38689 Mdot
.932 .38704 Mdot
.932 .38706 Mdot
.932 .38867 Mdot
.932 .38872 Mdot
.932 .38877 Mdot
.932 .38905 Mdot
.932 .38998 Mdot
.932 .3901 Mdot
.932 .39021 Mdot
.932 .39138 Mdot
.932 .39172 Mdot
.932 .39174 Mdot
.932 .39191 Mdot
.932 .39193 Mdot
.932 .39261 Mdot
.932 .39387 Mdot
.932 .39407 Mdot
.932 .39458 Mdot
.932 .39488 Mdot
.932 .39516 Mdot
.932 .39578 Mdot
.932 .39762 Mdot
.932 .39857 Mdot
.932 .40179 Mdot
.932 .40197 Mdot
.932 .40235 Mdot
.932 .40261 Mdot
.932 .40379 Mdot
.932 .40451 Mdot
.932 .4059 Mdot
.932 .40673 Mdot
.932 .40693 Mdot
.932 .40713 Mdot
.932 .40737 Mdot
.932 .40778 Mdot
.932 .40847 Mdot
.932 .40867 Mdot
.932 .40911 Mdot
.932 .40975 Mdot
.932 .40984 Mdot
.932 .41031 Mdot
.932 .41131 Mdot
.932 .41204 Mdot
.932 .41306 Mdot
.932 .41345 Mdot
.932 .41372 Mdot
.932 .41458 Mdot
.932 .41509 Mdot
.932 .41564 Mdot
.932 .41566 Mdot
.932 .41658 Mdot
.932 .41802 Mdot
.932 .4184 Mdot
.932 .41847 Mdot
.932 .41881 Mdot
.932 .41896 Mdot
.932 .42007 Mdot
.932 .42185 Mdot
.932 .42341 Mdot
.932 .42352 Mdot
.932 .42378 Mdot
.932 .42425 Mdot
.932 .42475 Mdot
.932 .42516 Mdot
.932 .42579 Mdot
.932 .4266 Mdot
.932 .42706 Mdot
.932 .42802 Mdot
.932 .42935 Mdot
.932 .43128 Mdot
.932 .43362 Mdot
.932 .43472 Mdot
.932 .43521 Mdot
.932 .43568 Mdot
.932 .43861 Mdot
.932 .43966 Mdot
.932 .44125 Mdot
.932 .44127 Mdot
.932 .44287 Mdot
.932 .44392 Mdot
.932 .44404 Mdot
.932 .44533 Mdot
.932 .44554 Mdot
.932 .44601 Mdot
.932 .44667 Mdot
.932 .44695 Mdot
.932 .44756 Mdot
.932 .44763 Mdot
.932 .44788 Mdot
.932 .44837 Mdot
.932 .44905 Mdot
.932 .45003 Mdot
.932 .45021 Mdot
.932 .45119 Mdot
.932 .45132 Mdot
.932 .45184 Mdot
.932 .45371 Mdot
.932 .45535 Mdot
.932 .45568 Mdot
.932 .45606 Mdot
.932 .4571 Mdot
.932 .45732 Mdot
.932 .45777 Mdot
.932 .46018 Mdot
.932 .46291 Mdot
.932 .46299 Mdot
.932 .46328 Mdot
.932 .46384 Mdot
.932 .46633 Mdot
.932 .46767 Mdot
.932 .46785 Mdot
.932 .46791 Mdot
.932 .46845 Mdot
.932 .46938 Mdot
.932 .46944 Mdot
.932 .46955 Mdot
.932 .46994 Mdot
.932 .4704 Mdot
.932 .4713 Mdot
.932 .47313 Mdot
.932 .47347 Mdot
.932 .47366 Mdot
.932 .475 Mdot
.932 .47764 Mdot
.932 .47848 Mdot
.932 .47865 Mdot
.932 .47905 Mdot
.932 .47953 Mdot
.932 .47987 Mdot
.932 .47989 Mdot
.932 .48217 Mdot
.932 .48221 Mdot
.932 .48223 Mdot
.932 .4825 Mdot
.932 .48328 Mdot
.932 .48346 Mdot
.932 .48355 Mdot
.932 .48372 Mdot
.932 .48428 Mdot
.932 .48456 Mdot
.932 .4852 Mdot
.932 .48587 Mdot
.932 .4859 Mdot
.932 .48684 Mdot
.932 .48719 Mdot
.932 .48819 Mdot
.932 .48915 Mdot
.932 .48916 Mdot
.932 .4898 Mdot
.932 .49032 Mdot
.932 .49129 Mdot
.932 .49129 Mdot
.932 .49152 Mdot
.932 .4924 Mdot
.932 .49402 Mdot
.932 .49411 Mdot
.932 .49417 Mdot
.932 .49559 Mdot
.932 .49648 Mdot
.932 .49986 Mdot
.932 .50051 Mdot
.932 .50251 Mdot
.932 .50389 Mdot
.932 .50436 Mdot
.932 .50615 Mdot
.932 .50643 Mdot
.932 .51015 Mdot
.932 .51107 Mdot
.932 .51122 Mdot
.932 .51265 Mdot
.932 .51275 Mdot
.932 .5145 Mdot
.932 .51582 Mdot
.932 .51584 Mdot
.932 .51633 Mdot
.932 .51836 Mdot
.932 .51951 Mdot
.932 .5207 Mdot
.932 .52081 Mdot
.932 .52092 Mdot
.932 .52164 Mdot
.932 .52198 Mdot
.932 .52233 Mdot
.932 .5241 Mdot
.932 .52445 Mdot
.932 .52519 Mdot
.932 .52676 Mdot
.932 .52882 Mdot
.932 .52985 Mdot
.932 .53011 Mdot
.932 .53093 Mdot
.932 .53136 Mdot
.932 .53161 Mdot
.932 .53513 Mdot
.932 .53923 Mdot
.932 .54066 Mdot
.932 .54141 Mdot
.932 .54153 Mdot
.932 .54261 Mdot
.932 .54278 Mdot
.932 .54341 Mdot
.932 .54463 Mdot
.932 .5449 Mdot
.932 .54591 Mdot
.932 .54717 Mdot
.932 .54784 Mdot
.932 .55089 Mdot
.932 .55534 Mdot
.932 .55633 Mdot
.932 .55651 Mdot
.932 .55661 Mdot
.932 .55874 Mdot
.932 .55976 Mdot
.932 .55994 Mdot
.932 .55995 Mdot
.932 .56118 Mdot
.932 .56177 Mdot
.932 .56187 Mdot
.932 .56201 Mdot
.932 .56246 Mdot
.932 .56368 Mdot
.932 .56387 Mdot
.934 .01581 Mdot
.934 .01618 Mdot
.934 .01659 Mdot
.934 .01666 Mdot
.934 .01676 Mdot
.934 .01746 Mdot
.934 .0177 Mdot
.934 .01802 Mdot
.934 .01812 Mdot
.934 .01822 Mdot
.934 .01835 Mdot
.934 .01852 Mdot
.934 .01854 Mdot
.934 .01983 Mdot
.934 .02029 Mdot
.934 .02032 Mdot
.934 .0209 Mdot
.934 .02107 Mdot
.934 .02126 Mdot
.934 .02132 Mdot
.934 .02151 Mdot
.934 .02181 Mdot
.934 .02186 Mdot
.934 .02191 Mdot
.934 .02232 Mdot
.934 .0241 Mdot
.934 .02428 Mdot
.934 .02513 Mdot
.934 .02519 Mdot
.934 .02582 Mdot
.934 .02626 Mdot
.934 .02631 Mdot
.934 .02659 Mdot
.934 .02694 Mdot
.934 .02706 Mdot
.934 .02741 Mdot
.934 .02798 Mdot
.934 .02807 Mdot
.934 .02815 Mdot
.934 .02892 Mdot
.934 .0298 Mdot
.934 .02981 Mdot
.934 .03015 Mdot
.934 .03145 Mdot
.934 .03208 Mdot
.934 .03225 Mdot
.934 .03258 Mdot
.934 .03319 Mdot
.934 .03357 Mdot
.934 .03374 Mdot
.934 .03418 Mdot
.934 .03428 Mdot
.934 .03546 Mdot
.934 .03557 Mdot
.934 .03616 Mdot
.934 .03617 Mdot
.934 .03628 Mdot
.934 .03637 Mdot
.934 .0369 Mdot
.934 .03695 Mdot
.934 .03755 Mdot
.934 .03778 Mdot
.934 .03842 Mdot
.934 .03844 Mdot
.934 .03852 Mdot
.934 .03915 Mdot
.934 .03949 Mdot
.934 .03966 Mdot
.934 .03981 Mdot
.934 .03984 Mdot
.934 .0401 Mdot
.934 .04108 Mdot
.934 .04126 Mdot
.934 .04273 Mdot
.934 .0429 Mdot
.934 .04291 Mdot
.934 .04305 Mdot
.934 .04327 Mdot
.934 .04355 Mdot
.934 .04409 Mdot
.934 .04598 Mdot
.934 .04714 Mdot
.934 .04746 Mdot
.934 .04793 Mdot
.934 .04809 Mdot
.934 .04823 Mdot
.934 .04922 Mdot
.934 .04994 Mdot
.934 .05011 Mdot
.934 .05025 Mdot
.934 .05107 Mdot
.934 .05125 Mdot
.934 .05191 Mdot
.934 .05279 Mdot
.934 .05315 Mdot
.934 .05335 Mdot
.934 .05347 Mdot
.934 .05367 Mdot
.934 .05373 Mdot
.934 .05426 Mdot
.934 .05477 Mdot
.934 .0548 Mdot
.934 .055 Mdot
.934 .05516 Mdot
.934 .05534 Mdot
.934 .05549 Mdot
.934 .05616 Mdot
.934 .05619 Mdot
.934 .05625 Mdot
.934 .05701 Mdot
.934 .05736 Mdot
.934 .05737 Mdot
.934 .0578 Mdot
.934 .05782 Mdot
.934 .05824 Mdot
.934 .059 Mdot
.934 .05903 Mdot
.934 .05917 Mdot
.934 .05918 Mdot
.934 .05944 Mdot
.934 .06036 Mdot
.934 .06039 Mdot
.934 .06099 Mdot
.934 .06132 Mdot
.934 .06159 Mdot
.934 .06163 Mdot
.934 .06164 Mdot
.934 .06208 Mdot
.934 .06214 Mdot
.934 .06298 Mdot
.934 .06358 Mdot
.934 .06397 Mdot
.934 .06429 Mdot
.934 .06474 Mdot
.934 .06536 Mdot
.934 .06607 Mdot
.934 .0665 Mdot
.934 .06705 Mdot
.934 .06736 Mdot
.934 .06739 Mdot
.934 .0676 Mdot
.934 .06764 Mdot
.934 .06806 Mdot
.934 .06857 Mdot
.934 .06958 Mdot
.934 .07148 Mdot
.934 .07192 Mdot
.934 .0729 Mdot
.934 .07312 Mdot
.934 .07529 Mdot
.934 .07545 Mdot
.934 .07589 Mdot
.934 .07613 Mdot
.934 .07675 Mdot
.934 .07705 Mdot
.934 .07706 Mdot
.934 .07732 Mdot
.934 .07863 Mdot
.934 .07909 Mdot
.934 .07911 Mdot
.934 .07917 Mdot
.934 .07995 Mdot
.934 .08052 Mdot
.934 .08084 Mdot
.934 .08109 Mdot
.934 .08198 Mdot
.934 .08263 Mdot
.934 .08297 Mdot
.934 .08381 Mdot
.934 .0842 Mdot
.934 .08552 Mdot
.934 .08583 Mdot
.934 .08608 Mdot
.934 .08651 Mdot
.934 .08688 Mdot
.934 .08703 Mdot
.934 .0871 Mdot
.934 .08732 Mdot
.934 .08747 Mdot
.934 .0875 Mdot
.934 .0876 Mdot
.934 .08769 Mdot
.934 .0884 Mdot
.934 .08859 Mdot
.934 .08929 Mdot
.934 .08954 Mdot
.934 .08959 Mdot
.934 .08998 Mdot
.934 .09027 Mdot
.934 .09037 Mdot
.934 .09061 Mdot
.934 .0908 Mdot
.934 .09089 Mdot
.934 .09213 Mdot
.934 .09219 Mdot
.934 .09223 Mdot
.934 .0923 Mdot
.934 .09293 Mdot
.934 .09372 Mdot
.934 .09387 Mdot
.934 .09438 Mdot
.934 .09439 Mdot
.934 .09519 Mdot
.934 .0952 Mdot
.934 .09524 Mdot
.934 .09583 Mdot
.934 .09595 Mdot
.934 .09603 Mdot
.934 .09744 Mdot
.934 .09749 Mdot
.934 .09775 Mdot
.934 .09777 Mdot
.934 .09827 Mdot
.934 .09832 Mdot
.934 .09839 Mdot
.934 .09962 Mdot
.934 .09997 Mdot
.934 .10003 Mdot
.934 .10116 Mdot
.934 .10177 Mdot
.934 .10177 Mdot
.934 .10229 Mdot
.934 .10234 Mdot
.934 .10237 Mdot
.934 .10274 Mdot
.934 .10309 Mdot
.934 .1032 Mdot
.934 .10331 Mdot
.934 .10335 Mdot
.934 .10375 Mdot
.934 .10488 Mdot
.934 .10599 Mdot
.934 .10631 Mdot
.934 .10665 Mdot
.934 .10672 Mdot
.934 .10686 Mdot
.934 .10733 Mdot
.934 .10816 Mdot
.934 .10887 Mdot
.934 .10933 Mdot
.934 .11065 Mdot
.934 .11089 Mdot
.934 .11145 Mdot
.934 .11191 Mdot
.934 .11248 Mdot
.934 .11301 Mdot
.934 .11305 Mdot
.934 .11311 Mdot
.934 .1135 Mdot
.934 .11359 Mdot
.934 .11436 Mdot
.934 .11532 Mdot
.934 .11553 Mdot
.934 .11698 Mdot
.934 .11721 Mdot
.934 .11818 Mdot
.934 .11953 Mdot
.934 .12075 Mdot
.934 .1209 Mdot
.934 .12157 Mdot
.934 .12341 Mdot
.934 .12382 Mdot
.934 .12405 Mdot
.934 .12424 Mdot
.934 .12693 Mdot
.934 .12761 Mdot
.934 .12787 Mdot
.934 .12817 Mdot
.934 .12854 Mdot
.934 .12895 Mdot
.934 .12899 Mdot
.934 .12944 Mdot
.934 .13048 Mdot
.934 .1306 Mdot
.934 .13072 Mdot
.934 .13116 Mdot
.934 .13118 Mdot
.934 .13165 Mdot
.934 .13251 Mdot
.934 .13268 Mdot
.934 .13325 Mdot
.934 .13356 Mdot
.934 .13411 Mdot
.934 .13423 Mdot
.934 .13496 Mdot
.934 .13501 Mdot
.934 .13511 Mdot
.934 .13657 Mdot
.934 .13677 Mdot
.934 .13763 Mdot
.934 .13824 Mdot
.934 .1387 Mdot
.934 .14036 Mdot
.934 .14157 Mdot
.934 .14221 Mdot
.934 .14224 Mdot
.934 .14242 Mdot
.934 .14378 Mdot
.934 .14443 Mdot
.934 .14452 Mdot
.934 .14544 Mdot
.934 .14558 Mdot
.934 .14698 Mdot
.934 .14754 Mdot
.934 .14757 Mdot
.934 .14802 Mdot
.934 .14883 Mdot
.934 .14907 Mdot
.934 .14916 Mdot
.934 .14951 Mdot
.934 .1498 Mdot
.934 .14993 Mdot
.934 .15034 Mdot
.934 .15063 Mdot
.934 .15067 Mdot
.934 .15087 Mdot
.934 .15103 Mdot
.934 .15131 Mdot
.934 .15236 Mdot
.934 .15271 Mdot
.934 .15353 Mdot
.934 .15403 Mdot
.934 .15449 Mdot
.934 .1545 Mdot
.934 .15457 Mdot
.934 .1553 Mdot
.934 .15585 Mdot
.934 .15603 Mdot
.934 .15648 Mdot
.934 .15682 Mdot
.934 .15684 Mdot
.934 .157 Mdot
.934 .15849 Mdot
.934 .15886 Mdot
.934 .15889 Mdot
.934 .15933 Mdot
.934 .15944 Mdot
.934 .15952 Mdot
.934 .15964 Mdot
.934 .16013 Mdot
.934 .16081 Mdot
.934 .16094 Mdot
.934 .16121 Mdot
.934 .1623 Mdot
.934 .16258 Mdot
.934 .16315 Mdot
.934 .16352 Mdot
.934 .16354 Mdot
.934 .16504 Mdot
.934 .16505 Mdot
.934 .16514 Mdot
.934 .16623 Mdot
.934 .16647 Mdot
.934 .1666 Mdot
.934 .16805 Mdot
.934 .16878 Mdot
.934 .16924 Mdot
.934 .16934 Mdot
.934 .16978 Mdot
.934 .16983 Mdot
.934 .16986 Mdot
.934 .17001 Mdot
.934 .1708 Mdot
.934 .17088 Mdot
.934 .17089 Mdot
.934 .17096 Mdot
.934 .17101 Mdot
.934 .17266 Mdot
.934 .17332 Mdot
.934 .17354 Mdot
.934 .17356 Mdot
.934 .17398 Mdot
.934 .17409 Mdot
.934 .17506 Mdot
.934 .17619 Mdot
.934 .17632 Mdot
.934 .17733 Mdot
.934 .17733 Mdot
.934 .1783 Mdot
.934 .17841 Mdot
.934 .17845 Mdot
.934 .17915 Mdot
.934 .1798 Mdot
.934 .17982 Mdot
.934 .18 Mdot
.934 .1802 Mdot
.934 .18028 Mdot
.934 .18103 Mdot
.934 .18119 Mdot
.934 .18315 Mdot
.934 .18366 Mdot
.934 .18402 Mdot
.934 .18522 Mdot
.934 .18574 Mdot
.934 .18582 Mdot
.934 .18609 Mdot
.934 .18645 Mdot
.934 .18658 Mdot
.934 .18684 Mdot
.934 .18772 Mdot
.934 .18927 Mdot
.934 .1906 Mdot
.934 .19145 Mdot
.934 .19146 Mdot
.934 .1928 Mdot
.934 .19373 Mdot
.934 .19381 Mdot
.934 .19391 Mdot
.934 .19438 Mdot
.934 .19481 Mdot
.934 .19522 Mdot
.934 .19542 Mdot
.934 .19628 Mdot
.934 .19698 Mdot
.934 .19733 Mdot
.934 .19823 Mdot
.934 .19833 Mdot
.934 .1984 Mdot
.934 .19852 Mdot
.934 .19925 Mdot
.934 .19941 Mdot
.934 .19999 Mdot
.934 .20086 Mdot
.934 .20117 Mdot
.934 .20189 Mdot
.934 .20265 Mdot
.934 .20304 Mdot
.934 .20434 Mdot
.934 .20535 Mdot
.934 .20574 Mdot
.934 .20618 Mdot
.934 .20697 Mdot
.934 .20725 Mdot
.934 .20798 Mdot
.934 .20955 Mdot
.934 .21018 Mdot
.934 .21051 Mdot
.934 .21107 Mdot
.934 .21279 Mdot
.934 .21306 Mdot
.934 .2142 Mdot
.934 .21431 Mdot
.934 .21432 Mdot
.934 .21695 Mdot
.934 .21744 Mdot
.934 .21751 Mdot
.934 .21776 Mdot
.934 .21778 Mdot
.934 .21827 Mdot
.934 .21852 Mdot
.934 .21852 Mdot
.934 .21896 Mdot
.934 .21932 Mdot
.934 .22032 Mdot
.934 .22142 Mdot
.934 .22152 Mdot
.934 .22433 Mdot
.934 .22461 Mdot
.934 .22559 Mdot
.934 .2261 Mdot
.934 .22664 Mdot
.934 .22734 Mdot
.934 .22764 Mdot
.934 .2281 Mdot
.934 .22818 Mdot
.934 .22902 Mdot
.934 .23017 Mdot
.934 .23096 Mdot
.934 .2311 Mdot
.934 .23112 Mdot
.934 .2312 Mdot
.934 .23134 Mdot
.934 .23141 Mdot
.934 .23224 Mdot
.934 .23227 Mdot
.934 .23316 Mdot
.934 .23475 Mdot
.934 .23502 Mdot
.934 .23508 Mdot
.934 .23614 Mdot
.934 .23672 Mdot
.934 .23706 Mdot
.934 .23774 Mdot
.934 .23795 Mdot
.934 .23823 Mdot
.934 .23934 Mdot
.934 .23942 Mdot
.934 .23961 Mdot
.934 .24062 Mdot
.934 .24133 Mdot
.934 .24232 Mdot
.934 .24234 Mdot
.934 .24254 Mdot
.934 .24271 Mdot
.934 .24278 Mdot
.934 .24432 Mdot
.934 .24546 Mdot
.934 .24619 Mdot
.934 .24632 Mdot
.934 .24648 Mdot
.934 .24714 Mdot
.934 .24746 Mdot
.934 .2484 Mdot
.934 .24942 Mdot
.934 .25066 Mdot
.934 .25169 Mdot
.934 .25288 Mdot
.934 .25292 Mdot
.934 .25315 Mdot
.934 .25327 Mdot
.934 .25367 Mdot
.934 .2558 Mdot
.934 .25632 Mdot
.934 .25658 Mdot
.934 .25666 Mdot
.934 .25702 Mdot
.934 .25718 Mdot
.934 .25736 Mdot
.934 .25796 Mdot
.934 .2582 Mdot
.934 .25891 Mdot
.934 .25918 Mdot
.934 .26103 Mdot
.934 .26115 Mdot
.934 .26178 Mdot
.934 .26225 Mdot
.934 .26283 Mdot
.934 .26288 Mdot
.934 .26358 Mdot
.934 .26372 Mdot
.934 .26524 Mdot
.934 .26541 Mdot
.934 .26551 Mdot
.934 .26568 Mdot
.934 .26585 Mdot
.934 .26651 Mdot
.934 .26706 Mdot
.934 .2673 Mdot
.934 .26754 Mdot
.934 .26806 Mdot
.934 .2686 Mdot
.934 .26869 Mdot
.934 .26904 Mdot
.934 .26935 Mdot
.934 .26988 Mdot
.934 .27009 Mdot
.934 .27057 Mdot
.934 .27109 Mdot
.934 .27184 Mdot
.934 .27249 Mdot
.934 .27343 Mdot
.934 .27403 Mdot
.934 .27454 Mdot
.934 .27495 Mdot
.934 .2752 Mdot
.934 .27554 Mdot
.934 .27581 Mdot
.934 .27584 Mdot
.934 .27597 Mdot
.934 .27733 Mdot
.934 .27779 Mdot
.934 .27835 Mdot
.934 .27836 Mdot
.934 .2787 Mdot
.934 .27954 Mdot
.934 .28005 Mdot
.934 .28017 Mdot
.934 .28021 Mdot
.934 .28051 Mdot
.934 .28137 Mdot
.934 .28328 Mdot
.934 .28398 Mdot
.934 .28403 Mdot
.934 .28485 Mdot
.934 .28506 Mdot
.934 .2852 Mdot
.934 .28543 Mdot
.934 .2857 Mdot
.934 .28634 Mdot
.934 .28763 Mdot
.934 .28786 Mdot
.934 .28836 Mdot
.934 .28928 Mdot
.934 .2904 Mdot
.934 .29094 Mdot
.934 .29199 Mdot
.934 .29269 Mdot
.934 .29273 Mdot
.934 .29345 Mdot
.934 .29359 Mdot
.934 .2944 Mdot
.934 .2948 Mdot
.934 .29553 Mdot
.934 .29555 Mdot
.934 .29571 Mdot
.934 .29621 Mdot
.934 .2977 Mdot
.934 .29775 Mdot
.934 .29818 Mdot
.934 .29845 Mdot
.934 .30115 Mdot
.934 .3025 Mdot
.934 .30337 Mdot
.934 .30356 Mdot
.934 .30364 Mdot
.934 .30437 Mdot
.934 .30448 Mdot
.934 .30453 Mdot
.934 .30481 Mdot
.934 .30543 Mdot
.934 .30627 Mdot
.934 .30635 Mdot
.934 .30644 Mdot
.934 .30645 Mdot
.934 .30651 Mdot
.934 .30657 Mdot
.934 .30664 Mdot
.934 .30668 Mdot
.934 .30788 Mdot
.934 .30846 Mdot
.934 .30908 Mdot
.934 .30976 Mdot
.934 .31098 Mdot
.934 .31118 Mdot
.934 .3114 Mdot
.934 .31144 Mdot
.934 .31199 Mdot
.934 .31217 Mdot
.934 .31222 Mdot
.934 .31243 Mdot
.934 .3134 Mdot
.934 .31393 Mdot
.934 .31425 Mdot
.934 .31447 Mdot
.934 .31542 Mdot
.934 .31634 Mdot
.934 .3166 Mdot
.934 .31847 Mdot
.934 .31848 Mdot
.934 .31866 Mdot
.934 .31936 Mdot
.934 .31969 Mdot
.934 .32028 Mdot
.934 .32049 Mdot
.934 .32058 Mdot
.934 .32156 Mdot
.934 .32188 Mdot
.934 .32188 Mdot
.934 .3223 Mdot
.934 .3231 Mdot
.934 .32314 Mdot
.934 .32348 Mdot
.934 .32384 Mdot
.934 .32399 Mdot
.934 .32451 Mdot
.934 .32539 Mdot
.934 .32556 Mdot
.934 .32568 Mdot
.934 .32612 Mdot
.934 .32818 Mdot
.934 .32834 Mdot
.934 .32935 Mdot
.934 .33031 Mdot
.934 .33078 Mdot
.934 .33097 Mdot
.934 .33108 Mdot
.934 .33128 Mdot
.934 .33157 Mdot
.934 .33215 Mdot
.934 .33223 Mdot
.934 .3326 Mdot
.934 .33304 Mdot
.934 .33323 Mdot
.934 .33347 Mdot
.934 .3337 Mdot
.934 .33419 Mdot
.934 .33434 Mdot
.934 .33485 Mdot
.934 .33551 Mdot
.934 .33575 Mdot
.934 .33624 Mdot
.934 .33655 Mdot
.934 .33718 Mdot
.934 .33751 Mdot
.934 .33789 Mdot
.934 .33812 Mdot
.934 .33871 Mdot
.934 .34078 Mdot
.934 .34102 Mdot
.934 .34155 Mdot
.934 .34291 Mdot
.934 .34327 Mdot
.934 .34377 Mdot
.934 .34461 Mdot
.934 .34486 Mdot
.934 .34487 Mdot
.934 .34532 Mdot
.934 .3464 Mdot
.934 .34738 Mdot
.934 .3483 Mdot
.934 .3486 Mdot
.934 .34911 Mdot
.934 .34926 Mdot
.934 .34936 Mdot
.934 .34946 Mdot
.934 .34984 Mdot
.934 .35032 Mdot
.934 .35089 Mdot
.934 .35113 Mdot
.934 .35189 Mdot
.934 .35227 Mdot
.934 .35277 Mdot
.934 .35348 Mdot
.934 .35382 Mdot
.934 .35388 Mdot
.934 .35515 Mdot
.934 .35519 Mdot
.934 .35585 Mdot
.934 .357 Mdot
.934 .35752 Mdot
.934 .35771 Mdot
.934 .35784 Mdot
.934 .35806 Mdot
.934 .35943 Mdot
.934 .35961 Mdot
.934 .35972 Mdot
.934 .3608 Mdot
.934 .36188 Mdot
.934 .36243 Mdot
.934 .36302 Mdot
.934 .36437 Mdot
.934 .36514 Mdot
.934 .36578 Mdot
.934 .36651 Mdot
.934 .36724 Mdot
.934 .36893 Mdot
.934 .36903 Mdot
.934 .37047 Mdot
.934 .37083 Mdot
.934 .37133 Mdot
.934 .37155 Mdot
.934 .37237 Mdot
.934 .3725 Mdot
.934 .37345 Mdot
.934 .37355 Mdot
.934 .37385 Mdot
.934 .37402 Mdot
.934 .37438 Mdot
.934 .37574 Mdot
.934 .37866 Mdot
.934 .37876 Mdot
.934 .37984 Mdot
.934 .38038 Mdot
.934 .38045 Mdot
.934 .3815 Mdot
.934 .38232 Mdot
.934 .38237 Mdot
.934 .38352 Mdot
.934 .38471 Mdot
.934 .38523 Mdot
.934 .38647 Mdot
.934 .38736 Mdot
.934 .38756 Mdot
.934 .38758 Mdot
.934 .38824 Mdot
.934 .38867 Mdot
.934 .38882 Mdot
.934 .38986 Mdot
.934 .39248 Mdot
.934 .39287 Mdot
.934 .39341 Mdot
.934 .39353 Mdot
.934 .394 Mdot
.934 .39404 Mdot
.934 .39495 Mdot
.934 .39542 Mdot
.934 .39543 Mdot
.934 .39624 Mdot
.934 .39691 Mdot
.934 .39878 Mdot
.934 .39951 Mdot
.934 .40084 Mdot
.934 .40103 Mdot
.934 .40195 Mdot
.934 .40214 Mdot
.934 .40501 Mdot
.934 .40573 Mdot
.934 .40623 Mdot
.934 .40627 Mdot
.934 .40681 Mdot
.934 .40702 Mdot
.934 .40797 Mdot
.934 .40864 Mdot
.934 .40958 Mdot
.934 .41021 Mdot
.934 .4106 Mdot
.934 .41191 Mdot
.934 .41245 Mdot
.934 .41332 Mdot
.934 .41347 Mdot
.934 .4147 Mdot
.934 .41503 Mdot
.934 .41551 Mdot
.934 .41719 Mdot
.934 .41725 Mdot
.934 .41866 Mdot
.934 .41892 Mdot
.934 .41896 Mdot
.934 .4191 Mdot
.934 .41936 Mdot
.934 .4195 Mdot
.934 .42046 Mdot
.934 .42105 Mdot
.934 .42111 Mdot
.934 .42276 Mdot
.934 .42438 Mdot
.934 .42574 Mdot
.934 .42623 Mdot
.934 .42624 Mdot
.934 .42636 Mdot
.934 .42833 Mdot
.934 .42942 Mdot
.934 .4299 Mdot
.934 .43005 Mdot
.934 .43133 Mdot
.934 .43171 Mdot
.934 .43224 Mdot
.934 .43236 Mdot
.934 .43249 Mdot
.934 .43431 Mdot
.934 .43447 Mdot
.934 .43482 Mdot
.934 .43499 Mdot
.934 .43549 Mdot
.934 .43671 Mdot
.934 .43804 Mdot
.934 .43832 Mdot
.934 .43973 Mdot
.934 .43987 Mdot
.934 .43992 Mdot
.934 .44029 Mdot
.934 .44062 Mdot
.934 .44074 Mdot
.934 .44226 Mdot
.934 .44232 Mdot
.934 .44291 Mdot
.934 .44362 Mdot
.934 .4446 Mdot
.934 .44465 Mdot
.934 .44574 Mdot
.934 .4471 Mdot
.934 .44736 Mdot
.934 .44764 Mdot
.934 .44889 Mdot
.934 .44949 Mdot
.934 .44984 Mdot
.934 .45002 Mdot
.934 .45123 Mdot
.934 .45153 Mdot
.934 .45244 Mdot
.934 .45315 Mdot
.934 .45546 Mdot
.934 .45738 Mdot
.934 .45961 Mdot
.934 .45969 Mdot
.934 .46012 Mdot
.934 .46034 Mdot
.934 .46109 Mdot
.934 .46189 Mdot
.934 .46507 Mdot
.934 .46602 Mdot
.934 .46652 Mdot
.934 .4666 Mdot
.934 .46667 Mdot
.934 .46734 Mdot
.934 .46765 Mdot
.934 .46798 Mdot
.934 .4691 Mdot
.934 .46954 Mdot
.934 .46963 Mdot
.934 .47029 Mdot
.934 .47058 Mdot
.934 .47086 Mdot
.934 .47137 Mdot
.934 .47311 Mdot
.934 .47348 Mdot
.934 .47366 Mdot
.934 .47466 Mdot
.934 .47483 Mdot
.934 .47506 Mdot
.934 .47624 Mdot
.934 .4768 Mdot
.934 .4771 Mdot
.934 .4782 Mdot
.934 .47829 Mdot
.934 .47959 Mdot
.934 .47975 Mdot
.934 .47987 Mdot
.934 .48002 Mdot
.934 .48033 Mdot
.934 .48037 Mdot
.934 .48057 Mdot
.934 .4808 Mdot
.934 .48104 Mdot
.934 .48116 Mdot
.934 .48269 Mdot
.934 .48302 Mdot
.934 .4832 Mdot
.934 .48352 Mdot
.934 .48384 Mdot
.934 .48508 Mdot
.934 .48536 Mdot
.934 .48609 Mdot
.934 .48655 Mdot
.934 .487 Mdot
.934 .48738 Mdot
.934 .48796 Mdot
.934 .48897 Mdot
.934 .48913 Mdot
.934 .48954 Mdot
.934 .4898 Mdot
.934 .49036 Mdot
.934 .49137 Mdot
.934 .49175 Mdot
.934 .49193 Mdot
.934 .49264 Mdot
.934 .49363 Mdot
.934 .49503 Mdot
.934 .49625 Mdot
.934 .49799 Mdot
.934 .49911 Mdot
.934 .50007 Mdot
.934 .50084 Mdot
.934 .5013 Mdot
.934 .50193 Mdot
.934 .50244 Mdot
.934 .50249 Mdot
.934 .50274 Mdot
.934 .50528 Mdot
.934 .50615 Mdot
.934 .50719 Mdot
.934 .50721 Mdot
.934 .50783 Mdot
.934 .50941 Mdot
.934 .51036 Mdot
.934 .51059 Mdot
.934 .51067 Mdot
.934 .51122 Mdot
.934 .51283 Mdot
.934 .51639 Mdot
.934 .5177 Mdot
.934 .5178 Mdot
.934 .51933 Mdot
.934 .51972 Mdot
.934 .51998 Mdot
.934 .52041 Mdot
.934 .52092 Mdot
.934 .52212 Mdot
.934 .52452 Mdot
.934 .52495 Mdot
.934 .52588 Mdot
.934 .52761 Mdot
.934 .5297 Mdot
.934 .5307 Mdot
.934 .53266 Mdot
.934 .53397 Mdot
.934 .53404 Mdot
.934 .53538 Mdot
.934 .53565 Mdot
.934 .53716 Mdot
.934 .53792 Mdot
.934 .53927 Mdot
.934 .53931 Mdot
.934 .53962 Mdot
.934 .54056 Mdot
.934 .54333 Mdot
.934 .54343 Mdot
.934 .54424 Mdot
.934 .54472 Mdot
.934 .54978 Mdot
.934 .55231 Mdot
.934 .55393 Mdot
.934 .55428 Mdot
.934 .55443 Mdot
.934 .55579 Mdot
.934 .55599 Mdot
.934 .55608 Mdot
.934 .55662 Mdot
.934 .55777 Mdot
.934 .55935 Mdot
.934 .55949 Mdot
.934 .55965 Mdot
.934 .55968 Mdot
.934 .55978 Mdot
.934 .55991 Mdot
.934 .56003 Mdot
.934 .5601 Mdot
.934 .56235 Mdot
.934 .56343 Mdot
.934 .56459 Mdot
.934 .56586 Mdot
.936 .01493 Mdot
.936 .01511 Mdot
.936 .01523 Mdot
.936 .01546 Mdot
.936 .01568 Mdot
.936 .01611 Mdot
.936 .01647 Mdot
.936 .01652 Mdot
.936 .01671 Mdot
.936 .01732 Mdot
.936 .0177 Mdot
.936 .01799 Mdot
.936 .0181 Mdot
.936 .01845 Mdot
.936 .0196 Mdot
.936 .01976 Mdot
.936 .02029 Mdot
.936 .02034 Mdot
.936 .02085 Mdot
.936 .02104 Mdot
.936 .02171 Mdot
.936 .02188 Mdot
.936 .02261 Mdot
.936 .02368 Mdot
.936 .02386 Mdot
.936 .02416 Mdot
.936 .02474 Mdot
.936 .02507 Mdot
.936 .02516 Mdot
.936 .02525 Mdot
.936 .026 Mdot
.936 .0262 Mdot
.936 .02656 Mdot
.936 .02781 Mdot
.936 .02813 Mdot
.936 .02827 Mdot
.936 .02898 Mdot
.936 .0295 Mdot
.936 .03147 Mdot
.936 .0315 Mdot
.936 .03183 Mdot
.936 .03226 Mdot
.936 .03238 Mdot
.936 .03239 Mdot
.936 .03315 Mdot
.936 .03347 Mdot
.936 .0341 Mdot
.936 .03425 Mdot
.936 .03426 Mdot
.936 .03443 Mdot
.936 .03528 Mdot
.936 .03529 Mdot
.936 .03584 Mdot
.936 .03621 Mdot
.936 .03689 Mdot
.936 .03703 Mdot
.936 .03753 Mdot
.936 .03856 Mdot
.936 .03923 Mdot
.936 .03983 Mdot
.936 .04009 Mdot
.936 .04045 Mdot
.936 .04142 Mdot
.936 .04285 Mdot
.936 .0445 Mdot
.936 .04499 Mdot
.936 .04601 Mdot
.936 .04607 Mdot
.936 .04613 Mdot
.936 .04657 Mdot
.936 .04675 Mdot
.936 .04735 Mdot
.936 .04736 Mdot
.936 .04744 Mdot
.936 .04755 Mdot
.936 .04778 Mdot
.936 .04781 Mdot
.936 .04783 Mdot
.936 .04787 Mdot
.936 .04923 Mdot
.936 .04983 Mdot
.936 .051 Mdot
.936 .05128 Mdot
.936 .05131 Mdot
.936 .05141 Mdot
.936 .05151 Mdot
.936 .05162 Mdot
.936 .05251 Mdot
.936 .05259 Mdot
.936 .05294 Mdot
.936 .05321 Mdot
.936 .05323 Mdot
.936 .05369 Mdot
.936 .05426 Mdot
.936 .05495 Mdot
.936 .05509 Mdot
.936 .05623 Mdot
.936 .0565 Mdot
.936 .05695 Mdot
.936 .05743 Mdot
.936 .05843 Mdot
.936 .05843 Mdot
.936 .05936 Mdot
.936 .0606 Mdot
.936 .06063 Mdot
.936 .06173 Mdot
.936 .06221 Mdot
.936 .0629 Mdot
.936 .06441 Mdot
.936 .06471 Mdot
.936 .06543 Mdot
.936 .06572 Mdot
.936 .06608 Mdot
.936 .06641 Mdot
.936 .06647 Mdot
.936 .06666 Mdot
.936 .06739 Mdot
.936 .0697 Mdot
.936 .07021 Mdot
.936 .07046 Mdot
.936 .07108 Mdot
.936 .07139 Mdot
.936 .07144 Mdot
.936 .07222 Mdot
.936 .07225 Mdot
.936 .07269 Mdot
.936 .0733 Mdot
.936 .07342 Mdot
.936 .07353 Mdot
.936 .07355 Mdot
.936 .07372 Mdot
.936 .07434 Mdot
.936 .07469 Mdot
.936 .07485 Mdot
.936 .07513 Mdot
.936 .07526 Mdot
.936 .07581 Mdot
.936 .07582 Mdot
.936 .07597 Mdot
.936 .07619 Mdot
.936 .07661 Mdot
.936 .07666 Mdot
.936 .07666 Mdot
.936 .0767 Mdot
.936 .07678 Mdot
.936 .07908 Mdot
.936 .07932 Mdot
.936 .07999 Mdot
.936 .08045 Mdot
.936 .08151 Mdot
.936 .08171 Mdot
.936 .08178 Mdot
.936 .08222 Mdot
.936 .08241 Mdot
.936 .08264 Mdot
.936 .08316 Mdot
.936 .08322 Mdot
.936 .0834 Mdot
.936 .08359 Mdot
.936 .0838 Mdot
.936 .08387 Mdot
.936 .08399 Mdot
.936 .08546 Mdot
.936 .08562 Mdot
.936 .08628 Mdot
.936 .08677 Mdot
.936 .08681 Mdot
.936 .08753 Mdot
.936 .08763 Mdot
.936 .08767 Mdot
.936 .08847 Mdot
.936 .08875 Mdot
.936 .08986 Mdot
.936 .08991 Mdot
.936 .09003 Mdot
.936 .09029 Mdot
.936 .09192 Mdot
.936 .092 Mdot
.936 .09226 Mdot
.936 .09244 Mdot
.936 .09293 Mdot
.936 .09358 Mdot
.936 .09372 Mdot
.936 .09378 Mdot
.936 .09468 Mdot
.936 .09549 Mdot
.936 .09607 Mdot
.936 .09655 Mdot
.936 .09655 Mdot
.936 .09664 Mdot
.936 .09677 Mdot
.936 .09748 Mdot
.936 .09824 Mdot
.936 .09828 Mdot
.936 .09889 Mdot
.936 .09917 Mdot
.936 .10062 Mdot
.936 .10067 Mdot
.936 .10081 Mdot
.936 .10126 Mdot
.936 .10164 Mdot
.936 .10178 Mdot
.936 .1019 Mdot
.936 .10223 Mdot
.936 .10257 Mdot
.936 .10272 Mdot
.936 .10363 Mdot
.936 .10492 Mdot
.936 .10575 Mdot
.936 .10666 Mdot
.936 .10682 Mdot
.936 .10698 Mdot
.936 .10774 Mdot
.936 .10806 Mdot
.936 .10808 Mdot
.936 .10826 Mdot
.936 .1083 Mdot
.936 .10938 Mdot
.936 .10965 Mdot
.936 .1102 Mdot
.936 .11054 Mdot
.936 .11087 Mdot
.936 .11149 Mdot
.936 .1116 Mdot
.936 .11196 Mdot
.936 .11221 Mdot
.936 .11332 Mdot
.936 .11694 Mdot
.936 .11697 Mdot
.936 .11765 Mdot
.936 .1186 Mdot
.936 .11908 Mdot
.936 .12024 Mdot
.936 .12072 Mdot
.936 .12081 Mdot
.936 .12091 Mdot
.936 .12143 Mdot
.936 .12237 Mdot
.936 .12242 Mdot
.936 .12324 Mdot
.936 .12439 Mdot
.936 .12461 Mdot
.936 .12481 Mdot
.936 .12486 Mdot
.936 .12516 Mdot
.936 .12633 Mdot
.936 .12695 Mdot
.936 .12696 Mdot
.936 .12699 Mdot
.936 .12728 Mdot
.936 .12781 Mdot
.936 .12805 Mdot
.936 .12865 Mdot
.936 .12908 Mdot
.936 .12911 Mdot
.936 .12939 Mdot
.936 .1298 Mdot
.936 .13058 Mdot
.936 .13067 Mdot
.936 .13068 Mdot
.936 .13076 Mdot
.936 .1309 Mdot
.936 .13183 Mdot
.936 .13202 Mdot
.936 .13259 Mdot
.936 .1352 Mdot
.936 .13566 Mdot
.936 .13648 Mdot
.936 .13691 Mdot
.936 .13736 Mdot
.936 .13778 Mdot
.936 .13976 Mdot
.936 .14013 Mdot
.936 .14025 Mdot
.936 .1408 Mdot
.936 .14109 Mdot
.936 .14144 Mdot
.936 .14188 Mdot
.936 .14268 Mdot
.936 .14285 Mdot
.936 .14296 Mdot
.936 .14329 Mdot
.936 .14365 Mdot
.936 .14404 Mdot
.936 .14418 Mdot
.936 .1444 Mdot
.936 .14584 Mdot
.936 .14715 Mdot
.936 .14745 Mdot
.936 .14864 Mdot
.936 .14868 Mdot
.936 .1496 Mdot
.936 .14967 Mdot
.936 .15048 Mdot
.936 .15058 Mdot
.936 .15102 Mdot
.936 .15121 Mdot
.936 .15124 Mdot
.936 .15129 Mdot
.936 .1521 Mdot
.936 .15249 Mdot
.936 .15279 Mdot
.936 .1533 Mdot
.936 .15344 Mdot
.936 .15376 Mdot
.936 .15538 Mdot
.936 .15548 Mdot
.936 .1557 Mdot
.936 .15619 Mdot
.936 .1564 Mdot
.936 .15661 Mdot
.936 .15719 Mdot
.936 .15773 Mdot
.936 .15788 Mdot
.936 .1589 Mdot
.936 .15925 Mdot
.936 .1594 Mdot
.936 .15987 Mdot
.936 .16022 Mdot
.936 .16114 Mdot
.936 .1613 Mdot
.936 .16236 Mdot
.936 .16247 Mdot
.936 .16261 Mdot
.936 .16272 Mdot
.936 .16442 Mdot
.936 .16502 Mdot
.936 .16593 Mdot
.936 .16701 Mdot
.936 .16716 Mdot
.936 .16743 Mdot
.936 .16762 Mdot
.936 .16778 Mdot
.936 .1679 Mdot
.936 .16791 Mdot
.936 .16808 Mdot
.936 .16833 Mdot
.936 .16966 Mdot
.936 .17108 Mdot
.936 .17115 Mdot
.936 .1723 Mdot
.936 .17281 Mdot
.936 .17316 Mdot
.936 .17427 Mdot
.936 .17471 Mdot
.936 .17522 Mdot
.936 .17552 Mdot
.936 .17562 Mdot
.936 .17588 Mdot
.936 .17674 Mdot
.936 .17744 Mdot
.936 .1777 Mdot
.936 .17793 Mdot
.936 .17853 Mdot
.936 .17903 Mdot
.936 .17918 Mdot
.936 .17947 Mdot
.936 .18069 Mdot
.936 .18116 Mdot
.936 .1813 Mdot
.936 .1816 Mdot
.936 .18198 Mdot
.936 .18211 Mdot
.936 .18212 Mdot
.936 .18316 Mdot
.936 .18347 Mdot
.936 .18357 Mdot
.936 .18379 Mdot
.936 .18514 Mdot
.936 .18514 Mdot
.936 .18577 Mdot
.936 .18684 Mdot
.936 .18714 Mdot
.936 .18722 Mdot
.936 .18743 Mdot
.936 .18749 Mdot
.936 .18885 Mdot
.936 .18921 Mdot
.936 .18945 Mdot
.936 .1895 Mdot
.936 .18982 Mdot
.936 .1899 Mdot
.936 .19103 Mdot
.936 .1918 Mdot
.936 .19193 Mdot
.936 .1924 Mdot
.936 .19243 Mdot
.936 .19344 Mdot
.936 .19347 Mdot
.936 .19411 Mdot
.936 .19472 Mdot
.936 .19521 Mdot
.936 .19572 Mdot
.936 .19588 Mdot
.936 .19608 Mdot
.936 .1965 Mdot
.936 .19676 Mdot
.936 .19723 Mdot
.936 .19751 Mdot
.936 .19754 Mdot
.936 .19773 Mdot
.936 .19895 Mdot
.936 .1993 Mdot
.936 .19968 Mdot
.936 .20001 Mdot
.936 .20184 Mdot
.936 .20312 Mdot
.936 .20469 Mdot
.936 .20608 Mdot
.936 .20614 Mdot
.936 .20741 Mdot
.936 .20766 Mdot
.936 .20864 Mdot
.936 .20918 Mdot
.936 .21008 Mdot
.936 .21144 Mdot
.936 .21162 Mdot
.936 .21187 Mdot
.936 .21225 Mdot
.936 .21316 Mdot
.936 .21332 Mdot
.936 .21347 Mdot
.936 .21352 Mdot
.936 .21381 Mdot
.936 .21449 Mdot
.936 .21617 Mdot
.936 .21624 Mdot
.936 .21634 Mdot
.936 .21788 Mdot
.936 .21819 Mdot
.936 .22003 Mdot
.936 .22028 Mdot
.936 .22043 Mdot
.936 .22044 Mdot
.936 .22082 Mdot
.936 .22091 Mdot
.936 .2213 Mdot
.936 .22148 Mdot
.936 .22189 Mdot
.936 .22197 Mdot
.936 .22246 Mdot
.936 .2232 Mdot
.936 .22337 Mdot
.936 .22367 Mdot
.936 .22417 Mdot
.936 .22483 Mdot
.936 .22484 Mdot
.936 .22489 Mdot
.936 .22524 Mdot
.936 .22544 Mdot
.936 .22643 Mdot
.936 .22688 Mdot
.936 .228 Mdot
.936 .2288 Mdot
.936 .22885 Mdot
.936 .22938 Mdot
.936 .22948 Mdot
.936 .23015 Mdot
.936 .23073 Mdot
.936 .23137 Mdot
.936 .23161 Mdot
.936 .23178 Mdot
.936 .2318 Mdot
.936 .23194 Mdot
.936 .2322 Mdot
.936 .23243 Mdot
.936 .23395 Mdot
.936 .23431 Mdot
.936 .23449 Mdot
.936 .23538 Mdot
.936 .23818 Mdot
.936 .23954 Mdot
.936 .24027 Mdot
.936 .24034 Mdot
.936 .24112 Mdot
.936 .24131 Mdot
.936 .2424 Mdot
.936 .24258 Mdot
.936 .24266 Mdot
.936 .24346 Mdot
.936 .24431 Mdot
.936 .24432 Mdot
.936 .24508 Mdot
.936 .24588 Mdot
.936 .24764 Mdot
.936 .24879 Mdot
.936 .24909 Mdot
.936 .24948 Mdot
.936 .24972 Mdot
.936 .25076 Mdot
.936 .25128 Mdot
.936 .25163 Mdot
.936 .25187 Mdot
.936 .25194 Mdot
.936 .25276 Mdot
.936 .25426 Mdot
.936 .25458 Mdot
.936 .2546 Mdot
.936 .25479 Mdot
.936 .25527 Mdot
.936 .25541 Mdot
.936 .25608 Mdot
.936 .25682 Mdot
.936 .25707 Mdot
.936 .25749 Mdot
.936 .25911 Mdot
.936 .25971 Mdot
.936 .26002 Mdot
.936 .26017 Mdot
.936 .26263 Mdot
.936 .2628 Mdot
.936 .26319 Mdot
.936 .26348 Mdot
.936 .26542 Mdot
.936 .2655 Mdot
.936 .26563 Mdot
.936 .26581 Mdot
.936 .26581 Mdot
.936 .26648 Mdot
.936 .26722 Mdot
.936 .26736 Mdot
.936 .2685 Mdot
.936 .26886 Mdot
.936 .26906 Mdot
.936 .26987 Mdot
.936 .27023 Mdot
.936 .27029 Mdot
.936 .27038 Mdot
.936 .27092 Mdot
.936 .27106 Mdot
.936 .2713 Mdot
.936 .2719 Mdot
.936 .27263 Mdot
.936 .2732 Mdot
.936 .27415 Mdot
.936 .27441 Mdot
.936 .27501 Mdot
.936 .27745 Mdot
.936 .27773 Mdot
.936 .27804 Mdot
.936 .27823 Mdot
.936 .27864 Mdot
.936 .27956 Mdot
.936 .27995 Mdot
.936 .28035 Mdot
.936 .28143 Mdot
.936 .28151 Mdot
.936 .28209 Mdot
.936 .28243 Mdot
.936 .28254 Mdot
.936 .28272 Mdot
.936 .28392 Mdot
.936 .28463 Mdot
.936 .28475 Mdot
.936 .28528 Mdot
.936 .28556 Mdot
.936 .28645 Mdot
.936 .28709 Mdot
.936 .28837 Mdot
.936 .28882 Mdot
.936 .28913 Mdot
.936 .29023 Mdot
.936 .2911 Mdot
.936 .29131 Mdot
.936 .29143 Mdot
.936 .29158 Mdot
.936 .29175 Mdot
.936 .29177 Mdot
.936 .29228 Mdot
.936 .29254 Mdot
.936 .29496 Mdot
.936 .29529 Mdot
.936 .29542 Mdot
.936 .29609 Mdot
.936 .29713 Mdot
.936 .2978 Mdot
.936 .29927 Mdot
.936 .29981 Mdot
.936 .30009 Mdot
.936 .30041 Mdot
.936 .30059 Mdot
.936 .30065 Mdot
.936 .30081 Mdot
.936 .30095 Mdot
.936 .30125 Mdot
.936 .30149 Mdot
.936 .30149 Mdot
.936 .30176 Mdot
.936 .30181 Mdot
.936 .30186 Mdot
.936 .30188 Mdot
.936 .30227 Mdot
.936 .30252 Mdot
.936 .30275 Mdot
.936 .30421 Mdot
.936 .3047 Mdot
.936 .30477 Mdot
.936 .30478 Mdot
.936 .30629 Mdot
.936 .30632 Mdot
.936 .30704 Mdot
.936 .30743 Mdot
.936 .30757 Mdot
.936 .30812 Mdot
.936 .3084 Mdot
.936 .30878 Mdot
.936 .30885 Mdot
.936 .30962 Mdot
.936 .30971 Mdot
.936 .31051 Mdot
.936 .31067 Mdot
.936 .31133 Mdot
.936 .31146 Mdot
.936 .31199 Mdot
.936 .31309 Mdot
.936 .3134 Mdot
.936 .31422 Mdot
.936 .31462 Mdot
.936 .31519 Mdot
.936 .31575 Mdot
.936 .31593 Mdot
.936 .31642 Mdot
.936 .31764 Mdot
.936 .31802 Mdot
.936 .31934 Mdot
.936 .31977 Mdot
.936 .31983 Mdot
.936 .32024 Mdot
.936 .32083 Mdot
.936 .32138 Mdot
.936 .32139 Mdot
.936 .32232 Mdot
.936 .32259 Mdot
.936 .32313 Mdot
.936 .32415 Mdot
.936 .32543 Mdot
.936 .3263 Mdot
.936 .32657 Mdot
.936 .32711 Mdot
.936 .32741 Mdot
.936 .32783 Mdot
.936 .32783 Mdot
.936 .32788 Mdot
.936 .32808 Mdot
.936 .32811 Mdot
.936 .33 Mdot
.936 .33005 Mdot
.936 .33058 Mdot
.936 .33063 Mdot
.936 .33082 Mdot
.936 .33121 Mdot
.936 .33196 Mdot
.936 .33296 Mdot
.936 .33375 Mdot
.936 .33375 Mdot
.936 .33492 Mdot
.936 .33694 Mdot
.936 .33749 Mdot
.936 .33764 Mdot
.936 .33783 Mdot
.936 .33801 Mdot
.936 .33804 Mdot
.936 .33815 Mdot
.936 .33977 Mdot
.936 .34004 Mdot
.936 .34051 Mdot
.936 .3407 Mdot
.936 .34112 Mdot
.936 .34113 Mdot
.936 .34137 Mdot
.936 .34183 Mdot
.936 .34191 Mdot
.936 .34252 Mdot
.936 .34267 Mdot
.936 .34274 Mdot
.936 .34348 Mdot
.936 .34478 Mdot
.936 .34526 Mdot
.936 .34608 Mdot
.936 .34618 Mdot
.936 .34622 Mdot
.936 .34646 Mdot
.936 .34656 Mdot
.936 .34734 Mdot
.936 .3474 Mdot
.936 .34929 Mdot
.936 .34935 Mdot
.936 .3498 Mdot
.936 .35054 Mdot
.936 .35057 Mdot
.936 .35164 Mdot
.936 .35168 Mdot
.936 .35182 Mdot
.936 .35253 Mdot
.936 .3526 Mdot
.936 .35355 Mdot
.936 .35385 Mdot
.936 .35416 Mdot
.936 .35423 Mdot
.936 .35461 Mdot
.936 .35502 Mdot
.936 .35536 Mdot
.936 .35551 Mdot
.936 .35639 Mdot
.936 .35663 Mdot
.936 .35683 Mdot
.936 .35691 Mdot
.936 .35697 Mdot
.936 .35714 Mdot
.936 .35733 Mdot
.936 .35903 Mdot
.936 .35951 Mdot
.936 .3596 Mdot
.936 .35968 Mdot
.936 .36026 Mdot
.936 .36027 Mdot
.936 .36036 Mdot
.936 .36097 Mdot
.936 .36159 Mdot
.936 .36248 Mdot
.936 .365 Mdot
.936 .36502 Mdot
.936 .36702 Mdot
.936 .3674 Mdot
.936 .37035 Mdot
.936 .37036 Mdot
.936 .37126 Mdot
.936 .37296 Mdot
.936 .37306 Mdot
.936 .37336 Mdot
.936 .37544 Mdot
.936 .37591 Mdot
.936 .37775 Mdot
.936 .37875 Mdot
.936 .38044 Mdot
.936 .38194 Mdot
.936 .38292 Mdot
.936 .38298 Mdot
.936 .38333 Mdot
.936 .38379 Mdot
.936 .38399 Mdot
.936 .3845 Mdot
.936 .38467 Mdot
.936 .38608 Mdot
.936 .3862 Mdot
.936 .3865 Mdot
.936 .38679 Mdot
.936 .38687 Mdot
.936 .38742 Mdot
.936 .3887 Mdot
.936 .38932 Mdot
.936 .39069 Mdot
.936 .39183 Mdot
.936 .39197 Mdot
.936 .39207 Mdot
.936 .39216 Mdot
.936 .39504 Mdot
.936 .39563 Mdot
.936 .39586 Mdot
.936 .39614 Mdot
.936 .39817 Mdot
.936 .39906 Mdot
.936 .39939 Mdot
.936 .39954 Mdot
.936 .39975 Mdot
.936 .39982 Mdot
.936 .39982 Mdot
.936 .40038 Mdot
.936 .40054 Mdot
.936 .40071 Mdot
.936 .40143 Mdot
.936 .40177 Mdot
.936 .40255 Mdot
.936 .40269 Mdot
.936 .40361 Mdot
.936 .40458 Mdot
.936 .40499 Mdot
.936 .40531 Mdot
.936 .40587 Mdot
.936 .40681 Mdot
.936 .40708 Mdot
.936 .4075 Mdot
.936 .40804 Mdot
.936 .40806 Mdot
.936 .40816 Mdot
.936 .40881 Mdot
.936 .4092 Mdot
.936 .40938 Mdot
.936 .41035 Mdot
.936 .41104 Mdot
.936 .41188 Mdot
.936 .41347 Mdot
.936 .41399 Mdot
.936 .41548 Mdot
.936 .41558 Mdot
.936 .41571 Mdot
.936 .41657 Mdot
.936 .41675 Mdot
.936 .41801 Mdot
.936 .41909 Mdot
.936 .42021 Mdot
.936 .42029 Mdot
.936 .42075 Mdot
.936 .42107 Mdot
.936 .42111 Mdot
.936 .42137 Mdot
.936 .42176 Mdot
.936 .42186 Mdot
.936 .42228 Mdot
.936 .42285 Mdot
.936 .42512 Mdot
.936 .42579 Mdot
.936 .42613 Mdot
.936 .4267 Mdot
.936 .4278 Mdot
.936 .42977 Mdot
.936 .4305 Mdot
.936 .43092 Mdot
.936 .43144 Mdot
.936 .43202 Mdot
.936 .43212 Mdot
.936 .43305 Mdot
.936 .43388 Mdot
.936 .43482 Mdot
.936 .4356 Mdot
.936 .43695 Mdot
.936 .43708 Mdot
.936 .43854 Mdot
.936 .4389 Mdot
.936 .44095 Mdot
.936 .44127 Mdot
.936 .44143 Mdot
.936 .44292 Mdot
.936 .44328 Mdot
.936 .44443 Mdot
.936 .44453 Mdot
.936 .44453 Mdot
.936 .44489 Mdot
.936 .44597 Mdot
.936 .44726 Mdot
.936 .44746 Mdot
.936 .45075 Mdot
.936 .4509 Mdot
.936 .45291 Mdot
.936 .45322 Mdot
.936 .45346 Mdot
.936 .4542 Mdot
.936 .45465 Mdot
.936 .45658 Mdot
.936 .45757 Mdot
.936 .45821 Mdot
.936 .45838 Mdot
.936 .45867 Mdot
.936 .45881 Mdot
.936 .46027 Mdot
.936 .46034 Mdot
.936 .46126 Mdot
.936 .4624 Mdot
.936 .46301 Mdot
.936 .46314 Mdot
.936 .46323 Mdot
.936 .46373 Mdot
.936 .46379 Mdot
.936 .46379 Mdot
.936 .46414 Mdot
.936 .46426 Mdot
.936 .46504 Mdot
.936 .46531 Mdot
.936 .46534 Mdot
.936 .46615 Mdot
.936 .46617 Mdot
.936 .46655 Mdot
.936 .46713 Mdot
.936 .46728 Mdot
.936 .46748 Mdot
.936 .46752 Mdot
.936 .46793 Mdot
.936 .46841 Mdot
.936 .46892 Mdot
.936 .4692 Mdot
.936 .46978 Mdot
.936 .4706 Mdot
.936 .47221 Mdot
.936 .47335 Mdot
.936 .47392 Mdot
.936 .47421 Mdot
.936 .47569 Mdot
.936 .47743 Mdot
.936 .47766 Mdot
.936 .47768 Mdot
.936 .47882 Mdot
.936 .47913 Mdot
.936 .47987 Mdot
.936 .4804 Mdot
.936 .483 Mdot
.936 .4831 Mdot
.936 .48404 Mdot
.936 .48418 Mdot
.936 .48443 Mdot
.936 .48476 Mdot
.936 .48476 Mdot
.936 .48562 Mdot
.936 .48602 Mdot
.936 .48697 Mdot
.936 .48741 Mdot
.936 .48746 Mdot
.936 .48766 Mdot
.936 .48939 Mdot
.936 .4898 Mdot
.936 .49038 Mdot
.936 .49047 Mdot
.936 .49085 Mdot
.936 .49172 Mdot
.936 .49196 Mdot
.936 .49237 Mdot
.936 .49304 Mdot
.936 .49315 Mdot
.936 .49332 Mdot
.936 .49432 Mdot
.936 .49458 Mdot
.936 .49467 Mdot
.936 .49499 Mdot
.936 .49504 Mdot
.936 .49617 Mdot
.936 .49752 Mdot
.936 .49859 Mdot
.936 .50037 Mdot
.936 .50086 Mdot
.936 .50198 Mdot
.936 .50656 Mdot
.936 .50709 Mdot
.936 .50766 Mdot
.936 .50802 Mdot
.936 .50878 Mdot
.936 .51051 Mdot
.936 .51124 Mdot
.936 .51198 Mdot
.936 .514 Mdot
.936 .51415 Mdot
.936 .51523 Mdot
.936 .51588 Mdot
.936 .51607 Mdot
.936 .51641 Mdot
.936 .51866 Mdot
.936 .52 Mdot
.936 .52022 Mdot
.936 .52122 Mdot
.936 .52174 Mdot
.936 .5234 Mdot
.936 .5246 Mdot
.936 .52701 Mdot
.936 .52784 Mdot
.936 .52842 Mdot
.936 .53047 Mdot
.936 .53211 Mdot
.936 .5325 Mdot
.936 .53273 Mdot
.936 .53301 Mdot
.936 .53332 Mdot
.936 .53337 Mdot
.936 .53431 Mdot
.936 .53481 Mdot
.936 .53933 Mdot
.936 .53995 Mdot
.936 .54019 Mdot
.936 .54145 Mdot
.936 .5434 Mdot
.936 .54464 Mdot
.936 .5474 Mdot
.936 .54841 Mdot
.936 .54894 Mdot
.936 .54954 Mdot
.936 .54987 Mdot
.936 .54999 Mdot
.936 .55029 Mdot
.936 .55054 Mdot
.936 .55112 Mdot
.936 .55155 Mdot
.936 .55156 Mdot
.936 .55207 Mdot
.936 .55215 Mdot
.936 .55226 Mdot
.936 .55228 Mdot
.936 .55302 Mdot
.936 .55349 Mdot
.936 .55392 Mdot
.936 .55664 Mdot
.936 .55758 Mdot
.936 .5577 Mdot
.936 .55771 Mdot
.936 .56055 Mdot
.936 .5606 Mdot
.936 .56195 Mdot
.936 .56267 Mdot
.936 .56293 Mdot
.936 .56396 Mdot
.936 .56449 Mdot
.936 .56521 Mdot
.936 .56534 Mdot
.936 .56678 Mdot
.936 .56695 Mdot
.938 .01811 Mdot
.938 .01817 Mdot
.938 .01969 Mdot
.938 .02004 Mdot
.938 .02029 Mdot
.938 .02053 Mdot
.938 .02068 Mdot
.938 .02078 Mdot
.938 .02109 Mdot
.938 .02119 Mdot
.938 .02168 Mdot
.938 .02363 Mdot
.938 .02405 Mdot
.938 .02446 Mdot
.938 .02449 Mdot
.938 .0247 Mdot
.938 .02518 Mdot
.938 .02562 Mdot
.938 .02591 Mdot
.938 .02608 Mdot
.938 .02668 Mdot
.938 .02687 Mdot
.938 .02703 Mdot
.938 .02777 Mdot
.938 .0278 Mdot
.938 .02834 Mdot
.938 .02839 Mdot
.938 .02916 Mdot
.938 .0293 Mdot
.938 .03037 Mdot
.938 .03144 Mdot
.938 .03178 Mdot
.938 .03222 Mdot
.938 .033 Mdot
.938 .03306 Mdot
.938 .03341 Mdot
.938 .03344 Mdot
.938 .03434 Mdot
.938 .03518 Mdot
.938 .03556 Mdot
.938 .03572 Mdot
.938 .03604 Mdot
.938 .03716 Mdot
.938 .03751 Mdot
.938 .03782 Mdot
.938 .03873 Mdot
.938 .03921 Mdot
.938 .03926 Mdot
.938 .04028 Mdot
.938 .04037 Mdot
.938 .04085 Mdot
.938 .04114 Mdot
.938 .04181 Mdot
.938 .04207 Mdot
.938 .04389 Mdot
.938 .04409 Mdot
.938 .04609 Mdot
.938 .04672 Mdot
.938 .04733 Mdot
.938 .04756 Mdot
.938 .04877 Mdot
.938 .04888 Mdot
.938 .04902 Mdot
.938 .04912 Mdot
.938 .04914 Mdot
.938 .04934 Mdot
.938 .04966 Mdot
.938 .04979 Mdot
.938 .04984 Mdot
.938 .05145 Mdot
.938 .05154 Mdot
.938 .05301 Mdot
.938 .05311 Mdot
.938 .05382 Mdot
.938 .05398 Mdot
.938 .05412 Mdot
.938 .05473 Mdot
.938 .05591 Mdot
.938 .05603 Mdot
.938 .05655 Mdot
.938 .05661 Mdot
.938 .05682 Mdot
.938 .05748 Mdot
.938 .05805 Mdot
.938 .05946 Mdot
.938 .05977 Mdot
.938 .05995 Mdot
.938 .06068 Mdot
.938 .06076 Mdot
.938 .06088 Mdot
.938 .06247 Mdot
.938 .06267 Mdot
.938 .06284 Mdot
.938 .06311 Mdot
.938 .06315 Mdot
.938 .06374 Mdot
.938 .06429 Mdot
.938 .06446 Mdot
.938 .06524 Mdot
.938 .06554 Mdot
.938 .06603 Mdot
.938 .06728 Mdot
.938 .06871 Mdot
.938 .06876 Mdot
.938 .0693 Mdot
.938 .06945 Mdot
.938 .06956 Mdot
.938 .06958 Mdot
.938 .06982 Mdot
.938 .07038 Mdot
.938 .07077 Mdot
.938 .07079 Mdot
.938 .07089 Mdot
.938 .07131 Mdot
.938 .07187 Mdot
.938 .07358 Mdot
.938 .07373 Mdot
.938 .07407 Mdot
.938 .07424 Mdot
.938 .07476 Mdot
.938 .0759 Mdot
.938 .07614 Mdot
.938 .07634 Mdot
.938 .0773 Mdot
.938 .0776 Mdot
.938 .07861 Mdot
.938 .07881 Mdot
.938 .07907 Mdot
.938 .07926 Mdot
.938 .0793 Mdot
.938 .07948 Mdot
.938 .07967 Mdot
.938 .08027 Mdot
.938 .0805 Mdot
.938 .08051 Mdot
.938 .08062 Mdot
.938 .08157 Mdot
.938 .08195 Mdot
.938 .08307 Mdot
.938 .08363 Mdot
.938 .08379 Mdot
.938 .08399 Mdot
.938 .08543 Mdot
.938 .08578 Mdot
.938 .08581 Mdot
.938 .08655 Mdot
.938 .08674 Mdot
.938 .0876 Mdot
.938 .08808 Mdot
.938 .08837 Mdot
.938 .08864 Mdot
.938 .08865 Mdot
.938 .08869 Mdot
.938 .08952 Mdot
.938 .08978 Mdot
.938 .09005 Mdot
.938 .09084 Mdot
.938 .09201 Mdot
.938 .09223 Mdot
.938 .09293 Mdot
.938 .0932 Mdot
.938 .0933 Mdot
.938 .09371 Mdot
.938 .09495 Mdot
.938 .09503 Mdot
.938 .09561 Mdot
.938 .09565 Mdot
.938 .09596 Mdot
.938 .09602 Mdot
.938 .09624 Mdot
.938 .0964 Mdot
.938 .09866 Mdot
.938 .09925 Mdot
.938 .09948 Mdot
.938 .09957 Mdot
.938 .10079 Mdot
.938 .10094 Mdot
.938 .1011 Mdot
.938 .10131 Mdot
.938 .10269 Mdot
.938 .10273 Mdot
.938 .10429 Mdot
.938 .10468 Mdot
.938 .10499 Mdot
.938 .10551 Mdot
.938 .10558 Mdot
.938 .10626 Mdot
.938 .10638 Mdot
.938 .10669 Mdot
.938 .10704 Mdot
.938 .10772 Mdot
.938 .10803 Mdot
.938 .10854 Mdot
.938 .1095 Mdot
.938 .11006 Mdot
.938 .11099 Mdot
.938 .1111 Mdot
.938 .11177 Mdot
.938 .11294 Mdot
.938 .11333 Mdot
.938 .11452 Mdot
.938 .11601 Mdot
.938 .1161 Mdot
.938 .11712 Mdot
.938 .11739 Mdot
.938 .1176 Mdot
.938 .11765 Mdot
.938 .11765 Mdot
.938 .11793 Mdot
.938 .11809 Mdot
.938 .11864 Mdot
.938 .11892 Mdot
.938 .11897 Mdot
.938 .11907 Mdot
.938 .11914 Mdot
.938 .11988 Mdot
.938 .11991 Mdot
.938 .12009 Mdot
.938 .12088 Mdot
.938 .12193 Mdot
.938 .12409 Mdot
.938 .12514 Mdot
.938 .1253 Mdot
.938 .12543 Mdot
.938 .12606 Mdot
.938 .12639 Mdot
.938 .12658 Mdot
.938 .12736 Mdot
.938 .12793 Mdot
.938 .12843 Mdot
.938 .12881 Mdot
.938 .12938 Mdot
.938 .12947 Mdot
.938 .12949 Mdot
.938 .12951 Mdot
.938 .12995 Mdot
.938 .13032 Mdot
.938 .13079 Mdot
.938 .13103 Mdot
.938 .13117 Mdot
.938 .13212 Mdot
.938 .13269 Mdot
.938 .13458 Mdot
.938 .13495 Mdot
.938 .13545 Mdot
.938 .13581 Mdot
.938 .13588 Mdot
.938 .13612 Mdot
.938 .13621 Mdot
.938 .13657 Mdot
.938 .13695 Mdot
.938 .13718 Mdot
.938 .13727 Mdot
.938 .13735 Mdot
.938 .1377 Mdot
.938 .13792 Mdot
.938 .13813 Mdot
.938 .13814 Mdot
.938 .13832 Mdot
.938 .13835 Mdot
.938 .1384 Mdot
.938 .1393 Mdot
.938 .13961 Mdot
.938 .13962 Mdot
.938 .14014 Mdot
.938 .14084 Mdot
.938 .14146 Mdot
.938 .14181 Mdot
.938 .14253 Mdot
.938 .14296 Mdot
.938 .144 Mdot
.938 .1443 Mdot
.938 .14468 Mdot
.938 .14502 Mdot
.938 .14615 Mdot
.938 .14627 Mdot
.938 .14737 Mdot
.938 .14801 Mdot
.938 .14804 Mdot
.938 .14808 Mdot
.938 .14832 Mdot
.938 .14859 Mdot
.938 .14894 Mdot
.938 .14903 Mdot
.938 .1494 Mdot
.938 .14948 Mdot
.938 .14949 Mdot
.938 .14983 Mdot
.938 .15007 Mdot
.938 .15144 Mdot
.938 .15157 Mdot
.938 .15235 Mdot
.938 .15289 Mdot
.938 .1534 Mdot
.938 .15341 Mdot
.938 .15349 Mdot
.938 .15435 Mdot
.938 .15456 Mdot
.938 .15504 Mdot
.938 .15554 Mdot
.938 .15574 Mdot
.938 .15604 Mdot
.938 .15753 Mdot
.938 .15753 Mdot
.938 .15887 Mdot
.938 .15971 Mdot
.938 .16012 Mdot
.938 .16029 Mdot
.938 .16095 Mdot
.938 .16144 Mdot
.938 .16195 Mdot
.938 .16214 Mdot
.938 .16291 Mdot
.938 .16361 Mdot
.938 .16523 Mdot
.938 .16539 Mdot
.938 .16611 Mdot
.938 .16619 Mdot
.938 .16647 Mdot
.938 .16655 Mdot
.938 .16713 Mdot
.938 .16724 Mdot
.938 .16765 Mdot
.938 .16792 Mdot
.938 .16795 Mdot
.938 .16985 Mdot
.938 .1722 Mdot
.938 .17228 Mdot
.938 .17329 Mdot
.938 .17374 Mdot
.938 .17391 Mdot
.938 .17431 Mdot
.938 .17486 Mdot
.938 .17511 Mdot
.938 .1762 Mdot
.938 .17647 Mdot
.938 .17678 Mdot
.938 .17718 Mdot
.938 .17975 Mdot
.938 .17984 Mdot
.938 .18217 Mdot
.938 .18226 Mdot
.938 .18277 Mdot
.938 .18348 Mdot
.938 .18403 Mdot
.938 .18407 Mdot
.938 .18421 Mdot
.938 .18423 Mdot
.938 .18504 Mdot
.938 .18518 Mdot
.938 .18544 Mdot
.938 .18646 Mdot
.938 .18668 Mdot
.938 .18726 Mdot
.938 .18784 Mdot
.938 .18792 Mdot
.938 .18826 Mdot
.938 .18829 Mdot
.938 .1891 Mdot
.938 .18919 Mdot
.938 .18978 Mdot
.938 .19011 Mdot
.938 .19073 Mdot
.938 .19102 Mdot
.938 .19132 Mdot
.938 .19252 Mdot
.938 .19253 Mdot
.938 .19358 Mdot
.938 .19396 Mdot
.938 .19515 Mdot
.938 .19533 Mdot
.938 .19549 Mdot
.938 .19554 Mdot
.938 .19679 Mdot
.938 .19732 Mdot
.938 .19834 Mdot
.938 .19856 Mdot
.938 .19899 Mdot
.938 .19972 Mdot
.938 .1999 Mdot
.938 .20158 Mdot
.938 .20186 Mdot
.938 .20195 Mdot
.938 .20198 Mdot
.938 .20375 Mdot
.938 .20475 Mdot
.938 .20491 Mdot
.938 .20493 Mdot
.938 .20494 Mdot
.938 .20538 Mdot
.938 .20682 Mdot
.938 .20734 Mdot
.938 .20747 Mdot
.938 .20773 Mdot
.938 .20782 Mdot
.938 .20782 Mdot
.938 .20834 Mdot
.938 .20844 Mdot
.938 .20864 Mdot
.938 .20967 Mdot
.938 .2102 Mdot
.938 .21029 Mdot
.938 .21049 Mdot
.938 .2106 Mdot
.938 .21062 Mdot
.938 .21079 Mdot
.938 .212 Mdot
.938 .21206 Mdot
.938 .2124 Mdot
.938 .21329 Mdot
.938 .21369 Mdot
.938 .21388 Mdot
.938 .21535 Mdot
.938 .21586 Mdot
.938 .2171 Mdot
.938 .21767 Mdot
.938 .21783 Mdot
.938 .2179 Mdot
.938 .21991 Mdot
.938 .21993 Mdot
.938 .22044 Mdot
.938 .22084 Mdot
.938 .22188 Mdot
.938 .22216 Mdot
.938 .22242 Mdot
.938 .22251 Mdot
.938 .22326 Mdot
.938 .2236 Mdot
.938 .22421 Mdot
.938 .2245 Mdot
.938 .22457 Mdot
.938 .22495 Mdot
.938 .22604 Mdot
.938 .22638 Mdot
.938 .2271 Mdot
.938 .22799 Mdot
.938 .22804 Mdot
.938 .22875 Mdot
.938 .22887 Mdot
.938 .22983 Mdot
.938 .23 Mdot
.938 .23004 Mdot
.938 .23006 Mdot
.938 .23064 Mdot
.938 .2309 Mdot
.938 .23158 Mdot
.938 .23247 Mdot
.938 .23293 Mdot
.938 .23318 Mdot
.938 .23498 Mdot
.938 .23519 Mdot
.938 .23597 Mdot
.938 .23604 Mdot
.938 .23679 Mdot
.938 .23869 Mdot
.938 .23895 Mdot
.938 .23958 Mdot
.938 .24027 Mdot
.938 .24121 Mdot
.938 .24157 Mdot
.938 .24188 Mdot
.938 .24202 Mdot
.938 .24247 Mdot
.938 .24263 Mdot
.938 .24307 Mdot
.938 .24331 Mdot
.938 .24403 Mdot
.938 .24447 Mdot
.938 .24463 Mdot
.938 .24477 Mdot
.938 .24543 Mdot
.938 .24547 Mdot
.938 .24586 Mdot
.938 .24624 Mdot
.938 .24626 Mdot
.938 .24659 Mdot
.938 .24665 Mdot
.938 .24675 Mdot
.938 .24828 Mdot
.938 .24843 Mdot
.938 .24903 Mdot
.938 .24904 Mdot
.938 .24919 Mdot
.938 .25001 Mdot
.938 .25132 Mdot
.938 .25141 Mdot
.938 .25249 Mdot
.938 .25314 Mdot
.938 .25384 Mdot
.938 .25449 Mdot
.938 .25495 Mdot
.938 .25497 Mdot
.938 .2553 Mdot
.938 .25687 Mdot
.938 .25715 Mdot
.938 .25725 Mdot
.938 .25782 Mdot
.938 .25841 Mdot
.938 .25853 Mdot
.938 .25917 Mdot
.938 .2595 Mdot
.938 .25998 Mdot
.938 .26128 Mdot
.938 .26152 Mdot
.938 .26156 Mdot
.938 .26214 Mdot
.938 .26358 Mdot
.938 .26367 Mdot
.938 .26368 Mdot
.938 .26453 Mdot
.938 .26477 Mdot
.938 .26483 Mdot
.938 .26491 Mdot
.938 .26536 Mdot
.938 .26587 Mdot
.938 .26653 Mdot
.938 .2667 Mdot
.938 .26705 Mdot
.938 .26738 Mdot
.938 .26754 Mdot
.938 .26755 Mdot
.938 .26819 Mdot
.938 .2686 Mdot
.938 .26865 Mdot
.938 .26918 Mdot
.938 .26967 Mdot
.938 .27122 Mdot
.938 .27146 Mdot
.938 .27198 Mdot
.938 .27213 Mdot
.938 .27291 Mdot
.938 .27349 Mdot
.938 .27392 Mdot
.938 .27398 Mdot
.938 .27486 Mdot
.938 .27489 Mdot
.938 .27491 Mdot
.938 .27492 Mdot
.938 .27506 Mdot
.938 .27608 Mdot
.938 .27627 Mdot
.938 .27662 Mdot
.938 .27667 Mdot
.938 .27707 Mdot
.938 .27797 Mdot
.938 .2789 Mdot
.938 .27929 Mdot
.938 .27984 Mdot
.938 .28202 Mdot
.938 .28202 Mdot
.938 .28256 Mdot
.938 .28263 Mdot
.938 .28263 Mdot
.938 .28327 Mdot
.938 .28372 Mdot
.938 .28464 Mdot
.938 .28469 Mdot
.938 .28471 Mdot
.938 .28515 Mdot
.938 .28522 Mdot
.938 .28568 Mdot
.938 .28673 Mdot
.938 .2875 Mdot
.938 .28782 Mdot
.938 .28812 Mdot
.938 .28818 Mdot
.938 .28905 Mdot
.938 .28998 Mdot
.938 .29093 Mdot
.938 .29129 Mdot
.938 .29273 Mdot
.938 .29273 Mdot
.938 .29302 Mdot
.938 .29405 Mdot
.938 .29561 Mdot
.938 .29683 Mdot
.938 .29702 Mdot
.938 .29709 Mdot
.938 .29723 Mdot
.938 .29738 Mdot
.938 .29889 Mdot
.938 .2991 Mdot
.938 .29913 Mdot
.938 .29942 Mdot
.938 .29956 Mdot
.938 .30008 Mdot
.938 .30064 Mdot
.938 .30084 Mdot
.938 .3016 Mdot
.938 .30162 Mdot
.938 .30212 Mdot
.938 .30218 Mdot
.938 .30348 Mdot
.938 .30388 Mdot
.938 .30549 Mdot
.938 .30555 Mdot
.938 .30574 Mdot
.938 .30672 Mdot
.938 .30721 Mdot
.938 .30853 Mdot
.938 .31016 Mdot
.938 .31031 Mdot
.938 .31221 Mdot
.938 .31224 Mdot
.938 .31305 Mdot
.938 .31323 Mdot
.938 .31337 Mdot
.938 .3135 Mdot
.938 .31358 Mdot
.938 .31363 Mdot
.938 .31411 Mdot
.938 .31515 Mdot
.938 .31559 Mdot
.938 .31561 Mdot
.938 .31696 Mdot
.938 .31737 Mdot
.938 .31766 Mdot
.938 .31768 Mdot
.938 .31809 Mdot
.938 .31817 Mdot
.938 .31874 Mdot
.938 .31949 Mdot
.938 .32036 Mdot
.938 .32151 Mdot
.938 .3232 Mdot
.938 .32433 Mdot
.938 .32448 Mdot
.938 .32595 Mdot
.938 .32778 Mdot
.938 .32855 Mdot
.938 .32861 Mdot
.938 .32875 Mdot
.938 .32885 Mdot
.938 .32902 Mdot
.938 .32998 Mdot
.938 .33081 Mdot
.938 .33132 Mdot
.938 .33236 Mdot
.938 .33242 Mdot
.938 .3327 Mdot
.938 .33273 Mdot
.938 .33425 Mdot
.938 .33451 Mdot
.938 .335 Mdot
.938 .33585 Mdot
.938 .33619 Mdot
.938 .33622 Mdot
.938 .33691 Mdot
.938 .33733 Mdot
.938 .33842 Mdot
.938 .33918 Mdot
.938 .3392 Mdot
.938 .33949 Mdot
.938 .33963 Mdot
.938 .33964 Mdot
.938 .34007 Mdot
.938 .34028 Mdot
.938 .34029 Mdot
.938 .34034 Mdot
.938 .34056 Mdot
.938 .34086 Mdot
.938 .34186 Mdot
.938 .34203 Mdot
.938 .34213 Mdot
.938 .34314 Mdot
.938 .34376 Mdot
.938 .34392 Mdot
.938 .34492 Mdot
.938 .34546 Mdot
.938 .34603 Mdot
.938 .34623 Mdot
.938 .34684 Mdot
.938 .34732 Mdot
.938 .34809 Mdot
.938 .34828 Mdot
.938 .34829 Mdot
.938 .34925 Mdot
.938 .3498 Mdot
.938 .34983 Mdot
.938 .35027 Mdot
.938 .35055 Mdot
.938 .35098 Mdot
.938 .35209 Mdot
.938 .35321 Mdot
.938 .35352 Mdot
.938 .35354 Mdot
.938 .3537 Mdot
.938 .35385 Mdot
.938 .35394 Mdot
.938 .35558 Mdot
.938 .35628 Mdot
.938 .35729 Mdot
.938 .35731 Mdot
.938 .3592 Mdot
.938 .35926 Mdot
.938 .35961 Mdot
.938 .36041 Mdot
.938 .36178 Mdot
.938 .36213 Mdot
.938 .36276 Mdot
.938 .3636 Mdot
.938 .36526 Mdot
.938 .36541 Mdot
.938 .36579 Mdot
.938 .36594 Mdot
.938 .36597 Mdot
.938 .36602 Mdot
.938 .3687 Mdot
.938 .36934 Mdot
.938 .37002 Mdot
.938 .37074 Mdot
.938 .37101 Mdot
.938 .37121 Mdot
.938 .37152 Mdot
.938 .37157 Mdot
.938 .37158 Mdot
.938 .37227 Mdot
.938 .3724 Mdot
.938 .37247 Mdot
.938 .37511 Mdot
.938 .37555 Mdot
.938 .37568 Mdot
.938 .37573 Mdot
.938 .37576 Mdot
.938 .37607 Mdot
.938 .37628 Mdot
.938 .37633 Mdot
.938 .37681 Mdot
.938 .37697 Mdot
.938 .37698 Mdot
.938 .37796 Mdot
.938 .37814 Mdot
.938 .37853 Mdot
.938 .37986 Mdot
.938 .38046 Mdot
.938 .38052 Mdot
.938 .38145 Mdot
.938 .38161 Mdot
.938 .38176 Mdot
.938 .38195 Mdot
.938 .38199 Mdot
.938 .38219 Mdot
.938 .38224 Mdot
.938 .38255 Mdot
.938 .38335 Mdot
.938 .38483 Mdot
.938 .38494 Mdot
.938 .38557 Mdot
.938 .38652 Mdot
.938 .38724 Mdot
.938 .388 Mdot
.938 .38835 Mdot
.938 .38977 Mdot
.938 .3911 Mdot
.938 .39114 Mdot
.938 .39206 Mdot
.938 .39309 Mdot
.938 .39439 Mdot
.938 .39547 Mdot
.938 .39576 Mdot
.938 .39589 Mdot
.938 .39966 Mdot
.938 .3997 Mdot
.938 .40065 Mdot
.938 .40075 Mdot
.938 .40076 Mdot
.938 .4014 Mdot
.938 .40268 Mdot
.938 .4029 Mdot
.938 .40292 Mdot
.938 .40335 Mdot
.938 .40389 Mdot
.938 .40438 Mdot
.938 .40454 Mdot
.938 .40518 Mdot
.938 .40594 Mdot
.938 .40658 Mdot
.938 .40676 Mdot
.938 .40774 Mdot
.938 .40828 Mdot
.938 .4084 Mdot
.938 .40911 Mdot
.938 .41 Mdot
.938 .41015 Mdot
.938 .41022 Mdot
.938 .41116 Mdot
.938 .41179 Mdot
.938 .4118 Mdot
.938 .41203 Mdot
.938 .41314 Mdot
.938 .41366 Mdot
.938 .41481 Mdot
.938 .41491 Mdot
.938 .41625 Mdot
.938 .41646 Mdot
.938 .41734 Mdot
.938 .41828 Mdot
.938 .41858 Mdot
.938 .41867 Mdot
.938 .4187 Mdot
.938 .41979 Mdot
.938 .42006 Mdot
.938 .42027 Mdot
.938 .42116 Mdot
.938 .42156 Mdot
.938 .42222 Mdot
.938 .42246 Mdot
.938 .42322 Mdot
.938 .42408 Mdot
.938 .42455 Mdot
.938 .42549 Mdot
.938 .42792 Mdot
.938 .42834 Mdot
.938 .42877 Mdot
.938 .42979 Mdot
.938 .42993 Mdot
.938 .43132 Mdot
.938 .43212 Mdot
.938 .4334 Mdot
.938 .4349 Mdot
.938 .43538 Mdot
.938 .43656 Mdot
.938 .43786 Mdot
.938 .43845 Mdot
.938 .43846 Mdot
.938 .43947 Mdot
.938 .43963 Mdot
.938 .4403 Mdot
.938 .44088 Mdot
.938 .44113 Mdot
.938 .44198 Mdot
.938 .44229 Mdot
.938 .4431 Mdot
.938 .44311 Mdot
.938 .44356 Mdot
.938 .4449 Mdot
.938 .44573 Mdot
.938 .44604 Mdot
.938 .4463 Mdot
.938 .44753 Mdot
.938 .44761 Mdot
.938 .44834 Mdot
.938 .4486 Mdot
.938 .44906 Mdot
.938 .4491 Mdot
.938 .44972 Mdot
.938 .44982 Mdot
.938 .45 Mdot
.938 .45288 Mdot
.938 .45288 Mdot
.938 .45317 Mdot
.938 .45355 Mdot
.938 .45379 Mdot
.938 .45428 Mdot
.938 .4543 Mdot
.938 .45431 Mdot
.938 .45459 Mdot
.938 .45484 Mdot
.938 .45613 Mdot
.938 .45617 Mdot
.938 .45859 Mdot
.938 .45875 Mdot
.938 .46013 Mdot
.938 .46078 Mdot
.938 .46088 Mdot
.938 .46099 Mdot
.938 .46199 Mdot
.938 .46201 Mdot
.938 .46251 Mdot
.938 .46332 Mdot
.938 .46432 Mdot
.938 .46453 Mdot
.938 .46539 Mdot
.938 .46543 Mdot
.938 .46605 Mdot
.938 .46631 Mdot
.938 .46701 Mdot
.938 .46899 Mdot
.938 .46952 Mdot
.938 .46966 Mdot
.938 .4697 Mdot
.938 .46973 Mdot
.938 .47078 Mdot
.938 .47151 Mdot
.938 .47173 Mdot
.938 .47189 Mdot
.938 .47211 Mdot
.938 .47332 Mdot
.938 .47393 Mdot
.938 .47483 Mdot
.938 .4763 Mdot
.938 .47728 Mdot
.938 .47769 Mdot
.938 .47772 Mdot
.938 .47779 Mdot
.938 .47889 Mdot
.938 .48158 Mdot
.938 .48176 Mdot
.938 .48177 Mdot
.938 .48335 Mdot
.938 .48336 Mdot
.938 .48359 Mdot
.938 .48383 Mdot
.938 .48394 Mdot
.938 .48409 Mdot
.938 .48425 Mdot
.938 .48492 Mdot
.938 .48588 Mdot
.938 .48711 Mdot
.938 .48743 Mdot
.938 .48769 Mdot
.938 .4881 Mdot
.938 .48872 Mdot
.938 .48902 Mdot
.938 .48903 Mdot
.938 .48941 Mdot
.938 .49023 Mdot
.938 .49099 Mdot
.938 .49109 Mdot
.938 .49209 Mdot
.938 .49302 Mdot
.938 .49406 Mdot
.938 .49592 Mdot
.938 .49637 Mdot
.938 .49734 Mdot
.938 .49762 Mdot
.938 .49909 Mdot
.938 .49979 Mdot
.938 .50018 Mdot
.938 .50032 Mdot
.938 .50099 Mdot
.938 .5011 Mdot
.938 .50274 Mdot
.938 .50281 Mdot
.938 .50283 Mdot
.938 .50285 Mdot
.938 .50313 Mdot
.938 .50503 Mdot
.938 .50539 Mdot
.938 .50605 Mdot
.938 .50615 Mdot
.938 .5069 Mdot
.938 .50859 Mdot
.938 .51032 Mdot
.938 .51105 Mdot
.938 .51209 Mdot
.938 .51617 Mdot
.938 .51617 Mdot
.938 .5172 Mdot
.938 .51732 Mdot
.938 .51733 Mdot
.938 .51853 Mdot
.938 .51937 Mdot
.938 .5211 Mdot
.938 .52118 Mdot
.938 .52122 Mdot
.938 .52206 Mdot
.938 .52218 Mdot
.938 .52305 Mdot
.938 .52502 Mdot
.938 .52646 Mdot
.938 .52705 Mdot
.938 .52762 Mdot
.938 .52774 Mdot
.938 .52936 Mdot
.938 .53111 Mdot
.938 .53289 Mdot
.938 .53358 Mdot
.938 .53627 Mdot
.938 .53627 Mdot
.938 .53681 Mdot
.938 .53875 Mdot
.938 .54168 Mdot
.938 .54396 Mdot
.938 .54432 Mdot
.938 .54444 Mdot
.938 .54472 Mdot
.938 .545 Mdot
.938 .54571 Mdot
.938 .54782 Mdot
.938 .54822 Mdot
.938 .54828 Mdot
.938 .54881 Mdot
.938 .54909 Mdot
.938 .55006 Mdot
.938 .55112 Mdot
.938 .55149 Mdot
.938 .5529 Mdot
.938 .55294 Mdot
.938 .55389 Mdot
.938 .55401 Mdot
.938 .55644 Mdot
.938 .55718 Mdot
.938 .5602 Mdot
.938 .56033 Mdot
.938 .56068 Mdot
.938 .56252 Mdot
.938 .56343 Mdot
.938 .56591 Mdot
.938 .56897 Mdot
.938 .56925 Mdot
.94 .01539 Mdot
.94 .01599 Mdot
.94 .01676 Mdot
.94 .017 Mdot
.94 .01701 Mdot
.94 .01711 Mdot
.94 .01852 Mdot
.94 .01855 Mdot
.94 .0188 Mdot
.94 .01901 Mdot
.94 .01903 Mdot
.94 .01922 Mdot
.94 .01928 Mdot
.94 .02 Mdot
.94 .02187 Mdot
.94 .02193 Mdot
.94 .02239 Mdot
.94 .02278 Mdot
.94 .02282 Mdot
.94 .02318 Mdot
.94 .02329 Mdot
.94 .02415 Mdot
.94 .02464 Mdot
.94 .02627 Mdot
.94 .02638 Mdot
.94 .02721 Mdot
.94 .02816 Mdot
.94 .02827 Mdot
.94 .02851 Mdot
.94 .02915 Mdot
.94 .02963 Mdot
.94 .02988 Mdot
.94 .02995 Mdot
.94 .03048 Mdot
.94 .03063 Mdot
.94 .03084 Mdot
.94 .03234 Mdot
.94 .03245 Mdot
.94 .03302 Mdot
.94 .03338 Mdot
.94 .03362 Mdot
.94 .03379 Mdot
.94 .03419 Mdot
.94 .03645 Mdot
.94 .03664 Mdot
.94 .03805 Mdot
.94 .03821 Mdot
.94 .03938 Mdot
.94 .04 Mdot
.94 .0402 Mdot
.94 .04065 Mdot
.94 .04118 Mdot
.94 .04185 Mdot
.94 .04275 Mdot
.94 .04312 Mdot
.94 .04323 Mdot
.94 .04336 Mdot
.94 .04385 Mdot
.94 .04428 Mdot
.94 .04435 Mdot
.94 .04464 Mdot
.94 .04503 Mdot
.94 .04723 Mdot
.94 .04785 Mdot
.94 .04807 Mdot
.94 .04912 Mdot
.94 .0498 Mdot
.94 .05025 Mdot
.94 .05036 Mdot
.94 .05057 Mdot
.94 .05129 Mdot
.94 .05133 Mdot
.94 .05257 Mdot
.94 .05276 Mdot
.94 .05557 Mdot
.94 .05593 Mdot
.94 .05606 Mdot
.94 .05665 Mdot
.94 .05746 Mdot
.94 .05858 Mdot
.94 .05858 Mdot
.94 .05889 Mdot
.94 .0594 Mdot
.94 .06014 Mdot
.94 .06108 Mdot
.94 .06224 Mdot
.94 .06257 Mdot
.94 .06264 Mdot
.94 .06346 Mdot
.94 .06441 Mdot
.94 .06448 Mdot
.94 .06574 Mdot
.94 .06742 Mdot
.94 .0678 Mdot
.94 .06812 Mdot
.94 .06829 Mdot
.94 .06831 Mdot
.94 .06857 Mdot
.94 .06949 Mdot
.94 .0703 Mdot
.94 .07043 Mdot
.94 .07068 Mdot
.94 .07097 Mdot
.94 .07171 Mdot
.94 .07176 Mdot
.94 .07584 Mdot
.94 .07605 Mdot
.94 .07643 Mdot
.94 .077 Mdot
.94 .07712 Mdot
.94 .07741 Mdot
.94 .07777 Mdot
.94 .07826 Mdot
.94 .0783 Mdot
.94 .07903 Mdot
.94 .07939 Mdot
.94 .07954 Mdot
.94 .07967 Mdot
.94 .07998 Mdot
.94 .08045 Mdot
.94 .08068 Mdot
.94 .08152 Mdot
.94 .08173 Mdot
.94 .08203 Mdot
.94 .08212 Mdot
.94 .08347 Mdot
.94 .08355 Mdot
.94 .0845 Mdot
.94 .08492 Mdot
.94 .08587 Mdot
.94 .08623 Mdot
.94 .08692 Mdot
.94 .08844 Mdot
.94 .08873 Mdot
.94 .08885 Mdot
.94 .08925 Mdot
.94 .0899 Mdot
.94 .09027 Mdot
.94 .09152 Mdot
.94 .0922 Mdot
.94 .09244 Mdot
.94 .09333 Mdot
.94 .09356 Mdot
.94 .09391 Mdot
.94 .09508 Mdot
.94 .09523 Mdot
.94 .09621 Mdot
.94 .09689 Mdot
.94 .09718 Mdot
.94 .09719 Mdot
.94 .09764 Mdot
.94 .09777 Mdot
.94 .09848 Mdot
.94 .09872 Mdot
.94 .10011 Mdot
.94 .10113 Mdot
.94 .10122 Mdot
.94 .10188 Mdot
.94 .10407 Mdot
.94 .10468 Mdot
.94 .10481 Mdot
.94 .10636 Mdot
.94 .10766 Mdot
.94 .10794 Mdot
.94 .10794 Mdot
.94 .10813 Mdot
.94 .10815 Mdot
.94 .10827 Mdot
.94 .10951 Mdot
.94 .11029 Mdot
.94 .11064 Mdot
.94 .11098 Mdot
.94 .11139 Mdot
.94 .11243 Mdot
.94 .1138 Mdot
.94 .11451 Mdot
.94 .11465 Mdot
.94 .11512 Mdot
.94 .11544 Mdot
.94 .11548 Mdot
.94 .11596 Mdot
.94 .1162 Mdot
.94 .11724 Mdot
.94 .11769 Mdot
.94 .11826 Mdot
.94 .11921 Mdot
.94 .11946 Mdot
.94 .1195 Mdot
.94 .11993 Mdot
.94 .12048 Mdot
.94 .12186 Mdot
.94 .12195 Mdot
.94 .12197 Mdot
.94 .12203 Mdot
.94 .12204 Mdot
.94 .12285 Mdot
.94 .12432 Mdot
.94 .12601 Mdot
.94 .12751 Mdot
.94 .12815 Mdot
.94 .1284 Mdot
.94 .12842 Mdot
.94 .12963 Mdot
.94 .12964 Mdot
.94 .13003 Mdot
.94 .13073 Mdot
.94 .13078 Mdot
.94 .13084 Mdot
.94 .13157 Mdot
.94 .13182 Mdot
.94 .13204 Mdot
.94 .13259 Mdot
.94 .13319 Mdot
.94 .13326 Mdot
.94 .13417 Mdot
.94 .13418 Mdot
.94 .13426 Mdot
.94 .13451 Mdot
.94 .13468 Mdot
.94 .13473 Mdot
.94 .13563 Mdot
.94 .13631 Mdot
.94 .13659 Mdot
.94 .13682 Mdot
.94 .13742 Mdot
.94 .13755 Mdot
.94 .13779 Mdot
.94 .13829 Mdot
.94 .13872 Mdot
.94 .13896 Mdot
.94 .14006 Mdot
.94 .14009 Mdot
.94 .1403 Mdot
.94 .1407 Mdot
.94 .14127 Mdot
.94 .14144 Mdot
.94 .1422 Mdot
.94 .14283 Mdot
.94 .14306 Mdot
.94 .14318 Mdot
.94 .14324 Mdot
.94 .14329 Mdot
.94 .14398 Mdot
.94 .14413 Mdot
.94 .14515 Mdot
.94 .14592 Mdot
.94 .14651 Mdot
.94 .1467 Mdot
.94 .14685 Mdot
.94 .14849 Mdot
.94 .14917 Mdot
.94 .15031 Mdot
.94 .15046 Mdot
.94 .1519 Mdot
.94 .15216 Mdot
.94 .15313 Mdot
.94 .15316 Mdot
.94 .15331 Mdot
.94 .15385 Mdot
.94 .15409 Mdot
.94 .15413 Mdot
.94 .1547 Mdot
.94 .15479 Mdot
.94 .15481 Mdot
.94 .15485 Mdot
.94 .15513 Mdot
.94 .15539 Mdot
.94 .15606 Mdot
.94 .15675 Mdot
.94 .15794 Mdot
.94 .15818 Mdot
.94 .1588 Mdot
.94 .1591 Mdot
.94 .1597 Mdot
.94 .1604 Mdot
.94 .16085 Mdot
.94 .16159 Mdot
.94 .16187 Mdot
.94 .16246 Mdot
.94 .16252 Mdot
.94 .16295 Mdot
.94 .16354 Mdot
.94 .1636 Mdot
.94 .16364 Mdot
.94 .16379 Mdot
.94 .16401 Mdot
.94 .16428 Mdot
.94 .1645 Mdot
.94 .1658 Mdot
.94 .16608 Mdot
.94 .16737 Mdot
.94 .16778 Mdot
.94 .16793 Mdot
.94 .1681 Mdot
.94 .1692 Mdot
.94 .16974 Mdot
.94 .16976 Mdot
.94 .17061 Mdot
.94 .1708 Mdot
.94 .17086 Mdot
.94 .17111 Mdot
.94 .17138 Mdot
.94 .17149 Mdot
.94 .17188 Mdot
.94 .17197 Mdot
.94 .17218 Mdot
.94 .17264 Mdot
.94 .17526 Mdot
.94 .17553 Mdot
.94 .17621 Mdot
.94 .17717 Mdot
.94 .17734 Mdot
.94 .17739 Mdot
.94 .17859 Mdot
.94 .17948 Mdot
.94 .1827 Mdot
.94 .18369 Mdot
.94 .18386 Mdot
.94 .18409 Mdot
.94 .18701 Mdot
.94 .18715 Mdot
.94 .18813 Mdot
.94 .18935 Mdot
.94 .18945 Mdot
.94 .18997 Mdot
.94 .18998 Mdot
.94 .19033 Mdot
.94 .19037 Mdot
.94 .19059 Mdot
.94 .19104 Mdot
.94 .19285 Mdot
.94 .19293 Mdot
.94 .19308 Mdot
.94 .1944 Mdot
.94 .19477 Mdot
.94 .19505 Mdot
.94 .19524 Mdot
.94 .19569 Mdot
.94 .19647 Mdot
.94 .19837 Mdot
.94 .19842 Mdot
.94 .201 Mdot
.94 .20164 Mdot
.94 .20233 Mdot
.94 .20236 Mdot
.94 .20259 Mdot
.94 .203 Mdot
.94 .20348 Mdot
.94 .20409 Mdot
.94 .20416 Mdot
.94 .20505 Mdot
.94 .20551 Mdot
.94 .20589 Mdot
.94 .20595 Mdot
.94 .20746 Mdot
.94 .2083 Mdot
.94 .20834 Mdot
.94 .20928 Mdot
.94 .20938 Mdot
.94 .21116 Mdot
.94 .2116 Mdot
.94 .21163 Mdot
.94 .21172 Mdot
.94 .21252 Mdot
.94 .21258 Mdot
.94 .21276 Mdot
.94 .21301 Mdot
.94 .21355 Mdot
.94 .21363 Mdot
.94 .21423 Mdot
.94 .21437 Mdot
.94 .21518 Mdot
.94 .21615 Mdot
.94 .21632 Mdot
.94 .21635 Mdot
.94 .21646 Mdot
.94 .21648 Mdot
.94 .21749 Mdot
.94 .21802 Mdot
.94 .2198 Mdot
.94 .22078 Mdot
.94 .2214 Mdot
.94 .22239 Mdot
.94 .22246 Mdot
.94 .22395 Mdot
.94 .22488 Mdot
.94 .22508 Mdot
.94 .22677 Mdot
.94 .22798 Mdot
.94 .22803 Mdot
.94 .2281 Mdot
.94 .22844 Mdot
.94 .22848 Mdot
.94 .22871 Mdot
.94 .22972 Mdot
.94 .23002 Mdot
.94 .23047 Mdot
.94 .23075 Mdot
.94 .23077 Mdot
.94 .23151 Mdot
.94 .23237 Mdot
.94 .23254 Mdot
.94 .23283 Mdot
.94 .23291 Mdot
.94 .23304 Mdot
.94 .23362 Mdot
.94 .23439 Mdot
.94 .23487 Mdot
.94 .23527 Mdot
.94 .23528 Mdot
.94 .23632 Mdot
.94 .23696 Mdot
.94 .23745 Mdot
.94 .23757 Mdot
.94 .23835 Mdot
.94 .2384 Mdot
.94 .23925 Mdot
.94 .2393 Mdot
.94 .23932 Mdot
.94 .23945 Mdot
.94 .23994 Mdot
.94 .24025 Mdot
.94 .24033 Mdot
.94 .24203 Mdot
.94 .24206 Mdot
.94 .24332 Mdot
.94 .24384 Mdot
.94 .24428 Mdot
.94 .24432 Mdot
.94 .24539 Mdot
.94 .24564 Mdot
.94 .24605 Mdot
.94 .2461 Mdot
.94 .2465 Mdot
.94 .24704 Mdot
.94 .24785 Mdot
.94 .2483 Mdot
.94 .24854 Mdot
.94 .24924 Mdot
.94 .24943 Mdot
.94 .25036 Mdot
.94 .25041 Mdot
.94 .25082 Mdot
.94 .25157 Mdot
.94 .25203 Mdot
.94 .25244 Mdot
.94 .2526 Mdot
.94 .25264 Mdot
.94 .25267 Mdot
.94 .25296 Mdot
.94 .25315 Mdot
.94 .25421 Mdot
.94 .25439 Mdot
.94 .25486 Mdot
.94 .25546 Mdot
.94 .25557 Mdot
.94 .25596 Mdot
.94 .256 Mdot
.94 .25622 Mdot
.94 .25627 Mdot
.94 .25634 Mdot
.94 .25644 Mdot
.94 .25773 Mdot
.94 .25802 Mdot
.94 .25936 Mdot
.94 .25993 Mdot
.94 .2601 Mdot
.94 .26138 Mdot
.94 .26225 Mdot
.94 .26237 Mdot
.94 .26249 Mdot
.94 .26285 Mdot
.94 .26313 Mdot
.94 .26514 Mdot
.94 .26547 Mdot
.94 .26615 Mdot
.94 .26622 Mdot
.94 .26681 Mdot
.94 .26748 Mdot
.94 .26866 Mdot
.94 .26964 Mdot
.94 .26992 Mdot
.94 .2702 Mdot
.94 .27036 Mdot
.94 .27263 Mdot
.94 .27295 Mdot
.94 .27312 Mdot
.94 .2737 Mdot
.94 .27414 Mdot
.94 .27417 Mdot
.94 .27493 Mdot
.94 .27499 Mdot
.94 .275 Mdot
.94 .27528 Mdot
.94 .27606 Mdot
.94 .2763 Mdot
.94 .27648 Mdot
.94 .27663 Mdot
.94 .27673 Mdot
.94 .27682 Mdot
.94 .27788 Mdot
.94 .27805 Mdot
.94 .27806 Mdot
.94 .27809 Mdot
.94 .27816 Mdot
.94 .27869 Mdot
.94 .27873 Mdot
.94 .27919 Mdot
.94 .27995 Mdot
.94 .28045 Mdot
.94 .28175 Mdot
.94 .28219 Mdot
.94 .28275 Mdot
.94 .28282 Mdot
.94 .28399 Mdot
.94 .28442 Mdot
.94 .28443 Mdot
.94 .28493 Mdot
.94 .28528 Mdot
.94 .28559 Mdot
.94 .28617 Mdot
.94 .28728 Mdot
.94 .28775 Mdot
.94 .28841 Mdot
.94 .2886 Mdot
.94 .28944 Mdot
.94 .29084 Mdot
.94 .29137 Mdot
.94 .29169 Mdot
.94 .29188 Mdot
.94 .29247 Mdot
.94 .29258 Mdot
.94 .29334 Mdot
.94 .29339 Mdot
.94 .29349 Mdot
.94 .29451 Mdot
.94 .29463 Mdot
.94 .2947 Mdot
.94 .29498 Mdot
.94 .29538 Mdot
.94 .2959 Mdot
.94 .29599 Mdot
.94 .29632 Mdot
.94 .29761 Mdot
.94 .29875 Mdot
.94 .29904 Mdot
.94 .29928 Mdot
.94 .29961 Mdot
.94 .29977 Mdot
.94 .29985 Mdot
.94 .3009 Mdot
.94 .30108 Mdot
.94 .30156 Mdot
.94 .30171 Mdot
.94 .30248 Mdot
.94 .30275 Mdot
.94 .303 Mdot
.94 .30308 Mdot
.94 .30463 Mdot
.94 .30514 Mdot
.94 .3053 Mdot
.94 .30593 Mdot
.94 .30617 Mdot
.94 .3062 Mdot
.94 .30679 Mdot
.94 .30761 Mdot
.94 .3078 Mdot
.94 .30786 Mdot
.94 .30815 Mdot
.94 .30827 Mdot
.94 .30844 Mdot
.94 .30874 Mdot
.94 .30925 Mdot
.94 .30945 Mdot
.94 .30971 Mdot
.94 .3101 Mdot
.94 .31019 Mdot
.94 .31035 Mdot
.94 .31076 Mdot
.94 .31148 Mdot
.94 .31161 Mdot
.94 .31162 Mdot
.94 .31242 Mdot
.94 .31257 Mdot
.94 .31282 Mdot
.94 .3132 Mdot
.94 .31542 Mdot
.94 .31654 Mdot
.94 .3166 Mdot
.94 .31705 Mdot
.94 .31773 Mdot
.94 .31833 Mdot
.94 .31878 Mdot
.94 .31977 Mdot
.94 .32013 Mdot
.94 .32045 Mdot
.94 .32054 Mdot
.94 .32076 Mdot
.94 .32281 Mdot
.94 .32351 Mdot
.94 .32448 Mdot
.94 .32551 Mdot
.94 .32589 Mdot
.94 .32612 Mdot
.94 .32769 Mdot
.94 .32936 Mdot
.94 .32985 Mdot
.94 .33053 Mdot
.94 .33063 Mdot
.94 .33239 Mdot
.94 .3327 Mdot
.94 .33313 Mdot
.94 .33373 Mdot
.94 .33416 Mdot
.94 .33456 Mdot
.94 .33585 Mdot
.94 .33683 Mdot
.94 .33863 Mdot
.94 .3389 Mdot
.94 .34016 Mdot
.94 .34074 Mdot
.94 .34302 Mdot
.94 .34322 Mdot
.94 .34359 Mdot
.94 .34394 Mdot
.94 .34419 Mdot
.94 .34422 Mdot
.94 .34461 Mdot
.94 .34488 Mdot
.94 .34494 Mdot
.94 .34511 Mdot
.94 .34536 Mdot
.94 .3462 Mdot
.94 .34752 Mdot
.94 .34774 Mdot
.94 .3488 Mdot
.94 .34961 Mdot
.94 .34976 Mdot
.94 .34983 Mdot
.94 .35004 Mdot
.94 .35039 Mdot
.94 .35058 Mdot
.94 .35221 Mdot
.94 .35252 Mdot
.94 .35322 Mdot
.94 .35374 Mdot
.94 .3541 Mdot
.94 .3545 Mdot
.94 .35495 Mdot
.94 .35636 Mdot
.94 .35641 Mdot
.94 .35984 Mdot
.94 .35998 Mdot
.94 .35999 Mdot
.94 .36008 Mdot
.94 .36082 Mdot
.94 .36123 Mdot
.94 .3616 Mdot
.94 .36182 Mdot
.94 .36237 Mdot
.94 .36355 Mdot
.94 .36438 Mdot
.94 .36493 Mdot
.94 .36547 Mdot
.94 .36614 Mdot
.94 .36744 Mdot
.94 .36748 Mdot
.94 .36748 Mdot
.94 .36792 Mdot
.94 .3687 Mdot
.94 .3696 Mdot
.94 .37039 Mdot
.94 .37073 Mdot
.94 .37087 Mdot
.94 .37088 Mdot
.94 .37153 Mdot
.94 .37213 Mdot
.94 .37217 Mdot
.94 .37255 Mdot
.94 .37341 Mdot
.94 .37394 Mdot
.94 .37412 Mdot
.94 .37421 Mdot
.94 .37423 Mdot
.94 .37573 Mdot
.94 .37586 Mdot
.94 .37649 Mdot
.94 .37707 Mdot
.94 .37708 Mdot
.94 .37821 Mdot
.94 .37854 Mdot
.94 .37866 Mdot
.94 .37873 Mdot
.94 .37876 Mdot
.94 .37879 Mdot
.94 .37977 Mdot
.94 .3805 Mdot
.94 .38068 Mdot
.94 .38252 Mdot
.94 .38337 Mdot
.94 .38402 Mdot
.94 .38404 Mdot
.94 .38455 Mdot
.94 .38486 Mdot
.94 .38491 Mdot
.94 .38491 Mdot
.94 .38508 Mdot
.94 .38522 Mdot
.94 .38658 Mdot
.94 .38671 Mdot
.94 .38703 Mdot
.94 .38751 Mdot
.94 .38852 Mdot
.94 .38867 Mdot
.94 .38898 Mdot
.94 .38956 Mdot
.94 .38961 Mdot
.94 .38969 Mdot
.94 .38981 Mdot
.94 .38995 Mdot
.94 .39007 Mdot
.94 .3916 Mdot
.94 .39181 Mdot
.94 .39198 Mdot
.94 .39342 Mdot
.94 .39359 Mdot
.94 .39373 Mdot
.94 .39379 Mdot
.94 .39399 Mdot
.94 .39404 Mdot
.94 .39594 Mdot
.94 .3963 Mdot
.94 .39692 Mdot
.94 .39804 Mdot
.94 .40028 Mdot
.94 .40212 Mdot
.94 .40264 Mdot
.94 .40329 Mdot
.94 .40419 Mdot
.94 .40515 Mdot
.94 .40527 Mdot
.94 .40617 Mdot
.94 .40642 Mdot
.94 .40808 Mdot
.94 .40982 Mdot
.94 .41021 Mdot
.94 .41055 Mdot
.94 .41208 Mdot
.94 .41212 Mdot
.94 .41339 Mdot
.94 .41389 Mdot
.94 .41512 Mdot
.94 .41565 Mdot
.94 .41574 Mdot
.94 .41587 Mdot
.94 .4162 Mdot
.94 .41652 Mdot
.94 .4166 Mdot
.94 .41703 Mdot
.94 .41826 Mdot
.94 .41893 Mdot
.94 .41948 Mdot
.94 .42034 Mdot
.94 .42086 Mdot
.94 .4209 Mdot
.94 .42219 Mdot
.94 .42229 Mdot
.94 .42386 Mdot
.94 .4239 Mdot
.94 .42422 Mdot
.94 .42476 Mdot
.94 .42492 Mdot
.94 .42516 Mdot
.94 .42617 Mdot
.94 .42626 Mdot
.94 .42684 Mdot
.94 .42771 Mdot
.94 .42861 Mdot
.94 .42935 Mdot
.94 .42938 Mdot
.94 .42983 Mdot
.94 .43133 Mdot
.94 .43253 Mdot
.94 .43345 Mdot
.94 .43368 Mdot
.94 .43477 Mdot
.94 .43515 Mdot
.94 .43524 Mdot
.94 .43663 Mdot
.94 .43684 Mdot
.94 .43693 Mdot
.94 .43697 Mdot
.94 .43722 Mdot
.94 .43779 Mdot
.94 .43813 Mdot
.94 .43845 Mdot
.94 .43872 Mdot
.94 .43888 Mdot
.94 .44053 Mdot
.94 .44092 Mdot
.94 .44206 Mdot
.94 .44213 Mdot
.94 .4436 Mdot
.94 .44378 Mdot
.94 .44414 Mdot
.94 .44449 Mdot
.94 .44547 Mdot
.94 .44629 Mdot
.94 .44638 Mdot
.94 .44775 Mdot
.94 .44816 Mdot
.94 .44839 Mdot
.94 .44841 Mdot
.94 .44885 Mdot
.94 .44941 Mdot
.94 .44963 Mdot
.94 .44971 Mdot
.94 .45047 Mdot
.94 .45083 Mdot
.94 .45148 Mdot
.94 .45267 Mdot
.94 .45297 Mdot
.94 .453 Mdot
.94 .45386 Mdot
.94 .45413 Mdot
.94 .45431 Mdot
.94 .45563 Mdot
.94 .45598 Mdot
.94 .45772 Mdot
.94 .45782 Mdot
.94 .4586 Mdot
.94 .45868 Mdot
.94 .46001 Mdot
.94 .46087 Mdot
.94 .46163 Mdot
.94 .46193 Mdot
.94 .46202 Mdot
.94 .46207 Mdot
.94 .46262 Mdot
.94 .46272 Mdot
.94 .46297 Mdot
.94 .46374 Mdot
.94 .46461 Mdot
.94 .46496 Mdot
.94 .4653 Mdot
.94 .46575 Mdot
.94 .46619 Mdot
.94 .46632 Mdot
.94 .46663 Mdot
.94 .46731 Mdot
.94 .46751 Mdot
.94 .46825 Mdot
.94 .46832 Mdot
.94 .46875 Mdot
.94 .46883 Mdot
.94 .46896 Mdot
.94 .46917 Mdot
.94 .47034 Mdot
.94 .47097 Mdot
.94 .47158 Mdot
.94 .47213 Mdot
.94 .47266 Mdot
.94 .47318 Mdot
.94 .47465 Mdot
.94 .47571 Mdot
.94 .47592 Mdot
.94 .47604 Mdot
.94 .47687 Mdot
.94 .47776 Mdot
.94 .47802 Mdot
.94 .47844 Mdot
.94 .48008 Mdot
.94 .48032 Mdot
.94 .48053 Mdot
.94 .48121 Mdot
.94 .48173 Mdot
.94 .48351 Mdot
.94 .48533 Mdot
.94 .48551 Mdot
.94 .48587 Mdot
.94 .48614 Mdot
.94 .48742 Mdot
.94 .48754 Mdot
.94 .4881 Mdot
.94 .48865 Mdot
.94 .48895 Mdot
.94 .48905 Mdot
.94 .48992 Mdot
.94 .49114 Mdot
.94 .49212 Mdot
.94 .49397 Mdot
.94 .49405 Mdot
.94 .49449 Mdot
.94 .49472 Mdot
.94 .49491 Mdot
.94 .49503 Mdot
.94 .49532 Mdot
.94 .49595 Mdot
.94 .49639 Mdot
.94 .49697 Mdot
.94 .49804 Mdot
.94 .49959 Mdot
.94 .49984 Mdot
.94 .50019 Mdot
.94 .50051 Mdot
.94 .50053 Mdot
.94 .50148 Mdot
.94 .50162 Mdot
.94 .50243 Mdot
.94 .5025 Mdot
.94 .50283 Mdot
.94 .50314 Mdot
.94 .50374 Mdot
.94 .50392 Mdot
.94 .50404 Mdot
.94 .50405 Mdot
.94 .50458 Mdot
.94 .50604 Mdot
.94 .50649 Mdot
.94 .50683 Mdot
.94 .50712 Mdot
.94 .50731 Mdot
.94 .50748 Mdot
.94 .50947 Mdot
.94 .50978 Mdot
.94 .50981 Mdot
.94 .50985 Mdot
.94 .50999 Mdot
.94 .51098 Mdot
.94 .51107 Mdot
.94 .51192 Mdot
.94 .51337 Mdot
.94 .51429 Mdot
.94 .51674 Mdot
.94 .51756 Mdot
.94 .51862 Mdot
.94 .51875 Mdot
.94 .52095 Mdot
.94 .52176 Mdot
.94 .52178 Mdot
.94 .52272 Mdot
.94 .52338 Mdot
.94 .52395 Mdot
.94 .52505 Mdot
.94 .52714 Mdot
.94 .52803 Mdot
.94 .52925 Mdot
.94 .52961 Mdot
.94 .5312 Mdot
.94 .53383 Mdot
.94 .53482 Mdot
.94 .53543 Mdot
.94 .53579 Mdot
.94 .53689 Mdot
.94 .5371 Mdot
.94 .53853 Mdot
.94 .53862 Mdot
.94 .53881 Mdot
.94 .54074 Mdot
.94 .54095 Mdot
.94 .54108 Mdot
.94 .54162 Mdot
.94 .54237 Mdot
.94 .54335 Mdot
.94 .54351 Mdot
.94 .54413 Mdot
.94 .54655 Mdot
.94 .5487 Mdot
.94 .54924 Mdot
.94 .5497 Mdot
.94 .55031 Mdot
.94 .55061 Mdot
.94 .55078 Mdot
.94 .55275 Mdot
.94 .55309 Mdot
.94 .55398 Mdot
.94 .55426 Mdot
.94 .55572 Mdot
.94 .55622 Mdot
.94 .5567 Mdot
.94 .55684 Mdot
.94 .55975 Mdot
.94 .56072 Mdot
.94 .56101 Mdot
.94 .5622 Mdot
.94 .56265 Mdot
.94 .5627 Mdot
.94 .56381 Mdot
.94 .56536 Mdot
.94 .56572 Mdot
.94 .56582 Mdot
.94 .56637 Mdot
.94 .5666 Mdot
.94 .56691 Mdot
.94 .56748 Mdot
.94 .56844 Mdot
.94 .56881 Mdot
.94 .56931 Mdot
.94 .57003 Mdot
.94 .5702 Mdot
.94 .57052 Mdot
.942 .01561 Mdot
.942 .01613 Mdot
.942 .01641 Mdot
.942 .01737 Mdot
.942 .01739 Mdot
.942 .0176 Mdot
.942 .0179 Mdot
.942 .01972 Mdot
.942 .01976 Mdot
.942 .02015 Mdot
.942 .02072 Mdot
.942 .02415 Mdot
.942 .02415 Mdot
.942 .02422 Mdot
.942 .02495 Mdot
.942 .02602 Mdot
.942 .02612 Mdot
.942 .02746 Mdot
.942 .02763 Mdot
.942 .02772 Mdot
.942 .02775 Mdot
.942 .02857 Mdot
.942 .03098 Mdot
.942 .03169 Mdot
.942 .03249 Mdot
.942 .03249 Mdot
.942 .03263 Mdot
.942 .03279 Mdot
.942 .03335 Mdot
.942 .03395 Mdot
.942 .03401 Mdot
.942 .03408 Mdot
.942 .0351 Mdot
.942 .03601 Mdot
.942 .03602 Mdot
.942 .03621 Mdot
.942 .03626 Mdot
.942 .03649 Mdot
.942 .03873 Mdot
.942 .03899 Mdot
.942 .03904 Mdot
.942 .03921 Mdot
.942 .03927 Mdot
.942 .03944 Mdot
.942 .03944 Mdot
.942 .0399 Mdot
.942 .04048 Mdot
.942 .04081 Mdot
.942 .04141 Mdot
.942 .04305 Mdot
.942 .04441 Mdot
.942 .04462 Mdot
.942 .04534 Mdot
.942 .04536 Mdot
.942 .04639 Mdot
.942 .0467 Mdot
.942 .04712 Mdot
.942 .04804 Mdot
.942 .04821 Mdot
.942 .04821 Mdot
.942 .04846 Mdot
.942 .04877 Mdot
.942 .0492 Mdot
.942 .04952 Mdot
.942 .04982 Mdot
.942 .04983 Mdot
.942 .04994 Mdot
.942 .05032 Mdot
.942 .05095 Mdot
.942 .05105 Mdot
.942 .05106 Mdot
.942 .05119 Mdot
.942 .05218 Mdot
.942 .05258 Mdot
.942 .05306 Mdot
.942 .05313 Mdot
.942 .05352 Mdot
.942 .0537 Mdot
.942 .05484 Mdot
.942 .05486 Mdot
.942 .05507 Mdot
.942 .0552 Mdot
.942 .05531 Mdot
.942 .05533 Mdot
.942 .05574 Mdot
.942 .05605 Mdot
.942 .0563 Mdot
.942 .05914 Mdot
.942 .05916 Mdot
.942 .05997 Mdot
.942 .06046 Mdot
.942 .06055 Mdot
.942 .06086 Mdot
.942 .06098 Mdot
.942 .06118 Mdot
.942 .06129 Mdot
.942 .0613 Mdot
.942 .06194 Mdot
.942 .06216 Mdot
.942 .06221 Mdot
.942 .06326 Mdot
.942 .06363 Mdot
.942 .06388 Mdot
.942 .06501 Mdot
.942 .06774 Mdot
.942 .0681 Mdot
.942 .06816 Mdot
.942 .06925 Mdot
.942 .0701 Mdot
.942 .07067 Mdot
.942 .07105 Mdot
.942 .07242 Mdot
.942 .07244 Mdot
.942 .07389 Mdot
.942 .07413 Mdot
.942 .0744 Mdot
.942 .07498 Mdot
.942 .07577 Mdot
.942 .07701 Mdot
.942 .07749 Mdot
.942 .07781 Mdot
.942 .07782 Mdot
.942 .07811 Mdot
.942 .0783 Mdot
.942 .07888 Mdot
.942 .07961 Mdot
.942 .07968 Mdot
.942 .07992 Mdot
.942 .0803 Mdot
.942 .08085 Mdot
.942 .08088 Mdot
.942 .08108 Mdot
.942 .08179 Mdot
.942 .08298 Mdot
.942 .08316 Mdot
.942 .08319 Mdot
.942 .08332 Mdot
.942 .08344 Mdot
.942 .08529 Mdot
.942 .08604 Mdot
.942 .08696 Mdot
.942 .08708 Mdot
.942 .08754 Mdot
.942 .08783 Mdot
.942 .08817 Mdot
.942 .08849 Mdot
.942 .08867 Mdot
.942 .09031 Mdot
.942 .09034 Mdot
.942 .09075 Mdot
.942 .091 Mdot
.942 .0912 Mdot
.942 .09124 Mdot
.942 .09133 Mdot
.942 .09194 Mdot
.942 .092 Mdot
.942 .09259 Mdot
.942 .09307 Mdot
.942 .09842 Mdot
.942 .09845 Mdot
.942 .09996 Mdot
.942 .09997 Mdot
.942 .10089 Mdot
.942 .10091 Mdot
.942 .10107 Mdot
.942 .1012 Mdot
.942 .10165 Mdot
.942 .10171 Mdot
.942 .10187 Mdot
.942 .10226 Mdot
.942 .10246 Mdot
.942 .10249 Mdot
.942 .103 Mdot
.942 .10329 Mdot
.942 .10368 Mdot
.942 .10405 Mdot
.942 .10409 Mdot
.942 .1042 Mdot
.942 .10497 Mdot
.942 .10595 Mdot
.942 .10617 Mdot
.942 .1063 Mdot
.942 .10687 Mdot
.942 .1069 Mdot
.942 .10733 Mdot
.942 .10948 Mdot
.942 .11091 Mdot
.942 .11166 Mdot
.942 .11318 Mdot
.942 .11397 Mdot
.942 .11428 Mdot
.942 .11461 Mdot
.942 .11504 Mdot
.942 .1153 Mdot
.942 .1154 Mdot
.942 .11613 Mdot
.942 .11622 Mdot
.942 .11745 Mdot
.942 .11827 Mdot
.942 .11907 Mdot
.942 .11934 Mdot
.942 .12012 Mdot
.942 .12086 Mdot
.942 .12142 Mdot
.942 .12295 Mdot
.942 .12342 Mdot
.942 .12348 Mdot
.942 .12349 Mdot
.942 .12374 Mdot
.942 .12456 Mdot
.942 .12537 Mdot
.942 .12564 Mdot
.942 .12585 Mdot
.942 .12619 Mdot
.942 .12638 Mdot
.942 .12644 Mdot
.942 .12651 Mdot
.942 .12664 Mdot
.942 .12716 Mdot
.942 .12825 Mdot
.942 .12854 Mdot
.942 .12975 Mdot
.942 .13027 Mdot
.942 .13028 Mdot
.942 .1309 Mdot
.942 .13092 Mdot
.942 .13207 Mdot
.942 .13234 Mdot
.942 .13253 Mdot
.942 .13266 Mdot
.942 .13298 Mdot
.942 .13337 Mdot
.942 .13359 Mdot
.942 .1336 Mdot
.942 .13381 Mdot
.942 .13398 Mdot
.942 .13416 Mdot
.942 .13451 Mdot
.942 .13472 Mdot
.942 .1356 Mdot
.942 .13585 Mdot
.942 .13616 Mdot
.942 .13644 Mdot
.942 .13666 Mdot
.942 .13698 Mdot
.942 .13711 Mdot
.942 .13712 Mdot
.942 .13756 Mdot
.942 .13827 Mdot
.942 .13932 Mdot
.942 .13936 Mdot
.942 .13974 Mdot
.942 .14027 Mdot
.942 .14031 Mdot
.942 .14108 Mdot
.942 .14333 Mdot
.942 .14358 Mdot
.942 .14367 Mdot
.942 .14371 Mdot
.942 .14396 Mdot
.942 .1442 Mdot
.942 .14435 Mdot
.942 .14467 Mdot
.942 .14528 Mdot
.942 .14768 Mdot
.942 .1491 Mdot
.942 .14926 Mdot
.942 .15014 Mdot
.942 .15029 Mdot
.942 .15083 Mdot
.942 .15106 Mdot
.942 .15165 Mdot
.942 .15169 Mdot
.942 .15176 Mdot
.942 .15191 Mdot
.942 .15246 Mdot
.942 .15311 Mdot
.942 .15371 Mdot
.942 .15372 Mdot
.942 .15383 Mdot
.942 .154 Mdot
.942 .15405 Mdot
.942 .15549 Mdot
.942 .15611 Mdot
.942 .15669 Mdot
.942 .15713 Mdot
.942 .15719 Mdot
.942 .15733 Mdot
.942 .15797 Mdot
.942 .15843 Mdot
.942 .15881 Mdot
.942 .15889 Mdot
.942 .15906 Mdot
.942 .15928 Mdot
.942 .15939 Mdot
.942 .16021 Mdot
.942 .16032 Mdot
.942 .16082 Mdot
.942 .16085 Mdot
.942 .16117 Mdot
.942 .16144 Mdot
.942 .16234 Mdot
.942 .16235 Mdot
.942 .16255 Mdot
.942 .16295 Mdot
.942 .16356 Mdot
.942 .16746 Mdot
.942 .1712 Mdot
.942 .17241 Mdot
.942 .17247 Mdot
.942 .17525 Mdot
.942 .17532 Mdot
.942 .17533 Mdot
.942 .17624 Mdot
.942 .17708 Mdot
.942 .17711 Mdot
.942 .1774 Mdot
.942 .17766 Mdot
.942 .1785 Mdot
.942 .17862 Mdot
.942 .17892 Mdot
.942 .17964 Mdot
.942 .18003 Mdot
.942 .18008 Mdot
.942 .18058 Mdot
.942 .18079 Mdot
.942 .18105 Mdot
.942 .18147 Mdot
.942 .18158 Mdot
.942 .18169 Mdot
.942 .18189 Mdot
.942 .18221 Mdot
.942 .18232 Mdot
.942 .18303 Mdot
.942 .1831 Mdot
.942 .1833 Mdot
.942 .18461 Mdot
.942 .18475 Mdot
.942 .18496 Mdot
.942 .18504 Mdot
.942 .18544 Mdot
.942 .1866 Mdot
.942 .18671 Mdot
.942 .18702 Mdot
.942 .18726 Mdot
.942 .18833 Mdot
.942 .1884 Mdot
.942 .18921 Mdot
.942 .18952 Mdot
.942 .19003 Mdot
.942 .19218 Mdot
.942 .19324 Mdot
.942 .19594 Mdot
.942 .19683 Mdot
.942 .19736 Mdot
.942 .19746 Mdot
.942 .19763 Mdot
.942 .19876 Mdot
.942 .19897 Mdot
.942 .1994 Mdot
.942 .20023 Mdot
.942 .20083 Mdot
.942 .20172 Mdot
.942 .2023 Mdot
.942 .20237 Mdot
.942 .2026 Mdot
.942 .20283 Mdot
.942 .20291 Mdot
.942 .20312 Mdot
.942 .20314 Mdot
.942 .20373 Mdot
.942 .20421 Mdot
.942 .20439 Mdot
.942 .2044 Mdot
.942 .2048 Mdot
.942 .20485 Mdot
.942 .20489 Mdot
.942 .20526 Mdot
.942 .20579 Mdot
.942 .20595 Mdot
.942 .20614 Mdot
.942 .20818 Mdot
.942 .20827 Mdot
.942 .20957 Mdot
.942 .20981 Mdot
.942 .21024 Mdot
.942 .21027 Mdot
.942 .21085 Mdot
.942 .21132 Mdot
.942 .21184 Mdot
.942 .21292 Mdot
.942 .21331 Mdot
.942 .21469 Mdot
.942 .21575 Mdot
.942 .21689 Mdot
.942 .21864 Mdot
.942 .21876 Mdot
.942 .21885 Mdot
.942 .21952 Mdot
.942 .21962 Mdot
.942 .21964 Mdot
.942 .21976 Mdot
.942 .22012 Mdot
.942 .22165 Mdot
.942 .22314 Mdot
.942 .22319 Mdot
.942 .22351 Mdot
.942 .22357 Mdot
.942 .22369 Mdot
.942 .22409 Mdot
.942 .22459 Mdot
.942 .22466 Mdot
.942 .22474 Mdot
.942 .2251 Mdot
.942 .22521 Mdot
.942 .22534 Mdot
.942 .22559 Mdot
.942 .22655 Mdot
.942 .22674 Mdot
.942 .22675 Mdot
.942 .22692 Mdot
.942 .22862 Mdot
.942 .22917 Mdot
.942 .22943 Mdot
.942 .23038 Mdot
.942 .23048 Mdot
.942 .23081 Mdot
.942 .23139 Mdot
.942 .23144 Mdot
.942 .23242 Mdot
.942 .23245 Mdot
.942 .2327 Mdot
.942 .23307 Mdot
.942 .2336 Mdot
.942 .23365 Mdot
.942 .23457 Mdot
.942 .23476 Mdot
.942 .23582 Mdot
.942 .23632 Mdot
.942 .23668 Mdot
.942 .23691 Mdot
.942 .23754 Mdot
.942 .23802 Mdot
.942 .23827 Mdot
.942 .23867 Mdot
.942 .2387 Mdot
.942 .2387 Mdot
.942 .23909 Mdot
.942 .2394 Mdot
.942 .23974 Mdot
.942 .24025 Mdot
.942 .2404 Mdot
.942 .2408 Mdot
.942 .24122 Mdot
.942 .24245 Mdot
.942 .24246 Mdot
.942 .2426 Mdot
.942 .24294 Mdot
.942 .24353 Mdot
.942 .24405 Mdot
.942 .24421 Mdot
.942 .24446 Mdot
.942 .24506 Mdot
.942 .2453 Mdot
.942 .24533 Mdot
.942 .2455 Mdot
.942 .24615 Mdot
.942 .24634 Mdot
.942 .24749 Mdot
.942 .24854 Mdot
.942 .24885 Mdot
.942 .24928 Mdot
.942 .24946 Mdot
.942 .24955 Mdot
.942 .25026 Mdot
.942 .25026 Mdot
.942 .25057 Mdot
.942 .25114 Mdot
.942 .25125 Mdot
.942 .25133 Mdot
.942 .25259 Mdot
.942 .25267 Mdot
.942 .25267 Mdot
.942 .25279 Mdot
.942 .25325 Mdot
.942 .25404 Mdot
.942 .25492 Mdot
.942 .25517 Mdot
.942 .25637 Mdot
.942 .25667 Mdot
.942 .25689 Mdot
.942 .25703 Mdot
.942 .2575 Mdot
.942 .25766 Mdot
.942 .25775 Mdot
.942 .25818 Mdot
.942 .25822 Mdot
.942 .25866 Mdot
.942 .25873 Mdot
.942 .25895 Mdot
.942 .25954 Mdot
.942 .26012 Mdot
.942 .2607 Mdot
.942 .26161 Mdot
.942 .26522 Mdot
.942 .26599 Mdot
.942 .26602 Mdot
.942 .26651 Mdot
.942 .26771 Mdot
.942 .26789 Mdot
.942 .26797 Mdot
.942 .26816 Mdot
.942 .26821 Mdot
.942 .2698 Mdot
.942 .26985 Mdot
.942 .27014 Mdot
.942 .27061 Mdot
.942 .27115 Mdot
.942 .27158 Mdot
.942 .27168 Mdot
.942 .27224 Mdot
.942 .27271 Mdot
.942 .27277 Mdot
.942 .27291 Mdot
.942 .27312 Mdot
.942 .2732 Mdot
.942 .27374 Mdot
.942 .27374 Mdot
.942 .27423 Mdot
.942 .27524 Mdot
.942 .27544 Mdot
.942 .27575 Mdot
.942 .27611 Mdot
.942 .27619 Mdot
.942 .27658 Mdot
.942 .2766 Mdot
.942 .27681 Mdot
.942 .27681 Mdot
.942 .27713 Mdot
.942 .27722 Mdot
.942 .27912 Mdot
.942 .27977 Mdot
.942 .2798 Mdot
.942 .27993 Mdot
.942 .2811 Mdot
.942 .28118 Mdot
.942 .28219 Mdot
.942 .28302 Mdot
.942 .28314 Mdot
.942 .28339 Mdot
.942 .2834 Mdot
.942 .28389 Mdot
.942 .2846 Mdot
.942 .28547 Mdot
.942 .28619 Mdot
.942 .28635 Mdot
.942 .28667 Mdot
.942 .28707 Mdot
.942 .28728 Mdot
.942 .28761 Mdot
.942 .28869 Mdot
.942 .28883 Mdot
.942 .28904 Mdot
.942 .28997 Mdot
.942 .29004 Mdot
.942 .29023 Mdot
.942 .29063 Mdot
.942 .29088 Mdot
.942 .29114 Mdot
.942 .29118 Mdot
.942 .29283 Mdot
.942 .29286 Mdot
.942 .29323 Mdot
.942 .2937 Mdot
.942 .2937 Mdot
.942 .294 Mdot
.942 .2946 Mdot
.942 .29481 Mdot
.942 .29514 Mdot
.942 .29682 Mdot
.942 .29724 Mdot
.942 .29741 Mdot
.942 .29751 Mdot
.942 .29857 Mdot
.942 .29925 Mdot
.942 .30197 Mdot
.942 .30226 Mdot
.942 .30227 Mdot
.942 .30248 Mdot
.942 .30271 Mdot
.942 .30433 Mdot
.942 .30634 Mdot
.942 .30714 Mdot
.942 .30954 Mdot
.942 .31023 Mdot
.942 .31087 Mdot
.942 .31115 Mdot
.942 .31182 Mdot
.942 .31193 Mdot
.942 .3154 Mdot
.942 .31645 Mdot
.942 .31716 Mdot
.942 .31725 Mdot
.942 .3173 Mdot
.942 .31731 Mdot
.942 .31775 Mdot
.942 .31903 Mdot
.942 .31941 Mdot
.942 .31999 Mdot
.942 .32029 Mdot
.942 .32061 Mdot
.942 .32067 Mdot
.942 .32122 Mdot
.942 .3217 Mdot
.942 .32183 Mdot
.942 .32195 Mdot
.942 .32328 Mdot
.942 .32352 Mdot
.942 .32352 Mdot
.942 .32376 Mdot
.942 .32407 Mdot
.942 .32457 Mdot
.942 .32544 Mdot
.942 .32616 Mdot
.942 .32627 Mdot
.942 .32665 Mdot
.942 .32721 Mdot
.942 .3276 Mdot
.942 .32808 Mdot
.942 .3287 Mdot
.942 .32887 Mdot
.942 .32904 Mdot
.942 .32909 Mdot
.942 .32929 Mdot
.942 .32968 Mdot
.942 .33028 Mdot
.942 .33049 Mdot
.942 .33075 Mdot
.942 .33099 Mdot
.942 .33109 Mdot
.942 .33182 Mdot
.942 .33196 Mdot
.942 .33234 Mdot
.942 .33247 Mdot
.942 .33398 Mdot
.942 .33399 Mdot
.942 .3348 Mdot
.942 .33506 Mdot
.942 .33546 Mdot
.942 .33561 Mdot
.942 .33636 Mdot
.942 .33854 Mdot
.942 .33876 Mdot
.942 .33934 Mdot
.942 .3398 Mdot
.942 .3418 Mdot
.942 .34193 Mdot
.942 .34346 Mdot
.942 .34405 Mdot
.942 .34484 Mdot
.942 .345 Mdot
.942 .34681 Mdot
.942 .34905 Mdot
.942 .34956 Mdot
.942 .34965 Mdot
.942 .35106 Mdot
.942 .35139 Mdot
.942 .35564 Mdot
.942 .35615 Mdot
.942 .3563 Mdot
.942 .35657 Mdot
.942 .35726 Mdot
.942 .35741 Mdot
.942 .35782 Mdot
.942 .3583 Mdot
.942 .35882 Mdot
.942 .35901 Mdot
.942 .35933 Mdot
.942 .36145 Mdot
.942 .36185 Mdot
.942 .36266 Mdot
.942 .36308 Mdot
.942 .36325 Mdot
.942 .36365 Mdot
.942 .36423 Mdot
.942 .36427 Mdot
.942 .36536 Mdot
.942 .36593 Mdot
.942 .36703 Mdot
.942 .36785 Mdot
.942 .36813 Mdot
.942 .36826 Mdot
.942 .3687 Mdot
.942 .36913 Mdot
.942 .36927 Mdot
.942 .36939 Mdot
.942 .36967 Mdot
.942 .3697 Mdot
.942 .36974 Mdot
.942 .37082 Mdot
.942 .37173 Mdot
.942 .37174 Mdot
.942 .37206 Mdot
.942 .37208 Mdot
.942 .37283 Mdot
.942 .37293 Mdot
.942 .373 Mdot
.942 .37338 Mdot
.942 .37361 Mdot
.942 .3737 Mdot
.942 .37409 Mdot
.942 .37469 Mdot
.942 .37486 Mdot
.942 .37501 Mdot
.942 .37512 Mdot
.942 .37537 Mdot
.942 .37704 Mdot
.942 .37706 Mdot
.942 .3788 Mdot
.942 .37921 Mdot
.942 .37937 Mdot
.942 .3797 Mdot
.942 .38181 Mdot
.942 .38228 Mdot
.942 .38236 Mdot
.942 .38308 Mdot
.942 .3831 Mdot
.942 .38314 Mdot
.942 .38418 Mdot
.942 .38424 Mdot
.942 .38433 Mdot
.942 .38512 Mdot
.942 .38545 Mdot
.942 .38575 Mdot
.942 .38609 Mdot
.942 .38713 Mdot
.942 .38719 Mdot
.942 .38795 Mdot
.942 .38796 Mdot
.942 .38813 Mdot
.942 .38886 Mdot
.942 .38908 Mdot
.942 .3894 Mdot
.942 .39147 Mdot
.942 .39346 Mdot
.942 .39561 Mdot
.942 .39613 Mdot
.942 .39844 Mdot
.942 .39855 Mdot
.942 .3989 Mdot
.942 .39902 Mdot
.942 .39913 Mdot
.942 .3993 Mdot
.942 .40058 Mdot
.942 .40076 Mdot
.942 .4008 Mdot
.942 .40101 Mdot
.942 .40169 Mdot
.942 .40318 Mdot
.942 .40345 Mdot
.942 .40459 Mdot
.942 .40706 Mdot
.942 .4074 Mdot
.942 .40749 Mdot
.942 .40808 Mdot
.942 .4082 Mdot
.942 .40842 Mdot
.942 .40918 Mdot
.942 .41 Mdot
.942 .41012 Mdot
.942 .41025 Mdot
.942 .4104 Mdot
.942 .41041 Mdot
.942 .41107 Mdot
.942 .41129 Mdot
.942 .41132 Mdot
.942 .41134 Mdot
.942 .41153 Mdot
.942 .412 Mdot
.942 .41309 Mdot
.942 .41382 Mdot
.942 .41418 Mdot
.942 .41419 Mdot
.942 .4145 Mdot
.942 .4156 Mdot
.942 .41771 Mdot
.942 .4187 Mdot
.942 .41875 Mdot
.942 .41923 Mdot
.942 .42103 Mdot
.942 .42122 Mdot
.942 .42125 Mdot
.942 .4218 Mdot
.942 .42183 Mdot
.942 .42294 Mdot
.942 .42294 Mdot
.942 .42303 Mdot
.942 .42436 Mdot
.942 .42487 Mdot
.942 .42492 Mdot
.942 .42509 Mdot
.942 .42541 Mdot
.942 .4261 Mdot
.942 .4263 Mdot
.942 .42709 Mdot
.942 .42719 Mdot
.942 .42892 Mdot
.942 .42928 Mdot
.942 .43011 Mdot
.942 .43062 Mdot
.942 .43128 Mdot
.942 .43135 Mdot
.942 .43221 Mdot
.942 .43289 Mdot
.942 .43334 Mdot
.942 .43451 Mdot
.942 .43467 Mdot
.942 .4349 Mdot
.942 .43542 Mdot
.942 .43558 Mdot
.942 .43588 Mdot
.942 .43665 Mdot
.942 .4367 Mdot
.942 .4367 Mdot
.942 .43701 Mdot
.942 .43743 Mdot
.942 .43789 Mdot
.942 .43803 Mdot
.942 .43866 Mdot
.942 .43882 Mdot
.942 .43894 Mdot
.942 .43963 Mdot
.942 .43991 Mdot
.942 .44065 Mdot
.942 .44144 Mdot
.942 .44377 Mdot
.942 .44379 Mdot
.942 .44405 Mdot
.942 .44468 Mdot
.942 .44482 Mdot
.942 .44492 Mdot
.942 .44579 Mdot
.942 .44622 Mdot
.942 .44679 Mdot
.942 .44709 Mdot
.942 .44756 Mdot
.942 .44788 Mdot
.942 .44788 Mdot
.942 .44868 Mdot
.942 .44895 Mdot
.942 .44914 Mdot
.942 .44918 Mdot
.942 .44951 Mdot
.942 .45074 Mdot
.942 .45108 Mdot
.942 .4511 Mdot
.942 .45183 Mdot
.942 .45301 Mdot
.942 .45327 Mdot
.942 .45525 Mdot
.942 .45582 Mdot
.942 .45664 Mdot
.942 .45698 Mdot
.942 .45714 Mdot
.942 .45847 Mdot
.942 .45848 Mdot
.942 .45895 Mdot
.942 .45907 Mdot
.942 .46013 Mdot
.942 .46035 Mdot
.942 .46045 Mdot
.942 .4605 Mdot
.942 .46106 Mdot
.942 .46142 Mdot
.942 .46286 Mdot
.942 .46302 Mdot
.942 .46303 Mdot
.942 .46326 Mdot
.942 .46412 Mdot
.942 .46519 Mdot
.942 .46561 Mdot
.942 .46725 Mdot
.942 .46759 Mdot
.942 .46774 Mdot
.942 .47 Mdot
.942 .47055 Mdot
.942 .47098 Mdot
.942 .47124 Mdot
.942 .47212 Mdot
.942 .47243 Mdot
.942 .47259 Mdot
.942 .47341 Mdot
.942 .47347 Mdot
.942 .47431 Mdot
.942 .47443 Mdot
.942 .47486 Mdot
.942 .47597 Mdot
.942 .47705 Mdot
.942 .47723 Mdot
.942 .47814 Mdot
.942 .47827 Mdot
.942 .47832 Mdot
.942 .47906 Mdot
.942 .47986 Mdot
.942 .47986 Mdot
.942 .48562 Mdot
.942 .48667 Mdot
.942 .48812 Mdot
.942 .48818 Mdot
.942 .4891 Mdot
.942 .49136 Mdot
.942 .49171 Mdot
.942 .49185 Mdot
.942 .49221 Mdot
.942 .49229 Mdot
.942 .49277 Mdot
.942 .4953 Mdot
.942 .49539 Mdot
.942 .4956 Mdot
.942 .49594 Mdot
.942 .49682 Mdot
.942 .49783 Mdot
.942 .49865 Mdot
.942 .49884 Mdot
.942 .4999 Mdot
.942 .50077 Mdot
.942 .50089 Mdot
.942 .50115 Mdot
.942 .50156 Mdot
.942 .5017 Mdot
.942 .50271 Mdot
.942 .50272 Mdot
.942 .50365 Mdot
.942 .50412 Mdot
.942 .50554 Mdot
.942 .50593 Mdot
.942 .5065 Mdot
.942 .50658 Mdot
.942 .50717 Mdot
.942 .50734 Mdot
.942 .50807 Mdot
.942 .5081 Mdot
.942 .5085 Mdot
.942 .50851 Mdot
.942 .5091 Mdot
.942 .50927 Mdot
.942 .51285 Mdot
.942 .51407 Mdot
.942 .51413 Mdot
.942 .51438 Mdot
.942 .51659 Mdot
.942 .51673 Mdot
.942 .51865 Mdot
.942 .52021 Mdot
.942 .52042 Mdot
.942 .52091 Mdot
.942 .52092 Mdot
.942 .52185 Mdot
.942 .52318 Mdot
.942 .52483 Mdot
.942 .52618 Mdot
.942 .52647 Mdot
.942 .52708 Mdot
.942 .52783 Mdot
.942 .52822 Mdot
.942 .52886 Mdot
.942 .53088 Mdot
.942 .53115 Mdot
.942 .53154 Mdot
.942 .5333 Mdot
.942 .53342 Mdot
.942 .53379 Mdot
.942 .53454 Mdot
.942 .53501 Mdot
.942 .53551 Mdot
.942 .53557 Mdot
.942 .53869 Mdot
.942 .53874 Mdot
.942 .53943 Mdot
.942 .54031 Mdot
.942 .54032 Mdot
.942 .54088 Mdot
.942 .54201 Mdot
.942 .54241 Mdot
.942 .54304 Mdot
.942 .54619 Mdot
.942 .54698 Mdot
.942 .54731 Mdot
.942 .5475 Mdot
.942 .5495 Mdot
.942 .55078 Mdot
.942 .55589 Mdot
.942 .55645 Mdot
.942 .55647 Mdot
.942 .55686 Mdot
.942 .55729 Mdot
.942 .56035 Mdot
.942 .56414 Mdot
.942 .56565 Mdot
.942 .57017 Mdot
.942 .57147 Mdot
.944 .01524 Mdot
.944 .0153 Mdot
.944 .01541 Mdot
.944 .01554 Mdot
.944 .01571 Mdot
.944 .01583 Mdot
.944 .01603 Mdot
.944 .01628 Mdot
.944 .01659 Mdot
.944 .01681 Mdot
.944 .01719 Mdot
.944 .01727 Mdot
.944 .01727 Mdot
.944 .01767 Mdot
.944 .01786 Mdot
.944 .01826 Mdot
.944 .01868 Mdot
.944 .01938 Mdot
.944 .01953 Mdot
.944 .01954 Mdot
.944 .01972 Mdot
.944 .0203 Mdot
.944 .02037 Mdot
.944 .02041 Mdot
.944 .02065 Mdot
.944 .02142 Mdot
.944 .02155 Mdot
.944 .02219 Mdot
.944 .02353 Mdot
.944 .02381 Mdot
.944 .02382 Mdot
.944 .02402 Mdot
.944 .02416 Mdot
.944 .02469 Mdot
.944 .02525 Mdot
.944 .02539 Mdot
.944 .02547 Mdot
.944 .02592 Mdot
.944 .02693 Mdot
.944 .02737 Mdot
.944 .02744 Mdot
.944 .02762 Mdot
.944 .02775 Mdot
.944 .02796 Mdot
.944 .02884 Mdot
.944 .02908 Mdot
.944 .02943 Mdot
.944 .02944 Mdot
.944 .02974 Mdot
.944 .02992 Mdot
.944 .03136 Mdot
.944 .03189 Mdot
.944 .03191 Mdot
.944 .03229 Mdot
.944 .03254 Mdot
.944 .03288 Mdot
.944 .03354 Mdot
.944 .03461 Mdot
.944 .03487 Mdot
.944 .03502 Mdot
.944 .03563 Mdot
.944 .03588 Mdot
.944 .03779 Mdot
.944 .0386 Mdot
.944 .03874 Mdot
.944 .03907 Mdot
.944 .03909 Mdot
.944 .03932 Mdot
.944 .03973 Mdot
.944 .04072 Mdot
.944 .0413 Mdot
.944 .04131 Mdot
.944 .04138 Mdot
.944 .04184 Mdot
.944 .04213 Mdot
.944 .04251 Mdot
.944 .04251 Mdot
.944 .04264 Mdot
.944 .04276 Mdot
.944 .04308 Mdot
.944 .04308 Mdot
.944 .04327 Mdot
.944 .04342 Mdot
.944 .04468 Mdot
.944 .04584 Mdot
.944 .04589 Mdot
.944 .04614 Mdot
.944 .04664 Mdot
.944 .04673 Mdot
.944 .04714 Mdot
.944 .04719 Mdot
.944 .04789 Mdot
.944 .04837 Mdot
.944 .04902 Mdot
.944 .04969 Mdot
.944 .05026 Mdot
.944 .05077 Mdot
.944 .0509 Mdot
.944 .05144 Mdot
.944 .05228 Mdot
.944 .05278 Mdot
.944 .05304 Mdot
.944 .05358 Mdot
.944 .05411 Mdot
.944 .05421 Mdot
.944 .05467 Mdot
.944 .05542 Mdot
.944 .05644 Mdot
.944 .0573 Mdot
.944 .05736 Mdot
.944 .05782 Mdot
.944 .05827 Mdot
.944 .05871 Mdot
.944 .0591 Mdot
.944 .05938 Mdot
.944 .05981 Mdot
.944 .05981 Mdot
.944 .06008 Mdot
.944 .0607 Mdot
.944 .06074 Mdot
.944 .06116 Mdot
.944 .06171 Mdot
.944 .06193 Mdot
.944 .0622 Mdot
.944 .06315 Mdot
.944 .06382 Mdot
.944 .06453 Mdot
.944 .06491 Mdot
.944 .06493 Mdot
.944 .06505 Mdot
.944 .06582 Mdot
.944 .06594 Mdot
.944 .06648 Mdot
.944 .06718 Mdot
.944 .0672 Mdot
.944 .06745 Mdot
.944 .06757 Mdot
.944 .06767 Mdot
.944 .06827 Mdot
.944 .06828 Mdot
.944 .06862 Mdot
.944 .06891 Mdot
.944 .06931 Mdot
.944 .06949 Mdot
.944 .07041 Mdot
.944 .07083 Mdot
.944 .07105 Mdot
.944 .07129 Mdot
.944 .07188 Mdot
.944 .07347 Mdot
.944 .07358 Mdot
.944 .07405 Mdot
.944 .07498 Mdot
.944 .07515 Mdot
.944 .07593 Mdot
.944 .07602 Mdot
.944 .07736 Mdot
.944 .07807 Mdot
.944 .07826 Mdot
.944 .07934 Mdot
.944 .07943 Mdot
.944 .07948 Mdot
.944 .08036 Mdot
.944 .08075 Mdot
.944 .08182 Mdot
.944 .08194 Mdot
.944 .08279 Mdot
.944 .08303 Mdot
.944 .08388 Mdot
.944 .08405 Mdot
.944 .08533 Mdot
.944 .08564 Mdot
.944 .08577 Mdot
.944 .08583 Mdot
.944 .08603 Mdot
.944 .08657 Mdot
.944 .08698 Mdot
.944 .08708 Mdot
.944 .08809 Mdot
.944 .08859 Mdot
.944 .08909 Mdot
.944 .08928 Mdot
.944 .08944 Mdot
.944 .09015 Mdot
.944 .09156 Mdot
.944 .09349 Mdot
.944 .09427 Mdot
.944 .09447 Mdot
.944 .09512 Mdot
.944 .0952 Mdot
.944 .09523 Mdot
.944 .09602 Mdot
.944 .0961 Mdot
.944 .0965 Mdot
.944 .09695 Mdot
.944 .09777 Mdot
.944 .09841 Mdot
.944 .09851 Mdot
.944 .09851 Mdot
.944 .09905 Mdot
.944 .0996 Mdot
.944 .09985 Mdot
.944 .09985 Mdot
.944 .10037 Mdot
.944 .10153 Mdot
.944 .10162 Mdot
.944 .10241 Mdot
.944 .10302 Mdot
.944 .10344 Mdot
.944 .10387 Mdot
.944 .10399 Mdot
.944 .10437 Mdot
.944 .10578 Mdot
.944 .10616 Mdot
.944 .10708 Mdot
.944 .10728 Mdot
.944 .10742 Mdot
.944 .10826 Mdot
.944 .1084 Mdot
.944 .10877 Mdot
.944 .10949 Mdot
.944 .10952 Mdot
.944 .10975 Mdot
.944 .1112 Mdot
.944 .11142 Mdot
.944 .11245 Mdot
.944 .1128 Mdot
.944 .11327 Mdot
.944 .11334 Mdot
.944 .11378 Mdot
.944 .1138 Mdot
.944 .11418 Mdot
.944 .11427 Mdot
.944 .11451 Mdot
.944 .1147 Mdot
.944 .11537 Mdot
.944 .11582 Mdot
.944 .11584 Mdot
.944 .11649 Mdot
.944 .11655 Mdot
.944 .1166 Mdot
.944 .11703 Mdot
.944 .1177 Mdot
.944 .1178 Mdot
.944 .11814 Mdot
.944 .11922 Mdot
.944 .11975 Mdot
.944 .11986 Mdot
.944 .12017 Mdot
.944 .12067 Mdot
.944 .12096 Mdot
.944 .12107 Mdot
.944 .12154 Mdot
.944 .12263 Mdot
.944 .12314 Mdot
.944 .12328 Mdot
.944 .12402 Mdot
.944 .12565 Mdot
.944 .12585 Mdot
.944 .12588 Mdot
.944 .12609 Mdot
.944 .12633 Mdot
.944 .12646 Mdot
.944 .12674 Mdot
.944 .12775 Mdot
.944 .12779 Mdot
.944 .12789 Mdot
.944 .12805 Mdot
.944 .1285 Mdot
.944 .12867 Mdot
.944 .12882 Mdot
.944 .12934 Mdot
.944 .13029 Mdot
.944 .13046 Mdot
.944 .13047 Mdot
.944 .13127 Mdot
.944 .13247 Mdot
.944 .13299 Mdot
.944 .13323 Mdot
.944 .13389 Mdot
.944 .13433 Mdot
.944 .13469 Mdot
.944 .13598 Mdot
.944 .13674 Mdot
.944 .13689 Mdot
.944 .13689 Mdot
.944 .13698 Mdot
.944 .13701 Mdot
.944 .13765 Mdot
.944 .13837 Mdot
.944 .13841 Mdot
.944 .13866 Mdot
.944 .13938 Mdot
.944 .14142 Mdot
.944 .14143 Mdot
.944 .14164 Mdot
.944 .1418 Mdot
.944 .14214 Mdot
.944 .14325 Mdot
.944 .14369 Mdot
.944 .14405 Mdot
.944 .14506 Mdot
.944 .1453 Mdot
.944 .14562 Mdot
.944 .1472 Mdot
.944 .14804 Mdot
.944 .14863 Mdot
.944 .14887 Mdot
.944 .14897 Mdot
.944 .14936 Mdot
.944 .14952 Mdot
.944 .1502 Mdot
.944 .15039 Mdot
.944 .15051 Mdot
.944 .15115 Mdot
.944 .15134 Mdot
.944 .15248 Mdot
.944 .15298 Mdot
.944 .15324 Mdot
.944 .15374 Mdot
.944 .15388 Mdot
.944 .1542 Mdot
.944 .15491 Mdot
.944 .15514 Mdot
.944 .1555 Mdot
.944 .1558 Mdot
.944 .15623 Mdot
.944 .15713 Mdot
.944 .15865 Mdot
.944 .15931 Mdot
.944 .15966 Mdot
.944 .15976 Mdot
.944 .15981 Mdot
.944 .16266 Mdot
.944 .16332 Mdot
.944 .16344 Mdot
.944 .1641 Mdot
.944 .16491 Mdot
.944 .16529 Mdot
.944 .1655 Mdot
.944 .16617 Mdot
.944 .16651 Mdot
.944 .16667 Mdot
.944 .16672 Mdot
.944 .16823 Mdot
.944 .16837 Mdot
.944 .16898 Mdot
.944 .16912 Mdot
.944 .16952 Mdot
.944 .16998 Mdot
.944 .17077 Mdot
.944 .17149 Mdot
.944 .17152 Mdot
.944 .17204 Mdot
.944 .17221 Mdot
.944 .17273 Mdot
.944 .17291 Mdot
.944 .17292 Mdot
.944 .17394 Mdot
.944 .17475 Mdot
.944 .1749 Mdot
.944 .17498 Mdot
.944 .17536 Mdot
.944 .17546 Mdot
.944 .17546 Mdot
.944 .17642 Mdot
.944 .17817 Mdot
.944 .17862 Mdot
.944 .17878 Mdot
.944 .17902 Mdot
.944 .17916 Mdot
.944 .17919 Mdot
.944 .18028 Mdot
.944 .18114 Mdot
.944 .18144 Mdot
.944 .18148 Mdot
.944 .18223 Mdot
.944 .18275 Mdot
.944 .18303 Mdot
.944 .18327 Mdot
.944 .18329 Mdot
.944 .18386 Mdot
.944 .18398 Mdot
.944 .18465 Mdot
.944 .1853 Mdot
.944 .18615 Mdot
.944 .18664 Mdot
.944 .18669 Mdot
.944 .18707 Mdot
.944 .18713 Mdot
.944 .18736 Mdot
.944 .1891 Mdot
.944 .18948 Mdot
.944 .18974 Mdot
.944 .19073 Mdot
.944 .19126 Mdot
.944 .19133 Mdot
.944 .1916 Mdot
.944 .19205 Mdot
.944 .19229 Mdot
.944 .19364 Mdot
.944 .1937 Mdot
.944 .19414 Mdot
.944 .19481 Mdot
.944 .19514 Mdot
.944 .1961 Mdot
.944 .19687 Mdot
.944 .19729 Mdot
.944 .19884 Mdot
.944 .19923 Mdot
.944 .19991 Mdot
.944 .20022 Mdot
.944 .20064 Mdot
.944 .20079 Mdot
.944 .20091 Mdot
.944 .20174 Mdot
.944 .20178 Mdot
.944 .20251 Mdot
.944 .20267 Mdot
.944 .20304 Mdot
.944 .20305 Mdot
.944 .20312 Mdot
.944 .20348 Mdot
.944 .2038 Mdot
.944 .20436 Mdot
.944 .20457 Mdot
.944 .20476 Mdot
.944 .2056 Mdot
.944 .20564 Mdot
.944 .20602 Mdot
.944 .20687 Mdot
.944 .20698 Mdot
.944 .20707 Mdot
.944 .20761 Mdot
.944 .20789 Mdot
.944 .20849 Mdot
.944 .20915 Mdot
.944 .20934 Mdot
.944 .20998 Mdot
.944 .21037 Mdot
.944 .21199 Mdot
.944 .21202 Mdot
.944 .21302 Mdot
.944 .21323 Mdot
.944 .21363 Mdot
.944 .21382 Mdot
.944 .21475 Mdot
.944 .21531 Mdot
.944 .21551 Mdot
.944 .21626 Mdot
.944 .21639 Mdot
.944 .21718 Mdot
.944 .21747 Mdot
.944 .21811 Mdot
.944 .21847 Mdot
.944 .21918 Mdot
.944 .21942 Mdot
.944 .21968 Mdot
.944 .21969 Mdot
.944 .22108 Mdot
.944 .22221 Mdot
.944 .22337 Mdot
.944 .22416 Mdot
.944 .22437 Mdot
.944 .22453 Mdot
.944 .22459 Mdot
.944 .22499 Mdot
.944 .22544 Mdot
.944 .22569 Mdot
.944 .22621 Mdot
.944 .22787 Mdot
.944 .22813 Mdot
.944 .22821 Mdot
.944 .22839 Mdot
.944 .22869 Mdot
.944 .22883 Mdot
.944 .22954 Mdot
.944 .22986 Mdot
.944 .23014 Mdot
.944 .23112 Mdot
.944 .23139 Mdot
.944 .23292 Mdot
.944 .23325 Mdot
.944 .23326 Mdot
.944 .23427 Mdot
.944 .23477 Mdot
.944 .23545 Mdot
.944 .23548 Mdot
.944 .23694 Mdot
.944 .23703 Mdot
.944 .23801 Mdot
.944 .23847 Mdot
.944 .23908 Mdot
.944 .23972 Mdot
.944 .23972 Mdot
.944 .24055 Mdot
.944 .24085 Mdot
.944 .24123 Mdot
.944 .24328 Mdot
.944 .24339 Mdot
.944 .24366 Mdot
.944 .24419 Mdot
.944 .24509 Mdot
.944 .24538 Mdot
.944 .24539 Mdot
.944 .24547 Mdot
.944 .24556 Mdot
.944 .24562 Mdot
.944 .24587 Mdot
.944 .24604 Mdot
.944 .24682 Mdot
.944 .2478 Mdot
.944 .24817 Mdot
.944 .24825 Mdot
.944 .24861 Mdot
.944 .24872 Mdot
.944 .24894 Mdot
.944 .25009 Mdot
.944 .25242 Mdot
.944 .25393 Mdot
.944 .25395 Mdot
.944 .25404 Mdot
.944 .25435 Mdot
.944 .25466 Mdot
.944 .25529 Mdot
.944 .25624 Mdot
.944 .25654 Mdot
.944 .25738 Mdot
.944 .25823 Mdot
.944 .25849 Mdot
.944 .25852 Mdot
.944 .2589 Mdot
.944 .25903 Mdot
.944 .25973 Mdot
.944 .26081 Mdot
.944 .26126 Mdot
.944 .26147 Mdot
.944 .26187 Mdot
.944 .26255 Mdot
.944 .26388 Mdot
.944 .26427 Mdot
.944 .26484 Mdot
.944 .26643 Mdot
.944 .26754 Mdot
.944 .268 Mdot
.944 .26818 Mdot
.944 .2682 Mdot
.944 .26893 Mdot
.944 .26923 Mdot
.944 .27006 Mdot
.944 .27052 Mdot
.944 .27086 Mdot
.944 .27109 Mdot
.944 .27121 Mdot
.944 .2716 Mdot
.944 .27229 Mdot
.944 .27254 Mdot
.944 .27266 Mdot
.944 .27445 Mdot
.944 .27482 Mdot
.944 .27576 Mdot
.944 .27626 Mdot
.944 .2772 Mdot
.944 .27747 Mdot
.944 .27765 Mdot
.944 .27806 Mdot
.944 .27869 Mdot
.944 .27871 Mdot
.944 .27901 Mdot
.944 .27933 Mdot
.944 .27941 Mdot
.944 .27953 Mdot
.944 .27983 Mdot
.944 .28043 Mdot
.944 .28051 Mdot
.944 .28104 Mdot
.944 .28109 Mdot
.944 .2819 Mdot
.944 .28226 Mdot
.944 .28359 Mdot
.944 .28383 Mdot
.944 .28647 Mdot
.944 .2873 Mdot
.944 .28771 Mdot
.944 .28837 Mdot
.944 .28856 Mdot
.944 .28862 Mdot
.944 .28865 Mdot
.944 .28891 Mdot
.944 .29021 Mdot
.944 .29058 Mdot
.944 .29068 Mdot
.944 .29136 Mdot
.944 .29194 Mdot
.944 .29222 Mdot
.944 .29403 Mdot
.944 .29528 Mdot
.944 .29547 Mdot
.944 .29551 Mdot
.944 .29675 Mdot
.944 .29828 Mdot
.944 .299 Mdot
.944 .29939 Mdot
.944 .30057 Mdot
.944 .30067 Mdot
.944 .30131 Mdot
.944 .3016 Mdot
.944 .30171 Mdot
.944 .30377 Mdot
.944 .30455 Mdot
.944 .30481 Mdot
.944 .30597 Mdot
.944 .30623 Mdot
.944 .30698 Mdot
.944 .30915 Mdot
.944 .30925 Mdot
.944 .30935 Mdot
.944 .30954 Mdot
.944 .31068 Mdot
.944 .31071 Mdot
.944 .31076 Mdot
.944 .31084 Mdot
.944 .31175 Mdot
.944 .31175 Mdot
.944 .31206 Mdot
.944 .31305 Mdot
.944 .31339 Mdot
.944 .31341 Mdot
.944 .31402 Mdot
.944 .31533 Mdot
.944 .31568 Mdot
.944 .31687 Mdot
.944 .31714 Mdot
.944 .3173 Mdot
.944 .31741 Mdot
.944 .31801 Mdot
.944 .31819 Mdot
.944 .31819 Mdot
.944 .31835 Mdot
.944 .31845 Mdot
.944 .32002 Mdot
.944 .32148 Mdot
.944 .32331 Mdot
.944 .32417 Mdot
.944 .32448 Mdot
.944 .32448 Mdot
.944 .32492 Mdot
.944 .32519 Mdot
.944 .32525 Mdot
.944 .32542 Mdot
.944 .32552 Mdot
.944 .32627 Mdot
.944 .32688 Mdot
.944 .32691 Mdot
.944 .3273 Mdot
.944 .32735 Mdot
.944 .32892 Mdot
.944 .3295 Mdot
.944 .32956 Mdot
.944 .32985 Mdot
.944 .33098 Mdot
.944 .33126 Mdot
.944 .33196 Mdot
.944 .3325 Mdot
.944 .33295 Mdot
.944 .33298 Mdot
.944 .33323 Mdot
.944 .3337 Mdot
.944 .3339 Mdot
.944 .33406 Mdot
.944 .33428 Mdot
.944 .33529 Mdot
.944 .33555 Mdot
.944 .33605 Mdot
.944 .33678 Mdot
.944 .33746 Mdot
.944 .33839 Mdot
.944 .33932 Mdot
.944 .33941 Mdot
.944 .33989 Mdot
.944 .34012 Mdot
.944 .34023 Mdot
.944 .34067 Mdot
.944 .34395 Mdot
.944 .34463 Mdot
.944 .34467 Mdot
.944 .34517 Mdot
.944 .346 Mdot
.944 .34703 Mdot
.944 .3478 Mdot
.944 .34803 Mdot
.944 .34806 Mdot
.944 .34817 Mdot
.944 .34867 Mdot
.944 .34953 Mdot
.944 .34998 Mdot
.944 .35253 Mdot
.944 .35264 Mdot
.944 .35303 Mdot
.944 .35346 Mdot
.944 .35371 Mdot
.944 .35473 Mdot
.944 .35478 Mdot
.944 .35536 Mdot
.944 .35717 Mdot
.944 .35768 Mdot
.944 .35863 Mdot
.944 .35932 Mdot
.944 .35942 Mdot
.944 .35994 Mdot
.944 .36002 Mdot
.944 .36235 Mdot
.944 .3626 Mdot
.944 .36263 Mdot
.944 .36308 Mdot
.944 .36371 Mdot
.944 .36433 Mdot
.944 .36436 Mdot
.944 .36494 Mdot
.944 .36575 Mdot
.944 .36603 Mdot
.944 .36625 Mdot
.944 .36667 Mdot
.944 .36782 Mdot
.944 .3679 Mdot
.944 .36829 Mdot
.944 .36927 Mdot
.944 .36939 Mdot
.944 .36951 Mdot
.944 .36958 Mdot
.944 .37027 Mdot
.944 .37029 Mdot
.944 .37034 Mdot
.944 .37042 Mdot
.944 .37075 Mdot
.944 .37111 Mdot
.944 .37171 Mdot
.944 .37213 Mdot
.944 .37277 Mdot
.944 .37317 Mdot
.944 .37352 Mdot
.944 .37462 Mdot
.944 .37511 Mdot
.944 .37517 Mdot
.944 .37551 Mdot
.944 .37589 Mdot
.944 .37591 Mdot
.944 .37751 Mdot
.944 .37771 Mdot
.944 .37789 Mdot
.944 .3789 Mdot
.944 .37944 Mdot
.944 .38057 Mdot
.944 .3818 Mdot
.944 .38216 Mdot
.944 .38232 Mdot
.944 .38337 Mdot
.944 .38363 Mdot
.944 .38403 Mdot
.944 .38411 Mdot
.944 .38465 Mdot
.944 .38535 Mdot
.944 .38664 Mdot
.944 .38698 Mdot
.944 .38717 Mdot
.944 .38722 Mdot
.944 .38876 Mdot
.944 .38911 Mdot
.944 .38952 Mdot
.944 .39026 Mdot
.944 .39062 Mdot
.944 .3921 Mdot
.944 .39239 Mdot
.944 .39305 Mdot
.944 .39343 Mdot
.944 .39373 Mdot
.944 .39381 Mdot
.944 .39516 Mdot
.944 .39524 Mdot
.944 .39548 Mdot
.944 .39697 Mdot
.944 .39742 Mdot
.944 .3975 Mdot
.944 .39751 Mdot
.944 .39854 Mdot
.944 .39872 Mdot
.944 .3994 Mdot
.944 .39968 Mdot
.944 .39998 Mdot
.944 .4004 Mdot
.944 .40075 Mdot
.944 .4012 Mdot
.944 .40149 Mdot
.944 .40169 Mdot
.944 .40172 Mdot
.944 .40362 Mdot
.944 .40391 Mdot
.944 .40432 Mdot
.944 .40578 Mdot
.944 .40596 Mdot
.944 .40647 Mdot
.944 .40792 Mdot
.944 .40865 Mdot
.944 .40888 Mdot
.944 .41014 Mdot
.944 .41015 Mdot
.944 .41055 Mdot
.944 .41084 Mdot
.944 .41096 Mdot
.944 .41172 Mdot
.944 .41256 Mdot
.944 .41303 Mdot
.944 .41403 Mdot
.944 .41488 Mdot
.944 .41575 Mdot
.944 .41715 Mdot
.944 .41763 Mdot
.944 .41779 Mdot
.944 .41813 Mdot
.944 .41869 Mdot
.944 .41896 Mdot
.944 .4203 Mdot
.944 .42091 Mdot
.944 .42144 Mdot
.944 .4233 Mdot
.944 .4238 Mdot
.944 .42516 Mdot
.944 .42669 Mdot
.944 .42731 Mdot
.944 .42733 Mdot
.944 .4281 Mdot
.944 .42924 Mdot
.944 .42957 Mdot
.944 .43017 Mdot
.944 .43146 Mdot
.944 .43152 Mdot
.944 .43194 Mdot
.944 .43262 Mdot
.944 .43283 Mdot
.944 .43292 Mdot
.944 .43385 Mdot
.944 .43428 Mdot
.944 .43445 Mdot
.944 .4363 Mdot
.944 .43716 Mdot
.944 .43833 Mdot
.944 .43848 Mdot
.944 .43952 Mdot
.944 .43953 Mdot
.944 .4398 Mdot
.944 .44017 Mdot
.944 .44109 Mdot
.944 .44167 Mdot
.944 .44237 Mdot
.944 .44257 Mdot
.944 .44464 Mdot
.944 .44564 Mdot
.944 .44625 Mdot
.944 .44646 Mdot
.944 .44696 Mdot
.944 .44797 Mdot
.944 .44966 Mdot
.944 .45021 Mdot
.944 .45022 Mdot
.944 .45038 Mdot
.944 .45055 Mdot
.944 .45066 Mdot
.944 .45114 Mdot
.944 .45146 Mdot
.944 .4521 Mdot
.944 .45294 Mdot
.944 .45477 Mdot
.944 .45548 Mdot
.944 .45563 Mdot
.944 .45631 Mdot
.944 .45651 Mdot
.944 .45657 Mdot
.944 .45692 Mdot
.944 .45723 Mdot
.944 .45738 Mdot
.944 .4591 Mdot
.944 .4618 Mdot
.944 .4635 Mdot
.944 .46635 Mdot
.944 .4664 Mdot
.944 .46655 Mdot
.944 .46715 Mdot
.944 .46724 Mdot
.944 .46772 Mdot
.944 .46892 Mdot
.944 .4698 Mdot
.944 .47072 Mdot
.944 .47122 Mdot
.944 .47127 Mdot
.944 .47288 Mdot
.944 .47447 Mdot
.944 .47497 Mdot
.944 .47502 Mdot
.944 .47541 Mdot
.944 .47574 Mdot
.944 .47575 Mdot
.944 .47599 Mdot
.944 .47731 Mdot
.944 .47806 Mdot
.944 .4791 Mdot
.944 .47935 Mdot
.944 .47946 Mdot
.944 .48019 Mdot
.944 .48059 Mdot
.944 .48134 Mdot
.944 .48263 Mdot
.944 .48514 Mdot
.944 .48587 Mdot
.944 .48682 Mdot
.944 .48696 Mdot
.944 .48959 Mdot
.944 .48995 Mdot
.944 .49052 Mdot
.944 .49205 Mdot
.944 .49292 Mdot
.944 .49325 Mdot
.944 .49329 Mdot
.944 .49466 Mdot
.944 .49467 Mdot
.944 .49525 Mdot
.944 .49558 Mdot
.944 .49681 Mdot
.944 .49767 Mdot
.944 .49825 Mdot
.944 .49832 Mdot
.944 .49876 Mdot
.944 .49898 Mdot
.944 .4997 Mdot
.944 .50103 Mdot
.944 .5015 Mdot
.944 .50171 Mdot
.944 .5051 Mdot
.944 .5058 Mdot
.944 .50601 Mdot
.944 .50634 Mdot
.944 .50671 Mdot
.944 .50739 Mdot
.944 .50757 Mdot
.944 .50851 Mdot
.944 .51028 Mdot
.944 .51079 Mdot
.944 .51114 Mdot
.944 .5119 Mdot
.944 .5131 Mdot
.944 .51314 Mdot
.944 .5137 Mdot
.944 .5143 Mdot
.944 .51446 Mdot
.944 .51468 Mdot
.944 .51525 Mdot
.944 .51639 Mdot
.944 .51653 Mdot
.944 .51753 Mdot
.944 .51762 Mdot
.944 .51866 Mdot
.944 .51917 Mdot
.944 .51984 Mdot
.944 .52235 Mdot
.944 .52281 Mdot
.944 .52779 Mdot
.944 .52935 Mdot
.944 .53013 Mdot
.944 .53138 Mdot
.944 .53174 Mdot
.944 .53186 Mdot
.944 .5319 Mdot
.944 .5324 Mdot
.944 .53485 Mdot
.944 .53555 Mdot
.944 .53574 Mdot
.944 .53702 Mdot
.944 .53811 Mdot
.944 .53864 Mdot
.944 .54206 Mdot
.944 .54443 Mdot
.944 .54478 Mdot
.944 .54486 Mdot
.944 .5472 Mdot
.944 .55008 Mdot
.944 .55144 Mdot
.944 .55219 Mdot
.944 .55441 Mdot
.944 .55459 Mdot
.944 .55581 Mdot
.944 .55636 Mdot
.944 .55655 Mdot
.944 .56045 Mdot
.944 .56192 Mdot
.944 .56241 Mdot
.944 .5646 Mdot
.944 .56509 Mdot
.944 .56651 Mdot
.944 .57062 Mdot
.944 .57079 Mdot
.944 .57099 Mdot
.944 .57135 Mdot
.946 .01873 Mdot
.946 .02232 Mdot
.946 .02252 Mdot
.946 .0229 Mdot
.946 .023 Mdot
.946 .02395 Mdot
.946 .0243 Mdot
.946 .02489 Mdot
.946 .0258 Mdot
.946 .02617 Mdot
.946 .02672 Mdot
.946 .02677 Mdot
.946 .0273 Mdot
.946 .02811 Mdot
.946 .0291 Mdot
.946 .02917 Mdot
.946 .02922 Mdot
.946 .02948 Mdot
.946 .03019 Mdot
.946 .03039 Mdot
.946 .03071 Mdot
.946 .03218 Mdot
.946 .03248 Mdot
.946 .03284 Mdot
.946 .03331 Mdot
.946 .03384 Mdot
.946 .03397 Mdot
.946 .03425 Mdot
.946 .03568 Mdot
.946 .03623 Mdot
.946 .03639 Mdot
.946 .03645 Mdot
.946 .03743 Mdot
.946 .03752 Mdot
.946 .03754 Mdot
.946 .03796 Mdot
.946 .03852 Mdot
.946 .03952 Mdot
.946 .0397 Mdot
.946 .04005 Mdot
.946 .04016 Mdot
.946 .04053 Mdot
.946 .04193 Mdot
.946 .04206 Mdot
.946 .04216 Mdot
.946 .04265 Mdot
.946 .044 Mdot
.946 .04435 Mdot
.946 .04437 Mdot
.946 .04498 Mdot
.946 .04509 Mdot
.946 .04708 Mdot
.946 .04776 Mdot
.946 .04824 Mdot
.946 .04832 Mdot
.946 .04901 Mdot
.946 .04912 Mdot
.946 .04966 Mdot
.946 .04989 Mdot
.946 .05091 Mdot
.946 .05115 Mdot
.946 .05167 Mdot
.946 .05196 Mdot
.946 .05243 Mdot
.946 .05252 Mdot
.946 .05309 Mdot
.946 .05438 Mdot
.946 .05541 Mdot
.946 .05572 Mdot
.946 .05583 Mdot
.946 .05656 Mdot
.946 .05695 Mdot
.946 .0572 Mdot
.946 .0577 Mdot
.946 .05786 Mdot
.946 .0579 Mdot
.946 .05801 Mdot
.946 .05805 Mdot
.946 .05869 Mdot
.946 .05924 Mdot
.946 .05931 Mdot
.946 .05962 Mdot
.946 .05976 Mdot
.946 .0611 Mdot
.946 .06164 Mdot
.946 .06199 Mdot
.946 .06266 Mdot
.946 .06285 Mdot
.946 .06314 Mdot
.946 .06356 Mdot
.946 .06534 Mdot
.946 .0662 Mdot
.946 .06621 Mdot
.946 .06645 Mdot
.946 .06665 Mdot
.946 .06701 Mdot
.946 .06757 Mdot
.946 .06809 Mdot
.946 .06903 Mdot
.946 .0696 Mdot
.946 .07012 Mdot
.946 .07026 Mdot
.946 .07079 Mdot
.946 .07083 Mdot
.946 .07198 Mdot
.946 .07211 Mdot
.946 .07219 Mdot
.946 .07541 Mdot
.946 .07574 Mdot
.946 .07594 Mdot
.946 .07643 Mdot
.946 .07724 Mdot
.946 .07815 Mdot
.946 .0783 Mdot
.946 .07868 Mdot
.946 .07932 Mdot
.946 .0796 Mdot
.946 .07981 Mdot
.946 .08034 Mdot
.946 .08082 Mdot
.946 .08086 Mdot
.946 .081 Mdot
.946 .08115 Mdot
.946 .08127 Mdot
.946 .08177 Mdot
.946 .083 Mdot
.946 .08319 Mdot
.946 .08354 Mdot
.946 .08365 Mdot
.946 .08463 Mdot
.946 .08519 Mdot
.946 .0853 Mdot
.946 .08606 Mdot
.946 .08624 Mdot
.946 .0865 Mdot
.946 .08713 Mdot
.946 .08732 Mdot
.946 .08742 Mdot
.946 .08845 Mdot
.946 .08903 Mdot
.946 .08977 Mdot
.946 .09051 Mdot
.946 .09087 Mdot
.946 .09172 Mdot
.946 .09193 Mdot
.946 .09229 Mdot
.946 .09251 Mdot
.946 .09331 Mdot
.946 .09382 Mdot
.946 .09389 Mdot
.946 .09461 Mdot
.946 .09509 Mdot
.946 .09604 Mdot
.946 .09635 Mdot
.946 .09641 Mdot
.946 .09663 Mdot
.946 .09671 Mdot
.946 .09731 Mdot
.946 .09791 Mdot
.946 .09895 Mdot
.946 .09909 Mdot
.946 .09945 Mdot
.946 .09968 Mdot
.946 .09994 Mdot
.946 .10049 Mdot
.946 .1024 Mdot
.946 .10247 Mdot
.946 .10349 Mdot
.946 .1039 Mdot
.946 .10395 Mdot
.946 .10416 Mdot
.946 .10534 Mdot
.946 .10542 Mdot
.946 .10579 Mdot
.946 .10633 Mdot
.946 .10643 Mdot
.946 .10712 Mdot
.946 .1082 Mdot
.946 .10951 Mdot
.946 .11049 Mdot
.946 .11207 Mdot
.946 .11213 Mdot
.946 .11215 Mdot
.946 .11259 Mdot
.946 .11297 Mdot
.946 .113 Mdot
.946 .11346 Mdot
.946 .11365 Mdot
.946 .11367 Mdot
.946 .11462 Mdot
.946 .11472 Mdot
.946 .11507 Mdot
.946 .11516 Mdot
.946 .1157 Mdot
.946 .11748 Mdot
.946 .11765 Mdot
.946 .11817 Mdot
.946 .11856 Mdot
.946 .11952 Mdot
.946 .11955 Mdot
.946 .11981 Mdot
.946 .12073 Mdot
.946 .12079 Mdot
.946 .12081 Mdot
.946 .12089 Mdot
.946 .12094 Mdot
.946 .12289 Mdot
.946 .12305 Mdot
.946 .1233 Mdot
.946 .12346 Mdot
.946 .12407 Mdot
.946 .12447 Mdot
.946 .12477 Mdot
.946 .12536 Mdot
.946 .12549 Mdot
.946 .12587 Mdot
.946 .12636 Mdot
.946 .12664 Mdot
.946 .12956 Mdot
.946 .13018 Mdot
.946 .13036 Mdot
.946 .13056 Mdot
.946 .13092 Mdot
.946 .13148 Mdot
.946 .13192 Mdot
.946 .1326 Mdot
.946 .13301 Mdot
.946 .13398 Mdot
.946 .13473 Mdot
.946 .13498 Mdot
.946 .13501 Mdot
.946 .13511 Mdot
.946 .13556 Mdot
.946 .13574 Mdot
.946 .13694 Mdot
.946 .13717 Mdot
.946 .13748 Mdot
.946 .13788 Mdot
.946 .13826 Mdot
.946 .13863 Mdot
.946 .13887 Mdot
.946 .13925 Mdot
.946 .13979 Mdot
.946 .13986 Mdot
.946 .14012 Mdot
.946 .14041 Mdot
.946 .14064 Mdot
.946 .14158 Mdot
.946 .14169 Mdot
.946 .14275 Mdot
.946 .14329 Mdot
.946 .14392 Mdot
.946 .14427 Mdot
.946 .14492 Mdot
.946 .14514 Mdot
.946 .14531 Mdot
.946 .14621 Mdot
.946 .14692 Mdot
.946 .147 Mdot
.946 .14711 Mdot
.946 .14767 Mdot
.946 .14804 Mdot
.946 .14827 Mdot
.946 .14971 Mdot
.946 .15004 Mdot
.946 .15053 Mdot
.946 .15123 Mdot
.946 .15129 Mdot
.946 .15173 Mdot
.946 .15193 Mdot
.946 .15208 Mdot
.946 .15227 Mdot
.946 .15247 Mdot
.946 .15254 Mdot
.946 .15387 Mdot
.946 .15422 Mdot
.946 .15508 Mdot
.946 .15517 Mdot
.946 .15532 Mdot
.946 .15596 Mdot
.946 .15672 Mdot
.946 .15706 Mdot
.946 .15813 Mdot
.946 .15862 Mdot
.946 .1588 Mdot
.946 .15935 Mdot
.946 .15947 Mdot
.946 .15951 Mdot
.946 .1599 Mdot
.946 .1604 Mdot
.946 .1608 Mdot
.946 .16149 Mdot
.946 .1619 Mdot
.946 .16203 Mdot
.946 .16289 Mdot
.946 .16342 Mdot
.946 .16344 Mdot
.946 .16439 Mdot
.946 .16452 Mdot
.946 .16465 Mdot
.946 .16507 Mdot
.946 .1653 Mdot
.946 .16543 Mdot
.946 .16588 Mdot
.946 .1662 Mdot
.946 .16678 Mdot
.946 .16703 Mdot
.946 .16859 Mdot
.946 .16916 Mdot
.946 .16929 Mdot
.946 .16971 Mdot
.946 .16984 Mdot
.946 .17098 Mdot
.946 .17099 Mdot
.946 .17212 Mdot
.946 .17331 Mdot
.946 .17367 Mdot
.946 .17384 Mdot
.946 .17409 Mdot
.946 .17435 Mdot
.946 .17436 Mdot
.946 .17474 Mdot
.946 .17503 Mdot
.946 .17546 Mdot
.946 .17596 Mdot
.946 .177 Mdot
.946 .17707 Mdot
.946 .17749 Mdot
.946 .18003 Mdot
.946 .18061 Mdot
.946 .18076 Mdot
.946 .18269 Mdot
.946 .18286 Mdot
.946 .18309 Mdot
.946 .1831 Mdot
.946 .18345 Mdot
.946 .18354 Mdot
.946 .18395 Mdot
.946 .18452 Mdot
.946 .18617 Mdot
.946 .18633 Mdot
.946 .18703 Mdot
.946 .18795 Mdot
.946 .18804 Mdot
.946 .18824 Mdot
.946 .18904 Mdot
.946 .18955 Mdot
.946 .19071 Mdot
.946 .19159 Mdot
.946 .19176 Mdot
.946 .19309 Mdot
.946 .19407 Mdot
.946 .19549 Mdot
.946 .19591 Mdot
.946 .19592 Mdot
.946 .19662 Mdot
.946 .19858 Mdot
.946 .19864 Mdot
.946 .1989 Mdot
.946 .19903 Mdot
.946 .19905 Mdot
.946 .1999 Mdot
.946 .20061 Mdot
.946 .20063 Mdot
.946 .20067 Mdot
.946 .20154 Mdot
.946 .2019 Mdot
.946 .20194 Mdot
.946 .20374 Mdot
.946 .20393 Mdot
.946 .20459 Mdot
.946 .20463 Mdot
.946 .20475 Mdot
.946 .20551 Mdot
.946 .20578 Mdot
.946 .20676 Mdot
.946 .20691 Mdot
.946 .20798 Mdot
.946 .20814 Mdot
.946 .20915 Mdot
.946 .20948 Mdot
.946 .21045 Mdot
.946 .2112 Mdot
.946 .2114 Mdot
.946 .21288 Mdot
.946 .213 Mdot
.946 .21306 Mdot
.946 .21331 Mdot
.946 .21355 Mdot
.946 .21465 Mdot
.946 .2153 Mdot
.946 .2154 Mdot
.946 .21545 Mdot
.946 .21559 Mdot
.946 .2157 Mdot
.946 .21647 Mdot
.946 .21803 Mdot
.946 .21939 Mdot
.946 .21969 Mdot
.946 .22016 Mdot
.946 .22045 Mdot
.946 .22083 Mdot
.946 .22161 Mdot
.946 .22237 Mdot
.946 .22293 Mdot
.946 .22405 Mdot
.946 .22429 Mdot
.946 .22469 Mdot
.946 .22498 Mdot
.946 .22503 Mdot
.946 .22594 Mdot
.946 .22647 Mdot
.946 .23199 Mdot
.946 .23307 Mdot
.946 .23317 Mdot
.946 .23351 Mdot
.946 .23389 Mdot
.946 .23454 Mdot
.946 .23458 Mdot
.946 .23564 Mdot
.946 .23646 Mdot
.946 .23694 Mdot
.946 .23729 Mdot
.946 .23776 Mdot
.946 .23852 Mdot
.946 .23853 Mdot
.946 .23929 Mdot
.946 .23985 Mdot
.946 .24037 Mdot
.946 .24085 Mdot
.946 .24178 Mdot
.946 .24219 Mdot
.946 .24225 Mdot
.946 .24231 Mdot
.946 .24233 Mdot
.946 .2425 Mdot
.946 .24311 Mdot
.946 .24336 Mdot
.946 .2437 Mdot
.946 .24597 Mdot
.946 .24611 Mdot
.946 .2464 Mdot
.946 .24699 Mdot
.946 .24774 Mdot
.946 .24846 Mdot
.946 .24907 Mdot
.946 .24917 Mdot
.946 .24962 Mdot
.946 .2502 Mdot
.946 .25033 Mdot
.946 .25076 Mdot
.946 .25137 Mdot
.946 .25149 Mdot
.946 .25177 Mdot
.946 .25199 Mdot
.946 .25205 Mdot
.946 .25221 Mdot
.946 .25252 Mdot
.946 .25296 Mdot
.946 .2537 Mdot
.946 .25475 Mdot
.946 .25496 Mdot
.946 .25642 Mdot
.946 .25648 Mdot
.946 .25696 Mdot
.946 .25728 Mdot
.946 .25735 Mdot
.946 .25797 Mdot
.946 .25909 Mdot
.946 .25916 Mdot
.946 .25918 Mdot
.946 .25983 Mdot
.946 .26107 Mdot
.946 .2612 Mdot
.946 .26148 Mdot
.946 .2618 Mdot
.946 .26304 Mdot
.946 .2635 Mdot
.946 .26368 Mdot
.946 .26479 Mdot
.946 .26484 Mdot
.946 .265 Mdot
.946 .2652 Mdot
.946 .26626 Mdot
.946 .26698 Mdot
.946 .2674 Mdot
.946 .26811 Mdot
.946 .26879 Mdot
.946 .26957 Mdot
.946 .2698 Mdot
.946 .27001 Mdot
.946 .27008 Mdot
.946 .27012 Mdot
.946 .27067 Mdot
.946 .27075 Mdot
.946 .27168 Mdot
.946 .27288 Mdot
.946 .27301 Mdot
.946 .27311 Mdot
.946 .27375 Mdot
.946 .27394 Mdot
.946 .27432 Mdot
.946 .27461 Mdot
.946 .27497 Mdot
.946 .27497 Mdot
.946 .27503 Mdot
.946 .27535 Mdot
.946 .27547 Mdot
.946 .27585 Mdot
.946 .27757 Mdot
.946 .278 Mdot
.946 .27867 Mdot
.946 .28029 Mdot
.946 .28045 Mdot
.946 .28074 Mdot
.946 .28195 Mdot
.946 .28285 Mdot
.946 .28312 Mdot
.946 .28338 Mdot
.946 .28361 Mdot
.946 .28403 Mdot
.946 .2846 Mdot
.946 .28464 Mdot
.946 .28605 Mdot
.946 .28675 Mdot
.946 .28698 Mdot
.946 .28732 Mdot
.946 .28836 Mdot
.946 .2886 Mdot
.946 .28866 Mdot
.946 .28941 Mdot
.946 .28942 Mdot
.946 .28968 Mdot
.946 .29035 Mdot
.946 .29111 Mdot
.946 .29203 Mdot
.946 .29215 Mdot
.946 .29241 Mdot
.946 .29319 Mdot
.946 .29344 Mdot
.946 .29419 Mdot
.946 .29456 Mdot
.946 .29507 Mdot
.946 .29561 Mdot
.946 .29607 Mdot
.946 .2961 Mdot
.946 .29615 Mdot
.946 .29789 Mdot
.946 .29815 Mdot
.946 .29823 Mdot
.946 .29838 Mdot
.946 .2987 Mdot
.946 .29919 Mdot
.946 .29927 Mdot
.946 .29962 Mdot
.946 .29987 Mdot
.946 .30025 Mdot
.946 .30073 Mdot
.946 .30133 Mdot
.946 .30237 Mdot
.946 .30241 Mdot
.946 .30243 Mdot
.946 .30262 Mdot
.946 .30285 Mdot
.946 .3029 Mdot
.946 .30293 Mdot
.946 .30387 Mdot
.946 .30465 Mdot
.946 .30485 Mdot
.946 .30543 Mdot
.946 .30584 Mdot
.946 .30656 Mdot
.946 .30692 Mdot
.946 .30716 Mdot
.946 .30796 Mdot
.946 .30811 Mdot
.946 .30821 Mdot
.946 .30886 Mdot
.946 .31037 Mdot
.946 .31039 Mdot
.946 .31078 Mdot
.946 .31252 Mdot
.946 .31452 Mdot
.946 .31472 Mdot
.946 .31478 Mdot
.946 .31528 Mdot
.946 .31546 Mdot
.946 .31578 Mdot
.946 .31625 Mdot
.946 .31645 Mdot
.946 .31674 Mdot
.946 .31677 Mdot
.946 .31705 Mdot
.946 .31747 Mdot
.946 .31803 Mdot
.946 .31806 Mdot
.946 .31885 Mdot
.946 .31978 Mdot
.946 .32022 Mdot
.946 .32051 Mdot
.946 .32072 Mdot
.946 .32177 Mdot
.946 .32188 Mdot
.946 .32246 Mdot
.946 .32268 Mdot
.946 .3235 Mdot
.946 .3236 Mdot
.946 .32384 Mdot
.946 .32404 Mdot
.946 .32606 Mdot
.946 .32645 Mdot
.946 .3275 Mdot
.946 .32812 Mdot
.946 .32858 Mdot
.946 .32886 Mdot
.946 .33008 Mdot
.946 .33033 Mdot
.946 .33038 Mdot
.946 .33068 Mdot
.946 .33252 Mdot
.946 .33272 Mdot
.946 .33285 Mdot
.946 .33328 Mdot
.946 .3333 Mdot
.946 .33393 Mdot
.946 .33397 Mdot
.946 .33413 Mdot
.946 .33491 Mdot
.946 .33599 Mdot
.946 .33715 Mdot
.946 .33761 Mdot
.946 .33803 Mdot
.946 .33861 Mdot
.946 .3391 Mdot
.946 .33941 Mdot
.946 .33975 Mdot
.946 .34073 Mdot
.946 .34248 Mdot
.946 .34265 Mdot
.946 .34302 Mdot
.946 .34421 Mdot
.946 .34454 Mdot
.946 .34508 Mdot
.946 .34536 Mdot
.946 .34543 Mdot
.946 .34551 Mdot
.946 .34584 Mdot
.946 .34649 Mdot
.946 .34677 Mdot
.946 .34771 Mdot
.946 .34834 Mdot
.946 .34867 Mdot
.946 .34882 Mdot
.946 .34937 Mdot
.946 .34968 Mdot
.946 .35046 Mdot
.946 .35065 Mdot
.946 .35121 Mdot
.946 .35194 Mdot
.946 .35221 Mdot
.946 .35405 Mdot
.946 .35518 Mdot
.946 .35573 Mdot
.946 .35674 Mdot
.946 .35753 Mdot
.946 .35756 Mdot
.946 .35829 Mdot
.946 .35887 Mdot
.946 .35981 Mdot
.946 .3605 Mdot
.946 .36185 Mdot
.946 .36234 Mdot
.946 .36259 Mdot
.946 .3627 Mdot
.946 .3632 Mdot
.946 .36344 Mdot
.946 .36348 Mdot
.946 .3648 Mdot
.946 .36508 Mdot
.946 .36579 Mdot
.946 .36643 Mdot
.946 .36646 Mdot
.946 .36654 Mdot
.946 .36757 Mdot
.946 .36819 Mdot
.946 .36841 Mdot
.946 .36856 Mdot
.946 .36887 Mdot
.946 .36894 Mdot
.946 .36915 Mdot
.946 .3694 Mdot
.946 .36955 Mdot
.946 .37152 Mdot
.946 .37182 Mdot
.946 .37234 Mdot
.946 .3727 Mdot
.946 .37343 Mdot
.946 .37396 Mdot
.946 .37403 Mdot
.946 .37427 Mdot
.946 .37512 Mdot
.946 .3757 Mdot
.946 .37589 Mdot
.946 .37622 Mdot
.946 .37751 Mdot
.946 .37807 Mdot
.946 .37835 Mdot
.946 .37942 Mdot
.946 .37989 Mdot
.946 .38027 Mdot
.946 .38037 Mdot
.946 .38067 Mdot
.946 .38255 Mdot
.946 .38258 Mdot
.946 .38292 Mdot
.946 .38321 Mdot
.946 .38324 Mdot
.946 .38395 Mdot
.946 .38459 Mdot
.946 .38463 Mdot
.946 .38505 Mdot
.946 .38563 Mdot
.946 .38646 Mdot
.946 .38684 Mdot
.946 .38691 Mdot
.946 .38692 Mdot
.946 .38713 Mdot
.946 .38826 Mdot
.946 .38871 Mdot
.946 .389 Mdot
.946 .38964 Mdot
.946 .38987 Mdot
.946 .38999 Mdot
.946 .39006 Mdot
.946 .39046 Mdot
.946 .3909 Mdot
.946 .39299 Mdot
.946 .39422 Mdot
.946 .39441 Mdot
.946 .3945 Mdot
.946 .39478 Mdot
.946 .39497 Mdot
.946 .39621 Mdot
.946 .39643 Mdot
.946 .39777 Mdot
.946 .39927 Mdot
.946 .39939 Mdot
.946 .39939 Mdot
.946 .40015 Mdot
.946 .40196 Mdot
.946 .40254 Mdot
.946 .40342 Mdot
.946 .40397 Mdot
.946 .40468 Mdot
.946 .40594 Mdot
.946 .40616 Mdot
.946 .40654 Mdot
.946 .40758 Mdot
.946 .40761 Mdot
.946 .40866 Mdot
.946 .41077 Mdot
.946 .41124 Mdot
.946 .4119 Mdot
.946 .41198 Mdot
.946 .41254 Mdot
.946 .41263 Mdot
.946 .41435 Mdot
.946 .41513 Mdot
.946 .41536 Mdot
.946 .41607 Mdot
.946 .41703 Mdot
.946 .41786 Mdot
.946 .41933 Mdot
.946 .42137 Mdot
.946 .42153 Mdot
.946 .42581 Mdot
.946 .42658 Mdot
.946 .42785 Mdot
.946 .42804 Mdot
.946 .42868 Mdot
.946 .42909 Mdot
.946 .42939 Mdot
.946 .42992 Mdot
.946 .43063 Mdot
.946 .4307 Mdot
.946 .43111 Mdot
.946 .4327 Mdot
.946 .43426 Mdot
.946 .43486 Mdot
.946 .43516 Mdot
.946 .43569 Mdot
.946 .43584 Mdot
.946 .43592 Mdot
.946 .43671 Mdot
.946 .43815 Mdot
.946 .43818 Mdot
.946 .4386 Mdot
.946 .43864 Mdot
.946 .43956 Mdot
.946 .4396 Mdot
.946 .44067 Mdot
.946 .44165 Mdot
.946 .44198 Mdot
.946 .44257 Mdot
.946 .44432 Mdot
.946 .44469 Mdot
.946 .4451 Mdot
.946 .44522 Mdot
.946 .44533 Mdot
.946 .44537 Mdot
.946 .44568 Mdot
.946 .44685 Mdot
.946 .44731 Mdot
.946 .44795 Mdot
.946 .44798 Mdot
.946 .44842 Mdot
.946 .44932 Mdot
.946 .45212 Mdot
.946 .45226 Mdot
.946 .45252 Mdot
.946 .45304 Mdot
.946 .45306 Mdot
.946 .45418 Mdot
.946 .45559 Mdot
.946 .45573 Mdot
.946 .45697 Mdot
.946 .45703 Mdot
.946 .45811 Mdot
.946 .45831 Mdot
.946 .45886 Mdot
.946 .45915 Mdot
.946 .46025 Mdot
.946 .4605 Mdot
.946 .46079 Mdot
.946 .46131 Mdot
.946 .46244 Mdot
.946 .46246 Mdot
.946 .46257 Mdot
.946 .46269 Mdot
.946 .46273 Mdot
.946 .46322 Mdot
.946 .46364 Mdot
.946 .46374 Mdot
.946 .46405 Mdot
.946 .46465 Mdot
.946 .46547 Mdot
.946 .46586 Mdot
.946 .46688 Mdot
.946 .46886 Mdot
.946 .46896 Mdot
.946 .46925 Mdot
.946 .46988 Mdot
.946 .47019 Mdot
.946 .47073 Mdot
.946 .47187 Mdot
.946 .47202 Mdot
.946 .47213 Mdot
.946 .47305 Mdot
.946 .4736 Mdot
.946 .47366 Mdot
.946 .47378 Mdot
.946 .47389 Mdot
.946 .47496 Mdot
.946 .47516 Mdot
.946 .47604 Mdot
.946 .47708 Mdot
.946 .47721 Mdot
.946 .47724 Mdot
.946 .4774 Mdot
.946 .47847 Mdot
.946 .47911 Mdot
.946 .48082 Mdot
.946 .48106 Mdot
.946 .48128 Mdot
.946 .48159 Mdot
.946 .48219 Mdot
.946 .48455 Mdot
.946 .48501 Mdot
.946 .48515 Mdot
.946 .48519 Mdot
.946 .48541 Mdot
.946 .48575 Mdot
.946 .4859 Mdot
.946 .48673 Mdot
.946 .48691 Mdot
.946 .48699 Mdot
.946 .48785 Mdot
.946 .48795 Mdot
.946 .48825 Mdot
.946 .48863 Mdot
.946 .49035 Mdot
.946 .49064 Mdot
.946 .49199 Mdot
.946 .49279 Mdot
.946 .49316 Mdot
.946 .49387 Mdot
.946 .49413 Mdot
.946 .49543 Mdot
.946 .49595 Mdot
.946 .4969 Mdot
.946 .49734 Mdot
.946 .49742 Mdot
.946 .49773 Mdot
.946 .49786 Mdot
.946 .49794 Mdot
.946 .49898 Mdot
.946 .49914 Mdot
.946 .49999 Mdot
.946 .50088 Mdot
.946 .50129 Mdot
.946 .50215 Mdot
.946 .50316 Mdot
.946 .50341 Mdot
.946 .50361 Mdot
.946 .50481 Mdot
.946 .50501 Mdot
.946 .50518 Mdot
.946 .50555 Mdot
.946 .50589 Mdot
.946 .50591 Mdot
.946 .50644 Mdot
.946 .50711 Mdot
.946 .50712 Mdot
.946 .50723 Mdot
.946 .50783 Mdot
.946 .50807 Mdot
.946 .50822 Mdot
.946 .50878 Mdot
.946 .51203 Mdot
.946 .51286 Mdot
.946 .51365 Mdot
.946 .51372 Mdot
.946 .51411 Mdot
.946 .51718 Mdot
.946 .51749 Mdot
.946 .51804 Mdot
.946 .52033 Mdot
.946 .52203 Mdot
.946 .52253 Mdot
.946 .52304 Mdot
.946 .52347 Mdot
.946 .52425 Mdot
.946 .52533 Mdot
.946 .52542 Mdot
.946 .52809 Mdot
.946 .52941 Mdot
.946 .52985 Mdot
.946 .53048 Mdot
.946 .53246 Mdot
.946 .5329 Mdot
.946 .53302 Mdot
.946 .53444 Mdot
.946 .53446 Mdot
.946 .53494 Mdot
.946 .53622 Mdot
.946 .53765 Mdot
.946 .5394 Mdot
.946 .53962 Mdot
.946 .5401 Mdot
.946 .54158 Mdot
.946 .54207 Mdot
.946 .54349 Mdot
.946 .54418 Mdot
.946 .54515 Mdot
.946 .54617 Mdot
.946 .54703 Mdot
.946 .5471 Mdot
.946 .54719 Mdot
.946 .55048 Mdot
.946 .55097 Mdot
.946 .55113 Mdot
.946 .55142 Mdot
.946 .55202 Mdot
.946 .55294 Mdot
.946 .55309 Mdot
.946 .55376 Mdot
.946 .55423 Mdot
.946 .55494 Mdot
.946 .55585 Mdot
.946 .557 Mdot
.946 .55896 Mdot
.946 .55904 Mdot
.946 .55906 Mdot
.946 .55944 Mdot
.946 .55987 Mdot
.946 .55997 Mdot
.946 .56001 Mdot
.946 .56179 Mdot
.946 .56327 Mdot
.946 .56365 Mdot
.946 .56475 Mdot
.946 .56553 Mdot
.946 .56689 Mdot
.946 .56757 Mdot
.946 .56802 Mdot
.946 .56954 Mdot
.946 .56982 Mdot
.946 .57001 Mdot
.946 .57124 Mdot
.946 .5741 Mdot
.946 .57414 Mdot
.948 .01479 Mdot
.948 .01485 Mdot
.948 .01497 Mdot
.948 .01519 Mdot
.948 .01561 Mdot
.948 .01562 Mdot
.948 .01563 Mdot
.948 .01641 Mdot
.948 .01644 Mdot
.948 .01645 Mdot
.948 .01793 Mdot
.948 .01798 Mdot
.948 .018 Mdot
.948 .01913 Mdot
.948 .01946 Mdot
.948 .01977 Mdot
.948 .02082 Mdot
.948 .0209 Mdot
.948 .0209 Mdot
.948 .02094 Mdot
.948 .0227 Mdot
.948 .02308 Mdot
.948 .02323 Mdot
.948 .02372 Mdot
.948 .02431 Mdot
.948 .02482 Mdot
.948 .02536 Mdot
.948 .02553 Mdot
.948 .02607 Mdot
.948 .02628 Mdot
.948 .02645 Mdot
.948 .02645 Mdot
.948 .02652 Mdot
.948 .02657 Mdot
.948 .02689 Mdot
.948 .02839 Mdot
.948 .02858 Mdot
.948 .02986 Mdot
.948 .0304 Mdot
.948 .03057 Mdot
.948 .03086 Mdot
.948 .03178 Mdot
.948 .0329 Mdot
.948 .03388 Mdot
.948 .03406 Mdot
.948 .03489 Mdot
.948 .03521 Mdot
.948 .03579 Mdot
.948 .03601 Mdot
.948 .03625 Mdot
.948 .03665 Mdot
.948 .03696 Mdot
.948 .03697 Mdot
.948 .0371 Mdot
.948 .0372 Mdot
.948 .03721 Mdot
.948 .0378 Mdot
.948 .03816 Mdot
.948 .03859 Mdot
.948 .03896 Mdot
.948 .04005 Mdot
.948 .04064 Mdot
.948 .041 Mdot
.948 .04175 Mdot
.948 .04343 Mdot
.948 .04394 Mdot
.948 .04446 Mdot
.948 .04478 Mdot
.948 .04493 Mdot
.948 .04532 Mdot
.948 .04695 Mdot
.948 .04707 Mdot
.948 .04805 Mdot
.948 .04919 Mdot
.948 .05105 Mdot
.948 .05139 Mdot
.948 .05297 Mdot
.948 .05358 Mdot
.948 .05412 Mdot
.948 .05468 Mdot
.948 .05485 Mdot
.948 .05509 Mdot
.948 .05554 Mdot
.948 .0563 Mdot
.948 .05688 Mdot
.948 .0569 Mdot
.948 .05716 Mdot
.948 .05734 Mdot
.948 .05736 Mdot
.948 .0581 Mdot
.948 .05844 Mdot
.948 .05849 Mdot
.948 .05917 Mdot
.948 .05997 Mdot
.948 .06068 Mdot
.948 .06275 Mdot
.948 .06326 Mdot
.948 .06388 Mdot
.948 .064 Mdot
.948 .06456 Mdot
.948 .06526 Mdot
.948 .06549 Mdot
.948 .06598 Mdot
.948 .06609 Mdot
.948 .06674 Mdot
.948 .06842 Mdot
.948 .06891 Mdot
.948 .06916 Mdot
.948 .06948 Mdot
.948 .07013 Mdot
.948 .07041 Mdot
.948 .07111 Mdot
.948 .07171 Mdot
.948 .072 Mdot
.948 .07215 Mdot
.948 .07274 Mdot
.948 .07482 Mdot
.948 .07583 Mdot
.948 .07592 Mdot
.948 .07606 Mdot
.948 .07626 Mdot
.948 .07757 Mdot
.948 .07791 Mdot
.948 .07833 Mdot
.948 .0785 Mdot
.948 .07882 Mdot
.948 .07935 Mdot
.948 .08008 Mdot
.948 .08021 Mdot
.948 .08123 Mdot
.948 .08146 Mdot
.948 .0819 Mdot
.948 .08361 Mdot
.948 .08425 Mdot
.948 .08495 Mdot
.948 .08519 Mdot
.948 .08571 Mdot
.948 .0866 Mdot
.948 .08724 Mdot
.948 .0884 Mdot
.948 .08869 Mdot
.948 .08908 Mdot
.948 .08938 Mdot
.948 .08943 Mdot
.948 .09003 Mdot
.948 .09048 Mdot
.948 .09082 Mdot
.948 .09094 Mdot
.948 .09127 Mdot
.948 .09158 Mdot
.948 .09204 Mdot
.948 .09211 Mdot
.948 .09326 Mdot
.948 .09356 Mdot
.948 .09467 Mdot
.948 .0947 Mdot
.948 .09501 Mdot
.948 .0952 Mdot
.948 .09554 Mdot
.948 .09557 Mdot
.948 .09698 Mdot
.948 .09761 Mdot
.948 .09766 Mdot
.948 .09771 Mdot
.948 .09814 Mdot
.948 .09822 Mdot
.948 .09875 Mdot
.948 .099 Mdot
.948 .10009 Mdot
.948 .10052 Mdot
.948 .10068 Mdot
.948 .10186 Mdot
.948 .10485 Mdot
.948 .10514 Mdot
.948 .10539 Mdot
.948 .10579 Mdot
.948 .10595 Mdot
.948 .106 Mdot
.948 .1063 Mdot
.948 .10676 Mdot
.948 .10682 Mdot
.948 .10727 Mdot
.948 .10782 Mdot
.948 .10788 Mdot
.948 .10792 Mdot
.948 .10815 Mdot
.948 .10849 Mdot
.948 .10914 Mdot
.948 .10921 Mdot
.948 .10922 Mdot
.948 .1093 Mdot
.948 .11023 Mdot
.948 .11055 Mdot
.948 .11063 Mdot
.948 .11098 Mdot
.948 .11154 Mdot
.948 .11191 Mdot
.948 .11205 Mdot
.948 .11211 Mdot
.948 .11298 Mdot
.948 .11319 Mdot
.948 .11335 Mdot
.948 .11348 Mdot
.948 .11404 Mdot
.948 .11412 Mdot
.948 .11437 Mdot
.948 .11477 Mdot
.948 .11534 Mdot
.948 .11574 Mdot
.948 .11653 Mdot
.948 .11654 Mdot
.948 .11747 Mdot
.948 .11749 Mdot
.948 .11795 Mdot
.948 .11795 Mdot
.948 .11803 Mdot
.948 .11854 Mdot
.948 .11978 Mdot
.948 .12028 Mdot
.948 .12031 Mdot
.948 .12163 Mdot
.948 .12278 Mdot
.948 .123 Mdot
.948 .12333 Mdot
.948 .12361 Mdot
.948 .1237 Mdot
.948 .12387 Mdot
.948 .12397 Mdot
.948 .1243 Mdot
.948 .12473 Mdot
.948 .12527 Mdot
.948 .12639 Mdot
.948 .12683 Mdot
.948 .12724 Mdot
.948 .12745 Mdot
.948 .12867 Mdot
.948 .13059 Mdot
.948 .13062 Mdot
.948 .13068 Mdot
.948 .13076 Mdot
.948 .13103 Mdot
.948 .13106 Mdot
.948 .13141 Mdot
.948 .13163 Mdot
.948 .13221 Mdot
.948 .13304 Mdot
.948 .1333 Mdot
.948 .13389 Mdot
.948 .13398 Mdot
.948 .13433 Mdot
.948 .13453 Mdot
.948 .13534 Mdot
.948 .13566 Mdot
.948 .13605 Mdot
.948 .13625 Mdot
.948 .13631 Mdot
.948 .13725 Mdot
.948 .13787 Mdot
.948 .13865 Mdot
.948 .1389 Mdot
.948 .13995 Mdot
.948 .14083 Mdot
.948 .14127 Mdot
.948 .14209 Mdot
.948 .14269 Mdot
.948 .14411 Mdot
.948 .14534 Mdot
.948 .14656 Mdot
.948 .14761 Mdot
.948 .14788 Mdot
.948 .14804 Mdot
.948 .14814 Mdot
.948 .14834 Mdot
.948 .14932 Mdot
.948 .15101 Mdot
.948 .15223 Mdot
.948 .15244 Mdot
.948 .15442 Mdot
.948 .15445 Mdot
.948 .15456 Mdot
.948 .15496 Mdot
.948 .15571 Mdot
.948 .15629 Mdot
.948 .15637 Mdot
.948 .15751 Mdot
.948 .1577 Mdot
.948 .15775 Mdot
.948 .15828 Mdot
.948 .15837 Mdot
.948 .159 Mdot
.948 .15911 Mdot
.948 .15924 Mdot
.948 .15985 Mdot
.948 .15998 Mdot
.948 .16045 Mdot
.948 .16133 Mdot
.948 .16146 Mdot
.948 .16176 Mdot
.948 .16198 Mdot
.948 .16203 Mdot
.948 .16364 Mdot
.948 .1642 Mdot
.948 .1663 Mdot
.948 .16637 Mdot
.948 .16696 Mdot
.948 .16724 Mdot
.948 .16731 Mdot
.948 .16783 Mdot
.948 .16796 Mdot
.948 .16803 Mdot
.948 .16826 Mdot
.948 .16912 Mdot
.948 .17018 Mdot
.948 .17068 Mdot
.948 .17092 Mdot
.948 .17189 Mdot
.948 .17199 Mdot
.948 .17207 Mdot
.948 .17289 Mdot
.948 .17303 Mdot
.948 .17363 Mdot
.948 .17367 Mdot
.948 .17382 Mdot
.948 .17405 Mdot
.948 .17452 Mdot
.948 .17503 Mdot
.948 .17659 Mdot
.948 .17719 Mdot
.948 .17741 Mdot
.948 .17771 Mdot
.948 .17819 Mdot
.948 .17994 Mdot
.948 .18163 Mdot
.948 .18283 Mdot
.948 .18437 Mdot
.948 .18496 Mdot
.948 .1856 Mdot
.948 .18574 Mdot
.948 .18616 Mdot
.948 .18664 Mdot
.948 .18738 Mdot
.948 .18769 Mdot
.948 .18779 Mdot
.948 .18815 Mdot
.948 .18836 Mdot
.948 .18864 Mdot
.948 .18923 Mdot
.948 .18935 Mdot
.948 .1902 Mdot
.948 .19041 Mdot
.948 .19066 Mdot
.948 .19124 Mdot
.948 .19135 Mdot
.948 .19144 Mdot
.948 .19187 Mdot
.948 .19218 Mdot
.948 .19252 Mdot
.948 .19374 Mdot
.948 .19387 Mdot
.948 .19389 Mdot
.948 .19404 Mdot
.948 .19441 Mdot
.948 .19458 Mdot
.948 .19574 Mdot
.948 .19582 Mdot
.948 .19629 Mdot
.948 .19641 Mdot
.948 .19656 Mdot
.948 .19658 Mdot
.948 .19693 Mdot
.948 .19698 Mdot
.948 .19724 Mdot
.948 .19806 Mdot
.948 .19814 Mdot
.948 .19829 Mdot
.948 .19839 Mdot
.948 .19877 Mdot
.948 .19899 Mdot
.948 .19925 Mdot
.948 .19938 Mdot
.948 .20079 Mdot
.948 .20098 Mdot
.948 .20103 Mdot
.948 .20106 Mdot
.948 .20142 Mdot
.948 .20173 Mdot
.948 .20197 Mdot
.948 .20303 Mdot
.948 .20319 Mdot
.948 .20358 Mdot
.948 .20365 Mdot
.948 .20394 Mdot
.948 .20442 Mdot
.948 .2055 Mdot
.948 .20626 Mdot
.948 .20666 Mdot
.948 .20763 Mdot
.948 .20775 Mdot
.948 .20778 Mdot
.948 .20954 Mdot
.948 .20957 Mdot
.948 .21044 Mdot
.948 .21045 Mdot
.948 .2106 Mdot
.948 .21157 Mdot
.948 .21309 Mdot
.948 .21326 Mdot
.948 .21391 Mdot
.948 .21487 Mdot
.948 .21493 Mdot
.948 .21526 Mdot
.948 .21614 Mdot
.948 .21743 Mdot
.948 .21824 Mdot
.948 .21891 Mdot
.948 .21961 Mdot
.948 .22003 Mdot
.948 .22065 Mdot
.948 .2207 Mdot
.948 .22102 Mdot
.948 .22117 Mdot
.948 .22135 Mdot
.948 .22167 Mdot
.948 .22169 Mdot
.948 .22186 Mdot
.948 .22248 Mdot
.948 .2225 Mdot
.948 .2233 Mdot
.948 .22433 Mdot
.948 .22645 Mdot
.948 .22728 Mdot
.948 .22806 Mdot
.948 .22847 Mdot
.948 .23077 Mdot
.948 .23077 Mdot
.948 .23079 Mdot
.948 .23086 Mdot
.948 .23111 Mdot
.948 .23199 Mdot
.948 .23441 Mdot
.948 .23447 Mdot
.948 .23459 Mdot
.948 .23473 Mdot
.948 .23517 Mdot
.948 .23526 Mdot
.948 .2353 Mdot
.948 .23596 Mdot
.948 .23638 Mdot
.948 .23642 Mdot
.948 .23749 Mdot
.948 .23899 Mdot
.948 .239 Mdot
.948 .23905 Mdot
.948 .23954 Mdot
.948 .2396 Mdot
.948 .24067 Mdot
.948 .24084 Mdot
.948 .2415 Mdot
.948 .24189 Mdot
.948 .24342 Mdot
.948 .24385 Mdot
.948 .24403 Mdot
.948 .2441 Mdot
.948 .24452 Mdot
.948 .24476 Mdot
.948 .24502 Mdot
.948 .24515 Mdot
.948 .24526 Mdot
.948 .24643 Mdot
.948 .24659 Mdot
.948 .24691 Mdot
.948 .24705 Mdot
.948 .24707 Mdot
.948 .24752 Mdot
.948 .24765 Mdot
.948 .24821 Mdot
.948 .24945 Mdot
.948 .24969 Mdot
.948 .25017 Mdot
.948 .25095 Mdot
.948 .25096 Mdot
.948 .25108 Mdot
.948 .25135 Mdot
.948 .25217 Mdot
.948 .25383 Mdot
.948 .25466 Mdot
.948 .25492 Mdot
.948 .25576 Mdot
.948 .25622 Mdot
.948 .25721 Mdot
.948 .25735 Mdot
.948 .25881 Mdot
.948 .25928 Mdot
.948 .26004 Mdot
.948 .26033 Mdot
.948 .26037 Mdot
.948 .26055 Mdot
.948 .26232 Mdot
.948 .26238 Mdot
.948 .26253 Mdot
.948 .26268 Mdot
.948 .26326 Mdot
.948 .2647 Mdot
.948 .26635 Mdot
.948 .26668 Mdot
.948 .26678 Mdot
.948 .26699 Mdot
.948 .2672 Mdot
.948 .2675 Mdot
.948 .26768 Mdot
.948 .26808 Mdot
.948 .26841 Mdot
.948 .26937 Mdot
.948 .26993 Mdot
.948 .27076 Mdot
.948 .27312 Mdot
.948 .27423 Mdot
.948 .27452 Mdot
.948 .27544 Mdot
.948 .27557 Mdot
.948 .27584 Mdot
.948 .27624 Mdot
.948 .27675 Mdot
.948 .27741 Mdot
.948 .27781 Mdot
.948 .27844 Mdot
.948 .2787 Mdot
.948 .2796 Mdot
.948 .27966 Mdot
.948 .27986 Mdot
.948 .28022 Mdot
.948 .28063 Mdot
.948 .28108 Mdot
.948 .28202 Mdot
.948 .28205 Mdot
.948 .28247 Mdot
.948 .28288 Mdot
.948 .28314 Mdot
.948 .28328 Mdot
.948 .28544 Mdot
.948 .28582 Mdot
.948 .28582 Mdot
.948 .28591 Mdot
.948 .28691 Mdot
.948 .28707 Mdot
.948 .28709 Mdot
.948 .28758 Mdot
.948 .28764 Mdot
.948 .28828 Mdot
.948 .28849 Mdot
.948 .28873 Mdot
.948 .2888 Mdot
.948 .2893 Mdot
.948 .28938 Mdot
.948 .2899 Mdot
.948 .29014 Mdot
.948 .29099 Mdot
.948 .29104 Mdot
.948 .29119 Mdot
.948 .29136 Mdot
.948 .29146 Mdot
.948 .29269 Mdot
.948 .29295 Mdot
.948 .29348 Mdot
.948 .29351 Mdot
.948 .29393 Mdot
.948 .29403 Mdot
.948 .29424 Mdot
.948 .29495 Mdot
.948 .29637 Mdot
.948 .29708 Mdot
.948 .29793 Mdot
.948 .29815 Mdot
.948 .29879 Mdot
.948 .30054 Mdot
.948 .30124 Mdot
.948 .30213 Mdot
.948 .30225 Mdot
.948 .30332 Mdot
.948 .30336 Mdot
.948 .30336 Mdot
.948 .30379 Mdot
.948 .3039 Mdot
.948 .30404 Mdot
.948 .30478 Mdot
.948 .30502 Mdot
.948 .30527 Mdot
.948 .30539 Mdot
.948 .30583 Mdot
.948 .30747 Mdot
.948 .3077 Mdot
.948 .30947 Mdot
.948 .31043 Mdot
.948 .31087 Mdot
.948 .31088 Mdot
.948 .31272 Mdot
.948 .3129 Mdot
.948 .31306 Mdot
.948 .31366 Mdot
.948 .31461 Mdot
.948 .31489 Mdot
.948 .31573 Mdot
.948 .31601 Mdot
.948 .3161 Mdot
.948 .31639 Mdot
.948 .31665 Mdot
.948 .31682 Mdot
.948 .31761 Mdot
.948 .31771 Mdot
.948 .31867 Mdot
.948 .3206 Mdot
.948 .32151 Mdot
.948 .32163 Mdot
.948 .32226 Mdot
.948 .32276 Mdot
.948 .32299 Mdot
.948 .32318 Mdot
.948 .32376 Mdot
.948 .32466 Mdot
.948 .32581 Mdot
.948 .32633 Mdot
.948 .3274 Mdot
.948 .32798 Mdot
.948 .33118 Mdot
.948 .33157 Mdot
.948 .33328 Mdot
.948 .33346 Mdot
.948 .336 Mdot
.948 .33639 Mdot
.948 .33705 Mdot
.948 .33718 Mdot
.948 .33749 Mdot
.948 .33783 Mdot
.948 .33872 Mdot
.948 .33898 Mdot
.948 .33928 Mdot
.948 .33977 Mdot
.948 .34069 Mdot
.948 .3421 Mdot
.948 .34268 Mdot
.948 .34286 Mdot
.948 .34355 Mdot
.948 .34395 Mdot
.948 .34404 Mdot
.948 .34421 Mdot
.948 .34448 Mdot
.948 .34494 Mdot
.948 .34548 Mdot
.948 .3456 Mdot
.948 .34583 Mdot
.948 .34744 Mdot
.948 .34757 Mdot
.948 .34784 Mdot
.948 .34831 Mdot
.948 .34941 Mdot
.948 .34962 Mdot
.948 .34978 Mdot
.948 .35012 Mdot
.948 .3506 Mdot
.948 .35094 Mdot
.948 .35118 Mdot
.948 .35182 Mdot
.948 .35275 Mdot
.948 .35415 Mdot
.948 .3544 Mdot
.948 .35444 Mdot
.948 .35472 Mdot
.948 .35543 Mdot
.948 .35574 Mdot
.948 .35793 Mdot
.948 .35809 Mdot
.948 .35822 Mdot
.948 .35851 Mdot
.948 .35854 Mdot
.948 .3587 Mdot
.948 .35898 Mdot
.948 .35921 Mdot
.948 .3595 Mdot
.948 .35953 Mdot
.948 .35986 Mdot
.948 .3602 Mdot
.948 .36023 Mdot
.948 .36028 Mdot
.948 .36078 Mdot
.948 .36098 Mdot
.948 .36146 Mdot
.948 .36173 Mdot
.948 .36222 Mdot
.948 .36233 Mdot
.948 .36249 Mdot
.948 .36278 Mdot
.948 .36283 Mdot
.948 .36295 Mdot
.948 .36317 Mdot
.948 .36347 Mdot
.948 .36368 Mdot
.948 .3641 Mdot
.948 .3646 Mdot
.948 .36485 Mdot
.948 .36489 Mdot
.948 .36608 Mdot
.948 .36751 Mdot
.948 .36788 Mdot
.948 .36797 Mdot
.948 .36802 Mdot
.948 .36819 Mdot
.948 .36871 Mdot
.948 .3693 Mdot
.948 .36953 Mdot
.948 .36974 Mdot
.948 .36986 Mdot
.948 .37153 Mdot
.948 .37156 Mdot
.948 .37176 Mdot
.948 .37206 Mdot
.948 .37237 Mdot
.948 .3728 Mdot
.948 .37294 Mdot
.948 .37348 Mdot
.948 .37439 Mdot
.948 .37453 Mdot
.948 .37535 Mdot
.948 .37645 Mdot
.948 .37789 Mdot
.948 .37864 Mdot
.948 .38049 Mdot
.948 .38072 Mdot
.948 .38077 Mdot
.948 .38303 Mdot
.948 .3841 Mdot
.948 .38416 Mdot
.948 .38581 Mdot
.948 .38584 Mdot
.948 .38612 Mdot
.948 .38656 Mdot
.948 .38701 Mdot
.948 .38795 Mdot
.948 .38807 Mdot
.948 .3881 Mdot
.948 .39084 Mdot
.948 .39115 Mdot
.948 .39138 Mdot
.948 .39184 Mdot
.948 .39239 Mdot
.948 .39278 Mdot
.948 .39421 Mdot
.948 .39423 Mdot
.948 .39431 Mdot
.948 .39495 Mdot
.948 .39609 Mdot
.948 .39661 Mdot
.948 .39843 Mdot
.948 .39906 Mdot
.948 .39988 Mdot
.948 .40019 Mdot
.948 .4006 Mdot
.948 .40187 Mdot
.948 .40213 Mdot
.948 .40306 Mdot
.948 .40319 Mdot
.948 .40399 Mdot
.948 .40517 Mdot
.948 .40526 Mdot
.948 .40587 Mdot
.948 .40616 Mdot
.948 .40632 Mdot
.948 .4065 Mdot
.948 .40653 Mdot
.948 .4071 Mdot
.948 .40714 Mdot
.948 .40727 Mdot
.948 .40747 Mdot
.948 .40854 Mdot
.948 .40864 Mdot
.948 .40868 Mdot
.948 .41001 Mdot
.948 .4102 Mdot
.948 .41163 Mdot
.948 .41215 Mdot
.948 .41503 Mdot
.948 .41511 Mdot
.948 .41617 Mdot
.948 .41663 Mdot
.948 .41774 Mdot
.948 .41809 Mdot
.948 .41904 Mdot
.948 .41921 Mdot
.948 .41956 Mdot
.948 .41999 Mdot
.948 .42435 Mdot
.948 .42436 Mdot
.948 .4244 Mdot
.948 .42453 Mdot
.948 .42499 Mdot
.948 .42667 Mdot
.948 .42733 Mdot
.948 .42868 Mdot
.948 .42869 Mdot
.948 .42901 Mdot
.948 .43125 Mdot
.948 .43138 Mdot
.948 .4316 Mdot
.948 .43187 Mdot
.948 .43261 Mdot
.948 .43269 Mdot
.948 .43286 Mdot
.948 .43295 Mdot
.948 .43318 Mdot
.948 .43325 Mdot
.948 .4342 Mdot
.948 .43499 Mdot
.948 .435 Mdot
.948 .43506 Mdot
.948 .43521 Mdot
.948 .43709 Mdot
.948 .43753 Mdot
.948 .43829 Mdot
.948 .43914 Mdot
.948 .43939 Mdot
.948 .43994 Mdot
.948 .43996 Mdot
.948 .44006 Mdot
.948 .44099 Mdot
.948 .4411 Mdot
.948 .44118 Mdot
.948 .44148 Mdot
.948 .44312 Mdot
.948 .44334 Mdot
.948 .44345 Mdot
.948 .4442 Mdot
.948 .44471 Mdot
.948 .44544 Mdot
.948 .44727 Mdot
.948 .44743 Mdot
.948 .44798 Mdot
.948 .44833 Mdot
.948 .4486 Mdot
.948 .44895 Mdot
.948 .44916 Mdot
.948 .44949 Mdot
.948 .44963 Mdot
.948 .45043 Mdot
.948 .45088 Mdot
.948 .45138 Mdot
.948 .45162 Mdot
.948 .45183 Mdot
.948 .45339 Mdot
.948 .45405 Mdot
.948 .45431 Mdot
.948 .45434 Mdot
.948 .45496 Mdot
.948 .45522 Mdot
.948 .45526 Mdot
.948 .45611 Mdot
.948 .45622 Mdot
.948 .45631 Mdot
.948 .45636 Mdot
.948 .45742 Mdot
.948 .45783 Mdot
.948 .4582 Mdot
.948 .45895 Mdot
.948 .45977 Mdot
.948 .46023 Mdot
.948 .46115 Mdot
.948 .46151 Mdot
.948 .46261 Mdot
.948 .46263 Mdot
.948 .46286 Mdot
.948 .46338 Mdot
.948 .46492 Mdot
.948 .4666 Mdot
.948 .46807 Mdot
.948 .46916 Mdot
.948 .46964 Mdot
.948 .47015 Mdot
.948 .47173 Mdot
.948 .47221 Mdot
.948 .4726 Mdot
.948 .47299 Mdot
.948 .47448 Mdot
.948 .47475 Mdot
.948 .47531 Mdot
.948 .47751 Mdot
.948 .47842 Mdot
.948 .47985 Mdot
.948 .48041 Mdot
.948 .48047 Mdot
.948 .48082 Mdot
.948 .48158 Mdot
.948 .48409 Mdot
.948 .48418 Mdot
.948 .48428 Mdot
.948 .48457 Mdot
.948 .48485 Mdot
.948 .48595 Mdot
.948 .4873 Mdot
.948 .48773 Mdot
.948 .48868 Mdot
.948 .49157 Mdot
.948 .49172 Mdot
.948 .49174 Mdot
.948 .49182 Mdot
.948 .49243 Mdot
.948 .49263 Mdot
.948 .49303 Mdot
.948 .49328 Mdot
.948 .49342 Mdot
.948 .49368 Mdot
.948 .494 Mdot
.948 .49418 Mdot
.948 .49434 Mdot
.948 .49509 Mdot
.948 .49571 Mdot
.948 .49683 Mdot
.948 .49753 Mdot
.948 .49771 Mdot
.948 .49859 Mdot
.948 .49861 Mdot
.948 .49903 Mdot
.948 .50017 Mdot
.948 .5006 Mdot
.948 .50466 Mdot
.948 .50651 Mdot
.948 .50676 Mdot
.948 .50731 Mdot
.948 .50733 Mdot
.948 .50906 Mdot
.948 .5093 Mdot
.948 .5098 Mdot
.948 .51056 Mdot
.948 .51154 Mdot
.948 .51278 Mdot
.948 .51354 Mdot
.948 .5137 Mdot
.948 .51473 Mdot
.948 .51522 Mdot
.948 .51694 Mdot
.948 .51705 Mdot
.948 .51744 Mdot
.948 .51811 Mdot
.948 .51888 Mdot
.948 .51974 Mdot
.948 .52153 Mdot
.948 .52158 Mdot
.948 .52238 Mdot
.948 .52315 Mdot
.948 .52365 Mdot
.948 .52392 Mdot
.948 .52802 Mdot
.948 .52873 Mdot
.948 .52874 Mdot
.948 .5289 Mdot
.948 .5308 Mdot
.948 .53111 Mdot
.948 .53114 Mdot
.948 .53206 Mdot
.948 .53217 Mdot
.948 .5334 Mdot
.948 .5338 Mdot
.948 .53425 Mdot
.948 .53438 Mdot
.948 .53532 Mdot
.948 .53549 Mdot
.948 .53647 Mdot
.948 .53692 Mdot
.948 .53854 Mdot
.948 .53862 Mdot
.948 .53891 Mdot
.948 .53924 Mdot
.948 .53942 Mdot
.948 .54176 Mdot
.948 .54225 Mdot
.948 .54326 Mdot
.948 .5433 Mdot
.948 .5441 Mdot
.948 .5443 Mdot
.948 .5447 Mdot
.948 .54605 Mdot
.948 .54873 Mdot
.948 .55008 Mdot
.948 .55169 Mdot
.948 .5521 Mdot
.948 .55333 Mdot
.948 .55663 Mdot
.948 .55796 Mdot
.948 .55965 Mdot
.948 .55988 Mdot
.948 .5619 Mdot
.948 .56198 Mdot
.948 .56199 Mdot
.948 .5628 Mdot
.948 .56302 Mdot
.948 .56328 Mdot
.948 .56468 Mdot
.948 .56514 Mdot
.948 .5656 Mdot
.948 .56584 Mdot
.948 .56667 Mdot
.948 .56978 Mdot
.948 .57021 Mdot
.948 .57358 Mdot
.95 .01497 Mdot
.95 .0152 Mdot
.95 .01534 Mdot
.95 .01564 Mdot
.95 .0159 Mdot
.95 .01639 Mdot
.95 .01647 Mdot
.95 .01696 Mdot
.95 .01789 Mdot
.95 .01805 Mdot
.95 .01825 Mdot
.95 .01895 Mdot
.95 .01895 Mdot
.95 .01898 Mdot
.95 .02001 Mdot
.95 .02029 Mdot
.95 .02075 Mdot
.95 .02082 Mdot
.95 .02105 Mdot
.95 .02142 Mdot
.95 .02143 Mdot
.95 .02276 Mdot
.95 .02276 Mdot
.95 .02282 Mdot
.95 .02477 Mdot
.95 .0252 Mdot
.95 .0253 Mdot
.95 .0258 Mdot
.95 .02618 Mdot
.95 .02624 Mdot
.95 .02632 Mdot
.95 .02675 Mdot
.95 .02745 Mdot
.95 .02747 Mdot
.95 .02775 Mdot
.95 .02777 Mdot
.95 .02813 Mdot
.95 .02877 Mdot
.95 .02891 Mdot
.95 .02995 Mdot
.95 .02996 Mdot
.95 .03 Mdot
.95 .03 Mdot
.95 .03011 Mdot
.95 .03111 Mdot
.95 .03358 Mdot
.95 .0337 Mdot
.95 .03371 Mdot
.95 .03381 Mdot
.95 .03464 Mdot
.95 .03475 Mdot
.95 .03482 Mdot
.95 .03514 Mdot
.95 .03578 Mdot
.95 .03581 Mdot
.95 .03625 Mdot
.95 .0365 Mdot
.95 .0366 Mdot
.95 .03661 Mdot
.95 .03676 Mdot
.95 .03724 Mdot
.95 .03757 Mdot
.95 .03829 Mdot
.95 .03876 Mdot
.95 .03892 Mdot
.95 .03894 Mdot
.95 .03948 Mdot
.95 .03952 Mdot
.95 .0402 Mdot
.95 .04142 Mdot
.95 .04168 Mdot
.95 .04203 Mdot
.95 .04367 Mdot
.95 .04368 Mdot
.95 .04375 Mdot
.95 .04376 Mdot
.95 .04396 Mdot
.95 .04464 Mdot
.95 .04559 Mdot
.95 .04586 Mdot
.95 .04586 Mdot
.95 .04596 Mdot
.95 .04804 Mdot
.95 .04837 Mdot
.95 .04875 Mdot
.95 .04898 Mdot
.95 .05057 Mdot
.95 .05078 Mdot
.95 .0508 Mdot
.95 .051 Mdot
.95 .0513 Mdot
.95 .05185 Mdot
.95 .05214 Mdot
.95 .05258 Mdot
.95 .05278 Mdot
.95 .05285 Mdot
.95 .05292 Mdot
.95 .05353 Mdot
.95 .05372 Mdot
.95 .05474 Mdot
.95 .05479 Mdot
.95 .05513 Mdot
.95 .05545 Mdot
.95 .05563 Mdot
.95 .05575 Mdot
.95 .0561 Mdot
.95 .05629 Mdot
.95 .05632 Mdot
.95 .0566 Mdot
.95 .05712 Mdot
.95 .05742 Mdot
.95 .05752 Mdot
.95 .05768 Mdot
.95 .05815 Mdot
.95 .0595 Mdot
.95 .06021 Mdot
.95 .06041 Mdot
.95 .06063 Mdot
.95 .0607 Mdot
.95 .06075 Mdot
.95 .06092 Mdot
.95 .06177 Mdot
.95 .06185 Mdot
.95 .06195 Mdot
.95 .06213 Mdot
.95 .06314 Mdot
.95 .06544 Mdot
.95 .06545 Mdot
.95 .06594 Mdot
.95 .06616 Mdot
.95 .06662 Mdot
.95 .06716 Mdot
.95 .06729 Mdot
.95 .0675 Mdot
.95 .06855 Mdot
.95 .06908 Mdot
.95 .06973 Mdot
.95 .06975 Mdot
.95 .06988 Mdot
.95 .06991 Mdot
.95 .06999 Mdot
.95 .07028 Mdot
.95 .07084 Mdot
.95 .07158 Mdot
.95 .07221 Mdot
.95 .07221 Mdot
.95 .07226 Mdot
.95 .07303 Mdot
.95 .07338 Mdot
.95 .07364 Mdot
.95 .07389 Mdot
.95 .0739 Mdot
.95 .07408 Mdot
.95 .07464 Mdot
.95 .07561 Mdot
.95 .07653 Mdot
.95 .07706 Mdot
.95 .07804 Mdot
.95 .07865 Mdot
.95 .07938 Mdot
.95 .07981 Mdot
.95 .08076 Mdot
.95 .08201 Mdot
.95 .08243 Mdot
.95 .08283 Mdot
.95 .08293 Mdot
.95 .08297 Mdot
.95 .08318 Mdot
.95 .08325 Mdot
.95 .08328 Mdot
.95 .08366 Mdot
.95 .084 Mdot
.95 .08422 Mdot
.95 .08528 Mdot
.95 .08582 Mdot
.95 .08665 Mdot
.95 .08704 Mdot
.95 .08717 Mdot
.95 .08731 Mdot
.95 .08846 Mdot
.95 .08858 Mdot
.95 .08866 Mdot
.95 .08882 Mdot
.95 .09077 Mdot
.95 .09086 Mdot
.95 .0915 Mdot
.95 .09159 Mdot
.95 .09212 Mdot
.95 .09246 Mdot
.95 .09269 Mdot
.95 .0927 Mdot
.95 .09336 Mdot
.95 .09371 Mdot
.95 .09377 Mdot
.95 .0943 Mdot
.95 .09529 Mdot
.95 .09535 Mdot
.95 .09586 Mdot
.95 .09604 Mdot
.95 .09635 Mdot
.95 .09671 Mdot
.95 .09686 Mdot
.95 .09724 Mdot
.95 .09937 Mdot
.95 .09981 Mdot
.95 .09991 Mdot
.95 .10116 Mdot
.95 .10118 Mdot
.95 .10153 Mdot
.95 .10158 Mdot
.95 .10195 Mdot
.95 .10208 Mdot
.95 .10218 Mdot
.95 .10251 Mdot
.95 .10285 Mdot
.95 .10412 Mdot
.95 .10427 Mdot
.95 .10447 Mdot
.95 .10468 Mdot
.95 .1048 Mdot
.95 .10512 Mdot
.95 .10657 Mdot
.95 .10672 Mdot
.95 .11105 Mdot
.95 .1111 Mdot
.95 .11111 Mdot
.95 .11205 Mdot
.95 .11246 Mdot
.95 .11333 Mdot
.95 .11368 Mdot
.95 .11403 Mdot
.95 .11408 Mdot
.95 .11424 Mdot
.95 .11437 Mdot
.95 .1146 Mdot
.95 .11501 Mdot
.95 .11555 Mdot
.95 .11663 Mdot
.95 .11701 Mdot
.95 .11787 Mdot
.95 .11802 Mdot
.95 .11924 Mdot
.95 .11928 Mdot
.95 .11953 Mdot
.95 .11958 Mdot
.95 .11973 Mdot
.95 .12008 Mdot
.95 .12028 Mdot
.95 .12052 Mdot
.95 .12136 Mdot
.95 .12273 Mdot
.95 .12275 Mdot
.95 .12338 Mdot
.95 .12395 Mdot
.95 .12396 Mdot
.95 .12404 Mdot
.95 .12551 Mdot
.95 .12619 Mdot
.95 .12667 Mdot
.95 .12714 Mdot
.95 .12716 Mdot
.95 .12751 Mdot
.95 .1278 Mdot
.95 .12858 Mdot
.95 .12934 Mdot
.95 .12966 Mdot
.95 .12984 Mdot
.95 .13041 Mdot
.95 .1317 Mdot
.95 .13191 Mdot
.95 .13216 Mdot
.95 .1327 Mdot
.95 .13317 Mdot
.95 .13412 Mdot
.95 .13446 Mdot
.95 .13503 Mdot
.95 .13556 Mdot
.95 .13619 Mdot
.95 .13643 Mdot
.95 .13758 Mdot
.95 .13805 Mdot
.95 .1384 Mdot
.95 .14 Mdot
.95 .1402 Mdot
.95 .14082 Mdot
.95 .1413 Mdot
.95 .14154 Mdot
.95 .14258 Mdot
.95 .14286 Mdot
.95 .14337 Mdot
.95 .14376 Mdot
.95 .14414 Mdot
.95 .14433 Mdot
.95 .1444 Mdot
.95 .14451 Mdot
.95 .1448 Mdot
.95 .14493 Mdot
.95 .14498 Mdot
.95 .14571 Mdot
.95 .14602 Mdot
.95 .14636 Mdot
.95 .14678 Mdot
.95 .14802 Mdot
.95 .14878 Mdot
.95 .14946 Mdot
.95 .14981 Mdot
.95 .15069 Mdot
.95 .15096 Mdot
.95 .15139 Mdot
.95 .15195 Mdot
.95 .15213 Mdot
.95 .15238 Mdot
.95 .15264 Mdot
.95 .15289 Mdot
.95 .15456 Mdot
.95 .15476 Mdot
.95 .15482 Mdot
.95 .15506 Mdot
.95 .15521 Mdot
.95 .15551 Mdot
.95 .15676 Mdot
.95 .15761 Mdot
.95 .15922 Mdot
.95 .1594 Mdot
.95 .16024 Mdot
.95 .16049 Mdot
.95 .1606 Mdot
.95 .16078 Mdot
.95 .16107 Mdot
.95 .16147 Mdot
.95 .16178 Mdot
.95 .16243 Mdot
.95 .16287 Mdot
.95 .16288 Mdot
.95 .16296 Mdot
.95 .16413 Mdot
.95 .16428 Mdot
.95 .1648 Mdot
.95 .16491 Mdot
.95 .16574 Mdot
.95 .16593 Mdot
.95 .16667 Mdot
.95 .1678 Mdot
.95 .16792 Mdot
.95 .16816 Mdot
.95 .16889 Mdot
.95 .16923 Mdot
.95 .16982 Mdot
.95 .16986 Mdot
.95 .1701 Mdot
.95 .17051 Mdot
.95 .1708 Mdot
.95 .17151 Mdot
.95 .17188 Mdot
.95 .17219 Mdot
.95 .17324 Mdot
.95 .17395 Mdot
.95 .17395 Mdot
.95 .17456 Mdot
.95 .17456 Mdot
.95 .17488 Mdot
.95 .17556 Mdot
.95 .1756 Mdot
.95 .1756 Mdot
.95 .1763 Mdot
.95 .1764 Mdot
.95 .17658 Mdot
.95 .177 Mdot
.95 .17863 Mdot
.95 .17896 Mdot
.95 .17899 Mdot
.95 .17957 Mdot
.95 .17966 Mdot
.95 .17976 Mdot
.95 .18047 Mdot
.95 .1807 Mdot
.95 .1809 Mdot
.95 .18114 Mdot
.95 .18153 Mdot
.95 .18217 Mdot
.95 .18294 Mdot
.95 .18342 Mdot
.95 .18439 Mdot
.95 .18459 Mdot
.95 .18487 Mdot
.95 .18496 Mdot
.95 .18525 Mdot
.95 .1854 Mdot
.95 .18565 Mdot
.95 .18588 Mdot
.95 .18626 Mdot
.95 .18628 Mdot
.95 .18649 Mdot
.95 .18924 Mdot
.95 .18953 Mdot
.95 .19082 Mdot
.95 .19267 Mdot
.95 .19379 Mdot
.95 .19394 Mdot
.95 .19526 Mdot
.95 .19702 Mdot
.95 .19775 Mdot
.95 .19785 Mdot
.95 .19786 Mdot
.95 .19791 Mdot
.95 .19827 Mdot
.95 .19891 Mdot
.95 .19965 Mdot
.95 .20044 Mdot
.95 .20209 Mdot
.95 .20218 Mdot
.95 .20223 Mdot
.95 .20274 Mdot
.95 .2028 Mdot
.95 .20341 Mdot
.95 .20351 Mdot
.95 .20381 Mdot
.95 .20405 Mdot
.95 .2045 Mdot
.95 .20504 Mdot
.95 .20527 Mdot
.95 .20629 Mdot
.95 .208 Mdot
.95 .20835 Mdot
.95 .20861 Mdot
.95 .20908 Mdot
.95 .20913 Mdot
.95 .21065 Mdot
.95 .21072 Mdot
.95 .21099 Mdot
.95 .2114 Mdot
.95 .21177 Mdot
.95 .21284 Mdot
.95 .21331 Mdot
.95 .21338 Mdot
.95 .21387 Mdot
.95 .21396 Mdot
.95 .21425 Mdot
.95 .21445 Mdot
.95 .21461 Mdot
.95 .2149 Mdot
.95 .21529 Mdot
.95 .21574 Mdot
.95 .21644 Mdot
.95 .21734 Mdot
.95 .2175 Mdot
.95 .21762 Mdot
.95 .21786 Mdot
.95 .21912 Mdot
.95 .21994 Mdot
.95 .21998 Mdot
.95 .22035 Mdot
.95 .22084 Mdot
.95 .22118 Mdot
.95 .22227 Mdot
.95 .22228 Mdot
.95 .22244 Mdot
.95 .22405 Mdot
.95 .22419 Mdot
.95 .22492 Mdot
.95 .22522 Mdot
.95 .22651 Mdot
.95 .22661 Mdot
.95 .22743 Mdot
.95 .22832 Mdot
.95 .22836 Mdot
.95 .22857 Mdot
.95 .22903 Mdot
.95 .22958 Mdot
.95 .23105 Mdot
.95 .2325 Mdot
.95 .23311 Mdot
.95 .23346 Mdot
.95 .23391 Mdot
.95 .23454 Mdot
.95 .2367 Mdot
.95 .23699 Mdot
.95 .23738 Mdot
.95 .23787 Mdot
.95 .23889 Mdot
.95 .23912 Mdot
.95 .23979 Mdot
.95 .24131 Mdot
.95 .24138 Mdot
.95 .24158 Mdot
.95 .24223 Mdot
.95 .24259 Mdot
.95 .24332 Mdot
.95 .24421 Mdot
.95 .24433 Mdot
.95 .24552 Mdot
.95 .24597 Mdot
.95 .24647 Mdot
.95 .24715 Mdot
.95 .24768 Mdot
.95 .24817 Mdot
.95 .24905 Mdot
.95 .24971 Mdot
.95 .25149 Mdot
.95 .25276 Mdot
.95 .25313 Mdot
.95 .25429 Mdot
.95 .25431 Mdot
.95 .25522 Mdot
.95 .25532 Mdot
.95 .25568 Mdot
.95 .25623 Mdot
.95 .25674 Mdot
.95 .25766 Mdot
.95 .25818 Mdot
.95 .25823 Mdot
.95 .25851 Mdot
.95 .25916 Mdot
.95 .25991 Mdot
.95 .26063 Mdot
.95 .26098 Mdot
.95 .26112 Mdot
.95 .26133 Mdot
.95 .26187 Mdot
.95 .26211 Mdot
.95 .26219 Mdot
.95 .26222 Mdot
.95 .26301 Mdot
.95 .26361 Mdot
.95 .2642 Mdot
.95 .26485 Mdot
.95 .26542 Mdot
.95 .26564 Mdot
.95 .2671 Mdot
.95 .26799 Mdot
.95 .26873 Mdot
.95 .26944 Mdot
.95 .2707 Mdot
.95 .27073 Mdot
.95 .27092 Mdot
.95 .27106 Mdot
.95 .2712 Mdot
.95 .27139 Mdot
.95 .27189 Mdot
.95 .27308 Mdot
.95 .27358 Mdot
.95 .27426 Mdot
.95 .2744 Mdot
.95 .27546 Mdot
.95 .27555 Mdot
.95 .2758 Mdot
.95 .27628 Mdot
.95 .27677 Mdot
.95 .27726 Mdot
.95 .27819 Mdot
.95 .28042 Mdot
.95 .28081 Mdot
.95 .28092 Mdot
.95 .28136 Mdot
.95 .28139 Mdot
.95 .28165 Mdot
.95 .28182 Mdot
.95 .28204 Mdot
.95 .28222 Mdot
.95 .28461 Mdot
.95 .28529 Mdot
.95 .28613 Mdot
.95 .28621 Mdot
.95 .28676 Mdot
.95 .28745 Mdot
.95 .28775 Mdot
.95 .28904 Mdot
.95 .28928 Mdot
.95 .28956 Mdot
.95 .28962 Mdot
.95 .29122 Mdot
.95 .29169 Mdot
.95 .29191 Mdot
.95 .29201 Mdot
.95 .29224 Mdot
.95 .2928 Mdot
.95 .29287 Mdot
.95 .29338 Mdot
.95 .29354 Mdot
.95 .29391 Mdot
.95 .29414 Mdot
.95 .29537 Mdot
.95 .29568 Mdot
.95 .2962 Mdot
.95 .29624 Mdot
.95 .29638 Mdot
.95 .29689 Mdot
.95 .29798 Mdot
.95 .29861 Mdot
.95 .29887 Mdot
.95 .2989 Mdot
.95 .29987 Mdot
.95 .30009 Mdot
.95 .30052 Mdot
.95 .30125 Mdot
.95 .30165 Mdot
.95 .30202 Mdot
.95 .30211 Mdot
.95 .30344 Mdot
.95 .30558 Mdot
.95 .30581 Mdot
.95 .30625 Mdot
.95 .30764 Mdot
.95 .3077 Mdot
.95 .3083 Mdot
.95 .30941 Mdot
.95 .30949 Mdot
.95 .30996 Mdot
.95 .31053 Mdot
.95 .31072 Mdot
.95 .31128 Mdot
.95 .31226 Mdot
.95 .31262 Mdot
.95 .31263 Mdot
.95 .31333 Mdot
.95 .31361 Mdot
.95 .31392 Mdot
.95 .31592 Mdot
.95 .31623 Mdot
.95 .31646 Mdot
.95 .31726 Mdot
.95 .31727 Mdot
.95 .31746 Mdot
.95 .31779 Mdot
.95 .31786 Mdot
.95 .31842 Mdot
.95 .31842 Mdot
.95 .31902 Mdot
.95 .32033 Mdot
.95 .32039 Mdot
.95 .32039 Mdot
.95 .32094 Mdot
.95 .32115 Mdot
.95 .3215 Mdot
.95 .32173 Mdot
.95 .32191 Mdot
.95 .32225 Mdot
.95 .3228 Mdot
.95 .32305 Mdot
.95 .32477 Mdot
.95 .32615 Mdot
.95 .32665 Mdot
.95 .32679 Mdot
.95 .32684 Mdot
.95 .32794 Mdot
.95 .32811 Mdot
.95 .32831 Mdot
.95 .32843 Mdot
.95 .32965 Mdot
.95 .32994 Mdot
.95 .33009 Mdot
.95 .33047 Mdot
.95 .33092 Mdot
.95 .33167 Mdot
.95 .33184 Mdot
.95 .332 Mdot
.95 .33272 Mdot
.95 .33287 Mdot
.95 .33301 Mdot
.95 .33434 Mdot
.95 .33456 Mdot
.95 .33472 Mdot
.95 .33526 Mdot
.95 .33535 Mdot
.95 .3371 Mdot
.95 .33747 Mdot
.95 .338 Mdot
.95 .33807 Mdot
.95 .33818 Mdot
.95 .33873 Mdot
.95 .33901 Mdot
.95 .33949 Mdot
.95 .33994 Mdot
.95 .34066 Mdot
.95 .34066 Mdot
.95 .34068 Mdot
.95 .34109 Mdot
.95 .34141 Mdot
.95 .34194 Mdot
.95 .34244 Mdot
.95 .34293 Mdot
.95 .34321 Mdot
.95 .34516 Mdot
.95 .34582 Mdot
.95 .34603 Mdot
.95 .3463 Mdot
.95 .34632 Mdot
.95 .34643 Mdot
.95 .34686 Mdot
.95 .34927 Mdot
.95 .34931 Mdot
.95 .35086 Mdot
.95 .35144 Mdot
.95 .35284 Mdot
.95 .35355 Mdot
.95 .35363 Mdot
.95 .35495 Mdot
.95 .35523 Mdot
.95 .3559 Mdot
.95 .35612 Mdot
.95 .35678 Mdot
.95 .35775 Mdot
.95 .35798 Mdot
.95 .35874 Mdot
.95 .3611 Mdot
.95 .36248 Mdot
.95 .36267 Mdot
.95 .36269 Mdot
.95 .36278 Mdot
.95 .36346 Mdot
.95 .36404 Mdot
.95 .36469 Mdot
.95 .36585 Mdot
.95 .36608 Mdot
.95 .36725 Mdot
.95 .36759 Mdot
.95 .36991 Mdot
.95 .37072 Mdot
.95 .37089 Mdot
.95 .37099 Mdot
.95 .37197 Mdot
.95 .37208 Mdot
.95 .37249 Mdot
.95 .37324 Mdot
.95 .37342 Mdot
.95 .374 Mdot
.95 .37446 Mdot
.95 .37531 Mdot
.95 .37634 Mdot
.95 .37677 Mdot
.95 .37702 Mdot
.95 .37715 Mdot
.95 .37784 Mdot
.95 .37832 Mdot
.95 .37871 Mdot
.95 .3795 Mdot
.95 .38056 Mdot
.95 .38132 Mdot
.95 .38196 Mdot
.95 .3821 Mdot
.95 .38262 Mdot
.95 .38312 Mdot
.95 .384 Mdot
.95 .38411 Mdot
.95 .38516 Mdot
.95 .3856 Mdot
.95 .38699 Mdot
.95 .38712 Mdot
.95 .38743 Mdot
.95 .38763 Mdot
.95 .38842 Mdot
.95 .38912 Mdot
.95 .38988 Mdot
.95 .39037 Mdot
.95 .39115 Mdot
.95 .39205 Mdot
.95 .39218 Mdot
.95 .39311 Mdot
.95 .39328 Mdot
.95 .39383 Mdot
.95 .3942 Mdot
.95 .39421 Mdot
.95 .39452 Mdot
.95 .39452 Mdot
.95 .39469 Mdot
.95 .39507 Mdot
.95 .39507 Mdot
.95 .39544 Mdot
.95 .39581 Mdot
.95 .39667 Mdot
.95 .39716 Mdot
.95 .39799 Mdot
.95 .39894 Mdot
.95 .39919 Mdot
.95 .3997 Mdot
.95 .4 Mdot
.95 .40023 Mdot
.95 .40068 Mdot
.95 .40069 Mdot
.95 .40308 Mdot
.95 .40406 Mdot
.95 .40464 Mdot
.95 .40472 Mdot
.95 .40542 Mdot
.95 .40635 Mdot
.95 .40681 Mdot
.95 .407 Mdot
.95 .40734 Mdot
.95 .40906 Mdot
.95 .40909 Mdot
.95 .40939 Mdot
.95 .41057 Mdot
.95 .41213 Mdot
.95 .41245 Mdot
.95 .41272 Mdot
.95 .41352 Mdot
.95 .41392 Mdot
.95 .41411 Mdot
.95 .41467 Mdot
.95 .41552 Mdot
.95 .41561 Mdot
.95 .41657 Mdot
.95 .41712 Mdot
.95 .41719 Mdot
.95 .41731 Mdot
.95 .41798 Mdot
.95 .41862 Mdot
.95 .41888 Mdot
.95 .42057 Mdot
.95 .42065 Mdot
.95 .42103 Mdot
.95 .42192 Mdot
.95 .42295 Mdot
.95 .42576 Mdot
.95 .42723 Mdot
.95 .4285 Mdot
.95 .42966 Mdot
.95 .4297 Mdot
.95 .43033 Mdot
.95 .43118 Mdot
.95 .43237 Mdot
.95 .43273 Mdot
.95 .43301 Mdot
.95 .43502 Mdot
.95 .43649 Mdot
.95 .43703 Mdot
.95 .43751 Mdot
.95 .43778 Mdot
.95 .43856 Mdot
.95 .43871 Mdot
.95 .44065 Mdot
.95 .44108 Mdot
.95 .44235 Mdot
.95 .44323 Mdot
.95 .44409 Mdot
.95 .44512 Mdot
.95 .44524 Mdot
.95 .44531 Mdot
.95 .44539 Mdot
.95 .44575 Mdot
.95 .447 Mdot
.95 .44768 Mdot
.95 .44907 Mdot
.95 .45075 Mdot
.95 .45098 Mdot
.95 .4511 Mdot
.95 .4528 Mdot
.95 .45325 Mdot
.95 .45358 Mdot
.95 .45394 Mdot
.95 .4541 Mdot
.95 .45478 Mdot
.95 .45505 Mdot
.95 .45634 Mdot
.95 .45679 Mdot
.95 .45706 Mdot
.95 .45734 Mdot
.95 .45827 Mdot
.95 .45891 Mdot
.95 .45948 Mdot
.95 .45995 Mdot
.95 .46082 Mdot
.95 .4612 Mdot
.95 .46166 Mdot
.95 .4646 Mdot
.95 .46609 Mdot
.95 .467 Mdot
.95 .46719 Mdot
.95 .46771 Mdot
.95 .46909 Mdot
.95 .46921 Mdot
.95 .46973 Mdot
.95 .46991 Mdot
.95 .46995 Mdot
.95 .47157 Mdot
.95 .47168 Mdot
.95 .47186 Mdot
.95 .47255 Mdot
.95 .47359 Mdot
.95 .47457 Mdot
.95 .47551 Mdot
.95 .47631 Mdot
.95 .4773 Mdot
.95 .47739 Mdot
.95 .47776 Mdot
.95 .47792 Mdot
.95 .47874 Mdot
.95 .47882 Mdot
.95 .47915 Mdot
.95 .48058 Mdot
.95 .48194 Mdot
.95 .48234 Mdot
.95 .48262 Mdot
.95 .48289 Mdot
.95 .48314 Mdot
.95 .48329 Mdot
.95 .48431 Mdot
.95 .48466 Mdot
.95 .48477 Mdot
.95 .48491 Mdot
.95 .48498 Mdot
.95 .48648 Mdot
.95 .48731 Mdot
.95 .48762 Mdot
.95 .48873 Mdot
.95 .48877 Mdot
.95 .48997 Mdot
.95 .49008 Mdot
.95 .49043 Mdot
.95 .49106 Mdot
.95 .49146 Mdot
.95 .49425 Mdot
.95 .4952 Mdot
.95 .49594 Mdot
.95 .49734 Mdot
.95 .4987 Mdot
.95 .50108 Mdot
.95 .50115 Mdot
.95 .50151 Mdot
.95 .50177 Mdot
.95 .50203 Mdot
.95 .50239 Mdot
.95 .50294 Mdot
.95 .50334 Mdot
.95 .50376 Mdot
.95 .50537 Mdot
.95 .5056 Mdot
.95 .50656 Mdot
.95 .50785 Mdot
.95 .50811 Mdot
.95 .51013 Mdot
.95 .5103 Mdot
.95 .51038 Mdot
.95 .51058 Mdot
.95 .51078 Mdot
.95 .51168 Mdot
.95 .51262 Mdot
.95 .51275 Mdot
.95 .51354 Mdot
.95 .51531 Mdot
.95 .51676 Mdot
.95 .51704 Mdot
.95 .51874 Mdot
.95 .51956 Mdot
.95 .52029 Mdot
.95 .5205 Mdot
.95 .52135 Mdot
.95 .52139 Mdot
.95 .5219 Mdot
.95 .52222 Mdot
.95 .52264 Mdot
.95 .52298 Mdot
.95 .52751 Mdot
.95 .52881 Mdot
.95 .5304 Mdot
.95 .53055 Mdot
.95 .53161 Mdot
.95 .53292 Mdot
.95 .53347 Mdot
.95 .53593 Mdot
.95 .53638 Mdot
.95 .53693 Mdot
.95 .53703 Mdot
.95 .54007 Mdot
.95 .54097 Mdot
.95 .54138 Mdot
.95 .54157 Mdot
.95 .54201 Mdot
.95 .54307 Mdot
.95 .54321 Mdot
.95 .54418 Mdot
.95 .54448 Mdot
.95 .54519 Mdot
.95 .54563 Mdot
.95 .54796 Mdot
.95 .54854 Mdot
.95 .54954 Mdot
.95 .5496 Mdot
.95 .54988 Mdot
.95 .55084 Mdot
.95 .55292 Mdot
.95 .55411 Mdot
.95 .55462 Mdot
.95 .55466 Mdot
.95 .55651 Mdot
.95 .55694 Mdot
.95 .55774 Mdot
.95 .55913 Mdot
.95 .5599 Mdot
.95 .56059 Mdot
.95 .56077 Mdot
.95 .56328 Mdot
.95 .56736 Mdot
.95 .56779 Mdot
.95 .56863 Mdot
.95 .57127 Mdot
.95 .57138 Mdot
.95 .57252 Mdot
.95 .57463 Mdot
.95 .57478 Mdot
.95 .57567 Mdot
.952 .01477 Mdot
.952 .01483 Mdot
.952 .01493 Mdot
.952 .01512 Mdot
.952 .0155 Mdot
.952 .01554 Mdot
.952 .01578 Mdot
.952 .0162 Mdot
.952 .01628 Mdot
.952 .01673 Mdot
.952 .01674 Mdot
.952 .01675 Mdot
.952 .01733 Mdot
.952 .01754 Mdot
.952 .01769 Mdot
.952 .01829 Mdot
.952 .01851 Mdot
.952 .01856 Mdot
.952 .01857 Mdot
.952 .0186 Mdot
.952 .01969 Mdot
.952 .0197 Mdot
.952 .02009 Mdot
.952 .0201 Mdot
.952 .02039 Mdot
.952 .02098 Mdot
.952 .02153 Mdot
.952 .02194 Mdot
.952 .02202 Mdot
.952 .02204 Mdot
.952 .02206 Mdot
.952 .0221 Mdot
.952 .02276 Mdot
.952 .02323 Mdot
.952 .02326 Mdot
.952 .02329 Mdot
.952 .02418 Mdot
.952 .0242 Mdot
.952 .02452 Mdot
.952 .02494 Mdot
.952 .02497 Mdot
.952 .02527 Mdot
.952 .02544 Mdot
.952 .02551 Mdot
.952 .02618 Mdot
.952 .02664 Mdot
.952 .02769 Mdot
.952 .02848 Mdot
.952 .02863 Mdot
.952 .02866 Mdot
.952 .0287 Mdot
.952 .02878 Mdot
.952 .03002 Mdot
.952 .03079 Mdot
.952 .03092 Mdot
.952 .03098 Mdot
.952 .03104 Mdot
.952 .0321 Mdot
.952 .03274 Mdot
.952 .03278 Mdot
.952 .03286 Mdot
.952 .03337 Mdot
.952 .03338 Mdot
.952 .03419 Mdot
.952 .03424 Mdot
.952 .0348 Mdot
.952 .03514 Mdot
.952 .03527 Mdot
.952 .03535 Mdot
.952 .03653 Mdot
.952 .03655 Mdot
.952 .0368 Mdot
.952 .03743 Mdot
.952 .0381 Mdot
.952 .03941 Mdot
.952 .0407 Mdot
.952 .04092 Mdot
.952 .0412 Mdot
.952 .04126 Mdot
.952 .04134 Mdot
.952 .0415 Mdot
.952 .04181 Mdot
.952 .0433 Mdot
.952 .04373 Mdot
.952 .04387 Mdot
.952 .04532 Mdot
.952 .04557 Mdot
.952 .04568 Mdot
.952 .0458 Mdot
.952 .04631 Mdot
.952 .04738 Mdot
.952 .04781 Mdot
.952 .04903 Mdot
.952 .04911 Mdot
.952 .04926 Mdot
.952 .05023 Mdot
.952 .05025 Mdot
.952 .05057 Mdot
.952 .05179 Mdot
.952 .05189 Mdot
.952 .05195 Mdot
.952 .05297 Mdot
.952 .05324 Mdot
.952 .05359 Mdot
.952 .05386 Mdot
.952 .054 Mdot
.952 .0551 Mdot
.952 .05523 Mdot
.952 .05532 Mdot
.952 .05625 Mdot
.952 .05628 Mdot
.952 .05676 Mdot
.952 .0575 Mdot
.952 .05796 Mdot
.952 .05923 Mdot
.952 .06174 Mdot
.952 .06192 Mdot
.952 .06245 Mdot
.952 .06418 Mdot
.952 .06461 Mdot
.952 .06515 Mdot
.952 .06526 Mdot
.952 .0654 Mdot
.952 .06571 Mdot
.952 .06631 Mdot
.952 .06738 Mdot
.952 .06914 Mdot
.952 .06971 Mdot
.952 .06973 Mdot
.952 .06997 Mdot
.952 .07022 Mdot
.952 .07132 Mdot
.952 .0717 Mdot
.952 .0721 Mdot
.952 .07261 Mdot
.952 .07299 Mdot
.952 .07347 Mdot
.952 .07367 Mdot
.952 .07391 Mdot
.952 .07487 Mdot
.952 .07587 Mdot
.952 .07658 Mdot
.952 .0769 Mdot
.952 .07773 Mdot
.952 .07779 Mdot
.952 .07864 Mdot
.952 .07908 Mdot
.952 .08005 Mdot
.952 .08019 Mdot
.952 .0802 Mdot
.952 .08048 Mdot
.952 .08233 Mdot
.952 .08236 Mdot
.952 .08298 Mdot
.952 .08441 Mdot
.952 .08531 Mdot
.952 .08545 Mdot
.952 .08549 Mdot
.952 .08561 Mdot
.952 .08741 Mdot
.952 .08746 Mdot
.952 .08754 Mdot
.952 .08791 Mdot
.952 .08806 Mdot
.952 .08874 Mdot
.952 .08912 Mdot
.952 .08924 Mdot
.952 .08952 Mdot
.952 .09078 Mdot
.952 .09114 Mdot
.952 .09161 Mdot
.952 .09174 Mdot
.952 .09185 Mdot
.952 .09191 Mdot
.952 .09204 Mdot
.952 .09205 Mdot
.952 .09209 Mdot
.952 .09349 Mdot
.952 .09379 Mdot
.952 .09386 Mdot
.952 .09398 Mdot
.952 .09477 Mdot
.952 .09489 Mdot
.952 .09618 Mdot
.952 .09657 Mdot
.952 .09666 Mdot
.952 .09706 Mdot
.952 .09898 Mdot
.952 .09948 Mdot
.952 .10186 Mdot
.952 .10312 Mdot
.952 .10424 Mdot
.952 .10459 Mdot
.952 .10554 Mdot
.952 .1056 Mdot
.952 .10638 Mdot
.952 .1073 Mdot
.952 .10748 Mdot
.952 .10789 Mdot
.952 .10815 Mdot
.952 .1089 Mdot
.952 .10969 Mdot
.952 .10972 Mdot
.952 .11015 Mdot
.952 .1102 Mdot
.952 .11046 Mdot
.952 .11074 Mdot
.952 .11083 Mdot
.952 .11095 Mdot
.952 .11122 Mdot
.952 .11177 Mdot
.952 .11181 Mdot
.952 .11264 Mdot
.952 .11295 Mdot
.952 .11456 Mdot
.952 .11498 Mdot
.952 .11515 Mdot
.952 .11535 Mdot
.952 .1155 Mdot
.952 .11598 Mdot
.952 .11789 Mdot
.952 .11805 Mdot
.952 .11834 Mdot
.952 .11897 Mdot
.952 .11942 Mdot
.952 .11947 Mdot
.952 .11992 Mdot
.952 .12039 Mdot
.952 .12168 Mdot
.952 .12194 Mdot
.952 .1225 Mdot
.952 .12321 Mdot
.952 .12328 Mdot
.952 .12353 Mdot
.952 .12391 Mdot
.952 .12397 Mdot
.952 .12495 Mdot
.952 .12559 Mdot
.952 .12568 Mdot
.952 .12658 Mdot
.952 .12681 Mdot
.952 .12696 Mdot
.952 .12709 Mdot
.952 .12737 Mdot
.952 .12742 Mdot
.952 .12763 Mdot
.952 .12889 Mdot
.952 .12925 Mdot
.952 .12978 Mdot
.952 .12989 Mdot
.952 .13061 Mdot
.952 .13116 Mdot
.952 .13144 Mdot
.952 .1325 Mdot
.952 .13312 Mdot
.952 .13369 Mdot
.952 .13409 Mdot
.952 .1347 Mdot
.952 .13481 Mdot
.952 .13505 Mdot
.952 .13643 Mdot
.952 .13727 Mdot
.952 .13912 Mdot
.952 .13939 Mdot
.952 .1394 Mdot
.952 .13993 Mdot
.952 .14089 Mdot
.952 .14152 Mdot
.952 .1416 Mdot
.952 .14312 Mdot
.952 .14345 Mdot
.952 .14352 Mdot
.952 .14382 Mdot
.952 .14465 Mdot
.952 .14468 Mdot
.952 .14478 Mdot
.952 .14498 Mdot
.952 .14534 Mdot
.952 .14622 Mdot
.952 .14638 Mdot
.952 .14738 Mdot
.952 .14742 Mdot
.952 .14788 Mdot
.952 .14793 Mdot
.952 .14912 Mdot
.952 .14925 Mdot
.952 .1494 Mdot
.952 .14947 Mdot
.952 .14969 Mdot
.952 .14993 Mdot
.952 .15074 Mdot
.952 .15075 Mdot
.952 .1531 Mdot
.952 .15312 Mdot
.952 .15322 Mdot
.952 .15338 Mdot
.952 .15373 Mdot
.952 .15408 Mdot
.952 .15436 Mdot
.952 .15566 Mdot
.952 .15638 Mdot
.952 .15662 Mdot
.952 .15682 Mdot
.952 .15715 Mdot
.952 .15854 Mdot
.952 .15955 Mdot
.952 .15976 Mdot
.952 .16023 Mdot
.952 .1605 Mdot
.952 .16113 Mdot
.952 .16137 Mdot
.952 .16159 Mdot
.952 .16169 Mdot
.952 .16193 Mdot
.952 .16195 Mdot
.952 .16204 Mdot
.952 .16207 Mdot
.952 .16388 Mdot
.952 .16467 Mdot
.952 .1647 Mdot
.952 .16476 Mdot
.952 .16498 Mdot
.952 .16528 Mdot
.952 .16541 Mdot
.952 .16564 Mdot
.952 .16699 Mdot
.952 .16714 Mdot
.952 .16736 Mdot
.952 .16744 Mdot
.952 .16761 Mdot
.952 .16925 Mdot
.952 .16982 Mdot
.952 .17057 Mdot
.952 .17073 Mdot
.952 .17138 Mdot
.952 .17149 Mdot
.952 .17174 Mdot
.952 .17444 Mdot
.952 .1748 Mdot
.952 .17515 Mdot
.952 .1757 Mdot
.952 .1761 Mdot
.952 .17789 Mdot
.952 .17801 Mdot
.952 .1799 Mdot
.952 .18028 Mdot
.952 .18064 Mdot
.952 .18115 Mdot
.952 .18119 Mdot
.952 .18303 Mdot
.952 .18318 Mdot
.952 .18518 Mdot
.952 .18519 Mdot
.952 .18584 Mdot
.952 .18741 Mdot
.952 .18764 Mdot
.952 .18777 Mdot
.952 .18807 Mdot
.952 .18924 Mdot
.952 .19006 Mdot
.952 .19099 Mdot
.952 .19134 Mdot
.952 .19188 Mdot
.952 .19212 Mdot
.952 .19261 Mdot
.952 .19405 Mdot
.952 .19439 Mdot
.952 .19555 Mdot
.952 .1956 Mdot
.952 .19571 Mdot
.952 .19633 Mdot
.952 .19642 Mdot
.952 .19652 Mdot
.952 .19678 Mdot
.952 .19702 Mdot
.952 .19755 Mdot
.952 .19771 Mdot
.952 .19794 Mdot
.952 .19847 Mdot
.952 .19851 Mdot
.952 .19877 Mdot
.952 .19952 Mdot
.952 .19959 Mdot
.952 .20003 Mdot
.952 .20059 Mdot
.952 .20101 Mdot
.952 .20109 Mdot
.952 .20116 Mdot
.952 .2015 Mdot
.952 .20175 Mdot
.952 .20221 Mdot
.952 .20283 Mdot
.952 .20482 Mdot
.952 .20543 Mdot
.952 .20562 Mdot
.952 .20585 Mdot
.952 .20589 Mdot
.952 .20594 Mdot
.952 .20604 Mdot
.952 .20633 Mdot
.952 .2066 Mdot
.952 .20674 Mdot
.952 .20753 Mdot
.952 .21002 Mdot
.952 .21116 Mdot
.952 .2114 Mdot
.952 .21146 Mdot
.952 .21201 Mdot
.952 .21264 Mdot
.952 .21323 Mdot
.952 .21407 Mdot
.952 .21417 Mdot
.952 .21442 Mdot
.952 .21502 Mdot
.952 .21506 Mdot
.952 .21558 Mdot
.952 .21568 Mdot
.952 .21592 Mdot
.952 .21703 Mdot
.952 .21765 Mdot
.952 .21838 Mdot
.952 .21888 Mdot
.952 .21957 Mdot
.952 .21994 Mdot
.952 .22011 Mdot
.952 .22023 Mdot
.952 .22128 Mdot
.952 .22142 Mdot
.952 .22153 Mdot
.952 .2219 Mdot
.952 .22262 Mdot
.952 .22273 Mdot
.952 .22279 Mdot
.952 .22388 Mdot
.952 .22461 Mdot
.952 .22545 Mdot
.952 .22582 Mdot
.952 .22599 Mdot
.952 .22652 Mdot
.952 .22706 Mdot
.952 .22741 Mdot
.952 .22771 Mdot
.952 .22814 Mdot
.952 .22843 Mdot
.952 .22868 Mdot
.952 .22922 Mdot
.952 .2293 Mdot
.952 .22936 Mdot
.952 .22966 Mdot
.952 .2297 Mdot
.952 .22987 Mdot
.952 .23098 Mdot
.952 .23111 Mdot
.952 .23172 Mdot
.952 .23211 Mdot
.952 .23219 Mdot
.952 .23278 Mdot
.952 .23352 Mdot
.952 .2338 Mdot
.952 .23401 Mdot
.952 .23538 Mdot
.952 .23574 Mdot
.952 .23622 Mdot
.952 .23643 Mdot
.952 .23697 Mdot
.952 .23844 Mdot
.952 .23898 Mdot
.952 .23983 Mdot
.952 .24012 Mdot
.952 .24015 Mdot
.952 .24123 Mdot
.952 .24162 Mdot
.952 .242 Mdot
.952 .24227 Mdot
.952 .24316 Mdot
.952 .24337 Mdot
.952 .24383 Mdot
.952 .24472 Mdot
.952 .24496 Mdot
.952 .24597 Mdot
.952 .24646 Mdot
.952 .24674 Mdot
.952 .24734 Mdot
.952 .24806 Mdot
.952 .24927 Mdot
.952 .25158 Mdot
.952 .25169 Mdot
.952 .25173 Mdot
.952 .25209 Mdot
.952 .25212 Mdot
.952 .25263 Mdot
.952 .25299 Mdot
.952 .25313 Mdot
.952 .25473 Mdot
.952 .25496 Mdot
.952 .25534 Mdot
.952 .2555 Mdot
.952 .25615 Mdot
.952 .2563 Mdot
.952 .25746 Mdot
.952 .2592 Mdot
.952 .25983 Mdot
.952 .25996 Mdot
.952 .26053 Mdot
.952 .26211 Mdot
.952 .26218 Mdot
.952 .26235 Mdot
.952 .26273 Mdot
.952 .26278 Mdot
.952 .26343 Mdot
.952 .26473 Mdot
.952 .26511 Mdot
.952 .26541 Mdot
.952 .2673 Mdot
.952 .26739 Mdot
.952 .26781 Mdot
.952 .26826 Mdot
.952 .26836 Mdot
.952 .26887 Mdot
.952 .26901 Mdot
.952 .26994 Mdot
.952 .27062 Mdot
.952 .27087 Mdot
.952 .27116 Mdot
.952 .27128 Mdot
.952 .27171 Mdot
.952 .27216 Mdot
.952 .27292 Mdot
.952 .2737 Mdot
.952 .27372 Mdot
.952 .27432 Mdot
.952 .27569 Mdot
.952 .27669 Mdot
.952 .2782 Mdot
.952 .27824 Mdot
.952 .27842 Mdot
.952 .27874 Mdot
.952 .27939 Mdot
.952 .27989 Mdot
.952 .28007 Mdot
.952 .2805 Mdot
.952 .2806 Mdot
.952 .28067 Mdot
.952 .28234 Mdot
.952 .28308 Mdot
.952 .28327 Mdot
.952 .28445 Mdot
.952 .28489 Mdot
.952 .28527 Mdot
.952 .28555 Mdot
.952 .28591 Mdot
.952 .28604 Mdot
.952 .28643 Mdot
.952 .28855 Mdot
.952 .29008 Mdot
.952 .29048 Mdot
.952 .29088 Mdot
.952 .29177 Mdot
.952 .29186 Mdot
.952 .29219 Mdot
.952 .29229 Mdot
.952 .29277 Mdot
.952 .29287 Mdot
.952 .29349 Mdot
.952 .29395 Mdot
.952 .29436 Mdot
.952 .29456 Mdot
.952 .29502 Mdot
.952 .29506 Mdot
.952 .29506 Mdot
.952 .29506 Mdot
.952 .29521 Mdot
.952 .29528 Mdot
.952 .29579 Mdot
.952 .29767 Mdot
.952 .29872 Mdot
.952 .29906 Mdot
.952 .29979 Mdot
.952 .30022 Mdot
.952 .30028 Mdot
.952 .3004 Mdot
.952 .30082 Mdot
.952 .30138 Mdot
.952 .30164 Mdot
.952 .30207 Mdot
.952 .30208 Mdot
.952 .30406 Mdot
.952 .30465 Mdot
.952 .30494 Mdot
.952 .30535 Mdot
.952 .3055 Mdot
.952 .30582 Mdot
.952 .30723 Mdot
.952 .30896 Mdot
.952 .31004 Mdot
.952 .31005 Mdot
.952 .31043 Mdot
.952 .31083 Mdot
.952 .31095 Mdot
.952 .31146 Mdot
.952 .31147 Mdot
.952 .31177 Mdot
.952 .31228 Mdot
.952 .31239 Mdot
.952 .31301 Mdot
.952 .31322 Mdot
.952 .31369 Mdot
.952 .31423 Mdot
.952 .31462 Mdot
.952 .31487 Mdot
.952 .31488 Mdot
.952 .3149 Mdot
.952 .31554 Mdot
.952 .31594 Mdot
.952 .31603 Mdot
.952 .31642 Mdot
.952 .31884 Mdot
.952 .31953 Mdot
.952 .31992 Mdot
.952 .32019 Mdot
.952 .32123 Mdot
.952 .32185 Mdot
.952 .32199 Mdot
.952 .32268 Mdot
.952 .32404 Mdot
.952 .32463 Mdot
.952 .32541 Mdot
.952 .32564 Mdot
.952 .32699 Mdot
.952 .32755 Mdot
.952 .32923 Mdot
.952 .32995 Mdot
.952 .33063 Mdot
.952 .33161 Mdot
.952 .33167 Mdot
.952 .33172 Mdot
.952 .33287 Mdot
.952 .33519 Mdot
.952 .33547 Mdot
.952 .33805 Mdot
.952 .33928 Mdot
.952 .33929 Mdot
.952 .34013 Mdot
.952 .34032 Mdot
.952 .34053 Mdot
.952 .3408 Mdot
.952 .34252 Mdot
.952 .34289 Mdot
.952 .34352 Mdot
.952 .34397 Mdot
.952 .3442 Mdot
.952 .34479 Mdot
.952 .347 Mdot
.952 .34755 Mdot
.952 .34857 Mdot
.952 .3486 Mdot
.952 .34884 Mdot
.952 .34947 Mdot
.952 .35035 Mdot
.952 .35054 Mdot
.952 .35085 Mdot
.952 .35094 Mdot
.952 .35101 Mdot
.952 .35103 Mdot
.952 .35177 Mdot
.952 .35203 Mdot
.952 .3525 Mdot
.952 .35339 Mdot
.952 .35343 Mdot
.952 .35465 Mdot
.952 .35616 Mdot
.952 .35683 Mdot
.952 .3581 Mdot
.952 .35854 Mdot
.952 .35902 Mdot
.952 .35912 Mdot
.952 .35933 Mdot
.952 .35947 Mdot
.952 .36028 Mdot
.952 .36052 Mdot
.952 .36055 Mdot
.952 .36068 Mdot
.952 .36088 Mdot
.952 .36137 Mdot
.952 .36183 Mdot
.952 .36283 Mdot
.952 .36315 Mdot
.952 .36325 Mdot
.952 .36333 Mdot
.952 .36358 Mdot
.952 .36458 Mdot
.952 .36467 Mdot
.952 .36515 Mdot
.952 .36658 Mdot
.952 .36671 Mdot
.952 .36741 Mdot
.952 .36755 Mdot
.952 .36775 Mdot
.952 .36863 Mdot
.952 .36927 Mdot
.952 .36942 Mdot
.952 .36957 Mdot
.952 .3697 Mdot
.952 .37036 Mdot
.952 .37083 Mdot
.952 .37089 Mdot
.952 .37127 Mdot
.952 .3717 Mdot
.952 .37288 Mdot
.952 .37309 Mdot
.952 .3736 Mdot
.952 .37667 Mdot
.952 .37699 Mdot
.952 .37704 Mdot
.952 .37784 Mdot
.952 .3782 Mdot
.952 .37864 Mdot
.952 .37871 Mdot
.952 .37881 Mdot
.952 .379 Mdot
.952 .37947 Mdot
.952 .37955 Mdot
.952 .38007 Mdot
.952 .38034 Mdot
.952 .38036 Mdot
.952 .38106 Mdot
.952 .38141 Mdot
.952 .38184 Mdot
.952 .38184 Mdot
.952 .38308 Mdot
.952 .38341 Mdot
.952 .38503 Mdot
.952 .38593 Mdot
.952 .38658 Mdot
.952 .38696 Mdot
.952 .38779 Mdot
.952 .38874 Mdot
.952 .38915 Mdot
.952 .3892 Mdot
.952 .38932 Mdot
.952 .39037 Mdot
.952 .39061 Mdot
.952 .3907 Mdot
.952 .39156 Mdot
.952 .39268 Mdot
.952 .39287 Mdot
.952 .39429 Mdot
.952 .39448 Mdot
.952 .39495 Mdot
.952 .3961 Mdot
.952 .39616 Mdot
.952 .39715 Mdot
.952 .39735 Mdot
.952 .39781 Mdot
.952 .39783 Mdot
.952 .39887 Mdot
.952 .39993 Mdot
.952 .4011 Mdot
.952 .40144 Mdot
.952 .40249 Mdot
.952 .40344 Mdot
.952 .40477 Mdot
.952 .40546 Mdot
.952 .40578 Mdot
.952 .40602 Mdot
.952 .40693 Mdot
.952 .40706 Mdot
.952 .40772 Mdot
.952 .40802 Mdot
.952 .40824 Mdot
.952 .40828 Mdot
.952 .4085 Mdot
.952 .40887 Mdot
.952 .40919 Mdot
.952 .41056 Mdot
.952 .41078 Mdot
.952 .4108 Mdot
.952 .41088 Mdot
.952 .41125 Mdot
.952 .41297 Mdot
.952 .4137 Mdot
.952 .41435 Mdot
.952 .41528 Mdot
.952 .41562 Mdot
.952 .41589 Mdot
.952 .41595 Mdot
.952 .41666 Mdot
.952 .41698 Mdot
.952 .41799 Mdot
.952 .41827 Mdot
.952 .41834 Mdot
.952 .41902 Mdot
.952 .41968 Mdot
.952 .42025 Mdot
.952 .42107 Mdot
.952 .42164 Mdot
.952 .42192 Mdot
.952 .4221 Mdot
.952 .42313 Mdot
.952 .42329 Mdot
.952 .4234 Mdot
.952 .42398 Mdot
.952 .42405 Mdot
.952 .42437 Mdot
.952 .42461 Mdot
.952 .42532 Mdot
.952 .42648 Mdot
.952 .42673 Mdot
.952 .4279 Mdot
.952 .42863 Mdot
.952 .42878 Mdot
.952 .42957 Mdot
.952 .42991 Mdot
.952 .4312 Mdot
.952 .43132 Mdot
.952 .43185 Mdot
.952 .43226 Mdot
.952 .43257 Mdot
.952 .43359 Mdot
.952 .43486 Mdot
.952 .43488 Mdot
.952 .43535 Mdot
.952 .43554 Mdot
.952 .43646 Mdot
.952 .43677 Mdot
.952 .43686 Mdot
.952 .43789 Mdot
.952 .44068 Mdot
.952 .44171 Mdot
.952 .44333 Mdot
.952 .44388 Mdot
.952 .44395 Mdot
.952 .44444 Mdot
.952 .44601 Mdot
.952 .44674 Mdot
.952 .44746 Mdot
.952 .44799 Mdot
.952 .44967 Mdot
.952 .44999 Mdot
.952 .45008 Mdot
.952 .45095 Mdot
.952 .45145 Mdot
.952 .45264 Mdot
.952 .4529 Mdot
.952 .4531 Mdot
.952 .45502 Mdot
.952 .45595 Mdot
.952 .45613 Mdot
.952 .45643 Mdot
.952 .45649 Mdot
.952 .45763 Mdot
.952 .45764 Mdot
.952 .45802 Mdot
.952 .459 Mdot
.952 .45974 Mdot
.952 .46012 Mdot
.952 .46132 Mdot
.952 .46237 Mdot
.952 .46403 Mdot
.952 .46551 Mdot
.952 .46571 Mdot
.952 .46592 Mdot
.952 .46598 Mdot
.952 .46625 Mdot
.952 .46668 Mdot
.952 .46674 Mdot
.952 .46771 Mdot
.952 .46791 Mdot
.952 .46804 Mdot
.952 .46805 Mdot
.952 .46806 Mdot
.952 .46839 Mdot
.952 .4686 Mdot
.952 .46865 Mdot
.952 .46885 Mdot
.952 .47069 Mdot
.952 .47171 Mdot
.952 .47214 Mdot
.952 .47286 Mdot
.952 .47317 Mdot
.952 .47441 Mdot
.952 .4747 Mdot
.952 .47689 Mdot
.952 .47749 Mdot
.952 .48022 Mdot
.952 .48131 Mdot
.952 .48141 Mdot
.952 .48166 Mdot
.952 .48256 Mdot
.952 .48275 Mdot
.952 .4852 Mdot
.952 .48576 Mdot
.952 .48588 Mdot
.952 .48621 Mdot
.952 .48677 Mdot
.952 .48694 Mdot
.952 .48698 Mdot
.952 .48703 Mdot
.952 .48742 Mdot
.952 .48827 Mdot
.952 .48893 Mdot
.952 .49074 Mdot
.952 .49097 Mdot
.952 .49146 Mdot
.952 .49189 Mdot
.952 .49203 Mdot
.952 .49345 Mdot
.952 .49349 Mdot
.952 .49564 Mdot
.952 .49581 Mdot
.952 .49661 Mdot
.952 .49746 Mdot
.952 .49766 Mdot
.952 .49862 Mdot
.952 .49888 Mdot
.952 .50067 Mdot
.952 .50069 Mdot
.952 .50197 Mdot
.952 .50244 Mdot
.952 .5028 Mdot
.952 .50299 Mdot
.952 .50321 Mdot
.952 .50386 Mdot
.952 .50404 Mdot
.952 .50489 Mdot
.952 .50536 Mdot
.952 .50591 Mdot
.952 .50634 Mdot
.952 .50705 Mdot
.952 .50782 Mdot
.952 .50787 Mdot
.952 .509 Mdot
.952 .51161 Mdot
.952 .51216 Mdot
.952 .51351 Mdot
.952 .51639 Mdot
.952 .51646 Mdot
.952 .51681 Mdot
.952 .51741 Mdot
.952 .51842 Mdot
.952 .51866 Mdot
.952 .51962 Mdot
.952 .51995 Mdot
.952 .52078 Mdot
.952 .52095 Mdot
.952 .5211 Mdot
.952 .52235 Mdot
.952 .52238 Mdot
.952 .52427 Mdot
.952 .52568 Mdot
.952 .52605 Mdot
.952 .52828 Mdot
.952 .52914 Mdot
.952 .52986 Mdot
.952 .53039 Mdot
.952 .53107 Mdot
.952 .53132 Mdot
.952 .53207 Mdot
.952 .53609 Mdot
.952 .53901 Mdot
.952 .53977 Mdot
.952 .54053 Mdot
.952 .54223 Mdot
.952 .54239 Mdot
.952 .54302 Mdot
.952 .54322 Mdot
.952 .54413 Mdot
.952 .54433 Mdot
.952 .54551 Mdot
.952 .54638 Mdot
.952 .54716 Mdot
.952 .54755 Mdot
.952 .54842 Mdot
.952 .54849 Mdot
.952 .54849 Mdot
.952 .5485 Mdot
.952 .54878 Mdot
.952 .54891 Mdot
.952 .54988 Mdot
.952 .55345 Mdot
.952 .55545 Mdot
.952 .55611 Mdot
.952 .5575 Mdot
.952 .55833 Mdot
.952 .55844 Mdot
.952 .55867 Mdot
.952 .55946 Mdot
.952 .56053 Mdot
.952 .56101 Mdot
.952 .56183 Mdot
.952 .56185 Mdot
.952 .56564 Mdot
.952 .56674 Mdot
.952 .5673 Mdot
.952 .56809 Mdot
.952 .56837 Mdot
.952 .56898 Mdot
.952 .57166 Mdot
.952 .57495 Mdot
.952 .57701 Mdot
.952 .57703 Mdot
.954 .01503 Mdot
.954 .01526 Mdot
.954 .01532 Mdot
.954 .01532 Mdot
.954 .01576 Mdot
.954 .01577 Mdot
.954 .01587 Mdot
.954 .01588 Mdot
.954 .01651 Mdot
.954 .01664 Mdot
.954 .01671 Mdot
.954 .01672 Mdot
.954 .01692 Mdot
.954 .01693 Mdot
.954 .01781 Mdot
.954 .01814 Mdot
.954 .0184 Mdot
.954 .01853 Mdot
.954 .01855 Mdot
.954 .01892 Mdot
.954 .01894 Mdot
.954 .02063 Mdot
.954 .02082 Mdot
.954 .02124 Mdot
.954 .0215 Mdot
.954 .02154 Mdot
.954 .02161 Mdot
.954 .02174 Mdot
.954 .02199 Mdot
.954 .02203 Mdot
.954 .02274 Mdot
.954 .02277 Mdot
.954 .02293 Mdot
.954 .02396 Mdot
.954 .02401 Mdot
.954 .02481 Mdot
.954 .02519 Mdot
.954 .026 Mdot
.954 .02636 Mdot
.954 .02717 Mdot
.954 .02753 Mdot
.954 .02766 Mdot
.954 .02773 Mdot
.954 .02787 Mdot
.954 .02811 Mdot
.954 .02859 Mdot
.954 .02868 Mdot
.954 .02874 Mdot
.954 .03003 Mdot
.954 .03005 Mdot
.954 .03009 Mdot
.954 .03009 Mdot
.954 .03039 Mdot
.954 .03216 Mdot
.954 .03235 Mdot
.954 .03245 Mdot
.954 .03398 Mdot
.954 .03471 Mdot
.954 .03624 Mdot
.954 .03694 Mdot
.954 .03847 Mdot
.954 .03916 Mdot
.954 .03942 Mdot
.954 .03956 Mdot
.954 .03982 Mdot
.954 .04028 Mdot
.954 .0403 Mdot
.954 .04119 Mdot
.954 .04135 Mdot
.954 .04148 Mdot
.954 .04393 Mdot
.954 .04398 Mdot
.954 .04405 Mdot
.954 .04405 Mdot
.954 .04462 Mdot
.954 .04484 Mdot
.954 .0464 Mdot
.954 .04674 Mdot
.954 .04681 Mdot
.954 .04786 Mdot
.954 .04792 Mdot
.954 .048 Mdot
.954 .04837 Mdot
.954 .04855 Mdot
.954 .0487 Mdot
.954 .05126 Mdot
.954 .05146 Mdot
.954 .05286 Mdot
.954 .05301 Mdot
.954 .05499 Mdot
.954 .05578 Mdot
.954 .0559 Mdot
.954 .05637 Mdot
.954 .05712 Mdot
.954 .05921 Mdot
.954 .06004 Mdot
.954 .06132 Mdot
.954 .06136 Mdot
.954 .0618 Mdot
.954 .06185 Mdot
.954 .06204 Mdot
.954 .06211 Mdot
.954 .06261 Mdot
.954 .06262 Mdot
.954 .06303 Mdot
.954 .06341 Mdot
.954 .06349 Mdot
.954 .06351 Mdot
.954 .06353 Mdot
.954 .06392 Mdot
.954 .0651 Mdot
.954 .06523 Mdot
.954 .06554 Mdot
.954 .06559 Mdot
.954 .0657 Mdot
.954 .06579 Mdot
.954 .06598 Mdot
.954 .06651 Mdot
.954 .06825 Mdot
.954 .06875 Mdot
.954 .07047 Mdot
.954 .07055 Mdot
.954 .07068 Mdot
.954 .07069 Mdot
.954 .07177 Mdot
.954 .0722 Mdot
.954 .07441 Mdot
.954 .07462 Mdot
.954 .07518 Mdot
.954 .07529 Mdot
.954 .07581 Mdot
.954 .07596 Mdot
.954 .07613 Mdot
.954 .07779 Mdot
.954 .07796 Mdot
.954 .07807 Mdot
.954 .07823 Mdot
.954 .07871 Mdot
.954 .07893 Mdot
.954 .07928 Mdot
.954 .07956 Mdot
.954 .07962 Mdot
.954 .08135 Mdot
.954 .08159 Mdot
.954 .08355 Mdot
.954 .08443 Mdot
.954 .08483 Mdot
.954 .08526 Mdot
.954 .08544 Mdot
.954 .08653 Mdot
.954 .08654 Mdot
.954 .0875 Mdot
.954 .08778 Mdot
.954 .08873 Mdot
.954 .08931 Mdot
.954 .08941 Mdot
.954 .08958 Mdot
.954 .09051 Mdot
.954 .09085 Mdot
.954 .09094 Mdot
.954 .09121 Mdot
.954 .09155 Mdot
.954 .09227 Mdot
.954 .09307 Mdot
.954 .09329 Mdot
.954 .09338 Mdot
.954 .09419 Mdot
.954 .09563 Mdot
.954 .09586 Mdot
.954 .09681 Mdot
.954 .09692 Mdot
.954 .09727 Mdot
.954 .09739 Mdot
.954 .09744 Mdot
.954 .09814 Mdot
.954 .09962 Mdot
.954 .1005 Mdot
.954 .10072 Mdot
.954 .1012 Mdot
.954 .10173 Mdot
.954 .10272 Mdot
.954 .10283 Mdot
.954 .10295 Mdot
.954 .10296 Mdot
.954 .10364 Mdot
.954 .10372 Mdot
.954 .10456 Mdot
.954 .10466 Mdot
.954 .10478 Mdot
.954 .10502 Mdot
.954 .10515 Mdot
.954 .10556 Mdot
.954 .10609 Mdot
.954 .10612 Mdot
.954 .10668 Mdot
.954 .1069 Mdot
.954 .10691 Mdot
.954 .10762 Mdot
.954 .10777 Mdot
.954 .10782 Mdot
.954 .10785 Mdot
.954 .10829 Mdot
.954 .1086 Mdot
.954 .10901 Mdot
.954 .10918 Mdot
.954 .11003 Mdot
.954 .11012 Mdot
.954 .1107 Mdot
.954 .11084 Mdot
.954 .11111 Mdot
.954 .11125 Mdot
.954 .11169 Mdot
.954 .11178 Mdot
.954 .11199 Mdot
.954 .11216 Mdot
.954 .11253 Mdot
.954 .11265 Mdot
.954 .11321 Mdot
.954 .11355 Mdot
.954 .11383 Mdot
.954 .11476 Mdot
.954 .11496 Mdot
.954 .11588 Mdot
.954 .11686 Mdot
.954 .11726 Mdot
.954 .11782 Mdot
.954 .11827 Mdot
.954 .12009 Mdot
.954 .12109 Mdot
.954 .12109 Mdot
.954 .12124 Mdot
.954 .12149 Mdot
.954 .12152 Mdot
.954 .12221 Mdot
.954 .12267 Mdot
.954 .12357 Mdot
.954 .12412 Mdot
.954 .12439 Mdot
.954 .12479 Mdot
.954 .12533 Mdot
.954 .12596 Mdot
.954 .12621 Mdot
.954 .12662 Mdot
.954 .12741 Mdot
.954 .12786 Mdot
.954 .12861 Mdot
.954 .12902 Mdot
.954 .12914 Mdot
.954 .12955 Mdot
.954 .12995 Mdot
.954 .12996 Mdot
.954 .13008 Mdot
.954 .1303 Mdot
.954 .13079 Mdot
.954 .13128 Mdot
.954 .13157 Mdot
.954 .13189 Mdot
.954 .1347 Mdot
.954 .13506 Mdot
.954 .13539 Mdot
.954 .1356 Mdot
.954 .1359 Mdot
.954 .13682 Mdot
.954 .13705 Mdot
.954 .1371 Mdot
.954 .13724 Mdot
.954 .1379 Mdot
.954 .13839 Mdot
.954 .13844 Mdot
.954 .13855 Mdot
.954 .13902 Mdot
.954 .14093 Mdot
.954 .14186 Mdot
.954 .14231 Mdot
.954 .14234 Mdot
.954 .14546 Mdot
.954 .14605 Mdot
.954 .14685 Mdot
.954 .14714 Mdot
.954 .14774 Mdot
.954 .1485 Mdot
.954 .14932 Mdot
.954 .14942 Mdot
.954 .14965 Mdot
.954 .15052 Mdot
.954 .15175 Mdot
.954 .15175 Mdot
.954 .15322 Mdot
.954 .1536 Mdot
.954 .15411 Mdot
.954 .15478 Mdot
.954 .15594 Mdot
.954 .15705 Mdot
.954 .15723 Mdot
.954 .15756 Mdot
.954 .15802 Mdot
.954 .15933 Mdot
.954 .15943 Mdot
.954 .15997 Mdot
.954 .16004 Mdot
.954 .16015 Mdot
.954 .16063 Mdot
.954 .16068 Mdot
.954 .16094 Mdot
.954 .16132 Mdot
.954 .16208 Mdot
.954 .16246 Mdot
.954 .16269 Mdot
.954 .16284 Mdot
.954 .16318 Mdot
.954 .16422 Mdot
.954 .1643 Mdot
.954 .16463 Mdot
.954 .16482 Mdot
.954 .16635 Mdot
.954 .16673 Mdot
.954 .1691 Mdot
.954 .16953 Mdot
.954 .16983 Mdot
.954 .17018 Mdot
.954 .17021 Mdot
.954 .17136 Mdot
.954 .17156 Mdot
.954 .17194 Mdot
.954 .17222 Mdot
.954 .17246 Mdot
.954 .17256 Mdot
.954 .1739 Mdot
.954 .17391 Mdot
.954 .17671 Mdot
.954 .17796 Mdot
.954 .17839 Mdot
.954 .17879 Mdot
.954 .17881 Mdot
.954 .17972 Mdot
.954 .1802 Mdot
.954 .18075 Mdot
.954 .18249 Mdot
.954 .18262 Mdot
.954 .18284 Mdot
.954 .18306 Mdot
.954 .18309 Mdot
.954 .1832 Mdot
.954 .18369 Mdot
.954 .18439 Mdot
.954 .18453 Mdot
.954 .18614 Mdot
.954 .18632 Mdot
.954 .18655 Mdot
.954 .18701 Mdot
.954 .18726 Mdot
.954 .18805 Mdot
.954 .18906 Mdot
.954 .18911 Mdot
.954 .18941 Mdot
.954 .18941 Mdot
.954 .19018 Mdot
.954 .1902 Mdot
.954 .19025 Mdot
.954 .1905 Mdot
.954 .1906 Mdot
.954 .19062 Mdot
.954 .19197 Mdot
.954 .19224 Mdot
.954 .19226 Mdot
.954 .19236 Mdot
.954 .19239 Mdot
.954 .19241 Mdot
.954 .19325 Mdot
.954 .19359 Mdot
.954 .19386 Mdot
.954 .19392 Mdot
.954 .19464 Mdot
.954 .19494 Mdot
.954 .19659 Mdot
.954 .19674 Mdot
.954 .19722 Mdot
.954 .19785 Mdot
.954 .19813 Mdot
.954 .19863 Mdot
.954 .1989 Mdot
.954 .19974 Mdot
.954 .19992 Mdot
.954 .20031 Mdot
.954 .20042 Mdot
.954 .20064 Mdot
.954 .20123 Mdot
.954 .20134 Mdot
.954 .20157 Mdot
.954 .20264 Mdot
.954 .20329 Mdot
.954 .20366 Mdot
.954 .20383 Mdot
.954 .20435 Mdot
.954 .2056 Mdot
.954 .20598 Mdot
.954 .20669 Mdot
.954 .20699 Mdot
.954 .20773 Mdot
.954 .2096 Mdot
.954 .20977 Mdot
.954 .20985 Mdot
.954 .21037 Mdot
.954 .21046 Mdot
.954 .21144 Mdot
.954 .21229 Mdot
.954 .21239 Mdot
.954 .21287 Mdot
.954 .21453 Mdot
.954 .21475 Mdot
.954 .21514 Mdot
.954 .21577 Mdot
.954 .21597 Mdot
.954 .21767 Mdot
.954 .21767 Mdot
.954 .21797 Mdot
.954 .21845 Mdot
.954 .21849 Mdot
.954 .21891 Mdot
.954 .21982 Mdot
.954 .2207 Mdot
.954 .22158 Mdot
.954 .22178 Mdot
.954 .22242 Mdot
.954 .22329 Mdot
.954 .22345 Mdot
.954 .22398 Mdot
.954 .22412 Mdot
.954 .22474 Mdot
.954 .22497 Mdot
.954 .22577 Mdot
.954 .22656 Mdot
.954 .22698 Mdot
.954 .22744 Mdot
.954 .22788 Mdot
.954 .22824 Mdot
.954 .22884 Mdot
.954 .22974 Mdot
.954 .23007 Mdot
.954 .23044 Mdot
.954 .2306 Mdot
.954 .23202 Mdot
.954 .23279 Mdot
.954 .23281 Mdot
.954 .23304 Mdot
.954 .23334 Mdot
.954 .23382 Mdot
.954 .23456 Mdot
.954 .23458 Mdot
.954 .2346 Mdot
.954 .23483 Mdot
.954 .23512 Mdot
.954 .23525 Mdot
.954 .23591 Mdot
.954 .23619 Mdot
.954 .23647 Mdot
.954 .23713 Mdot
.954 .23767 Mdot
.954 .23829 Mdot
.954 .23833 Mdot
.954 .24164 Mdot
.954 .24364 Mdot
.954 .24433 Mdot
.954 .24433 Mdot
.954 .24445 Mdot
.954 .24454 Mdot
.954 .24497 Mdot
.954 .24535 Mdot
.954 .24537 Mdot
.954 .24582 Mdot
.954 .24593 Mdot
.954 .24645 Mdot
.954 .24768 Mdot
.954 .24812 Mdot
.954 .2482 Mdot
.954 .24823 Mdot
.954 .24848 Mdot
.954 .24976 Mdot
.954 .25069 Mdot
.954 .25078 Mdot
.954 .25089 Mdot
.954 .25095 Mdot
.954 .25099 Mdot
.954 .25106 Mdot
.954 .25188 Mdot
.954 .2519 Mdot
.954 .25292 Mdot
.954 .25342 Mdot
.954 .25553 Mdot
.954 .2558 Mdot
.954 .25683 Mdot
.954 .25731 Mdot
.954 .25786 Mdot
.954 .25816 Mdot
.954 .25823 Mdot
.954 .26025 Mdot
.954 .2605 Mdot
.954 .26156 Mdot
.954 .26176 Mdot
.954 .26223 Mdot
.954 .26292 Mdot
.954 .26418 Mdot
.954 .26448 Mdot
.954 .26463 Mdot
.954 .26472 Mdot
.954 .26531 Mdot
.954 .26683 Mdot
.954 .26692 Mdot
.954 .26719 Mdot
.954 .26738 Mdot
.954 .26852 Mdot
.954 .26928 Mdot
.954 .26997 Mdot
.954 .27154 Mdot
.954 .27174 Mdot
.954 .27212 Mdot
.954 .27218 Mdot
.954 .27329 Mdot
.954 .27382 Mdot
.954 .27617 Mdot
.954 .27618 Mdot
.954 .27666 Mdot
.954 .27776 Mdot
.954 .27899 Mdot
.954 .2797 Mdot
.954 .28069 Mdot
.954 .28196 Mdot
.954 .28396 Mdot
.954 .28418 Mdot
.954 .28629 Mdot
.954 .28644 Mdot
.954 .28647 Mdot
.954 .28664 Mdot
.954 .2869 Mdot
.954 .28721 Mdot
.954 .28725 Mdot
.954 .28755 Mdot
.954 .28796 Mdot
.954 .28813 Mdot
.954 .28877 Mdot
.954 .29018 Mdot
.954 .29024 Mdot
.954 .29065 Mdot
.954 .29077 Mdot
.954 .29083 Mdot
.954 .2916 Mdot
.954 .29187 Mdot
.954 .29188 Mdot
.954 .292 Mdot
.954 .29206 Mdot
.954 .29221 Mdot
.954 .29229 Mdot
.954 .29313 Mdot
.954 .29321 Mdot
.954 .29371 Mdot
.954 .29417 Mdot
.954 .29444 Mdot
.954 .29589 Mdot
.954 .29662 Mdot
.954 .29704 Mdot
.954 .29734 Mdot
.954 .29738 Mdot
.954 .29798 Mdot
.954 .29867 Mdot
.954 .29925 Mdot
.954 .29933 Mdot
.954 .29996 Mdot
.954 .30012 Mdot
.954 .30013 Mdot
.954 .30027 Mdot
.954 .30053 Mdot
.954 .3006 Mdot
.954 .30067 Mdot
.954 .30076 Mdot
.954 .30111 Mdot
.954 .30158 Mdot
.954 .30162 Mdot
.954 .30217 Mdot
.954 .30404 Mdot
.954 .30476 Mdot
.954 .30622 Mdot
.954 .30798 Mdot
.954 .30855 Mdot
.954 .30927 Mdot
.954 .30963 Mdot
.954 .30993 Mdot
.954 .3101 Mdot
.954 .31035 Mdot
.954 .31056 Mdot
.954 .31068 Mdot
.954 .31071 Mdot
.954 .31095 Mdot
.954 .31134 Mdot
.954 .31141 Mdot
.954 .31202 Mdot
.954 .3136 Mdot
.954 .31395 Mdot
.954 .31397 Mdot
.954 .31401 Mdot
.954 .3147 Mdot
.954 .31524 Mdot
.954 .31527 Mdot
.954 .31569 Mdot
.954 .31589 Mdot
.954 .31711 Mdot
.954 .31775 Mdot
.954 .31843 Mdot
.954 .31845 Mdot
.954 .31954 Mdot
.954 .3238 Mdot
.954 .32619 Mdot
.954 .327 Mdot
.954 .32718 Mdot
.954 .32722 Mdot
.954 .32777 Mdot
.954 .3278 Mdot
.954 .32821 Mdot
.954 .32955 Mdot
.954 .33047 Mdot
.954 .3315 Mdot
.954 .33198 Mdot
.954 .33223 Mdot
.954 .33372 Mdot
.954 .33482 Mdot
.954 .33508 Mdot
.954 .3352 Mdot
.954 .3355 Mdot
.954 .33572 Mdot
.954 .33592 Mdot
.954 .33597 Mdot
.954 .33619 Mdot
.954 .3368 Mdot
.954 .33706 Mdot
.954 .33712 Mdot
.954 .33726 Mdot
.954 .33754 Mdot
.954 .33845 Mdot
.954 .33872 Mdot
.954 .34168 Mdot
.954 .3418 Mdot
.954 .34215 Mdot
.954 .34258 Mdot
.954 .34345 Mdot
.954 .34394 Mdot
.954 .34441 Mdot
.954 .34532 Mdot
.954 .34544 Mdot
.954 .34647 Mdot
.954 .34737 Mdot
.954 .34746 Mdot
.954 .34804 Mdot
.954 .34804 Mdot
.954 .34919 Mdot
.954 .34949 Mdot
.954 .34954 Mdot
.954 .34963 Mdot
.954 .34993 Mdot
.954 .35012 Mdot
.954 .3503 Mdot
.954 .35035 Mdot
.954 .35049 Mdot
.954 .35104 Mdot
.954 .35163 Mdot
.954 .35292 Mdot
.954 .35343 Mdot
.954 .35348 Mdot
.954 .35366 Mdot
.954 .35373 Mdot
.954 .35376 Mdot
.954 .35412 Mdot
.954 .35536 Mdot
.954 .35547 Mdot
.954 .356 Mdot
.954 .35652 Mdot
.954 .35658 Mdot
.954 .35664 Mdot
.954 .35665 Mdot
.954 .3576 Mdot
.954 .35801 Mdot
.954 .35859 Mdot
.954 .35872 Mdot
.954 .35944 Mdot
.954 .35982 Mdot
.954 .3599 Mdot
.954 .36035 Mdot
.954 .3604 Mdot
.954 .3607 Mdot
.954 .36099 Mdot
.954 .36172 Mdot
.954 .36202 Mdot
.954 .36234 Mdot
.954 .36283 Mdot
.954 .36293 Mdot
.954 .36342 Mdot
.954 .36414 Mdot
.954 .36467 Mdot
.954 .36562 Mdot
.954 .36615 Mdot
.954 .36674 Mdot
.954 .36698 Mdot
.954 .36773 Mdot
.954 .36809 Mdot
.954 .36837 Mdot
.954 .3687 Mdot
.954 .36883 Mdot
.954 .36905 Mdot
.954 .36946 Mdot
.954 .3697 Mdot
.954 .37037 Mdot
.954 .37058 Mdot
.954 .37079 Mdot
.954 .3708 Mdot
.954 .37123 Mdot
.954 .37328 Mdot
.954 .37451 Mdot
.954 .37454 Mdot
.954 .37522 Mdot
.954 .37555 Mdot
.954 .37654 Mdot
.954 .37729 Mdot
.954 .37892 Mdot
.954 .37965 Mdot
.954 .3798 Mdot
.954 .381 Mdot
.954 .38157 Mdot
.954 .38299 Mdot
.954 .38381 Mdot
.954 .3855 Mdot
.954 .38624 Mdot
.954 .38656 Mdot
.954 .38687 Mdot
.954 .38703 Mdot
.954 .38763 Mdot
.954 .38783 Mdot
.954 .38803 Mdot
.954 .38821 Mdot
.954 .38879 Mdot
.954 .39007 Mdot
.954 .3917 Mdot
.954 .39187 Mdot
.954 .39189 Mdot
.954 .3928 Mdot
.954 .39383 Mdot
.954 .39595 Mdot
.954 .39639 Mdot
.954 .39713 Mdot
.954 .39833 Mdot
.954 .3987 Mdot
.954 .39896 Mdot
.954 .40196 Mdot
.954 .40196 Mdot
.954 .40237 Mdot
.954 .40239 Mdot
.954 .40253 Mdot
.954 .40344 Mdot
.954 .40352 Mdot
.954 .40414 Mdot
.954 .40432 Mdot
.954 .40605 Mdot
.954 .40773 Mdot
.954 .40815 Mdot
.954 .40942 Mdot
.954 .40979 Mdot
.954 .41101 Mdot
.954 .41117 Mdot
.954 .41262 Mdot
.954 .41267 Mdot
.954 .41299 Mdot
.954 .414 Mdot
.954 .41425 Mdot
.954 .41512 Mdot
.954 .41524 Mdot
.954 .41544 Mdot
.954 .41587 Mdot
.954 .41742 Mdot
.954 .41882 Mdot
.954 .41892 Mdot
.954 .41971 Mdot
.954 .42015 Mdot
.954 .42059 Mdot
.954 .42143 Mdot
.954 .42212 Mdot
.954 .42262 Mdot
.954 .42327 Mdot
.954 .42346 Mdot
.954 .42469 Mdot
.954 .42498 Mdot
.954 .42562 Mdot
.954 .42591 Mdot
.954 .42632 Mdot
.954 .42662 Mdot
.954 .4276 Mdot
.954 .42933 Mdot
.954 .43074 Mdot
.954 .4308 Mdot
.954 .43085 Mdot
.954 .43128 Mdot
.954 .43152 Mdot
.954 .43185 Mdot
.954 .43277 Mdot
.954 .43418 Mdot
.954 .43421 Mdot
.954 .43426 Mdot
.954 .4347 Mdot
.954 .43524 Mdot
.954 .4355 Mdot
.954 .43675 Mdot
.954 .43729 Mdot
.954 .43783 Mdot
.954 .43908 Mdot
.954 .43921 Mdot
.954 .43977 Mdot
.954 .43988 Mdot
.954 .44012 Mdot
.954 .44048 Mdot
.954 .4413 Mdot
.954 .44138 Mdot
.954 .44143 Mdot
.954 .44258 Mdot
.954 .44272 Mdot
.954 .44382 Mdot
.954 .4453 Mdot
.954 .44592 Mdot
.954 .44768 Mdot
.954 .44826 Mdot
.954 .45151 Mdot
.954 .45281 Mdot
.954 .45283 Mdot
.954 .45305 Mdot
.954 .45322 Mdot
.954 .45339 Mdot
.954 .45361 Mdot
.954 .45403 Mdot
.954 .45477 Mdot
.954 .4548 Mdot
.954 .45508 Mdot
.954 .45551 Mdot
.954 .45566 Mdot
.954 .45576 Mdot
.954 .45588 Mdot
.954 .45686 Mdot
.954 .45854 Mdot
.954 .45922 Mdot
.954 .45952 Mdot
.954 .45956 Mdot
.954 .45999 Mdot
.954 .46006 Mdot
.954 .4602 Mdot
.954 .46023 Mdot
.954 .46027 Mdot
.954 .46075 Mdot
.954 .46077 Mdot
.954 .46105 Mdot
.954 .46318 Mdot
.954 .4641 Mdot
.954 .4644 Mdot
.954 .46496 Mdot
.954 .46512 Mdot
.954 .46534 Mdot
.954 .46545 Mdot
.954 .46553 Mdot
.954 .46565 Mdot
.954 .46622 Mdot
.954 .46723 Mdot
.954 .46726 Mdot
.954 .46792 Mdot
.954 .46888 Mdot
.954 .46922 Mdot
.954 .47016 Mdot
.954 .47416 Mdot
.954 .47418 Mdot
.954 .4747 Mdot
.954 .47668 Mdot
.954 .47681 Mdot
.954 .47759 Mdot
.954 .47837 Mdot
.954 .47864 Mdot
.954 .4792 Mdot
.954 .47934 Mdot
.954 .47945 Mdot
.954 .47959 Mdot
.954 .48176 Mdot
.954 .48319 Mdot
.954 .48367 Mdot
.954 .48427 Mdot
.954 .4857 Mdot
.954 .48609 Mdot
.954 .48638 Mdot
.954 .48667 Mdot
.954 .48697 Mdot
.954 .48828 Mdot
.954 .48899 Mdot
.954 .48957 Mdot
.954 .48961 Mdot
.954 .4901 Mdot
.954 .49069 Mdot
.954 .49107 Mdot
.954 .49127 Mdot
.954 .49131 Mdot
.954 .49155 Mdot
.954 .49157 Mdot
.954 .49173 Mdot
.954 .49188 Mdot
.954 .49259 Mdot
.954 .49285 Mdot
.954 .49315 Mdot
.954 .49489 Mdot
.954 .49502 Mdot
.954 .49575 Mdot
.954 .49592 Mdot
.954 .49645 Mdot
.954 .4968 Mdot
.954 .49702 Mdot
.954 .49898 Mdot
.954 .50042 Mdot
.954 .50174 Mdot
.954 .50384 Mdot
.954 .50473 Mdot
.954 .50512 Mdot
.954 .50585 Mdot
.954 .50595 Mdot
.954 .50645 Mdot
.954 .50808 Mdot
.954 .50909 Mdot
.954 .51178 Mdot
.954 .51357 Mdot
.954 .51358 Mdot
.954 .5145 Mdot
.954 .5166 Mdot
.954 .51818 Mdot
.954 .51894 Mdot
.954 .52025 Mdot
.954 .52031 Mdot
.954 .52219 Mdot
.954 .52289 Mdot
.954 .52418 Mdot
.954 .52462 Mdot
.954 .52527 Mdot
.954 .52591 Mdot
.954 .52679 Mdot
.954 .52844 Mdot
.954 .52885 Mdot
.954 .53288 Mdot
.954 .53317 Mdot
.954 .53323 Mdot
.954 .53354 Mdot
.954 .53404 Mdot
.954 .53464 Mdot
.954 .53472 Mdot
.954 .53529 Mdot
.954 .53607 Mdot
.954 .53639 Mdot
.954 .53762 Mdot
.954 .54031 Mdot
.954 .54042 Mdot
.954 .54119 Mdot
.954 .54142 Mdot
.954 .54155 Mdot
.954 .54301 Mdot
.954 .54352 Mdot
.954 .54354 Mdot
.954 .54377 Mdot
.954 .5439 Mdot
.954 .54418 Mdot
.954 .54433 Mdot
.954 .54592 Mdot
.954 .54608 Mdot
.954 .54703 Mdot
.954 .54792 Mdot
.954 .54843 Mdot
.954 .5512 Mdot
.954 .55258 Mdot
.954 .5534 Mdot
.954 .55397 Mdot
.954 .55404 Mdot
.954 .55518 Mdot
.954 .5565 Mdot
.954 .5576 Mdot
.954 .55775 Mdot
.954 .55897 Mdot
.954 .55927 Mdot
.954 .55929 Mdot
.954 .55955 Mdot
.954 .56006 Mdot
.954 .56019 Mdot
.954 .56032 Mdot
.954 .56048 Mdot
.954 .56115 Mdot
.954 .56206 Mdot
.954 .56213 Mdot
.954 .56318 Mdot
.954 .56675 Mdot
.954 .56812 Mdot
.954 .57091 Mdot
.954 .57427 Mdot
.954 .57535 Mdot
.954 .57673 Mdot
.954 .57741 Mdot
.954 .57798 Mdot
.954 .57832 Mdot
.954 .57878 Mdot
.956 .01594 Mdot
.956 .01658 Mdot
.956 .01705 Mdot
.956 .01756 Mdot
.956 .01767 Mdot
.956 .01829 Mdot
.956 .01914 Mdot
.956 .01918 Mdot
.956 .01972 Mdot
.956 .02015 Mdot
.956 .02037 Mdot
.956 .02145 Mdot
.956 .02154 Mdot
.956 .02317 Mdot
.956 .02325 Mdot
.956 .02335 Mdot
.956 .02429 Mdot
.956 .0251 Mdot
.956 .02545 Mdot
.956 .02553 Mdot
.956 .02572 Mdot
.956 .02603 Mdot
.956 .02623 Mdot
.956 .02651 Mdot
.956 .02759 Mdot
.956 .02777 Mdot
.956 .02831 Mdot
.956 .03068 Mdot
.956 .03088 Mdot
.956 .03103 Mdot
.956 .03123 Mdot
.956 .03178 Mdot
.956 .03275 Mdot
.956 .03302 Mdot
.956 .03317 Mdot
.956 .03336 Mdot
.956 .03457 Mdot
.956 .03476 Mdot
.956 .0348 Mdot
.956 .03525 Mdot
.956 .0354 Mdot
.956 .03575 Mdot
.956 .03581 Mdot
.956 .03634 Mdot
.956 .03673 Mdot
.956 .03704 Mdot
.956 .03726 Mdot
.956 .03746 Mdot
.956 .03902 Mdot
.956 .03934 Mdot
.956 .03968 Mdot
.956 .04071 Mdot
.956 .04102 Mdot
.956 .04213 Mdot
.956 .04219 Mdot
.956 .0422 Mdot
.956 .04389 Mdot
.956 .04451 Mdot
.956 .04456 Mdot
.956 .04487 Mdot
.956 .04518 Mdot
.956 .04525 Mdot
.956 .04562 Mdot
.956 .04591 Mdot
.956 .04628 Mdot
.956 .04735 Mdot
.956 .04882 Mdot
.956 .04891 Mdot
.956 .0492 Mdot
.956 .04971 Mdot
.956 .04972 Mdot
.956 .05001 Mdot
.956 .05005 Mdot
.956 .05036 Mdot
.956 .05127 Mdot
.956 .05133 Mdot
.956 .05141 Mdot
.956 .05269 Mdot
.956 .05304 Mdot
.956 .05312 Mdot
.956 .05314 Mdot
.956 .05342 Mdot
.956 .0539 Mdot
.956 .05397 Mdot
.956 .05426 Mdot
.956 .05466 Mdot
.956 .05494 Mdot
.956 .05505 Mdot
.956 .05538 Mdot
.956 .05607 Mdot
.956 .05682 Mdot
.956 .05711 Mdot
.956 .05739 Mdot
.956 .05782 Mdot
.956 .05821 Mdot
.956 .05869 Mdot
.956 .05907 Mdot
.956 .06119 Mdot
.956 .06119 Mdot
.956 .0618 Mdot
.956 .06227 Mdot
.956 .06244 Mdot
.956 .06442 Mdot
.956 .065 Mdot
.956 .06592 Mdot
.956 .06714 Mdot
.956 .06725 Mdot
.956 .06726 Mdot
.956 .06881 Mdot
.956 .06915 Mdot
.956 .0705 Mdot
.956 .07053 Mdot
.956 .07055 Mdot
.956 .07169 Mdot
.956 .0717 Mdot
.956 .07177 Mdot
.956 .07237 Mdot
.956 .07297 Mdot
.956 .0731 Mdot
.956 .0738 Mdot
.956 .07436 Mdot
.956 .07508 Mdot
.956 .07535 Mdot
.956 .07605 Mdot
.956 .07712 Mdot
.956 .07827 Mdot
.956 .07837 Mdot
.956 .07858 Mdot
.956 .07863 Mdot
.956 .07931 Mdot
.956 .07948 Mdot
.956 .07967 Mdot
.956 .07993 Mdot
.956 .08009 Mdot
.956 .08065 Mdot
.956 .08066 Mdot
.956 .08137 Mdot
.956 .08163 Mdot
.956 .08163 Mdot
.956 .0822 Mdot
.956 .08228 Mdot
.956 .08265 Mdot
.956 .08275 Mdot
.956 .08286 Mdot
.956 .08461 Mdot
.956 .08472 Mdot
.956 .08478 Mdot
.956 .08486 Mdot
.956 .08487 Mdot
.956 .08722 Mdot
.956 .08732 Mdot
.956 .08788 Mdot
.956 .08799 Mdot
.956 .08814 Mdot
.956 .08818 Mdot
.956 .08872 Mdot
.956 .08909 Mdot
.956 .08964 Mdot
.956 .08978 Mdot
.956 .09005 Mdot
.956 .09032 Mdot
.956 .09108 Mdot
.956 .09144 Mdot
.956 .09162 Mdot
.956 .09183 Mdot
.956 .09248 Mdot
.956 .0928 Mdot
.956 .09348 Mdot
.956 .09378 Mdot
.956 .09426 Mdot
.956 .09501 Mdot
.956 .09521 Mdot
.956 .09577 Mdot
.956 .096 Mdot
.956 .09631 Mdot
.956 .09713 Mdot
.956 .09721 Mdot
.956 .09724 Mdot
.956 .09788 Mdot
.956 .09879 Mdot
.956 .09953 Mdot
.956 .10049 Mdot
.956 .10083 Mdot
.956 .10131 Mdot
.956 .10358 Mdot
.956 .10358 Mdot
.956 .10427 Mdot
.956 .10474 Mdot
.956 .10486 Mdot
.956 .10563 Mdot
.956 .10597 Mdot
.956 .10687 Mdot
.956 .10799 Mdot
.956 .10956 Mdot
.956 .10972 Mdot
.956 .10974 Mdot
.956 .11034 Mdot
.956 .11058 Mdot
.956 .11087 Mdot
.956 .11235 Mdot
.956 .11263 Mdot
.956 .11345 Mdot
.956 .11359 Mdot
.956 .11495 Mdot
.956 .11517 Mdot
.956 .11519 Mdot
.956 .11519 Mdot
.956 .11579 Mdot
.956 .11681 Mdot
.956 .11779 Mdot
.956 .11815 Mdot
.956 .11879 Mdot
.956 .11944 Mdot
.956 .12038 Mdot
.956 .12063 Mdot
.956 .12083 Mdot
.956 .12137 Mdot
.956 .12143 Mdot
.956 .12146 Mdot
.956 .12147 Mdot
.956 .12226 Mdot
.956 .12364 Mdot
.956 .12368 Mdot
.956 .1238 Mdot
.956 .12495 Mdot
.956 .12506 Mdot
.956 .1258 Mdot
.956 .12609 Mdot
.956 .12634 Mdot
.956 .12769 Mdot
.956 .12875 Mdot
.956 .13012 Mdot
.956 .1306 Mdot
.956 .13064 Mdot
.956 .1318 Mdot
.956 .13199 Mdot
.956 .13219 Mdot
.956 .13308 Mdot
.956 .13375 Mdot
.956 .13403 Mdot
.956 .13486 Mdot
.956 .13623 Mdot
.956 .13643 Mdot
.956 .13682 Mdot
.956 .13691 Mdot
.956 .13737 Mdot
.956 .13823 Mdot
.956 .13854 Mdot
.956 .13892 Mdot
.956 .1394 Mdot
.956 .13948 Mdot
.956 .13972 Mdot
.956 .14018 Mdot
.956 .14052 Mdot
.956 .14077 Mdot
.956 .14079 Mdot
.956 .14107 Mdot
.956 .14173 Mdot
.956 .14216 Mdot
.956 .14265 Mdot
.956 .14266 Mdot
.956 .14289 Mdot
.956 .14374 Mdot
.956 .14391 Mdot
.956 .1446 Mdot
.956 .14464 Mdot
.956 .14479 Mdot
.956 .14501 Mdot
.956 .14669 Mdot
.956 .14836 Mdot
.956 .14857 Mdot
.956 .14868 Mdot
.956 .14884 Mdot
.956 .14886 Mdot
.956 .14961 Mdot
.956 .15001 Mdot
.956 .15008 Mdot
.956 .15153 Mdot
.956 .15164 Mdot
.956 .15167 Mdot
.956 .15258 Mdot
.956 .15335 Mdot
.956 .15353 Mdot
.956 .15447 Mdot
.956 .1546 Mdot
.956 .15481 Mdot
.956 .15511 Mdot
.956 .15519 Mdot
.956 .15584 Mdot
.956 .15622 Mdot
.956 .1564 Mdot
.956 .15691 Mdot
.956 .15738 Mdot
.956 .15798 Mdot
.956 .15824 Mdot
.956 .15875 Mdot
.956 .15879 Mdot
.956 .15928 Mdot
.956 .16073 Mdot
.956 .16091 Mdot
.956 .16116 Mdot
.956 .16136 Mdot
.956 .16141 Mdot
.956 .16145 Mdot
.956 .16176 Mdot
.956 .16215 Mdot
.956 .16297 Mdot
.956 .16339 Mdot
.956 .16402 Mdot
.956 .16465 Mdot
.956 .16532 Mdot
.956 .16589 Mdot
.956 .16606 Mdot
.956 .16657 Mdot
.956 .1668 Mdot
.956 .1669 Mdot
.956 .16823 Mdot
.956 .16862 Mdot
.956 .16903 Mdot
.956 .16969 Mdot
.956 .16987 Mdot
.956 .17014 Mdot
.956 .17017 Mdot
.956 .17073 Mdot
.956 .1712 Mdot
.956 .1723 Mdot
.956 .17237 Mdot
.956 .17245 Mdot
.956 .17251 Mdot
.956 .17373 Mdot
.956 .17441 Mdot
.956 .17547 Mdot
.956 .17655 Mdot
.956 .17686 Mdot
.956 .17688 Mdot
.956 .17752 Mdot
.956 .17871 Mdot
.956 .17938 Mdot
.956 .18029 Mdot
.956 .18139 Mdot
.956 .18207 Mdot
.956 .18463 Mdot
.956 .18463 Mdot
.956 .18595 Mdot
.956 .18684 Mdot
.956 .18703 Mdot
.956 .18708 Mdot
.956 .18794 Mdot
.956 .18797 Mdot
.956 .18853 Mdot
.956 .18855 Mdot
.956 .18919 Mdot
.956 .18937 Mdot
.956 .1897 Mdot
.956 .19035 Mdot
.956 .19091 Mdot
.956 .19112 Mdot
.956 .1916 Mdot
.956 .19305 Mdot
.956 .19487 Mdot
.956 .19531 Mdot
.956 .19552 Mdot
.956 .19558 Mdot
.956 .19607 Mdot
.956 .19637 Mdot
.956 .19641 Mdot
.956 .19684 Mdot
.956 .19756 Mdot
.956 .19801 Mdot
.956 .19839 Mdot
.956 .19856 Mdot
.956 .19878 Mdot
.956 .19954 Mdot
.956 .19975 Mdot
.956 .20106 Mdot
.956 .20139 Mdot
.956 .20192 Mdot
.956 .20223 Mdot
.956 .20349 Mdot
.956 .20368 Mdot
.956 .20377 Mdot
.956 .20392 Mdot
.956 .20442 Mdot
.956 .20637 Mdot
.956 .20678 Mdot
.956 .20682 Mdot
.956 .20682 Mdot
.956 .20796 Mdot
.956 .20991 Mdot
.956 .21076 Mdot
.956 .2109 Mdot
.956 .21099 Mdot
.956 .2118 Mdot
.956 .21188 Mdot
.956 .21249 Mdot
.956 .21304 Mdot
.956 .21371 Mdot
.956 .21495 Mdot
.956 .2165 Mdot
.956 .21674 Mdot
.956 .21714 Mdot
.956 .21723 Mdot
.956 .21761 Mdot
.956 .21864 Mdot
.956 .21876 Mdot
.956 .21882 Mdot
.956 .21883 Mdot
.956 .21992 Mdot
.956 .22033 Mdot
.956 .22065 Mdot
.956 .22105 Mdot
.956 .22125 Mdot
.956 .22299 Mdot
.956 .22305 Mdot
.956 .22329 Mdot
.956 .22361 Mdot
.956 .22456 Mdot
.956 .22549 Mdot
.956 .22569 Mdot
.956 .2258 Mdot
.956 .2271 Mdot
.956 .22767 Mdot
.956 .22788 Mdot
.956 .22814 Mdot
.956 .22865 Mdot
.956 .2296 Mdot
.956 .23073 Mdot
.956 .23145 Mdot
.956 .23272 Mdot
.956 .23275 Mdot
.956 .23293 Mdot
.956 .23445 Mdot
.956 .23495 Mdot
.956 .23538 Mdot
.956 .23619 Mdot
.956 .23629 Mdot
.956 .23637 Mdot
.956 .23792 Mdot
.956 .23859 Mdot
.956 .23895 Mdot
.956 .23907 Mdot
.956 .23933 Mdot
.956 .24071 Mdot
.956 .24103 Mdot
.956 .24171 Mdot
.956 .24232 Mdot
.956 .24284 Mdot
.956 .24423 Mdot
.956 .24444 Mdot
.956 .24474 Mdot
.956 .24477 Mdot
.956 .24577 Mdot
.956 .24616 Mdot
.956 .24633 Mdot
.956 .24646 Mdot
.956 .24705 Mdot
.956 .24711 Mdot
.956 .24743 Mdot
.956 .24818 Mdot
.956 .24836 Mdot
.956 .24923 Mdot
.956 .25087 Mdot
.956 .25148 Mdot
.956 .25219 Mdot
.956 .25268 Mdot
.956 .25311 Mdot
.956 .25326 Mdot
.956 .25372 Mdot
.956 .2545 Mdot
.956 .25456 Mdot
.956 .2546 Mdot
.956 .25525 Mdot
.956 .25574 Mdot
.956 .25578 Mdot
.956 .25606 Mdot
.956 .25631 Mdot
.956 .25757 Mdot
.956 .25839 Mdot
.956 .25902 Mdot
.956 .25933 Mdot
.956 .25935 Mdot
.956 .25938 Mdot
.956 .25953 Mdot
.956 .25968 Mdot
.956 .25978 Mdot
.956 .26141 Mdot
.956 .26173 Mdot
.956 .26204 Mdot
.956 .26305 Mdot
.956 .26314 Mdot
.956 .26342 Mdot
.956 .26383 Mdot
.956 .26536 Mdot
.956 .26705 Mdot
.956 .26779 Mdot
.956 .26841 Mdot
.956 .26883 Mdot
.956 .26912 Mdot
.956 .26954 Mdot
.956 .27024 Mdot
.956 .27051 Mdot
.956 .27065 Mdot
.956 .27085 Mdot
.956 .27116 Mdot
.956 .27119 Mdot
.956 .27122 Mdot
.956 .27263 Mdot
.956 .27339 Mdot
.956 .27353 Mdot
.956 .27511 Mdot
.956 .27555 Mdot
.956 .2763 Mdot
.956 .27652 Mdot
.956 .27657 Mdot
.956 .27671 Mdot
.956 .27831 Mdot
.956 .2792 Mdot
.956 .27979 Mdot
.956 .28013 Mdot
.956 .28143 Mdot
.956 .28146 Mdot
.956 .28193 Mdot
.956 .28217 Mdot
.956 .28257 Mdot
.956 .28308 Mdot
.956 .28315 Mdot
.956 .2833 Mdot
.956 .28335 Mdot
.956 .28455 Mdot
.956 .28527 Mdot
.956 .28563 Mdot
.956 .28654 Mdot
.956 .2866 Mdot
.956 .28694 Mdot
.956 .28749 Mdot
.956 .2884 Mdot
.956 .28863 Mdot
.956 .28913 Mdot
.956 .28919 Mdot
.956 .29012 Mdot
.956 .29019 Mdot
.956 .29028 Mdot
.956 .29038 Mdot
.956 .29112 Mdot
.956 .29343 Mdot
.956 .29389 Mdot
.956 .29394 Mdot
.956 .29405 Mdot
.956 .29425 Mdot
.956 .2946 Mdot
.956 .29473 Mdot
.956 .2951 Mdot
.956 .29519 Mdot
.956 .29528 Mdot
.956 .29529 Mdot
.956 .29548 Mdot
.956 .29586 Mdot
.956 .2961 Mdot
.956 .29659 Mdot
.956 .29662 Mdot
.956 .29755 Mdot
.956 .29818 Mdot
.956 .29872 Mdot
.956 .29896 Mdot
.956 .29899 Mdot
.956 .30011 Mdot
.956 .30018 Mdot
.956 .30047 Mdot
.956 .3014 Mdot
.956 .30267 Mdot
.956 .30286 Mdot
.956 .30352 Mdot
.956 .30376 Mdot
.956 .30409 Mdot
.956 .30507 Mdot
.956 .30551 Mdot
.956 .30568 Mdot
.956 .3067 Mdot
.956 .30824 Mdot
.956 .30899 Mdot
.956 .30976 Mdot
.956 .31103 Mdot
.956 .31137 Mdot
.956 .31188 Mdot
.956 .31194 Mdot
.956 .31271 Mdot
.956 .31301 Mdot
.956 .31392 Mdot
.956 .31491 Mdot
.956 .31601 Mdot
.956 .31615 Mdot
.956 .31631 Mdot
.956 .31642 Mdot
.956 .31656 Mdot
.956 .31751 Mdot
.956 .31875 Mdot
.956 .31932 Mdot
.956 .31983 Mdot
.956 .32005 Mdot
.956 .32015 Mdot
.956 .32088 Mdot
.956 .3209 Mdot
.956 .32143 Mdot
.956 .32207 Mdot
.956 .32229 Mdot
.956 .32311 Mdot
.956 .32415 Mdot
.956 .32474 Mdot
.956 .32477 Mdot
.956 .32477 Mdot
.956 .32565 Mdot
.956 .32598 Mdot
.956 .326 Mdot
.956 .32617 Mdot
.956 .32633 Mdot
.956 .32823 Mdot
.956 .32828 Mdot
.956 .3287 Mdot
.956 .32888 Mdot
.956 .32952 Mdot
.956 .32955 Mdot
.956 .32959 Mdot
.956 .33049 Mdot
.956 .33064 Mdot
.956 .33089 Mdot
.956 .33129 Mdot
.956 .33167 Mdot
.956 .33257 Mdot
.956 .33339 Mdot
.956 .3336 Mdot
.956 .33471 Mdot
.956 .33527 Mdot
.956 .33718 Mdot
.956 .33869 Mdot
.956 .33887 Mdot
.956 .33959 Mdot
.956 .3396 Mdot
.956 .3402 Mdot
.956 .34211 Mdot
.956 .34248 Mdot
.956 .34363 Mdot
.956 .34369 Mdot
.956 .3438 Mdot
.956 .34382 Mdot
.956 .34418 Mdot
.956 .34427 Mdot
.956 .34437 Mdot
.956 .34488 Mdot
.956 .34526 Mdot
.956 .34539 Mdot
.956 .34592 Mdot
.956 .34598 Mdot
.956 .34704 Mdot
.956 .34708 Mdot
.956 .34832 Mdot
.956 .34866 Mdot
.956 .34929 Mdot
.956 .3498 Mdot
.956 .35052 Mdot
.956 .35124 Mdot
.956 .35159 Mdot
.956 .352 Mdot
.956 .35239 Mdot
.956 .35291 Mdot
.956 .35354 Mdot
.956 .35356 Mdot
.956 .35526 Mdot
.956 .35544 Mdot
.956 .35569 Mdot
.956 .35723 Mdot
.956 .35754 Mdot
.956 .35859 Mdot
.956 .35918 Mdot
.956 .36 Mdot
.956 .36009 Mdot
.956 .36041 Mdot
.956 .36053 Mdot
.956 .36146 Mdot
.956 .36203 Mdot
.956 .36211 Mdot
.956 .36295 Mdot
.956 .36326 Mdot
.956 .36379 Mdot
.956 .36431 Mdot
.956 .36517 Mdot
.956 .36566 Mdot
.956 .36579 Mdot
.956 .3659 Mdot
.956 .36623 Mdot
.956 .36664 Mdot
.956 .36811 Mdot
.956 .36849 Mdot
.956 .371 Mdot
.956 .37163 Mdot
.956 .37184 Mdot
.956 .3723 Mdot
.956 .37266 Mdot
.956 .37324 Mdot
.956 .37455 Mdot
.956 .37565 Mdot
.956 .37601 Mdot
.956 .37619 Mdot
.956 .37648 Mdot
.956 .37683 Mdot
.956 .37743 Mdot
.956 .37835 Mdot
.956 .37942 Mdot
.956 .38095 Mdot
.956 .38116 Mdot
.956 .38119 Mdot
.956 .38195 Mdot
.956 .38201 Mdot
.956 .38203 Mdot
.956 .3825 Mdot
.956 .38349 Mdot
.956 .38421 Mdot
.956 .3845 Mdot
.956 .38501 Mdot
.956 .38575 Mdot
.956 .38686 Mdot
.956 .38699 Mdot
.956 .38709 Mdot
.956 .38714 Mdot
.956 .38794 Mdot
.956 .38882 Mdot
.956 .38955 Mdot
.956 .38982 Mdot
.956 .38999 Mdot
.956 .3911 Mdot
.956 .39154 Mdot
.956 .3917 Mdot
.956 .39224 Mdot
.956 .39285 Mdot
.956 .39392 Mdot
.956 .39504 Mdot
.956 .3952 Mdot
.956 .39555 Mdot
.956 .39757 Mdot
.956 .39793 Mdot
.956 .40052 Mdot
.956 .401 Mdot
.956 .40101 Mdot
.956 .4013 Mdot
.956 .40174 Mdot
.956 .40192 Mdot
.956 .40225 Mdot
.956 .40266 Mdot
.956 .40291 Mdot
.956 .40462 Mdot
.956 .40485 Mdot
.956 .40496 Mdot
.956 .40499 Mdot
.956 .40565 Mdot
.956 .40646 Mdot
.956 .40666 Mdot
.956 .40706 Mdot
.956 .40717 Mdot
.956 .40786 Mdot
.956 .40847 Mdot
.956 .40923 Mdot
.956 .40935 Mdot
.956 .40961 Mdot
.956 .41293 Mdot
.956 .413 Mdot
.956 .41305 Mdot
.956 .41352 Mdot
.956 .41412 Mdot
.956 .41593 Mdot
.956 .41626 Mdot
.956 .41772 Mdot
.956 .4181 Mdot
.956 .41831 Mdot
.956 .41842 Mdot
.956 .41965 Mdot
.956 .42015 Mdot
.956 .4208 Mdot
.956 .42188 Mdot
.956 .42229 Mdot
.956 .42279 Mdot
.956 .42375 Mdot
.956 .42441 Mdot
.956 .42453 Mdot
.956 .42532 Mdot
.956 .42558 Mdot
.956 .42623 Mdot
.956 .42714 Mdot
.956 .42773 Mdot
.956 .42859 Mdot
.956 .42912 Mdot
.956 .43043 Mdot
.956 .4307 Mdot
.956 .43072 Mdot
.956 .43124 Mdot
.956 .43144 Mdot
.956 .43153 Mdot
.956 .4316 Mdot
.956 .43194 Mdot
.956 .43486 Mdot
.956 .43581 Mdot
.956 .43584 Mdot
.956 .43662 Mdot
.956 .43817 Mdot
.956 .43836 Mdot
.956 .43844 Mdot
.956 .43851 Mdot
.956 .43975 Mdot
.956 .44149 Mdot
.956 .44276 Mdot
.956 .44308 Mdot
.956 .4433 Mdot
.956 .44345 Mdot
.956 .44367 Mdot
.956 .44418 Mdot
.956 .44455 Mdot
.956 .44658 Mdot
.956 .44681 Mdot
.956 .44742 Mdot
.956 .44873 Mdot
.956 .44989 Mdot
.956 .44991 Mdot
.956 .45075 Mdot
.956 .4509 Mdot
.956 .45256 Mdot
.956 .45277 Mdot
.956 .45354 Mdot
.956 .45395 Mdot
.956 .45452 Mdot
.956 .45457 Mdot
.956 .45617 Mdot
.956 .45643 Mdot
.956 .45649 Mdot
.956 .45678 Mdot
.956 .45714 Mdot
.956 .45724 Mdot
.956 .45756 Mdot
.956 .45782 Mdot
.956 .45832 Mdot
.956 .45893 Mdot
.956 .45906 Mdot
.956 .45966 Mdot
.956 .45985 Mdot
.956 .4611 Mdot
.956 .46145 Mdot
.956 .46311 Mdot
.956 .46625 Mdot
.956 .4674 Mdot
.956 .46827 Mdot
.956 .46876 Mdot
.956 .46971 Mdot
.956 .46997 Mdot
.956 .47014 Mdot
.956 .47052 Mdot
.956 .47054 Mdot
.956 .47081 Mdot
.956 .47126 Mdot
.956 .47169 Mdot
.956 .47256 Mdot
.956 .47302 Mdot
.956 .47319 Mdot
.956 .47329 Mdot
.956 .47337 Mdot
.956 .47437 Mdot
.956 .47462 Mdot
.956 .47471 Mdot
.956 .47504 Mdot
.956 .47508 Mdot
.956 .47555 Mdot
.956 .47563 Mdot
.956 .47576 Mdot
.956 .47617 Mdot
.956 .47664 Mdot
.956 .47717 Mdot
.956 .47805 Mdot
.956 .47905 Mdot
.956 .47984 Mdot
.956 .47993 Mdot
.956 .48063 Mdot
.956 .48182 Mdot
.956 .48243 Mdot
.956 .48245 Mdot
.956 .48251 Mdot
.956 .48281 Mdot
.956 .48308 Mdot
.956 .48327 Mdot
.956 .48335 Mdot
.956 .48565 Mdot
.956 .4864 Mdot
.956 .487 Mdot
.956 .48761 Mdot
.956 .48762 Mdot
.956 .4885 Mdot
.956 .4886 Mdot
.956 .48954 Mdot
.956 .4897 Mdot
.956 .49025 Mdot
.956 .49103 Mdot
.956 .49269 Mdot
.956 .49297 Mdot
.956 .49394 Mdot
.956 .49401 Mdot
.956 .49718 Mdot
.956 .49742 Mdot
.956 .49859 Mdot
.956 .49978 Mdot
.956 .50058 Mdot
.956 .50114 Mdot
.956 .50194 Mdot
.956 .50207 Mdot
.956 .50275 Mdot
.956 .50327 Mdot
.956 .5038 Mdot
.956 .50407 Mdot
.956 .50445 Mdot
.956 .50503 Mdot
.956 .5051 Mdot
.956 .50515 Mdot
.956 .50518 Mdot
.956 .50606 Mdot
.956 .50725 Mdot
.956 .50785 Mdot
.956 .50931 Mdot
.956 .50958 Mdot
.956 .51082 Mdot
.956 .51243 Mdot
.956 .51259 Mdot
.956 .51308 Mdot
.956 .51343 Mdot
.956 .51486 Mdot
.956 .51528 Mdot
.956 .51539 Mdot
.956 .51565 Mdot
.956 .5168 Mdot
.956 .51871 Mdot
.956 .52041 Mdot
.956 .52154 Mdot
.956 .52218 Mdot
.956 .52244 Mdot
.956 .52467 Mdot
.956 .52473 Mdot
.956 .52515 Mdot
.956 .52562 Mdot
.956 .5261 Mdot
.956 .52686 Mdot
.956 .52782 Mdot
.956 .52796 Mdot
.956 .52797 Mdot
.956 .52824 Mdot
.956 .52835 Mdot
.956 .53065 Mdot
.956 .53201 Mdot
.956 .5327 Mdot
.956 .53444 Mdot
.956 .53455 Mdot
.956 .53521 Mdot
.956 .53627 Mdot
.956 .53801 Mdot
.956 .53845 Mdot
.956 .5394 Mdot
.956 .53951 Mdot
.956 .54128 Mdot
.956 .54142 Mdot
.956 .5416 Mdot
.956 .54179 Mdot
.956 .54321 Mdot
.956 .54761 Mdot
.956 .5485 Mdot
.956 .54859 Mdot
.956 .5488 Mdot
.956 .54918 Mdot
.956 .54985 Mdot
.956 .5501 Mdot
.956 .5508 Mdot
.956 .55098 Mdot
.956 .55115 Mdot
.956 .55117 Mdot
.956 .55153 Mdot
.956 .55227 Mdot
.956 .55273 Mdot
.956 .55366 Mdot
.956 .55371 Mdot
.956 .5555 Mdot
.956 .5567 Mdot
.956 .55773 Mdot
.956 .55819 Mdot
.956 .55824 Mdot
.956 .56038 Mdot
.956 .56053 Mdot
.956 .56108 Mdot
.956 .56286 Mdot
.956 .56529 Mdot
.956 .56565 Mdot
.956 .56692 Mdot
.956 .56737 Mdot
.956 .568 Mdot
.956 .56987 Mdot
.956 .57071 Mdot
.956 .57105 Mdot
.956 .57299 Mdot
.956 .57594 Mdot
.956 .57736 Mdot
.956 .57883 Mdot
.958 .01499 Mdot
.958 .01524 Mdot
.958 .01563 Mdot
.958 .01572 Mdot
.958 .01646 Mdot
.958 .01664 Mdot
.958 .01756 Mdot
.958 .01806 Mdot
.958 .0184 Mdot
.958 .0188 Mdot
.958 .0188 Mdot
.958 .01905 Mdot
.958 .02016 Mdot
.958 .02103 Mdot
.958 .02112 Mdot
.958 .02177 Mdot
.958 .0218 Mdot
.958 .02254 Mdot
.958 .02255 Mdot
.958 .02302 Mdot
.958 .02432 Mdot
.958 .02516 Mdot
.958 .02682 Mdot
.958 .02697 Mdot
.958 .02699 Mdot
.958 .02823 Mdot
.958 .0283 Mdot
.958 .02971 Mdot
.958 .02973 Mdot
.958 .03063 Mdot
.958 .03077 Mdot
.958 .03175 Mdot
.958 .03312 Mdot
.958 .03472 Mdot
.958 .03524 Mdot
.958 .03638 Mdot
.958 .03791 Mdot
.958 .0382 Mdot
.958 .03824 Mdot
.958 .03891 Mdot
.958 .04027 Mdot
.958 .04062 Mdot
.958 .04074 Mdot
.958 .04079 Mdot
.958 .0433 Mdot
.958 .04344 Mdot
.958 .04348 Mdot
.958 .04357 Mdot
.958 .04502 Mdot
.958 .04521 Mdot
.958 .04524 Mdot
.958 .04547 Mdot
.958 .04574 Mdot
.958 .04591 Mdot
.958 .04678 Mdot
.958 .04709 Mdot
.958 .04736 Mdot
.958 .04911 Mdot
.958 .0495 Mdot
.958 .04997 Mdot
.958 .05157 Mdot
.958 .05186 Mdot
.958 .05305 Mdot
.958 .05377 Mdot
.958 .05403 Mdot
.958 .05471 Mdot
.958 .05501 Mdot
.958 .05555 Mdot
.958 .05623 Mdot
.958 .05905 Mdot
.958 .05915 Mdot
.958 .05949 Mdot
.958 .05972 Mdot
.958 .05978 Mdot
.958 .06107 Mdot
.958 .06115 Mdot
.958 .06181 Mdot
.958 .06368 Mdot
.958 .06391 Mdot
.958 .0643 Mdot
.958 .06435 Mdot
.958 .06457 Mdot
.958 .06467 Mdot
.958 .06604 Mdot
.958 .06633 Mdot
.958 .06719 Mdot
.958 .06808 Mdot
.958 .06872 Mdot
.958 .06882 Mdot
.958 .06949 Mdot
.958 .06974 Mdot
.958 .06982 Mdot
.958 .07 Mdot
.958 .07035 Mdot
.958 .07056 Mdot
.958 .07135 Mdot
.958 .07226 Mdot
.958 .07235 Mdot
.958 .07279 Mdot
.958 .07284 Mdot
.958 .07301 Mdot
.958 .07315 Mdot
.958 .07321 Mdot
.958 .07364 Mdot
.958 .0737 Mdot
.958 .074 Mdot
.958 .07417 Mdot
.958 .07448 Mdot
.958 .07501 Mdot
.958 .07529 Mdot
.958 .07615 Mdot
.958 .07667 Mdot
.958 .07675 Mdot
.958 .07682 Mdot
.958 .07726 Mdot
.958 .07842 Mdot
.958 .08061 Mdot
.958 .08068 Mdot
.958 .08109 Mdot
.958 .08136 Mdot
.958 .08155 Mdot
.958 .08227 Mdot
.958 .08285 Mdot
.958 .08305 Mdot
.958 .0835 Mdot
.958 .0847 Mdot
.958 .08532 Mdot
.958 .08589 Mdot
.958 .08692 Mdot
.958 .08816 Mdot
.958 .08854 Mdot
.958 .08955 Mdot
.958 .09005 Mdot
.958 .09016 Mdot
.958 .09093 Mdot
.958 .09134 Mdot
.958 .09192 Mdot
.958 .0927 Mdot
.958 .09296 Mdot
.958 .09324 Mdot
.958 .09426 Mdot
.958 .0948 Mdot
.958 .097 Mdot
.958 .09754 Mdot
.958 .09768 Mdot
.958 .09936 Mdot
.958 .09967 Mdot
.958 .09982 Mdot
.958 .09986 Mdot
.958 .1002 Mdot
.958 .1005 Mdot
.958 .10094 Mdot
.958 .10099 Mdot
.958 .10106 Mdot
.958 .1026 Mdot
.958 .10272 Mdot
.958 .10285 Mdot
.958 .10344 Mdot
.958 .10352 Mdot
.958 .10369 Mdot
.958 .1047 Mdot
.958 .10495 Mdot
.958 .10497 Mdot
.958 .10696 Mdot
.958 .10736 Mdot
.958 .10805 Mdot
.958 .10843 Mdot
.958 .10853 Mdot
.958 .10897 Mdot
.958 .10971 Mdot
.958 .1098 Mdot
.958 .10981 Mdot
.958 .11024 Mdot
.958 .11042 Mdot
.958 .11114 Mdot
.958 .11214 Mdot
.958 .11229 Mdot
.958 .11305 Mdot
.958 .11362 Mdot
.958 .11368 Mdot
.958 .11525 Mdot
.958 .11628 Mdot
.958 .11638 Mdot
.958 .11697 Mdot
.958 .11702 Mdot
.958 .11705 Mdot
.958 .11744 Mdot
.958 .11819 Mdot
.958 .11837 Mdot
.958 .11929 Mdot
.958 .11967 Mdot
.958 .12012 Mdot
.958 .12015 Mdot
.958 .12022 Mdot
.958 .1203 Mdot
.958 .12064 Mdot
.958 .12113 Mdot
.958 .12132 Mdot
.958 .12139 Mdot
.958 .12171 Mdot
.958 .12196 Mdot
.958 .12254 Mdot
.958 .12263 Mdot
.958 .12287 Mdot
.958 .12322 Mdot
.958 .12469 Mdot
.958 .12496 Mdot
.958 .12515 Mdot
.958 .12598 Mdot
.958 .12609 Mdot
.958 .12641 Mdot
.958 .12644 Mdot
.958 .12668 Mdot
.958 .12679 Mdot
.958 .12715 Mdot
.958 .12762 Mdot
.958 .12773 Mdot
.958 .1283 Mdot
.958 .12862 Mdot
.958 .12923 Mdot
.958 .13024 Mdot
.958 .13043 Mdot
.958 .13078 Mdot
.958 .13109 Mdot
.958 .13242 Mdot
.958 .13336 Mdot
.958 .13342 Mdot
.958 .13349 Mdot
.958 .13357 Mdot
.958 .13371 Mdot
.958 .13377 Mdot
.958 .1345 Mdot
.958 .13455 Mdot
.958 .13521 Mdot
.958 .13677 Mdot
.958 .1376 Mdot
.958 .13882 Mdot
.958 .13985 Mdot
.958 .14098 Mdot
.958 .1411 Mdot
.958 .1413 Mdot
.958 .14189 Mdot
.958 .1424 Mdot
.958 .14277 Mdot
.958 .14384 Mdot
.958 .14414 Mdot
.958 .14425 Mdot
.958 .14464 Mdot
.958 .14492 Mdot
.958 .14525 Mdot
.958 .14564 Mdot
.958 .14651 Mdot
.958 .14881 Mdot
.958 .15 Mdot
.958 .15042 Mdot
.958 .15072 Mdot
.958 .15093 Mdot
.958 .15109 Mdot
.958 .15152 Mdot
.958 .15182 Mdot
.958 .15261 Mdot
.958 .15305 Mdot
.958 .15408 Mdot
.958 .15483 Mdot
.958 .15532 Mdot
.958 .15543 Mdot
.958 .15617 Mdot
.958 .1581 Mdot
.958 .15869 Mdot
.958 .15905 Mdot
.958 .15927 Mdot
.958 .16075 Mdot
.958 .16106 Mdot
.958 .16152 Mdot
.958 .16255 Mdot
.958 .16264 Mdot
.958 .16329 Mdot
.958 .16414 Mdot
.958 .16463 Mdot
.958 .16516 Mdot
.958 .16609 Mdot
.958 .16665 Mdot
.958 .16712 Mdot
.958 .1674 Mdot
.958 .16774 Mdot
.958 .16779 Mdot
.958 .168 Mdot
.958 .16816 Mdot
.958 .16911 Mdot
.958 .16981 Mdot
.958 .17015 Mdot
.958 .17022 Mdot
.958 .17076 Mdot
.958 .17238 Mdot
.958 .17341 Mdot
.958 .17368 Mdot
.958 .176 Mdot
.958 .1769 Mdot
.958 .17729 Mdot
.958 .17749 Mdot
.958 .17777 Mdot
.958 .17786 Mdot
.958 .17851 Mdot
.958 .17908 Mdot
.958 .17993 Mdot
.958 .18001 Mdot
.958 .18016 Mdot
.958 .18123 Mdot
.958 .18244 Mdot
.958 .1831 Mdot
.958 .18333 Mdot
.958 .18357 Mdot
.958 .18377 Mdot
.958 .18425 Mdot
.958 .18471 Mdot
.958 .18474 Mdot
.958 .18487 Mdot
.958 .18519 Mdot
.958 .18554 Mdot
.958 .18596 Mdot
.958 .18639 Mdot
.958 .18712 Mdot
.958 .1876 Mdot
.958 .18765 Mdot
.958 .18959 Mdot
.958 .1898 Mdot
.958 .19028 Mdot
.958 .19085 Mdot
.958 .19145 Mdot
.958 .1916 Mdot
.958 .19164 Mdot
.958 .19209 Mdot
.958 .19222 Mdot
.958 .19254 Mdot
.958 .19321 Mdot
.958 .19355 Mdot
.958 .19427 Mdot
.958 .19446 Mdot
.958 .19494 Mdot
.958 .1953 Mdot
.958 .19558 Mdot
.958 .19562 Mdot
.958 .1967 Mdot
.958 .19673 Mdot
.958 .19691 Mdot
.958 .19691 Mdot
.958 .19775 Mdot
.958 .19803 Mdot
.958 .19809 Mdot
.958 .19841 Mdot
.958 .19843 Mdot
.958 .1985 Mdot
.958 .19947 Mdot
.958 .20056 Mdot
.958 .20074 Mdot
.958 .20136 Mdot
.958 .20139 Mdot
.958 .20147 Mdot
.958 .20167 Mdot
.958 .20251 Mdot
.958 .20312 Mdot
.958 .20421 Mdot
.958 .20432 Mdot
.958 .206 Mdot
.958 .20608 Mdot
.958 .20638 Mdot
.958 .2066 Mdot
.958 .2072 Mdot
.958 .20734 Mdot
.958 .20826 Mdot
.958 .2089 Mdot
.958 .20931 Mdot
.958 .20951 Mdot
.958 .21027 Mdot
.958 .21042 Mdot
.958 .21063 Mdot
.958 .21073 Mdot
.958 .21079 Mdot
.958 .2114 Mdot
.958 .21154 Mdot
.958 .21297 Mdot
.958 .21332 Mdot
.958 .21509 Mdot
.958 .21522 Mdot
.958 .21535 Mdot
.958 .21557 Mdot
.958 .2158 Mdot
.958 .21667 Mdot
.958 .21673 Mdot
.958 .21686 Mdot
.958 .21702 Mdot
.958 .21748 Mdot
.958 .21766 Mdot
.958 .21813 Mdot
.958 .2183 Mdot
.958 .21861 Mdot
.958 .21897 Mdot
.958 .21908 Mdot
.958 .2191 Mdot
.958 .21971 Mdot
.958 .21991 Mdot
.958 .22019 Mdot
.958 .22114 Mdot
.958 .22131 Mdot
.958 .22147 Mdot
.958 .22176 Mdot
.958 .22193 Mdot
.958 .22231 Mdot
.958 .22261 Mdot
.958 .22365 Mdot
.958 .22493 Mdot
.958 .22544 Mdot
.958 .22559 Mdot
.958 .22595 Mdot
.958 .2263 Mdot
.958 .22704 Mdot
.958 .22766 Mdot
.958 .2279 Mdot
.958 .22811 Mdot
.958 .22873 Mdot
.958 .22878 Mdot
.958 .22924 Mdot
.958 .22945 Mdot
.958 .22994 Mdot
.958 .23014 Mdot
.958 .23082 Mdot
.958 .23104 Mdot
.958 .23125 Mdot
.958 .23158 Mdot
.958 .23234 Mdot
.958 .23296 Mdot
.958 .23385 Mdot
.958 .23395 Mdot
.958 .23402 Mdot
.958 .23412 Mdot
.958 .23422 Mdot
.958 .23473 Mdot
.958 .23557 Mdot
.958 .23573 Mdot
.958 .23581 Mdot
.958 .23606 Mdot
.958 .23642 Mdot
.958 .23651 Mdot
.958 .2371 Mdot
.958 .23768 Mdot
.958 .23829 Mdot
.958 .23903 Mdot
.958 .24024 Mdot
.958 .24087 Mdot
.958 .24093 Mdot
.958 .24151 Mdot
.958 .24204 Mdot
.958 .24215 Mdot
.958 .24228 Mdot
.958 .24233 Mdot
.958 .24243 Mdot
.958 .24272 Mdot
.958 .24283 Mdot
.958 .24309 Mdot
.958 .24422 Mdot
.958 .24432 Mdot
.958 .24432 Mdot
.958 .24522 Mdot
.958 .24559 Mdot
.958 .2471 Mdot
.958 .24783 Mdot
.958 .24858 Mdot
.958 .24939 Mdot
.958 .25016 Mdot
.958 .25059 Mdot
.958 .25095 Mdot
.958 .2525 Mdot
.958 .25266 Mdot
.958 .25302 Mdot
.958 .25329 Mdot
.958 .25365 Mdot
.958 .25392 Mdot
.958 .25402 Mdot
.958 .25447 Mdot
.958 .25588 Mdot
.958 .25663 Mdot
.958 .25688 Mdot
.958 .25726 Mdot
.958 .25763 Mdot
.958 .25787 Mdot
.958 .25815 Mdot
.958 .25839 Mdot
.958 .25896 Mdot
.958 .25908 Mdot
.958 .25936 Mdot
.958 .25953 Mdot
.958 .25985 Mdot
.958 .26008 Mdot
.958 .26074 Mdot
.958 .26208 Mdot
.958 .26211 Mdot
.958 .26241 Mdot
.958 .2627 Mdot
.958 .2629 Mdot
.958 .26365 Mdot
.958 .26419 Mdot
.958 .26458 Mdot
.958 .26483 Mdot
.958 .26522 Mdot
.958 .26557 Mdot
.958 .26671 Mdot
.958 .26723 Mdot
.958 .26805 Mdot
.958 .26895 Mdot
.958 .26903 Mdot
.958 .27163 Mdot
.958 .27168 Mdot
.958 .27393 Mdot
.958 .27473 Mdot
.958 .2748 Mdot
.958 .2753 Mdot
.958 .2757 Mdot
.958 .276 Mdot
.958 .27612 Mdot
.958 .27683 Mdot
.958 .27741 Mdot
.958 .27841 Mdot
.958 .27864 Mdot
.958 .27893 Mdot
.958 .27977 Mdot
.958 .28075 Mdot
.958 .28101 Mdot
.958 .28173 Mdot
.958 .28272 Mdot
.958 .28312 Mdot
.958 .28317 Mdot
.958 .28359 Mdot
.958 .28412 Mdot
.958 .28415 Mdot
.958 .28432 Mdot
.958 .2852 Mdot
.958 .2856 Mdot
.958 .28574 Mdot
.958 .28656 Mdot
.958 .28944 Mdot
.958 .29058 Mdot
.958 .29072 Mdot
.958 .29107 Mdot
.958 .29107 Mdot
.958 .29127 Mdot
.958 .29169 Mdot
.958 .29437 Mdot
.958 .29452 Mdot
.958 .29506 Mdot
.958 .29511 Mdot
.958 .29575 Mdot
.958 .296 Mdot
.958 .29796 Mdot
.958 .29815 Mdot
.958 .29938 Mdot
.958 .30101 Mdot
.958 .30128 Mdot
.958 .30196 Mdot
.958 .30297 Mdot
.958 .30308 Mdot
.958 .30397 Mdot
.958 .30406 Mdot
.958 .30474 Mdot
.958 .30582 Mdot
.958 .30651 Mdot
.958 .30652 Mdot
.958 .30671 Mdot
.958 .30673 Mdot
.958 .30727 Mdot
.958 .30791 Mdot
.958 .30794 Mdot
.958 .30801 Mdot
.958 .3084 Mdot
.958 .30872 Mdot
.958 .30968 Mdot
.958 .31054 Mdot
.958 .31087 Mdot
.958 .31188 Mdot
.958 .31253 Mdot
.958 .31253 Mdot
.958 .31266 Mdot
.958 .31369 Mdot
.958 .3141 Mdot
.958 .31541 Mdot
.958 .31679 Mdot
.958 .31877 Mdot
.958 .31929 Mdot
.958 .32111 Mdot
.958 .32171 Mdot
.958 .32302 Mdot
.958 .32373 Mdot
.958 .324 Mdot
.958 .32532 Mdot
.958 .32546 Mdot
.958 .32622 Mdot
.958 .32633 Mdot
.958 .32659 Mdot
.958 .32668 Mdot
.958 .32713 Mdot
.958 .32729 Mdot
.958 .32835 Mdot
.958 .32855 Mdot
.958 .32963 Mdot
.958 .32978 Mdot
.958 .33078 Mdot
.958 .33127 Mdot
.958 .33143 Mdot
.958 .33171 Mdot
.958 .33354 Mdot
.958 .33376 Mdot
.958 .33463 Mdot
.958 .33497 Mdot
.958 .33607 Mdot
.958 .33627 Mdot
.958 .33718 Mdot
.958 .33734 Mdot
.958 .33778 Mdot
.958 .33825 Mdot
.958 .33858 Mdot
.958 .33863 Mdot
.958 .33944 Mdot
.958 .33954 Mdot
.958 .33995 Mdot
.958 .34043 Mdot
.958 .34048 Mdot
.958 .34074 Mdot
.958 .34082 Mdot
.958 .34118 Mdot
.958 .34134 Mdot
.958 .34186 Mdot
.958 .34201 Mdot
.958 .34273 Mdot
.958 .34281 Mdot
.958 .34364 Mdot
.958 .34482 Mdot
.958 .34504 Mdot
.958 .34528 Mdot
.958 .34596 Mdot
.958 .34606 Mdot
.958 .3463 Mdot
.958 .34692 Mdot
.958 .34808 Mdot
.958 .34893 Mdot
.958 .34977 Mdot
.958 .35018 Mdot
.958 .3511 Mdot
.958 .35138 Mdot
.958 .3522 Mdot
.958 .35334 Mdot
.958 .35362 Mdot
.958 .3537 Mdot
.958 .35457 Mdot
.958 .35481 Mdot
.958 .35501 Mdot
.958 .35542 Mdot
.958 .35626 Mdot
.958 .35633 Mdot
.958 .35639 Mdot
.958 .3567 Mdot
.958 .35736 Mdot
.958 .3575 Mdot
.958 .35854 Mdot
.958 .35875 Mdot
.958 .35911 Mdot
.958 .35931 Mdot
.958 .36003 Mdot
.958 .36072 Mdot
.958 .36125 Mdot
.958 .36132 Mdot
.958 .36205 Mdot
.958 .3634 Mdot
.958 .36346 Mdot
.958 .36379 Mdot
.958 .36381 Mdot
.958 .36401 Mdot
.958 .36498 Mdot
.958 .36541 Mdot
.958 .36546 Mdot
.958 .36594 Mdot
.958 .36607 Mdot
.958 .36637 Mdot
.958 .36667 Mdot
.958 .36672 Mdot
.958 .36684 Mdot
.958 .3678 Mdot
.958 .36871 Mdot
.958 .36908 Mdot
.958 .37079 Mdot
.958 .37113 Mdot
.958 .37232 Mdot
.958 .37238 Mdot
.958 .37253 Mdot
.958 .37291 Mdot
.958 .37329 Mdot
.958 .37453 Mdot
.958 .37517 Mdot
.958 .37571 Mdot
.958 .37647 Mdot
.958 .37779 Mdot
.958 .378 Mdot
.958 .37821 Mdot
.958 .37835 Mdot
.958 .38123 Mdot
.958 .38138 Mdot
.958 .38149 Mdot
.958 .3818 Mdot
.958 .38195 Mdot
.958 .38237 Mdot
.958 .38313 Mdot
.958 .38352 Mdot
.958 .38378 Mdot
.958 .38554 Mdot
.958 .38678 Mdot
.958 .38755 Mdot
.958 .38794 Mdot
.958 .3894 Mdot
.958 .38969 Mdot
.958 .39009 Mdot
.958 .39026 Mdot
.958 .39029 Mdot
.958 .3904 Mdot
.958 .39098 Mdot
.958 .39134 Mdot
.958 .39152 Mdot
.958 .39156 Mdot
.958 .39184 Mdot
.958 .39457 Mdot
.958 .39525 Mdot
.958 .39731 Mdot
.958 .39793 Mdot
.958 .39863 Mdot
.958 .39888 Mdot
.958 .39913 Mdot
.958 .39955 Mdot
.958 .39977 Mdot
.958 .4 Mdot
.958 .40167 Mdot
.958 .40178 Mdot
.958 .40203 Mdot
.958 .40233 Mdot
.958 .40272 Mdot
.958 .40274 Mdot
.958 .40297 Mdot
.958 .40321 Mdot
.958 .40355 Mdot
.958 .40446 Mdot
.958 .40479 Mdot
.958 .40481 Mdot
.958 .40538 Mdot
.958 .40607 Mdot
.958 .40627 Mdot
.958 .40628 Mdot
.958 .40632 Mdot
.958 .40739 Mdot
.958 .40748 Mdot
.958 .40781 Mdot
.958 .40787 Mdot
.958 .40841 Mdot
.958 .41023 Mdot
.958 .41028 Mdot
.958 .41043 Mdot
.958 .41055 Mdot
.958 .41086 Mdot
.958 .41141 Mdot
.958 .41175 Mdot
.958 .41246 Mdot
.958 .41254 Mdot
.958 .41305 Mdot
.958 .41504 Mdot
.958 .41511 Mdot
.958 .41523 Mdot
.958 .41622 Mdot
.958 .41656 Mdot
.958 .41665 Mdot
.958 .41706 Mdot
.958 .41749 Mdot
.958 .41814 Mdot
.958 .41846 Mdot
.958 .41874 Mdot
.958 .41945 Mdot
.958 .42011 Mdot
.958 .42045 Mdot
.958 .42122 Mdot
.958 .42154 Mdot
.958 .42273 Mdot
.958 .42318 Mdot
.958 .42358 Mdot
.958 .42477 Mdot
.958 .42482 Mdot
.958 .42486 Mdot
.958 .42496 Mdot
.958 .42523 Mdot
.958 .42566 Mdot
.958 .42575 Mdot
.958 .42579 Mdot
.958 .42616 Mdot
.958 .42708 Mdot
.958 .42747 Mdot
.958 .42843 Mdot
.958 .42846 Mdot
.958 .42876 Mdot
.958 .42919 Mdot
.958 .42959 Mdot
.958 .43023 Mdot
.958 .4307 Mdot
.958 .43168 Mdot
.958 .43206 Mdot
.958 .43288 Mdot
.958 .4335 Mdot
.958 .43369 Mdot
.958 .43459 Mdot
.958 .43477 Mdot
.958 .43491 Mdot
.958 .4351 Mdot
.958 .43524 Mdot
.958 .43529 Mdot
.958 .43627 Mdot
.958 .43718 Mdot
.958 .4373 Mdot
.958 .43745 Mdot
.958 .43787 Mdot
.958 .43794 Mdot
.958 .43817 Mdot
.958 .43833 Mdot
.958 .4388 Mdot
.958 .4395 Mdot
.958 .43967 Mdot
.958 .44081 Mdot
.958 .44114 Mdot
.958 .44192 Mdot
.958 .44262 Mdot
.958 .44308 Mdot
.958 .44313 Mdot
.958 .44451 Mdot
.958 .44614 Mdot
.958 .44683 Mdot
.958 .44802 Mdot
.958 .44814 Mdot
.958 .44925 Mdot
.958 .44938 Mdot
.958 .45028 Mdot
.958 .45048 Mdot
.958 .45073 Mdot
.958 .45083 Mdot
.958 .45102 Mdot
.958 .45157 Mdot
.958 .45178 Mdot
.958 .45228 Mdot
.958 .45445 Mdot
.958 .45463 Mdot
.958 .45463 Mdot
.958 .45636 Mdot
.958 .45672 Mdot
.958 .45707 Mdot
.958 .45996 Mdot
.958 .4609 Mdot
.958 .46137 Mdot
.958 .46141 Mdot
.958 .46269 Mdot
.958 .4627 Mdot
.958 .4628 Mdot
.958 .46344 Mdot
.958 .46435 Mdot
.958 .46497 Mdot
.958 .46583 Mdot
.958 .46665 Mdot
.958 .46733 Mdot
.958 .47031 Mdot
.958 .47062 Mdot
.958 .47131 Mdot
.958 .47182 Mdot
.958 .47251 Mdot
.958 .47303 Mdot
.958 .47322 Mdot
.958 .47409 Mdot
.958 .47484 Mdot
.958 .47536 Mdot
.958 .4768 Mdot
.958 .47737 Mdot
.958 .47755 Mdot
.958 .47822 Mdot
.958 .4787 Mdot
.958 .47943 Mdot
.958 .47987 Mdot
.958 .48014 Mdot
.958 .4806 Mdot
.958 .48079 Mdot
.958 .48114 Mdot
.958 .48159 Mdot
.958 .48269 Mdot
.958 .48292 Mdot
.958 .48346 Mdot
.958 .48378 Mdot
.958 .48439 Mdot
.958 .48483 Mdot
.958 .48611 Mdot
.958 .48801 Mdot
.958 .48866 Mdot
.958 .48869 Mdot
.958 .48873 Mdot
.958 .4893 Mdot
.958 .48985 Mdot
.958 .49025 Mdot
.958 .49168 Mdot
.958 .4927 Mdot
.958 .49321 Mdot
.958 .49346 Mdot
.958 .49393 Mdot
.958 .49468 Mdot
.958 .49535 Mdot
.958 .49754 Mdot
.958 .49852 Mdot
.958 .4992 Mdot
.958 .50011 Mdot
.958 .50019 Mdot
.958 .50182 Mdot
.958 .50198 Mdot
.958 .50268 Mdot
.958 .5064 Mdot
.958 .50678 Mdot
.958 .50697 Mdot
.958 .50706 Mdot
.958 .51008 Mdot
.958 .51041 Mdot
.958 .51136 Mdot
.958 .5129 Mdot
.958 .51291 Mdot
.958 .51304 Mdot
.958 .514 Mdot
.958 .51476 Mdot
.958 .51534 Mdot
.958 .51556 Mdot
.958 .51685 Mdot
.958 .51693 Mdot
.958 .51803 Mdot
.958 .51937 Mdot
.958 .51943 Mdot
.958 .51995 Mdot
.958 .52013 Mdot
.958 .52018 Mdot
.958 .52039 Mdot
.958 .52095 Mdot
.958 .52216 Mdot
.958 .52256 Mdot
.958 .52444 Mdot
.958 .52451 Mdot
.958 .52465 Mdot
.958 .52488 Mdot
.958 .52495 Mdot
.958 .52632 Mdot
.958 .52634 Mdot
.958 .52751 Mdot
.958 .52822 Mdot
.958 .52897 Mdot
.958 .52907 Mdot
.958 .52988 Mdot
.958 .53089 Mdot
.958 .53095 Mdot
.958 .53103 Mdot
.958 .53128 Mdot
.958 .53296 Mdot
.958 .53373 Mdot
.958 .53399 Mdot
.958 .53557 Mdot
.958 .53726 Mdot
.958 .54109 Mdot
.958 .54327 Mdot
.958 .54354 Mdot
.958 .5442 Mdot
.958 .54421 Mdot
.958 .54459 Mdot
.958 .54539 Mdot
.958 .55054 Mdot
.958 .55082 Mdot
.958 .55186 Mdot
.958 .55196 Mdot
.958 .55317 Mdot
.958 .55365 Mdot
.958 .55742 Mdot
.958 .55777 Mdot
.958 .56013 Mdot
.958 .56326 Mdot
.958 .56377 Mdot
.958 .56508 Mdot
.958 .56702 Mdot
.958 .56721 Mdot
.958 .56894 Mdot
.958 .56911 Mdot
.958 .57041 Mdot
.958 .57247 Mdot
.958 .57379 Mdot
.958 .57382 Mdot
.958 .57418 Mdot
.958 .57421 Mdot
.958 .57524 Mdot
.958 .57647 Mdot
.958 .57654 Mdot
.958 .57666 Mdot
.958 .57742 Mdot
.958 .57803 Mdot
.958 .57987 Mdot
.96 .01625 Mdot
.96 .01653 Mdot
.96 .01765 Mdot
.96 .01815 Mdot
.96 .01821 Mdot
.96 .01843 Mdot
.96 .01864 Mdot
.96 .01945 Mdot
.96 .02036 Mdot
.96 .02131 Mdot
.96 .02142 Mdot
.96 .02184 Mdot
.96 .02225 Mdot
.96 .02301 Mdot
.96 .02336 Mdot
.96 .02381 Mdot
.96 .02404 Mdot
.96 .02417 Mdot
.96 .02462 Mdot
.96 .02544 Mdot
.96 .02555 Mdot
.96 .0258 Mdot
.96 .02642 Mdot
.96 .02716 Mdot
.96 .02737 Mdot
.96 .02758 Mdot
.96 .0284 Mdot
.96 .02885 Mdot
.96 .02917 Mdot
.96 .02918 Mdot
.96 .03031 Mdot
.96 .03064 Mdot
.96 .03092 Mdot
.96 .03131 Mdot
.96 .03218 Mdot
.96 .03243 Mdot
.96 .03262 Mdot
.96 .03287 Mdot
.96 .0332 Mdot
.96 .0335 Mdot
.96 .03356 Mdot
.96 .03373 Mdot
.96 .03381 Mdot
.96 .03393 Mdot
.96 .03458 Mdot
.96 .03531 Mdot
.96 .03551 Mdot
.96 .03597 Mdot
.96 .03601 Mdot
.96 .03707 Mdot
.96 .03719 Mdot
.96 .03861 Mdot
.96 .03893 Mdot
.96 .03902 Mdot
.96 .03942 Mdot
.96 .04021 Mdot
.96 .04034 Mdot
.96 .04098 Mdot
.96 .04185 Mdot
.96 .04247 Mdot
.96 .04248 Mdot
.96 .04358 Mdot
.96 .04466 Mdot
.96 .04529 Mdot
.96 .04569 Mdot
.96 .04577 Mdot
.96 .04582 Mdot
.96 .04656 Mdot
.96 .04658 Mdot
.96 .0469 Mdot
.96 .04695 Mdot
.96 .04825 Mdot
.96 .04873 Mdot
.96 .0489 Mdot
.96 .04909 Mdot
.96 .04956 Mdot
.96 .05021 Mdot
.96 .05078 Mdot
.96 .05089 Mdot
.96 .05122 Mdot
.96 .05138 Mdot
.96 .05161 Mdot
.96 .05235 Mdot
.96 .05285 Mdot
.96 .05426 Mdot
.96 .05465 Mdot
.96 .05552 Mdot
.96 .05559 Mdot
.96 .0571 Mdot
.96 .05713 Mdot
.96 .05764 Mdot
.96 .05787 Mdot
.96 .05837 Mdot
.96 .05838 Mdot
.96 .06056 Mdot
.96 .0606 Mdot
.96 .06117 Mdot
.96 .0612 Mdot
.96 .06138 Mdot
.96 .06215 Mdot
.96 .06366 Mdot
.96 .06391 Mdot
.96 .06433 Mdot
.96 .06464 Mdot
.96 .06515 Mdot
.96 .06682 Mdot
.96 .06801 Mdot
.96 .06802 Mdot
.96 .06822 Mdot
.96 .06851 Mdot
.96 .06943 Mdot
.96 .0696 Mdot
.96 .07006 Mdot
.96 .07014 Mdot
.96 .07037 Mdot
.96 .07052 Mdot
.96 .0706 Mdot
.96 .0722 Mdot
.96 .07342 Mdot
.96 .07385 Mdot
.96 .07418 Mdot
.96 .07435 Mdot
.96 .07444 Mdot
.96 .07446 Mdot
.96 .07585 Mdot
.96 .0759 Mdot
.96 .07651 Mdot
.96 .07661 Mdot
.96 .07663 Mdot
.96 .07685 Mdot
.96 .07714 Mdot
.96 .07721 Mdot
.96 .07733 Mdot
.96 .07831 Mdot
.96 .07843 Mdot
.96 .0787 Mdot
.96 .07898 Mdot
.96 .07911 Mdot
.96 .08003 Mdot
.96 .08035 Mdot
.96 .08039 Mdot
.96 .08071 Mdot
.96 .08118 Mdot
.96 .0812 Mdot
.96 .08155 Mdot
.96 .08162 Mdot
.96 .08216 Mdot
.96 .08239 Mdot
.96 .08287 Mdot
.96 .08342 Mdot
.96 .08396 Mdot
.96 .08417 Mdot
.96 .0848 Mdot
.96 .08511 Mdot
.96 .08534 Mdot
.96 .08556 Mdot
.96 .08573 Mdot
.96 .08654 Mdot
.96 .08697 Mdot
.96 .08793 Mdot
.96 .08816 Mdot
.96 .08917 Mdot
.96 .09022 Mdot
.96 .09065 Mdot
.96 .09093 Mdot
.96 .09126 Mdot
.96 .09138 Mdot
.96 .09147 Mdot
.96 .09163 Mdot
.96 .09182 Mdot
.96 .09295 Mdot
.96 .09305 Mdot
.96 .0932 Mdot
.96 .09461 Mdot
.96 .09545 Mdot
.96 .0961 Mdot
.96 .09615 Mdot
.96 .09713 Mdot
.96 .09758 Mdot
.96 .09853 Mdot
.96 .09854 Mdot
.96 .099 Mdot
.96 .0993 Mdot
.96 .10091 Mdot
.96 .10274 Mdot
.96 .10279 Mdot
.96 .10281 Mdot
.96 .1037 Mdot
.96 .10391 Mdot
.96 .10396 Mdot
.96 .10432 Mdot
.96 .10507 Mdot
.96 .10579 Mdot
.96 .10598 Mdot
.96 .10687 Mdot
.96 .10869 Mdot
.96 .10872 Mdot
.96 .10917 Mdot
.96 .1095 Mdot
.96 .10998 Mdot
.96 .11057 Mdot
.96 .11155 Mdot
.96 .11213 Mdot
.96 .11238 Mdot
.96 .11355 Mdot
.96 .11471 Mdot
.96 .11476 Mdot
.96 .11533 Mdot
.96 .11553 Mdot
.96 .11557 Mdot
.96 .11681 Mdot
.96 .11704 Mdot
.96 .11706 Mdot
.96 .11744 Mdot
.96 .11761 Mdot
.96 .1179 Mdot
.96 .11799 Mdot
.96 .11978 Mdot
.96 .12009 Mdot
.96 .12084 Mdot
.96 .12098 Mdot
.96 .12113 Mdot
.96 .12128 Mdot
.96 .12157 Mdot
.96 .12186 Mdot
.96 .12201 Mdot
.96 .1227 Mdot
.96 .12327 Mdot
.96 .12476 Mdot
.96 .12509 Mdot
.96 .12544 Mdot
.96 .12672 Mdot
.96 .1268 Mdot
.96 .12743 Mdot
.96 .12826 Mdot
.96 .12863 Mdot
.96 .12889 Mdot
.96 .12901 Mdot
.96 .12921 Mdot
.96 .12939 Mdot
.96 .12943 Mdot
.96 .13068 Mdot
.96 .1321 Mdot
.96 .13219 Mdot
.96 .13241 Mdot
.96 .13273 Mdot
.96 .13336 Mdot
.96 .13354 Mdot
.96 .13355 Mdot
.96 .13359 Mdot
.96 .13396 Mdot
.96 .13401 Mdot
.96 .13431 Mdot
.96 .13458 Mdot
.96 .13461 Mdot
.96 .1347 Mdot
.96 .13494 Mdot
.96 .13533 Mdot
.96 .1365 Mdot
.96 .13681 Mdot
.96 .13705 Mdot
.96 .13749 Mdot
.96 .13756 Mdot
.96 .1381 Mdot
.96 .13826 Mdot
.96 .13834 Mdot
.96 .14012 Mdot
.96 .14073 Mdot
.96 .14081 Mdot
.96 .1413 Mdot
.96 .14143 Mdot
.96 .14231 Mdot
.96 .14233 Mdot
.96 .14237 Mdot
.96 .14304 Mdot
.96 .14318 Mdot
.96 .14421 Mdot
.96 .14451 Mdot
.96 .14465 Mdot
.96 .14557 Mdot
.96 .14657 Mdot
.96 .14663 Mdot
.96 .14766 Mdot
.96 .14807 Mdot
.96 .14841 Mdot
.96 .14888 Mdot
.96 .14928 Mdot
.96 .14963 Mdot
.96 .14987 Mdot
.96 .14991 Mdot
.96 .15023 Mdot
.96 .15031 Mdot
.96 .15039 Mdot
.96 .15042 Mdot
.96 .15074 Mdot
.96 .15106 Mdot
.96 .15262 Mdot
.96 .15344 Mdot
.96 .15381 Mdot
.96 .15473 Mdot
.96 .15512 Mdot
.96 .15528 Mdot
.96 .15572 Mdot
.96 .15767 Mdot
.96 .15914 Mdot
.96 .15969 Mdot
.96 .16051 Mdot
.96 .16056 Mdot
.96 .16085 Mdot
.96 .16105 Mdot
.96 .16169 Mdot
.96 .16192 Mdot
.96 .16209 Mdot
.96 .1624 Mdot
.96 .16275 Mdot
.96 .16366 Mdot
.96 .16492 Mdot
.96 .16512 Mdot
.96 .16541 Mdot
.96 .16643 Mdot
.96 .16812 Mdot
.96 .1685 Mdot
.96 .16921 Mdot
.96 .16965 Mdot
.96 .16972 Mdot
.96 .17097 Mdot
.96 .17106 Mdot
.96 .17128 Mdot
.96 .1714 Mdot
.96 .17172 Mdot
.96 .17295 Mdot
.96 .17373 Mdot
.96 .17381 Mdot
.96 .17393 Mdot
.96 .1741 Mdot
.96 .17528 Mdot
.96 .17563 Mdot
.96 .17567 Mdot
.96 .17655 Mdot
.96 .17712 Mdot
.96 .17735 Mdot
.96 .17745 Mdot
.96 .17799 Mdot
.96 .18021 Mdot
.96 .18022 Mdot
.96 .18218 Mdot
.96 .18331 Mdot
.96 .18373 Mdot
.96 .18381 Mdot
.96 .18385 Mdot
.96 .18557 Mdot
.96 .1857 Mdot
.96 .18597 Mdot
.96 .18607 Mdot
.96 .18653 Mdot
.96 .18675 Mdot
.96 .18685 Mdot
.96 .18701 Mdot
.96 .18787 Mdot
.96 .1882 Mdot
.96 .18864 Mdot
.96 .18958 Mdot
.96 .18994 Mdot
.96 .19039 Mdot
.96 .19062 Mdot
.96 .19166 Mdot
.96 .19285 Mdot
.96 .19372 Mdot
.96 .19422 Mdot
.96 .19514 Mdot
.96 .19521 Mdot
.96 .19601 Mdot
.96 .19606 Mdot
.96 .19607 Mdot
.96 .19671 Mdot
.96 .19762 Mdot
.96 .19816 Mdot
.96 .19857 Mdot
.96 .19875 Mdot
.96 .19912 Mdot
.96 .19972 Mdot
.96 .20017 Mdot
.96 .20064 Mdot
.96 .20073 Mdot
.96 .20095 Mdot
.96 .20106 Mdot
.96 .20116 Mdot
.96 .20124 Mdot
.96 .20175 Mdot
.96 .20223 Mdot
.96 .20333 Mdot
.96 .20448 Mdot
.96 .20539 Mdot
.96 .20548 Mdot
.96 .20645 Mdot
.96 .2067 Mdot
.96 .2068 Mdot
.96 .20789 Mdot
.96 .20828 Mdot
.96 .20836 Mdot
.96 .20987 Mdot
.96 .21043 Mdot
.96 .21074 Mdot
.96 .21119 Mdot
.96 .21122 Mdot
.96 .21131 Mdot
.96 .21185 Mdot
.96 .21195 Mdot
.96 .21227 Mdot
.96 .21283 Mdot
.96 .21286 Mdot
.96 .21301 Mdot
.96 .21414 Mdot
.96 .21532 Mdot
.96 .21643 Mdot
.96 .21704 Mdot
.96 .21789 Mdot
.96 .21848 Mdot
.96 .21874 Mdot
.96 .21902 Mdot
.96 .21924 Mdot
.96 .21931 Mdot
.96 .21988 Mdot
.96 .22044 Mdot
.96 .22073 Mdot
.96 .22204 Mdot
.96 .22247 Mdot
.96 .22281 Mdot
.96 .22313 Mdot
.96 .22383 Mdot
.96 .22507 Mdot
.96 .22589 Mdot
.96 .226 Mdot
.96 .22663 Mdot
.96 .22731 Mdot
.96 .2282 Mdot
.96 .22976 Mdot
.96 .22991 Mdot
.96 .23073 Mdot
.96 .23112 Mdot
.96 .23113 Mdot
.96 .23273 Mdot
.96 .23344 Mdot
.96 .23392 Mdot
.96 .23401 Mdot
.96 .23416 Mdot
.96 .23454 Mdot
.96 .23488 Mdot
.96 .23497 Mdot
.96 .2351 Mdot
.96 .23737 Mdot
.96 .23975 Mdot
.96 .24009 Mdot
.96 .24026 Mdot
.96 .24031 Mdot
.96 .2407 Mdot
.96 .2413 Mdot
.96 .24216 Mdot
.96 .24251 Mdot
.96 .24287 Mdot
.96 .24287 Mdot
.96 .24295 Mdot
.96 .24331 Mdot
.96 .24366 Mdot
.96 .24377 Mdot
.96 .24433 Mdot
.96 .24476 Mdot
.96 .24482 Mdot
.96 .24485 Mdot
.96 .24491 Mdot
.96 .24509 Mdot
.96 .24555 Mdot
.96 .24629 Mdot
.96 .2473 Mdot
.96 .24854 Mdot
.96 .24914 Mdot
.96 .24959 Mdot
.96 .25044 Mdot
.96 .25058 Mdot
.96 .25068 Mdot
.96 .25097 Mdot
.96 .25159 Mdot
.96 .25162 Mdot
.96 .25193 Mdot
.96 .25208 Mdot
.96 .25331 Mdot
.96 .25509 Mdot
.96 .2554 Mdot
.96 .25549 Mdot
.96 .25598 Mdot
.96 .25666 Mdot
.96 .25682 Mdot
.96 .25737 Mdot
.96 .25775 Mdot
.96 .258 Mdot
.96 .25863 Mdot
.96 .25896 Mdot
.96 .25944 Mdot
.96 .25969 Mdot
.96 .25974 Mdot
.96 .25977 Mdot
.96 .25982 Mdot
.96 .2611 Mdot
.96 .26137 Mdot
.96 .26305 Mdot
.96 .26335 Mdot
.96 .26392 Mdot
.96 .26418 Mdot
.96 .26502 Mdot
.96 .26596 Mdot
.96 .26681 Mdot
.96 .26726 Mdot
.96 .26781 Mdot
.96 .26788 Mdot
.96 .26799 Mdot
.96 .26997 Mdot
.96 .27075 Mdot
.96 .27142 Mdot
.96 .27231 Mdot
.96 .27308 Mdot
.96 .27324 Mdot
.96 .27339 Mdot
.96 .27374 Mdot
.96 .27421 Mdot
.96 .27429 Mdot
.96 .2749 Mdot
.96 .27506 Mdot
.96 .27521 Mdot
.96 .27527 Mdot
.96 .27588 Mdot
.96 .2765 Mdot
.96 .27658 Mdot
.96 .27678 Mdot
.96 .27782 Mdot
.96 .27847 Mdot
.96 .27864 Mdot
.96 .2795 Mdot
.96 .28006 Mdot
.96 .28106 Mdot
.96 .28179 Mdot
.96 .2823 Mdot
.96 .28239 Mdot
.96 .28355 Mdot
.96 .28429 Mdot
.96 .28461 Mdot
.96 .28545 Mdot
.96 .28547 Mdot
.96 .28674 Mdot
.96 .28806 Mdot
.96 .28809 Mdot
.96 .28837 Mdot
.96 .28919 Mdot
.96 .28971 Mdot
.96 .29099 Mdot
.96 .29139 Mdot
.96 .29174 Mdot
.96 .29189 Mdot
.96 .292 Mdot
.96 .29307 Mdot
.96 .29347 Mdot
.96 .29391 Mdot
.96 .29464 Mdot
.96 .29474 Mdot
.96 .29505 Mdot
.96 .29526 Mdot
.96 .29529 Mdot
.96 .29539 Mdot
.96 .29559 Mdot
.96 .29568 Mdot
.96 .29626 Mdot
.96 .2969 Mdot
.96 .29735 Mdot
.96 .29767 Mdot
.96 .29797 Mdot
.96 .29827 Mdot
.96 .29894 Mdot
.96 .29973 Mdot
.96 .30068 Mdot
.96 .30069 Mdot
.96 .30311 Mdot
.96 .30338 Mdot
.96 .3035 Mdot
.96 .30405 Mdot
.96 .30441 Mdot
.96 .30601 Mdot
.96 .30897 Mdot
.96 .30925 Mdot
.96 .30998 Mdot
.96 .31119 Mdot
.96 .31134 Mdot
.96 .31218 Mdot
.96 .31233 Mdot
.96 .31244 Mdot
.96 .31286 Mdot
.96 .31472 Mdot
.96 .3149 Mdot
.96 .31525 Mdot
.96 .31532 Mdot
.96 .31555 Mdot
.96 .31598 Mdot
.96 .31617 Mdot
.96 .31649 Mdot
.96 .31688 Mdot
.96 .31776 Mdot
.96 .31793 Mdot
.96 .31852 Mdot
.96 .31883 Mdot
.96 .31962 Mdot
.96 .32003 Mdot
.96 .32018 Mdot
.96 .32021 Mdot
.96 .32034 Mdot
.96 .32041 Mdot
.96 .32074 Mdot
.96 .32146 Mdot
.96 .32204 Mdot
.96 .32301 Mdot
.96 .32367 Mdot
.96 .32374 Mdot
.96 .32543 Mdot
.96 .32653 Mdot
.96 .32657 Mdot
.96 .32698 Mdot
.96 .32716 Mdot
.96 .32718 Mdot
.96 .3282 Mdot
.96 .33 Mdot
.96 .33247 Mdot
.96 .33249 Mdot
.96 .33313 Mdot
.96 .33314 Mdot
.96 .33428 Mdot
.96 .33459 Mdot
.96 .33624 Mdot
.96 .3364 Mdot
.96 .33826 Mdot
.96 .33841 Mdot
.96 .3389 Mdot
.96 .33898 Mdot
.96 .33922 Mdot
.96 .33938 Mdot
.96 .33946 Mdot
.96 .3395 Mdot
.96 .3412 Mdot
.96 .34151 Mdot
.96 .34264 Mdot
.96 .34276 Mdot
.96 .34291 Mdot
.96 .34294 Mdot
.96 .34301 Mdot
.96 .34352 Mdot
.96 .34358 Mdot
.96 .34372 Mdot
.96 .34387 Mdot
.96 .3446 Mdot
.96 .34501 Mdot
.96 .34503 Mdot
.96 .34521 Mdot
.96 .34552 Mdot
.96 .34564 Mdot
.96 .34618 Mdot
.96 .34718 Mdot
.96 .34738 Mdot
.96 .34781 Mdot
.96 .34865 Mdot
.96 .34918 Mdot
.96 .34972 Mdot
.96 .35009 Mdot
.96 .35026 Mdot
.96 .35037 Mdot
.96 .35046 Mdot
.96 .35055 Mdot
.96 .35114 Mdot
.96 .35201 Mdot
.96 .35244 Mdot
.96 .3543 Mdot
.96 .35445 Mdot
.96 .35529 Mdot
.96 .35627 Mdot
.96 .35674 Mdot
.96 .35746 Mdot
.96 .3584 Mdot
.96 .35936 Mdot
.96 .35976 Mdot
.96 .36113 Mdot
.96 .36126 Mdot
.96 .36187 Mdot
.96 .36247 Mdot
.96 .3628 Mdot
.96 .3629 Mdot
.96 .36292 Mdot
.96 .36357 Mdot
.96 .36399 Mdot
.96 .36414 Mdot
.96 .36567 Mdot
.96 .3659 Mdot
.96 .36664 Mdot
.96 .36693 Mdot
.96 .36771 Mdot
.96 .36807 Mdot
.96 .36873 Mdot
.96 .36877 Mdot
.96 .36973 Mdot
.96 .36993 Mdot
.96 .3708 Mdot
.96 .3717 Mdot
.96 .37186 Mdot
.96 .37229 Mdot
.96 .3725 Mdot
.96 .37268 Mdot
.96 .37284 Mdot
.96 .37321 Mdot
.96 .37382 Mdot
.96 .37434 Mdot
.96 .37474 Mdot
.96 .37632 Mdot
.96 .37685 Mdot
.96 .378 Mdot
.96 .37907 Mdot
.96 .38003 Mdot
.96 .38027 Mdot
.96 .38066 Mdot
.96 .38081 Mdot
.96 .38098 Mdot
.96 .38106 Mdot
.96 .38108 Mdot
.96 .38284 Mdot
.96 .38332 Mdot
.96 .38352 Mdot
.96 .38562 Mdot
.96 .38636 Mdot
.96 .38651 Mdot
.96 .38797 Mdot
.96 .38942 Mdot
.96 .39049 Mdot
.96 .39086 Mdot
.96 .39109 Mdot
.96 .39194 Mdot
.96 .392 Mdot
.96 .39217 Mdot
.96 .39322 Mdot
.96 .39332 Mdot
.96 .39341 Mdot
.96 .39403 Mdot
.96 .3951 Mdot
.96 .39515 Mdot
.96 .39543 Mdot
.96 .3966 Mdot
.96 .39761 Mdot
.96 .3982 Mdot
.96 .39945 Mdot
.96 .39988 Mdot
.96 .40005 Mdot
.96 .40013 Mdot
.96 .40058 Mdot
.96 .40098 Mdot
.96 .40189 Mdot
.96 .40201 Mdot
.96 .40318 Mdot
.96 .40363 Mdot
.96 .40389 Mdot
.96 .40482 Mdot
.96 .40485 Mdot
.96 .40594 Mdot
.96 .40615 Mdot
.96 .40644 Mdot
.96 .40675 Mdot
.96 .40699 Mdot
.96 .40728 Mdot
.96 .40739 Mdot
.96 .40745 Mdot
.96 .4075 Mdot
.96 .40754 Mdot
.96 .40863 Mdot
.96 .40971 Mdot
.96 .40975 Mdot
.96 .41026 Mdot
.96 .41204 Mdot
.96 .41233 Mdot
.96 .41279 Mdot
.96 .41307 Mdot
.96 .4136 Mdot
.96 .41426 Mdot
.96 .41488 Mdot
.96 .41622 Mdot
.96 .41692 Mdot
.96 .4186 Mdot
.96 .41878 Mdot
.96 .41931 Mdot
.96 .41996 Mdot
.96 .42038 Mdot
.96 .42159 Mdot
.96 .4229 Mdot
.96 .42311 Mdot
.96 .42461 Mdot
.96 .42518 Mdot
.96 .4276 Mdot
.96 .42789 Mdot
.96 .42886 Mdot
.96 .42946 Mdot
.96 .43021 Mdot
.96 .43024 Mdot
.96 .43153 Mdot
.96 .4333 Mdot
.96 .43344 Mdot
.96 .43377 Mdot
.96 .43467 Mdot
.96 .43559 Mdot
.96 .43575 Mdot
.96 .43605 Mdot
.96 .43678 Mdot
.96 .43744 Mdot
.96 .43761 Mdot
.96 .43786 Mdot
.96 .43803 Mdot
.96 .43974 Mdot
.96 .44076 Mdot
.96 .44169 Mdot
.96 .44193 Mdot
.96 .44222 Mdot
.96 .44505 Mdot
.96 .44512 Mdot
.96 .44678 Mdot
.96 .44689 Mdot
.96 .44743 Mdot
.96 .44777 Mdot
.96 .44786 Mdot
.96 .4486 Mdot
.96 .44976 Mdot
.96 .44981 Mdot
.96 .45141 Mdot
.96 .45208 Mdot
.96 .45277 Mdot
.96 .45278 Mdot
.96 .45293 Mdot
.96 .45362 Mdot
.96 .45429 Mdot
.96 .4545 Mdot
.96 .45468 Mdot
.96 .45476 Mdot
.96 .45558 Mdot
.96 .45581 Mdot
.96 .4564 Mdot
.96 .45651 Mdot
.96 .45658 Mdot
.96 .45669 Mdot
.96 .45703 Mdot
.96 .45793 Mdot
.96 .45884 Mdot
.96 .45934 Mdot
.96 .46074 Mdot
.96 .46128 Mdot
.96 .46366 Mdot
.96 .46481 Mdot
.96 .46546 Mdot
.96 .46568 Mdot
.96 .46693 Mdot
.96 .46731 Mdot
.96 .46757 Mdot
.96 .46777 Mdot
.96 .46823 Mdot
.96 .46832 Mdot
.96 .46879 Mdot
.96 .4692 Mdot
.96 .46951 Mdot
.96 .46958 Mdot
.96 .47016 Mdot
.96 .47046 Mdot
.96 .47282 Mdot
.96 .47314 Mdot
.96 .4746 Mdot
.96 .47624 Mdot
.96 .47624 Mdot
.96 .47683 Mdot
.96 .477 Mdot
.96 .47794 Mdot
.96 .47891 Mdot
.96 .47924 Mdot
.96 .47928 Mdot
.96 .47956 Mdot
.96 .48044 Mdot
.96 .4806 Mdot
.96 .48119 Mdot
.96 .48133 Mdot
.96 .48135 Mdot
.96 .48168 Mdot
.96 .48183 Mdot
.96 .48243 Mdot
.96 .48275 Mdot
.96 .48303 Mdot
.96 .48366 Mdot
.96 .48459 Mdot
.96 .48488 Mdot
.96 .48507 Mdot
.96 .48516 Mdot
.96 .48522 Mdot
.96 .48531 Mdot
.96 .48726 Mdot
.96 .48778 Mdot
.96 .48829 Mdot
.96 .48891 Mdot
.96 .49011 Mdot
.96 .49121 Mdot
.96 .49152 Mdot
.96 .49209 Mdot
.96 .49231 Mdot
.96 .49319 Mdot
.96 .49369 Mdot
.96 .49478 Mdot
.96 .4953 Mdot
.96 .49711 Mdot
.96 .4977 Mdot
.96 .49873 Mdot
.96 .49961 Mdot
.96 .50067 Mdot
.96 .50079 Mdot
.96 .50099 Mdot
.96 .5012 Mdot
.96 .50121 Mdot
.96 .5048 Mdot
.96 .50631 Mdot
.96 .50759 Mdot
.96 .50929 Mdot
.96 .51013 Mdot
.96 .51078 Mdot
.96 .51109 Mdot
.96 .51114 Mdot
.96 .51137 Mdot
.96 .51158 Mdot
.96 .51205 Mdot
.96 .51295 Mdot
.96 .51309 Mdot
.96 .51359 Mdot
.96 .51427 Mdot
.96 .51458 Mdot
.96 .51486 Mdot
.96 .51495 Mdot
.96 .51497 Mdot
.96 .51614 Mdot
.96 .51734 Mdot
.96 .51749 Mdot
.96 .51787 Mdot
.96 .51988 Mdot
.96 .52085 Mdot
.96 .52112 Mdot
.96 .52146 Mdot
.96 .5231 Mdot
.96 .52418 Mdot
.96 .5261 Mdot
.96 .52749 Mdot
.96 .52848 Mdot
.96 .52865 Mdot
.96 .53087 Mdot
.96 .53176 Mdot
.96 .5323 Mdot
.96 .53278 Mdot
.96 .5329 Mdot
.96 .53453 Mdot
.96 .53457 Mdot
.96 .53549 Mdot
.96 .53701 Mdot
.96 .53954 Mdot
.96 .53959 Mdot
.96 .54013 Mdot
.96 .54171 Mdot
.96 .5427 Mdot
.96 .54516 Mdot
.96 .54592 Mdot
.96 .5466 Mdot
.96 .54689 Mdot
.96 .54711 Mdot
.96 .54916 Mdot
.96 .54992 Mdot
.96 .55077 Mdot
.96 .55216 Mdot
.96 .55236 Mdot
.96 .55296 Mdot
.96 .55335 Mdot
.96 .55343 Mdot
.96 .55361 Mdot
.96 .554 Mdot
.96 .55417 Mdot
.96 .55527 Mdot
.96 .55651 Mdot
.96 .55737 Mdot
.96 .558 Mdot
.96 .55857 Mdot
.96 .55914 Mdot
.96 .56043 Mdot
.96 .56195 Mdot
.96 .56377 Mdot
.96 .56378 Mdot
.96 .56842 Mdot
.96 .56895 Mdot
.96 .56918 Mdot
.96 .57023 Mdot
.96 .57093 Mdot
.96 .57401 Mdot
.96 .57969 Mdot
.96 .58022 Mdot
.96 .58163 Mdot
.962 .01651 Mdot
.962 .01728 Mdot
.962 .01761 Mdot
.962 .01817 Mdot
.962 .01897 Mdot
.962 .01966 Mdot
.962 .01973 Mdot
.962 .02029 Mdot
.962 .02039 Mdot
.962 .02136 Mdot
.962 .02206 Mdot
.962 .0224 Mdot
.962 .02291 Mdot
.962 .02422 Mdot
.962 .02436 Mdot
.962 .02499 Mdot
.962 .02544 Mdot
.962 .02564 Mdot
.962 .0275 Mdot
.962 .02837 Mdot
.962 .02884 Mdot
.962 .0292 Mdot
.962 .0295 Mdot
.962 .02972 Mdot
.962 .0298 Mdot
.962 .03009 Mdot
.962 .03048 Mdot
.962 .0312 Mdot
.962 .03256 Mdot
.962 .03295 Mdot
.962 .03301 Mdot
.962 .03306 Mdot
.962 .03327 Mdot
.962 .0333 Mdot
.962 .03449 Mdot
.962 .03535 Mdot
.962 .03573 Mdot
.962 .03593 Mdot
.962 .03739 Mdot
.962 .03861 Mdot
.962 .03931 Mdot
.962 .03941 Mdot
.962 .04064 Mdot
.962 .04098 Mdot
.962 .04139 Mdot
.962 .0419 Mdot
.962 .04258 Mdot
.962 .04316 Mdot
.962 .04344 Mdot
.962 .04358 Mdot
.962 .04369 Mdot
.962 .04375 Mdot
.962 .04414 Mdot
.962 .04429 Mdot
.962 .04504 Mdot
.962 .04505 Mdot
.962 .04525 Mdot
.962 .04531 Mdot
.962 .04644 Mdot
.962 .04905 Mdot
.962 .04979 Mdot
.962 .0498 Mdot
.962 .04991 Mdot
.962 .05 Mdot
.962 .05041 Mdot
.962 .05047 Mdot
.962 .05191 Mdot
.962 .05275 Mdot
.962 .0528 Mdot
.962 .05441 Mdot
.962 .05515 Mdot
.962 .05553 Mdot
.962 .05557 Mdot
.962 .05733 Mdot
.962 .05756 Mdot
.962 .05835 Mdot
.962 .05934 Mdot
.962 .06037 Mdot
.962 .0607 Mdot
.962 .06134 Mdot
.962 .06164 Mdot
.962 .06203 Mdot
.962 .06223 Mdot
.962 .06459 Mdot
.962 .06525 Mdot
.962 .06604 Mdot
.962 .06691 Mdot
.962 .06701 Mdot
.962 .06833 Mdot
.962 .06881 Mdot
.962 .06909 Mdot
.962 .06945 Mdot
.962 .06999 Mdot
.962 .07025 Mdot
.962 .07047 Mdot
.962 .07057 Mdot
.962 .07134 Mdot
.962 .07142 Mdot
.962 .07146 Mdot
.962 .07162 Mdot
.962 .07226 Mdot
.962 .073 Mdot
.962 .07307 Mdot
.962 .07308 Mdot
.962 .07346 Mdot
.962 .07358 Mdot
.962 .0746 Mdot
.962 .07465 Mdot
.962 .07526 Mdot
.962 .07554 Mdot
.962 .07575 Mdot
.962 .07594 Mdot
.962 .07914 Mdot
.962 .08078 Mdot
.962 .0815 Mdot
.962 .08151 Mdot
.962 .08156 Mdot
.962 .08173 Mdot
.962 .08221 Mdot
.962 .08223 Mdot
.962 .08242 Mdot
.962 .08261 Mdot
.962 .0828 Mdot
.962 .08304 Mdot
.962 .0834 Mdot
.962 .08351 Mdot
.962 .08372 Mdot
.962 .08395 Mdot
.962 .08426 Mdot
.962 .08478 Mdot
.962 .08627 Mdot
.962 .08686 Mdot
.962 .08768 Mdot
.962 .0879 Mdot
.962 .08799 Mdot
.962 .08843 Mdot
.962 .08878 Mdot
.962 .09108 Mdot
.962 .09209 Mdot
.962 .09251 Mdot
.962 .09312 Mdot
.962 .09323 Mdot
.962 .09331 Mdot
.962 .09423 Mdot
.962 .09439 Mdot
.962 .09671 Mdot
.962 .09691 Mdot
.962 .09715 Mdot
.962 .09823 Mdot
.962 .09866 Mdot
.962 .10033 Mdot
.962 .10057 Mdot
.962 .10256 Mdot
.962 .10319 Mdot
.962 .10364 Mdot
.962 .10398 Mdot
.962 .10436 Mdot
.962 .10443 Mdot
.962 .10499 Mdot
.962 .10575 Mdot
.962 .10613 Mdot
.962 .10968 Mdot
.962 .11047 Mdot
.962 .11067 Mdot
.962 .11179 Mdot
.962 .11195 Mdot
.962 .11217 Mdot
.962 .11239 Mdot
.962 .11346 Mdot
.962 .11354 Mdot
.962 .1145 Mdot
.962 .11514 Mdot
.962 .11533 Mdot
.962 .11627 Mdot
.962 .11638 Mdot
.962 .11656 Mdot
.962 .11675 Mdot
.962 .11786 Mdot
.962 .11823 Mdot
.962 .11844 Mdot
.962 .11879 Mdot
.962 .11919 Mdot
.962 .11934 Mdot
.962 .12002 Mdot
.962 .12105 Mdot
.962 .12156 Mdot
.962 .12199 Mdot
.962 .12218 Mdot
.962 .12219 Mdot
.962 .12366 Mdot
.962 .12382 Mdot
.962 .1239 Mdot
.962 .1242 Mdot
.962 .12544 Mdot
.962 .12664 Mdot
.962 .12676 Mdot
.962 .12686 Mdot
.962 .12699 Mdot
.962 .127 Mdot
.962 .12774 Mdot
.962 .1278 Mdot
.962 .12783 Mdot
.962 .12791 Mdot
.962 .12796 Mdot
.962 .12927 Mdot
.962 .12994 Mdot
.962 .13004 Mdot
.962 .13066 Mdot
.962 .1307 Mdot
.962 .13119 Mdot
.962 .13121 Mdot
.962 .13174 Mdot
.962 .13215 Mdot
.962 .13244 Mdot
.962 .13249 Mdot
.962 .13251 Mdot
.962 .13642 Mdot
.962 .1372 Mdot
.962 .13834 Mdot
.962 .13867 Mdot
.962 .13991 Mdot
.962 .14024 Mdot
.962 .14116 Mdot
.962 .14137 Mdot
.962 .14149 Mdot
.962 .14183 Mdot
.962 .14322 Mdot
.962 .14323 Mdot
.962 .14332 Mdot
.962 .14355 Mdot
.962 .14366 Mdot
.962 .14428 Mdot
.962 .14457 Mdot
.962 .14461 Mdot
.962 .14499 Mdot
.962 .14535 Mdot
.962 .14571 Mdot
.962 .14618 Mdot
.962 .14618 Mdot
.962 .14632 Mdot
.962 .14667 Mdot
.962 .14686 Mdot
.962 .14707 Mdot
.962 .14747 Mdot
.962 .14792 Mdot
.962 .14852 Mdot
.962 .14907 Mdot
.962 .14925 Mdot
.962 .14929 Mdot
.962 .14953 Mdot
.962 .14964 Mdot
.962 .15184 Mdot
.962 .15239 Mdot
.962 .15278 Mdot
.962 .15283 Mdot
.962 .15353 Mdot
.962 .15419 Mdot
.962 .15453 Mdot
.962 .15473 Mdot
.962 .1551 Mdot
.962 .15553 Mdot
.962 .15569 Mdot
.962 .15654 Mdot
.962 .15654 Mdot
.962 .15697 Mdot
.962 .15722 Mdot
.962 .15942 Mdot
.962 .16023 Mdot
.962 .16108 Mdot
.962 .16137 Mdot
.962 .16165 Mdot
.962 .16208 Mdot
.962 .16244 Mdot
.962 .16248 Mdot
.962 .16356 Mdot
.962 .16359 Mdot
.962 .16439 Mdot
.962 .16494 Mdot
.962 .16556 Mdot
.962 .16578 Mdot
.962 .16594 Mdot
.962 .16691 Mdot
.962 .16769 Mdot
.962 .16801 Mdot
.962 .16819 Mdot
.962 .16888 Mdot
.962 .16909 Mdot
.962 .16918 Mdot
.962 .16975 Mdot
.962 .16993 Mdot
.962 .17038 Mdot
.962 .17047 Mdot
.962 .17117 Mdot
.962 .17231 Mdot
.962 .17247 Mdot
.962 .17255 Mdot
.962 .17285 Mdot
.962 .17322 Mdot
.962 .17332 Mdot
.962 .17342 Mdot
.962 .1754 Mdot
.962 .17622 Mdot
.962 .17659 Mdot
.962 .17664 Mdot
.962 .17943 Mdot
.962 .17991 Mdot
.962 .17997 Mdot
.962 .18045 Mdot
.962 .18099 Mdot
.962 .18107 Mdot
.962 .18301 Mdot
.962 .18308 Mdot
.962 .18373 Mdot
.962 .18457 Mdot
.962 .18459 Mdot
.962 .18483 Mdot
.962 .18493 Mdot
.962 .1858 Mdot
.962 .18645 Mdot
.962 .18704 Mdot
.962 .18718 Mdot
.962 .18732 Mdot
.962 .1884 Mdot
.962 .18987 Mdot
.962 .18992 Mdot
.962 .1906 Mdot
.962 .19096 Mdot
.962 .19152 Mdot
.962 .19242 Mdot
.962 .19251 Mdot
.962 .19535 Mdot
.962 .19583 Mdot
.962 .19586 Mdot
.962 .19743 Mdot
.962 .19863 Mdot
.962 .19894 Mdot
.962 .19934 Mdot
.962 .2002 Mdot
.962 .20021 Mdot
.962 .20148 Mdot
.962 .20179 Mdot
.962 .20222 Mdot
.962 .20264 Mdot
.962 .2032 Mdot
.962 .20404 Mdot
.962 .20469 Mdot
.962 .20484 Mdot
.962 .20544 Mdot
.962 .20607 Mdot
.962 .20671 Mdot
.962 .20682 Mdot
.962 .20794 Mdot
.962 .20801 Mdot
.962 .2083 Mdot
.962 .20861 Mdot
.962 .20985 Mdot
.962 .2101 Mdot
.962 .21012 Mdot
.962 .21033 Mdot
.962 .21066 Mdot
.962 .21097 Mdot
.962 .21103 Mdot
.962 .21121 Mdot
.962 .21127 Mdot
.962 .21214 Mdot
.962 .21317 Mdot
.962 .21388 Mdot
.962 .21428 Mdot
.962 .21428 Mdot
.962 .21495 Mdot
.962 .21572 Mdot
.962 .21601 Mdot
.962 .21642 Mdot
.962 .21733 Mdot
.962 .21851 Mdot
.962 .21931 Mdot
.962 .22029 Mdot
.962 .22111 Mdot
.962 .22141 Mdot
.962 .22148 Mdot
.962 .22149 Mdot
.962 .22173 Mdot
.962 .22231 Mdot
.962 .22289 Mdot
.962 .22345 Mdot
.962 .22432 Mdot
.962 .22463 Mdot
.962 .22478 Mdot
.962 .22536 Mdot
.962 .22559 Mdot
.962 .22642 Mdot
.962 .22775 Mdot
.962 .2283 Mdot
.962 .22951 Mdot
.962 .23006 Mdot
.962 .23029 Mdot
.962 .23034 Mdot
.962 .23049 Mdot
.962 .23073 Mdot
.962 .23076 Mdot
.962 .23079 Mdot
.962 .23218 Mdot
.962 .23229 Mdot
.962 .23235 Mdot
.962 .23239 Mdot
.962 .2325 Mdot
.962 .2326 Mdot
.962 .23426 Mdot
.962 .23442 Mdot
.962 .23512 Mdot
.962 .23578 Mdot
.962 .2364 Mdot
.962 .23647 Mdot
.962 .23659 Mdot
.962 .2378 Mdot
.962 .2378 Mdot
.962 .23787 Mdot
.962 .23882 Mdot
.962 .23884 Mdot
.962 .23987 Mdot
.962 .24067 Mdot
.962 .24095 Mdot
.962 .24123 Mdot
.962 .24131 Mdot
.962 .24136 Mdot
.962 .24297 Mdot
.962 .24327 Mdot
.962 .24384 Mdot
.962 .24385 Mdot
.962 .24402 Mdot
.962 .24458 Mdot
.962 .24546 Mdot
.962 .24557 Mdot
.962 .2457 Mdot
.962 .24703 Mdot
.962 .24887 Mdot
.962 .25038 Mdot
.962 .25085 Mdot
.962 .25125 Mdot
.962 .25145 Mdot
.962 .25163 Mdot
.962 .25202 Mdot
.962 .2524 Mdot
.962 .25257 Mdot
.962 .2532 Mdot
.962 .25349 Mdot
.962 .2556 Mdot
.962 .25623 Mdot
.962 .25677 Mdot
.962 .25786 Mdot
.962 .25799 Mdot
.962 .2584 Mdot
.962 .25852 Mdot
.962 .25862 Mdot
.962 .25914 Mdot
.962 .25928 Mdot
.962 .26172 Mdot
.962 .26195 Mdot
.962 .26199 Mdot
.962 .26215 Mdot
.962 .26257 Mdot
.962 .2626 Mdot
.962 .26281 Mdot
.962 .26283 Mdot
.962 .264 Mdot
.962 .26415 Mdot
.962 .26416 Mdot
.962 .26456 Mdot
.962 .26463 Mdot
.962 .26536 Mdot
.962 .26605 Mdot
.962 .26646 Mdot
.962 .26673 Mdot
.962 .26675 Mdot
.962 .26716 Mdot
.962 .26717 Mdot
.962 .26766 Mdot
.962 .26766 Mdot
.962 .26793 Mdot
.962 .26859 Mdot
.962 .26896 Mdot
.962 .26936 Mdot
.962 .26992 Mdot
.962 .27014 Mdot
.962 .271 Mdot
.962 .27147 Mdot
.962 .27162 Mdot
.962 .27163 Mdot
.962 .2719 Mdot
.962 .27216 Mdot
.962 .27322 Mdot
.962 .27357 Mdot
.962 .27363 Mdot
.962 .2737 Mdot
.962 .27409 Mdot
.962 .27431 Mdot
.962 .27485 Mdot
.962 .27505 Mdot
.962 .27541 Mdot
.962 .27549 Mdot
.962 .27729 Mdot
.962 .27855 Mdot
.962 .27861 Mdot
.962 .27931 Mdot
.962 .27959 Mdot
.962 .28036 Mdot
.962 .28044 Mdot
.962 .28089 Mdot
.962 .2818 Mdot
.962 .28226 Mdot
.962 .28307 Mdot
.962 .28311 Mdot
.962 .28329 Mdot
.962 .28372 Mdot
.962 .2841 Mdot
.962 .28432 Mdot
.962 .28463 Mdot
.962 .2848 Mdot
.962 .28482 Mdot
.962 .28564 Mdot
.962 .28595 Mdot
.962 .28686 Mdot
.962 .28758 Mdot
.962 .28759 Mdot
.962 .28841 Mdot
.962 .28889 Mdot
.962 .28958 Mdot
.962 .29078 Mdot
.962 .29159 Mdot
.962 .29188 Mdot
.962 .29312 Mdot
.962 .29399 Mdot
.962 .29404 Mdot
.962 .29466 Mdot
.962 .29466 Mdot
.962 .29468 Mdot
.962 .29475 Mdot
.962 .29633 Mdot
.962 .29672 Mdot
.962 .29687 Mdot
.962 .29741 Mdot
.962 .29825 Mdot
.962 .29895 Mdot
.962 .29901 Mdot
.962 .29999 Mdot
.962 .3004 Mdot
.962 .30057 Mdot
.962 .30089 Mdot
.962 .3011 Mdot
.962 .30115 Mdot
.962 .30269 Mdot
.962 .30375 Mdot
.962 .30405 Mdot
.962 .30494 Mdot
.962 .30537 Mdot
.962 .30567 Mdot
.962 .30581 Mdot
.962 .30753 Mdot
.962 .30895 Mdot
.962 .30904 Mdot
.962 .30965 Mdot
.962 .30999 Mdot
.962 .31133 Mdot
.962 .31173 Mdot
.962 .3119 Mdot
.962 .31261 Mdot
.962 .313 Mdot
.962 .31335 Mdot
.962 .31421 Mdot
.962 .31439 Mdot
.962 .31574 Mdot
.962 .31749 Mdot
.962 .31792 Mdot
.962 .31819 Mdot
.962 .31824 Mdot
.962 .31839 Mdot
.962 .31897 Mdot
.962 .31967 Mdot
.962 .31988 Mdot
.962 .31993 Mdot
.962 .32005 Mdot
.962 .32142 Mdot
.962 .32218 Mdot
.962 .32282 Mdot
.962 .32323 Mdot
.962 .32387 Mdot
.962 .32426 Mdot
.962 .32533 Mdot
.962 .32546 Mdot
.962 .32569 Mdot
.962 .32616 Mdot
.962 .32627 Mdot
.962 .3263 Mdot
.962 .32863 Mdot
.962 .32973 Mdot
.962 .33163 Mdot
.962 .33255 Mdot
.962 .33267 Mdot
.962 .33359 Mdot
.962 .33413 Mdot
.962 .33463 Mdot
.962 .33478 Mdot
.962 .33753 Mdot
.962 .33851 Mdot
.962 .33866 Mdot
.962 .33987 Mdot
.962 .33989 Mdot
.962 .34031 Mdot
.962 .34069 Mdot
.962 .34152 Mdot
.962 .34155 Mdot
.962 .34186 Mdot
.962 .34201 Mdot
.962 .34222 Mdot
.962 .34388 Mdot
.962 .34511 Mdot
.962 .34511 Mdot
.962 .34514 Mdot
.962 .34523 Mdot
.962 .34578 Mdot
.962 .34591 Mdot
.962 .34626 Mdot
.962 .34638 Mdot
.962 .34654 Mdot
.962 .34681 Mdot
.962 .3479 Mdot
.962 .34832 Mdot
.962 .34871 Mdot
.962 .34889 Mdot
.962 .35061 Mdot
.962 .35114 Mdot
.962 .35172 Mdot
.962 .35181 Mdot
.962 .35311 Mdot
.962 .3538 Mdot
.962 .35489 Mdot
.962 .35661 Mdot
.962 .35679 Mdot
.962 .35699 Mdot
.962 .35975 Mdot
.962 .36016 Mdot
.962 .36085 Mdot
.962 .36105 Mdot
.962 .36116 Mdot
.962 .36176 Mdot
.962 .36226 Mdot
.962 .36318 Mdot
.962 .36324 Mdot
.962 .36333 Mdot
.962 .36343 Mdot
.962 .3642 Mdot
.962 .36431 Mdot
.962 .3647 Mdot
.962 .36626 Mdot
.962 .36857 Mdot
.962 .36863 Mdot
.962 .36917 Mdot
.962 .36919 Mdot
.962 .36923 Mdot
.962 .36994 Mdot
.962 .37066 Mdot
.962 .37068 Mdot
.962 .37094 Mdot
.962 .37159 Mdot
.962 .37161 Mdot
.962 .37365 Mdot
.962 .37406 Mdot
.962 .37465 Mdot
.962 .37547 Mdot
.962 .37564 Mdot
.962 .37612 Mdot
.962 .37623 Mdot
.962 .37629 Mdot
.962 .37736 Mdot
.962 .37774 Mdot
.962 .37873 Mdot
.962 .3788 Mdot
.962 .37898 Mdot
.962 .38023 Mdot
.962 .38032 Mdot
.962 .38034 Mdot
.962 .38052 Mdot
.962 .38167 Mdot
.962 .38216 Mdot
.962 .38218 Mdot
.962 .38289 Mdot
.962 .38306 Mdot
.962 .38317 Mdot
.962 .38411 Mdot
.962 .38433 Mdot
.962 .3856 Mdot
.962 .38603 Mdot
.962 .38647 Mdot
.962 .38662 Mdot
.962 .38699 Mdot
.962 .38718 Mdot
.962 .3872 Mdot
.962 .38776 Mdot
.962 .38848 Mdot
.962 .3895 Mdot
.962 .39016 Mdot
.962 .39052 Mdot
.962 .39063 Mdot
.962 .39068 Mdot
.962 .39098 Mdot
.962 .39107 Mdot
.962 .3913 Mdot
.962 .39135 Mdot
.962 .39171 Mdot
.962 .3923 Mdot
.962 .39243 Mdot
.962 .39278 Mdot
.962 .39288 Mdot
.962 .39453 Mdot
.962 .39456 Mdot
.962 .39629 Mdot
.962 .39654 Mdot
.962 .39682 Mdot
.962 .39686 Mdot
.962 .39787 Mdot
.962 .39791 Mdot
.962 .39868 Mdot
.962 .39869 Mdot
.962 .39881 Mdot
.962 .39996 Mdot
.962 .40146 Mdot
.962 .402 Mdot
.962 .40229 Mdot
.962 .40276 Mdot
.962 .4028 Mdot
.962 .40405 Mdot
.962 .40428 Mdot
.962 .40453 Mdot
.962 .40455 Mdot
.962 .40599 Mdot
.962 .4068 Mdot
.962 .40681 Mdot
.962 .40836 Mdot
.962 .4088 Mdot
.962 .40952 Mdot
.962 .40986 Mdot
.962 .41024 Mdot
.962 .41086 Mdot
.962 .41117 Mdot
.962 .41182 Mdot
.962 .41196 Mdot
.962 .4124 Mdot
.962 .41253 Mdot
.962 .41255 Mdot
.962 .41301 Mdot
.962 .41412 Mdot
.962 .41523 Mdot
.962 .41632 Mdot
.962 .41783 Mdot
.962 .41799 Mdot
.962 .41829 Mdot
.962 .41859 Mdot
.962 .41888 Mdot
.962 .42 Mdot
.962 .42043 Mdot
.962 .42141 Mdot
.962 .42204 Mdot
.962 .42247 Mdot
.962 .4227 Mdot
.962 .42354 Mdot
.962 .4245 Mdot
.962 .42459 Mdot
.962 .4253 Mdot
.962 .42566 Mdot
.962 .42634 Mdot
.962 .42798 Mdot
.962 .42903 Mdot
.962 .42919 Mdot
.962 .42948 Mdot
.962 .42949 Mdot
.962 .42958 Mdot
.962 .42987 Mdot
.962 .43033 Mdot
.962 .43038 Mdot
.962 .43045 Mdot
.962 .43114 Mdot
.962 .43313 Mdot
.962 .43333 Mdot
.962 .43344 Mdot
.962 .43353 Mdot
.962 .43373 Mdot
.962 .43393 Mdot
.962 .4345 Mdot
.962 .43621 Mdot
.962 .43677 Mdot
.962 .43711 Mdot
.962 .43743 Mdot
.962 .43877 Mdot
.962 .43922 Mdot
.962 .43936 Mdot
.962 .44004 Mdot
.962 .44005 Mdot
.962 .44124 Mdot
.962 .44138 Mdot
.962 .44161 Mdot
.962 .44161 Mdot
.962 .44304 Mdot
.962 .44385 Mdot
.962 .44392 Mdot
.962 .44393 Mdot
.962 .44407 Mdot
.962 .445 Mdot
.962 .4456 Mdot
.962 .44571 Mdot
.962 .44589 Mdot
.962 .44594 Mdot
.962 .44687 Mdot
.962 .44756 Mdot
.962 .44792 Mdot
.962 .44874 Mdot
.962 .44945 Mdot
.962 .44989 Mdot
.962 .44999 Mdot
.962 .45052 Mdot
.962 .45069 Mdot
.962 .45077 Mdot
.962 .45185 Mdot
.962 .45326 Mdot
.962 .45388 Mdot
.962 .4543 Mdot
.962 .45445 Mdot
.962 .45555 Mdot
.962 .45558 Mdot
.962 .4559 Mdot
.962 .4559 Mdot
.962 .45595 Mdot
.962 .45697 Mdot
.962 .45867 Mdot
.962 .45888 Mdot
.962 .45897 Mdot
.962 .45914 Mdot
.962 .46078 Mdot
.962 .46169 Mdot
.962 .46332 Mdot
.962 .46523 Mdot
.962 .46776 Mdot
.962 .46813 Mdot
.962 .46903 Mdot
.962 .46981 Mdot
.962 .4702 Mdot
.962 .47053 Mdot
.962 .47075 Mdot
.962 .47128 Mdot
.962 .47184 Mdot
.962 .47203 Mdot
.962 .47234 Mdot
.962 .47355 Mdot
.962 .47412 Mdot
.962 .47641 Mdot
.962 .47818 Mdot
.962 .4794 Mdot
.962 .47962 Mdot
.962 .47982 Mdot
.962 .48043 Mdot
.962 .48212 Mdot
.962 .48212 Mdot
.962 .48218 Mdot
.962 .48247 Mdot
.962 .48254 Mdot
.962 .48278 Mdot
.962 .48357 Mdot
.962 .48379 Mdot
.962 .48399 Mdot
.962 .48498 Mdot
.962 .48526 Mdot
.962 .48829 Mdot
.962 .48973 Mdot
.962 .48994 Mdot
.962 .4903 Mdot
.962 .4904 Mdot
.962 .49046 Mdot
.962 .49077 Mdot
.962 .49159 Mdot
.962 .49164 Mdot
.962 .49204 Mdot
.962 .4921 Mdot
.962 .4923 Mdot
.962 .49435 Mdot
.962 .49463 Mdot
.962 .49465 Mdot
.962 .4954 Mdot
.962 .49541 Mdot
.962 .49554 Mdot
.962 .49695 Mdot
.962 .49799 Mdot
.962 .49823 Mdot
.962 .49829 Mdot
.962 .49908 Mdot
.962 .49959 Mdot
.962 .49963 Mdot
.962 .50042 Mdot
.962 .50043 Mdot
.962 .50137 Mdot
.962 .50139 Mdot
.962 .50185 Mdot
.962 .5019 Mdot
.962 .50317 Mdot
.962 .50338 Mdot
.962 .50389 Mdot
.962 .50399 Mdot
.962 .50466 Mdot
.962 .50519 Mdot
.962 .50572 Mdot
.962 .50596 Mdot
.962 .50613 Mdot
.962 .50615 Mdot
.962 .50781 Mdot
.962 .50872 Mdot
.962 .50899 Mdot
.962 .50902 Mdot
.962 .50954 Mdot
.962 .51003 Mdot
.962 .51184 Mdot
.962 .51208 Mdot
.962 .51275 Mdot
.962 .51287 Mdot
.962 .513 Mdot
.962 .51376 Mdot
.962 .51418 Mdot
.962 .51522 Mdot
.962 .5156 Mdot
.962 .51577 Mdot
.962 .51629 Mdot
.962 .51645 Mdot
.962 .51686 Mdot
.962 .51991 Mdot
.962 .52016 Mdot
.962 .52177 Mdot
.962 .52233 Mdot
.962 .52245 Mdot
.962 .52288 Mdot
.962 .52338 Mdot
.962 .5238 Mdot
.962 .52434 Mdot
.962 .52582 Mdot
.962 .52597 Mdot
.962 .52683 Mdot
.962 .52858 Mdot
.962 .52947 Mdot
.962 .52976 Mdot
.962 .53103 Mdot
.962 .5311 Mdot
.962 .53146 Mdot
.962 .53227 Mdot
.962 .53302 Mdot
.962 .53344 Mdot
.962 .53404 Mdot
.962 .53435 Mdot
.962 .5344 Mdot
.962 .53501 Mdot
.962 .53537 Mdot
.962 .53598 Mdot
.962 .53658 Mdot
.962 .53759 Mdot
.962 .53833 Mdot
.962 .53887 Mdot
.962 .5397 Mdot
.962 .53973 Mdot
.962 .5413 Mdot
.962 .54224 Mdot
.962 .54356 Mdot
.962 .54587 Mdot
.962 .54742 Mdot
.962 .54799 Mdot
.962 .55036 Mdot
.962 .55203 Mdot
.962 .55214 Mdot
.962 .55333 Mdot
.962 .55333 Mdot
.962 .55336 Mdot
.962 .55351 Mdot
.962 .55654 Mdot
.962 .55729 Mdot
.962 .55758 Mdot
.962 .55862 Mdot
.962 .56023 Mdot
.962 .56158 Mdot
.962 .56171 Mdot
.962 .56358 Mdot
.962 .56438 Mdot
.962 .5647 Mdot
.962 .56532 Mdot
.962 .56572 Mdot
.962 .56581 Mdot
.962 .56878 Mdot
.962 .57082 Mdot
.962 .57139 Mdot
.962 .5731 Mdot
.962 .57394 Mdot
.962 .57452 Mdot
.962 .57478 Mdot
.962 .57809 Mdot
.962 .58082 Mdot
.962 .581 Mdot
.962 .58216 Mdot
.962 .58283 Mdot
.964 .0148 Mdot
.964 .01487 Mdot
.964 .01502 Mdot
.964 .0153 Mdot
.964 .01578 Mdot
.964 .01585 Mdot
.964 .01606 Mdot
.964 .01678 Mdot
.964 .01679 Mdot
.964 .0169 Mdot
.964 .0173 Mdot
.964 .01869 Mdot
.964 .01871 Mdot
.964 .01893 Mdot
.964 .0197 Mdot
.964 .01979 Mdot
.964 .02033 Mdot
.964 .02238 Mdot
.964 .02242 Mdot
.964 .02256 Mdot
.964 .02275 Mdot
.964 .02285 Mdot
.964 .02358 Mdot
.964 .02433 Mdot
.964 .02449 Mdot
.964 .02514 Mdot
.964 .02554 Mdot
.964 .02695 Mdot
.964 .02735 Mdot
.964 .02736 Mdot
.964 .02894 Mdot
.964 .02949 Mdot
.964 .02957 Mdot
.964 .02973 Mdot
.964 .02985 Mdot
.964 .02987 Mdot
.964 .03008 Mdot
.964 .03021 Mdot
.964 .03039 Mdot
.964 .03123 Mdot
.964 .0318 Mdot
.964 .03235 Mdot
.964 .03325 Mdot
.964 .03341 Mdot
.964 .03356 Mdot
.964 .03482 Mdot
.964 .03498 Mdot
.964 .03558 Mdot
.964 .03687 Mdot
.964 .03763 Mdot
.964 .03831 Mdot
.964 .03907 Mdot
.964 .0391 Mdot
.964 .04072 Mdot
.964 .04077 Mdot
.964 .04115 Mdot
.964 .04151 Mdot
.964 .04153 Mdot
.964 .04214 Mdot
.964 .04319 Mdot
.964 .04336 Mdot
.964 .04366 Mdot
.964 .04389 Mdot
.964 .04393 Mdot
.964 .04434 Mdot
.964 .04458 Mdot
.964 .04494 Mdot
.964 .04527 Mdot
.964 .04575 Mdot
.964 .046 Mdot
.964 .04618 Mdot
.964 .04656 Mdot
.964 .04766 Mdot
.964 .04871 Mdot
.964 .05009 Mdot
.964 .05045 Mdot
.964 .05076 Mdot
.964 .05083 Mdot
.964 .05105 Mdot
.964 .05237 Mdot
.964 .05328 Mdot
.964 .05347 Mdot
.964 .05378 Mdot
.964 .05494 Mdot
.964 .05513 Mdot
.964 .05585 Mdot
.964 .05612 Mdot
.964 .05689 Mdot
.964 .05744 Mdot
.964 .0589 Mdot
.964 .05941 Mdot
.964 .06021 Mdot
.964 .0604 Mdot
.964 .06168 Mdot
.964 .06172 Mdot
.964 .06172 Mdot
.964 .06224 Mdot
.964 .06228 Mdot
.964 .06267 Mdot
.964 .06403 Mdot
.964 .06452 Mdot
.964 .06485 Mdot
.964 .06495 Mdot
.964 .06499 Mdot
.964 .06525 Mdot
.964 .06569 Mdot
.964 .06637 Mdot
.964 .06642 Mdot
.964 .06659 Mdot
.964 .06759 Mdot
.964 .06776 Mdot
.964 .06883 Mdot
.964 .06948 Mdot
.964 .06962 Mdot
.964 .06994 Mdot
.964 .07052 Mdot
.964 .07073 Mdot
.964 .07096 Mdot
.964 .07104 Mdot
.964 .07153 Mdot
.964 .07183 Mdot
.964 .0723 Mdot
.964 .0724 Mdot
.964 .07298 Mdot
.964 .07322 Mdot
.964 .07362 Mdot
.964 .07391 Mdot
.964 .07455 Mdot
.964 .07504 Mdot
.964 .07538 Mdot
.964 .07591 Mdot
.964 .07612 Mdot
.964 .07696 Mdot
.964 .07737 Mdot
.964 .07823 Mdot
.964 .07917 Mdot
.964 .08025 Mdot
.964 .08049 Mdot
.964 .0822 Mdot
.964 .08244 Mdot
.964 .08292 Mdot
.964 .08361 Mdot
.964 .08395 Mdot
.964 .08421 Mdot
.964 .08435 Mdot
.964 .08478 Mdot
.964 .08732 Mdot
.964 .08796 Mdot
.964 .08907 Mdot
.964 .08944 Mdot
.964 .09003 Mdot
.964 .09145 Mdot
.964 .09227 Mdot
.964 .09263 Mdot
.964 .09279 Mdot
.964 .09353 Mdot
.964 .09402 Mdot
.964 .0941 Mdot
.964 .0942 Mdot
.964 .09455 Mdot
.964 .09504 Mdot
.964 .09602 Mdot
.964 .09602 Mdot
.964 .0964 Mdot
.964 .09709 Mdot
.964 .09789 Mdot
.964 .098 Mdot
.964 .09865 Mdot
.964 .0999 Mdot
.964 .10089 Mdot
.964 .10127 Mdot
.964 .1019 Mdot
.964 .10208 Mdot
.964 .10242 Mdot
.964 .10252 Mdot
.964 .1028 Mdot
.964 .10371 Mdot
.964 .10448 Mdot
.964 .10526 Mdot
.964 .10534 Mdot
.964 .10535 Mdot
.964 .1056 Mdot
.964 .10634 Mdot
.964 .10642 Mdot
.964 .10668 Mdot
.964 .10718 Mdot
.964 .10729 Mdot
.964 .10813 Mdot
.964 .10891 Mdot
.964 .1098 Mdot
.964 .11074 Mdot
.964 .11138 Mdot
.964 .11158 Mdot
.964 .11164 Mdot
.964 .11202 Mdot
.964 .11215 Mdot
.964 .1125 Mdot
.964 .113 Mdot
.964 .11411 Mdot
.964 .1143 Mdot
.964 .1144 Mdot
.964 .11474 Mdot
.964 .11493 Mdot
.964 .11666 Mdot
.964 .11699 Mdot
.964 .11734 Mdot
.964 .11904 Mdot
.964 .11974 Mdot
.964 .12031 Mdot
.964 .12058 Mdot
.964 .12119 Mdot
.964 .12147 Mdot
.964 .1223 Mdot
.964 .1223 Mdot
.964 .12271 Mdot
.964 .12291 Mdot
.964 .12315 Mdot
.964 .12331 Mdot
.964 .12332 Mdot
.964 .12425 Mdot
.964 .12462 Mdot
.964 .12467 Mdot
.964 .12484 Mdot
.964 .12538 Mdot
.964 .12574 Mdot
.964 .12594 Mdot
.964 .1261 Mdot
.964 .12705 Mdot
.964 .12751 Mdot
.964 .12828 Mdot
.964 .12884 Mdot
.964 .1292 Mdot
.964 .13007 Mdot
.964 .13022 Mdot
.964 .13101 Mdot
.964 .13168 Mdot
.964 .1327 Mdot
.964 .13283 Mdot
.964 .1331 Mdot
.964 .13473 Mdot
.964 .13551 Mdot
.964 .13552 Mdot
.964 .13655 Mdot
.964 .13661 Mdot
.964 .13718 Mdot
.964 .13743 Mdot
.964 .13851 Mdot
.964 .13882 Mdot
.964 .13892 Mdot
.964 .13899 Mdot
.964 .13927 Mdot
.964 .14018 Mdot
.964 .14107 Mdot
.964 .14154 Mdot
.964 .14201 Mdot
.964 .14233 Mdot
.964 .14256 Mdot
.964 .14294 Mdot
.964 .14335 Mdot
.964 .14347 Mdot
.964 .14483 Mdot
.964 .14528 Mdot
.964 .14544 Mdot
.964 .14571 Mdot
.964 .14607 Mdot
.964 .14621 Mdot
.964 .14754 Mdot
.964 .14821 Mdot
.964 .14871 Mdot
.964 .14897 Mdot
.964 .14899 Mdot
.964 .14966 Mdot
.964 .14979 Mdot
.964 .15021 Mdot
.964 .15179 Mdot
.964 .15186 Mdot
.964 .15287 Mdot
.964 .1547 Mdot
.964 .15552 Mdot
.964 .15594 Mdot
.964 .15697 Mdot
.964 .15808 Mdot
.964 .15833 Mdot
.964 .15879 Mdot
.964 .15891 Mdot
.964 .15905 Mdot
.964 .15993 Mdot
.964 .16059 Mdot
.964 .16104 Mdot
.964 .16121 Mdot
.964 .16149 Mdot
.964 .162 Mdot
.964 .16206 Mdot
.964 .16244 Mdot
.964 .16265 Mdot
.964 .16285 Mdot
.964 .1629 Mdot
.964 .16424 Mdot
.964 .16493 Mdot
.964 .16525 Mdot
.964 .16667 Mdot
.964 .16748 Mdot
.964 .16756 Mdot
.964 .16762 Mdot
.964 .16776 Mdot
.964 .16795 Mdot
.964 .16863 Mdot
.964 .16944 Mdot
.964 .16959 Mdot
.964 .17024 Mdot
.964 .17088 Mdot
.964 .17137 Mdot
.964 .17148 Mdot
.964 .17148 Mdot
.964 .17221 Mdot
.964 .17252 Mdot
.964 .17282 Mdot
.964 .17353 Mdot
.964 .17404 Mdot
.964 .17507 Mdot
.964 .17509 Mdot
.964 .17528 Mdot
.964 .17529 Mdot
.964 .17654 Mdot
.964 .17759 Mdot
.964 .17779 Mdot
.964 .17895 Mdot
.964 .17914 Mdot
.964 .1801 Mdot
.964 .18086 Mdot
.964 .18087 Mdot
.964 .1816 Mdot
.964 .18281 Mdot
.964 .18315 Mdot
.964 .18382 Mdot
.964 .184 Mdot
.964 .18454 Mdot
.964 .18482 Mdot
.964 .18623 Mdot
.964 .1863 Mdot
.964 .18778 Mdot
.964 .18928 Mdot
.964 .18943 Mdot
.964 .18946 Mdot
.964 .18995 Mdot
.964 .19005 Mdot
.964 .19136 Mdot
.964 .19153 Mdot
.964 .19158 Mdot
.964 .1917 Mdot
.964 .19202 Mdot
.964 .19253 Mdot
.964 .19298 Mdot
.964 .19321 Mdot
.964 .19482 Mdot
.964 .19633 Mdot
.964 .19702 Mdot
.964 .19729 Mdot
.964 .19804 Mdot
.964 .19915 Mdot
.964 .19985 Mdot
.964 .20057 Mdot
.964 .20087 Mdot
.964 .20109 Mdot
.964 .20138 Mdot
.964 .20146 Mdot
.964 .20149 Mdot
.964 .20158 Mdot
.964 .20232 Mdot
.964 .20241 Mdot
.964 .20247 Mdot
.964 .20257 Mdot
.964 .20324 Mdot
.964 .20332 Mdot
.964 .20341 Mdot
.964 .2042 Mdot
.964 .20524 Mdot
.964 .20635 Mdot
.964 .20671 Mdot
.964 .20691 Mdot
.964 .20744 Mdot
.964 .20749 Mdot
.964 .20756 Mdot
.964 .20772 Mdot
.964 .20793 Mdot
.964 .20794 Mdot
.964 .2097 Mdot
.964 .20992 Mdot
.964 .21009 Mdot
.964 .21127 Mdot
.964 .21189 Mdot
.964 .21195 Mdot
.964 .21231 Mdot
.964 .21257 Mdot
.964 .21422 Mdot
.964 .21566 Mdot
.964 .21569 Mdot
.964 .21585 Mdot
.964 .21719 Mdot
.964 .21769 Mdot
.964 .21829 Mdot
.964 .21857 Mdot
.964 .21859 Mdot
.964 .21881 Mdot
.964 .21884 Mdot
.964 .21933 Mdot
.964 .22 Mdot
.964 .22006 Mdot
.964 .22053 Mdot
.964 .22175 Mdot
.964 .22213 Mdot
.964 .22214 Mdot
.964 .22292 Mdot
.964 .22292 Mdot
.964 .22299 Mdot
.964 .22332 Mdot
.964 .22377 Mdot
.964 .22409 Mdot
.964 .22411 Mdot
.964 .2255 Mdot
.964 .2259 Mdot
.964 .22662 Mdot
.964 .2267 Mdot
.964 .22704 Mdot
.964 .22808 Mdot
.964 .22819 Mdot
.964 .22832 Mdot
.964 .22876 Mdot
.964 .22916 Mdot
.964 .22946 Mdot
.964 .22966 Mdot
.964 .2313 Mdot
.964 .23218 Mdot
.964 .23232 Mdot
.964 .23263 Mdot
.964 .23333 Mdot
.964 .23366 Mdot
.964 .23386 Mdot
.964 .23388 Mdot
.964 .23474 Mdot
.964 .23544 Mdot
.964 .23666 Mdot
.964 .23712 Mdot
.964 .23741 Mdot
.964 .23774 Mdot
.964 .23815 Mdot
.964 .23865 Mdot
.964 .23894 Mdot
.964 .23952 Mdot
.964 .24023 Mdot
.964 .2403 Mdot
.964 .24049 Mdot
.964 .24176 Mdot
.964 .2422 Mdot
.964 .24244 Mdot
.964 .24289 Mdot
.964 .24296 Mdot
.964 .24362 Mdot
.964 .24495 Mdot
.964 .2461 Mdot
.964 .2476 Mdot
.964 .24763 Mdot
.964 .24886 Mdot
.964 .24961 Mdot
.964 .24972 Mdot
.964 .24974 Mdot
.964 .25082 Mdot
.964 .25131 Mdot
.964 .253 Mdot
.964 .2534 Mdot
.964 .25351 Mdot
.964 .254 Mdot
.964 .25418 Mdot
.964 .25431 Mdot
.964 .2545 Mdot
.964 .25467 Mdot
.964 .25486 Mdot
.964 .25636 Mdot
.964 .25661 Mdot
.964 .25728 Mdot
.964 .25833 Mdot
.964 .25852 Mdot
.964 .25923 Mdot
.964 .25924 Mdot
.964 .25933 Mdot
.964 .26015 Mdot
.964 .26076 Mdot
.964 .2612 Mdot
.964 .26194 Mdot
.964 .26252 Mdot
.964 .26272 Mdot
.964 .26296 Mdot
.964 .26513 Mdot
.964 .26557 Mdot
.964 .26645 Mdot
.964 .26676 Mdot
.964 .26727 Mdot
.964 .26774 Mdot
.964 .26797 Mdot
.964 .26823 Mdot
.964 .26948 Mdot
.964 .26964 Mdot
.964 .27081 Mdot
.964 .27136 Mdot
.964 .27209 Mdot
.964 .27243 Mdot
.964 .27306 Mdot
.964 .27355 Mdot
.964 .2736 Mdot
.964 .27368 Mdot
.964 .27451 Mdot
.964 .27452 Mdot
.964 .27488 Mdot
.964 .27514 Mdot
.964 .27519 Mdot
.964 .27594 Mdot
.964 .27703 Mdot
.964 .27813 Mdot
.964 .27899 Mdot
.964 .27912 Mdot
.964 .27975 Mdot
.964 .28029 Mdot
.964 .28108 Mdot
.964 .28134 Mdot
.964 .28293 Mdot
.964 .28317 Mdot
.964 .28387 Mdot
.964 .2846 Mdot
.964 .28482 Mdot
.964 .28618 Mdot
.964 .28699 Mdot
.964 .2886 Mdot
.964 .28898 Mdot
.964 .28945 Mdot
.964 .29023 Mdot
.964 .29109 Mdot
.964 .29112 Mdot
.964 .29114 Mdot
.964 .2916 Mdot
.964 .29248 Mdot
.964 .29272 Mdot
.964 .29279 Mdot
.964 .29299 Mdot
.964 .29305 Mdot
.964 .29469 Mdot
.964 .29553 Mdot
.964 .29596 Mdot
.964 .29613 Mdot
.964 .29683 Mdot
.964 .29689 Mdot
.964 .29716 Mdot
.964 .2977 Mdot
.964 .2982 Mdot
.964 .29868 Mdot
.964 .2988 Mdot
.964 .29954 Mdot
.964 .29993 Mdot
.964 .29994 Mdot
.964 .30032 Mdot
.964 .30041 Mdot
.964 .30048 Mdot
.964 .30301 Mdot
.964 .30369 Mdot
.964 .30434 Mdot
.964 .30474 Mdot
.964 .30494 Mdot
.964 .30768 Mdot
.964 .30843 Mdot
.964 .30876 Mdot
.964 .30925 Mdot
.964 .30939 Mdot
.964 .30952 Mdot
.964 .30979 Mdot
.964 .31016 Mdot
.964 .31032 Mdot
.964 .31044 Mdot
.964 .31095 Mdot
.964 .31109 Mdot
.964 .31147 Mdot
.964 .31303 Mdot
.964 .31331 Mdot
.964 .31447 Mdot
.964 .31456 Mdot
.964 .31499 Mdot
.964 .3158 Mdot
.964 .31674 Mdot
.964 .31695 Mdot
.964 .31696 Mdot
.964 .31777 Mdot
.964 .31818 Mdot
.964 .31826 Mdot
.964 .31837 Mdot
.964 .31896 Mdot
.964 .31954 Mdot
.964 .32009 Mdot
.964 .32091 Mdot
.964 .32189 Mdot
.964 .32228 Mdot
.964 .32388 Mdot
.964 .32391 Mdot
.964 .32411 Mdot
.964 .32429 Mdot
.964 .32431 Mdot
.964 .32624 Mdot
.964 .32649 Mdot
.964 .32662 Mdot
.964 .32672 Mdot
.964 .32874 Mdot
.964 .32913 Mdot
.964 .32993 Mdot
.964 .3304 Mdot
.964 .33136 Mdot
.964 .33173 Mdot
.964 .33187 Mdot
.964 .33227 Mdot
.964 .33358 Mdot
.964 .33409 Mdot
.964 .33478 Mdot
.964 .33504 Mdot
.964 .33507 Mdot
.964 .33527 Mdot
.964 .33598 Mdot
.964 .33623 Mdot
.964 .33647 Mdot
.964 .33661 Mdot
.964 .3373 Mdot
.964 .33791 Mdot
.964 .33846 Mdot
.964 .3388 Mdot
.964 .33945 Mdot
.964 .33986 Mdot
.964 .34032 Mdot
.964 .34074 Mdot
.964 .3411 Mdot
.964 .34214 Mdot
.964 .34268 Mdot
.964 .3429 Mdot
.964 .34383 Mdot
.964 .3454 Mdot
.964 .34552 Mdot
.964 .34631 Mdot
.964 .34839 Mdot
.964 .35019 Mdot
.964 .35089 Mdot
.964 .35127 Mdot
.964 .35157 Mdot
.964 .35162 Mdot
.964 .35206 Mdot
.964 .35257 Mdot
.964 .35277 Mdot
.964 .35354 Mdot
.964 .35359 Mdot
.964 .35393 Mdot
.964 .35529 Mdot
.964 .35562 Mdot
.964 .35571 Mdot
.964 .35594 Mdot
.964 .35655 Mdot
.964 .35695 Mdot
.964 .35754 Mdot
.964 .35809 Mdot
.964 .35841 Mdot
.964 .35885 Mdot
.964 .35925 Mdot
.964 .36087 Mdot
.964 .36111 Mdot
.964 .36195 Mdot
.964 .36237 Mdot
.964 .36362 Mdot
.964 .36487 Mdot
.964 .36577 Mdot
.964 .3662 Mdot
.964 .36651 Mdot
.964 .36673 Mdot
.964 .3674 Mdot
.964 .36742 Mdot
.964 .36779 Mdot
.964 .36817 Mdot
.964 .36978 Mdot
.964 .37031 Mdot
.964 .37166 Mdot
.964 .37305 Mdot
.964 .37359 Mdot
.964 .37362 Mdot
.964 .37405 Mdot
.964 .37461 Mdot
.964 .37477 Mdot
.964 .37482 Mdot
.964 .375 Mdot
.964 .37547 Mdot
.964 .37642 Mdot
.964 .37659 Mdot
.964 .37671 Mdot
.964 .3769 Mdot
.964 .37711 Mdot
.964 .37718 Mdot
.964 .3782 Mdot
.964 .37834 Mdot
.964 .37853 Mdot
.964 .38004 Mdot
.964 .38039 Mdot
.964 .38067 Mdot
.964 .38149 Mdot
.964 .38153 Mdot
.964 .38205 Mdot
.964 .38343 Mdot
.964 .38418 Mdot
.964 .38488 Mdot
.964 .38518 Mdot
.964 .38526 Mdot
.964 .38606 Mdot
.964 .38629 Mdot
.964 .38638 Mdot
.964 .38652 Mdot
.964 .38679 Mdot
.964 .38682 Mdot
.964 .38702 Mdot
.964 .38723 Mdot
.964 .38725 Mdot
.964 .38963 Mdot
.964 .38967 Mdot
.964 .39065 Mdot
.964 .39106 Mdot
.964 .3914 Mdot
.964 .39165 Mdot
.964 .39225 Mdot
.964 .3924 Mdot
.964 .39303 Mdot
.964 .39358 Mdot
.964 .39368 Mdot
.964 .39488 Mdot
.964 .39498 Mdot
.964 .39568 Mdot
.964 .39618 Mdot
.964 .39658 Mdot
.964 .39863 Mdot
.964 .39936 Mdot
.964 .40134 Mdot
.964 .40213 Mdot
.964 .40219 Mdot
.964 .40262 Mdot
.964 .40495 Mdot
.964 .40509 Mdot
.964 .40606 Mdot
.964 .40679 Mdot
.964 .40695 Mdot
.964 .40721 Mdot
.964 .40727 Mdot
.964 .40775 Mdot
.964 .40778 Mdot
.964 .40822 Mdot
.964 .40827 Mdot
.964 .40922 Mdot
.964 .41036 Mdot
.964 .41038 Mdot
.964 .4105 Mdot
.964 .41062 Mdot
.964 .41153 Mdot
.964 .41164 Mdot
.964 .41173 Mdot
.964 .4127 Mdot
.964 .41288 Mdot
.964 .41387 Mdot
.964 .41462 Mdot
.964 .41464 Mdot
.964 .41568 Mdot
.964 .41613 Mdot
.964 .41614 Mdot
.964 .41627 Mdot
.964 .41653 Mdot
.964 .4169 Mdot
.964 .41778 Mdot
.964 .41839 Mdot
.964 .41842 Mdot
.964 .41973 Mdot
.964 .42112 Mdot
.964 .42119 Mdot
.964 .42188 Mdot
.964 .42326 Mdot
.964 .42342 Mdot
.964 .42379 Mdot
.964 .42406 Mdot
.964 .42407 Mdot
.964 .42551 Mdot
.964 .42608 Mdot
.964 .42629 Mdot
.964 .42654 Mdot
.964 .427 Mdot
.964 .4274 Mdot
.964 .4275 Mdot
.964 .42816 Mdot
.964 .42874 Mdot
.964 .42912 Mdot
.964 .42982 Mdot
.964 .43184 Mdot
.964 .43228 Mdot
.964 .43399 Mdot
.964 .43425 Mdot
.964 .43477 Mdot
.964 .43486 Mdot
.964 .43573 Mdot
.964 .43621 Mdot
.964 .43685 Mdot
.964 .43723 Mdot
.964 .43727 Mdot
.964 .43892 Mdot
.964 .44028 Mdot
.964 .44163 Mdot
.964 .44254 Mdot
.964 .44262 Mdot
.964 .44351 Mdot
.964 .44407 Mdot
.964 .44472 Mdot
.964 .44515 Mdot
.964 .44515 Mdot
.964 .4455 Mdot
.964 .44645 Mdot
.964 .44702 Mdot
.964 .44786 Mdot
.964 .44814 Mdot
.964 .44869 Mdot
.964 .44951 Mdot
.964 .44964 Mdot
.964 .45 Mdot
.964 .45049 Mdot
.964 .45245 Mdot
.964 .45289 Mdot
.964 .4533 Mdot
.964 .45374 Mdot
.964 .45377 Mdot
.964 .45463 Mdot
.964 .45476 Mdot
.964 .45605 Mdot
.964 .45636 Mdot
.964 .45675 Mdot
.964 .45743 Mdot
.964 .45833 Mdot
.964 .45862 Mdot
.964 .46028 Mdot
.964 .46082 Mdot
.964 .46274 Mdot
.964 .46291 Mdot
.964 .46372 Mdot
.964 .46378 Mdot
.964 .46405 Mdot
.964 .46412 Mdot
.964 .46587 Mdot
.964 .46614 Mdot
.964 .46758 Mdot
.964 .4678 Mdot
.964 .46783 Mdot
.964 .46879 Mdot
.964 .46992 Mdot
.964 .47087 Mdot
.964 .47198 Mdot
.964 .47211 Mdot
.964 .47217 Mdot
.964 .47389 Mdot
.964 .47413 Mdot
.964 .4749 Mdot
.964 .4751 Mdot
.964 .47605 Mdot
.964 .4764 Mdot
.964 .47666 Mdot
.964 .47703 Mdot
.964 .47716 Mdot
.964 .47735 Mdot
.964 .47771 Mdot
.964 .47803 Mdot
.964 .47831 Mdot
.964 .47904 Mdot
.964 .47928 Mdot
.964 .48061 Mdot
.964 .4811 Mdot
.964 .48238 Mdot
.964 .4844 Mdot
.964 .48476 Mdot
.964 .48537 Mdot
.964 .48613 Mdot
.964 .48616 Mdot
.964 .48634 Mdot
.964 .48791 Mdot
.964 .4885 Mdot
.964 .4891 Mdot
.964 .48994 Mdot
.964 .49006 Mdot
.964 .49072 Mdot
.964 .49136 Mdot
.964 .49248 Mdot
.964 .49286 Mdot
.964 .49332 Mdot
.964 .49334 Mdot
.964 .49353 Mdot
.964 .49456 Mdot
.964 .49653 Mdot
.964 .49751 Mdot
.964 .49836 Mdot
.964 .4984 Mdot
.964 .50006 Mdot
.964 .50021 Mdot
.964 .50063 Mdot
.964 .50065 Mdot
.964 .50164 Mdot
.964 .50255 Mdot
.964 .503 Mdot
.964 .50338 Mdot
.964 .5035 Mdot
.964 .50485 Mdot
.964 .50488 Mdot
.964 .5059 Mdot
.964 .50621 Mdot
.964 .50629 Mdot
.964 .50662 Mdot
.964 .5069 Mdot
.964 .50846 Mdot
.964 .50952 Mdot
.964 .51093 Mdot
.964 .51159 Mdot
.964 .5128 Mdot
.964 .51376 Mdot
.964 .51384 Mdot
.964 .514 Mdot
.964 .51561 Mdot
.964 .51562 Mdot
.964 .51627 Mdot
.964 .51632 Mdot
.964 .51682 Mdot
.964 .51692 Mdot
.964 .51836 Mdot
.964 .5188 Mdot
.964 .52046 Mdot
.964 .52122 Mdot
.964 .52257 Mdot
.964 .52271 Mdot
.964 .52346 Mdot
.964 .52424 Mdot
.964 .52449 Mdot
.964 .5257 Mdot
.964 .52675 Mdot
.964 .52827 Mdot
.964 .52877 Mdot
.964 .53183 Mdot
.964 .53229 Mdot
.964 .53365 Mdot
.964 .53365 Mdot
.964 .53506 Mdot
.964 .53549 Mdot
.964 .53642 Mdot
.964 .53767 Mdot
.964 .53811 Mdot
.964 .53946 Mdot
.964 .53967 Mdot
.964 .54002 Mdot
.964 .54049 Mdot
.964 .5415 Mdot
.964 .54277 Mdot
.964 .54286 Mdot
.964 .54345 Mdot
.964 .54349 Mdot
.964 .5444 Mdot
.964 .54591 Mdot
.964 .54756 Mdot
.964 .54763 Mdot
.964 .54767 Mdot
.964 .54856 Mdot
.964 .55025 Mdot
.964 .5507 Mdot
.964 .55085 Mdot
.964 .55123 Mdot
.964 .55135 Mdot
.964 .55451 Mdot
.964 .55613 Mdot
.964 .55695 Mdot
.964 .55729 Mdot
.964 .55864 Mdot
.964 .55874 Mdot
.964 .55928 Mdot
.964 .5603 Mdot
.964 .56127 Mdot
.964 .56221 Mdot
.964 .56243 Mdot
.964 .56385 Mdot
.964 .56462 Mdot
.964 .56463 Mdot
.964 .56536 Mdot
.964 .56553 Mdot
.964 .56568 Mdot
.964 .57054 Mdot
.964 .57185 Mdot
.964 .57311 Mdot
.964 .57388 Mdot
.964 .57427 Mdot
.964 .57955 Mdot
.964 .58099 Mdot
.964 .58164 Mdot
.964 .58257 Mdot
.964 .58286 Mdot
.964 .5831 Mdot
.964 .58362 Mdot
.964 .58433 Mdot
.964 .58464 Mdot
.966 .01479 Mdot
.966 .01485 Mdot
.966 .01499 Mdot
.966 .01524 Mdot
.966 .01559 Mdot
.966 .01565 Mdot
.966 .01572 Mdot
.966 .0164 Mdot
.966 .01652 Mdot
.966 .01666 Mdot
.966 .01741 Mdot
.966 .01797 Mdot
.966 .0182 Mdot
.966 .01848 Mdot
.966 .01884 Mdot
.966 .01991 Mdot
.966 .021 Mdot
.966 .02144 Mdot
.966 .02199 Mdot
.966 .022 Mdot
.966 .02208 Mdot
.966 .02269 Mdot
.966 .02346 Mdot
.966 .02476 Mdot
.966 .02633 Mdot
.966 .02686 Mdot
.966 .02771 Mdot
.966 .02848 Mdot
.966 .02855 Mdot
.966 .02876 Mdot
.966 .0288 Mdot
.966 .02883 Mdot
.966 .02894 Mdot
.966 .02997 Mdot
.966 .03012 Mdot
.966 .03162 Mdot
.966 .03177 Mdot
.966 .03247 Mdot
.966 .03412 Mdot
.966 .03423 Mdot
.966 .03526 Mdot
.966 .03678 Mdot
.966 .03715 Mdot
.966 .0373 Mdot
.966 .03771 Mdot
.966 .03781 Mdot
.966 .03786 Mdot
.966 .03818 Mdot
.966 .0385 Mdot
.966 .03913 Mdot
.966 .0395 Mdot
.966 .03982 Mdot
.966 .04131 Mdot
.966 .04136 Mdot
.966 .04145 Mdot
.966 .04185 Mdot
.966 .04192 Mdot
.966 .04199 Mdot
.966 .0422 Mdot
.966 .04297 Mdot
.966 .04419 Mdot
.966 .04448 Mdot
.966 .045 Mdot
.966 .04737 Mdot
.966 .0474 Mdot
.966 .04766 Mdot
.966 .04839 Mdot
.966 .04902 Mdot
.966 .05015 Mdot
.966 .05143 Mdot
.966 .05161 Mdot
.966 .05162 Mdot
.966 .05207 Mdot
.966 .0522 Mdot
.966 .05242 Mdot
.966 .05244 Mdot
.966 .05263 Mdot
.966 .05287 Mdot
.966 .05441 Mdot
.966 .05468 Mdot
.966 .05567 Mdot
.966 .05601 Mdot
.966 .05734 Mdot
.966 .05806 Mdot
.966 .05826 Mdot
.966 .05835 Mdot
.966 .05842 Mdot
.966 .05868 Mdot
.966 .05913 Mdot
.966 .05934 Mdot
.966 .05943 Mdot
.966 .06006 Mdot
.966 .06067 Mdot
.966 .06189 Mdot
.966 .06233 Mdot
.966 .06237 Mdot
.966 .06259 Mdot
.966 .06322 Mdot
.966 .06408 Mdot
.966 .06523 Mdot
.966 .06609 Mdot
.966 .0662 Mdot
.966 .06637 Mdot
.966 .06647 Mdot
.966 .06714 Mdot
.966 .06728 Mdot
.966 .06741 Mdot
.966 .06782 Mdot
.966 .06929 Mdot
.966 .0697 Mdot
.966 .07 Mdot
.966 .07008 Mdot
.966 .07166 Mdot
.966 .07201 Mdot
.966 .07223 Mdot
.966 .07294 Mdot
.966 .07323 Mdot
.966 .07371 Mdot
.966 .07521 Mdot
.966 .07581 Mdot
.966 .0778 Mdot
.966 .07786 Mdot
.966 .07836 Mdot
.966 .07977 Mdot
.966 .08091 Mdot
.966 .081 Mdot
.966 .08189 Mdot
.966 .08277 Mdot
.966 .08317 Mdot
.966 .0836 Mdot
.966 .08363 Mdot
.966 .08379 Mdot
.966 .0845 Mdot
.966 .08503 Mdot
.966 .08525 Mdot
.966 .08566 Mdot
.966 .08599 Mdot
.966 .08602 Mdot
.966 .08604 Mdot
.966 .08689 Mdot
.966 .08689 Mdot
.966 .08714 Mdot
.966 .08755 Mdot
.966 .0876 Mdot
.966 .08766 Mdot
.966 .08798 Mdot
.966 .08835 Mdot
.966 .08844 Mdot
.966 .08869 Mdot
.966 .09094 Mdot
.966 .0914 Mdot
.966 .09192 Mdot
.966 .09384 Mdot
.966 .0945 Mdot
.966 .09664 Mdot
.966 .09678 Mdot
.966 .09706 Mdot
.966 .09723 Mdot
.966 .09846 Mdot
.966 .0986 Mdot
.966 .09884 Mdot
.966 .09902 Mdot
.966 .09916 Mdot
.966 .09961 Mdot
.966 .09966 Mdot
.966 .10053 Mdot
.966 .10054 Mdot
.966 .10078 Mdot
.966 .10094 Mdot
.966 .10111 Mdot
.966 .10232 Mdot
.966 .1024 Mdot
.966 .10311 Mdot
.966 .10348 Mdot
.966 .10351 Mdot
.966 .10586 Mdot
.966 .10671 Mdot
.966 .10679 Mdot
.966 .10688 Mdot
.966 .10721 Mdot
.966 .10724 Mdot
.966 .10725 Mdot
.966 .10731 Mdot
.966 .10744 Mdot
.966 .10808 Mdot
.966 .10842 Mdot
.966 .10954 Mdot
.966 .11009 Mdot
.966 .11048 Mdot
.966 .11069 Mdot
.966 .11074 Mdot
.966 .11117 Mdot
.966 .11145 Mdot
.966 .11216 Mdot
.966 .11219 Mdot
.966 .11232 Mdot
.966 .11397 Mdot
.966 .11419 Mdot
.966 .11451 Mdot
.966 .1147 Mdot
.966 .11543 Mdot
.966 .11601 Mdot
.966 .1162 Mdot
.966 .11628 Mdot
.966 .11652 Mdot
.966 .11679 Mdot
.966 .11732 Mdot
.966 .11844 Mdot
.966 .11924 Mdot
.966 .11942 Mdot
.966 .12016 Mdot
.966 .12095 Mdot
.966 .12153 Mdot
.966 .12154 Mdot
.966 .12158 Mdot
.966 .12167 Mdot
.966 .12407 Mdot
.966 .12472 Mdot
.966 .12473 Mdot
.966 .1254 Mdot
.966 .12542 Mdot
.966 .12583 Mdot
.966 .1272 Mdot
.966 .12727 Mdot
.966 .12746 Mdot
.966 .12777 Mdot
.966 .12792 Mdot
.966 .1287 Mdot
.966 .12966 Mdot
.966 .13 Mdot
.966 .13095 Mdot
.966 .13127 Mdot
.966 .13139 Mdot
.966 .13158 Mdot
.966 .13159 Mdot
.966 .13274 Mdot
.966 .13407 Mdot
.966 .13423 Mdot
.966 .13556 Mdot
.966 .13593 Mdot
.966 .13659 Mdot
.966 .13671 Mdot
.966 .13767 Mdot
.966 .13904 Mdot
.966 .13999 Mdot
.966 .1404 Mdot
.966 .14109 Mdot
.966 .1413 Mdot
.966 .1426 Mdot
.966 .14278 Mdot
.966 .14448 Mdot
.966 .14451 Mdot
.966 .14528 Mdot
.966 .14542 Mdot
.966 .14619 Mdot
.966 .14621 Mdot
.966 .14639 Mdot
.966 .14663 Mdot
.966 .14697 Mdot
.966 .1473 Mdot
.966 .14774 Mdot
.966 .14779 Mdot
.966 .14785 Mdot
.966 .14787 Mdot
.966 .14809 Mdot
.966 .14816 Mdot
.966 .14953 Mdot
.966 .14954 Mdot
.966 .15056 Mdot
.966 .15069 Mdot
.966 .15098 Mdot
.966 .15177 Mdot
.966 .15242 Mdot
.966 .15242 Mdot
.966 .15248 Mdot
.966 .15252 Mdot
.966 .15412 Mdot
.966 .15415 Mdot
.966 .15416 Mdot
.966 .15464 Mdot
.966 .15544 Mdot
.966 .15553 Mdot
.966 .15564 Mdot
.966 .15625 Mdot
.966 .15697 Mdot
.966 .15714 Mdot
.966 .15764 Mdot
.966 .15889 Mdot
.966 .15922 Mdot
.966 .16047 Mdot
.966 .16081 Mdot
.966 .16086 Mdot
.966 .16121 Mdot
.966 .16198 Mdot
.966 .16287 Mdot
.966 .16314 Mdot
.966 .16388 Mdot
.966 .16447 Mdot
.966 .16758 Mdot
.966 .16799 Mdot
.966 .16887 Mdot
.966 .16971 Mdot
.966 .16973 Mdot
.966 .17087 Mdot
.966 .17145 Mdot
.966 .17154 Mdot
.966 .17185 Mdot
.966 .17299 Mdot
.966 .17326 Mdot
.966 .17381 Mdot
.966 .17392 Mdot
.966 .17413 Mdot
.966 .1743 Mdot
.966 .17533 Mdot
.966 .17587 Mdot
.966 .17652 Mdot
.966 .17678 Mdot
.966 .17725 Mdot
.966 .1776 Mdot
.966 .17764 Mdot
.966 .17765 Mdot
.966 .17787 Mdot
.966 .17792 Mdot
.966 .17873 Mdot
.966 .17882 Mdot
.966 .17947 Mdot
.966 .17954 Mdot
.966 .18052 Mdot
.966 .18053 Mdot
.966 .18098 Mdot
.966 .18129 Mdot
.966 .18162 Mdot
.966 .18249 Mdot
.966 .18336 Mdot
.966 .18396 Mdot
.966 .18413 Mdot
.966 .18549 Mdot
.966 .18621 Mdot
.966 .18626 Mdot
.966 .18645 Mdot
.966 .1866 Mdot
.966 .18687 Mdot
.966 .1871 Mdot
.966 .18758 Mdot
.966 .19023 Mdot
.966 .19082 Mdot
.966 .19144 Mdot
.966 .19245 Mdot
.966 .1926 Mdot
.966 .19277 Mdot
.966 .19316 Mdot
.966 .19342 Mdot
.966 .19347 Mdot
.966 .19348 Mdot
.966 .1936 Mdot
.966 .19368 Mdot
.966 .19387 Mdot
.966 .19387 Mdot
.966 .19474 Mdot
.966 .19495 Mdot
.966 .1951 Mdot
.966 .19555 Mdot
.966 .19576 Mdot
.966 .19581 Mdot
.966 .19638 Mdot
.966 .19723 Mdot
.966 .19742 Mdot
.966 .19791 Mdot
.966 .19797 Mdot
.966 .19809 Mdot
.966 .19855 Mdot
.966 .19898 Mdot
.966 .19907 Mdot
.966 .19973 Mdot
.966 .19978 Mdot
.966 .20013 Mdot
.966 .20023 Mdot
.966 .20107 Mdot
.966 .20162 Mdot
.966 .20274 Mdot
.966 .20278 Mdot
.966 .20299 Mdot
.966 .20303 Mdot
.966 .2031 Mdot
.966 .20328 Mdot
.966 .20388 Mdot
.966 .20511 Mdot
.966 .20647 Mdot
.966 .2069 Mdot
.966 .20752 Mdot
.966 .20788 Mdot
.966 .20882 Mdot
.966 .20929 Mdot
.966 .20959 Mdot
.966 .21041 Mdot
.966 .21079 Mdot
.966 .21093 Mdot
.966 .21141 Mdot
.966 .21148 Mdot
.966 .2119 Mdot
.966 .21192 Mdot
.966 .21294 Mdot
.966 .21377 Mdot
.966 .21381 Mdot
.966 .21478 Mdot
.966 .21511 Mdot
.966 .2157 Mdot
.966 .21643 Mdot
.966 .21666 Mdot
.966 .21701 Mdot
.966 .21813 Mdot
.966 .21823 Mdot
.966 .21844 Mdot
.966 .21976 Mdot
.966 .21997 Mdot
.966 .22109 Mdot
.966 .2211 Mdot
.966 .22117 Mdot
.966 .22136 Mdot
.966 .22269 Mdot
.966 .22598 Mdot
.966 .22725 Mdot
.966 .22727 Mdot
.966 .22739 Mdot
.966 .22857 Mdot
.966 .2286 Mdot
.966 .22939 Mdot
.966 .23204 Mdot
.966 .23204 Mdot
.966 .23218 Mdot
.966 .23248 Mdot
.966 .23254 Mdot
.966 .23314 Mdot
.966 .23342 Mdot
.966 .23427 Mdot
.966 .23493 Mdot
.966 .23677 Mdot
.966 .23679 Mdot
.966 .23686 Mdot
.966 .23731 Mdot
.966 .23745 Mdot
.966 .23748 Mdot
.966 .2383 Mdot
.966 .23855 Mdot
.966 .23861 Mdot
.966 .23928 Mdot
.966 .23989 Mdot
.966 .24014 Mdot
.966 .24033 Mdot
.966 .2405 Mdot
.966 .24052 Mdot
.966 .24169 Mdot
.966 .24181 Mdot
.966 .24275 Mdot
.966 .24475 Mdot
.966 .24525 Mdot
.966 .24531 Mdot
.966 .24562 Mdot
.966 .24698 Mdot
.966 .24819 Mdot
.966 .24889 Mdot
.966 .24934 Mdot
.966 .25018 Mdot
.966 .25041 Mdot
.966 .25227 Mdot
.966 .25464 Mdot
.966 .25465 Mdot
.966 .25492 Mdot
.966 .25516 Mdot
.966 .25629 Mdot
.966 .25641 Mdot
.966 .25653 Mdot
.966 .25675 Mdot
.966 .25754 Mdot
.966 .25833 Mdot
.966 .25835 Mdot
.966 .25875 Mdot
.966 .25888 Mdot
.966 .25913 Mdot
.966 .25928 Mdot
.966 .2598 Mdot
.966 .25981 Mdot
.966 .26179 Mdot
.966 .26214 Mdot
.966 .26296 Mdot
.966 .26315 Mdot
.966 .26497 Mdot
.966 .26542 Mdot
.966 .26544 Mdot
.966 .26547 Mdot
.966 .26697 Mdot
.966 .26724 Mdot
.966 .26729 Mdot
.966 .26872 Mdot
.966 .26876 Mdot
.966 .2691 Mdot
.966 .26957 Mdot
.966 .27024 Mdot
.966 .27085 Mdot
.966 .27088 Mdot
.966 .27172 Mdot
.966 .27182 Mdot
.966 .27194 Mdot
.966 .27197 Mdot
.966 .27209 Mdot
.966 .27231 Mdot
.966 .27239 Mdot
.966 .2724 Mdot
.966 .27254 Mdot
.966 .27264 Mdot
.966 .27432 Mdot
.966 .27485 Mdot
.966 .27495 Mdot
.966 .27518 Mdot
.966 .2752 Mdot
.966 .27717 Mdot
.966 .27742 Mdot
.966 .27798 Mdot
.966 .27801 Mdot
.966 .27894 Mdot
.966 .27918 Mdot
.966 .27951 Mdot
.966 .28076 Mdot
.966 .28076 Mdot
.966 .28087 Mdot
.966 .28096 Mdot
.966 .28143 Mdot
.966 .28168 Mdot
.966 .282 Mdot
.966 .28249 Mdot
.966 .28266 Mdot
.966 .28396 Mdot
.966 .28404 Mdot
.966 .28411 Mdot
.966 .28413 Mdot
.966 .28488 Mdot
.966 .28504 Mdot
.966 .28559 Mdot
.966 .28624 Mdot
.966 .28632 Mdot
.966 .28659 Mdot
.966 .28676 Mdot
.966 .28698 Mdot
.966 .28804 Mdot
.966 .28817 Mdot
.966 .28925 Mdot
.966 .28956 Mdot
.966 .28989 Mdot
.966 .29066 Mdot
.966 .29084 Mdot
.966 .2911 Mdot
.966 .29321 Mdot
.966 .29326 Mdot
.966 .2939 Mdot
.966 .29462 Mdot
.966 .29632 Mdot
.966 .29697 Mdot
.966 .29706 Mdot
.966 .29774 Mdot
.966 .29786 Mdot
.966 .29844 Mdot
.966 .2991 Mdot
.966 .29923 Mdot
.966 .30038 Mdot
.966 .30096 Mdot
.966 .30147 Mdot
.966 .30164 Mdot
.966 .3021 Mdot
.966 .3029 Mdot
.966 .30324 Mdot
.966 .30396 Mdot
.966 .30405 Mdot
.966 .30417 Mdot
.966 .30532 Mdot
.966 .31006 Mdot
.966 .31043 Mdot
.966 .31085 Mdot
.966 .31088 Mdot
.966 .31179 Mdot
.966 .31253 Mdot
.966 .31417 Mdot
.966 .31421 Mdot
.966 .31492 Mdot
.966 .31641 Mdot
.966 .31752 Mdot
.966 .31756 Mdot
.966 .3177 Mdot
.966 .31829 Mdot
.966 .31922 Mdot
.966 .31959 Mdot
.966 .3205 Mdot
.966 .32103 Mdot
.966 .32182 Mdot
.966 .32209 Mdot
.966 .3223 Mdot
.966 .32235 Mdot
.966 .32238 Mdot
.966 .32271 Mdot
.966 .32304 Mdot
.966 .32322 Mdot
.966 .32419 Mdot
.966 .32502 Mdot
.966 .32607 Mdot
.966 .32731 Mdot
.966 .32783 Mdot
.966 .32874 Mdot
.966 .3294 Mdot
.966 .32949 Mdot
.966 .3295 Mdot
.966 .32973 Mdot
.966 .32992 Mdot
.966 .33002 Mdot
.966 .33015 Mdot
.966 .33108 Mdot
.966 .33159 Mdot
.966 .33177 Mdot
.966 .33293 Mdot
.966 .33302 Mdot
.966 .33315 Mdot
.966 .33504 Mdot
.966 .33506 Mdot
.966 .33595 Mdot
.966 .33654 Mdot
.966 .33718 Mdot
.966 .33886 Mdot
.966 .33901 Mdot
.966 .33905 Mdot
.966 .34005 Mdot
.966 .34053 Mdot
.966 .34093 Mdot
.966 .34171 Mdot
.966 .34202 Mdot
.966 .34466 Mdot
.966 .34517 Mdot
.966 .34562 Mdot
.966 .34605 Mdot
.966 .34606 Mdot
.966 .34615 Mdot
.966 .34651 Mdot
.966 .34679 Mdot
.966 .3469 Mdot
.966 .34732 Mdot
.966 .34776 Mdot
.966 .34815 Mdot
.966 .34851 Mdot
.966 .34869 Mdot
.966 .34985 Mdot
.966 .3528 Mdot
.966 .35287 Mdot
.966 .35311 Mdot
.966 .35381 Mdot
.966 .35434 Mdot
.966 .35482 Mdot
.966 .35494 Mdot
.966 .35578 Mdot
.966 .35615 Mdot
.966 .35634 Mdot
.966 .3581 Mdot
.966 .35829 Mdot
.966 .35829 Mdot
.966 .35832 Mdot
.966 .35839 Mdot
.966 .35872 Mdot
.966 .35948 Mdot
.966 .35996 Mdot
.966 .36007 Mdot
.966 .3601 Mdot
.966 .36032 Mdot
.966 .36047 Mdot
.966 .36084 Mdot
.966 .36085 Mdot
.966 .36252 Mdot
.966 .36293 Mdot
.966 .36323 Mdot
.966 .36408 Mdot
.966 .3645 Mdot
.966 .36459 Mdot
.966 .36569 Mdot
.966 .36571 Mdot
.966 .367 Mdot
.966 .36734 Mdot
.966 .3677 Mdot
.966 .36866 Mdot
.966 .36875 Mdot
.966 .36899 Mdot
.966 .36989 Mdot
.966 .37007 Mdot
.966 .37056 Mdot
.966 .37072 Mdot
.966 .37079 Mdot
.966 .37089 Mdot
.966 .37217 Mdot
.966 .37226 Mdot
.966 .37295 Mdot
.966 .37313 Mdot
.966 .37475 Mdot
.966 .37524 Mdot
.966 .37581 Mdot
.966 .37592 Mdot
.966 .37756 Mdot
.966 .37798 Mdot
.966 .37805 Mdot
.966 .37846 Mdot
.966 .37855 Mdot
.966 .37867 Mdot
.966 .37902 Mdot
.966 .37925 Mdot
.966 .37932 Mdot
.966 .37943 Mdot
.966 .38018 Mdot
.966 .38078 Mdot
.966 .38167 Mdot
.966 .38255 Mdot
.966 .38502 Mdot
.966 .38519 Mdot
.966 .38584 Mdot
.966 .38601 Mdot
.966 .38604 Mdot
.966 .38622 Mdot
.966 .38722 Mdot
.966 .38791 Mdot
.966 .38973 Mdot
.966 .39062 Mdot
.966 .39063 Mdot
.966 .39122 Mdot
.966 .39152 Mdot
.966 .39157 Mdot
.966 .39173 Mdot
.966 .3928 Mdot
.966 .393 Mdot
.966 .39353 Mdot
.966 .39381 Mdot
.966 .39473 Mdot
.966 .39473 Mdot
.966 .39487 Mdot
.966 .39567 Mdot
.966 .39571 Mdot
.966 .39724 Mdot
.966 .39769 Mdot
.966 .39929 Mdot
.966 .39936 Mdot
.966 .3995 Mdot
.966 .39962 Mdot
.966 .39987 Mdot
.966 .40124 Mdot
.966 .40187 Mdot
.966 .40276 Mdot
.966 .40303 Mdot
.966 .40313 Mdot
.966 .40358 Mdot
.966 .40368 Mdot
.966 .40399 Mdot
.966 .40413 Mdot
.966 .40442 Mdot
.966 .40487 Mdot
.966 .40496 Mdot
.966 .40525 Mdot
.966 .40531 Mdot
.966 .40555 Mdot
.966 .40582 Mdot
.966 .40618 Mdot
.966 .40772 Mdot
.966 .40774 Mdot
.966 .4079 Mdot
.966 .40831 Mdot
.966 .40894 Mdot
.966 .41087 Mdot
.966 .41127 Mdot
.966 .41224 Mdot
.966 .41246 Mdot
.966 .41343 Mdot
.966 .41345 Mdot
.966 .41359 Mdot
.966 .41395 Mdot
.966 .41443 Mdot
.966 .4148 Mdot
.966 .41568 Mdot
.966 .41573 Mdot
.966 .41653 Mdot
.966 .41805 Mdot
.966 .42048 Mdot
.966 .42288 Mdot
.966 .42311 Mdot
.966 .42404 Mdot
.966 .42533 Mdot
.966 .42538 Mdot
.966 .42561 Mdot
.966 .4257 Mdot
.966 .42612 Mdot
.966 .42625 Mdot
.966 .42628 Mdot
.966 .42717 Mdot
.966 .42788 Mdot
.966 .42794 Mdot
.966 .42946 Mdot
.966 .42972 Mdot
.966 .43062 Mdot
.966 .43184 Mdot
.966 .43458 Mdot
.966 .43459 Mdot
.966 .43485 Mdot
.966 .43543 Mdot
.966 .4355 Mdot
.966 .43556 Mdot
.966 .43649 Mdot
.966 .4365 Mdot
.966 .43671 Mdot
.966 .43691 Mdot
.966 .43725 Mdot
.966 .43725 Mdot
.966 .43889 Mdot
.966 .43899 Mdot
.966 .43993 Mdot
.966 .44017 Mdot
.966 .44113 Mdot
.966 .44297 Mdot
.966 .44361 Mdot
.966 .44373 Mdot
.966 .44377 Mdot
.966 .4439 Mdot
.966 .44477 Mdot
.966 .44504 Mdot
.966 .44509 Mdot
.966 .44668 Mdot
.966 .44716 Mdot
.966 .44728 Mdot
.966 .44844 Mdot
.966 .44858 Mdot
.966 .44874 Mdot
.966 .449 Mdot
.966 .44909 Mdot
.966 .44976 Mdot
.966 .45023 Mdot
.966 .4506 Mdot
.966 .45094 Mdot
.966 .45098 Mdot
.966 .45187 Mdot
.966 .4525 Mdot
.966 .45322 Mdot
.966 .45345 Mdot
.966 .45455 Mdot
.966 .45528 Mdot
.966 .45695 Mdot
.966 .45725 Mdot
.966 .45826 Mdot
.966 .45891 Mdot
.966 .45915 Mdot
.966 .45974 Mdot
.966 .46011 Mdot
.966 .46022 Mdot
.966 .46081 Mdot
.966 .46346 Mdot
.966 .46369 Mdot
.966 .46416 Mdot
.966 .46578 Mdot
.966 .46715 Mdot
.966 .46801 Mdot
.966 .4682 Mdot
.966 .46935 Mdot
.966 .46963 Mdot
.966 .46964 Mdot
.966 .47008 Mdot
.966 .47058 Mdot
.966 .47345 Mdot
.966 .47366 Mdot
.966 .47415 Mdot
.966 .47511 Mdot
.966 .47825 Mdot
.966 .47827 Mdot
.966 .47879 Mdot
.966 .47925 Mdot
.966 .48144 Mdot
.966 .48167 Mdot
.966 .4819 Mdot
.966 .48234 Mdot
.966 .48298 Mdot
.966 .48317 Mdot
.966 .48386 Mdot
.966 .48539 Mdot
.966 .48543 Mdot
.966 .48555 Mdot
.966 .48618 Mdot
.966 .48643 Mdot
.966 .48693 Mdot
.966 .48722 Mdot
.966 .48823 Mdot
.966 .48823 Mdot
.966 .48825 Mdot
.966 .49207 Mdot
.966 .49274 Mdot
.966 .49433 Mdot
.966 .49458 Mdot
.966 .4947 Mdot
.966 .497 Mdot
.966 .49735 Mdot
.966 .49821 Mdot
.966 .49908 Mdot
.966 .49911 Mdot
.966 .49917 Mdot
.966 .49987 Mdot
.966 .50033 Mdot
.966 .50207 Mdot
.966 .50249 Mdot
.966 .50259 Mdot
.966 .50269 Mdot
.966 .50497 Mdot
.966 .50543 Mdot
.966 .50546 Mdot
.966 .50554 Mdot
.966 .50619 Mdot
.966 .50709 Mdot
.966 .50839 Mdot
.966 .50956 Mdot
.966 .50962 Mdot
.966 .50975 Mdot
.966 .51125 Mdot
.966 .51144 Mdot
.966 .51167 Mdot
.966 .51173 Mdot
.966 .51189 Mdot
.966 .51196 Mdot
.966 .51239 Mdot
.966 .51253 Mdot
.966 .51257 Mdot
.966 .51283 Mdot
.966 .51302 Mdot
.966 .51382 Mdot
.966 .51445 Mdot
.966 .51616 Mdot
.966 .51627 Mdot
.966 .51729 Mdot
.966 .51748 Mdot
.966 .51794 Mdot
.966 .51796 Mdot
.966 .51916 Mdot
.966 .52042 Mdot
.966 .52178 Mdot
.966 .52226 Mdot
.966 .52312 Mdot
.966 .52334 Mdot
.966 .52341 Mdot
.966 .52342 Mdot
.966 .52388 Mdot
.966 .5252 Mdot
.966 .52567 Mdot
.966 .5263 Mdot
.966 .52819 Mdot
.966 .52871 Mdot
.966 .52871 Mdot
.966 .52892 Mdot
.966 .5291 Mdot
.966 .53 Mdot
.966 .53049 Mdot
.966 .53111 Mdot
.966 .53206 Mdot
.966 .53239 Mdot
.966 .53489 Mdot
.966 .53505 Mdot
.966 .53518 Mdot
.966 .53523 Mdot
.966 .53667 Mdot
.966 .53699 Mdot
.966 .53805 Mdot
.966 .5393 Mdot
.966 .53945 Mdot
.966 .53997 Mdot
.966 .54031 Mdot
.966 .54074 Mdot
.966 .54278 Mdot
.966 .54303 Mdot
.966 .54512 Mdot
.966 .54571 Mdot
.966 .54586 Mdot
.966 .54635 Mdot
.966 .54784 Mdot
.966 .5482 Mdot
.966 .54869 Mdot
.966 .55277 Mdot
.966 .55287 Mdot
.966 .5541 Mdot
.966 .55549 Mdot
.966 .55877 Mdot
.966 .56003 Mdot
.966 .56021 Mdot
.966 .56151 Mdot
.966 .56175 Mdot
.966 .56287 Mdot
.966 .56415 Mdot
.966 .56439 Mdot
.966 .56663 Mdot
.966 .56773 Mdot
.966 .56873 Mdot
.966 .56906 Mdot
.966 .56994 Mdot
.966 .5715 Mdot
.966 .57215 Mdot
.966 .57355 Mdot
.966 .5737 Mdot
.966 .57394 Mdot
.966 .57617 Mdot
.966 .58532 Mdot
.968 .01543 Mdot
.968 .0161 Mdot
.968 .01668 Mdot
.968 .01668 Mdot
.968 .01741 Mdot
.968 .01852 Mdot
.968 .01853 Mdot
.968 .01869 Mdot
.968 .0192 Mdot
.968 .01992 Mdot
.968 .02165 Mdot
.968 .02208 Mdot
.968 .02209 Mdot
.968 .02242 Mdot
.968 .02281 Mdot
.968 .02341 Mdot
.968 .0248 Mdot
.968 .02814 Mdot
.968 .02853 Mdot
.968 .02898 Mdot
.968 .029 Mdot
.968 .02962 Mdot
.968 .02997 Mdot
.968 .03035 Mdot
.968 .03038 Mdot
.968 .03039 Mdot
.968 .03084 Mdot
.968 .0311 Mdot
.968 .03154 Mdot
.968 .03173 Mdot
.968 .03421 Mdot
.968 .03424 Mdot
.968 .03591 Mdot
.968 .03695 Mdot
.968 .03725 Mdot
.968 .03905 Mdot
.968 .03951 Mdot
.968 .03955 Mdot
.968 .04043 Mdot
.968 .04071 Mdot
.968 .04146 Mdot
.968 .0417 Mdot
.968 .04233 Mdot
.968 .04235 Mdot
.968 .04237 Mdot
.968 .04262 Mdot
.968 .04358 Mdot
.968 .04425 Mdot
.968 .04498 Mdot
.968 .04498 Mdot
.968 .04504 Mdot
.968 .04506 Mdot
.968 .04517 Mdot
.968 .04593 Mdot
.968 .04616 Mdot
.968 .04643 Mdot
.968 .04711 Mdot
.968 .04729 Mdot
.968 .04736 Mdot
.968 .04766 Mdot
.968 .0488 Mdot
.968 .04947 Mdot
.968 .05078 Mdot
.968 .05246 Mdot
.968 .05251 Mdot
.968 .05314 Mdot
.968 .05338 Mdot
.968 .05528 Mdot
.968 .05535 Mdot
.968 .05575 Mdot
.968 .05645 Mdot
.968 .05777 Mdot
.968 .05835 Mdot
.968 .05907 Mdot
.968 .06183 Mdot
.968 .06272 Mdot
.968 .06279 Mdot
.968 .06436 Mdot
.968 .06449 Mdot
.968 .06504 Mdot
.968 .0653 Mdot
.968 .06535 Mdot
.968 .06542 Mdot
.968 .06565 Mdot
.968 .06612 Mdot
.968 .06619 Mdot
.968 .06642 Mdot
.968 .06649 Mdot
.968 .06695 Mdot
.968 .06736 Mdot
.968 .06818 Mdot
.968 .06821 Mdot
.968 .06825 Mdot
.968 .06855 Mdot
.968 .06874 Mdot
.968 .06885 Mdot
.968 .06911 Mdot
.968 .07024 Mdot
.968 .07042 Mdot
.968 .07059 Mdot
.968 .07159 Mdot
.968 .07189 Mdot
.968 .0729 Mdot
.968 .0733 Mdot
.968 .07331 Mdot
.968 .07342 Mdot
.968 .07345 Mdot
.968 .07367 Mdot
.968 .07466 Mdot
.968 .07514 Mdot
.968 .0756 Mdot
.968 .07611 Mdot
.968 .07742 Mdot
.968 .07762 Mdot
.968 .07776 Mdot
.968 .07779 Mdot
.968 .07792 Mdot
.968 .0785 Mdot
.968 .07883 Mdot
.968 .07893 Mdot
.968 .07949 Mdot
.968 .08047 Mdot
.968 .0807 Mdot
.968 .082 Mdot
.968 .08237 Mdot
.968 .08243 Mdot
.968 .08343 Mdot
.968 .08454 Mdot
.968 .08778 Mdot
.968 .08789 Mdot
.968 .08844 Mdot
.968 .0891 Mdot
.968 .08958 Mdot
.968 .09019 Mdot
.968 .09164 Mdot
.968 .09325 Mdot
.968 .09338 Mdot
.968 .09415 Mdot
.968 .09551 Mdot
.968 .09583 Mdot
.968 .09586 Mdot
.968 .09741 Mdot
.968 .09807 Mdot
.968 .09919 Mdot
.968 .09935 Mdot
.968 .09972 Mdot
.968 .10057 Mdot
.968 .10058 Mdot
.968 .10059 Mdot
.968 .10086 Mdot
.968 .10186 Mdot
.968 .10293 Mdot
.968 .10294 Mdot
.968 .1042 Mdot
.968 .10527 Mdot
.968 .10594 Mdot
.968 .10765 Mdot
.968 .10779 Mdot
.968 .10781 Mdot
.968 .10842 Mdot
.968 .1097 Mdot
.968 .11083 Mdot
.968 .11108 Mdot
.968 .11159 Mdot
.968 .11192 Mdot
.968 .11215 Mdot
.968 .11265 Mdot
.968 .11275 Mdot
.968 .11288 Mdot
.968 .11332 Mdot
.968 .11346 Mdot
.968 .11419 Mdot
.968 .11423 Mdot
.968 .11437 Mdot
.968 .11482 Mdot
.968 .11495 Mdot
.968 .11528 Mdot
.968 .11555 Mdot
.968 .11577 Mdot
.968 .11585 Mdot
.968 .11663 Mdot
.968 .11665 Mdot
.968 .11769 Mdot
.968 .11781 Mdot
.968 .1181 Mdot
.968 .11822 Mdot
.968 .11828 Mdot
.968 .11837 Mdot
.968 .11893 Mdot
.968 .11931 Mdot
.968 .11951 Mdot
.968 .12002 Mdot
.968 .12203 Mdot
.968 .12222 Mdot
.968 .12222 Mdot
.968 .12247 Mdot
.968 .12256 Mdot
.968 .1229 Mdot
.968 .12483 Mdot
.968 .1254 Mdot
.968 .12582 Mdot
.968 .12736 Mdot
.968 .12814 Mdot
.968 .12816 Mdot
.968 .12837 Mdot
.968 .12843 Mdot
.968 .12852 Mdot
.968 .12886 Mdot
.968 .13024 Mdot
.968 .13076 Mdot
.968 .13115 Mdot
.968 .13154 Mdot
.968 .1317 Mdot
.968 .1325 Mdot
.968 .13259 Mdot
.968 .13358 Mdot
.968 .13612 Mdot
.968 .13651 Mdot
.968 .13678 Mdot
.968 .13683 Mdot
.968 .13709 Mdot
.968 .13801 Mdot
.968 .1382 Mdot
.968 .1383 Mdot
.968 .13884 Mdot
.968 .13903 Mdot
.968 .13972 Mdot
.968 .14013 Mdot
.968 .1404 Mdot
.968 .14111 Mdot
.968 .14151 Mdot
.968 .14153 Mdot
.968 .14202 Mdot
.968 .14245 Mdot
.968 .14497 Mdot
.968 .14526 Mdot
.968 .14569 Mdot
.968 .14582 Mdot
.968 .14699 Mdot
.968 .14761 Mdot
.968 .14775 Mdot
.968 .14776 Mdot
.968 .14804 Mdot
.968 .14931 Mdot
.968 .14989 Mdot
.968 .15169 Mdot
.968 .15251 Mdot
.968 .15293 Mdot
.968 .15331 Mdot
.968 .15359 Mdot
.968 .15362 Mdot
.968 .15371 Mdot
.968 .15388 Mdot
.968 .15458 Mdot
.968 .15618 Mdot
.968 .15639 Mdot
.968 .15745 Mdot
.968 .15776 Mdot
.968 .15873 Mdot
.968 .15883 Mdot
.968 .15965 Mdot
.968 .1608 Mdot
.968 .16084 Mdot
.968 .16163 Mdot
.968 .16269 Mdot
.968 .16288 Mdot
.968 .16317 Mdot
.968 .16364 Mdot
.968 .16395 Mdot
.968 .1641 Mdot
.968 .16436 Mdot
.968 .16446 Mdot
.968 .16461 Mdot
.968 .16505 Mdot
.968 .16539 Mdot
.968 .16676 Mdot
.968 .16701 Mdot
.968 .16797 Mdot
.968 .16797 Mdot
.968 .1685 Mdot
.968 .16864 Mdot
.968 .1696 Mdot
.968 .17113 Mdot
.968 .17161 Mdot
.968 .17174 Mdot
.968 .17181 Mdot
.968 .17198 Mdot
.968 .17264 Mdot
.968 .17394 Mdot
.968 .17406 Mdot
.968 .17482 Mdot
.968 .17557 Mdot
.968 .17583 Mdot
.968 .17608 Mdot
.968 .17615 Mdot
.968 .17827 Mdot
.968 .17858 Mdot
.968 .17928 Mdot
.968 .18094 Mdot
.968 .18095 Mdot
.968 .18097 Mdot
.968 .18124 Mdot
.968 .18149 Mdot
.968 .18181 Mdot
.968 .18196 Mdot
.968 .18344 Mdot
.968 .18423 Mdot
.968 .18473 Mdot
.968 .18549 Mdot
.968 .18551 Mdot
.968 .18578 Mdot
.968 .18711 Mdot
.968 .18797 Mdot
.968 .18908 Mdot
.968 .18951 Mdot
.968 .19002 Mdot
.968 .19035 Mdot
.968 .19043 Mdot
.968 .19098 Mdot
.968 .19132 Mdot
.968 .19228 Mdot
.968 .19244 Mdot
.968 .19338 Mdot
.968 .19379 Mdot
.968 .19398 Mdot
.968 .1944 Mdot
.968 .19464 Mdot
.968 .19492 Mdot
.968 .19495 Mdot
.968 .19613 Mdot
.968 .19851 Mdot
.968 .19861 Mdot
.968 .2008 Mdot
.968 .20098 Mdot
.968 .20117 Mdot
.968 .20127 Mdot
.968 .20128 Mdot
.968 .20227 Mdot
.968 .20273 Mdot
.968 .2029 Mdot
.968 .20294 Mdot
.968 .20301 Mdot
.968 .20335 Mdot
.968 .20432 Mdot
.968 .2045 Mdot
.968 .20457 Mdot
.968 .20476 Mdot
.968 .20561 Mdot
.968 .20589 Mdot
.968 .20642 Mdot
.968 .20705 Mdot
.968 .2073 Mdot
.968 .20737 Mdot
.968 .20764 Mdot
.968 .20851 Mdot
.968 .20877 Mdot
.968 .2093 Mdot
.968 .2094 Mdot
.968 .20992 Mdot
.968 .21036 Mdot
.968 .21052 Mdot
.968 .21202 Mdot
.968 .21206 Mdot
.968 .21308 Mdot
.968 .21344 Mdot
.968 .21396 Mdot
.968 .21408 Mdot
.968 .2143 Mdot
.968 .21486 Mdot
.968 .21511 Mdot
.968 .21522 Mdot
.968 .21527 Mdot
.968 .21538 Mdot
.968 .21648 Mdot
.968 .21719 Mdot
.968 .21722 Mdot
.968 .21761 Mdot
.968 .2181 Mdot
.968 .21859 Mdot
.968 .22046 Mdot
.968 .2206 Mdot
.968 .22095 Mdot
.968 .22146 Mdot
.968 .22234 Mdot
.968 .22237 Mdot
.968 .22247 Mdot
.968 .2226 Mdot
.968 .22284 Mdot
.968 .22285 Mdot
.968 .22332 Mdot
.968 .2235 Mdot
.968 .22415 Mdot
.968 .22415 Mdot
.968 .22483 Mdot
.968 .2249 Mdot
.968 .22604 Mdot
.968 .22727 Mdot
.968 .22727 Mdot
.968 .22755 Mdot
.968 .2279 Mdot
.968 .229 Mdot
.968 .2298 Mdot
.968 .22981 Mdot
.968 .23007 Mdot
.968 .2328 Mdot
.968 .23304 Mdot
.968 .2343 Mdot
.968 .23433 Mdot
.968 .23434 Mdot
.968 .23475 Mdot
.968 .23487 Mdot
.968 .23505 Mdot
.968 .2357 Mdot
.968 .23838 Mdot
.968 .23874 Mdot
.968 .23896 Mdot
.968 .23896 Mdot
.968 .23897 Mdot
.968 .23939 Mdot
.968 .24 Mdot
.968 .24012 Mdot
.968 .24088 Mdot
.968 .24119 Mdot
.968 .24133 Mdot
.968 .24275 Mdot
.968 .24292 Mdot
.968 .24483 Mdot
.968 .24544 Mdot
.968 .24729 Mdot
.968 .24843 Mdot
.968 .24849 Mdot
.968 .24944 Mdot
.968 .24975 Mdot
.968 .2505 Mdot
.968 .25103 Mdot
.968 .25112 Mdot
.968 .2513 Mdot
.968 .25163 Mdot
.968 .25317 Mdot
.968 .25335 Mdot
.968 .25341 Mdot
.968 .25379 Mdot
.968 .25398 Mdot
.968 .25435 Mdot
.968 .25502 Mdot
.968 .25539 Mdot
.968 .25673 Mdot
.968 .25751 Mdot
.968 .25805 Mdot
.968 .25834 Mdot
.968 .25849 Mdot
.968 .25942 Mdot
.968 .25968 Mdot
.968 .26019 Mdot
.968 .26023 Mdot
.968 .26058 Mdot
.968 .26112 Mdot
.968 .26118 Mdot
.968 .26202 Mdot
.968 .26332 Mdot
.968 .26336 Mdot
.968 .26521 Mdot
.968 .26532 Mdot
.968 .26543 Mdot
.968 .26547 Mdot
.968 .2669 Mdot
.968 .26699 Mdot
.968 .26705 Mdot
.968 .26745 Mdot
.968 .26745 Mdot
.968 .2681 Mdot
.968 .26829 Mdot
.968 .26854 Mdot
.968 .26976 Mdot
.968 .27055 Mdot
.968 .2708 Mdot
.968 .272 Mdot
.968 .27227 Mdot
.968 .27228 Mdot
.968 .27284 Mdot
.968 .27315 Mdot
.968 .2753 Mdot
.968 .27566 Mdot
.968 .27642 Mdot
.968 .2772 Mdot
.968 .27919 Mdot
.968 .27922 Mdot
.968 .27936 Mdot
.968 .27991 Mdot
.968 .2806 Mdot
.968 .28111 Mdot
.968 .28148 Mdot
.968 .28195 Mdot
.968 .28229 Mdot
.968 .28278 Mdot
.968 .28278 Mdot
.968 .2828 Mdot
.968 .28304 Mdot
.968 .28357 Mdot
.968 .28363 Mdot
.968 .28381 Mdot
.968 .28408 Mdot
.968 .28414 Mdot
.968 .28437 Mdot
.968 .28496 Mdot
.968 .28534 Mdot
.968 .2855 Mdot
.968 .28651 Mdot
.968 .28666 Mdot
.968 .28668 Mdot
.968 .28713 Mdot
.968 .28859 Mdot
.968 .28866 Mdot
.968 .289 Mdot
.968 .28907 Mdot
.968 .28997 Mdot
.968 .29074 Mdot
.968 .29104 Mdot
.968 .29113 Mdot
.968 .29164 Mdot
.968 .29165 Mdot
.968 .29353 Mdot
.968 .29371 Mdot
.968 .29499 Mdot
.968 .2953 Mdot
.968 .29546 Mdot
.968 .29697 Mdot
.968 .29754 Mdot
.968 .29761 Mdot
.968 .29763 Mdot
.968 .29774 Mdot
.968 .29893 Mdot
.968 .29915 Mdot
.968 .29963 Mdot
.968 .3012 Mdot
.968 .30156 Mdot
.968 .30188 Mdot
.968 .30212 Mdot
.968 .30304 Mdot
.968 .30363 Mdot
.968 .30392 Mdot
.968 .30443 Mdot
.968 .30462 Mdot
.968 .30478 Mdot
.968 .30491 Mdot
.968 .30576 Mdot
.968 .30625 Mdot
.968 .30643 Mdot
.968 .30706 Mdot
.968 .30736 Mdot
.968 .30752 Mdot
.968 .30907 Mdot
.968 .30955 Mdot
.968 .31077 Mdot
.968 .31141 Mdot
.968 .31141 Mdot
.968 .31245 Mdot
.968 .31272 Mdot
.968 .31398 Mdot
.968 .31458 Mdot
.968 .31753 Mdot
.968 .31828 Mdot
.968 .31847 Mdot
.968 .31849 Mdot
.968 .31872 Mdot
.968 .31886 Mdot
.968 .31919 Mdot
.968 .32047 Mdot
.968 .32134 Mdot
.968 .32188 Mdot
.968 .32204 Mdot
.968 .32297 Mdot
.968 .3232 Mdot
.968 .32322 Mdot
.968 .32368 Mdot
.968 .32433 Mdot
.968 .32467 Mdot
.968 .32481 Mdot
.968 .32603 Mdot
.968 .32613 Mdot
.968 .32664 Mdot
.968 .32713 Mdot
.968 .32726 Mdot
.968 .328 Mdot
.968 .32835 Mdot
.968 .32903 Mdot
.968 .33024 Mdot
.968 .33037 Mdot
.968 .33135 Mdot
.968 .33138 Mdot
.968 .33195 Mdot
.968 .33331 Mdot
.968 .33604 Mdot
.968 .33653 Mdot
.968 .33655 Mdot
.968 .33659 Mdot
.968 .3367 Mdot
.968 .33695 Mdot
.968 .33698 Mdot
.968 .3371 Mdot
.968 .33759 Mdot
.968 .3382 Mdot
.968 .33836 Mdot
.968 .33849 Mdot
.968 .33908 Mdot
.968 .33917 Mdot
.968 .33978 Mdot
.968 .34045 Mdot
.968 .34136 Mdot
.968 .34289 Mdot
.968 .34296 Mdot
.968 .34351 Mdot
.968 .34356 Mdot
.968 .34386 Mdot
.968 .34436 Mdot
.968 .34534 Mdot
.968 .34538 Mdot
.968 .34589 Mdot
.968 .34848 Mdot
.968 .34938 Mdot
.968 .35013 Mdot
.968 .35229 Mdot
.968 .35231 Mdot
.968 .35311 Mdot
.968 .35411 Mdot
.968 .3543 Mdot
.968 .35475 Mdot
.968 .35475 Mdot
.968 .35489 Mdot
.968 .35541 Mdot
.968 .35596 Mdot
.968 .35596 Mdot
.968 .35662 Mdot
.968 .35717 Mdot
.968 .35848 Mdot
.968 .35854 Mdot
.968 .3588 Mdot
.968 .35946 Mdot
.968 .36044 Mdot
.968 .3606 Mdot
.968 .3614 Mdot
.968 .36178 Mdot
.968 .36234 Mdot
.968 .36248 Mdot
.968 .36259 Mdot
.968 .36305 Mdot
.968 .36359 Mdot
.968 .36365 Mdot
.968 .3638 Mdot
.968 .36582 Mdot
.968 .36593 Mdot
.968 .36605 Mdot
.968 .36779 Mdot
.968 .36918 Mdot
.968 .37007 Mdot
.968 .37054 Mdot
.968 .37074 Mdot
.968 .37124 Mdot
.968 .37408 Mdot
.968 .37423 Mdot
.968 .37497 Mdot
.968 .37532 Mdot
.968 .37568 Mdot
.968 .37589 Mdot
.968 .3759 Mdot
.968 .37783 Mdot
.968 .37872 Mdot
.968 .37904 Mdot
.968 .37912 Mdot
.968 .37926 Mdot
.968 .37992 Mdot
.968 .38115 Mdot
.968 .38157 Mdot
.968 .38179 Mdot
.968 .38199 Mdot
.968 .38213 Mdot
.968 .38214 Mdot
.968 .38219 Mdot
.968 .38228 Mdot
.968 .38264 Mdot
.968 .38428 Mdot
.968 .38483 Mdot
.968 .38585 Mdot
.968 .38628 Mdot
.968 .38683 Mdot
.968 .38693 Mdot
.968 .38708 Mdot
.968 .38748 Mdot
.968 .38756 Mdot
.968 .38769 Mdot
.968 .38774 Mdot
.968 .38782 Mdot
.968 .38805 Mdot
.968 .38823 Mdot
.968 .38956 Mdot
.968 .38956 Mdot
.968 .3899 Mdot
.968 .3904 Mdot
.968 .39144 Mdot
.968 .39163 Mdot
.968 .39197 Mdot
.968 .39264 Mdot
.968 .3927 Mdot
.968 .39348 Mdot
.968 .39362 Mdot
.968 .39378 Mdot
.968 .39641 Mdot
.968 .3967 Mdot
.968 .39678 Mdot
.968 .39795 Mdot
.968 .39821 Mdot
.968 .39875 Mdot
.968 .39944 Mdot
.968 .40046 Mdot
.968 .40068 Mdot
.968 .40112 Mdot
.968 .40116 Mdot
.968 .40144 Mdot
.968 .40211 Mdot
.968 .4022 Mdot
.968 .40268 Mdot
.968 .40289 Mdot
.968 .40299 Mdot
.968 .40321 Mdot
.968 .40533 Mdot
.968 .40661 Mdot
.968 .4067 Mdot
.968 .40676 Mdot
.968 .40751 Mdot
.968 .40762 Mdot
.968 .40766 Mdot
.968 .40846 Mdot
.968 .40942 Mdot
.968 .40974 Mdot
.968 .41091 Mdot
.968 .41286 Mdot
.968 .41304 Mdot
.968 .41331 Mdot
.968 .41399 Mdot
.968 .41498 Mdot
.968 .41545 Mdot
.968 .41667 Mdot
.968 .41674 Mdot
.968 .41692 Mdot
.968 .41719 Mdot
.968 .41764 Mdot
.968 .41766 Mdot
.968 .41778 Mdot
.968 .41858 Mdot
.968 .41893 Mdot
.968 .41896 Mdot
.968 .41955 Mdot
.968 .42019 Mdot
.968 .42019 Mdot
.968 .42033 Mdot
.968 .42149 Mdot
.968 .42163 Mdot
.968 .42317 Mdot
.968 .42384 Mdot
.968 .42611 Mdot
.968 .42623 Mdot
.968 .42623 Mdot
.968 .42623 Mdot
.968 .42676 Mdot
.968 .42745 Mdot
.968 .42957 Mdot
.968 .43053 Mdot
.968 .43112 Mdot
.968 .43115 Mdot
.968 .43164 Mdot
.968 .4326 Mdot
.968 .43357 Mdot
.968 .43366 Mdot
.968 .43417 Mdot
.968 .43624 Mdot
.968 .43631 Mdot
.968 .43693 Mdot
.968 .43739 Mdot
.968 .43767 Mdot
.968 .43881 Mdot
.968 .43883 Mdot
.968 .43978 Mdot
.968 .43984 Mdot
.968 .4399 Mdot
.968 .43992 Mdot
.968 .4407 Mdot
.968 .44073 Mdot
.968 .44094 Mdot
.968 .44127 Mdot
.968 .44213 Mdot
.968 .44254 Mdot
.968 .44388 Mdot
.968 .44518 Mdot
.968 .44598 Mdot
.968 .44701 Mdot
.968 .44702 Mdot
.968 .44709 Mdot
.968 .44773 Mdot
.968 .44799 Mdot
.968 .44843 Mdot
.968 .44886 Mdot
.968 .44886 Mdot
.968 .44887 Mdot
.968 .44953 Mdot
.968 .44968 Mdot
.968 .44998 Mdot
.968 .45018 Mdot
.968 .45079 Mdot
.968 .45086 Mdot
.968 .45088 Mdot
.968 .45111 Mdot
.968 .4519 Mdot
.968 .45211 Mdot
.968 .45257 Mdot
.968 .45297 Mdot
.968 .45317 Mdot
.968 .45344 Mdot
.968 .45517 Mdot
.968 .45541 Mdot
.968 .45619 Mdot
.968 .45653 Mdot
.968 .45659 Mdot
.968 .4572 Mdot
.968 .45756 Mdot
.968 .45872 Mdot
.968 .46022 Mdot
.968 .46098 Mdot
.968 .4614 Mdot
.968 .46156 Mdot
.968 .46164 Mdot
.968 .46332 Mdot
.968 .46497 Mdot
.968 .46719 Mdot
.968 .46731 Mdot
.968 .46878 Mdot
.968 .46906 Mdot
.968 .46914 Mdot
.968 .46975 Mdot
.968 .46998 Mdot
.968 .47032 Mdot
.968 .47057 Mdot
.968 .4712 Mdot
.968 .47222 Mdot
.968 .4724 Mdot
.968 .47275 Mdot
.968 .47338 Mdot
.968 .47344 Mdot
.968 .47396 Mdot
.968 .47637 Mdot
.968 .47671 Mdot
.968 .47684 Mdot
.968 .47686 Mdot
.968 .47757 Mdot
.968 .47794 Mdot
.968 .47799 Mdot
.968 .4783 Mdot
.968 .47865 Mdot
.968 .47995 Mdot
.968 .48023 Mdot
.968 .48026 Mdot
.968 .48067 Mdot
.968 .48326 Mdot
.968 .48477 Mdot
.968 .4858 Mdot
.968 .48603 Mdot
.968 .48638 Mdot
.968 .48666 Mdot
.968 .48728 Mdot
.968 .48799 Mdot
.968 .48847 Mdot
.968 .48897 Mdot
.968 .48995 Mdot
.968 .49003 Mdot
.968 .49071 Mdot
.968 .49175 Mdot
.968 .49187 Mdot
.968 .49277 Mdot
.968 .49349 Mdot
.968 .49395 Mdot
.968 .49455 Mdot
.968 .49602 Mdot
.968 .4961 Mdot
.968 .49967 Mdot
.968 .49989 Mdot
.968 .5001 Mdot
.968 .50018 Mdot
.968 .50021 Mdot
.968 .50232 Mdot
.968 .5026 Mdot
.968 .50265 Mdot
.968 .50294 Mdot
.968 .50308 Mdot
.968 .50312 Mdot
.968 .50323 Mdot
.968 .50401 Mdot
.968 .50401 Mdot
.968 .50526 Mdot
.968 .50564 Mdot
.968 .50611 Mdot
.968 .50755 Mdot
.968 .50835 Mdot
.968 .50848 Mdot
.968 .51 Mdot
.968 .51015 Mdot
.968 .5105 Mdot
.968 .51282 Mdot
.968 .51334 Mdot
.968 .51336 Mdot
.968 .51444 Mdot
.968 .51504 Mdot
.968 .51605 Mdot
.968 .51739 Mdot
.968 .51859 Mdot
.968 .5192 Mdot
.968 .51951 Mdot
.968 .51991 Mdot
.968 .52137 Mdot
.968 .52289 Mdot
.968 .52295 Mdot
.968 .52517 Mdot
.968 .52625 Mdot
.968 .52675 Mdot
.968 .52679 Mdot
.968 .52706 Mdot
.968 .52812 Mdot
.968 .52816 Mdot
.968 .52887 Mdot
.968 .52945 Mdot
.968 .52946 Mdot
.968 .52996 Mdot
.968 .53045 Mdot
.968 .53117 Mdot
.968 .53207 Mdot
.968 .53275 Mdot
.968 .53316 Mdot
.968 .53369 Mdot
.968 .53369 Mdot
.968 .53373 Mdot
.968 .5342 Mdot
.968 .53499 Mdot
.968 .53522 Mdot
.968 .53533 Mdot
.968 .53564 Mdot
.968 .53568 Mdot
.968 .53621 Mdot
.968 .53632 Mdot
.968 .53677 Mdot
.968 .5379 Mdot
.968 .53803 Mdot
.968 .53864 Mdot
.968 .53895 Mdot
.968 .53914 Mdot
.968 .53974 Mdot
.968 .54091 Mdot
.968 .5412 Mdot
.968 .54125 Mdot
.968 .54211 Mdot
.968 .54493 Mdot
.968 .54508 Mdot
.968 .54556 Mdot
.968 .54573 Mdot
.968 .54586 Mdot
.968 .54734 Mdot
.968 .54761 Mdot
.968 .54911 Mdot
.968 .54969 Mdot
.968 .54985 Mdot
.968 .55085 Mdot
.968 .55086 Mdot
.968 .55449 Mdot
.968 .55486 Mdot
.968 .55732 Mdot
.968 .55793 Mdot
.968 .55824 Mdot
.968 .56117 Mdot
.968 .56226 Mdot
.968 .56241 Mdot
.968 .56243 Mdot
.968 .56265 Mdot
.968 .56496 Mdot
.968 .56537 Mdot
.968 .5663 Mdot
.968 .56935 Mdot
.968 .57004 Mdot
.968 .57066 Mdot
.968 .57113 Mdot
.968 .57292 Mdot
.968 .57406 Mdot
.968 .57462 Mdot
.968 .57561 Mdot
.968 .57597 Mdot
.968 .57627 Mdot
.968 .57653 Mdot
.968 .57819 Mdot
.968 .57913 Mdot
.968 .57947 Mdot
.968 .5807 Mdot
.968 .58128 Mdot
.968 .58159 Mdot
.968 .58459 Mdot
.968 .58551 Mdot
.97 .01602 Mdot
.97 .01707 Mdot
.97 .01721 Mdot
.97 .01725 Mdot
.97 .01753 Mdot
.97 .01876 Mdot
.97 .01883 Mdot
.97 .01928 Mdot
.97 .01956 Mdot
.97 .01964 Mdot
.97 .02017 Mdot
.97 .0211 Mdot
.97 .02205 Mdot
.97 .02255 Mdot
.97 .0227 Mdot
.97 .02357 Mdot
.97 .02411 Mdot
.97 .02415 Mdot
.97 .02426 Mdot
.97 .02436 Mdot
.97 .02529 Mdot
.97 .02667 Mdot
.97 .02668 Mdot
.97 .02707 Mdot
.97 .02711 Mdot
.97 .02732 Mdot
.97 .02893 Mdot
.97 .02894 Mdot
.97 .02992 Mdot
.97 .02999 Mdot
.97 .03021 Mdot
.97 .0304 Mdot
.97 .03042 Mdot
.97 .03046 Mdot
.97 .03146 Mdot
.97 .0319 Mdot
.97 .03221 Mdot
.97 .03295 Mdot
.97 .03301 Mdot
.97 .03324 Mdot
.97 .03342 Mdot
.97 .03512 Mdot
.97 .03523 Mdot
.97 .0365 Mdot
.97 .03738 Mdot
.97 .03791 Mdot
.97 .03794 Mdot
.97 .03869 Mdot
.97 .03876 Mdot
.97 .03917 Mdot
.97 .03984 Mdot
.97 .04145 Mdot
.97 .04189 Mdot
.97 .04229 Mdot
.97 .04232 Mdot
.97 .0437 Mdot
.97 .0442 Mdot
.97 .04422 Mdot
.97 .04435 Mdot
.97 .04477 Mdot
.97 .0448 Mdot
.97 .04515 Mdot
.97 .04519 Mdot
.97 .04527 Mdot
.97 .04567 Mdot
.97 .04658 Mdot
.97 .04685 Mdot
.97 .0472 Mdot
.97 .04763 Mdot
.97 .04806 Mdot
.97 .04865 Mdot
.97 .05008 Mdot
.97 .05021 Mdot
.97 .05065 Mdot
.97 .051 Mdot
.97 .05129 Mdot
.97 .0518 Mdot
.97 .05201 Mdot
.97 .05373 Mdot
.97 .05429 Mdot
.97 .05452 Mdot
.97 .0553 Mdot
.97 .05699 Mdot
.97 .05713 Mdot
.97 .05726 Mdot
.97 .05868 Mdot
.97 .05957 Mdot
.97 .05971 Mdot
.97 .05976 Mdot
.97 .05999 Mdot
.97 .06013 Mdot
.97 .06031 Mdot
.97 .06092 Mdot
.97 .06122 Mdot
.97 .06136 Mdot
.97 .06183 Mdot
.97 .06215 Mdot
.97 .06255 Mdot
.97 .06263 Mdot
.97 .06275 Mdot
.97 .06346 Mdot
.97 .06381 Mdot
.97 .06477 Mdot
.97 .06564 Mdot
.97 .06627 Mdot
.97 .06659 Mdot
.97 .06744 Mdot
.97 .06821 Mdot
.97 .06827 Mdot
.97 .07036 Mdot
.97 .07094 Mdot
.97 .07191 Mdot
.97 .07195 Mdot
.97 .07221 Mdot
.97 .07224 Mdot
.97 .07303 Mdot
.97 .07307 Mdot
.97 .07314 Mdot
.97 .07331 Mdot
.97 .07332 Mdot
.97 .07376 Mdot
.97 .07383 Mdot
.97 .07399 Mdot
.97 .07477 Mdot
.97 .07598 Mdot
.97 .07607 Mdot
.97 .07643 Mdot
.97 .07652 Mdot
.97 .07654 Mdot
.97 .07654 Mdot
.97 .07706 Mdot
.97 .07718 Mdot
.97 .07744 Mdot
.97 .07773 Mdot
.97 .07837 Mdot
.97 .07857 Mdot
.97 .07917 Mdot
.97 .07925 Mdot
.97 .07939 Mdot
.97 .08054 Mdot
.97 .08243 Mdot
.97 .0825 Mdot
.97 .08303 Mdot
.97 .08333 Mdot
.97 .08357 Mdot
.97 .08366 Mdot
.97 .08407 Mdot
.97 .08434 Mdot
.97 .08442 Mdot
.97 .08512 Mdot
.97 .08567 Mdot
.97 .08653 Mdot
.97 .08665 Mdot
.97 .08692 Mdot
.97 .08707 Mdot
.97 .089 Mdot
.97 .0903 Mdot
.97 .0904 Mdot
.97 .09073 Mdot
.97 .0915 Mdot
.97 .09194 Mdot
.97 .09196 Mdot
.97 .09293 Mdot
.97 .09299 Mdot
.97 .09346 Mdot
.97 .09415 Mdot
.97 .09557 Mdot
.97 .09567 Mdot
.97 .09672 Mdot
.97 .097 Mdot
.97 .09725 Mdot
.97 .09732 Mdot
.97 .09768 Mdot
.97 .09829 Mdot
.97 .09909 Mdot
.97 .09952 Mdot
.97 .09961 Mdot
.97 .09986 Mdot
.97 .1 Mdot
.97 .10013 Mdot
.97 .10025 Mdot
.97 .10168 Mdot
.97 .10173 Mdot
.97 .10174 Mdot
.97 .10183 Mdot
.97 .102 Mdot
.97 .10211 Mdot
.97 .10255 Mdot
.97 .10256 Mdot
.97 .10281 Mdot
.97 .10317 Mdot
.97 .10369 Mdot
.97 .104 Mdot
.97 .10435 Mdot
.97 .10491 Mdot
.97 .10494 Mdot
.97 .1052 Mdot
.97 .10521 Mdot
.97 .10546 Mdot
.97 .10563 Mdot
.97 .10612 Mdot
.97 .10674 Mdot
.97 .10752 Mdot
.97 .10766 Mdot
.97 .1079 Mdot
.97 .10845 Mdot
.97 .10929 Mdot
.97 .10996 Mdot
.97 .11085 Mdot
.97 .11182 Mdot
.97 .11303 Mdot
.97 .11351 Mdot
.97 .11467 Mdot
.97 .11472 Mdot
.97 .11535 Mdot
.97 .117 Mdot
.97 .11849 Mdot
.97 .1186 Mdot
.97 .11871 Mdot
.97 .11899 Mdot
.97 .11972 Mdot
.97 .12145 Mdot
.97 .12267 Mdot
.97 .12325 Mdot
.97 .1238 Mdot
.97 .12418 Mdot
.97 .12534 Mdot
.97 .12551 Mdot
.97 .12567 Mdot
.97 .12575 Mdot
.97 .12626 Mdot
.97 .12631 Mdot
.97 .12743 Mdot
.97 .12785 Mdot
.97 .12793 Mdot
.97 .12806 Mdot
.97 .12838 Mdot
.97 .1284 Mdot
.97 .12927 Mdot
.97 .12929 Mdot
.97 .1294 Mdot
.97 .12971 Mdot
.97 .13123 Mdot
.97 .1316 Mdot
.97 .13226 Mdot
.97 .13253 Mdot
.97 .13292 Mdot
.97 .13358 Mdot
.97 .13374 Mdot
.97 .13397 Mdot
.97 .13429 Mdot
.97 .13444 Mdot
.97 .13462 Mdot
.97 .13465 Mdot
.97 .13466 Mdot
.97 .13566 Mdot
.97 .1359 Mdot
.97 .13641 Mdot
.97 .13653 Mdot
.97 .13697 Mdot
.97 .13698 Mdot
.97 .1371 Mdot
.97 .13715 Mdot
.97 .1382 Mdot
.97 .1386 Mdot
.97 .13867 Mdot
.97 .13961 Mdot
.97 .13976 Mdot
.97 .13981 Mdot
.97 .13991 Mdot
.97 .14016 Mdot
.97 .14019 Mdot
.97 .14056 Mdot
.97 .14158 Mdot
.97 .14173 Mdot
.97 .14212 Mdot
.97 .14242 Mdot
.97 .14277 Mdot
.97 .143 Mdot
.97 .14543 Mdot
.97 .14609 Mdot
.97 .14621 Mdot
.97 .14725 Mdot
.97 .14761 Mdot
.97 .14783 Mdot
.97 .1483 Mdot
.97 .14847 Mdot
.97 .14908 Mdot
.97 .14926 Mdot
.97 .14979 Mdot
.97 .14994 Mdot
.97 .15007 Mdot
.97 .15129 Mdot
.97 .15236 Mdot
.97 .15404 Mdot
.97 .15428 Mdot
.97 .15441 Mdot
.97 .1548 Mdot
.97 .1548 Mdot
.97 .15509 Mdot
.97 .15882 Mdot
.97 .15893 Mdot
.97 .15927 Mdot
.97 .16135 Mdot
.97 .16155 Mdot
.97 .16218 Mdot
.97 .16241 Mdot
.97 .16367 Mdot
.97 .16452 Mdot
.97 .16457 Mdot
.97 .16645 Mdot
.97 .16656 Mdot
.97 .16748 Mdot
.97 .16775 Mdot
.97 .16779 Mdot
.97 .16883 Mdot
.97 .1709 Mdot
.97 .17119 Mdot
.97 .1713 Mdot
.97 .17158 Mdot
.97 .17178 Mdot
.97 .1738 Mdot
.97 .17435 Mdot
.97 .17483 Mdot
.97 .17496 Mdot
.97 .17535 Mdot
.97 .17567 Mdot
.97 .17587 Mdot
.97 .17685 Mdot
.97 .1784 Mdot
.97 .17843 Mdot
.97 .17924 Mdot
.97 .1794 Mdot
.97 .17986 Mdot
.97 .17989 Mdot
.97 .18017 Mdot
.97 .18043 Mdot
.97 .18066 Mdot
.97 .18241 Mdot
.97 .18343 Mdot
.97 .18353 Mdot
.97 .18355 Mdot
.97 .18356 Mdot
.97 .18373 Mdot
.97 .18404 Mdot
.97 .18425 Mdot
.97 .18512 Mdot
.97 .18514 Mdot
.97 .18563 Mdot
.97 .18631 Mdot
.97 .18732 Mdot
.97 .18791 Mdot
.97 .18792 Mdot
.97 .18861 Mdot
.97 .18917 Mdot
.97 .18933 Mdot
.97 .18968 Mdot
.97 .18975 Mdot
.97 .19025 Mdot
.97 .19028 Mdot
.97 .19047 Mdot
.97 .19077 Mdot
.97 .19085 Mdot
.97 .19109 Mdot
.97 .19124 Mdot
.97 .19203 Mdot
.97 .19325 Mdot
.97 .19369 Mdot
.97 .19476 Mdot
.97 .19483 Mdot
.97 .19503 Mdot
.97 .19549 Mdot
.97 .19597 Mdot
.97 .19621 Mdot
.97 .19657 Mdot
.97 .19818 Mdot
.97 .19882 Mdot
.97 .1989 Mdot
.97 .19949 Mdot
.97 .19961 Mdot
.97 .19965 Mdot
.97 .20036 Mdot
.97 .20057 Mdot
.97 .20088 Mdot
.97 .20121 Mdot
.97 .20244 Mdot
.97 .20309 Mdot
.97 .20435 Mdot
.97 .20545 Mdot
.97 .20554 Mdot
.97 .20637 Mdot
.97 .2078 Mdot
.97 .20863 Mdot
.97 .20873 Mdot
.97 .20995 Mdot
.97 .21063 Mdot
.97 .21199 Mdot
.97 .21315 Mdot
.97 .21383 Mdot
.97 .21499 Mdot
.97 .21529 Mdot
.97 .21535 Mdot
.97 .21604 Mdot
.97 .21626 Mdot
.97 .21646 Mdot
.97 .21701 Mdot
.97 .21843 Mdot
.97 .21954 Mdot
.97 .22042 Mdot
.97 .22044 Mdot
.97 .22155 Mdot
.97 .22178 Mdot
.97 .22293 Mdot
.97 .22414 Mdot
.97 .22475 Mdot
.97 .22528 Mdot
.97 .22633 Mdot
.97 .22708 Mdot
.97 .22799 Mdot
.97 .22924 Mdot
.97 .22929 Mdot
.97 .22932 Mdot
.97 .22966 Mdot
.97 .22998 Mdot
.97 .23013 Mdot
.97 .23111 Mdot
.97 .2312 Mdot
.97 .23145 Mdot
.97 .23157 Mdot
.97 .23339 Mdot
.97 .23358 Mdot
.97 .23407 Mdot
.97 .23419 Mdot
.97 .23434 Mdot
.97 .2346 Mdot
.97 .23523 Mdot
.97 .23526 Mdot
.97 .23579 Mdot
.97 .23695 Mdot
.97 .23698 Mdot
.97 .2372 Mdot
.97 .23754 Mdot
.97 .2378 Mdot
.97 .24036 Mdot
.97 .24075 Mdot
.97 .24147 Mdot
.97 .2416 Mdot
.97 .24275 Mdot
.97 .24328 Mdot
.97 .24376 Mdot
.97 .24379 Mdot
.97 .24404 Mdot
.97 .2453 Mdot
.97 .24554 Mdot
.97 .24563 Mdot
.97 .24608 Mdot
.97 .2467 Mdot
.97 .24698 Mdot
.97 .24701 Mdot
.97 .24733 Mdot
.97 .24738 Mdot
.97 .24742 Mdot
.97 .24785 Mdot
.97 .24849 Mdot
.97 .24868 Mdot
.97 .2488 Mdot
.97 .24935 Mdot
.97 .24981 Mdot
.97 .25006 Mdot
.97 .25077 Mdot
.97 .2508 Mdot
.97 .25103 Mdot
.97 .25125 Mdot
.97 .25183 Mdot
.97 .25189 Mdot
.97 .25191 Mdot
.97 .25214 Mdot
.97 .25224 Mdot
.97 .25372 Mdot
.97 .25428 Mdot
.97 .25453 Mdot
.97 .25505 Mdot
.97 .25519 Mdot
.97 .25553 Mdot
.97 .25586 Mdot
.97 .25627 Mdot
.97 .25678 Mdot
.97 .257 Mdot
.97 .25725 Mdot
.97 .25731 Mdot
.97 .25739 Mdot
.97 .2576 Mdot
.97 .25809 Mdot
.97 .25814 Mdot
.97 .25886 Mdot
.97 .26084 Mdot
.97 .26113 Mdot
.97 .26188 Mdot
.97 .26246 Mdot
.97 .26267 Mdot
.97 .26287 Mdot
.97 .26314 Mdot
.97 .26323 Mdot
.97 .26359 Mdot
.97 .26409 Mdot
.97 .26482 Mdot
.97 .26665 Mdot
.97 .26712 Mdot
.97 .26769 Mdot
.97 .26831 Mdot
.97 .26866 Mdot
.97 .26959 Mdot
.97 .26961 Mdot
.97 .26981 Mdot
.97 .2702 Mdot
.97 .27102 Mdot
.97 .27115 Mdot
.97 .27183 Mdot
.97 .27252 Mdot
.97 .27296 Mdot
.97 .27312 Mdot
.97 .27387 Mdot
.97 .27421 Mdot
.97 .27537 Mdot
.97 .27573 Mdot
.97 .27677 Mdot
.97 .27706 Mdot
.97 .2773 Mdot
.97 .27751 Mdot
.97 .27762 Mdot
.97 .27802 Mdot
.97 .27843 Mdot
.97 .27968 Mdot
.97 .27973 Mdot
.97 .28068 Mdot
.97 .28175 Mdot
.97 .2826 Mdot
.97 .2842 Mdot
.97 .28501 Mdot
.97 .28546 Mdot
.97 .28572 Mdot
.97 .28608 Mdot
.97 .28647 Mdot
.97 .28648 Mdot
.97 .28703 Mdot
.97 .2873 Mdot
.97 .29032 Mdot
.97 .2918 Mdot
.97 .29428 Mdot
.97 .29449 Mdot
.97 .29451 Mdot
.97 .29501 Mdot
.97 .29514 Mdot
.97 .29585 Mdot
.97 .29919 Mdot
.97 .29933 Mdot
.97 .29958 Mdot
.97 .30079 Mdot
.97 .30125 Mdot
.97 .30133 Mdot
.97 .3018 Mdot
.97 .30312 Mdot
.97 .30324 Mdot
.97 .30369 Mdot
.97 .30418 Mdot
.97 .3051 Mdot
.97 .30535 Mdot
.97 .30543 Mdot
.97 .30698 Mdot
.97 .30894 Mdot
.97 .30909 Mdot
.97 .30919 Mdot
.97 .30929 Mdot
.97 .30957 Mdot
.97 .30981 Mdot
.97 .31018 Mdot
.97 .31107 Mdot
.97 .31161 Mdot
.97 .31168 Mdot
.97 .31184 Mdot
.97 .31248 Mdot
.97 .31252 Mdot
.97 .31369 Mdot
.97 .31418 Mdot
.97 .31526 Mdot
.97 .31537 Mdot
.97 .31656 Mdot
.97 .31657 Mdot
.97 .31677 Mdot
.97 .31689 Mdot
.97 .31772 Mdot
.97 .31827 Mdot
.97 .31848 Mdot
.97 .31849 Mdot
.97 .31851 Mdot
.97 .31903 Mdot
.97 .31941 Mdot
.97 .32091 Mdot
.97 .32163 Mdot
.97 .32208 Mdot
.97 .32335 Mdot
.97 .32418 Mdot
.97 .32441 Mdot
.97 .32534 Mdot
.97 .32559 Mdot
.97 .3259 Mdot
.97 .32635 Mdot
.97 .32682 Mdot
.97 .32696 Mdot
.97 .32736 Mdot
.97 .32925 Mdot
.97 .32951 Mdot
.97 .32962 Mdot
.97 .33051 Mdot
.97 .33132 Mdot
.97 .33226 Mdot
.97 .33233 Mdot
.97 .33352 Mdot
.97 .33374 Mdot
.97 .3338 Mdot
.97 .3339 Mdot
.97 .33421 Mdot
.97 .33468 Mdot
.97 .33505 Mdot
.97 .33509 Mdot
.97 .33515 Mdot
.97 .3357 Mdot
.97 .3362 Mdot
.97 .33665 Mdot
.97 .33697 Mdot
.97 .33908 Mdot
.97 .34005 Mdot
.97 .34051 Mdot
.97 .3406 Mdot
.97 .3406 Mdot
.97 .34198 Mdot
.97 .34202 Mdot
.97 .34221 Mdot
.97 .34225 Mdot
.97 .34227 Mdot
.97 .34259 Mdot
.97 .34273 Mdot
.97 .34321 Mdot
.97 .34362 Mdot
.97 .34366 Mdot
.97 .3453 Mdot
.97 .34533 Mdot
.97 .34561 Mdot
.97 .34594 Mdot
.97 .34615 Mdot
.97 .34629 Mdot
.97 .34742 Mdot
.97 .34762 Mdot
.97 .34868 Mdot
.97 .34936 Mdot
.97 .34958 Mdot
.97 .35021 Mdot
.97 .35071 Mdot
.97 .35074 Mdot
.97 .35134 Mdot
.97 .35207 Mdot
.97 .35213 Mdot
.97 .35297 Mdot
.97 .35316 Mdot
.97 .35347 Mdot
.97 .35389 Mdot
.97 .35411 Mdot
.97 .35415 Mdot
.97 .35428 Mdot
.97 .35443 Mdot
.97 .35449 Mdot
.97 .35522 Mdot
.97 .35526 Mdot
.97 .3553 Mdot
.97 .35568 Mdot
.97 .35626 Mdot
.97 .35642 Mdot
.97 .35689 Mdot
.97 .35704 Mdot
.97 .35717 Mdot
.97 .35726 Mdot
.97 .35871 Mdot
.97 .35995 Mdot
.97 .36107 Mdot
.97 .36192 Mdot
.97 .364 Mdot
.97 .36415 Mdot
.97 .36452 Mdot
.97 .36542 Mdot
.97 .36634 Mdot
.97 .36682 Mdot
.97 .36742 Mdot
.97 .36751 Mdot
.97 .3685 Mdot
.97 .36945 Mdot
.97 .37065 Mdot
.97 .37099 Mdot
.97 .37113 Mdot
.97 .37133 Mdot
.97 .37187 Mdot
.97 .37203 Mdot
.97 .37319 Mdot
.97 .37342 Mdot
.97 .37348 Mdot
.97 .37351 Mdot
.97 .37429 Mdot
.97 .37477 Mdot
.97 .37488 Mdot
.97 .37506 Mdot
.97 .37527 Mdot
.97 .37579 Mdot
.97 .37587 Mdot
.97 .37607 Mdot
.97 .3764 Mdot
.97 .37652 Mdot
.97 .37778 Mdot
.97 .3789 Mdot
.97 .37965 Mdot
.97 .38017 Mdot
.97 .3824 Mdot
.97 .3826 Mdot
.97 .38473 Mdot
.97 .38491 Mdot
.97 .38653 Mdot
.97 .38928 Mdot
.97 .3893 Mdot
.97 .39091 Mdot
.97 .39105 Mdot
.97 .39111 Mdot
.97 .3932 Mdot
.97 .39347 Mdot
.97 .39479 Mdot
.97 .39552 Mdot
.97 .39684 Mdot
.97 .39743 Mdot
.97 .39967 Mdot
.97 .40032 Mdot
.97 .40041 Mdot
.97 .40099 Mdot
.97 .40119 Mdot
.97 .40265 Mdot
.97 .40324 Mdot
.97 .40383 Mdot
.97 .40395 Mdot
.97 .40529 Mdot
.97 .40534 Mdot
.97 .40571 Mdot
.97 .40572 Mdot
.97 .40609 Mdot
.97 .4062 Mdot
.97 .40636 Mdot
.97 .40716 Mdot
.97 .40815 Mdot
.97 .40876 Mdot
.97 .40992 Mdot
.97 .41138 Mdot
.97 .41208 Mdot
.97 .41303 Mdot
.97 .41363 Mdot
.97 .41378 Mdot
.97 .41382 Mdot
.97 .41598 Mdot
.97 .41643 Mdot
.97 .41644 Mdot
.97 .41701 Mdot
.97 .41773 Mdot
.97 .41866 Mdot
.97 .42033 Mdot
.97 .42098 Mdot
.97 .421 Mdot
.97 .42211 Mdot
.97 .42218 Mdot
.97 .42321 Mdot
.97 .42346 Mdot
.97 .42435 Mdot
.97 .42526 Mdot
.97 .42671 Mdot
.97 .42735 Mdot
.97 .42846 Mdot
.97 .42848 Mdot
.97 .42938 Mdot
.97 .43014 Mdot
.97 .43057 Mdot
.97 .4309 Mdot
.97 .43099 Mdot
.97 .43106 Mdot
.97 .43171 Mdot
.97 .43207 Mdot
.97 .43232 Mdot
.97 .43262 Mdot
.97 .43359 Mdot
.97 .43401 Mdot
.97 .43453 Mdot
.97 .4347 Mdot
.97 .43491 Mdot
.97 .43517 Mdot
.97 .43541 Mdot
.97 .43821 Mdot
.97 .43831 Mdot
.97 .4385 Mdot
.97 .43894 Mdot
.97 .43932 Mdot
.97 .44026 Mdot
.97 .4405 Mdot
.97 .4408 Mdot
.97 .4413 Mdot
.97 .44178 Mdot
.97 .44209 Mdot
.97 .44251 Mdot
.97 .44258 Mdot
.97 .44359 Mdot
.97 .44586 Mdot
.97 .44591 Mdot
.97 .44612 Mdot
.97 .44633 Mdot
.97 .447 Mdot
.97 .44749 Mdot
.97 .44848 Mdot
.97 .4493 Mdot
.97 .45027 Mdot
.97 .4509 Mdot
.97 .45246 Mdot
.97 .45322 Mdot
.97 .45462 Mdot
.97 .45488 Mdot
.97 .45531 Mdot
.97 .45711 Mdot
.97 .45814 Mdot
.97 .45838 Mdot
.97 .45906 Mdot
.97 .45912 Mdot
.97 .45961 Mdot
.97 .46008 Mdot
.97 .46105 Mdot
.97 .46206 Mdot
.97 .46219 Mdot
.97 .46238 Mdot
.97 .46251 Mdot
.97 .4627 Mdot
.97 .46356 Mdot
.97 .46388 Mdot
.97 .4639 Mdot
.97 .46476 Mdot
.97 .46531 Mdot
.97 .46537 Mdot
.97 .46599 Mdot
.97 .46599 Mdot
.97 .46609 Mdot
.97 .46616 Mdot
.97 .46698 Mdot
.97 .46699 Mdot
.97 .46823 Mdot
.97 .4686 Mdot
.97 .46883 Mdot
.97 .46991 Mdot
.97 .4708 Mdot
.97 .47128 Mdot
.97 .47266 Mdot
.97 .47272 Mdot
.97 .47318 Mdot
.97 .47359 Mdot
.97 .47473 Mdot
.97 .47484 Mdot
.97 .47488 Mdot
.97 .47533 Mdot
.97 .47552 Mdot
.97 .47651 Mdot
.97 .47759 Mdot
.97 .47833 Mdot
.97 .47838 Mdot
.97 .47838 Mdot
.97 .47909 Mdot
.97 .47948 Mdot
.97 .47996 Mdot
.97 .48096 Mdot
.97 .48113 Mdot
.97 .48124 Mdot
.97 .48189 Mdot
.97 .48255 Mdot
.97 .48289 Mdot
.97 .48333 Mdot
.97 .48392 Mdot
.97 .48432 Mdot
.97 .48476 Mdot
.97 .48523 Mdot
.97 .48534 Mdot
.97 .48551 Mdot
.97 .48554 Mdot
.97 .48592 Mdot
.97 .48685 Mdot
.97 .48697 Mdot
.97 .48835 Mdot
.97 .4922 Mdot
.97 .49276 Mdot
.97 .49325 Mdot
.97 .49404 Mdot
.97 .49411 Mdot
.97 .49422 Mdot
.97 .49534 Mdot
.97 .49574 Mdot
.97 .49599 Mdot
.97 .49614 Mdot
.97 .49652 Mdot
.97 .49666 Mdot
.97 .49683 Mdot
.97 .49754 Mdot
.97 .49851 Mdot
.97 .49918 Mdot
.97 .49993 Mdot
.97 .50347 Mdot
.97 .50438 Mdot
.97 .50549 Mdot
.97 .50669 Mdot
.97 .50737 Mdot
.97 .50916 Mdot
.97 .50921 Mdot
.97 .50961 Mdot
.97 .51036 Mdot
.97 .51175 Mdot
.97 .51195 Mdot
.97 .51219 Mdot
.97 .51227 Mdot
.97 .5132 Mdot
.97 .51351 Mdot
.97 .51486 Mdot
.97 .51571 Mdot
.97 .51602 Mdot
.97 .51747 Mdot
.97 .51777 Mdot
.97 .51813 Mdot
.97 .51948 Mdot
.97 .51981 Mdot
.97 .52039 Mdot
.97 .52109 Mdot
.97 .52155 Mdot
.97 .52309 Mdot
.97 .52367 Mdot
.97 .52414 Mdot
.97 .52453 Mdot
.97 .52475 Mdot
.97 .52553 Mdot
.97 .52631 Mdot
.97 .52653 Mdot
.97 .52699 Mdot
.97 .52869 Mdot
.97 .52875 Mdot
.97 .52884 Mdot
.97 .53053 Mdot
.97 .53069 Mdot
.97 .53277 Mdot
.97 .53399 Mdot
.97 .53441 Mdot
.97 .53491 Mdot
.97 .53523 Mdot
.97 .53751 Mdot
.97 .53909 Mdot
.97 .53997 Mdot
.97 .54046 Mdot
.97 .54105 Mdot
.97 .54115 Mdot
.97 .54193 Mdot
.97 .54194 Mdot
.97 .54301 Mdot
.97 .54352 Mdot
.97 .54843 Mdot
.97 .54899 Mdot
.97 .54937 Mdot
.97 .5494 Mdot
.97 .54976 Mdot
.97 .55082 Mdot
.97 .55172 Mdot
.97 .55225 Mdot
.97 .55309 Mdot
.97 .55706 Mdot
.97 .55747 Mdot
.97 .55751 Mdot
.97 .55848 Mdot
.97 .55875 Mdot
.97 .56012 Mdot
.97 .5666 Mdot
.97 .56687 Mdot
.97 .56734 Mdot
.97 .5697 Mdot
.97 .57058 Mdot
.97 .57075 Mdot
.97 .57165 Mdot
.97 .57422 Mdot
.97 .57446 Mdot
.97 .57533 Mdot
.97 .57628 Mdot
.97 .57806 Mdot
.97 .57854 Mdot
.97 .57871 Mdot
.97 .5817 Mdot
.97 .58551 Mdot
.97 .5858 Mdot
.97 .58599 Mdot
.97 .58619 Mdot
.97 .58674 Mdot
.97 .58721 Mdot
.97 .58791 Mdot
.972 .01516 Mdot
.972 .01521 Mdot
.972 .01558 Mdot
.972 .01567 Mdot
.972 .0164 Mdot
.972 .01658 Mdot
.972 .018 Mdot
.972 .01834 Mdot
.972 .01878 Mdot
.972 .01886 Mdot
.972 .01911 Mdot
.972 .01951 Mdot
.972 .01972 Mdot
.972 .01973 Mdot
.972 .02041 Mdot
.972 .0211 Mdot
.972 .02176 Mdot
.972 .02261 Mdot
.972 .02278 Mdot
.972 .02325 Mdot
.972 .02361 Mdot
.972 .02404 Mdot
.972 .02444 Mdot
.972 .02447 Mdot
.972 .02579 Mdot
.972 .02712 Mdot
.972 .02735 Mdot
.972 .0284 Mdot
.972 .03006 Mdot
.972 .03038 Mdot
.972 .03053 Mdot
.972 .03064 Mdot
.972 .03083 Mdot
.972 .03131 Mdot
.972 .032 Mdot
.972 .03284 Mdot
.972 .03332 Mdot
.972 .03363 Mdot
.972 .03369 Mdot
.972 .03466 Mdot
.972 .03532 Mdot
.972 .03544 Mdot
.972 .03616 Mdot
.972 .03619 Mdot
.972 .03624 Mdot
.972 .03643 Mdot
.972 .03711 Mdot
.972 .03744 Mdot
.972 .03754 Mdot
.972 .03804 Mdot
.972 .03883 Mdot
.972 .03925 Mdot
.972 .03927 Mdot
.972 .04132 Mdot
.972 .04268 Mdot
.972 .04269 Mdot
.972 .04415 Mdot
.972 .04454 Mdot
.972 .04518 Mdot
.972 .04545 Mdot
.972 .04566 Mdot
.972 .04604 Mdot
.972 .04688 Mdot
.972 .04698 Mdot
.972 .04826 Mdot
.972 .04832 Mdot
.972 .04995 Mdot
.972 .05055 Mdot
.972 .05088 Mdot
.972 .05148 Mdot
.972 .05159 Mdot
.972 .0535 Mdot
.972 .05477 Mdot
.972 .05479 Mdot
.972 .055 Mdot
.972 .05636 Mdot
.972 .0564 Mdot
.972 .05641 Mdot
.972 .05646 Mdot
.972 .05656 Mdot
.972 .0566 Mdot
.972 .05668 Mdot
.972 .05692 Mdot
.972 .05702 Mdot
.972 .05777 Mdot
.972 .05792 Mdot
.972 .05825 Mdot
.972 .05865 Mdot
.972 .0589 Mdot
.972 .05908 Mdot
.972 .05918 Mdot
.972 .06006 Mdot
.972 .06033 Mdot
.972 .06056 Mdot
.972 .06159 Mdot
.972 .06161 Mdot
.972 .06241 Mdot
.972 .06245 Mdot
.972 .06373 Mdot
.972 .06374 Mdot
.972 .064 Mdot
.972 .06528 Mdot
.972 .06562 Mdot
.972 .06571 Mdot
.972 .06601 Mdot
.972 .06644 Mdot
.972 .06739 Mdot
.972 .06854 Mdot
.972 .06908 Mdot
.972 .0691 Mdot
.972 .07091 Mdot
.972 .07194 Mdot
.972 .0727 Mdot
.972 .07293 Mdot
.972 .07351 Mdot
.972 .07375 Mdot
.972 .07393 Mdot
.972 .07433 Mdot
.972 .07447 Mdot
.972 .07488 Mdot
.972 .07495 Mdot
.972 .07505 Mdot
.972 .07523 Mdot
.972 .0756 Mdot
.972 .07581 Mdot
.972 .07584 Mdot
.972 .07725 Mdot
.972 .07744 Mdot
.972 .07751 Mdot
.972 .07802 Mdot
.972 .07805 Mdot
.972 .0785 Mdot
.972 .07964 Mdot
.972 .07993 Mdot
.972 .08005 Mdot
.972 .08018 Mdot
.972 .08031 Mdot
.972 .08092 Mdot
.972 .0813 Mdot
.972 .08322 Mdot
.972 .08437 Mdot
.972 .08465 Mdot
.972 .08502 Mdot
.972 .08618 Mdot
.972 .08641 Mdot
.972 .08726 Mdot
.972 .08749 Mdot
.972 .08875 Mdot
.972 .09011 Mdot
.972 .09019 Mdot
.972 .09139 Mdot
.972 .09259 Mdot
.972 .09262 Mdot
.972 .09302 Mdot
.972 .09351 Mdot
.972 .09467 Mdot
.972 .09511 Mdot
.972 .09567 Mdot
.972 .09576 Mdot
.972 .09578 Mdot
.972 .09588 Mdot
.972 .09606 Mdot
.972 .09613 Mdot
.972 .0963 Mdot
.972 .09676 Mdot
.972 .09696 Mdot
.972 .09783 Mdot
.972 .09841 Mdot
.972 .09862 Mdot
.972 .09867 Mdot
.972 .09871 Mdot
.972 .09884 Mdot
.972 .09934 Mdot
.972 .09984 Mdot
.972 .10013 Mdot
.972 .10028 Mdot
.972 .10061 Mdot
.972 .10096 Mdot
.972 .10116 Mdot
.972 .10119 Mdot
.972 .10127 Mdot
.972 .10286 Mdot
.972 .10303 Mdot
.972 .10323 Mdot
.972 .10339 Mdot
.972 .10384 Mdot
.972 .1039 Mdot
.972 .10438 Mdot
.972 .105 Mdot
.972 .10584 Mdot
.972 .10588 Mdot
.972 .10677 Mdot
.972 .10744 Mdot
.972 .1075 Mdot
.972 .10753 Mdot
.972 .10837 Mdot
.972 .10939 Mdot
.972 .10965 Mdot
.972 .11 Mdot
.972 .11001 Mdot
.972 .11053 Mdot
.972 .1106 Mdot
.972 .1107 Mdot
.972 .11226 Mdot
.972 .11236 Mdot
.972 .11273 Mdot
.972 .1128 Mdot
.972 .11302 Mdot
.972 .11367 Mdot
.972 .11384 Mdot
.972 .11444 Mdot
.972 .11526 Mdot
.972 .11618 Mdot
.972 .11712 Mdot
.972 .11934 Mdot
.972 .12041 Mdot
.972 .12044 Mdot
.972 .12113 Mdot
.972 .1216 Mdot
.972 .12182 Mdot
.972 .12278 Mdot
.972 .12397 Mdot
.972 .12401 Mdot
.972 .12493 Mdot
.972 .12597 Mdot
.972 .12743 Mdot
.972 .12788 Mdot
.972 .12795 Mdot
.972 .12902 Mdot
.972 .12938 Mdot
.972 .12949 Mdot
.972 .12983 Mdot
.972 .13042 Mdot
.972 .1306 Mdot
.972 .13088 Mdot
.972 .13168 Mdot
.972 .13182 Mdot
.972 .132 Mdot
.972 .13229 Mdot
.972 .13235 Mdot
.972 .13308 Mdot
.972 .13319 Mdot
.972 .13349 Mdot
.972 .13354 Mdot
.972 .13479 Mdot
.972 .13545 Mdot
.972 .13628 Mdot
.972 .1364 Mdot
.972 .13665 Mdot
.972 .13679 Mdot
.972 .13734 Mdot
.972 .13748 Mdot
.972 .13779 Mdot
.972 .13784 Mdot
.972 .13872 Mdot
.972 .13945 Mdot
.972 .13992 Mdot
.972 .14003 Mdot
.972 .14007 Mdot
.972 .14092 Mdot
.972 .1415 Mdot
.972 .14172 Mdot
.972 .14198 Mdot
.972 .14223 Mdot
.972 .14269 Mdot
.972 .14341 Mdot
.972 .14368 Mdot
.972 .14381 Mdot
.972 .14415 Mdot
.972 .14427 Mdot
.972 .14437 Mdot
.972 .14507 Mdot
.972 .146 Mdot
.972 .14789 Mdot
.972 .14824 Mdot
.972 .15013 Mdot
.972 .15015 Mdot
.972 .15067 Mdot
.972 .15124 Mdot
.972 .15138 Mdot
.972 .15365 Mdot
.972 .15409 Mdot
.972 .15546 Mdot
.972 .15574 Mdot
.972 .15619 Mdot
.972 .15652 Mdot
.972 .15728 Mdot
.972 .15863 Mdot
.972 .16 Mdot
.972 .1605 Mdot
.972 .16055 Mdot
.972 .16098 Mdot
.972 .16128 Mdot
.972 .16143 Mdot
.972 .16213 Mdot
.972 .16378 Mdot
.972 .16431 Mdot
.972 .16541 Mdot
.972 .1661 Mdot
.972 .16616 Mdot
.972 .16619 Mdot
.972 .16693 Mdot
.972 .16694 Mdot
.972 .16789 Mdot
.972 .16814 Mdot
.972 .16832 Mdot
.972 .17016 Mdot
.972 .171 Mdot
.972 .17108 Mdot
.972 .17209 Mdot
.972 .17227 Mdot
.972 .1723 Mdot
.972 .17249 Mdot
.972 .1725 Mdot
.972 .17256 Mdot
.972 .17274 Mdot
.972 .17285 Mdot
.972 .17299 Mdot
.972 .17331 Mdot
.972 .17422 Mdot
.972 .17422 Mdot
.972 .1746 Mdot
.972 .1763 Mdot
.972 .17742 Mdot
.972 .17783 Mdot
.972 .1779 Mdot
.972 .17792 Mdot
.972 .17801 Mdot
.972 .17825 Mdot
.972 .17858 Mdot
.972 .17922 Mdot
.972 .1802 Mdot
.972 .18075 Mdot
.972 .18106 Mdot
.972 .18169 Mdot
.972 .18222 Mdot
.972 .18237 Mdot
.972 .18259 Mdot
.972 .18275 Mdot
.972 .18283 Mdot
.972 .18298 Mdot
.972 .18343 Mdot
.972 .18369 Mdot
.972 .18399 Mdot
.972 .18417 Mdot
.972 .18532 Mdot
.972 .18607 Mdot
.972 .1864 Mdot
.972 .18678 Mdot
.972 .1871 Mdot
.972 .18797 Mdot
.972 .18809 Mdot
.972 .18903 Mdot
.972 .18907 Mdot
.972 .19024 Mdot
.972 .19117 Mdot
.972 .19138 Mdot
.972 .19187 Mdot
.972 .19193 Mdot
.972 .19221 Mdot
.972 .19366 Mdot
.972 .19497 Mdot
.972 .1951 Mdot
.972 .19515 Mdot
.972 .19541 Mdot
.972 .19574 Mdot
.972 .19678 Mdot
.972 .19743 Mdot
.972 .19793 Mdot
.972 .19876 Mdot
.972 .19926 Mdot
.972 .1993 Mdot
.972 .19994 Mdot
.972 .19997 Mdot
.972 .20097 Mdot
.972 .20112 Mdot
.972 .20131 Mdot
.972 .20215 Mdot
.972 .20294 Mdot
.972 .20434 Mdot
.972 .20454 Mdot
.972 .20526 Mdot
.972 .20539 Mdot
.972 .20582 Mdot
.972 .20709 Mdot
.972 .20741 Mdot
.972 .20746 Mdot
.972 .20857 Mdot
.972 .20858 Mdot
.972 .20999 Mdot
.972 .21017 Mdot
.972 .21114 Mdot
.972 .21124 Mdot
.972 .21196 Mdot
.972 .21295 Mdot
.972 .21351 Mdot
.972 .21378 Mdot
.972 .21463 Mdot
.972 .21509 Mdot
.972 .21641 Mdot
.972 .21662 Mdot
.972 .21811 Mdot
.972 .21942 Mdot
.972 .21971 Mdot
.972 .22019 Mdot
.972 .22024 Mdot
.972 .22106 Mdot
.972 .22159 Mdot
.972 .22172 Mdot
.972 .22221 Mdot
.972 .2225 Mdot
.972 .22292 Mdot
.972 .22366 Mdot
.972 .22405 Mdot
.972 .22442 Mdot
.972 .2248 Mdot
.972 .22516 Mdot
.972 .22675 Mdot
.972 .2271 Mdot
.972 .22719 Mdot
.972 .22809 Mdot
.972 .22897 Mdot
.972 .22953 Mdot
.972 .22953 Mdot
.972 .23005 Mdot
.972 .23099 Mdot
.972 .23102 Mdot
.972 .23243 Mdot
.972 .23384 Mdot
.972 .23385 Mdot
.972 .23471 Mdot
.972 .23484 Mdot
.972 .2352 Mdot
.972 .23693 Mdot
.972 .23732 Mdot
.972 .23762 Mdot
.972 .23783 Mdot
.972 .2385 Mdot
.972 .23965 Mdot
.972 .24 Mdot
.972 .24054 Mdot
.972 .24121 Mdot
.972 .24209 Mdot
.972 .24237 Mdot
.972 .24254 Mdot
.972 .24272 Mdot
.972 .2429 Mdot
.972 .243 Mdot
.972 .24328 Mdot
.972 .24339 Mdot
.972 .24366 Mdot
.972 .24482 Mdot
.972 .24504 Mdot
.972 .24562 Mdot
.972 .24571 Mdot
.972 .24627 Mdot
.972 .24722 Mdot
.972 .24815 Mdot
.972 .24943 Mdot
.972 .24962 Mdot
.972 .25104 Mdot
.972 .25126 Mdot
.972 .25173 Mdot
.972 .25173 Mdot
.972 .25176 Mdot
.972 .25204 Mdot
.972 .25309 Mdot
.972 .25327 Mdot
.972 .25337 Mdot
.972 .25368 Mdot
.972 .25397 Mdot
.972 .25407 Mdot
.972 .25578 Mdot
.972 .25648 Mdot
.972 .25664 Mdot
.972 .25683 Mdot
.972 .25719 Mdot
.972 .25726 Mdot
.972 .25734 Mdot
.972 .25811 Mdot
.972 .25833 Mdot
.972 .25841 Mdot
.972 .26006 Mdot
.972 .26118 Mdot
.972 .26162 Mdot
.972 .26203 Mdot
.972 .26212 Mdot
.972 .26261 Mdot
.972 .26269 Mdot
.972 .26349 Mdot
.972 .26421 Mdot
.972 .26491 Mdot
.972 .26542 Mdot
.972 .26567 Mdot
.972 .26634 Mdot
.972 .26656 Mdot
.972 .26677 Mdot
.972 .26802 Mdot
.972 .26806 Mdot
.972 .26812 Mdot
.972 .2691 Mdot
.972 .26993 Mdot
.972 .27129 Mdot
.972 .27164 Mdot
.972 .27179 Mdot
.972 .27233 Mdot
.972 .27314 Mdot
.972 .2736 Mdot
.972 .27429 Mdot
.972 .27436 Mdot
.972 .27622 Mdot
.972 .27753 Mdot
.972 .27796 Mdot
.972 .27801 Mdot
.972 .27902 Mdot
.972 .27968 Mdot
.972 .28003 Mdot
.972 .28012 Mdot
.972 .2804 Mdot
.972 .28117 Mdot
.972 .28228 Mdot
.972 .28311 Mdot
.972 .28328 Mdot
.972 .2848 Mdot
.972 .28561 Mdot
.972 .28565 Mdot
.972 .28822 Mdot
.972 .28832 Mdot
.972 .28887 Mdot
.972 .28887 Mdot
.972 .28973 Mdot
.972 .28996 Mdot
.972 .29038 Mdot
.972 .29129 Mdot
.972 .29186 Mdot
.972 .29333 Mdot
.972 .29426 Mdot
.972 .29449 Mdot
.972 .29554 Mdot
.972 .29585 Mdot
.972 .29715 Mdot
.972 .29798 Mdot
.972 .29813 Mdot
.972 .29823 Mdot
.972 .29906 Mdot
.972 .29918 Mdot
.972 .29963 Mdot
.972 .29993 Mdot
.972 .30024 Mdot
.972 .30089 Mdot
.972 .30129 Mdot
.972 .30158 Mdot
.972 .30224 Mdot
.972 .30262 Mdot
.972 .30361 Mdot
.972 .3037 Mdot
.972 .30411 Mdot
.972 .3045 Mdot
.972 .30514 Mdot
.972 .30553 Mdot
.972 .30668 Mdot
.972 .30766 Mdot
.972 .309 Mdot
.972 .30912 Mdot
.972 .30919 Mdot
.972 .30952 Mdot
.972 .30954 Mdot
.972 .31033 Mdot
.972 .31063 Mdot
.972 .31065 Mdot
.972 .31248 Mdot
.972 .31253 Mdot
.972 .31266 Mdot
.972 .31286 Mdot
.972 .31297 Mdot
.972 .31298 Mdot
.972 .31333 Mdot
.972 .31497 Mdot
.972 .31689 Mdot
.972 .31853 Mdot
.972 .31859 Mdot
.972 .31868 Mdot
.972 .31997 Mdot
.972 .32066 Mdot
.972 .321 Mdot
.972 .32106 Mdot
.972 .32143 Mdot
.972 .32144 Mdot
.972 .32156 Mdot
.972 .32191 Mdot
.972 .32209 Mdot
.972 .32214 Mdot
.972 .32239 Mdot
.972 .32302 Mdot
.972 .32478 Mdot
.972 .32479 Mdot
.972 .32554 Mdot
.972 .32694 Mdot
.972 .32765 Mdot
.972 .32883 Mdot
.972 .33101 Mdot
.972 .33182 Mdot
.972 .33184 Mdot
.972 .33194 Mdot
.972 .33198 Mdot
.972 .33216 Mdot
.972 .33254 Mdot
.972 .33262 Mdot
.972 .333 Mdot
.972 .33327 Mdot
.972 .33386 Mdot
.972 .33398 Mdot
.972 .33452 Mdot
.972 .33561 Mdot
.972 .33561 Mdot
.972 .33575 Mdot
.972 .33641 Mdot
.972 .33658 Mdot
.972 .33663 Mdot
.972 .33678 Mdot
.972 .33749 Mdot
.972 .33808 Mdot
.972 .33931 Mdot
.972 .34034 Mdot
.972 .34064 Mdot
.972 .34077 Mdot
.972 .34106 Mdot
.972 .34138 Mdot
.972 .34143 Mdot
.972 .34152 Mdot
.972 .34183 Mdot
.972 .34184 Mdot
.972 .3427 Mdot
.972 .34296 Mdot
.972 .34298 Mdot
.972 .34321 Mdot
.972 .34379 Mdot
.972 .34407 Mdot
.972 .34414 Mdot
.972 .34445 Mdot
.972 .34465 Mdot
.972 .34637 Mdot
.972 .34771 Mdot
.972 .34783 Mdot
.972 .34848 Mdot
.972 .34922 Mdot
.972 .34984 Mdot
.972 .35093 Mdot
.972 .35153 Mdot
.972 .35175 Mdot
.972 .35315 Mdot
.972 .35356 Mdot
.972 .35358 Mdot
.972 .35367 Mdot
.972 .35418 Mdot
.972 .35441 Mdot
.972 .35488 Mdot
.972 .35492 Mdot
.972 .35583 Mdot
.972 .35593 Mdot
.972 .35627 Mdot
.972 .35652 Mdot
.972 .35684 Mdot
.972 .35775 Mdot
.972 .35814 Mdot
.972 .35857 Mdot
.972 .3591 Mdot
.972 .35923 Mdot
.972 .35972 Mdot
.972 .35977 Mdot
.972 .36057 Mdot
.972 .36063 Mdot
.972 .36082 Mdot
.972 .36085 Mdot
.972 .36259 Mdot
.972 .36514 Mdot
.972 .36538 Mdot
.972 .36549 Mdot
.972 .36599 Mdot
.972 .36662 Mdot
.972 .36709 Mdot
.972 .36864 Mdot
.972 .36938 Mdot
.972 .36992 Mdot
.972 .37088 Mdot
.972 .37134 Mdot
.972 .37217 Mdot
.972 .37251 Mdot
.972 .37299 Mdot
.972 .37347 Mdot
.972 .37355 Mdot
.972 .37456 Mdot
.972 .3748 Mdot
.972 .37486 Mdot
.972 .37488 Mdot
.972 .37622 Mdot
.972 .37673 Mdot
.972 .3768 Mdot
.972 .37704 Mdot
.972 .37709 Mdot
.972 .37745 Mdot
.972 .37793 Mdot
.972 .37908 Mdot
.972 .38007 Mdot
.972 .38063 Mdot
.972 .38279 Mdot
.972 .38334 Mdot
.972 .38373 Mdot
.972 .38513 Mdot
.972 .38539 Mdot
.972 .38542 Mdot
.972 .38564 Mdot
.972 .38623 Mdot
.972 .38735 Mdot
.972 .38791 Mdot
.972 .38832 Mdot
.972 .3887 Mdot
.972 .38932 Mdot
.972 .38941 Mdot
.972 .39083 Mdot
.972 .39156 Mdot
.972 .39159 Mdot
.972 .39168 Mdot
.972 .39244 Mdot
.972 .39434 Mdot
.972 .39469 Mdot
.972 .39656 Mdot
.972 .39675 Mdot
.972 .39718 Mdot
.972 .39732 Mdot
.972 .39747 Mdot
.972 .39757 Mdot
.972 .39816 Mdot
.972 .40009 Mdot
.972 .40117 Mdot
.972 .40127 Mdot
.972 .4017 Mdot
.972 .40335 Mdot
.972 .40351 Mdot
.972 .40439 Mdot
.972 .40464 Mdot
.972 .40535 Mdot
.972 .40681 Mdot
.972 .40722 Mdot
.972 .40954 Mdot
.972 .41011 Mdot
.972 .41085 Mdot
.972 .41144 Mdot
.972 .41149 Mdot
.972 .41237 Mdot
.972 .41266 Mdot
.972 .41323 Mdot
.972 .41347 Mdot
.972 .41415 Mdot
.972 .41426 Mdot
.972 .4157 Mdot
.972 .41585 Mdot
.972 .41654 Mdot
.972 .41688 Mdot
.972 .41713 Mdot
.972 .41788 Mdot
.972 .41808 Mdot
.972 .41827 Mdot
.972 .41865 Mdot
.972 .41947 Mdot
.972 .42015 Mdot
.972 .4209 Mdot
.972 .4209 Mdot
.972 .42116 Mdot
.972 .42166 Mdot
.972 .42239 Mdot
.972 .42312 Mdot
.972 .42381 Mdot
.972 .42491 Mdot
.972 .4269 Mdot
.972 .42759 Mdot
.972 .42777 Mdot
.972 .42783 Mdot
.972 .42817 Mdot
.972 .42951 Mdot
.972 .43 Mdot
.972 .43123 Mdot
.972 .43232 Mdot
.972 .43232 Mdot
.972 .43311 Mdot
.972 .43332 Mdot
.972 .43476 Mdot
.972 .43484 Mdot
.972 .43494 Mdot
.972 .43516 Mdot
.972 .43521 Mdot
.972 .43762 Mdot
.972 .43795 Mdot
.972 .43874 Mdot
.972 .4407 Mdot
.972 .44072 Mdot
.972 .44125 Mdot
.972 .44238 Mdot
.972 .44256 Mdot
.972 .44264 Mdot
.972 .44291 Mdot
.972 .44333 Mdot
.972 .44396 Mdot
.972 .44491 Mdot
.972 .44559 Mdot
.972 .4467 Mdot
.972 .44687 Mdot
.972 .44746 Mdot
.972 .44803 Mdot
.972 .44846 Mdot
.972 .44855 Mdot
.972 .44975 Mdot
.972 .45109 Mdot
.972 .45142 Mdot
.972 .45199 Mdot
.972 .45267 Mdot
.972 .45372 Mdot
.972 .4542 Mdot
.972 .45486 Mdot
.972 .45501 Mdot
.972 .45611 Mdot
.972 .45673 Mdot
.972 .45727 Mdot
.972 .4576 Mdot
.972 .45796 Mdot
.972 .4583 Mdot
.972 .45849 Mdot
.972 .45901 Mdot
.972 .45905 Mdot
.972 .45926 Mdot
.972 .45979 Mdot
.972 .46058 Mdot
.972 .46205 Mdot
.972 .46246 Mdot
.972 .46359 Mdot
.972 .46366 Mdot
.972 .46376 Mdot
.972 .46382 Mdot
.972 .46485 Mdot
.972 .46671 Mdot
.972 .46742 Mdot
.972 .46851 Mdot
.972 .47101 Mdot
.972 .47137 Mdot
.972 .47353 Mdot
.972 .47389 Mdot
.972 .47412 Mdot
.972 .47457 Mdot
.972 .47463 Mdot
.972 .47546 Mdot
.972 .47547 Mdot
.972 .47554 Mdot
.972 .47597 Mdot
.972 .47599 Mdot
.972 .47607 Mdot
.972 .47812 Mdot
.972 .47846 Mdot
.972 .47867 Mdot
.972 .47925 Mdot
.972 .47925 Mdot
.972 .47982 Mdot
.972 .48001 Mdot
.972 .48011 Mdot
.972 .48169 Mdot
.972 .48334 Mdot
.972 .48449 Mdot
.972 .4847 Mdot
.972 .48502 Mdot
.972 .48514 Mdot
.972 .48538 Mdot
.972 .4854 Mdot
.972 .48587 Mdot
.972 .48609 Mdot
.972 .48622 Mdot
.972 .48639 Mdot
.972 .48728 Mdot
.972 .48787 Mdot
.972 .48831 Mdot
.972 .48833 Mdot
.972 .48843 Mdot
.972 .48845 Mdot
.972 .49166 Mdot
.972 .49284 Mdot
.972 .49385 Mdot
.972 .49427 Mdot
.972 .49469 Mdot
.972 .4955 Mdot
.972 .49567 Mdot
.972 .49636 Mdot
.972 .49662 Mdot
.972 .49678 Mdot
.972 .49723 Mdot
.972 .49833 Mdot
.972 .49974 Mdot
.972 .50109 Mdot
.972 .5012 Mdot
.972 .50208 Mdot
.972 .50237 Mdot
.972 .50258 Mdot
.972 .50387 Mdot
.972 .50431 Mdot
.972 .5047 Mdot
.972 .50714 Mdot
.972 .50721 Mdot
.972 .50729 Mdot
.972 .50734 Mdot
.972 .50924 Mdot
.972 .5104 Mdot
.972 .51084 Mdot
.972 .51098 Mdot
.972 .51134 Mdot
.972 .5135 Mdot
.972 .51417 Mdot
.972 .51447 Mdot
.972 .5145 Mdot
.972 .51495 Mdot
.972 .51552 Mdot
.972 .51666 Mdot
.972 .5171 Mdot
.972 .51778 Mdot
.972 .51799 Mdot
.972 .51896 Mdot
.972 .51934 Mdot
.972 .51947 Mdot
.972 .5214 Mdot
.972 .5229 Mdot
.972 .52308 Mdot
.972 .52402 Mdot
.972 .52562 Mdot
.972 .52647 Mdot
.972 .52651 Mdot
.972 .52656 Mdot
.972 .52794 Mdot
.972 .52852 Mdot
.972 .52981 Mdot
.972 .53048 Mdot
.972 .53066 Mdot
.972 .5312 Mdot
.972 .53169 Mdot
.972 .53204 Mdot
.972 .5327 Mdot
.972 .53356 Mdot
.972 .53487 Mdot
.972 .53504 Mdot
.972 .53647 Mdot
.972 .53681 Mdot
.972 .53745 Mdot
.972 .53894 Mdot
.972 .53975 Mdot
.972 .54133 Mdot
.972 .54142 Mdot
.972 .54327 Mdot
.972 .54641 Mdot
.972 .5466 Mdot
.972 .54698 Mdot
.972 .54766 Mdot
.972 .54768 Mdot
.972 .54935 Mdot
.972 .5498 Mdot
.972 .55061 Mdot
.972 .55205 Mdot
.972 .55238 Mdot
.972 .55252 Mdot
.972 .55276 Mdot
.972 .55348 Mdot
.972 .55403 Mdot
.972 .55408 Mdot
.972 .55634 Mdot
.972 .55708 Mdot
.972 .55815 Mdot
.972 .55861 Mdot
.972 .56065 Mdot
.972 .56125 Mdot
.972 .56378 Mdot
.972 .56538 Mdot
.972 .56567 Mdot
.972 .56586 Mdot
.972 .56749 Mdot
.972 .56772 Mdot
.972 .5686 Mdot
.972 .56918 Mdot
.972 .56978 Mdot
.972 .57104 Mdot
.972 .57181 Mdot
.972 .57238 Mdot
.972 .57367 Mdot
.972 .5744 Mdot
.972 .57633 Mdot
.972 .57651 Mdot
.972 .57729 Mdot
.972 .57805 Mdot
.972 .57929 Mdot
.972 .58006 Mdot
.972 .58229 Mdot
.972 .58419 Mdot
.972 .5868 Mdot
.972 .58704 Mdot
.972 .58717 Mdot
.972 .58782 Mdot
.972 .58785 Mdot
.972 .58939 Mdot
.974 .01473 Mdot
.974 .01474 Mdot
.974 .01477 Mdot
.974 .01481 Mdot
.974 .0149 Mdot
.974 .01508 Mdot
.974 .01543 Mdot
.974 .01585 Mdot
.974 .01612 Mdot
.974 .01632 Mdot
.974 .01693 Mdot
.974 .01693 Mdot
.974 .01744 Mdot
.974 .01785 Mdot
.974 .01902 Mdot
.974 .01903 Mdot
.974 .01932 Mdot
.974 .01936 Mdot
.974 .02003 Mdot
.974 .02033 Mdot
.974 .02081 Mdot
.974 .02224 Mdot
.974 .02311 Mdot
.974 .02311 Mdot
.974 .02351 Mdot
.974 .02367 Mdot
.974 .02369 Mdot
.974 .02376 Mdot
.974 .02463 Mdot
.974 .02506 Mdot
.974 .02563 Mdot
.974 .02566 Mdot
.974 .02632 Mdot
.974 .02657 Mdot
.974 .0266 Mdot
.974 .02679 Mdot
.974 .02872 Mdot
.974 .02898 Mdot
.974 .02915 Mdot
.974 .02937 Mdot
.974 .03106 Mdot
.974 .03108 Mdot
.974 .03155 Mdot
.974 .03184 Mdot
.974 .03208 Mdot
.974 .03214 Mdot
.974 .03216 Mdot
.974 .03219 Mdot
.974 .03234 Mdot
.974 .03252 Mdot
.974 .03272 Mdot
.974 .03342 Mdot
.974 .03397 Mdot
.974 .03403 Mdot
.974 .03438 Mdot
.974 .03487 Mdot
.974 .03525 Mdot
.974 .03595 Mdot
.974 .03598 Mdot
.974 .03603 Mdot
.974 .0367 Mdot
.974 .03733 Mdot
.974 .0378 Mdot
.974 .03786 Mdot
.974 .03824 Mdot
.974 .04001 Mdot
.974 .04199 Mdot
.974 .0425 Mdot
.974 .04283 Mdot
.974 .04319 Mdot
.974 .04319 Mdot
.974 .04326 Mdot
.974 .04335 Mdot
.974 .04656 Mdot
.974 .04659 Mdot
.974 .04713 Mdot
.974 .04751 Mdot
.974 .04778 Mdot
.974 .04807 Mdot
.974 .04836 Mdot
.974 .04854 Mdot
.974 .04866 Mdot
.974 .0487 Mdot
.974 .04876 Mdot
.974 .04905 Mdot
.974 .04939 Mdot
.974 .04978 Mdot
.974 .05054 Mdot
.974 .05116 Mdot
.974 .05124 Mdot
.974 .05223 Mdot
.974 .05235 Mdot
.974 .05253 Mdot
.974 .05302 Mdot
.974 .05398 Mdot
.974 .05434 Mdot
.974 .05472 Mdot
.974 .05534 Mdot
.974 .0554 Mdot
.974 .05608 Mdot
.974 .05614 Mdot
.974 .05619 Mdot
.974 .05624 Mdot
.974 .05669 Mdot
.974 .0567 Mdot
.974 .05754 Mdot
.974 .05759 Mdot
.974 .05829 Mdot
.974 .05876 Mdot
.974 .05969 Mdot
.974 .0598 Mdot
.974 .0598 Mdot
.974 .06055 Mdot
.974 .06296 Mdot
.974 .06296 Mdot
.974 .06365 Mdot
.974 .06385 Mdot
.974 .064 Mdot
.974 .06539 Mdot
.974 .06618 Mdot
.974 .06645 Mdot
.974 .06692 Mdot
.974 .06773 Mdot
.974 .06785 Mdot
.974 .06883 Mdot
.974 .06949 Mdot
.974 .07018 Mdot
.974 .07019 Mdot
.974 .07033 Mdot
.974 .0705 Mdot
.974 .07198 Mdot
.974 .07296 Mdot
.974 .07338 Mdot
.974 .07615 Mdot
.974 .07675 Mdot
.974 .0768 Mdot
.974 .07786 Mdot
.974 .0786 Mdot
.974 .07913 Mdot
.974 .07969 Mdot
.974 .07999 Mdot
.974 .08026 Mdot
.974 .08061 Mdot
.974 .08084 Mdot
.974 .08093 Mdot
.974 .08104 Mdot
.974 .0816 Mdot
.974 .08166 Mdot
.974 .08206 Mdot
.974 .08226 Mdot
.974 .08283 Mdot
.974 .08302 Mdot
.974 .08449 Mdot
.974 .08451 Mdot
.974 .08459 Mdot
.974 .08553 Mdot
.974 .0857 Mdot
.974 .08587 Mdot
.974 .08605 Mdot
.974 .08641 Mdot
.974 .08712 Mdot
.974 .08753 Mdot
.974 .08779 Mdot
.974 .0879 Mdot
.974 .08794 Mdot
.974 .08795 Mdot
.974 .08802 Mdot
.974 .08838 Mdot
.974 .08912 Mdot
.974 .08932 Mdot
.974 .09085 Mdot
.974 .09089 Mdot
.974 .09121 Mdot
.974 .0919 Mdot
.974 .09264 Mdot
.974 .09385 Mdot
.974 .09398 Mdot
.974 .09529 Mdot
.974 .09541 Mdot
.974 .09551 Mdot
.974 .09561 Mdot
.974 .09649 Mdot
.974 .09651 Mdot
.974 .09748 Mdot
.974 .09813 Mdot
.974 .09825 Mdot
.974 .09844 Mdot
.974 .09873 Mdot
.974 .09916 Mdot
.974 .0996 Mdot
.974 .09963 Mdot
.974 .10051 Mdot
.974 .10233 Mdot
.974 .10254 Mdot
.974 .10254 Mdot
.974 .10293 Mdot
.974 .10294 Mdot
.974 .104 Mdot
.974 .10575 Mdot
.974 .10604 Mdot
.974 .10741 Mdot
.974 .10863 Mdot
.974 .1087 Mdot
.974 .1087 Mdot
.974 .10916 Mdot
.974 .10993 Mdot
.974 .11003 Mdot
.974 .11043 Mdot
.974 .11056 Mdot
.974 .11072 Mdot
.974 .11169 Mdot
.974 .1117 Mdot
.974 .11344 Mdot
.974 .11379 Mdot
.974 .11491 Mdot
.974 .11492 Mdot
.974 .11497 Mdot
.974 .1155 Mdot
.974 .11641 Mdot
.974 .11798 Mdot
.974 .11798 Mdot
.974 .11823 Mdot
.974 .11903 Mdot
.974 .12013 Mdot
.974 .12071 Mdot
.974 .12141 Mdot
.974 .12144 Mdot
.974 .12197 Mdot
.974 .12276 Mdot
.974 .12279 Mdot
.974 .12305 Mdot
.974 .12339 Mdot
.974 .12358 Mdot
.974 .12397 Mdot
.974 .12397 Mdot
.974 .12404 Mdot
.974 .12627 Mdot
.974 .12817 Mdot
.974 .129 Mdot
.974 .12991 Mdot
.974 .12998 Mdot
.974 .13001 Mdot
.974 .13222 Mdot
.974 .13296 Mdot
.974 .13302 Mdot
.974 .13344 Mdot
.974 .13347 Mdot
.974 .13439 Mdot
.974 .13493 Mdot
.974 .13555 Mdot
.974 .13566 Mdot
.974 .13661 Mdot
.974 .1369 Mdot
.974 .13736 Mdot
.974 .13772 Mdot
.974 .13876 Mdot
.974 .13916 Mdot
.974 .13937 Mdot
.974 .14019 Mdot
.974 .14098 Mdot
.974 .14129 Mdot
.974 .14174 Mdot
.974 .14187 Mdot
.974 .14239 Mdot
.974 .14256 Mdot
.974 .14307 Mdot
.974 .14334 Mdot
.974 .14352 Mdot
.974 .1437 Mdot
.974 .14392 Mdot
.974 .14501 Mdot
.974 .14506 Mdot
.974 .14511 Mdot
.974 .14578 Mdot
.974 .14579 Mdot
.974 .14591 Mdot
.974 .14629 Mdot
.974 .1463 Mdot
.974 .14638 Mdot
.974 .14721 Mdot
.974 .14741 Mdot
.974 .14771 Mdot
.974 .14778 Mdot
.974 .14839 Mdot
.974 .14875 Mdot
.974 .14961 Mdot
.974 .14981 Mdot
.974 .15064 Mdot
.974 .15068 Mdot
.974 .15083 Mdot
.974 .15176 Mdot
.974 .15267 Mdot
.974 .153 Mdot
.974 .15333 Mdot
.974 .15368 Mdot
.974 .15437 Mdot
.974 .15466 Mdot
.974 .15526 Mdot
.974 .15557 Mdot
.974 .15566 Mdot
.974 .15576 Mdot
.974 .1562 Mdot
.974 .15656 Mdot
.974 .15674 Mdot
.974 .15706 Mdot
.974 .15727 Mdot
.974 .15728 Mdot
.974 .15736 Mdot
.974 .15739 Mdot
.974 .15751 Mdot
.974 .15767 Mdot
.974 .15786 Mdot
.974 .15821 Mdot
.974 .15966 Mdot
.974 .16005 Mdot
.974 .16302 Mdot
.974 .16311 Mdot
.974 .16373 Mdot
.974 .1643 Mdot
.974 .165 Mdot
.974 .16507 Mdot
.974 .16651 Mdot
.974 .16848 Mdot
.974 .16882 Mdot
.974 .16886 Mdot
.974 .16912 Mdot
.974 .17108 Mdot
.974 .17143 Mdot
.974 .17158 Mdot
.974 .17168 Mdot
.974 .17191 Mdot
.974 .1721 Mdot
.974 .17229 Mdot
.974 .17401 Mdot
.974 .17401 Mdot
.974 .17405 Mdot
.974 .17594 Mdot
.974 .17613 Mdot
.974 .17647 Mdot
.974 .17721 Mdot
.974 .17722 Mdot
.974 .17743 Mdot
.974 .1778 Mdot
.974 .17838 Mdot
.974 .17922 Mdot
.974 .17922 Mdot
.974 .1794 Mdot
.974 .17945 Mdot
.974 .17986 Mdot
.974 .18007 Mdot
.974 .18014 Mdot
.974 .18026 Mdot
.974 .18185 Mdot
.974 .1837 Mdot
.974 .1849 Mdot
.974 .18539 Mdot
.974 .18558 Mdot
.974 .1858 Mdot
.974 .1858 Mdot
.974 .18656 Mdot
.974 .18658 Mdot
.974 .18864 Mdot
.974 .18975 Mdot
.974 .19049 Mdot
.974 .19206 Mdot
.974 .19261 Mdot
.974 .19291 Mdot
.974 .19371 Mdot
.974 .19444 Mdot
.974 .19529 Mdot
.974 .19688 Mdot
.974 .19766 Mdot
.974 .19779 Mdot
.974 .1978 Mdot
.974 .1987 Mdot
.974 .19919 Mdot
.974 .20019 Mdot
.974 .2004 Mdot
.974 .20118 Mdot
.974 .20142 Mdot
.974 .20173 Mdot
.974 .20205 Mdot
.974 .2021 Mdot
.974 .20262 Mdot
.974 .20362 Mdot
.974 .20364 Mdot
.974 .20393 Mdot
.974 .20407 Mdot
.974 .20422 Mdot
.974 .20592 Mdot
.974 .20702 Mdot
.974 .20771 Mdot
.974 .20784 Mdot
.974 .20985 Mdot
.974 .2099 Mdot
.974 .20991 Mdot
.974 .21002 Mdot
.974 .21013 Mdot
.974 .21103 Mdot
.974 .21135 Mdot
.974 .21153 Mdot
.974 .21263 Mdot
.974 .21282 Mdot
.974 .21587 Mdot
.974 .21588 Mdot
.974 .21636 Mdot
.974 .21793 Mdot
.974 .218 Mdot
.974 .22007 Mdot
.974 .2212 Mdot
.974 .22228 Mdot
.974 .22256 Mdot
.974 .22262 Mdot
.974 .22365 Mdot
.974 .22458 Mdot
.974 .22519 Mdot
.974 .22524 Mdot
.974 .22575 Mdot
.974 .22637 Mdot
.974 .22641 Mdot
.974 .22679 Mdot
.974 .22742 Mdot
.974 .22746 Mdot
.974 .22753 Mdot
.974 .22754 Mdot
.974 .22766 Mdot
.974 .22768 Mdot
.974 .23156 Mdot
.974 .23181 Mdot
.974 .23202 Mdot
.974 .23279 Mdot
.974 .23361 Mdot
.974 .23373 Mdot
.974 .23509 Mdot
.974 .23573 Mdot
.974 .23734 Mdot
.974 .2374 Mdot
.974 .23754 Mdot
.974 .23761 Mdot
.974 .23912 Mdot
.974 .23925 Mdot
.974 .2393 Mdot
.974 .23953 Mdot
.974 .24054 Mdot
.974 .24158 Mdot
.974 .24188 Mdot
.974 .24205 Mdot
.974 .24349 Mdot
.974 .24362 Mdot
.974 .24505 Mdot
.974 .24518 Mdot
.974 .2459 Mdot
.974 .24599 Mdot
.974 .24602 Mdot
.974 .24606 Mdot
.974 .24632 Mdot
.974 .24635 Mdot
.974 .24678 Mdot
.974 .24683 Mdot
.974 .24686 Mdot
.974 .24784 Mdot
.974 .24889 Mdot
.974 .24978 Mdot
.974 .2501 Mdot
.974 .25032 Mdot
.974 .25217 Mdot
.974 .25273 Mdot
.974 .25364 Mdot
.974 .25407 Mdot
.974 .25432 Mdot
.974 .25636 Mdot
.974 .25713 Mdot
.974 .25754 Mdot
.974 .25853 Mdot
.974 .25893 Mdot
.974 .25915 Mdot
.974 .25921 Mdot
.974 .26068 Mdot
.974 .26128 Mdot
.974 .2616 Mdot
.974 .26206 Mdot
.974 .26215 Mdot
.974 .26241 Mdot
.974 .26255 Mdot
.974 .26335 Mdot
.974 .26343 Mdot
.974 .26376 Mdot
.974 .26475 Mdot
.974 .26527 Mdot
.974 .26562 Mdot
.974 .26597 Mdot
.974 .26626 Mdot
.974 .26641 Mdot
.974 .26853 Mdot
.974 .26864 Mdot
.974 .26873 Mdot
.974 .26938 Mdot
.974 .26984 Mdot
.974 .27004 Mdot
.974 .27006 Mdot
.974 .27029 Mdot
.974 .27102 Mdot
.974 .27105 Mdot
.974 .2712 Mdot
.974 .27281 Mdot
.974 .2732 Mdot
.974 .27379 Mdot
.974 .27392 Mdot
.974 .27403 Mdot
.974 .27456 Mdot
.974 .27497 Mdot
.974 .27511 Mdot
.974 .27582 Mdot
.974 .2768 Mdot
.974 .27741 Mdot
.974 .2775 Mdot
.974 .27788 Mdot
.974 .2795 Mdot
.974 .27957 Mdot
.974 .27988 Mdot
.974 .28168 Mdot
.974 .28344 Mdot
.974 .28377 Mdot
.974 .28409 Mdot
.974 .28428 Mdot
.974 .28453 Mdot
.974 .28457 Mdot
.974 .28474 Mdot
.974 .28542 Mdot
.974 .28676 Mdot
.974 .28734 Mdot
.974 .2885 Mdot
.974 .2891 Mdot
.974 .28927 Mdot
.974 .28948 Mdot
.974 .29017 Mdot
.974 .29029 Mdot
.974 .29032 Mdot
.974 .29076 Mdot
.974 .29098 Mdot
.974 .29103 Mdot
.974 .29108 Mdot
.974 .29138 Mdot
.974 .29183 Mdot
.974 .29201 Mdot
.974 .29242 Mdot
.974 .29243 Mdot
.974 .29258 Mdot
.974 .29264 Mdot
.974 .29289 Mdot
.974 .29319 Mdot
.974 .29352 Mdot
.974 .29356 Mdot
.974 .29425 Mdot
.974 .29565 Mdot
.974 .29707 Mdot
.974 .29783 Mdot
.974 .29963 Mdot
.974 .30075 Mdot
.974 .30138 Mdot
.974 .30316 Mdot
.974 .30361 Mdot
.974 .30378 Mdot
.974 .305 Mdot
.974 .30556 Mdot
.974 .30611 Mdot
.974 .30684 Mdot
.974 .30734 Mdot
.974 .30748 Mdot
.974 .30761 Mdot
.974 .30794 Mdot
.974 .30933 Mdot
.974 .3104 Mdot
.974 .31098 Mdot
.974 .31122 Mdot
.974 .31153 Mdot
.974 .31276 Mdot
.974 .31278 Mdot
.974 .31328 Mdot
.974 .31426 Mdot
.974 .31491 Mdot
.974 .31499 Mdot
.974 .31549 Mdot
.974 .316 Mdot
.974 .31635 Mdot
.974 .31648 Mdot
.974 .3166 Mdot
.974 .31758 Mdot
.974 .31772 Mdot
.974 .31781 Mdot
.974 .31904 Mdot
.974 .31931 Mdot
.974 .31934 Mdot
.974 .31953 Mdot
.974 .31964 Mdot
.974 .32 Mdot
.974 .32028 Mdot
.974 .32049 Mdot
.974 .32094 Mdot
.974 .3213 Mdot
.974 .32168 Mdot
.974 .32338 Mdot
.974 .32501 Mdot
.974 .32502 Mdot
.974 .3251 Mdot
.974 .32704 Mdot
.974 .32737 Mdot
.974 .32767 Mdot
.974 .32878 Mdot
.974 .32915 Mdot
.974 .32981 Mdot
.974 .33074 Mdot
.974 .33125 Mdot
.974 .33128 Mdot
.974 .33169 Mdot
.974 .33195 Mdot
.974 .33195 Mdot
.974 .33241 Mdot
.974 .33276 Mdot
.974 .33354 Mdot
.974 .33516 Mdot
.974 .33516 Mdot
.974 .33552 Mdot
.974 .33562 Mdot
.974 .33641 Mdot
.974 .33682 Mdot
.974 .33695 Mdot
.974 .3372 Mdot
.974 .33761 Mdot
.974 .33979 Mdot
.974 .34029 Mdot
.974 .34051 Mdot
.974 .34193 Mdot
.974 .3439 Mdot
.974 .34476 Mdot
.974 .34497 Mdot
.974 .34536 Mdot
.974 .34623 Mdot
.974 .34627 Mdot
.974 .34675 Mdot
.974 .34702 Mdot
.974 .3472 Mdot
.974 .34757 Mdot
.974 .34778 Mdot
.974 .34797 Mdot
.974 .34799 Mdot
.974 .34799 Mdot
.974 .34859 Mdot
.974 .34948 Mdot
.974 .3495 Mdot
.974 .35288 Mdot
.974 .35337 Mdot
.974 .35353 Mdot
.974 .35375 Mdot
.974 .35399 Mdot
.974 .35568 Mdot
.974 .35569 Mdot
.974 .35713 Mdot
.974 .35728 Mdot
.974 .35861 Mdot
.974 .35888 Mdot
.974 .35927 Mdot
.974 .3596 Mdot
.974 .36018 Mdot
.974 .36018 Mdot
.974 .36125 Mdot
.974 .36183 Mdot
.974 .36184 Mdot
.974 .36341 Mdot
.974 .36395 Mdot
.974 .36481 Mdot
.974 .36518 Mdot
.974 .36546 Mdot
.974 .36628 Mdot
.974 .36648 Mdot
.974 .36648 Mdot
.974 .36652 Mdot
.974 .36953 Mdot
.974 .36957 Mdot
.974 .36958 Mdot
.974 .37072 Mdot
.974 .3711 Mdot
.974 .37113 Mdot
.974 .37134 Mdot
.974 .37136 Mdot
.974 .37211 Mdot
.974 .37297 Mdot
.974 .37312 Mdot
.974 .37336 Mdot
.974 .37407 Mdot
.974 .37439 Mdot
.974 .37522 Mdot
.974 .3756 Mdot
.974 .37603 Mdot
.974 .37642 Mdot
.974 .37731 Mdot
.974 .37768 Mdot
.974 .37769 Mdot
.974 .37794 Mdot
.974 .37799 Mdot
.974 .37841 Mdot
.974 .37867 Mdot
.974 .37902 Mdot
.974 .3792 Mdot
.974 .37965 Mdot
.974 .37975 Mdot
.974 .38075 Mdot
.974 .38224 Mdot
.974 .38254 Mdot
.974 .3827 Mdot
.974 .38275 Mdot
.974 .38302 Mdot
.974 .3833 Mdot
.974 .38358 Mdot
.974 .38378 Mdot
.974 .38388 Mdot
.974 .38719 Mdot
.974 .38755 Mdot
.974 .38933 Mdot
.974 .3895 Mdot
.974 .39066 Mdot
.974 .39085 Mdot
.974 .39092 Mdot
.974 .39217 Mdot
.974 .39326 Mdot
.974 .39343 Mdot
.974 .39382 Mdot
.974 .39484 Mdot
.974 .39494 Mdot
.974 .39496 Mdot
.974 .39517 Mdot
.974 .39538 Mdot
.974 .39715 Mdot
.974 .39776 Mdot
.974 .39811 Mdot
.974 .40025 Mdot
.974 .40063 Mdot
.974 .40187 Mdot
.974 .40228 Mdot
.974 .40265 Mdot
.974 .40391 Mdot
.974 .4051 Mdot
.974 .40656 Mdot
.974 .40659 Mdot
.974 .40686 Mdot
.974 .40753 Mdot
.974 .4076 Mdot
.974 .40768 Mdot
.974 .40855 Mdot
.974 .40954 Mdot
.974 .41057 Mdot
.974 .41071 Mdot
.974 .41134 Mdot
.974 .41143 Mdot
.974 .41199 Mdot
.974 .41475 Mdot
.974 .41695 Mdot
.974 .41813 Mdot
.974 .41905 Mdot
.974 .41959 Mdot
.974 .41961 Mdot
.974 .41971 Mdot
.974 .42171 Mdot
.974 .42184 Mdot
.974 .42234 Mdot
.974 .42277 Mdot
.974 .42283 Mdot
.974 .42352 Mdot
.974 .42471 Mdot
.974 .42478 Mdot
.974 .42482 Mdot
.974 .4258 Mdot
.974 .42632 Mdot
.974 .42686 Mdot
.974 .42701 Mdot
.974 .4271 Mdot
.974 .42783 Mdot
.974 .42907 Mdot
.974 .42914 Mdot
.974 .42929 Mdot
.974 .42931 Mdot
.974 .42953 Mdot
.974 .42955 Mdot
.974 .42957 Mdot
.974 .43107 Mdot
.974 .43327 Mdot
.974 .43556 Mdot
.974 .43576 Mdot
.974 .43591 Mdot
.974 .43714 Mdot
.974 .43737 Mdot
.974 .43762 Mdot
.974 .43803 Mdot
.974 .43952 Mdot
.974 .44113 Mdot
.974 .44136 Mdot
.974 .44352 Mdot
.974 .44379 Mdot
.974 .444 Mdot
.974 .44494 Mdot
.974 .44525 Mdot
.974 .44851 Mdot
.974 .44877 Mdot
.974 .44891 Mdot
.974 .44893 Mdot
.974 .4518 Mdot
.974 .45186 Mdot
.974 .4521 Mdot
.974 .45222 Mdot
.974 .45227 Mdot
.974 .45265 Mdot
.974 .45352 Mdot
.974 .45462 Mdot
.974 .45666 Mdot
.974 .45723 Mdot
.974 .45756 Mdot
.974 .45847 Mdot
.974 .4597 Mdot
.974 .46036 Mdot
.974 .46061 Mdot
.974 .46092 Mdot
.974 .46163 Mdot
.974 .46248 Mdot
.974 .46261 Mdot
.974 .46277 Mdot
.974 .4634 Mdot
.974 .46341 Mdot
.974 .46366 Mdot
.974 .46506 Mdot
.974 .46524 Mdot
.974 .46531 Mdot
.974 .46537 Mdot
.974 .46587 Mdot
.974 .46594 Mdot
.974 .46599 Mdot
.974 .46662 Mdot
.974 .46677 Mdot
.974 .46687 Mdot
.974 .46693 Mdot
.974 .46885 Mdot
.974 .47073 Mdot
.974 .4709 Mdot
.974 .47105 Mdot
.974 .47262 Mdot
.974 .47325 Mdot
.974 .47325 Mdot
.974 .47367 Mdot
.974 .47615 Mdot
.974 .47727 Mdot
.974 .47764 Mdot
.974 .47837 Mdot
.974 .47982 Mdot
.974 .47993 Mdot
.974 .48013 Mdot
.974 .4806 Mdot
.974 .48085 Mdot
.974 .48098 Mdot
.974 .48137 Mdot
.974 .48147 Mdot
.974 .48179 Mdot
.974 .48399 Mdot
.974 .48425 Mdot
.974 .48444 Mdot
.974 .48456 Mdot
.974 .48543 Mdot
.974 .48625 Mdot
.974 .48693 Mdot
.974 .48707 Mdot
.974 .48727 Mdot
.974 .48744 Mdot
.974 .48774 Mdot
.974 .48859 Mdot
.974 .48967 Mdot
.974 .49031 Mdot
.974 .49045 Mdot
.974 .49087 Mdot
.974 .49097 Mdot
.974 .49099 Mdot
.974 .49254 Mdot
.974 .49257 Mdot
.974 .49315 Mdot
.974 .49336 Mdot
.974 .49386 Mdot
.974 .49431 Mdot
.974 .4945 Mdot
.974 .49503 Mdot
.974 .49546 Mdot
.974 .49566 Mdot
.974 .49653 Mdot
.974 .49672 Mdot
.974 .49673 Mdot
.974 .49688 Mdot
.974 .49723 Mdot
.974 .49751 Mdot
.974 .49906 Mdot
.974 .49922 Mdot
.974 .49947 Mdot
.974 .49986 Mdot
.974 .50179 Mdot
.974 .50279 Mdot
.974 .50348 Mdot
.974 .50416 Mdot
.974 .50472 Mdot
.974 .50481 Mdot
.974 .50501 Mdot
.974 .50914 Mdot
.974 .50935 Mdot
.974 .50954 Mdot
.974 .51019 Mdot
.974 .5108 Mdot
.974 .5117 Mdot
.974 .51208 Mdot
.974 .51212 Mdot
.974 .51257 Mdot
.974 .51308 Mdot
.974 .514 Mdot
.974 .51405 Mdot
.974 .51434 Mdot
.974 .51749 Mdot
.974 .51825 Mdot
.974 .51939 Mdot
.974 .51965 Mdot
.974 .51987 Mdot
.974 .5199 Mdot
.974 .5209 Mdot
.974 .52169 Mdot
.974 .52197 Mdot
.974 .52335 Mdot
.974 .52413 Mdot
.974 .52526 Mdot
.974 .52644 Mdot
.974 .52654 Mdot
.974 .52661 Mdot
.974 .52736 Mdot
.974 .53052 Mdot
.974 .53066 Mdot
.974 .53125 Mdot
.974 .5333 Mdot
.974 .53477 Mdot
.974 .53501 Mdot
.974 .53566 Mdot
.974 .5382 Mdot
.974 .53883 Mdot
.974 .53946 Mdot
.974 .53982 Mdot
.974 .54026 Mdot
.974 .54032 Mdot
.974 .5404 Mdot
.974 .54073 Mdot
.974 .54206 Mdot
.974 .54238 Mdot
.974 .54449 Mdot
.974 .54465 Mdot
.974 .54578 Mdot
.974 .54727 Mdot
.974 .54804 Mdot
.974 .54916 Mdot
.974 .54921 Mdot
.974 .54956 Mdot
.974 .54968 Mdot
.974 .54995 Mdot
.974 .55017 Mdot
.974 .5513 Mdot
.974 .55143 Mdot
.974 .55153 Mdot
.974 .55159 Mdot
.974 .55246 Mdot
.974 .55288 Mdot
.974 .55298 Mdot
.974 .55307 Mdot
.974 .55366 Mdot
.974 .55454 Mdot
.974 .55488 Mdot
.974 .55569 Mdot
.974 .5557 Mdot
.974 .556 Mdot
.974 .55611 Mdot
.974 .55659 Mdot
.974 .55669 Mdot
.974 .55718 Mdot
.974 .55783 Mdot
.974 .55791 Mdot
.974 .55924 Mdot
.974 .56198 Mdot
.974 .56475 Mdot
.974 .56623 Mdot
.974 .56973 Mdot
.974 .5719 Mdot
.974 .57314 Mdot
.974 .57661 Mdot
.974 .57749 Mdot
.974 .57782 Mdot
.974 .58018 Mdot
.974 .58127 Mdot
.974 .58235 Mdot
.974 .58378 Mdot
.974 .58475 Mdot
.974 .58502 Mdot
.974 .58527 Mdot
.974 .58592 Mdot
.974 .58862 Mdot
.976 .01501 Mdot
.976 .01507 Mdot
.976 .01529 Mdot
.976 .01542 Mdot
.976 .01583 Mdot
.976 .01608 Mdot
.976 .01689 Mdot
.976 .01738 Mdot
.976 .01759 Mdot
.976 .01825 Mdot
.976 .01896 Mdot
.976 .01993 Mdot
.976 .02033 Mdot
.976 .02099 Mdot
.976 .02117 Mdot
.976 .02162 Mdot
.976 .02233 Mdot
.976 .02301 Mdot
.976 .02406 Mdot
.976 .02443 Mdot
.976 .02464 Mdot
.976 .02489 Mdot
.976 .02543 Mdot
.976 .02568 Mdot
.976 .02614 Mdot
.976 .02696 Mdot
.976 .02712 Mdot
.976 .02731 Mdot
.976 .0279 Mdot
.976 .0282 Mdot
.976 .02915 Mdot
.976 .0294 Mdot
.976 .02958 Mdot
.976 .03002 Mdot
.976 .0309 Mdot
.976 .03268 Mdot
.976 .03295 Mdot
.976 .03363 Mdot
.976 .03368 Mdot
.976 .03408 Mdot
.976 .03457 Mdot
.976 .03562 Mdot
.976 .03611 Mdot
.976 .03637 Mdot
.976 .03702 Mdot
.976 .03861 Mdot
.976 .03893 Mdot
.976 .03894 Mdot
.976 .0393 Mdot
.976 .04045 Mdot
.976 .04052 Mdot
.976 .04103 Mdot
.976 .04167 Mdot
.976 .04231 Mdot
.976 .04259 Mdot
.976 .04289 Mdot
.976 .04337 Mdot
.976 .04372 Mdot
.976 .04386 Mdot
.976 .04443 Mdot
.976 .04459 Mdot
.976 .04534 Mdot
.976 .04595 Mdot
.976 .04631 Mdot
.976 .04718 Mdot
.976 .04828 Mdot
.976 .0485 Mdot
.976 .04932 Mdot
.976 .04952 Mdot
.976 .04962 Mdot
.976 .04978 Mdot
.976 .04999 Mdot
.976 .05008 Mdot
.976 .05031 Mdot
.976 .05032 Mdot
.976 .05046 Mdot
.976 .05071 Mdot
.976 .05071 Mdot
.976 .05117 Mdot
.976 .05125 Mdot
.976 .05164 Mdot
.976 .05173 Mdot
.976 .05215 Mdot
.976 .05252 Mdot
.976 .05347 Mdot
.976 .05471 Mdot
.976 .05511 Mdot
.976 .05552 Mdot
.976 .05596 Mdot
.976 .05648 Mdot
.976 .05695 Mdot
.976 .05699 Mdot
.976 .05722 Mdot
.976 .05725 Mdot
.976 .05825 Mdot
.976 .0585 Mdot
.976 .05912 Mdot
.976 .06136 Mdot
.976 .06141 Mdot
.976 .06198 Mdot
.976 .062 Mdot
.976 .0627 Mdot
.976 .06495 Mdot
.976 .06508 Mdot
.976 .06609 Mdot
.976 .06689 Mdot
.976 .06734 Mdot
.976 .06759 Mdot
.976 .06833 Mdot
.976 .06858 Mdot
.976 .06913 Mdot
.976 .0696 Mdot
.976 .06972 Mdot
.976 .07066 Mdot
.976 .07134 Mdot
.976 .0716 Mdot
.976 .07193 Mdot
.976 .07204 Mdot
.976 .07219 Mdot
.976 .07271 Mdot
.976 .07304 Mdot
.976 .07326 Mdot
.976 .07439 Mdot
.976 .07449 Mdot
.976 .07464 Mdot
.976 .07506 Mdot
.976 .07569 Mdot
.976 .07638 Mdot
.976 .07809 Mdot
.976 .08013 Mdot
.976 .08018 Mdot
.976 .08024 Mdot
.976 .08044 Mdot
.976 .08066 Mdot
.976 .08111 Mdot
.976 .08158 Mdot
.976 .08167 Mdot
.976 .08227 Mdot
.976 .0823 Mdot
.976 .08266 Mdot
.976 .08285 Mdot
.976 .08317 Mdot
.976 .08331 Mdot
.976 .08356 Mdot
.976 .08374 Mdot
.976 .0842 Mdot
.976 .08422 Mdot
.976 .08448 Mdot
.976 .08499 Mdot
.976 .08499 Mdot
.976 .08588 Mdot
.976 .08603 Mdot
.976 .08678 Mdot
.976 .08696 Mdot
.976 .08712 Mdot
.976 .08733 Mdot
.976 .08778 Mdot
.976 .0885 Mdot
.976 .09036 Mdot
.976 .09279 Mdot
.976 .09357 Mdot
.976 .09409 Mdot
.976 .09437 Mdot
.976 .09523 Mdot
.976 .09594 Mdot
.976 .09623 Mdot
.976 .09712 Mdot
.976 .09716 Mdot
.976 .09723 Mdot
.976 .09769 Mdot
.976 .09775 Mdot
.976 .09859 Mdot
.976 .0997 Mdot
.976 .10019 Mdot
.976 .10043 Mdot
.976 .1014 Mdot
.976 .10154 Mdot
.976 .10576 Mdot
.976 .10587 Mdot
.976 .10697 Mdot
.976 .10702 Mdot
.976 .10705 Mdot
.976 .10837 Mdot
.976 .10838 Mdot
.976 .10888 Mdot
.976 .11098 Mdot
.976 .11199 Mdot
.976 .11278 Mdot
.976 .11303 Mdot
.976 .11319 Mdot
.976 .11471 Mdot
.976 .11479 Mdot
.976 .1148 Mdot
.976 .11499 Mdot
.976 .11555 Mdot
.976 .11657 Mdot
.976 .11713 Mdot
.976 .11744 Mdot
.976 .11788 Mdot
.976 .11793 Mdot
.976 .11835 Mdot
.976 .11935 Mdot
.976 .11937 Mdot
.976 .11987 Mdot
.976 .12094 Mdot
.976 .12186 Mdot
.976 .12208 Mdot
.976 .12375 Mdot
.976 .12392 Mdot
.976 .12408 Mdot
.976 .1243 Mdot
.976 .12433 Mdot
.976 .12468 Mdot
.976 .12482 Mdot
.976 .12525 Mdot
.976 .12576 Mdot
.976 .12641 Mdot
.976 .12661 Mdot
.976 .12691 Mdot
.976 .12793 Mdot
.976 .12853 Mdot
.976 .12857 Mdot
.976 .12899 Mdot
.976 .13082 Mdot
.976 .13119 Mdot
.976 .13119 Mdot
.976 .13139 Mdot
.976 .13169 Mdot
.976 .13251 Mdot
.976 .13274 Mdot
.976 .13281 Mdot
.976 .13374 Mdot
.976 .13385 Mdot
.976 .13412 Mdot
.976 .13422 Mdot
.976 .13431 Mdot
.976 .13509 Mdot
.976 .1379 Mdot
.976 .13843 Mdot
.976 .13877 Mdot
.976 .14031 Mdot
.976 .14072 Mdot
.976 .14075 Mdot
.976 .1424 Mdot
.976 .14251 Mdot
.976 .14262 Mdot
.976 .14301 Mdot
.976 .14327 Mdot
.976 .14345 Mdot
.976 .14431 Mdot
.976 .14524 Mdot
.976 .14541 Mdot
.976 .14658 Mdot
.976 .14664 Mdot
.976 .1469 Mdot
.976 .14735 Mdot
.976 .14771 Mdot
.976 .14834 Mdot
.976 .14861 Mdot
.976 .14911 Mdot
.976 .14944 Mdot
.976 .14946 Mdot
.976 .15035 Mdot
.976 .15038 Mdot
.976 .15048 Mdot
.976 .1509 Mdot
.976 .15188 Mdot
.976 .15188 Mdot
.976 .15352 Mdot
.976 .15362 Mdot
.976 .15369 Mdot
.976 .15376 Mdot
.976 .15393 Mdot
.976 .1554 Mdot
.976 .15574 Mdot
.976 .15583 Mdot
.976 .15605 Mdot
.976 .15645 Mdot
.976 .15734 Mdot
.976 .15792 Mdot
.976 .15875 Mdot
.976 .15974 Mdot
.976 .15986 Mdot
.976 .16104 Mdot
.976 .16108 Mdot
.976 .16206 Mdot
.976 .16238 Mdot
.976 .16337 Mdot
.976 .16364 Mdot
.976 .16465 Mdot
.976 .16627 Mdot
.976 .16629 Mdot
.976 .16695 Mdot
.976 .16712 Mdot
.976 .16784 Mdot
.976 .16864 Mdot
.976 .16879 Mdot
.976 .16965 Mdot
.976 .16998 Mdot
.976 .17004 Mdot
.976 .17021 Mdot
.976 .17187 Mdot
.976 .17327 Mdot
.976 .17351 Mdot
.976 .17384 Mdot
.976 .17506 Mdot
.976 .17527 Mdot
.976 .17533 Mdot
.976 .17545 Mdot
.976 .17557 Mdot
.976 .17564 Mdot
.976 .17564 Mdot
.976 .17578 Mdot
.976 .17669 Mdot
.976 .17679 Mdot
.976 .17735 Mdot
.976 .17845 Mdot
.976 .17988 Mdot
.976 .1806 Mdot
.976 .18128 Mdot
.976 .18156 Mdot
.976 .18185 Mdot
.976 .18192 Mdot
.976 .18203 Mdot
.976 .18337 Mdot
.976 .18393 Mdot
.976 .18419 Mdot
.976 .18525 Mdot
.976 .18702 Mdot
.976 .18751 Mdot
.976 .18869 Mdot
.976 .19243 Mdot
.976 .19245 Mdot
.976 .19265 Mdot
.976 .19365 Mdot
.976 .19481 Mdot
.976 .19489 Mdot
.976 .19496 Mdot
.976 .19505 Mdot
.976 .19509 Mdot
.976 .19666 Mdot
.976 .19676 Mdot
.976 .19746 Mdot
.976 .19753 Mdot
.976 .19756 Mdot
.976 .19852 Mdot
.976 .19875 Mdot
.976 .19927 Mdot
.976 .20155 Mdot
.976 .20262 Mdot
.976 .20323 Mdot
.976 .20377 Mdot
.976 .20425 Mdot
.976 .20428 Mdot
.976 .20459 Mdot
.976 .20486 Mdot
.976 .2052 Mdot
.976 .20597 Mdot
.976 .20614 Mdot
.976 .20663 Mdot
.976 .20694 Mdot
.976 .20833 Mdot
.976 .20834 Mdot
.976 .20837 Mdot
.976 .2099 Mdot
.976 .21006 Mdot
.976 .21007 Mdot
.976 .21045 Mdot
.976 .21154 Mdot
.976 .21352 Mdot
.976 .21353 Mdot
.976 .21415 Mdot
.976 .21463 Mdot
.976 .21523 Mdot
.976 .21581 Mdot
.976 .21593 Mdot
.976 .21609 Mdot
.976 .21618 Mdot
.976 .217 Mdot
.976 .21837 Mdot
.976 .21897 Mdot
.976 .219 Mdot
.976 .21964 Mdot
.976 .21997 Mdot
.976 .22159 Mdot
.976 .22206 Mdot
.976 .22386 Mdot
.976 .2243 Mdot
.976 .22441 Mdot
.976 .22517 Mdot
.976 .22541 Mdot
.976 .2258 Mdot
.976 .22626 Mdot
.976 .22754 Mdot
.976 .2276 Mdot
.976 .22788 Mdot
.976 .2282 Mdot
.976 .22863 Mdot
.976 .22867 Mdot
.976 .22937 Mdot
.976 .22963 Mdot
.976 .22997 Mdot
.976 .23048 Mdot
.976 .23148 Mdot
.976 .23273 Mdot
.976 .23314 Mdot
.976 .23371 Mdot
.976 .23445 Mdot
.976 .23571 Mdot
.976 .23612 Mdot
.976 .23654 Mdot
.976 .23656 Mdot
.976 .23688 Mdot
.976 .23695 Mdot
.976 .23778 Mdot
.976 .23855 Mdot
.976 .23944 Mdot
.976 .24035 Mdot
.976 .24134 Mdot
.976 .24183 Mdot
.976 .24183 Mdot
.976 .24207 Mdot
.976 .24208 Mdot
.976 .24247 Mdot
.976 .24304 Mdot
.976 .24358 Mdot
.976 .24466 Mdot
.976 .2451 Mdot
.976 .24523 Mdot
.976 .24546 Mdot
.976 .24705 Mdot
.976 .24726 Mdot
.976 .24779 Mdot
.976 .24799 Mdot
.976 .24816 Mdot
.976 .24848 Mdot
.976 .24869 Mdot
.976 .24968 Mdot
.976 .24976 Mdot
.976 .2509 Mdot
.976 .251 Mdot
.976 .25263 Mdot
.976 .25279 Mdot
.976 .25487 Mdot
.976 .25546 Mdot
.976 .25621 Mdot
.976 .25645 Mdot
.976 .25687 Mdot
.976 .25772 Mdot
.976 .25853 Mdot
.976 .25966 Mdot
.976 .25967 Mdot
.976 .25987 Mdot
.976 .26068 Mdot
.976 .26073 Mdot
.976 .26205 Mdot
.976 .26347 Mdot
.976 .26395 Mdot
.976 .26417 Mdot
.976 .26438 Mdot
.976 .26514 Mdot
.976 .26566 Mdot
.976 .266 Mdot
.976 .26696 Mdot
.976 .26718 Mdot
.976 .26769 Mdot
.976 .26827 Mdot
.976 .26914 Mdot
.976 .26951 Mdot
.976 .26982 Mdot
.976 .26983 Mdot
.976 .27199 Mdot
.976 .27212 Mdot
.976 .27223 Mdot
.976 .27273 Mdot
.976 .27362 Mdot
.976 .27433 Mdot
.976 .27481 Mdot
.976 .27555 Mdot
.976 .27608 Mdot
.976 .27704 Mdot
.976 .27771 Mdot
.976 .27774 Mdot
.976 .27947 Mdot
.976 .27954 Mdot
.976 .27961 Mdot
.976 .27973 Mdot
.976 .28011 Mdot
.976 .28054 Mdot
.976 .28061 Mdot
.976 .28113 Mdot
.976 .28116 Mdot
.976 .28201 Mdot
.976 .28247 Mdot
.976 .28247 Mdot
.976 .28276 Mdot
.976 .28284 Mdot
.976 .28407 Mdot
.976 .28433 Mdot
.976 .28485 Mdot
.976 .28565 Mdot
.976 .28586 Mdot
.976 .286 Mdot
.976 .28612 Mdot
.976 .28645 Mdot
.976 .28749 Mdot
.976 .28749 Mdot
.976 .28805 Mdot
.976 .28812 Mdot
.976 .28815 Mdot
.976 .28853 Mdot
.976 .28932 Mdot
.976 .29 Mdot
.976 .29018 Mdot
.976 .29044 Mdot
.976 .2906 Mdot
.976 .29139 Mdot
.976 .2924 Mdot
.976 .29265 Mdot
.976 .29312 Mdot
.976 .2938 Mdot
.976 .29424 Mdot
.976 .29587 Mdot
.976 .29608 Mdot
.976 .29622 Mdot
.976 .2966 Mdot
.976 .29728 Mdot
.976 .29779 Mdot
.976 .29804 Mdot
.976 .29896 Mdot
.976 .30034 Mdot
.976 .30042 Mdot
.976 .30107 Mdot
.976 .30233 Mdot
.976 .30238 Mdot
.976 .30238 Mdot
.976 .30293 Mdot
.976 .30294 Mdot
.976 .30296 Mdot
.976 .30385 Mdot
.976 .30388 Mdot
.976 .30455 Mdot
.976 .30489 Mdot
.976 .30516 Mdot
.976 .30537 Mdot
.976 .30541 Mdot
.976 .30739 Mdot
.976 .30755 Mdot
.976 .30957 Mdot
.976 .30959 Mdot
.976 .30993 Mdot
.976 .31055 Mdot
.976 .31058 Mdot
.976 .31187 Mdot
.976 .31221 Mdot
.976 .31361 Mdot
.976 .3137 Mdot
.976 .3143 Mdot
.976 .31518 Mdot
.976 .31537 Mdot
.976 .31548 Mdot
.976 .31588 Mdot
.976 .31625 Mdot
.976 .31675 Mdot
.976 .31715 Mdot
.976 .31779 Mdot
.976 .31792 Mdot
.976 .31824 Mdot
.976 .3196 Mdot
.976 .32009 Mdot
.976 .32149 Mdot
.976 .32281 Mdot
.976 .32361 Mdot
.976 .32421 Mdot
.976 .32453 Mdot
.976 .32468 Mdot
.976 .32533 Mdot
.976 .32562 Mdot
.976 .32608 Mdot
.976 .3264 Mdot
.976 .32703 Mdot
.976 .32759 Mdot
.976 .3277 Mdot
.976 .32813 Mdot
.976 .32823 Mdot
.976 .32828 Mdot
.976 .32846 Mdot
.976 .32851 Mdot
.976 .32864 Mdot
.976 .32871 Mdot
.976 .32884 Mdot
.976 .32884 Mdot
.976 .32907 Mdot
.976 .32911 Mdot
.976 .32957 Mdot
.976 .33089 Mdot
.976 .33109 Mdot
.976 .33153 Mdot
.976 .33203 Mdot
.976 .33217 Mdot
.976 .33219 Mdot
.976 .33283 Mdot
.976 .33315 Mdot
.976 .33432 Mdot
.976 .33713 Mdot
.976 .33748 Mdot
.976 .33786 Mdot
.976 .33852 Mdot
.976 .33971 Mdot
.976 .33976 Mdot
.976 .33984 Mdot
.976 .34039 Mdot
.976 .34097 Mdot
.976 .3411 Mdot
.976 .34131 Mdot
.976 .34391 Mdot
.976 .34394 Mdot
.976 .34407 Mdot
.976 .34441 Mdot
.976 .34465 Mdot
.976 .3447 Mdot
.976 .34502 Mdot
.976 .34554 Mdot
.976 .34749 Mdot
.976 .34759 Mdot
.976 .35106 Mdot
.976 .35201 Mdot
.976 .35261 Mdot
.976 .35337 Mdot
.976 .35431 Mdot
.976 .35488 Mdot
.976 .3577 Mdot
.976 .35837 Mdot
.976 .35863 Mdot
.976 .35971 Mdot
.976 .36023 Mdot
.976 .36084 Mdot
.976 .36162 Mdot
.976 .36166 Mdot
.976 .36167 Mdot
.976 .36205 Mdot
.976 .36286 Mdot
.976 .36325 Mdot
.976 .36349 Mdot
.976 .364 Mdot
.976 .36625 Mdot
.976 .36643 Mdot
.976 .36654 Mdot
.976 .36655 Mdot
.976 .36673 Mdot
.976 .3668 Mdot
.976 .3687 Mdot
.976 .36987 Mdot
.976 .37007 Mdot
.976 .37086 Mdot
.976 .37089 Mdot
.976 .37143 Mdot
.976 .37156 Mdot
.976 .37162 Mdot
.976 .37166 Mdot
.976 .3735 Mdot
.976 .37395 Mdot
.976 .37474 Mdot
.976 .37495 Mdot
.976 .37496 Mdot
.976 .37625 Mdot
.976 .37811 Mdot
.976 .37942 Mdot
.976 .37995 Mdot
.976 .3815 Mdot
.976 .38159 Mdot
.976 .38269 Mdot
.976 .38376 Mdot
.976 .38469 Mdot
.976 .38475 Mdot
.976 .38536 Mdot
.976 .38538 Mdot
.976 .38588 Mdot
.976 .38655 Mdot
.976 .38669 Mdot
.976 .38721 Mdot
.976 .38804 Mdot
.976 .38804 Mdot
.976 .38838 Mdot
.976 .38884 Mdot
.976 .38933 Mdot
.976 .38994 Mdot
.976 .38997 Mdot
.976 .39174 Mdot
.976 .39254 Mdot
.976 .39265 Mdot
.976 .39268 Mdot
.976 .39274 Mdot
.976 .39284 Mdot
.976 .39371 Mdot
.976 .39501 Mdot
.976 .39572 Mdot
.976 .39602 Mdot
.976 .39605 Mdot
.976 .3968 Mdot
.976 .39776 Mdot
.976 .39867 Mdot
.976 .39892 Mdot
.976 .39952 Mdot
.976 .40145 Mdot
.976 .40207 Mdot
.976 .40278 Mdot
.976 .4028 Mdot
.976 .40361 Mdot
.976 .40366 Mdot
.976 .40401 Mdot
.976 .40468 Mdot
.976 .40494 Mdot
.976 .40611 Mdot
.976 .40697 Mdot
.976 .40725 Mdot
.976 .40749 Mdot
.976 .40751 Mdot
.976 .40781 Mdot
.976 .40798 Mdot
.976 .40838 Mdot
.976 .40958 Mdot
.976 .40959 Mdot
.976 .40961 Mdot
.976 .41224 Mdot
.976 .41257 Mdot
.976 .41342 Mdot
.976 .41348 Mdot
.976 .41473 Mdot
.976 .41538 Mdot
.976 .41638 Mdot
.976 .41782 Mdot
.976 .41821 Mdot
.976 .41833 Mdot
.976 .41853 Mdot
.976 .41877 Mdot
.976 .41945 Mdot
.976 .42067 Mdot
.976 .42297 Mdot
.976 .42382 Mdot
.976 .42404 Mdot
.976 .42405 Mdot
.976 .42507 Mdot
.976 .42552 Mdot
.976 .42599 Mdot
.976 .42675 Mdot
.976 .42675 Mdot
.976 .42764 Mdot
.976 .42861 Mdot
.976 .43015 Mdot
.976 .43026 Mdot
.976 .43081 Mdot
.976 .43139 Mdot
.976 .43144 Mdot
.976 .43228 Mdot
.976 .43236 Mdot
.976 .43343 Mdot
.976 .43373 Mdot
.976 .43424 Mdot
.976 .43489 Mdot
.976 .4353 Mdot
.976 .43588 Mdot
.976 .43588 Mdot
.976 .4371 Mdot
.976 .43783 Mdot
.976 .43962 Mdot
.976 .43973 Mdot
.976 .44029 Mdot
.976 .44074 Mdot
.976 .44109 Mdot
.976 .44219 Mdot
.976 .44364 Mdot
.976 .4461 Mdot
.976 .44636 Mdot
.976 .44661 Mdot
.976 .44688 Mdot
.976 .44689 Mdot
.976 .44733 Mdot
.976 .44771 Mdot
.976 .44776 Mdot
.976 .44839 Mdot
.976 .44852 Mdot
.976 .44878 Mdot
.976 .45014 Mdot
.976 .45014 Mdot
.976 .45042 Mdot
.976 .45046 Mdot
.976 .45048 Mdot
.976 .45067 Mdot
.976 .45165 Mdot
.976 .45265 Mdot
.976 .45278 Mdot
.976 .45337 Mdot
.976 .45454 Mdot
.976 .45461 Mdot
.976 .45481 Mdot
.976 .45515 Mdot
.976 .45602 Mdot
.976 .45709 Mdot
.976 .45776 Mdot
.976 .45777 Mdot
.976 .45804 Mdot
.976 .45805 Mdot
.976 .45852 Mdot
.976 .45853 Mdot
.976 .45887 Mdot
.976 .45919 Mdot
.976 .4593 Mdot
.976 .46042 Mdot
.976 .46145 Mdot
.976 .46146 Mdot
.976 .46163 Mdot
.976 .46357 Mdot
.976 .46387 Mdot
.976 .46442 Mdot
.976 .46468 Mdot
.976 .46487 Mdot
.976 .46513 Mdot
.976 .46659 Mdot
.976 .46684 Mdot
.976 .46823 Mdot
.976 .46864 Mdot
.976 .46911 Mdot
.976 .46967 Mdot
.976 .46991 Mdot
.976 .47007 Mdot
.976 .47039 Mdot
.976 .47068 Mdot
.976 .47103 Mdot
.976 .47115 Mdot
.976 .47122 Mdot
.976 .47144 Mdot
.976 .4717 Mdot
.976 .4727 Mdot
.976 .47296 Mdot
.976 .47304 Mdot
.976 .47336 Mdot
.976 .47353 Mdot
.976 .47575 Mdot
.976 .47594 Mdot
.976 .47689 Mdot
.976 .47692 Mdot
.976 .47904 Mdot
.976 .47912 Mdot
.976 .4793 Mdot
.976 .47942 Mdot
.976 .47944 Mdot
.976 .48087 Mdot
.976 .4835 Mdot
.976 .48389 Mdot
.976 .48466 Mdot
.976 .48611 Mdot
.976 .48645 Mdot
.976 .48658 Mdot
.976 .48714 Mdot
.976 .4874 Mdot
.976 .48772 Mdot
.976 .48814 Mdot
.976 .48875 Mdot
.976 .48895 Mdot
.976 .48907 Mdot
.976 .49063 Mdot
.976 .49174 Mdot
.976 .49285 Mdot
.976 .49286 Mdot
.976 .49326 Mdot
.976 .49483 Mdot
.976 .49494 Mdot
.976 .49561 Mdot
.976 .49656 Mdot
.976 .4975 Mdot
.976 .49835 Mdot
.976 .50028 Mdot
.976 .50096 Mdot
.976 .50122 Mdot
.976 .50165 Mdot
.976 .50206 Mdot
.976 .50264 Mdot
.976 .50355 Mdot
.976 .50395 Mdot
.976 .50411 Mdot
.976 .50455 Mdot
.976 .50522 Mdot
.976 .50663 Mdot
.976 .50709 Mdot
.976 .50753 Mdot
.976 .50852 Mdot
.976 .50883 Mdot
.976 .50962 Mdot
.976 .50965 Mdot
.976 .51017 Mdot
.976 .51135 Mdot
.976 .51162 Mdot
.976 .51207 Mdot
.976 .51269 Mdot
.976 .5127 Mdot
.976 .51421 Mdot
.976 .51617 Mdot
.976 .51691 Mdot
.976 .5171 Mdot
.976 .51717 Mdot
.976 .51739 Mdot
.976 .51836 Mdot
.976 .52009 Mdot
.976 .52062 Mdot
.976 .52148 Mdot
.976 .52243 Mdot
.976 .52386 Mdot
.976 .5249 Mdot
.976 .52586 Mdot
.976 .52616 Mdot
.976 .52678 Mdot
.976 .52807 Mdot
.976 .52813 Mdot
.976 .52864 Mdot
.976 .53152 Mdot
.976 .53165 Mdot
.976 .53179 Mdot
.976 .53202 Mdot
.976 .53277 Mdot
.976 .53346 Mdot
.976 .53361 Mdot
.976 .53363 Mdot
.976 .53363 Mdot
.976 .53373 Mdot
.976 .53475 Mdot
.976 .53482 Mdot
.976 .53571 Mdot
.976 .53575 Mdot
.976 .53585 Mdot
.976 .53647 Mdot
.976 .53737 Mdot
.976 .53737 Mdot
.976 .53794 Mdot
.976 .5381 Mdot
.976 .53926 Mdot
.976 .53935 Mdot
.976 .5405 Mdot
.976 .54101 Mdot
.976 .54189 Mdot
.976 .54202 Mdot
.976 .54318 Mdot
.976 .54359 Mdot
.976 .54399 Mdot
.976 .54423 Mdot
.976 .54426 Mdot
.976 .54451 Mdot
.976 .54502 Mdot
.976 .54515 Mdot
.976 .54519 Mdot
.976 .54717 Mdot
.976 .54718 Mdot
.976 .54827 Mdot
.976 .5484 Mdot
.976 .54846 Mdot
.976 .54921 Mdot
.976 .55075 Mdot
.976 .55206 Mdot
.976 .55241 Mdot
.976 .55271 Mdot
.976 .55293 Mdot
.976 .55324 Mdot
.976 .55334 Mdot
.976 .55477 Mdot
.976 .55676 Mdot
.976 .55724 Mdot
.976 .55816 Mdot
.976 .5595 Mdot
.976 .56036 Mdot
.976 .56103 Mdot
.976 .56111 Mdot
.976 .5624 Mdot
.976 .56353 Mdot
.976 .56394 Mdot
.976 .56422 Mdot
.976 .56496 Mdot
.976 .56629 Mdot
.976 .56729 Mdot
.976 .56777 Mdot
.976 .56957 Mdot
.976 .57225 Mdot
.976 .57241 Mdot
.976 .57368 Mdot
.976 .57615 Mdot
.976 .57623 Mdot
.976 .57624 Mdot
.976 .5773 Mdot
.976 .57732 Mdot
.976 .57737 Mdot
.976 .57912 Mdot
.976 .57916 Mdot
.976 .58046 Mdot
.976 .58113 Mdot
.976 .58166 Mdot
.976 .58207 Mdot
.976 .58216 Mdot
.976 .58601 Mdot
.976 .58633 Mdot
.976 .59027 Mdot
.976 .59031 Mdot
.976 .59097 Mdot
.978 .01549 Mdot
.978 .01613 Mdot
.978 .01624 Mdot
.978 .01749 Mdot
.978 .01769 Mdot
.978 .0177 Mdot
.978 .01875 Mdot
.978 .02013 Mdot
.978 .02054 Mdot
.978 .02055 Mdot
.978 .02057 Mdot
.978 .02069 Mdot
.978 .02261 Mdot
.978 .02302 Mdot
.978 .02501 Mdot
.978 .02532 Mdot
.978 .02611 Mdot
.978 .02612 Mdot
.978 .02617 Mdot
.978 .02639 Mdot
.978 .02735 Mdot
.978 .03001 Mdot
.978 .03016 Mdot
.978 .03072 Mdot
.978 .03095 Mdot
.978 .03343 Mdot
.978 .03347 Mdot
.978 .03382 Mdot
.978 .03468 Mdot
.978 .03485 Mdot
.978 .03545 Mdot
.978 .037 Mdot
.978 .03702 Mdot
.978 .03713 Mdot
.978 .03726 Mdot
.978 .03756 Mdot
.978 .03819 Mdot
.978 .03944 Mdot
.978 .04015 Mdot
.978 .04025 Mdot
.978 .04043 Mdot
.978 .04198 Mdot
.978 .04336 Mdot
.978 .04347 Mdot
.978 .044 Mdot
.978 .04406 Mdot
.978 .04463 Mdot
.978 .04492 Mdot
.978 .0451 Mdot
.978 .04577 Mdot
.978 .04602 Mdot
.978 .04647 Mdot
.978 .0471 Mdot
.978 .04728 Mdot
.978 .04794 Mdot
.978 .04862 Mdot
.978 .04867 Mdot
.978 .05132 Mdot
.978 .0514 Mdot
.978 .05188 Mdot
.978 .05207 Mdot
.978 .05377 Mdot
.978 .05411 Mdot
.978 .05443 Mdot
.978 .05527 Mdot
.978 .05644 Mdot
.978 .05805 Mdot
.978 .0583 Mdot
.978 .05835 Mdot
.978 .05856 Mdot
.978 .05881 Mdot
.978 .05887 Mdot
.978 .0594 Mdot
.978 .05982 Mdot
.978 .05989 Mdot
.978 .06062 Mdot
.978 .06307 Mdot
.978 .06379 Mdot
.978 .06446 Mdot
.978 .06466 Mdot
.978 .06501 Mdot
.978 .06675 Mdot
.978 .0671 Mdot
.978 .06805 Mdot
.978 .06815 Mdot
.978 .06827 Mdot
.978 .06945 Mdot
.978 .07073 Mdot
.978 .07075 Mdot
.978 .07097 Mdot
.978 .07196 Mdot
.978 .072 Mdot
.978 .07211 Mdot
.978 .07323 Mdot
.978 .0738 Mdot
.978 .07415 Mdot
.978 .07433 Mdot
.978 .07512 Mdot
.978 .07545 Mdot
.978 .07549 Mdot
.978 .07551 Mdot
.978 .07594 Mdot
.978 .07683 Mdot
.978 .07805 Mdot
.978 .07815 Mdot
.978 .07842 Mdot
.978 .07897 Mdot
.978 .07913 Mdot
.978 .07935 Mdot
.978 .07971 Mdot
.978 .08103 Mdot
.978 .08112 Mdot
.978 .08176 Mdot
.978 .08179 Mdot
.978 .08197 Mdot
.978 .08276 Mdot
.978 .08349 Mdot
.978 .08527 Mdot
.978 .08632 Mdot
.978 .08647 Mdot
.978 .08713 Mdot
.978 .08716 Mdot
.978 .08741 Mdot
.978 .08779 Mdot
.978 .08819 Mdot
.978 .08842 Mdot
.978 .08939 Mdot
.978 .0904 Mdot
.978 .09077 Mdot
.978 .0911 Mdot
.978 .09157 Mdot
.978 .09177 Mdot
.978 .0924 Mdot
.978 .09254 Mdot
.978 .0928 Mdot
.978 .09404 Mdot
.978 .09543 Mdot
.978 .09564 Mdot
.978 .09583 Mdot
.978 .09633 Mdot
.978 .09654 Mdot
.978 .09757 Mdot
.978 .09803 Mdot
.978 .09914 Mdot
.978 .09931 Mdot
.978 .09948 Mdot
.978 .09996 Mdot
.978 .10007 Mdot
.978 .10048 Mdot
.978 .10058 Mdot
.978 .10096 Mdot
.978 .10109 Mdot
.978 .10211 Mdot
.978 .10243 Mdot
.978 .10281 Mdot
.978 .10293 Mdot
.978 .10307 Mdot
.978 .10328 Mdot
.978 .10403 Mdot
.978 .10427 Mdot
.978 .10451 Mdot
.978 .1046 Mdot
.978 .10474 Mdot
.978 .10655 Mdot
.978 .10715 Mdot
.978 .10784 Mdot
.978 .10831 Mdot
.978 .10834 Mdot
.978 .10904 Mdot
.978 .1093 Mdot
.978 .11003 Mdot
.978 .11065 Mdot
.978 .11071 Mdot
.978 .11201 Mdot
.978 .1124 Mdot
.978 .11287 Mdot
.978 .11309 Mdot
.978 .11374 Mdot
.978 .1142 Mdot
.978 .11545 Mdot
.978 .11649 Mdot
.978 .11717 Mdot
.978 .11824 Mdot
.978 .11853 Mdot
.978 .11904 Mdot
.978 .11923 Mdot
.978 .11947 Mdot
.978 .12141 Mdot
.978 .12177 Mdot
.978 .12361 Mdot
.978 .12428 Mdot
.978 .12429 Mdot
.978 .12432 Mdot
.978 .12437 Mdot
.978 .12474 Mdot
.978 .12574 Mdot
.978 .12669 Mdot
.978 .12676 Mdot
.978 .12697 Mdot
.978 .12698 Mdot
.978 .12807 Mdot
.978 .12895 Mdot
.978 .12917 Mdot
.978 .12952 Mdot
.978 .12967 Mdot
.978 .13028 Mdot
.978 .13097 Mdot
.978 .13131 Mdot
.978 .13208 Mdot
.978 .13287 Mdot
.978 .13325 Mdot
.978 .13351 Mdot
.978 .13359 Mdot
.978 .13363 Mdot
.978 .13447 Mdot
.978 .13621 Mdot
.978 .13676 Mdot
.978 .13702 Mdot
.978 .13756 Mdot
.978 .1386 Mdot
.978 .1388 Mdot
.978 .139 Mdot
.978 .13931 Mdot
.978 .14039 Mdot
.978 .1404 Mdot
.978 .14072 Mdot
.978 .14113 Mdot
.978 .14166 Mdot
.978 .14185 Mdot
.978 .14226 Mdot
.978 .14419 Mdot
.978 .14443 Mdot
.978 .14461 Mdot
.978 .14469 Mdot
.978 .14488 Mdot
.978 .14586 Mdot
.978 .14592 Mdot
.978 .14626 Mdot
.978 .14659 Mdot
.978 .14743 Mdot
.978 .14781 Mdot
.978 .14796 Mdot
.978 .14828 Mdot
.978 .14924 Mdot
.978 .14953 Mdot
.978 .14969 Mdot
.978 .14978 Mdot
.978 .15012 Mdot
.978 .15132 Mdot
.978 .15271 Mdot
.978 .15354 Mdot
.978 .15428 Mdot
.978 .15471 Mdot
.978 .15477 Mdot
.978 .15506 Mdot
.978 .15559 Mdot
.978 .15636 Mdot
.978 .15643 Mdot
.978 .1569 Mdot
.978 .15716 Mdot
.978 .15765 Mdot
.978 .15801 Mdot
.978 .15842 Mdot
.978 .15888 Mdot
.978 .15997 Mdot
.978 .16078 Mdot
.978 .16275 Mdot
.978 .1633 Mdot
.978 .16337 Mdot
.978 .16348 Mdot
.978 .16371 Mdot
.978 .16413 Mdot
.978 .16441 Mdot
.978 .16448 Mdot
.978 .16505 Mdot
.978 .16543 Mdot
.978 .16608 Mdot
.978 .16666 Mdot
.978 .16694 Mdot
.978 .16741 Mdot
.978 .16744 Mdot
.978 .16857 Mdot
.978 .16918 Mdot
.978 .16988 Mdot
.978 .17006 Mdot
.978 .17077 Mdot
.978 .17078 Mdot
.978 .17087 Mdot
.978 .17177 Mdot
.978 .17202 Mdot
.978 .17255 Mdot
.978 .1726 Mdot
.978 .17301 Mdot
.978 .17337 Mdot
.978 .17434 Mdot
.978 .17457 Mdot
.978 .17476 Mdot
.978 .17679 Mdot
.978 .17742 Mdot
.978 .17767 Mdot
.978 .17985 Mdot
.978 .18019 Mdot
.978 .18052 Mdot
.978 .18084 Mdot
.978 .18146 Mdot
.978 .18167 Mdot
.978 .18246 Mdot
.978 .18267 Mdot
.978 .18341 Mdot
.978 .18346 Mdot
.978 .18367 Mdot
.978 .18481 Mdot
.978 .18508 Mdot
.978 .18566 Mdot
.978 .18622 Mdot
.978 .18629 Mdot
.978 .18703 Mdot
.978 .18727 Mdot
.978 .18754 Mdot
.978 .18766 Mdot
.978 .18795 Mdot
.978 .18799 Mdot
.978 .18941 Mdot
.978 .18988 Mdot
.978 .19022 Mdot
.978 .19035 Mdot
.978 .19054 Mdot
.978 .1908 Mdot
.978 .19434 Mdot
.978 .19452 Mdot
.978 .19522 Mdot
.978 .19551 Mdot
.978 .19589 Mdot
.978 .19686 Mdot
.978 .19778 Mdot
.978 .19785 Mdot
.978 .19799 Mdot
.978 .19922 Mdot
.978 .19972 Mdot
.978 .20035 Mdot
.978 .20079 Mdot
.978 .20116 Mdot
.978 .20217 Mdot
.978 .20236 Mdot
.978 .20247 Mdot
.978 .20311 Mdot
.978 .20385 Mdot
.978 .20482 Mdot
.978 .20502 Mdot
.978 .20579 Mdot
.978 .20626 Mdot
.978 .20649 Mdot
.978 .2067 Mdot
.978 .20693 Mdot
.978 .20714 Mdot
.978 .20766 Mdot
.978 .20841 Mdot
.978 .2093 Mdot
.978 .21041 Mdot
.978 .21071 Mdot
.978 .21108 Mdot
.978 .21175 Mdot
.978 .21323 Mdot
.978 .21378 Mdot
.978 .21452 Mdot
.978 .21512 Mdot
.978 .21594 Mdot
.978 .21711 Mdot
.978 .21721 Mdot
.978 .21777 Mdot
.978 .21848 Mdot
.978 .21878 Mdot
.978 .21914 Mdot
.978 .21944 Mdot
.978 .21952 Mdot
.978 .21961 Mdot
.978 .21964 Mdot
.978 .21992 Mdot
.978 .21995 Mdot
.978 .22029 Mdot
.978 .22041 Mdot
.978 .22145 Mdot
.978 .22159 Mdot
.978 .22182 Mdot
.978 .22287 Mdot
.978 .22334 Mdot
.978 .2234 Mdot
.978 .22412 Mdot
.978 .22482 Mdot
.978 .22564 Mdot
.978 .22731 Mdot
.978 .22772 Mdot
.978 .22784 Mdot
.978 .22873 Mdot
.978 .22902 Mdot
.978 .22905 Mdot
.978 .22911 Mdot
.978 .22921 Mdot
.978 .22993 Mdot
.978 .2306 Mdot
.978 .23187 Mdot
.978 .23274 Mdot
.978 .23374 Mdot
.978 .23388 Mdot
.978 .23429 Mdot
.978 .2343 Mdot
.978 .23454 Mdot
.978 .23479 Mdot
.978 .23543 Mdot
.978 .23644 Mdot
.978 .23752 Mdot
.978 .23816 Mdot
.978 .23859 Mdot
.978 .23927 Mdot
.978 .23958 Mdot
.978 .24021 Mdot
.978 .24077 Mdot
.978 .24211 Mdot
.978 .24278 Mdot
.978 .24335 Mdot
.978 .24427 Mdot
.978 .24583 Mdot
.978 .24656 Mdot
.978 .24709 Mdot
.978 .24722 Mdot
.978 .24731 Mdot
.978 .24752 Mdot
.978 .2477 Mdot
.978 .24813 Mdot
.978 .24896 Mdot
.978 .2492 Mdot
.978 .24972 Mdot
.978 .25129 Mdot
.978 .25129 Mdot
.978 .25177 Mdot
.978 .25213 Mdot
.978 .25235 Mdot
.978 .25333 Mdot
.978 .25343 Mdot
.978 .25395 Mdot
.978 .255 Mdot
.978 .2551 Mdot
.978 .25518 Mdot
.978 .25552 Mdot
.978 .25628 Mdot
.978 .2564 Mdot
.978 .25663 Mdot
.978 .257 Mdot
.978 .25704 Mdot
.978 .25742 Mdot
.978 .25782 Mdot
.978 .25843 Mdot
.978 .25977 Mdot
.978 .26013 Mdot
.978 .26053 Mdot
.978 .26056 Mdot
.978 .26118 Mdot
.978 .26126 Mdot
.978 .26199 Mdot
.978 .26231 Mdot
.978 .26302 Mdot
.978 .26339 Mdot
.978 .26372 Mdot
.978 .26402 Mdot
.978 .26418 Mdot
.978 .26719 Mdot
.978 .26797 Mdot
.978 .26844 Mdot
.978 .26879 Mdot
.978 .26895 Mdot
.978 .26931 Mdot
.978 .27052 Mdot
.978 .27084 Mdot
.978 .27124 Mdot
.978 .27135 Mdot
.978 .27201 Mdot
.978 .27266 Mdot
.978 .27427 Mdot
.978 .2743 Mdot
.978 .27436 Mdot
.978 .2745 Mdot
.978 .27489 Mdot
.978 .27505 Mdot
.978 .27534 Mdot
.978 .27596 Mdot
.978 .27611 Mdot
.978 .27644 Mdot
.978 .27648 Mdot
.978 .27739 Mdot
.978 .27785 Mdot
.978 .27809 Mdot
.978 .27836 Mdot
.978 .27842 Mdot
.978 .27856 Mdot
.978 .27873 Mdot
.978 .27891 Mdot
.978 .27956 Mdot
.978 .27963 Mdot
.978 .2808 Mdot
.978 .28084 Mdot
.978 .28191 Mdot
.978 .28221 Mdot
.978 .28464 Mdot
.978 .28468 Mdot
.978 .28625 Mdot
.978 .28633 Mdot
.978 .28709 Mdot
.978 .28762 Mdot
.978 .28771 Mdot
.978 .28854 Mdot
.978 .28867 Mdot
.978 .28879 Mdot
.978 .28923 Mdot
.978 .29026 Mdot
.978 .29126 Mdot
.978 .29178 Mdot
.978 .2919 Mdot
.978 .29283 Mdot
.978 .2929 Mdot
.978 .29334 Mdot
.978 .2943 Mdot
.978 .29501 Mdot
.978 .29548 Mdot
.978 .29581 Mdot
.978 .29633 Mdot
.978 .29664 Mdot
.978 .29667 Mdot
.978 .2967 Mdot
.978 .29884 Mdot
.978 .2991 Mdot
.978 .30042 Mdot
.978 .30123 Mdot
.978 .30426 Mdot
.978 .30469 Mdot
.978 .30534 Mdot
.978 .30548 Mdot
.978 .30571 Mdot
.978 .30614 Mdot
.978 .30635 Mdot
.978 .30689 Mdot
.978 .30697 Mdot
.978 .30751 Mdot
.978 .30765 Mdot
.978 .30877 Mdot
.978 .30893 Mdot
.978 .30952 Mdot
.978 .31079 Mdot
.978 .31112 Mdot
.978 .31192 Mdot
.978 .31246 Mdot
.978 .31339 Mdot
.978 .31345 Mdot
.978 .31464 Mdot
.978 .31566 Mdot
.978 .31686 Mdot
.978 .31822 Mdot
.978 .31858 Mdot
.978 .31996 Mdot
.978 .31998 Mdot
.978 .32016 Mdot
.978 .3206 Mdot
.978 .32192 Mdot
.978 .3224 Mdot
.978 .3234 Mdot
.978 .32345 Mdot
.978 .32354 Mdot
.978 .32434 Mdot
.978 .32504 Mdot
.978 .3251 Mdot
.978 .32537 Mdot
.978 .3254 Mdot
.978 .32593 Mdot
.978 .32627 Mdot
.978 .32695 Mdot
.978 .32705 Mdot
.978 .32738 Mdot
.978 .32773 Mdot
.978 .32775 Mdot
.978 .3294 Mdot
.978 .3307 Mdot
.978 .33173 Mdot
.978 .33255 Mdot
.978 .33297 Mdot
.978 .33345 Mdot
.978 .33349 Mdot
.978 .33549 Mdot
.978 .337 Mdot
.978 .33718 Mdot
.978 .33771 Mdot
.978 .33778 Mdot
.978 .33838 Mdot
.978 .33903 Mdot
.978 .33966 Mdot
.978 .34087 Mdot
.978 .34128 Mdot
.978 .34147 Mdot
.978 .34148 Mdot
.978 .34283 Mdot
.978 .34324 Mdot
.978 .34333 Mdot
.978 .34344 Mdot
.978 .34467 Mdot
.978 .34469 Mdot
.978 .34478 Mdot
.978 .34518 Mdot
.978 .34556 Mdot
.978 .34647 Mdot
.978 .34742 Mdot
.978 .34744 Mdot
.978 .34796 Mdot
.978 .34808 Mdot
.978 .34857 Mdot
.978 .34909 Mdot
.978 .34928 Mdot
.978 .34969 Mdot
.978 .35018 Mdot
.978 .35031 Mdot
.978 .35166 Mdot
.978 .35177 Mdot
.978 .35186 Mdot
.978 .35223 Mdot
.978 .35276 Mdot
.978 .35299 Mdot
.978 .35356 Mdot
.978 .35365 Mdot
.978 .3543 Mdot
.978 .35524 Mdot
.978 .35567 Mdot
.978 .35606 Mdot
.978 .35618 Mdot
.978 .35635 Mdot
.978 .35642 Mdot
.978 .35735 Mdot
.978 .35765 Mdot
.978 .358 Mdot
.978 .35824 Mdot
.978 .35826 Mdot
.978 .35862 Mdot
.978 .35913 Mdot
.978 .35944 Mdot
.978 .36058 Mdot
.978 .36102 Mdot
.978 .36126 Mdot
.978 .3619 Mdot
.978 .36332 Mdot
.978 .36347 Mdot
.978 .36494 Mdot
.978 .36607 Mdot
.978 .36642 Mdot
.978 .36646 Mdot
.978 .36716 Mdot
.978 .36779 Mdot
.978 .36835 Mdot
.978 .3688 Mdot
.978 .36909 Mdot
.978 .36917 Mdot
.978 .3704 Mdot
.978 .371 Mdot
.978 .37279 Mdot
.978 .37293 Mdot
.978 .3732 Mdot
.978 .37394 Mdot
.978 .37465 Mdot
.978 .3753 Mdot
.978 .3756 Mdot
.978 .37659 Mdot
.978 .37685 Mdot
.978 .37694 Mdot
.978 .37782 Mdot
.978 .37824 Mdot
.978 .37852 Mdot
.978 .37868 Mdot
.978 .37932 Mdot
.978 .3794 Mdot
.978 .37945 Mdot
.978 .37962 Mdot
.978 .38023 Mdot
.978 .38137 Mdot
.978 .38175 Mdot
.978 .38197 Mdot
.978 .38242 Mdot
.978 .38322 Mdot
.978 .38366 Mdot
.978 .38466 Mdot
.978 .38636 Mdot
.978 .3864 Mdot
.978 .38657 Mdot
.978 .38693 Mdot
.978 .38696 Mdot
.978 .38778 Mdot
.978 .38846 Mdot
.978 .38906 Mdot
.978 .38937 Mdot
.978 .38982 Mdot
.978 .39018 Mdot
.978 .39019 Mdot
.978 .39023 Mdot
.978 .39069 Mdot
.978 .39082 Mdot
.978 .39109 Mdot
.978 .39212 Mdot
.978 .39358 Mdot
.978 .39533 Mdot
.978 .39667 Mdot
.978 .39736 Mdot
.978 .3975 Mdot
.978 .39808 Mdot
.978 .39881 Mdot
.978 .39898 Mdot
.978 .40012 Mdot
.978 .40232 Mdot
.978 .40268 Mdot
.978 .40302 Mdot
.978 .40409 Mdot
.978 .4053 Mdot
.978 .40553 Mdot
.978 .40623 Mdot
.978 .40671 Mdot
.978 .40709 Mdot
.978 .40759 Mdot
.978 .40832 Mdot
.978 .40844 Mdot
.978 .40867 Mdot
.978 .40904 Mdot
.978 .41045 Mdot
.978 .4106 Mdot
.978 .41079 Mdot
.978 .41189 Mdot
.978 .41254 Mdot
.978 .41327 Mdot
.978 .41387 Mdot
.978 .41457 Mdot
.978 .41492 Mdot
.978 .41506 Mdot
.978 .4151 Mdot
.978 .41517 Mdot
.978 .4153 Mdot
.978 .41532 Mdot
.978 .41549 Mdot
.978 .41556 Mdot
.978 .41609 Mdot
.978 .41616 Mdot
.978 .41628 Mdot
.978 .41681 Mdot
.978 .41705 Mdot
.978 .41781 Mdot
.978 .41823 Mdot
.978 .41908 Mdot
.978 .41936 Mdot
.978 .41981 Mdot
.978 .42077 Mdot
.978 .42186 Mdot
.978 .42278 Mdot
.978 .42291 Mdot
.978 .42323 Mdot
.978 .4243 Mdot
.978 .42568 Mdot
.978 .42729 Mdot
.978 .42942 Mdot
.978 .42951 Mdot
.978 .42973 Mdot
.978 .43028 Mdot
.978 .43054 Mdot
.978 .43134 Mdot
.978 .43134 Mdot
.978 .43159 Mdot
.978 .43177 Mdot
.978 .43239 Mdot
.978 .43329 Mdot
.978 .43333 Mdot
.978 .4335 Mdot
.978 .4339 Mdot
.978 .43396 Mdot
.978 .43407 Mdot
.978 .43426 Mdot
.978 .43568 Mdot
.978 .43586 Mdot
.978 .43644 Mdot
.978 .43698 Mdot
.978 .4377 Mdot
.978 .43785 Mdot
.978 .43947 Mdot
.978 .44118 Mdot
.978 .44134 Mdot
.978 .44309 Mdot
.978 .44314 Mdot
.978 .44321 Mdot
.978 .44341 Mdot
.978 .44403 Mdot
.978 .4442 Mdot
.978 .44422 Mdot
.978 .44469 Mdot
.978 .44505 Mdot
.978 .44518 Mdot
.978 .44529 Mdot
.978 .44583 Mdot
.978 .44643 Mdot
.978 .44645 Mdot
.978 .44715 Mdot
.978 .44841 Mdot
.978 .44926 Mdot
.978 .44965 Mdot
.978 .44992 Mdot
.978 .45052 Mdot
.978 .45178 Mdot
.978 .45262 Mdot
.978 .45394 Mdot
.978 .45437 Mdot
.978 .45453 Mdot
.978 .45454 Mdot
.978 .45579 Mdot
.978 .45688 Mdot
.978 .45865 Mdot
.978 .45949 Mdot
.978 .45977 Mdot
.978 .46081 Mdot
.978 .46193 Mdot
.978 .46373 Mdot
.978 .46678 Mdot
.978 .46821 Mdot
.978 .46908 Mdot
.978 .46922 Mdot
.978 .46923 Mdot
.978 .4695 Mdot
.978 .46968 Mdot
.978 .47007 Mdot
.978 .47042 Mdot
.978 .47128 Mdot
.978 .47194 Mdot
.978 .47289 Mdot
.978 .47337 Mdot
.978 .47439 Mdot
.978 .47516 Mdot
.978 .47525 Mdot
.978 .47556 Mdot
.978 .47745 Mdot
.978 .47745 Mdot
.978 .4784 Mdot
.978 .47846 Mdot
.978 .47909 Mdot
.978 .47954 Mdot
.978 .48 Mdot
.978 .4805 Mdot
.978 .48083 Mdot
.978 .48108 Mdot
.978 .48144 Mdot
.978 .48165 Mdot
.978 .48266 Mdot
.978 .48276 Mdot
.978 .48401 Mdot
.978 .48449 Mdot
.978 .48471 Mdot
.978 .48491 Mdot
.978 .48497 Mdot
.978 .48506 Mdot
.978 .48572 Mdot
.978 .48602 Mdot
.978 .48664 Mdot
.978 .48722 Mdot
.978 .48745 Mdot
.978 .48756 Mdot
.978 .48789 Mdot
.978 .48862 Mdot
.978 .4887 Mdot
.978 .48945 Mdot
.978 .49022 Mdot
.978 .49058 Mdot
.978 .49142 Mdot
.978 .49161 Mdot
.978 .49224 Mdot
.978 .49405 Mdot
.978 .49441 Mdot
.978 .49474 Mdot
.978 .49553 Mdot
.978 .49558 Mdot
.978 .49625 Mdot
.978 .49639 Mdot
.978 .4968 Mdot
.978 .49687 Mdot
.978 .49695 Mdot
.978 .49727 Mdot
.978 .49838 Mdot
.978 .49902 Mdot
.978 .5004 Mdot
.978 .50042 Mdot
.978 .50069 Mdot
.978 .50113 Mdot
.978 .50178 Mdot
.978 .50235 Mdot
.978 .50235 Mdot
.978 .50268 Mdot
.978 .50567 Mdot
.978 .50602 Mdot
.978 .50685 Mdot
.978 .50856 Mdot
.978 .50874 Mdot
.978 .51008 Mdot
.978 .51056 Mdot
.978 .511 Mdot
.978 .51125 Mdot
.978 .51169 Mdot
.978 .5118 Mdot
.978 .51199 Mdot
.978 .51271 Mdot
.978 .51379 Mdot
.978 .515 Mdot
.978 .51507 Mdot
.978 .51509 Mdot
.978 .51521 Mdot
.978 .51569 Mdot
.978 .51648 Mdot
.978 .51669 Mdot
.978 .51799 Mdot
.978 .51925 Mdot
.978 .52241 Mdot
.978 .52246 Mdot
.978 .52257 Mdot
.978 .52285 Mdot
.978 .5234 Mdot
.978 .52362 Mdot
.978 .52393 Mdot
.978 .52439 Mdot
.978 .5245 Mdot
.978 .52571 Mdot
.978 .526 Mdot
.978 .52665 Mdot
.978 .52672 Mdot
.978 .52851 Mdot
.978 .5294 Mdot
.978 .52946 Mdot
.978 .52988 Mdot
.978 .5304 Mdot
.978 .53053 Mdot
.978 .5308 Mdot
.978 .53112 Mdot
.978 .53148 Mdot
.978 .53256 Mdot
.978 .53275 Mdot
.978 .53289 Mdot
.978 .53517 Mdot
.978 .53525 Mdot
.978 .53735 Mdot
.978 .53793 Mdot
.978 .54269 Mdot
.978 .54276 Mdot
.978 .54415 Mdot
.978 .5458 Mdot
.978 .54585 Mdot
.978 .546 Mdot
.978 .54748 Mdot
.978 .54827 Mdot
.978 .54853 Mdot
.978 .54869 Mdot
.978 .54882 Mdot
.978 .54968 Mdot
.978 .55032 Mdot
.978 .55057 Mdot
.978 .55081 Mdot
.978 .55135 Mdot
.978 .55166 Mdot
.978 .55214 Mdot
.978 .55368 Mdot
.978 .55421 Mdot
.978 .55453 Mdot
.978 .55564 Mdot
.978 .55658 Mdot
.978 .55665 Mdot
.978 .55689 Mdot
.978 .5571 Mdot
.978 .55871 Mdot
.978 .55885 Mdot
.978 .5597 Mdot
.978 .56139 Mdot
.978 .56157 Mdot
.978 .562 Mdot
.978 .56297 Mdot
.978 .56389 Mdot
.978 .56425 Mdot
.978 .56453 Mdot
.978 .56554 Mdot
.978 .56616 Mdot
.978 .56621 Mdot
.978 .56627 Mdot
.978 .57046 Mdot
.978 .57097 Mdot
.978 .57356 Mdot
.978 .57514 Mdot
.978 .58107 Mdot
.978 .58191 Mdot
.978 .58318 Mdot
.978 .58346 Mdot
.978 .5839 Mdot
.978 .58475 Mdot
.978 .58515 Mdot
.978 .58621 Mdot
.978 .58637 Mdot
.978 .58742 Mdot
.978 .58769 Mdot
.978 .58988 Mdot
.978 .59019 Mdot
.978 .59134 Mdot
.98 .01495 Mdot
.98 .01518 Mdot
.98 .01563 Mdot
.98 .0162 Mdot
.98 .0165 Mdot
.98 .01762 Mdot
.98 .01779 Mdot
.98 .01785 Mdot
.98 .01797 Mdot
.98 .01822 Mdot
.98 .0204 Mdot
.98 .02063 Mdot
.98 .02074 Mdot
.98 .02087 Mdot
.98 .02109 Mdot
.98 .02131 Mdot
.98 .02158 Mdot
.98 .02329 Mdot
.98 .02353 Mdot
.98 .02357 Mdot
.98 .02587 Mdot
.98 .02632 Mdot
.98 .02652 Mdot
.98 .02677 Mdot
.98 .02678 Mdot
.98 .02718 Mdot
.98 .02721 Mdot
.98 .02764 Mdot
.98 .02817 Mdot
.98 .02828 Mdot
.98 .02887 Mdot
.98 .03079 Mdot
.98 .03153 Mdot
.98 .03199 Mdot
.98 .03206 Mdot
.98 .03522 Mdot
.98 .03554 Mdot
.98 .03657 Mdot
.98 .03722 Mdot
.98 .03745 Mdot
.98 .03764 Mdot
.98 .03785 Mdot
.98 .03803 Mdot
.98 .03834 Mdot
.98 .03836 Mdot
.98 .03916 Mdot
.98 .03921 Mdot
.98 .04004 Mdot
.98 .04109 Mdot
.98 .0413 Mdot
.98 .04187 Mdot
.98 .04245 Mdot
.98 .04289 Mdot
.98 .04519 Mdot
.98 .04622 Mdot
.98 .04709 Mdot
.98 .04767 Mdot
.98 .04858 Mdot
.98 .04872 Mdot
.98 .04932 Mdot
.98 .05026 Mdot
.98 .05384 Mdot
.98 .0549 Mdot
.98 .05554 Mdot
.98 .05737 Mdot
.98 .05756 Mdot
.98 .05765 Mdot
.98 .05781 Mdot
.98 .05845 Mdot
.98 .05882 Mdot
.98 .05928 Mdot
.98 .05965 Mdot
.98 .06007 Mdot
.98 .06042 Mdot
.98 .06103 Mdot
.98 .06105 Mdot
.98 .06262 Mdot
.98 .06272 Mdot
.98 .0632 Mdot
.98 .0635 Mdot
.98 .06375 Mdot
.98 .06436 Mdot
.98 .06446 Mdot
.98 .06474 Mdot
.98 .06518 Mdot
.98 .06642 Mdot
.98 .06683 Mdot
.98 .06694 Mdot
.98 .06713 Mdot
.98 .06744 Mdot
.98 .06762 Mdot
.98 .06787 Mdot
.98 .06795 Mdot
.98 .06828 Mdot
.98 .06868 Mdot
.98 .06878 Mdot
.98 .06908 Mdot
.98 .06993 Mdot
.98 .06999 Mdot
.98 .07001 Mdot
.98 .07109 Mdot
.98 .07111 Mdot
.98 .07132 Mdot
.98 .07169 Mdot
.98 .07228 Mdot
.98 .07335 Mdot
.98 .07445 Mdot
.98 .07514 Mdot
.98 .07645 Mdot
.98 .07646 Mdot
.98 .07681 Mdot
.98 .07786 Mdot
.98 .07817 Mdot
.98 .07824 Mdot
.98 .07931 Mdot
.98 .0803 Mdot
.98 .08068 Mdot
.98 .08109 Mdot
.98 .08136 Mdot
.98 .08253 Mdot
.98 .08309 Mdot
.98 .08371 Mdot
.98 .08405 Mdot
.98 .08437 Mdot
.98 .08487 Mdot
.98 .08516 Mdot
.98 .08525 Mdot
.98 .08548 Mdot
.98 .08601 Mdot
.98 .08965 Mdot
.98 .09072 Mdot
.98 .09139 Mdot
.98 .0921 Mdot
.98 .09256 Mdot
.98 .09286 Mdot
.98 .09348 Mdot
.98 .09473 Mdot
.98 .09529 Mdot
.98 .09739 Mdot
.98 .09816 Mdot
.98 .09829 Mdot
.98 .09833 Mdot
.98 .09839 Mdot
.98 .09869 Mdot
.98 .09886 Mdot
.98 .09917 Mdot
.98 .10044 Mdot
.98 .10076 Mdot
.98 .10115 Mdot
.98 .10206 Mdot
.98 .1028 Mdot
.98 .10361 Mdot
.98 .10403 Mdot
.98 .10405 Mdot
.98 .10429 Mdot
.98 .1045 Mdot
.98 .10549 Mdot
.98 .10553 Mdot
.98 .10723 Mdot
.98 .10768 Mdot
.98 .1078 Mdot
.98 .10782 Mdot
.98 .1086 Mdot
.98 .1088 Mdot
.98 .10964 Mdot
.98 .10975 Mdot
.98 .11033 Mdot
.98 .11082 Mdot
.98 .11124 Mdot
.98 .11202 Mdot
.98 .11221 Mdot
.98 .11277 Mdot
.98 .11363 Mdot
.98 .11481 Mdot
.98 .11605 Mdot
.98 .11685 Mdot
.98 .11708 Mdot
.98 .11745 Mdot
.98 .11805 Mdot
.98 .11841 Mdot
.98 .11856 Mdot
.98 .11864 Mdot
.98 .11889 Mdot
.98 .11901 Mdot
.98 .11905 Mdot
.98 .1197 Mdot
.98 .12049 Mdot
.98 .12068 Mdot
.98 .12127 Mdot
.98 .12135 Mdot
.98 .12294 Mdot
.98 .12305 Mdot
.98 .1231 Mdot
.98 .12382 Mdot
.98 .12456 Mdot
.98 .12521 Mdot
.98 .12525 Mdot
.98 .12565 Mdot
.98 .12565 Mdot
.98 .12622 Mdot
.98 .12639 Mdot
.98 .12718 Mdot
.98 .12754 Mdot
.98 .12964 Mdot
.98 .12965 Mdot
.98 .13062 Mdot
.98 .13177 Mdot
.98 .1318 Mdot
.98 .13286 Mdot
.98 .13315 Mdot
.98 .13392 Mdot
.98 .13477 Mdot
.98 .13516 Mdot
.98 .13571 Mdot
.98 .13573 Mdot
.98 .1361 Mdot
.98 .13623 Mdot
.98 .13641 Mdot
.98 .13678 Mdot
.98 .13722 Mdot
.98 .1384 Mdot
.98 .13847 Mdot
.98 .13909 Mdot
.98 .13922 Mdot
.98 .13925 Mdot
.98 .14011 Mdot
.98 .14105 Mdot
.98 .14133 Mdot
.98 .14213 Mdot
.98 .14224 Mdot
.98 .14326 Mdot
.98 .14357 Mdot
.98 .14402 Mdot
.98 .14481 Mdot
.98 .1452 Mdot
.98 .14534 Mdot
.98 .14713 Mdot
.98 .14764 Mdot
.98 .14809 Mdot
.98 .14873 Mdot
.98 .1498 Mdot
.98 .14994 Mdot
.98 .14994 Mdot
.98 .1506 Mdot
.98 .1506 Mdot
.98 .15075 Mdot
.98 .15125 Mdot
.98 .1517 Mdot
.98 .15222 Mdot
.98 .15279 Mdot
.98 .15296 Mdot
.98 .15342 Mdot
.98 .15343 Mdot
.98 .15445 Mdot
.98 .15484 Mdot
.98 .15511 Mdot
.98 .1554 Mdot
.98 .15621 Mdot
.98 .15834 Mdot
.98 .1588 Mdot
.98 .15883 Mdot
.98 .15886 Mdot
.98 .15911 Mdot
.98 .16064 Mdot
.98 .16158 Mdot
.98 .16197 Mdot
.98 .16304 Mdot
.98 .16325 Mdot
.98 .16369 Mdot
.98 .16371 Mdot
.98 .16448 Mdot
.98 .16501 Mdot
.98 .16563 Mdot
.98 .16639 Mdot
.98 .16729 Mdot
.98 .16781 Mdot
.98 .16787 Mdot
.98 .16788 Mdot
.98 .1691 Mdot
.98 .16926 Mdot
.98 .16976 Mdot
.98 .17154 Mdot
.98 .17264 Mdot
.98 .17351 Mdot
.98 .17576 Mdot
.98 .17675 Mdot
.98 .17819 Mdot
.98 .17827 Mdot
.98 .17834 Mdot
.98 .17852 Mdot
.98 .1786 Mdot
.98 .17871 Mdot
.98 .1793 Mdot
.98 .17941 Mdot
.98 .17962 Mdot
.98 .17965 Mdot
.98 .17996 Mdot
.98 .17997 Mdot
.98 .18025 Mdot
.98 .18056 Mdot
.98 .1813 Mdot
.98 .18164 Mdot
.98 .18275 Mdot
.98 .18337 Mdot
.98 .18362 Mdot
.98 .18413 Mdot
.98 .18508 Mdot
.98 .18591 Mdot
.98 .18735 Mdot
.98 .18883 Mdot
.98 .18895 Mdot
.98 .18977 Mdot
.98 .1898 Mdot
.98 .18981 Mdot
.98 .19028 Mdot
.98 .1907 Mdot
.98 .19263 Mdot
.98 .19272 Mdot
.98 .19485 Mdot
.98 .19549 Mdot
.98 .19604 Mdot
.98 .19633 Mdot
.98 .19693 Mdot
.98 .19717 Mdot
.98 .1972 Mdot
.98 .19777 Mdot
.98 .19799 Mdot
.98 .19821 Mdot
.98 .19874 Mdot
.98 .19912 Mdot
.98 .20004 Mdot
.98 .20029 Mdot
.98 .20077 Mdot
.98 .20095 Mdot
.98 .20098 Mdot
.98 .20205 Mdot
.98 .20212 Mdot
.98 .20308 Mdot
.98 .20309 Mdot
.98 .2039 Mdot
.98 .20424 Mdot
.98 .20456 Mdot
.98 .20542 Mdot
.98 .2058 Mdot
.98 .20593 Mdot
.98 .20691 Mdot
.98 .20749 Mdot
.98 .20816 Mdot
.98 .20844 Mdot
.98 .20859 Mdot
.98 .20859 Mdot
.98 .20874 Mdot
.98 .20903 Mdot
.98 .20992 Mdot
.98 .2109 Mdot
.98 .21263 Mdot
.98 .21328 Mdot
.98 .21334 Mdot
.98 .21491 Mdot
.98 .21499 Mdot
.98 .21535 Mdot
.98 .21593 Mdot
.98 .21608 Mdot
.98 .21615 Mdot
.98 .21709 Mdot
.98 .21726 Mdot
.98 .21771 Mdot
.98 .21795 Mdot
.98 .21801 Mdot
.98 .21825 Mdot
.98 .21841 Mdot
.98 .2189 Mdot
.98 .21914 Mdot
.98 .21916 Mdot
.98 .21921 Mdot
.98 .21959 Mdot
.98 .22048 Mdot
.98 .22049 Mdot
.98 .22059 Mdot
.98 .22076 Mdot
.98 .22204 Mdot
.98 .22224 Mdot
.98 .2224 Mdot
.98 .22257 Mdot
.98 .22357 Mdot
.98 .22372 Mdot
.98 .22493 Mdot
.98 .22499 Mdot
.98 .22508 Mdot
.98 .22566 Mdot
.98 .22568 Mdot
.98 .22607 Mdot
.98 .22671 Mdot
.98 .22683 Mdot
.98 .22706 Mdot
.98 .22707 Mdot
.98 .22715 Mdot
.98 .22726 Mdot
.98 .22856 Mdot
.98 .22986 Mdot
.98 .23001 Mdot
.98 .23129 Mdot
.98 .23135 Mdot
.98 .23163 Mdot
.98 .23206 Mdot
.98 .23215 Mdot
.98 .23215 Mdot
.98 .23239 Mdot
.98 .23302 Mdot
.98 .23325 Mdot
.98 .23359 Mdot
.98 .23369 Mdot
.98 .23515 Mdot
.98 .23585 Mdot
.98 .23646 Mdot
.98 .23752 Mdot
.98 .23808 Mdot
.98 .23997 Mdot
.98 .23999 Mdot
.98 .2408 Mdot
.98 .24161 Mdot
.98 .24189 Mdot
.98 .24231 Mdot
.98 .24274 Mdot
.98 .24297 Mdot
.98 .24333 Mdot
.98 .24414 Mdot
.98 .2442 Mdot
.98 .24553 Mdot
.98 .24564 Mdot
.98 .24628 Mdot
.98 .24684 Mdot
.98 .24714 Mdot
.98 .24835 Mdot
.98 .2495 Mdot
.98 .24957 Mdot
.98 .25003 Mdot
.98 .25006 Mdot
.98 .25033 Mdot
.98 .25079 Mdot
.98 .25093 Mdot
.98 .25098 Mdot
.98 .25125 Mdot
.98 .2517 Mdot
.98 .25186 Mdot
.98 .25191 Mdot
.98 .25264 Mdot
.98 .25288 Mdot
.98 .25324 Mdot
.98 .25352 Mdot
.98 .25397 Mdot
.98 .25483 Mdot
.98 .2567 Mdot
.98 .25703 Mdot
.98 .25713 Mdot
.98 .25727 Mdot
.98 .25849 Mdot
.98 .25875 Mdot
.98 .25881 Mdot
.98 .25932 Mdot
.98 .26048 Mdot
.98 .26096 Mdot
.98 .26168 Mdot
.98 .26224 Mdot
.98 .26233 Mdot
.98 .26288 Mdot
.98 .26444 Mdot
.98 .26467 Mdot
.98 .26666 Mdot
.98 .26685 Mdot
.98 .26719 Mdot
.98 .26727 Mdot
.98 .26742 Mdot
.98 .26756 Mdot
.98 .26814 Mdot
.98 .26847 Mdot
.98 .26954 Mdot
.98 .26969 Mdot
.98 .27015 Mdot
.98 .27046 Mdot
.98 .27047 Mdot
.98 .27048 Mdot
.98 .27074 Mdot
.98 .27141 Mdot
.98 .27383 Mdot
.98 .27426 Mdot
.98 .27472 Mdot
.98 .27503 Mdot
.98 .27525 Mdot
.98 .27603 Mdot
.98 .27612 Mdot
.98 .27638 Mdot
.98 .27711 Mdot
.98 .27739 Mdot
.98 .27949 Mdot
.98 .27976 Mdot
.98 .27976 Mdot
.98 .28106 Mdot
.98 .28106 Mdot
.98 .28134 Mdot
.98 .28202 Mdot
.98 .2832 Mdot
.98 .28422 Mdot
.98 .2847 Mdot
.98 .28535 Mdot
.98 .28567 Mdot
.98 .28658 Mdot
.98 .28661 Mdot
.98 .28705 Mdot
.98 .28859 Mdot
.98 .28937 Mdot
.98 .28989 Mdot
.98 .29045 Mdot
.98 .29065 Mdot
.98 .29109 Mdot
.98 .2917 Mdot
.98 .29204 Mdot
.98 .29289 Mdot
.98 .29326 Mdot
.98 .29402 Mdot
.98 .29494 Mdot
.98 .29495 Mdot
.98 .29621 Mdot
.98 .29713 Mdot
.98 .29718 Mdot
.98 .29723 Mdot
.98 .29772 Mdot
.98 .30051 Mdot
.98 .30058 Mdot
.98 .30074 Mdot
.98 .30257 Mdot
.98 .30334 Mdot
.98 .3037 Mdot
.98 .30473 Mdot
.98 .30474 Mdot
.98 .30544 Mdot
.98 .30585 Mdot
.98 .30671 Mdot
.98 .30674 Mdot
.98 .30681 Mdot
.98 .30684 Mdot
.98 .3079 Mdot
.98 .30825 Mdot
.98 .30928 Mdot
.98 .30951 Mdot
.98 .31052 Mdot
.98 .31115 Mdot
.98 .31196 Mdot
.98 .312 Mdot
.98 .31206 Mdot
.98 .31342 Mdot
.98 .31376 Mdot
.98 .31477 Mdot
.98 .31489 Mdot
.98 .31491 Mdot
.98 .31655 Mdot
.98 .31676 Mdot
.98 .31732 Mdot
.98 .31762 Mdot
.98 .3186 Mdot
.98 .32086 Mdot
.98 .32102 Mdot
.98 .32188 Mdot
.98 .32209 Mdot
.98 .32229 Mdot
.98 .32425 Mdot
.98 .32477 Mdot
.98 .32595 Mdot
.98 .32691 Mdot
.98 .32805 Mdot
.98 .32853 Mdot
.98 .33036 Mdot
.98 .33216 Mdot
.98 .3323 Mdot
.98 .33238 Mdot
.98 .33271 Mdot
.98 .33513 Mdot
.98 .33529 Mdot
.98 .33541 Mdot
.98 .33577 Mdot
.98 .33592 Mdot
.98 .33614 Mdot
.98 .33704 Mdot
.98 .33714 Mdot
.98 .3373 Mdot
.98 .33739 Mdot
.98 .33751 Mdot
.98 .33773 Mdot
.98 .33793 Mdot
.98 .33798 Mdot
.98 .3386 Mdot
.98 .33861 Mdot
.98 .33916 Mdot
.98 .33917 Mdot
.98 .33927 Mdot
.98 .33947 Mdot
.98 .33977 Mdot
.98 .34031 Mdot
.98 .34122 Mdot
.98 .34189 Mdot
.98 .34208 Mdot
.98 .34261 Mdot
.98 .34281 Mdot
.98 .34386 Mdot
.98 .34405 Mdot
.98 .34528 Mdot
.98 .3456 Mdot
.98 .34577 Mdot
.98 .34619 Mdot
.98 .34634 Mdot
.98 .34638 Mdot
.98 .3465 Mdot
.98 .34677 Mdot
.98 .34863 Mdot
.98 .34918 Mdot
.98 .34988 Mdot
.98 .35011 Mdot
.98 .35027 Mdot
.98 .35151 Mdot
.98 .35257 Mdot
.98 .35297 Mdot
.98 .35304 Mdot
.98 .35309 Mdot
.98 .3543 Mdot
.98 .35596 Mdot
.98 .35597 Mdot
.98 .35621 Mdot
.98 .3576 Mdot
.98 .35783 Mdot
.98 .35789 Mdot
.98 .3579 Mdot
.98 .35883 Mdot
.98 .35964 Mdot
.98 .36146 Mdot
.98 .36338 Mdot
.98 .36342 Mdot
.98 .36361 Mdot
.98 .3648 Mdot
.98 .36606 Mdot
.98 .36644 Mdot
.98 .36699 Mdot
.98 .36728 Mdot
.98 .36778 Mdot
.98 .36903 Mdot
.98 .36953 Mdot
.98 .37012 Mdot
.98 .37068 Mdot
.98 .37121 Mdot
.98 .37165 Mdot
.98 .37185 Mdot
.98 .37233 Mdot
.98 .37239 Mdot
.98 .37268 Mdot
.98 .3729 Mdot
.98 .3735 Mdot
.98 .37394 Mdot
.98 .37437 Mdot
.98 .37485 Mdot
.98 .3754 Mdot
.98 .37546 Mdot
.98 .37614 Mdot
.98 .37697 Mdot
.98 .37796 Mdot
.98 .37844 Mdot
.98 .37932 Mdot
.98 .37939 Mdot
.98 .37973 Mdot
.98 .3798 Mdot
.98 .38028 Mdot
.98 .38117 Mdot
.98 .38189 Mdot
.98 .38203 Mdot
.98 .38217 Mdot
.98 .38259 Mdot
.98 .38367 Mdot
.98 .38391 Mdot
.98 .38393 Mdot
.98 .38394 Mdot
.98 .38406 Mdot
.98 .38485 Mdot
.98 .38553 Mdot
.98 .38607 Mdot
.98 .38618 Mdot
.98 .38641 Mdot
.98 .38681 Mdot
.98 .3874 Mdot
.98 .3885 Mdot
.98 .38854 Mdot
.98 .38924 Mdot
.98 .3895 Mdot
.98 .39141 Mdot
.98 .39256 Mdot
.98 .3938 Mdot
.98 .39388 Mdot
.98 .39442 Mdot
.98 .39453 Mdot
.98 .39471 Mdot
.98 .39471 Mdot
.98 .39501 Mdot
.98 .39539 Mdot
.98 .39556 Mdot
.98 .39657 Mdot
.98 .39732 Mdot
.98 .39923 Mdot
.98 .39973 Mdot
.98 .4023 Mdot
.98 .40263 Mdot
.98 .40306 Mdot
.98 .40379 Mdot
.98 .4039 Mdot
.98 .40402 Mdot
.98 .40495 Mdot
.98 .40508 Mdot
.98 .40541 Mdot
.98 .40597 Mdot
.98 .4065 Mdot
.98 .40709 Mdot
.98 .40725 Mdot
.98 .40796 Mdot
.98 .40875 Mdot
.98 .4091 Mdot
.98 .40924 Mdot
.98 .40931 Mdot
.98 .40939 Mdot
.98 .40953 Mdot
.98 .40999 Mdot
.98 .41137 Mdot
.98 .41171 Mdot
.98 .41258 Mdot
.98 .41306 Mdot
.98 .41317 Mdot
.98 .41365 Mdot
.98 .41396 Mdot
.98 .41412 Mdot
.98 .41471 Mdot
.98 .41493 Mdot
.98 .41538 Mdot
.98 .41543 Mdot
.98 .41552 Mdot
.98 .41627 Mdot
.98 .41645 Mdot
.98 .41765 Mdot
.98 .41768 Mdot
.98 .41773 Mdot
.98 .41802 Mdot
.98 .41803 Mdot
.98 .41823 Mdot
.98 .41856 Mdot
.98 .41874 Mdot
.98 .41884 Mdot
.98 .42016 Mdot
.98 .42107 Mdot
.98 .42129 Mdot
.98 .42146 Mdot
.98 .42178 Mdot
.98 .42212 Mdot
.98 .42353 Mdot
.98 .42407 Mdot
.98 .42436 Mdot
.98 .42574 Mdot
.98 .42616 Mdot
.98 .42652 Mdot
.98 .42673 Mdot
.98 .42685 Mdot
.98 .42703 Mdot
.98 .42816 Mdot
.98 .42821 Mdot
.98 .42898 Mdot
.98 .43019 Mdot
.98 .43022 Mdot
.98 .43047 Mdot
.98 .43061 Mdot
.98 .43091 Mdot
.98 .43094 Mdot
.98 .43108 Mdot
.98 .43131 Mdot
.98 .43224 Mdot
.98 .43386 Mdot
.98 .43403 Mdot
.98 .43519 Mdot
.98 .43603 Mdot
.98 .4364 Mdot
.98 .43668 Mdot
.98 .43904 Mdot
.98 .43921 Mdot
.98 .43933 Mdot
.98 .4394 Mdot
.98 .43986 Mdot
.98 .44041 Mdot
.98 .44072 Mdot
.98 .44088 Mdot
.98 .44089 Mdot
.98 .44136 Mdot
.98 .4426 Mdot
.98 .44305 Mdot
.98 .44321 Mdot
.98 .44372 Mdot
.98 .4439 Mdot
.98 .44427 Mdot
.98 .44678 Mdot
.98 .44814 Mdot
.98 .44934 Mdot
.98 .45118 Mdot
.98 .4514 Mdot
.98 .45171 Mdot
.98 .45232 Mdot
.98 .45251 Mdot
.98 .4529 Mdot
.98 .45337 Mdot
.98 .45337 Mdot
.98 .45621 Mdot
.98 .45625 Mdot
.98 .45784 Mdot
.98 .45836 Mdot
.98 .45837 Mdot
.98 .45942 Mdot
.98 .45944 Mdot
.98 .45998 Mdot
.98 .4608 Mdot
.98 .46164 Mdot
.98 .46205 Mdot
.98 .4621 Mdot
.98 .46279 Mdot
.98 .46439 Mdot
.98 .4645 Mdot
.98 .46659 Mdot
.98 .46668 Mdot
.98 .46711 Mdot
.98 .46732 Mdot
.98 .46859 Mdot
.98 .46968 Mdot
.98 .47026 Mdot
.98 .47051 Mdot
.98 .47236 Mdot
.98 .47247 Mdot
.98 .47264 Mdot
.98 .47485 Mdot
.98 .4749 Mdot
.98 .47503 Mdot
.98 .4752 Mdot
.98 .47593 Mdot
.98 .47599 Mdot
.98 .47609 Mdot
.98 .47652 Mdot
.98 .47742 Mdot
.98 .47769 Mdot
.98 .47779 Mdot
.98 .47833 Mdot
.98 .47921 Mdot
.98 .47952 Mdot
.98 .47959 Mdot
.98 .47961 Mdot
.98 .47968 Mdot
.98 .48104 Mdot
.98 .4814 Mdot
.98 .48152 Mdot
.98 .48223 Mdot
.98 .48277 Mdot
.98 .48298 Mdot
.98 .48301 Mdot
.98 .48365 Mdot
.98 .48534 Mdot
.98 .48731 Mdot
.98 .48829 Mdot
.98 .48901 Mdot
.98 .48966 Mdot
.98 .48985 Mdot
.98 .49013 Mdot
.98 .49028 Mdot
.98 .49143 Mdot
.98 .49228 Mdot
.98 .49251 Mdot
.98 .49303 Mdot
.98 .49314 Mdot
.98 .49414 Mdot
.98 .49445 Mdot
.98 .49522 Mdot
.98 .49642 Mdot
.98 .49691 Mdot
.98 .49736 Mdot
.98 .49787 Mdot
.98 .49809 Mdot
.98 .49864 Mdot
.98 .49878 Mdot
.98 .49884 Mdot
.98 .49924 Mdot
.98 .49986 Mdot
.98 .50004 Mdot
.98 .50054 Mdot
.98 .50112 Mdot
.98 .50381 Mdot
.98 .50418 Mdot
.98 .50462 Mdot
.98 .50522 Mdot
.98 .50683 Mdot
.98 .50814 Mdot
.98 .50853 Mdot
.98 .5089 Mdot
.98 .5095 Mdot
.98 .50956 Mdot
.98 .50973 Mdot
.98 .51002 Mdot
.98 .51029 Mdot
.98 .51144 Mdot
.98 .51168 Mdot
.98 .51172 Mdot
.98 .51207 Mdot
.98 .51417 Mdot
.98 .51447 Mdot
.98 .51536 Mdot
.98 .51597 Mdot
.98 .51599 Mdot
.98 .51601 Mdot
.98 .51653 Mdot
.98 .51658 Mdot
.98 .51726 Mdot
.98 .51783 Mdot
.98 .51898 Mdot
.98 .5201 Mdot
.98 .52032 Mdot
.98 .5205 Mdot
.98 .52237 Mdot
.98 .52259 Mdot
.98 .52342 Mdot
.98 .52433 Mdot
.98 .52493 Mdot
.98 .52535 Mdot
.98 .52689 Mdot
.98 .52707 Mdot
.98 .52759 Mdot
.98 .52902 Mdot
.98 .52956 Mdot
.98 .53308 Mdot
.98 .53335 Mdot
.98 .53366 Mdot
.98 .53396 Mdot
.98 .5342 Mdot
.98 .5342 Mdot
.98 .53675 Mdot
.98 .53675 Mdot
.98 .5373 Mdot
.98 .53863 Mdot
.98 .54095 Mdot
.98 .54099 Mdot
.98 .54294 Mdot
.98 .54389 Mdot
.98 .54394 Mdot
.98 .54516 Mdot
.98 .54534 Mdot
.98 .54579 Mdot
.98 .54758 Mdot
.98 .54762 Mdot
.98 .5485 Mdot
.98 .5493 Mdot
.98 .54932 Mdot
.98 .55152 Mdot
.98 .55201 Mdot
.98 .55303 Mdot
.98 .55362 Mdot
.98 .55405 Mdot
.98 .55516 Mdot
.98 .55555 Mdot
.98 .55641 Mdot
.98 .55691 Mdot
.98 .55701 Mdot
.98 .5573 Mdot
.98 .5574 Mdot
.98 .5576 Mdot
.98 .55827 Mdot
.98 .55993 Mdot
.98 .56065 Mdot
.98 .56148 Mdot
.98 .56215 Mdot
.98 .56284 Mdot
.98 .56395 Mdot
.98 .56397 Mdot
.98 .56645 Mdot
.98 .5668 Mdot
.98 .56767 Mdot
.98 .56825 Mdot
.98 .56836 Mdot
.98 .56845 Mdot
.98 .5694 Mdot
.98 .57487 Mdot
.98 .57501 Mdot
.98 .57532 Mdot
.98 .5789 Mdot
.98 .58041 Mdot
.98 .58112 Mdot
.98 .58315 Mdot
.98 .58315 Mdot
.98 .58453 Mdot
.98 .58535 Mdot
.98 .58702 Mdot
.98 .58708 Mdot
.98 .58722 Mdot
.98 .58728 Mdot
.98 .58936 Mdot
.98 .59005 Mdot
.98 .59207 Mdot
.98 .59252 Mdot
.982 .01536 Mdot
.982 .01587 Mdot
.982 .01597 Mdot
.982 .01613 Mdot
.982 .01699 Mdot
.982 .01718 Mdot
.982 .0175 Mdot
.982 .01863 Mdot
.982 .01919 Mdot
.982 .01956 Mdot
.982 .01983 Mdot
.982 .02018 Mdot
.982 .0211 Mdot
.982 .0224 Mdot
.982 .02286 Mdot
.982 .0235 Mdot
.982 .0237 Mdot
.982 .02424 Mdot
.982 .02474 Mdot
.982 .02476 Mdot
.982 .02544 Mdot
.982 .02612 Mdot
.982 .02719 Mdot
.982 .02726 Mdot
.982 .02727 Mdot
.982 .02805 Mdot
.982 .02947 Mdot
.982 .02982 Mdot
.982 .03 Mdot
.982 .03034 Mdot
.982 .03071 Mdot
.982 .03196 Mdot
.982 .0321 Mdot
.982 .03237 Mdot
.982 .03342 Mdot
.982 .03441 Mdot
.982 .03445 Mdot
.982 .03532 Mdot
.982 .03572 Mdot
.982 .03578 Mdot
.982 .03603 Mdot
.982 .03615 Mdot
.982 .03711 Mdot
.982 .03908 Mdot
.982 .03921 Mdot
.982 .03935 Mdot
.982 .03938 Mdot
.982 .03958 Mdot
.982 .0409 Mdot
.982 .04311 Mdot
.982 .04356 Mdot
.982 .0437 Mdot
.982 .04438 Mdot
.982 .04473 Mdot
.982 .0454 Mdot
.982 .04614 Mdot
.982 .04789 Mdot
.982 .04845 Mdot
.982 .04858 Mdot
.982 .04886 Mdot
.982 .04939 Mdot
.982 .04959 Mdot
.982 .05145 Mdot
.982 .05174 Mdot
.982 .05319 Mdot
.982 .0534 Mdot
.982 .05347 Mdot
.982 .05435 Mdot
.982 .05519 Mdot
.982 .05565 Mdot
.982 .05598 Mdot
.982 .05609 Mdot
.982 .05658 Mdot
.982 .05658 Mdot
.982 .05667 Mdot
.982 .05669 Mdot
.982 .05682 Mdot
.982 .05683 Mdot
.982 .05689 Mdot
.982 .05695 Mdot
.982 .05827 Mdot
.982 .05849 Mdot
.982 .05869 Mdot
.982 .05887 Mdot
.982 .0597 Mdot
.982 .06023 Mdot
.982 .06044 Mdot
.982 .06069 Mdot
.982 .06151 Mdot
.982 .06196 Mdot
.982 .0622 Mdot
.982 .06242 Mdot
.982 .06258 Mdot
.982 .06283 Mdot
.982 .06309 Mdot
.982 .06316 Mdot
.982 .06356 Mdot
.982 .06408 Mdot
.982 .06575 Mdot
.982 .06613 Mdot
.982 .06629 Mdot
.982 .06639 Mdot
.982 .06857 Mdot
.982 .07048 Mdot
.982 .0706 Mdot
.982 .07137 Mdot
.982 .07164 Mdot
.982 .07297 Mdot
.982 .07366 Mdot
.982 .07396 Mdot
.982 .07435 Mdot
.982 .07497 Mdot
.982 .07623 Mdot
.982 .07623 Mdot
.982 .07643 Mdot
.982 .07658 Mdot
.982 .07919 Mdot
.982 .07988 Mdot
.982 .08097 Mdot
.982 .08124 Mdot
.982 .08177 Mdot
.982 .08209 Mdot
.982 .08282 Mdot
.982 .08321 Mdot
.982 .08526 Mdot
.982 .08611 Mdot
.982 .08655 Mdot
.982 .08676 Mdot
.982 .08687 Mdot
.982 .08743 Mdot
.982 .0877 Mdot
.982 .08834 Mdot
.982 .08873 Mdot
.982 .09027 Mdot
.982 .09068 Mdot
.982 .09084 Mdot
.982 .09102 Mdot
.982 .09113 Mdot
.982 .09116 Mdot
.982 .09189 Mdot
.982 .09205 Mdot
.982 .09256 Mdot
.982 .0942 Mdot
.982 .09512 Mdot
.982 .09518 Mdot
.982 .09575 Mdot
.982 .09582 Mdot
.982 .09597 Mdot
.982 .09626 Mdot
.982 .0969 Mdot
.982 .09693 Mdot
.982 .09694 Mdot
.982 .09712 Mdot
.982 .09715 Mdot
.982 .09731 Mdot
.982 .09741 Mdot
.982 .09744 Mdot
.982 .09755 Mdot
.982 .09767 Mdot
.982 .09789 Mdot
.982 .09919 Mdot
.982 .10026 Mdot
.982 .10068 Mdot
.982 .10085 Mdot
.982 .10109 Mdot
.982 .10114 Mdot
.982 .10144 Mdot
.982 .10158 Mdot
.982 .10208 Mdot
.982 .10213 Mdot
.982 .10235 Mdot
.982 .1029 Mdot
.982 .10291 Mdot
.982 .10306 Mdot
.982 .10315 Mdot
.982 .1033 Mdot
.982 .10362 Mdot
.982 .1039 Mdot
.982 .10399 Mdot
.982 .10411 Mdot
.982 .10451 Mdot
.982 .10501 Mdot
.982 .10512 Mdot
.982 .10518 Mdot
.982 .10662 Mdot
.982 .10749 Mdot
.982 .10751 Mdot
.982 .10797 Mdot
.982 .10841 Mdot
.982 .10872 Mdot
.982 .10921 Mdot
.982 .10966 Mdot
.982 .10973 Mdot
.982 .10975 Mdot
.982 .10982 Mdot
.982 .10986 Mdot
.982 .11015 Mdot
.982 .11033 Mdot
.982 .11064 Mdot
.982 .11124 Mdot
.982 .11167 Mdot
.982 .11301 Mdot
.982 .11427 Mdot
.982 .11495 Mdot
.982 .11512 Mdot
.982 .116 Mdot
.982 .11621 Mdot
.982 .11653 Mdot
.982 .11801 Mdot
.982 .11835 Mdot
.982 .11892 Mdot
.982 .11934 Mdot
.982 .11941 Mdot
.982 .12007 Mdot
.982 .12013 Mdot
.982 .1205 Mdot
.982 .1215 Mdot
.982 .12158 Mdot
.982 .12243 Mdot
.982 .12294 Mdot
.982 .12424 Mdot
.982 .12447 Mdot
.982 .12598 Mdot
.982 .12652 Mdot
.982 .1272 Mdot
.982 .12791 Mdot
.982 .12912 Mdot
.982 .13028 Mdot
.982 .13048 Mdot
.982 .13107 Mdot
.982 .13183 Mdot
.982 .13306 Mdot
.982 .13554 Mdot
.982 .13554 Mdot
.982 .13592 Mdot
.982 .13621 Mdot
.982 .13679 Mdot
.982 .13681 Mdot
.982 .13701 Mdot
.982 .13715 Mdot
.982 .13961 Mdot
.982 .14044 Mdot
.982 .14135 Mdot
.982 .14269 Mdot
.982 .14383 Mdot
.982 .14483 Mdot
.982 .14536 Mdot
.982 .14613 Mdot
.982 .14642 Mdot
.982 .14704 Mdot
.982 .14725 Mdot
.982 .14847 Mdot
.982 .14924 Mdot
.982 .14986 Mdot
.982 .15111 Mdot
.982 .15171 Mdot
.982 .15325 Mdot
.982 .15327 Mdot
.982 .15329 Mdot
.982 .15382 Mdot
.982 .15386 Mdot
.982 .15393 Mdot
.982 .15445 Mdot
.982 .15481 Mdot
.982 .15494 Mdot
.982 .1558 Mdot
.982 .15621 Mdot
.982 .15642 Mdot
.982 .15695 Mdot
.982 .15752 Mdot
.982 .15805 Mdot
.982 .15833 Mdot
.982 .15931 Mdot
.982 .15981 Mdot
.982 .16008 Mdot
.982 .16069 Mdot
.982 .16133 Mdot
.982 .16143 Mdot
.982 .16195 Mdot
.982 .16311 Mdot
.982 .16392 Mdot
.982 .16411 Mdot
.982 .16422 Mdot
.982 .16457 Mdot
.982 .1648 Mdot
.982 .16486 Mdot
.982 .16523 Mdot
.982 .16628 Mdot
.982 .16659 Mdot
.982 .16692 Mdot
.982 .1676 Mdot
.982 .1685 Mdot
.982 .16909 Mdot
.982 .16923 Mdot
.982 .16932 Mdot
.982 .17071 Mdot
.982 .17082 Mdot
.982 .17171 Mdot
.982 .17263 Mdot
.982 .17274 Mdot
.982 .17387 Mdot
.982 .17401 Mdot
.982 .17431 Mdot
.982 .17486 Mdot
.982 .17588 Mdot
.982 .17612 Mdot
.982 .17619 Mdot
.982 .1762 Mdot
.982 .17622 Mdot
.982 .17656 Mdot
.982 .17661 Mdot
.982 .17693 Mdot
.982 .17712 Mdot
.982 .17718 Mdot
.982 .1774 Mdot
.982 .17757 Mdot
.982 .17763 Mdot
.982 .17806 Mdot
.982 .17866 Mdot
.982 .17975 Mdot
.982 .18062 Mdot
.982 .18273 Mdot
.982 .18356 Mdot
.982 .18389 Mdot
.982 .18419 Mdot
.982 .18435 Mdot
.982 .18445 Mdot
.982 .18505 Mdot
.982 .18531 Mdot
.982 .18629 Mdot
.982 .18641 Mdot
.982 .18668 Mdot
.982 .18683 Mdot
.982 .18791 Mdot
.982 .18793 Mdot
.982 .18813 Mdot
.982 .18819 Mdot
.982 .18823 Mdot
.982 .18831 Mdot
.982 .18841 Mdot
.982 .1887 Mdot
.982 .18932 Mdot
.982 .18988 Mdot
.982 .19005 Mdot
.982 .19029 Mdot
.982 .19107 Mdot
.982 .19205 Mdot
.982 .19228 Mdot
.982 .19239 Mdot
.982 .19258 Mdot
.982 .19259 Mdot
.982 .19297 Mdot
.982 .19332 Mdot
.982 .19443 Mdot
.982 .19461 Mdot
.982 .19522 Mdot
.982 .19692 Mdot
.982 .19697 Mdot
.982 .19701 Mdot
.982 .19764 Mdot
.982 .19786 Mdot
.982 .19874 Mdot
.982 .19933 Mdot
.982 .2003 Mdot
.982 .20118 Mdot
.982 .20119 Mdot
.982 .20133 Mdot
.982 .20134 Mdot
.982 .20136 Mdot
.982 .20149 Mdot
.982 .20158 Mdot
.982 .20214 Mdot
.982 .2025 Mdot
.982 .20288 Mdot
.982 .20311 Mdot
.982 .20328 Mdot
.982 .20343 Mdot
.982 .20429 Mdot
.982 .20472 Mdot
.982 .20513 Mdot
.982 .20535 Mdot
.982 .20777 Mdot
.982 .20985 Mdot
.982 .21024 Mdot
.982 .21138 Mdot
.982 .21157 Mdot
.982 .2119 Mdot
.982 .21252 Mdot
.982 .21365 Mdot
.982 .21405 Mdot
.982 .21419 Mdot
.982 .21453 Mdot
.982 .21469 Mdot
.982 .21655 Mdot
.982 .21698 Mdot
.982 .21759 Mdot
.982 .21825 Mdot
.982 .21911 Mdot
.982 .21937 Mdot
.982 .2202 Mdot
.982 .22033 Mdot
.982 .22164 Mdot
.982 .22175 Mdot
.982 .22239 Mdot
.982 .22247 Mdot
.982 .22338 Mdot
.982 .22341 Mdot
.982 .22416 Mdot
.982 .22445 Mdot
.982 .2246 Mdot
.982 .22627 Mdot
.982 .22661 Mdot
.982 .22663 Mdot
.982 .22712 Mdot
.982 .22726 Mdot
.982 .22785 Mdot
.982 .22945 Mdot
.982 .22982 Mdot
.982 .23027 Mdot
.982 .23216 Mdot
.982 .23261 Mdot
.982 .23324 Mdot
.982 .2343 Mdot
.982 .23449 Mdot
.982 .23502 Mdot
.982 .23508 Mdot
.982 .23536 Mdot
.982 .23563 Mdot
.982 .23702 Mdot
.982 .23731 Mdot
.982 .23886 Mdot
.982 .23899 Mdot
.982 .23941 Mdot
.982 .24168 Mdot
.982 .2419 Mdot
.982 .24207 Mdot
.982 .24211 Mdot
.982 .243 Mdot
.982 .24324 Mdot
.982 .24358 Mdot
.982 .24473 Mdot
.982 .24715 Mdot
.982 .24816 Mdot
.982 .24873 Mdot
.982 .25004 Mdot
.982 .25009 Mdot
.982 .25135 Mdot
.982 .25143 Mdot
.982 .25201 Mdot
.982 .25201 Mdot
.982 .25254 Mdot
.982 .25277 Mdot
.982 .25307 Mdot
.982 .25329 Mdot
.982 .25333 Mdot
.982 .25386 Mdot
.982 .25446 Mdot
.982 .25447 Mdot
.982 .25452 Mdot
.982 .2549 Mdot
.982 .25517 Mdot
.982 .25614 Mdot
.982 .26 Mdot
.982 .26129 Mdot
.982 .26164 Mdot
.982 .2623 Mdot
.982 .26232 Mdot
.982 .26342 Mdot
.982 .26371 Mdot
.982 .2654 Mdot
.982 .26545 Mdot
.982 .26607 Mdot
.982 .26681 Mdot
.982 .26788 Mdot
.982 .2683 Mdot
.982 .27027 Mdot
.982 .271 Mdot
.982 .2713 Mdot
.982 .27274 Mdot
.982 .27281 Mdot
.982 .27338 Mdot
.982 .27447 Mdot
.982 .2746 Mdot
.982 .27501 Mdot
.982 .27692 Mdot
.982 .27725 Mdot
.982 .27741 Mdot
.982 .27891 Mdot
.982 .27892 Mdot
.982 .27989 Mdot
.982 .28015 Mdot
.982 .28099 Mdot
.982 .28172 Mdot
.982 .28234 Mdot
.982 .28259 Mdot
.982 .28354 Mdot
.982 .28377 Mdot
.982 .28377 Mdot
.982 .28401 Mdot
.982 .28438 Mdot
.982 .28509 Mdot
.982 .28614 Mdot
.982 .28679 Mdot
.982 .28684 Mdot
.982 .28688 Mdot
.982 .28792 Mdot
.982 .28799 Mdot
.982 .28813 Mdot
.982 .28916 Mdot
.982 .28986 Mdot
.982 .29012 Mdot
.982 .2915 Mdot
.982 .29178 Mdot
.982 .29181 Mdot
.982 .29234 Mdot
.982 .29261 Mdot
.982 .29262 Mdot
.982 .29303 Mdot
.982 .29348 Mdot
.982 .29407 Mdot
.982 .29497 Mdot
.982 .29503 Mdot
.982 .29519 Mdot
.982 .29623 Mdot
.982 .29677 Mdot
.982 .2986 Mdot
.982 .29871 Mdot
.982 .29907 Mdot
.982 .29969 Mdot
.982 .30021 Mdot
.982 .30073 Mdot
.982 .30128 Mdot
.982 .30142 Mdot
.982 .30233 Mdot
.982 .30267 Mdot
.982 .30286 Mdot
.982 .30388 Mdot
.982 .30431 Mdot
.982 .30616 Mdot
.982 .30774 Mdot
.982 .30812 Mdot
.982 .30834 Mdot
.982 .30896 Mdot
.982 .30903 Mdot
.982 .30945 Mdot
.982 .30949 Mdot
.982 .30959 Mdot
.982 .3103 Mdot
.982 .31032 Mdot
.982 .31072 Mdot
.982 .31099 Mdot
.982 .31112 Mdot
.982 .31239 Mdot
.982 .313 Mdot
.982 .31365 Mdot
.982 .31454 Mdot
.982 .31497 Mdot
.982 .3155 Mdot
.982 .3162 Mdot
.982 .31675 Mdot
.982 .31679 Mdot
.982 .31718 Mdot
.982 .31791 Mdot
.982 .31818 Mdot
.982 .31835 Mdot
.982 .31925 Mdot
.982 .32089 Mdot
.982 .32109 Mdot
.982 .32125 Mdot
.982 .32131 Mdot
.982 .3228 Mdot
.982 .32306 Mdot
.982 .32485 Mdot
.982 .32508 Mdot
.982 .32729 Mdot
.982 .32757 Mdot
.982 .32815 Mdot
.982 .32925 Mdot
.982 .32998 Mdot
.982 .33058 Mdot
.982 .33124 Mdot
.982 .33171 Mdot
.982 .33176 Mdot
.982 .33177 Mdot
.982 .33184 Mdot
.982 .33187 Mdot
.982 .3319 Mdot
.982 .33257 Mdot
.982 .33268 Mdot
.982 .33288 Mdot
.982 .3333 Mdot
.982 .33357 Mdot
.982 .33368 Mdot
.982 .3338 Mdot
.982 .33422 Mdot
.982 .33445 Mdot
.982 .33457 Mdot
.982 .33469 Mdot
.982 .33553 Mdot
.982 .33638 Mdot
.982 .33666 Mdot
.982 .33671 Mdot
.982 .33782 Mdot
.982 .33885 Mdot
.982 .34056 Mdot
.982 .34076 Mdot
.982 .34172 Mdot
.982 .34172 Mdot
.982 .34189 Mdot
.982 .3447 Mdot
.982 .34632 Mdot
.982 .34675 Mdot
.982 .34697 Mdot
.982 .34708 Mdot
.982 .34756 Mdot
.982 .34788 Mdot
.982 .34808 Mdot
.982 .34925 Mdot
.982 .34931 Mdot
.982 .34932 Mdot
.982 .34969 Mdot
.982 .34977 Mdot
.982 .35136 Mdot
.982 .35169 Mdot
.982 .35191 Mdot
.982 .35224 Mdot
.982 .35245 Mdot
.982 .35274 Mdot
.982 .35341 Mdot
.982 .35425 Mdot
.982 .3544 Mdot
.982 .35462 Mdot
.982 .35488 Mdot
.982 .35491 Mdot
.982 .35502 Mdot
.982 .3553 Mdot
.982 .3553 Mdot
.982 .35543 Mdot
.982 .3555 Mdot
.982 .35566 Mdot
.982 .35581 Mdot
.982 .35585 Mdot
.982 .35643 Mdot
.982 .35646 Mdot
.982 .35763 Mdot
.982 .35874 Mdot
.982 .35878 Mdot
.982 .35882 Mdot
.982 .35899 Mdot
.982 .35908 Mdot
.982 .35954 Mdot
.982 .36045 Mdot
.982 .36109 Mdot
.982 .36152 Mdot
.982 .36224 Mdot
.982 .36299 Mdot
.982 .36316 Mdot
.982 .36345 Mdot
.982 .36367 Mdot
.982 .3637 Mdot
.982 .36404 Mdot
.982 .36407 Mdot
.982 .36477 Mdot
.982 .36481 Mdot
.982 .36524 Mdot
.982 .3655 Mdot
.982 .36767 Mdot
.982 .36803 Mdot
.982 .36924 Mdot
.982 .37255 Mdot
.982 .37256 Mdot
.982 .37266 Mdot
.982 .37273 Mdot
.982 .37399 Mdot
.982 .37441 Mdot
.982 .37614 Mdot
.982 .37731 Mdot
.982 .37788 Mdot
.982 .37921 Mdot
.982 .37984 Mdot
.982 .38015 Mdot
.982 .38093 Mdot
.982 .38095 Mdot
.982 .38122 Mdot
.982 .38124 Mdot
.982 .38128 Mdot
.982 .38154 Mdot
.982 .38173 Mdot
.982 .38282 Mdot
.982 .38352 Mdot
.982 .38427 Mdot
.982 .38472 Mdot
.982 .38505 Mdot
.982 .3851 Mdot
.982 .38536 Mdot
.982 .38646 Mdot
.982 .38703 Mdot
.982 .38789 Mdot
.982 .3887 Mdot
.982 .389 Mdot
.982 .38907 Mdot
.982 .38911 Mdot
.982 .38982 Mdot
.982 .39033 Mdot
.982 .39246 Mdot
.982 .39263 Mdot
.982 .39332 Mdot
.982 .39387 Mdot
.982 .39443 Mdot
.982 .39668 Mdot
.982 .39795 Mdot
.982 .39869 Mdot
.982 .39873 Mdot
.982 .39879 Mdot
.982 .40096 Mdot
.982 .40097 Mdot
.982 .40116 Mdot
.982 .40134 Mdot
.982 .4019 Mdot
.982 .40199 Mdot
.982 .40321 Mdot
.982 .40354 Mdot
.982 .40534 Mdot
.982 .40542 Mdot
.982 .4062 Mdot
.982 .4064 Mdot
.982 .40649 Mdot
.982 .40714 Mdot
.982 .40746 Mdot
.982 .40975 Mdot
.982 .41053 Mdot
.982 .41111 Mdot
.982 .41196 Mdot
.982 .41213 Mdot
.982 .41316 Mdot
.982 .41338 Mdot
.982 .41446 Mdot
.982 .41614 Mdot
.982 .41664 Mdot
.982 .41665 Mdot
.982 .41704 Mdot
.982 .41829 Mdot
.982 .4183 Mdot
.982 .41854 Mdot
.982 .41892 Mdot
.982 .41973 Mdot
.982 .42111 Mdot
.982 .42134 Mdot
.982 .4223 Mdot
.982 .42257 Mdot
.982 .4226 Mdot
.982 .42274 Mdot
.982 .42373 Mdot
.982 .42452 Mdot
.982 .42459 Mdot
.982 .42607 Mdot
.982 .42618 Mdot
.982 .42663 Mdot
.982 .42693 Mdot
.982 .42926 Mdot
.982 .42955 Mdot
.982 .43022 Mdot
.982 .43024 Mdot
.982 .43088 Mdot
.982 .43092 Mdot
.982 .43149 Mdot
.982 .43176 Mdot
.982 .43187 Mdot
.982 .43216 Mdot
.982 .43247 Mdot
.982 .43332 Mdot
.982 .43594 Mdot
.982 .43646 Mdot
.982 .43647 Mdot
.982 .43717 Mdot
.982 .43804 Mdot
.982 .43806 Mdot
.982 .43875 Mdot
.982 .4393 Mdot
.982 .44089 Mdot
.982 .44177 Mdot
.982 .44265 Mdot
.982 .4439 Mdot
.982 .44407 Mdot
.982 .44492 Mdot
.982 .44541 Mdot
.982 .44598 Mdot
.982 .44634 Mdot
.982 .44666 Mdot
.982 .44727 Mdot
.982 .44739 Mdot
.982 .44751 Mdot
.982 .4477 Mdot
.982 .44806 Mdot
.982 .44859 Mdot
.982 .45133 Mdot
.982 .45147 Mdot
.982 .45175 Mdot
.982 .45189 Mdot
.982 .45234 Mdot
.982 .45309 Mdot
.982 .45312 Mdot
.982 .45494 Mdot
.982 .45518 Mdot
.982 .45602 Mdot
.982 .4563 Mdot
.982 .45684 Mdot
.982 .45785 Mdot
.982 .46022 Mdot
.982 .46046 Mdot
.982 .4609 Mdot
.982 .46111 Mdot
.982 .46125 Mdot
.982 .46131 Mdot
.982 .46306 Mdot
.982 .46355 Mdot
.982 .4639 Mdot
.982 .4642 Mdot
.982 .4644 Mdot
.982 .46545 Mdot
.982 .46629 Mdot
.982 .46647 Mdot
.982 .46726 Mdot
.982 .47092 Mdot
.982 .47122 Mdot
.982 .47182 Mdot
.982 .47183 Mdot
.982 .47239 Mdot
.982 .47275 Mdot
.982 .4732 Mdot
.982 .47418 Mdot
.982 .47432 Mdot
.982 .47491 Mdot
.982 .47641 Mdot
.982 .4769 Mdot
.982 .4769 Mdot
.982 .47698 Mdot
.982 .47946 Mdot
.982 .47962 Mdot
.982 .48076 Mdot
.982 .48077 Mdot
.982 .48095 Mdot
.982 .48181 Mdot
.982 .48225 Mdot
.982 .48285 Mdot
.982 .48328 Mdot
.982 .48335 Mdot
.982 .48347 Mdot
.982 .48367 Mdot
.982 .48381 Mdot
.982 .48407 Mdot
.982 .4844 Mdot
.982 .48558 Mdot
.982 .4856 Mdot
.982 .48569 Mdot
.982 .48643 Mdot
.982 .48698 Mdot
.982 .48734 Mdot
.982 .48781 Mdot
.982 .48809 Mdot
.982 .48863 Mdot
.982 .48887 Mdot
.982 .49259 Mdot
.982 .49531 Mdot
.982 .49631 Mdot
.982 .49646 Mdot
.982 .49898 Mdot
.982 .49968 Mdot
.982 .50097 Mdot
.982 .501 Mdot
.982 .50139 Mdot
.982 .50165 Mdot
.982 .50273 Mdot
.982 .50282 Mdot
.982 .50317 Mdot
.982 .50373 Mdot
.982 .50488 Mdot
.982 .5059 Mdot
.982 .50595 Mdot
.982 .50706 Mdot
.982 .50716 Mdot
.982 .50754 Mdot
.982 .50837 Mdot
.982 .50929 Mdot
.982 .50983 Mdot
.982 .51153 Mdot
.982 .51193 Mdot
.982 .51275 Mdot
.982 .51338 Mdot
.982 .51504 Mdot
.982 .51525 Mdot
.982 .51589 Mdot
.982 .5162 Mdot
.982 .51662 Mdot
.982 .51792 Mdot
.982 .51806 Mdot
.982 .51865 Mdot
.982 .5199 Mdot
.982 .52147 Mdot
.982 .52161 Mdot
.982 .52197 Mdot
.982 .5226 Mdot
.982 .52274 Mdot
.982 .5231 Mdot
.982 .52487 Mdot
.982 .52514 Mdot
.982 .52594 Mdot
.982 .5263 Mdot
.982 .52658 Mdot
.982 .52739 Mdot
.982 .52901 Mdot
.982 .52944 Mdot
.982 .52969 Mdot
.982 .53033 Mdot
.982 .53064 Mdot
.982 .53086 Mdot
.982 .53278 Mdot
.982 .53292 Mdot
.982 .53322 Mdot
.982 .5336 Mdot
.982 .53362 Mdot
.982 .53524 Mdot
.982 .53551 Mdot
.982 .53602 Mdot
.982 .53723 Mdot
.982 .53769 Mdot
.982 .53911 Mdot
.982 .53936 Mdot
.982 .5399 Mdot
.982 .54032 Mdot
.982 .54082 Mdot
.982 .54268 Mdot
.982 .54314 Mdot
.982 .54314 Mdot
.982 .54343 Mdot
.982 .54361 Mdot
.982 .54434 Mdot
.982 .54471 Mdot
.982 .54547 Mdot
.982 .54572 Mdot
.982 .54779 Mdot
.982 .54907 Mdot
.982 .54917 Mdot
.982 .54924 Mdot
.982 .54937 Mdot
.982 .55104 Mdot
.982 .55128 Mdot
.982 .55142 Mdot
.982 .5517 Mdot
.982 .55372 Mdot
.982 .5551 Mdot
.982 .55561 Mdot
.982 .55819 Mdot
.982 .55833 Mdot
.982 .55888 Mdot
.982 .55892 Mdot
.982 .55997 Mdot
.982 .56049 Mdot
.982 .56052 Mdot
.982 .56132 Mdot
.982 .56222 Mdot
.982 .56336 Mdot
.982 .5643 Mdot
.982 .56514 Mdot
.982 .56525 Mdot
.982 .56557 Mdot
.982 .56574 Mdot
.982 .56661 Mdot
.982 .56762 Mdot
.982 .56867 Mdot
.982 .56899 Mdot
.982 .56925 Mdot
.982 .57088 Mdot
.982 .57102 Mdot
.982 .57143 Mdot
.982 .57226 Mdot
.982 .57248 Mdot
.982 .5732 Mdot
.982 .57417 Mdot
.982 .57425 Mdot
.982 .5744 Mdot
.982 .57543 Mdot
.982 .57644 Mdot
.982 .57753 Mdot
.982 .5778 Mdot
.982 .5796 Mdot
.982 .58025 Mdot
.982 .58064 Mdot
.982 .58263 Mdot
.982 .58347 Mdot
.982 .58712 Mdot
.982 .59023 Mdot
.982 .59096 Mdot
.982 .5914 Mdot
.982 .59262 Mdot
.982 .59275 Mdot
.982 .59357 Mdot
.982 .59365 Mdot
.982 .59386 Mdot
.982 .59525 Mdot
.982 .59529 Mdot
.984 .01548 Mdot
.984 .01622 Mdot
.984 .01658 Mdot
.984 .01677 Mdot
.984 .01689 Mdot
.984 .01768 Mdot
.984 .01839 Mdot
.984 .01876 Mdot
.984 .01898 Mdot
.984 .01899 Mdot
.984 .0202 Mdot
.984 .0203 Mdot
.984 .02054 Mdot
.984 .0212 Mdot
.984 .02195 Mdot
.984 .02259 Mdot
.984 .02267 Mdot
.984 .02311 Mdot
.984 .02312 Mdot
.984 .02323 Mdot
.984 .02415 Mdot
.984 .02551 Mdot
.984 .02571 Mdot
.984 .02618 Mdot
.984 .02627 Mdot
.984 .02627 Mdot
.984 .02748 Mdot
.984 .02787 Mdot
.984 .02892 Mdot
.984 .02895 Mdot
.984 .03022 Mdot
.984 .03038 Mdot
.984 .03084 Mdot
.984 .03123 Mdot
.984 .03126 Mdot
.984 .03148 Mdot
.984 .03287 Mdot
.984 .03328 Mdot
.984 .03596 Mdot
.984 .03635 Mdot
.984 .03658 Mdot
.984 .03728 Mdot
.984 .03746 Mdot
.984 .03746 Mdot
.984 .03749 Mdot
.984 .03931 Mdot
.984 .03983 Mdot
.984 .04009 Mdot
.984 .04061 Mdot
.984 .04268 Mdot
.984 .04273 Mdot
.984 .04323 Mdot
.984 .04523 Mdot
.984 .04552 Mdot
.984 .04554 Mdot
.984 .04645 Mdot
.984 .04722 Mdot
.984 .04728 Mdot
.984 .0477 Mdot
.984 .04969 Mdot
.984 .05037 Mdot
.984 .05044 Mdot
.984 .05049 Mdot
.984 .05125 Mdot
.984 .05144 Mdot
.984 .05146 Mdot
.984 .0521 Mdot
.984 .05262 Mdot
.984 .05584 Mdot
.984 .05653 Mdot
.984 .0573 Mdot
.984 .05774 Mdot
.984 .05815 Mdot
.984 .05833 Mdot
.984 .05912 Mdot
.984 .05947 Mdot
.984 .05948 Mdot
.984 .05954 Mdot
.984 .05999 Mdot
.984 .06035 Mdot
.984 .06051 Mdot
.984 .06057 Mdot
.984 .0627 Mdot
.984 .06312 Mdot
.984 .06356 Mdot
.984 .06414 Mdot
.984 .06465 Mdot
.984 .06515 Mdot
.984 .06567 Mdot
.984 .06676 Mdot
.984 .06966 Mdot
.984 .06975 Mdot
.984 .06985 Mdot
.984 .07084 Mdot
.984 .0712 Mdot
.984 .07161 Mdot
.984 .0745 Mdot
.984 .07477 Mdot
.984 .07534 Mdot
.984 .07538 Mdot
.984 .07593 Mdot
.984 .07718 Mdot
.984 .07727 Mdot
.984 .07793 Mdot
.984 .07825 Mdot
.984 .07841 Mdot
.984 .07869 Mdot
.984 .0788 Mdot
.984 .07953 Mdot
.984 .07964 Mdot
.984 .07965 Mdot
.984 .08024 Mdot
.984 .08097 Mdot
.984 .08355 Mdot
.984 .08394 Mdot
.984 .08418 Mdot
.984 .08443 Mdot
.984 .08483 Mdot
.984 .08488 Mdot
.984 .08503 Mdot
.984 .08512 Mdot
.984 .08662 Mdot
.984 .08698 Mdot
.984 .08698 Mdot
.984 .08702 Mdot
.984 .08708 Mdot
.984 .0883 Mdot
.984 .08931 Mdot
.984 .09116 Mdot
.984 .0948 Mdot
.984 .09565 Mdot
.984 .09588 Mdot
.984 .097 Mdot
.984 .09852 Mdot
.984 .0989 Mdot
.984 .09909 Mdot
.984 .09939 Mdot
.984 .1002 Mdot
.984 .10055 Mdot
.984 .10109 Mdot
.984 .10171 Mdot
.984 .1021 Mdot
.984 .10239 Mdot
.984 .10256 Mdot
.984 .10279 Mdot
.984 .10282 Mdot
.984 .10293 Mdot
.984 .1037 Mdot
.984 .10382 Mdot
.984 .10417 Mdot
.984 .10436 Mdot
.984 .10453 Mdot
.984 .10483 Mdot
.984 .10495 Mdot
.984 .10518 Mdot
.984 .10527 Mdot
.984 .10558 Mdot
.984 .10713 Mdot
.984 .10772 Mdot
.984 .10915 Mdot
.984 .10924 Mdot
.984 .10983 Mdot
.984 .10997 Mdot
.984 .11054 Mdot
.984 .11083 Mdot
.984 .11099 Mdot
.984 .11104 Mdot
.984 .11198 Mdot
.984 .11201 Mdot
.984 .11299 Mdot
.984 .11312 Mdot
.984 .11397 Mdot
.984 .11464 Mdot
.984 .11499 Mdot
.984 .11608 Mdot
.984 .11613 Mdot
.984 .11713 Mdot
.984 .11742 Mdot
.984 .11885 Mdot
.984 .1197 Mdot
.984 .12058 Mdot
.984 .12228 Mdot
.984 .12235 Mdot
.984 .12284 Mdot
.984 .12302 Mdot
.984 .12304 Mdot
.984 .12323 Mdot
.984 .1241 Mdot
.984 .12517 Mdot
.984 .12537 Mdot
.984 .12541 Mdot
.984 .12553 Mdot
.984 .12587 Mdot
.984 .12619 Mdot
.984 .12669 Mdot
.984 .12671 Mdot
.984 .12768 Mdot
.984 .12787 Mdot
.984 .1279 Mdot
.984 .12896 Mdot
.984 .12963 Mdot
.984 .13154 Mdot
.984 .13238 Mdot
.984 .13291 Mdot
.984 .13402 Mdot
.984 .1341 Mdot
.984 .13418 Mdot
.984 .13427 Mdot
.984 .13519 Mdot
.984 .13627 Mdot
.984 .13724 Mdot
.984 .13764 Mdot
.984 .13782 Mdot
.984 .13912 Mdot
.984 .13926 Mdot
.984 .13975 Mdot
.984 .1399 Mdot
.984 .14007 Mdot
.984 .14062 Mdot
.984 .14084 Mdot
.984 .14111 Mdot
.984 .14172 Mdot
.984 .14227 Mdot
.984 .14248 Mdot
.984 .14251 Mdot
.984 .14322 Mdot
.984 .14367 Mdot
.984 .14426 Mdot
.984 .1451 Mdot
.984 .14551 Mdot
.984 .14638 Mdot
.984 .14805 Mdot
.984 .15018 Mdot
.984 .1503 Mdot
.984 .15096 Mdot
.984 .15142 Mdot
.984 .15191 Mdot
.984 .15242 Mdot
.984 .15258 Mdot
.984 .15269 Mdot
.984 .15281 Mdot
.984 .15309 Mdot
.984 .15327 Mdot
.984 .15331 Mdot
.984 .1538 Mdot
.984 .15402 Mdot
.984 .15408 Mdot
.984 .15587 Mdot
.984 .15622 Mdot
.984 .15662 Mdot
.984 .15694 Mdot
.984 .15694 Mdot
.984 .15701 Mdot
.984 .15713 Mdot
.984 .15723 Mdot
.984 .15781 Mdot
.984 .15887 Mdot
.984 .15953 Mdot
.984 .16037 Mdot
.984 .16153 Mdot
.984 .16316 Mdot
.984 .16317 Mdot
.984 .16516 Mdot
.984 .16544 Mdot
.984 .16552 Mdot
.984 .1664 Mdot
.984 .16663 Mdot
.984 .16699 Mdot
.984 .16794 Mdot
.984 .16836 Mdot
.984 .17084 Mdot
.984 .17131 Mdot
.984 .17232 Mdot
.984 .17291 Mdot
.984 .17399 Mdot
.984 .1742 Mdot
.984 .17444 Mdot
.984 .17445 Mdot
.984 .17622 Mdot
.984 .17665 Mdot
.984 .17735 Mdot
.984 .17757 Mdot
.984 .17954 Mdot
.984 .17965 Mdot
.984 .1804 Mdot
.984 .18077 Mdot
.984 .18136 Mdot
.984 .18169 Mdot
.984 .18188 Mdot
.984 .1829 Mdot
.984 .18296 Mdot
.984 .18362 Mdot
.984 .18364 Mdot
.984 .1847 Mdot
.984 .18592 Mdot
.984 .1867 Mdot
.984 .18726 Mdot
.984 .1876 Mdot
.984 .18764 Mdot
.984 .18806 Mdot
.984 .18811 Mdot
.984 .18832 Mdot
.984 .18937 Mdot
.984 .18983 Mdot
.984 .19008 Mdot
.984 .19076 Mdot
.984 .19113 Mdot
.984 .19114 Mdot
.984 .19148 Mdot
.984 .19207 Mdot
.984 .19229 Mdot
.984 .19273 Mdot
.984 .19275 Mdot
.984 .19293 Mdot
.984 .19336 Mdot
.984 .19353 Mdot
.984 .19388 Mdot
.984 .19446 Mdot
.984 .19659 Mdot
.984 .19712 Mdot
.984 .19759 Mdot
.984 .19775 Mdot
.984 .20056 Mdot
.984 .20074 Mdot
.984 .20093 Mdot
.984 .20094 Mdot
.984 .20191 Mdot
.984 .20218 Mdot
.984 .20257 Mdot
.984 .20329 Mdot
.984 .20388 Mdot
.984 .20412 Mdot
.984 .20418 Mdot
.984 .20428 Mdot
.984 .20463 Mdot
.984 .20539 Mdot
.984 .20581 Mdot
.984 .20614 Mdot
.984 .2062 Mdot
.984 .20695 Mdot
.984 .20812 Mdot
.984 .20838 Mdot
.984 .20961 Mdot
.984 .21005 Mdot
.984 .21109 Mdot
.984 .21122 Mdot
.984 .21137 Mdot
.984 .21205 Mdot
.984 .21346 Mdot
.984 .21419 Mdot
.984 .2143 Mdot
.984 .21528 Mdot
.984 .21566 Mdot
.984 .21628 Mdot
.984 .21684 Mdot
.984 .21965 Mdot
.984 .22046 Mdot
.984 .22132 Mdot
.984 .22195 Mdot
.984 .22248 Mdot
.984 .22303 Mdot
.984 .22306 Mdot
.984 .22353 Mdot
.984 .22517 Mdot
.984 .22641 Mdot
.984 .22653 Mdot
.984 .22654 Mdot
.984 .2268 Mdot
.984 .22751 Mdot
.984 .22785 Mdot
.984 .22789 Mdot
.984 .22827 Mdot
.984 .22966 Mdot
.984 .22998 Mdot
.984 .23079 Mdot
.984 .23112 Mdot
.984 .23208 Mdot
.984 .23238 Mdot
.984 .23244 Mdot
.984 .23247 Mdot
.984 .23256 Mdot
.984 .23281 Mdot
.984 .23302 Mdot
.984 .23347 Mdot
.984 .23409 Mdot
.984 .23469 Mdot
.984 .23508 Mdot
.984 .23512 Mdot
.984 .23546 Mdot
.984 .23702 Mdot
.984 .23741 Mdot
.984 .23746 Mdot
.984 .2375 Mdot
.984 .238 Mdot
.984 .23954 Mdot
.984 .23963 Mdot
.984 .23976 Mdot
.984 .24081 Mdot
.984 .24088 Mdot
.984 .24117 Mdot
.984 .24157 Mdot
.984 .24202 Mdot
.984 .24282 Mdot
.984 .24342 Mdot
.984 .24463 Mdot
.984 .24621 Mdot
.984 .24628 Mdot
.984 .24732 Mdot
.984 .24792 Mdot
.984 .24813 Mdot
.984 .24951 Mdot
.984 .2496 Mdot
.984 .24966 Mdot
.984 .24982 Mdot
.984 .25 Mdot
.984 .25181 Mdot
.984 .25272 Mdot
.984 .25318 Mdot
.984 .25322 Mdot
.984 .25393 Mdot
.984 .25421 Mdot
.984 .25584 Mdot
.984 .25615 Mdot
.984 .25663 Mdot
.984 .25698 Mdot
.984 .25699 Mdot
.984 .25816 Mdot
.984 .2583 Mdot
.984 .25846 Mdot
.984 .25955 Mdot
.984 .25982 Mdot
.984 .25992 Mdot
.984 .26078 Mdot
.984 .26109 Mdot
.984 .26141 Mdot
.984 .26249 Mdot
.984 .26267 Mdot
.984 .26293 Mdot
.984 .26346 Mdot
.984 .26445 Mdot
.984 .26466 Mdot
.984 .2653 Mdot
.984 .26574 Mdot
.984 .26615 Mdot
.984 .26622 Mdot
.984 .26652 Mdot
.984 .26762 Mdot
.984 .26849 Mdot
.984 .26913 Mdot
.984 .26965 Mdot
.984 .2697 Mdot
.984 .27097 Mdot
.984 .27113 Mdot
.984 .27131 Mdot
.984 .27212 Mdot
.984 .27383 Mdot
.984 .27468 Mdot
.984 .27584 Mdot
.984 .27608 Mdot
.984 .2762 Mdot
.984 .27652 Mdot
.984 .27711 Mdot
.984 .27749 Mdot
.984 .27758 Mdot
.984 .27796 Mdot
.984 .2783 Mdot
.984 .27847 Mdot
.984 .27978 Mdot
.984 .28004 Mdot
.984 .28072 Mdot
.984 .28104 Mdot
.984 .28131 Mdot
.984 .28155 Mdot
.984 .28247 Mdot
.984 .28284 Mdot
.984 .28299 Mdot
.984 .28314 Mdot
.984 .28376 Mdot
.984 .28471 Mdot
.984 .28477 Mdot
.984 .28572 Mdot
.984 .28603 Mdot
.984 .28626 Mdot
.984 .2863 Mdot
.984 .28644 Mdot
.984 .28648 Mdot
.984 .28704 Mdot
.984 .28739 Mdot
.984 .28748 Mdot
.984 .28763 Mdot
.984 .28776 Mdot
.984 .28844 Mdot
.984 .28887 Mdot
.984 .28898 Mdot
.984 .2896 Mdot
.984 .2905 Mdot
.984 .29123 Mdot
.984 .29251 Mdot
.984 .2932 Mdot
.984 .29381 Mdot
.984 .29398 Mdot
.984 .29413 Mdot
.984 .29461 Mdot
.984 .29461 Mdot
.984 .29476 Mdot
.984 .29498 Mdot
.984 .29519 Mdot
.984 .2953 Mdot
.984 .29553 Mdot
.984 .29566 Mdot
.984 .29633 Mdot
.984 .29674 Mdot
.984 .29762 Mdot
.984 .29798 Mdot
.984 .29842 Mdot
.984 .2997 Mdot
.984 .30136 Mdot
.984 .30358 Mdot
.984 .30364 Mdot
.984 .30393 Mdot
.984 .3044 Mdot
.984 .30685 Mdot
.984 .30688 Mdot
.984 .30799 Mdot
.984 .30849 Mdot
.984 .30874 Mdot
.984 .30883 Mdot
.984 .3099 Mdot
.984 .30997 Mdot
.984 .31078 Mdot
.984 .31135 Mdot
.984 .31144 Mdot
.984 .3115 Mdot
.984 .31256 Mdot
.984 .31318 Mdot
.984 .31324 Mdot
.984 .31369 Mdot
.984 .3144 Mdot
.984 .31472 Mdot
.984 .31519 Mdot
.984 .31627 Mdot
.984 .31627 Mdot
.984 .31708 Mdot
.984 .31762 Mdot
.984 .31859 Mdot
.984 .31962 Mdot
.984 .32151 Mdot
.984 .32197 Mdot
.984 .32289 Mdot
.984 .32329 Mdot
.984 .32489 Mdot
.984 .32605 Mdot
.984 .32817 Mdot
.984 .32851 Mdot
.984 .32857 Mdot
.984 .32906 Mdot
.984 .32907 Mdot
.984 .32939 Mdot
.984 .32966 Mdot
.984 .33129 Mdot
.984 .33247 Mdot
.984 .33256 Mdot
.984 .3334 Mdot
.984 .33359 Mdot
.984 .33366 Mdot
.984 .33369 Mdot
.984 .33478 Mdot
.984 .33521 Mdot
.984 .33602 Mdot
.984 .33684 Mdot
.984 .33831 Mdot
.984 .3391 Mdot
.984 .33931 Mdot
.984 .34078 Mdot
.984 .3415 Mdot
.984 .34218 Mdot
.984 .34252 Mdot
.984 .34268 Mdot
.984 .34276 Mdot
.984 .34333 Mdot
.984 .34339 Mdot
.984 .34369 Mdot
.984 .34406 Mdot
.984 .34557 Mdot
.984 .34569 Mdot
.984 .34582 Mdot
.984 .34602 Mdot
.984 .34712 Mdot
.984 .34717 Mdot
.984 .34924 Mdot
.984 .35109 Mdot
.984 .35164 Mdot
.984 .35317 Mdot
.984 .35327 Mdot
.984 .35428 Mdot
.984 .3546 Mdot
.984 .35495 Mdot
.984 .35503 Mdot
.984 .35561 Mdot
.984 .35585 Mdot
.984 .35595 Mdot
.984 .35636 Mdot
.984 .35641 Mdot
.984 .35657 Mdot
.984 .35736 Mdot
.984 .35766 Mdot
.984 .35843 Mdot
.984 .35873 Mdot
.984 .35909 Mdot
.984 .35932 Mdot
.984 .35934 Mdot
.984 .35984 Mdot
.984 .3604 Mdot
.984 .36117 Mdot
.984 .3619 Mdot
.984 .36193 Mdot
.984 .36258 Mdot
.984 .36331 Mdot
.984 .36374 Mdot
.984 .36419 Mdot
.984 .36506 Mdot
.984 .36509 Mdot
.984 .36544 Mdot
.984 .36598 Mdot
.984 .36662 Mdot
.984 .36664 Mdot
.984 .36671 Mdot
.984 .36704 Mdot
.984 .3673 Mdot
.984 .36779 Mdot
.984 .36789 Mdot
.984 .36791 Mdot
.984 .36845 Mdot
.984 .36879 Mdot
.984 .36976 Mdot
.984 .3711 Mdot
.984 .37114 Mdot
.984 .37216 Mdot
.984 .37265 Mdot
.984 .37368 Mdot
.984 .37401 Mdot
.984 .37462 Mdot
.984 .37493 Mdot
.984 .37569 Mdot
.984 .37622 Mdot
.984 .37686 Mdot
.984 .3773 Mdot
.984 .37815 Mdot
.984 .37929 Mdot
.984 .38037 Mdot
.984 .38045 Mdot
.984 .38082 Mdot
.984 .38107 Mdot
.984 .38118 Mdot
.984 .38121 Mdot
.984 .38212 Mdot
.984 .3825 Mdot
.984 .38281 Mdot
.984 .38311 Mdot
.984 .38365 Mdot
.984 .38441 Mdot
.984 .38582 Mdot
.984 .38583 Mdot
.984 .38698 Mdot
.984 .38702 Mdot
.984 .38747 Mdot
.984 .38759 Mdot
.984 .38777 Mdot
.984 .38826 Mdot
.984 .38847 Mdot
.984 .38973 Mdot
.984 .38997 Mdot
.984 .39078 Mdot
.984 .39143 Mdot
.984 .39156 Mdot
.984 .39246 Mdot
.984 .39304 Mdot
.984 .39315 Mdot
.984 .39415 Mdot
.984 .39524 Mdot
.984 .39534 Mdot
.984 .39585 Mdot
.984 .39622 Mdot
.984 .39827 Mdot
.984 .39914 Mdot
.984 .40004 Mdot
.984 .40085 Mdot
.984 .40117 Mdot
.984 .40143 Mdot
.984 .40173 Mdot
.984 .40308 Mdot
.984 .40332 Mdot
.984 .40502 Mdot
.984 .40502 Mdot
.984 .40585 Mdot
.984 .40664 Mdot
.984 .4069 Mdot
.984 .40728 Mdot
.984 .4075 Mdot
.984 .40808 Mdot
.984 .40943 Mdot
.984 .41018 Mdot
.984 .41025 Mdot
.984 .41139 Mdot
.984 .41231 Mdot
.984 .4125 Mdot
.984 .41494 Mdot
.984 .4157 Mdot
.984 .41597 Mdot
.984 .41625 Mdot
.984 .4165 Mdot
.984 .41734 Mdot
.984 .41803 Mdot
.984 .41816 Mdot
.984 .41962 Mdot
.984 .42019 Mdot
.984 .42036 Mdot
.984 .421 Mdot
.984 .42103 Mdot
.984 .42132 Mdot
.984 .42217 Mdot
.984 .42256 Mdot
.984 .4236 Mdot
.984 .42386 Mdot
.984 .42468 Mdot
.984 .42475 Mdot
.984 .42528 Mdot
.984 .42547 Mdot
.984 .42567 Mdot
.984 .4259 Mdot
.984 .4263 Mdot
.984 .42661 Mdot
.984 .42802 Mdot
.984 .42889 Mdot
.984 .429 Mdot
.984 .42975 Mdot
.984 .43133 Mdot
.984 .43157 Mdot
.984 .43159 Mdot
.984 .43209 Mdot
.984 .43308 Mdot
.984 .4335 Mdot
.984 .4341 Mdot
.984 .43417 Mdot
.984 .43425 Mdot
.984 .43499 Mdot
.984 .43639 Mdot
.984 .43729 Mdot
.984 .43772 Mdot
.984 .43835 Mdot
.984 .43967 Mdot
.984 .43996 Mdot
.984 .44061 Mdot
.984 .44069 Mdot
.984 .44249 Mdot
.984 .44308 Mdot
.984 .4432 Mdot
.984 .44327 Mdot
.984 .44343 Mdot
.984 .44392 Mdot
.984 .44397 Mdot
.984 .44416 Mdot
.984 .44433 Mdot
.984 .44442 Mdot
.984 .44508 Mdot
.984 .44522 Mdot
.984 .44556 Mdot
.984 .44573 Mdot
.984 .44645 Mdot
.984 .44672 Mdot
.984 .44679 Mdot
.984 .44762 Mdot
.984 .44839 Mdot
.984 .44847 Mdot
.984 .44907 Mdot
.984 .44914 Mdot
.984 .45007 Mdot
.984 .45053 Mdot
.984 .4509 Mdot
.984 .45221 Mdot
.984 .45237 Mdot
.984 .45297 Mdot
.984 .45309 Mdot
.984 .45315 Mdot
.984 .4537 Mdot
.984 .45415 Mdot
.984 .45433 Mdot
.984 .45718 Mdot
.984 .45735 Mdot
.984 .45759 Mdot
.984 .45942 Mdot
.984 .45967 Mdot
.984 .4598 Mdot
.984 .45984 Mdot
.984 .46039 Mdot
.984 .46042 Mdot
.984 .46117 Mdot
.984 .46174 Mdot
.984 .46206 Mdot
.984 .46284 Mdot
.984 .46308 Mdot
.984 .46362 Mdot
.984 .46431 Mdot
.984 .4648 Mdot
.984 .46533 Mdot
.984 .46629 Mdot
.984 .46719 Mdot
.984 .46985 Mdot
.984 .47029 Mdot
.984 .47043 Mdot
.984 .47126 Mdot
.984 .47186 Mdot
.984 .47242 Mdot
.984 .47246 Mdot
.984 .47248 Mdot
.984 .47366 Mdot
.984 .47408 Mdot
.984 .47483 Mdot
.984 .47679 Mdot
.984 .47696 Mdot
.984 .47709 Mdot
.984 .47741 Mdot
.984 .47775 Mdot
.984 .47852 Mdot
.984 .47874 Mdot
.984 .48132 Mdot
.984 .48243 Mdot
.984 .4831 Mdot
.984 .48362 Mdot
.984 .48402 Mdot
.984 .4841 Mdot
.984 .4845 Mdot
.984 .48465 Mdot
.984 .4852 Mdot
.984 .48538 Mdot
.984 .4855 Mdot
.984 .48605 Mdot
.984 .48753 Mdot
.984 .48888 Mdot
.984 .48922 Mdot
.984 .48925 Mdot
.984 .48942 Mdot
.984 .48981 Mdot
.984 .48986 Mdot
.984 .48986 Mdot
.984 .49031 Mdot
.984 .49081 Mdot
.984 .49149 Mdot
.984 .49151 Mdot
.984 .49203 Mdot
.984 .49296 Mdot
.984 .49382 Mdot
.984 .49409 Mdot
.984 .49441 Mdot
.984 .49464 Mdot
.984 .49507 Mdot
.984 .49565 Mdot
.984 .4962 Mdot
.984 .49655 Mdot
.984 .49709 Mdot
.984 .49728 Mdot
.984 .49744 Mdot
.984 .49897 Mdot
.984 .49958 Mdot
.984 .5002 Mdot
.984 .50095 Mdot
.984 .50234 Mdot
.984 .50269 Mdot
.984 .5032 Mdot
.984 .50375 Mdot
.984 .50425 Mdot
.984 .50619 Mdot
.984 .5066 Mdot
.984 .50786 Mdot
.984 .50872 Mdot
.984 .50872 Mdot
.984 .50955 Mdot
.984 .50968 Mdot
.984 .51028 Mdot
.984 .51138 Mdot
.984 .51243 Mdot
.984 .51376 Mdot
.984 .51415 Mdot
.984 .51428 Mdot
.984 .51443 Mdot
.984 .51456 Mdot
.984 .51498 Mdot
.984 .5154 Mdot
.984 .51643 Mdot
.984 .51652 Mdot
.984 .51684 Mdot
.984 .51686 Mdot
.984 .51744 Mdot
.984 .51829 Mdot
.984 .51902 Mdot
.984 .51911 Mdot
.984 .51933 Mdot
.984 .51954 Mdot
.984 .51969 Mdot
.984 .52041 Mdot
.984 .52091 Mdot
.984 .52129 Mdot
.984 .52298 Mdot
.984 .5235 Mdot
.984 .52466 Mdot
.984 .52512 Mdot
.984 .52633 Mdot
.984 .52684 Mdot
.984 .52851 Mdot
.984 .52861 Mdot
.984 .52874 Mdot
.984 .52908 Mdot
.984 .52932 Mdot
.984 .52941 Mdot
.984 .52991 Mdot
.984 .52995 Mdot
.984 .53111 Mdot
.984 .53161 Mdot
.984 .53185 Mdot
.984 .53204 Mdot
.984 .53278 Mdot
.984 .53346 Mdot
.984 .53378 Mdot
.984 .53636 Mdot
.984 .53658 Mdot
.984 .53687 Mdot
.984 .53754 Mdot
.984 .5381 Mdot
.984 .53822 Mdot
.984 .53885 Mdot
.984 .53937 Mdot
.984 .53985 Mdot
.984 .54166 Mdot
.984 .54238 Mdot
.984 .54268 Mdot
.984 .54297 Mdot
.984 .54299 Mdot
.984 .54419 Mdot
.984 .54607 Mdot
.984 .54618 Mdot
.984 .54805 Mdot
.984 .54866 Mdot
.984 .54911 Mdot
.984 .54919 Mdot
.984 .54946 Mdot
.984 .54956 Mdot
.984 .55065 Mdot
.984 .55133 Mdot
.984 .55151 Mdot
.984 .55161 Mdot
.984 .5518 Mdot
.984 .55183 Mdot
.984 .55206 Mdot
.984 .55293 Mdot
.984 .55341 Mdot
.984 .55426 Mdot
.984 .55448 Mdot
.984 .55477 Mdot
.984 .55568 Mdot
.984 .55747 Mdot
.984 .55889 Mdot
.984 .56141 Mdot
.984 .56276 Mdot
.984 .56398 Mdot
.984 .56424 Mdot
.984 .56431 Mdot
.984 .56438 Mdot
.984 .5646 Mdot
.984 .56554 Mdot
.984 .56555 Mdot
.984 .56584 Mdot
.984 .56628 Mdot
.984 .5667 Mdot
.984 .56691 Mdot
.984 .56736 Mdot
.984 .56761 Mdot
.984 .56866 Mdot
.984 .56892 Mdot
.984 .56975 Mdot
.984 .57062 Mdot
.984 .57147 Mdot
.984 .57159 Mdot
.984 .57193 Mdot
.984 .57218 Mdot
.984 .57305 Mdot
.984 .57557 Mdot
.984 .57606 Mdot
.984 .57634 Mdot
.984 .57883 Mdot
.984 .58321 Mdot
.984 .58332 Mdot
.984 .58388 Mdot
.984 .58482 Mdot
.984 .58963 Mdot
.984 .5897 Mdot
.984 .59187 Mdot
.984 .59287 Mdot
.984 .59336 Mdot
.984 .59353 Mdot
.984 .59563 Mdot
.984 .59578 Mdot
.986 .01692 Mdot
.986 .01713 Mdot
.986 .01755 Mdot
.986 .01906 Mdot
.986 .01949 Mdot
.986 .0196 Mdot
.986 .0203 Mdot
.986 .02031 Mdot
.986 .02067 Mdot
.986 .02116 Mdot
.986 .02306 Mdot
.986 .02328 Mdot
.986 .02336 Mdot
.986 .02337 Mdot
.986 .0237 Mdot
.986 .0238 Mdot
.986 .02412 Mdot
.986 .02434 Mdot
.986 .02468 Mdot
.986 .02572 Mdot
.986 .02574 Mdot
.986 .02645 Mdot
.986 .02743 Mdot
.986 .02918 Mdot
.986 .03004 Mdot
.986 .03117 Mdot
.986 .03161 Mdot
.986 .03177 Mdot
.986 .03177 Mdot
.986 .03243 Mdot
.986 .03263 Mdot
.986 .03314 Mdot
.986 .03327 Mdot
.986 .0337 Mdot
.986 .03389 Mdot
.986 .03395 Mdot
.986 .03436 Mdot
.986 .03496 Mdot
.986 .03546 Mdot
.986 .03642 Mdot
.986 .03646 Mdot
.986 .03785 Mdot
.986 .03828 Mdot
.986 .03871 Mdot
.986 .03979 Mdot
.986 .04284 Mdot
.986 .04324 Mdot
.986 .04493 Mdot
.986 .04511 Mdot
.986 .04513 Mdot
.986 .04577 Mdot
.986 .04716 Mdot
.986 .04748 Mdot
.986 .04803 Mdot
.986 .04835 Mdot
.986 .04835 Mdot
.986 .04913 Mdot
.986 .04965 Mdot
.986 .04978 Mdot
.986 .05005 Mdot
.986 .0502 Mdot
.986 .05058 Mdot
.986 .05106 Mdot
.986 .0513 Mdot
.986 .05215 Mdot
.986 .05253 Mdot
.986 .05265 Mdot
.986 .0528 Mdot
.986 .05292 Mdot
.986 .05346 Mdot
.986 .05464 Mdot
.986 .05562 Mdot
.986 .05637 Mdot
.986 .05752 Mdot
.986 .05759 Mdot
.986 .05898 Mdot
.986 .05977 Mdot
.986 .06032 Mdot
.986 .06034 Mdot
.986 .06081 Mdot
.986 .06119 Mdot
.986 .06154 Mdot
.986 .06202 Mdot
.986 .0633 Mdot
.986 .06334 Mdot
.986 .06417 Mdot
.986 .06584 Mdot
.986 .06829 Mdot
.986 .06941 Mdot
.986 .06946 Mdot
.986 .07019 Mdot
.986 .07053 Mdot
.986 .07068 Mdot
.986 .07097 Mdot
.986 .07261 Mdot
.986 .07282 Mdot
.986 .07411 Mdot
.986 .07431 Mdot
.986 .07435 Mdot
.986 .07466 Mdot
.986 .0747 Mdot
.986 .07596 Mdot
.986 .07645 Mdot
.986 .07685 Mdot
.986 .07793 Mdot
.986 .07802 Mdot
.986 .07806 Mdot
.986 .07869 Mdot
.986 .07903 Mdot
.986 .07932 Mdot
.986 .08005 Mdot
.986 .08041 Mdot
.986 .08105 Mdot
.986 .08105 Mdot
.986 .08133 Mdot
.986 .08136 Mdot
.986 .08258 Mdot
.986 .08361 Mdot
.986 .08387 Mdot
.986 .0842 Mdot
.986 .0844 Mdot
.986 .08469 Mdot
.986 .08543 Mdot
.986 .08545 Mdot
.986 .08638 Mdot
.986 .08687 Mdot
.986 .08854 Mdot
.986 .08861 Mdot
.986 .08929 Mdot
.986 .08953 Mdot
.986 .08954 Mdot
.986 .08982 Mdot
.986 .09005 Mdot
.986 .09067 Mdot
.986 .09104 Mdot
.986 .09112 Mdot
.986 .09188 Mdot
.986 .09264 Mdot
.986 .09315 Mdot
.986 .09345 Mdot
.986 .09524 Mdot
.986 .09532 Mdot
.986 .09538 Mdot
.986 .09618 Mdot
.986 .09663 Mdot
.986 .09686 Mdot
.986 .09805 Mdot
.986 .09853 Mdot
.986 .09914 Mdot
.986 .09927 Mdot
.986 .09981 Mdot
.986 .10065 Mdot
.986 .10098 Mdot
.986 .102 Mdot
.986 .10252 Mdot
.986 .10357 Mdot
.986 .10461 Mdot
.986 .10465 Mdot
.986 .1047 Mdot
.986 .10497 Mdot
.986 .10561 Mdot
.986 .10569 Mdot
.986 .10636 Mdot
.986 .10705 Mdot
.986 .10801 Mdot
.986 .10827 Mdot
.986 .11002 Mdot
.986 .11052 Mdot
.986 .11061 Mdot
.986 .11082 Mdot
.986 .11214 Mdot
.986 .11224 Mdot
.986 .11239 Mdot
.986 .11242 Mdot
.986 .11303 Mdot
.986 .11325 Mdot
.986 .11554 Mdot
.986 .11626 Mdot
.986 .12036 Mdot
.986 .12104 Mdot
.986 .12127 Mdot
.986 .12129 Mdot
.986 .12166 Mdot
.986 .12231 Mdot
.986 .12257 Mdot
.986 .12267 Mdot
.986 .12276 Mdot
.986 .12379 Mdot
.986 .12405 Mdot
.986 .1241 Mdot
.986 .12478 Mdot
.986 .12508 Mdot
.986 .12564 Mdot
.986 .12689 Mdot
.986 .12868 Mdot
.986 .12888 Mdot
.986 .12926 Mdot
.986 .12927 Mdot
.986 .12929 Mdot
.986 .1293 Mdot
.986 .13183 Mdot
.986 .13223 Mdot
.986 .13232 Mdot
.986 .13293 Mdot
.986 .133 Mdot
.986 .13425 Mdot
.986 .13441 Mdot
.986 .13482 Mdot
.986 .13549 Mdot
.986 .13645 Mdot
.986 .13725 Mdot
.986 .1378 Mdot
.986 .13792 Mdot
.986 .13866 Mdot
.986 .13937 Mdot
.986 .13955 Mdot
.986 .13962 Mdot
.986 .13974 Mdot
.986 .14088 Mdot
.986 .14154 Mdot
.986 .14211 Mdot
.986 .14315 Mdot
.986 .14355 Mdot
.986 .14369 Mdot
.986 .14389 Mdot
.986 .14427 Mdot
.986 .1443 Mdot
.986 .14497 Mdot
.986 .14552 Mdot
.986 .14553 Mdot
.986 .14607 Mdot
.986 .14614 Mdot
.986 .14706 Mdot
.986 .14855 Mdot
.986 .14906 Mdot
.986 .15057 Mdot
.986 .15109 Mdot
.986 .15109 Mdot
.986 .15174 Mdot
.986 .15213 Mdot
.986 .1527 Mdot
.986 .15287 Mdot
.986 .15417 Mdot
.986 .1542 Mdot
.986 .15604 Mdot
.986 .15604 Mdot
.986 .15621 Mdot
.986 .157 Mdot
.986 .15875 Mdot
.986 .1603 Mdot
.986 .16043 Mdot
.986 .16072 Mdot
.986 .16177 Mdot
.986 .16212 Mdot
.986 .16225 Mdot
.986 .16227 Mdot
.986 .16248 Mdot
.986 .16272 Mdot
.986 .16283 Mdot
.986 .16327 Mdot
.986 .16389 Mdot
.986 .16444 Mdot
.986 .1645 Mdot
.986 .16522 Mdot
.986 .16538 Mdot
.986 .16591 Mdot
.986 .16631 Mdot
.986 .16688 Mdot
.986 .16688 Mdot
.986 .16699 Mdot
.986 .16837 Mdot
.986 .1686 Mdot
.986 .16939 Mdot
.986 .1696 Mdot
.986 .16999 Mdot
.986 .17071 Mdot
.986 .17082 Mdot
.986 .17189 Mdot
.986 .17247 Mdot
.986 .17248 Mdot
.986 .17264 Mdot
.986 .17308 Mdot
.986 .1735 Mdot
.986 .17367 Mdot
.986 .17378 Mdot
.986 .17388 Mdot
.986 .17537 Mdot
.986 .17624 Mdot
.986 .1767 Mdot
.986 .17872 Mdot
.986 .17905 Mdot
.986 .17954 Mdot
.986 .17999 Mdot
.986 .18063 Mdot
.986 .18091 Mdot
.986 .18119 Mdot
.986 .18146 Mdot
.986 .18252 Mdot
.986 .18419 Mdot
.986 .18469 Mdot
.986 .18482 Mdot
.986 .1856 Mdot
.986 .18684 Mdot
.986 .18723 Mdot
.986 .18786 Mdot
.986 .18971 Mdot
.986 .18994 Mdot
.986 .19077 Mdot
.986 .192 Mdot
.986 .19206 Mdot
.986 .19216 Mdot
.986 .19232 Mdot
.986 .1927 Mdot
.986 .19277 Mdot
.986 .1935 Mdot
.986 .19396 Mdot
.986 .19412 Mdot
.986 .19543 Mdot
.986 .19653 Mdot
.986 .1968 Mdot
.986 .19782 Mdot
.986 .19798 Mdot
.986 .19869 Mdot
.986 .1992 Mdot
.986 .19972 Mdot
.986 .201 Mdot
.986 .2022 Mdot
.986 .20265 Mdot
.986 .20364 Mdot
.986 .20381 Mdot
.986 .20423 Mdot
.986 .2048 Mdot
.986 .20507 Mdot
.986 .20522 Mdot
.986 .20683 Mdot
.986 .20704 Mdot
.986 .20732 Mdot
.986 .20739 Mdot
.986 .20836 Mdot
.986 .2086 Mdot
.986 .20902 Mdot
.986 .21033 Mdot
.986 .21174 Mdot
.986 .21256 Mdot
.986 .21287 Mdot
.986 .21353 Mdot
.986 .21496 Mdot
.986 .21785 Mdot
.986 .21944 Mdot
.986 .22006 Mdot
.986 .22154 Mdot
.986 .22157 Mdot
.986 .22191 Mdot
.986 .22304 Mdot
.986 .22404 Mdot
.986 .22439 Mdot
.986 .22483 Mdot
.986 .22489 Mdot
.986 .22514 Mdot
.986 .22562 Mdot
.986 .22634 Mdot
.986 .22689 Mdot
.986 .2274 Mdot
.986 .22759 Mdot
.986 .22777 Mdot
.986 .22778 Mdot
.986 .22877 Mdot
.986 .22886 Mdot
.986 .22982 Mdot
.986 .23014 Mdot
.986 .23016 Mdot
.986 .23033 Mdot
.986 .23043 Mdot
.986 .23176 Mdot
.986 .23226 Mdot
.986 .23236 Mdot
.986 .23283 Mdot
.986 .23346 Mdot
.986 .23407 Mdot
.986 .23435 Mdot
.986 .23477 Mdot
.986 .23525 Mdot
.986 .23536 Mdot
.986 .23592 Mdot
.986 .23592 Mdot
.986 .23604 Mdot
.986 .23738 Mdot
.986 .23946 Mdot
.986 .23986 Mdot
.986 .24034 Mdot
.986 .24059 Mdot
.986 .24061 Mdot
.986 .24065 Mdot
.986 .24067 Mdot
.986 .241 Mdot
.986 .24142 Mdot
.986 .24178 Mdot
.986 .24333 Mdot
.986 .24566 Mdot
.986 .24567 Mdot
.986 .24646 Mdot
.986 .24664 Mdot
.986 .24702 Mdot
.986 .24703 Mdot
.986 .24783 Mdot
.986 .24797 Mdot
.986 .24874 Mdot
.986 .24895 Mdot
.986 .24991 Mdot
.986 .25045 Mdot
.986 .25075 Mdot
.986 .25156 Mdot
.986 .25162 Mdot
.986 .25179 Mdot
.986 .25289 Mdot
.986 .25322 Mdot
.986 .25458 Mdot
.986 .25478 Mdot
.986 .25635 Mdot
.986 .25674 Mdot
.986 .25744 Mdot
.986 .25753 Mdot
.986 .25767 Mdot
.986 .2587 Mdot
.986 .25914 Mdot
.986 .25947 Mdot
.986 .25991 Mdot
.986 .25999 Mdot
.986 .26014 Mdot
.986 .26021 Mdot
.986 .26053 Mdot
.986 .26089 Mdot
.986 .26103 Mdot
.986 .26126 Mdot
.986 .26351 Mdot
.986 .264 Mdot
.986 .26403 Mdot
.986 .2644 Mdot
.986 .26481 Mdot
.986 .26594 Mdot
.986 .26653 Mdot
.986 .26799 Mdot
.986 .26813 Mdot
.986 .26828 Mdot
.986 .26878 Mdot
.986 .26906 Mdot
.986 .26933 Mdot
.986 .26938 Mdot
.986 .26945 Mdot
.986 .26946 Mdot
.986 .27011 Mdot
.986 .2702 Mdot
.986 .27025 Mdot
.986 .2705 Mdot
.986 .27158 Mdot
.986 .27266 Mdot
.986 .27267 Mdot
.986 .27375 Mdot
.986 .27389 Mdot
.986 .27569 Mdot
.986 .2757 Mdot
.986 .27761 Mdot
.986 .27801 Mdot
.986 .27864 Mdot
.986 .27895 Mdot
.986 .27964 Mdot
.986 .27984 Mdot
.986 .28229 Mdot
.986 .28263 Mdot
.986 .28309 Mdot
.986 .28317 Mdot
.986 .28365 Mdot
.986 .28365 Mdot
.986 .28466 Mdot
.986 .28493 Mdot
.986 .28571 Mdot
.986 .28576 Mdot
.986 .28682 Mdot
.986 .28715 Mdot
.986 .28739 Mdot
.986 .28924 Mdot
.986 .28969 Mdot
.986 .28972 Mdot
.986 .28977 Mdot
.986 .29136 Mdot
.986 .29183 Mdot
.986 .29184 Mdot
.986 .29233 Mdot
.986 .29295 Mdot
.986 .2934 Mdot
.986 .29341 Mdot
.986 .29375 Mdot
.986 .2953 Mdot
.986 .2959 Mdot
.986 .29754 Mdot
.986 .29784 Mdot
.986 .29875 Mdot
.986 .30092 Mdot
.986 .30181 Mdot
.986 .30207 Mdot
.986 .30264 Mdot
.986 .3047 Mdot
.986 .30541 Mdot
.986 .30561 Mdot
.986 .30566 Mdot
.986 .30568 Mdot
.986 .30573 Mdot
.986 .30611 Mdot
.986 .30659 Mdot
.986 .3068 Mdot
.986 .30716 Mdot
.986 .30766 Mdot
.986 .30813 Mdot
.986 .30888 Mdot
.986 .30904 Mdot
.986 .30962 Mdot
.986 .30997 Mdot
.986 .31001 Mdot
.986 .31008 Mdot
.986 .31008 Mdot
.986 .31026 Mdot
.986 .31033 Mdot
.986 .31151 Mdot
.986 .31162 Mdot
.986 .31183 Mdot
.986 .31287 Mdot
.986 .31323 Mdot
.986 .31341 Mdot
.986 .31367 Mdot
.986 .31463 Mdot
.986 .31478 Mdot
.986 .31478 Mdot
.986 .31495 Mdot
.986 .315 Mdot
.986 .31545 Mdot
.986 .31773 Mdot
.986 .31817 Mdot
.986 .31974 Mdot
.986 .32012 Mdot
.986 .32015 Mdot
.986 .32066 Mdot
.986 .32091 Mdot
.986 .32235 Mdot
.986 .32256 Mdot
.986 .32466 Mdot
.986 .32581 Mdot
.986 .32582 Mdot
.986 .32615 Mdot
.986 .32701 Mdot
.986 .32785 Mdot
.986 .32818 Mdot
.986 .32839 Mdot
.986 .32858 Mdot
.986 .32971 Mdot
.986 .32977 Mdot
.986 .33152 Mdot
.986 .33284 Mdot
.986 .33325 Mdot
.986 .33352 Mdot
.986 .33377 Mdot
.986 .33414 Mdot
.986 .33503 Mdot
.986 .33505 Mdot
.986 .33632 Mdot
.986 .33756 Mdot
.986 .33813 Mdot
.986 .33816 Mdot
.986 .3387 Mdot
.986 .33878 Mdot
.986 .33975 Mdot
.986 .33986 Mdot
.986 .34051 Mdot
.986 .34064 Mdot
.986 .3417 Mdot
.986 .34191 Mdot
.986 .34245 Mdot
.986 .3425 Mdot
.986 .34252 Mdot
.986 .34301 Mdot
.986 .34353 Mdot
.986 .34418 Mdot
.986 .34419 Mdot
.986 .34563 Mdot
.986 .34626 Mdot
.986 .34787 Mdot
.986 .34834 Mdot
.986 .34891 Mdot
.986 .3491 Mdot
.986 .34953 Mdot
.986 .34991 Mdot
.986 .35017 Mdot
.986 .35123 Mdot
.986 .35127 Mdot
.986 .35171 Mdot
.986 .35193 Mdot
.986 .35265 Mdot
.986 .3529 Mdot
.986 .35355 Mdot
.986 .35398 Mdot
.986 .35414 Mdot
.986 .35492 Mdot
.986 .35598 Mdot
.986 .35617 Mdot
.986 .35653 Mdot
.986 .35784 Mdot
.986 .35872 Mdot
.986 .35913 Mdot
.986 .3598 Mdot
.986 .35992 Mdot
.986 .35994 Mdot
.986 .36025 Mdot
.986 .36036 Mdot
.986 .36189 Mdot
.986 .36432 Mdot
.986 .36443 Mdot
.986 .36444 Mdot
.986 .36463 Mdot
.986 .36496 Mdot
.986 .36519 Mdot
.986 .36571 Mdot
.986 .36584 Mdot
.986 .36728 Mdot
.986 .36819 Mdot
.986 .36848 Mdot
.986 .36848 Mdot
.986 .3685 Mdot
.986 .37101 Mdot
.986 .37109 Mdot
.986 .3713 Mdot
.986 .37281 Mdot
.986 .37287 Mdot
.986 .37325 Mdot
.986 .3738 Mdot
.986 .37552 Mdot
.986 .3758 Mdot
.986 .3759 Mdot
.986 .37611 Mdot
.986 .37645 Mdot
.986 .37751 Mdot
.986 .37852 Mdot
.986 .37955 Mdot
.986 .38045 Mdot
.986 .38206 Mdot
.986 .38215 Mdot
.986 .38343 Mdot
.986 .38444 Mdot
.986 .38515 Mdot
.986 .38533 Mdot
.986 .38545 Mdot
.986 .38604 Mdot
.986 .38632 Mdot
.986 .38707 Mdot
.986 .38727 Mdot
.986 .38756 Mdot
.986 .38762 Mdot
.986 .38843 Mdot
.986 .38894 Mdot
.986 .3895 Mdot
.986 .38956 Mdot
.986 .3901 Mdot
.986 .39039 Mdot
.986 .3904 Mdot
.986 .39048 Mdot
.986 .3907 Mdot
.986 .39111 Mdot
.986 .39356 Mdot
.986 .39398 Mdot
.986 .39453 Mdot
.986 .39467 Mdot
.986 .39659 Mdot
.986 .39705 Mdot
.986 .39788 Mdot
.986 .39913 Mdot
.986 .39967 Mdot
.986 .40046 Mdot
.986 .40069 Mdot
.986 .40106 Mdot
.986 .40116 Mdot
.986 .40259 Mdot
.986 .40325 Mdot
.986 .40333 Mdot
.986 .40421 Mdot
.986 .40486 Mdot
.986 .40547 Mdot
.986 .40679 Mdot
.986 .40693 Mdot
.986 .407 Mdot
.986 .4086 Mdot
.986 .40959 Mdot
.986 .41031 Mdot
.986 .41072 Mdot
.986 .41088 Mdot
.986 .4134 Mdot
.986 .41421 Mdot
.986 .41452 Mdot
.986 .41528 Mdot
.986 .41529 Mdot
.986 .41547 Mdot
.986 .41655 Mdot
.986 .4171 Mdot
.986 .41771 Mdot
.986 .41843 Mdot
.986 .41894 Mdot
.986 .41899 Mdot
.986 .41964 Mdot
.986 .41965 Mdot
.986 .42071 Mdot
.986 .421 Mdot
.986 .42163 Mdot
.986 .42178 Mdot
.986 .42199 Mdot
.986 .42223 Mdot
.986 .42229 Mdot
.986 .42257 Mdot
.986 .42263 Mdot
.986 .42331 Mdot
.986 .42481 Mdot
.986 .42515 Mdot
.986 .42536 Mdot
.986 .42554 Mdot
.986 .42633 Mdot
.986 .42751 Mdot
.986 .4282 Mdot
.986 .4282 Mdot
.986 .42907 Mdot
.986 .42918 Mdot
.986 .42966 Mdot
.986 .43053 Mdot
.986 .43061 Mdot
.986 .43134 Mdot
.986 .43203 Mdot
.986 .43313 Mdot
.986 .43353 Mdot
.986 .43412 Mdot
.986 .43451 Mdot
.986 .43473 Mdot
.986 .43477 Mdot
.986 .43485 Mdot
.986 .43489 Mdot
.986 .43681 Mdot
.986 .43682 Mdot
.986 .43701 Mdot
.986 .43809 Mdot
.986 .4389 Mdot
.986 .43898 Mdot
.986 .43951 Mdot
.986 .43954 Mdot
.986 .43958 Mdot
.986 .43991 Mdot
.986 .4401 Mdot
.986 .44273 Mdot
.986 .44371 Mdot
.986 .44391 Mdot
.986 .44439 Mdot
.986 .44484 Mdot
.986 .44609 Mdot
.986 .44649 Mdot
.986 .44653 Mdot
.986 .44729 Mdot
.986 .44784 Mdot
.986 .44867 Mdot
.986 .44961 Mdot
.986 .44984 Mdot
.986 .45068 Mdot
.986 .45092 Mdot
.986 .45093 Mdot
.986 .45117 Mdot
.986 .45149 Mdot
.986 .45298 Mdot
.986 .45382 Mdot
.986 .45397 Mdot
.986 .45553 Mdot
.986 .45791 Mdot
.986 .45797 Mdot
.986 .45869 Mdot
.986 .45919 Mdot
.986 .45965 Mdot
.986 .45994 Mdot
.986 .46014 Mdot
.986 .46018 Mdot
.986 .46027 Mdot
.986 .4603 Mdot
.986 .46096 Mdot
.986 .46177 Mdot
.986 .46187 Mdot
.986 .46248 Mdot
.986 .46265 Mdot
.986 .4629 Mdot
.986 .46527 Mdot
.986 .46554 Mdot
.986 .47013 Mdot
.986 .47016 Mdot
.986 .47172 Mdot
.986 .47206 Mdot
.986 .47219 Mdot
.986 .47283 Mdot
.986 .47284 Mdot
.986 .47348 Mdot
.986 .47411 Mdot
.986 .47441 Mdot
.986 .47469 Mdot
.986 .47528 Mdot
.986 .47561 Mdot
.986 .47621 Mdot
.986 .47661 Mdot
.986 .47662 Mdot
.986 .47747 Mdot
.986 .47747 Mdot
.986 .47852 Mdot
.986 .47934 Mdot
.986 .47958 Mdot
.986 .47996 Mdot
.986 .48018 Mdot
.986 .48104 Mdot
.986 .48106 Mdot
.986 .4814 Mdot
.986 .48176 Mdot
.986 .48189 Mdot
.986 .48222 Mdot
.986 .48243 Mdot
.986 .48345 Mdot
.986 .48373 Mdot
.986 .48439 Mdot
.986 .48484 Mdot
.986 .48505 Mdot
.986 .48545 Mdot
.986 .48546 Mdot
.986 .48567 Mdot
.986 .48774 Mdot
.986 .48812 Mdot
.986 .48979 Mdot
.986 .48979 Mdot
.986 .49108 Mdot
.986 .49122 Mdot
.986 .49199 Mdot
.986 .49202 Mdot
.986 .49336 Mdot
.986 .49355 Mdot
.986 .49383 Mdot
.986 .49586 Mdot
.986 .49672 Mdot
.986 .49737 Mdot
.986 .49824 Mdot
.986 .4984 Mdot
.986 .4987 Mdot
.986 .49884 Mdot
.986 .49922 Mdot
.986 .49946 Mdot
.986 .50016 Mdot
.986 .50045 Mdot
.986 .5009 Mdot
.986 .50095 Mdot
.986 .50106 Mdot
.986 .50126 Mdot
.986 .50533 Mdot
.986 .50561 Mdot
.986 .50631 Mdot
.986 .50636 Mdot
.986 .50709 Mdot
.986 .50746 Mdot
.986 .50791 Mdot
.986 .50929 Mdot
.986 .50932 Mdot
.986 .51013 Mdot
.986 .511 Mdot
.986 .51121 Mdot
.986 .51129 Mdot
.986 .51257 Mdot
.986 .51298 Mdot
.986 .51314 Mdot
.986 .51352 Mdot
.986 .51362 Mdot
.986 .51416 Mdot
.986 .51445 Mdot
.986 .51475 Mdot
.986 .51538 Mdot
.986 .5154 Mdot
.986 .51573 Mdot
.986 .51628 Mdot
.986 .51642 Mdot
.986 .51674 Mdot
.986 .51682 Mdot
.986 .51692 Mdot
.986 .51705 Mdot
.986 .51708 Mdot
.986 .51836 Mdot
.986 .51853 Mdot
.986 .51863 Mdot
.986 .51912 Mdot
.986 .52007 Mdot
.986 .52126 Mdot
.986 .52167 Mdot
.986 .52278 Mdot
.986 .52339 Mdot
.986 .52341 Mdot
.986 .52444 Mdot
.986 .52509 Mdot
.986 .52554 Mdot
.986 .52581 Mdot
.986 .52828 Mdot
.986 .52935 Mdot
.986 .52937 Mdot
.986 .53148 Mdot
.986 .53188 Mdot
.986 .53264 Mdot
.986 .53314 Mdot
.986 .53393 Mdot
.986 .53517 Mdot
.986 .53579 Mdot
.986 .53617 Mdot
.986 .53715 Mdot
.986 .53754 Mdot
.986 .53767 Mdot
.986 .53887 Mdot
.986 .54238 Mdot
.986 .54304 Mdot
.986 .54336 Mdot
.986 .54395 Mdot
.986 .54411 Mdot
.986 .54462 Mdot
.986 .54506 Mdot
.986 .54506 Mdot
.986 .54601 Mdot
.986 .54632 Mdot
.986 .54687 Mdot
.986 .54688 Mdot
.986 .54705 Mdot
.986 .54758 Mdot
.986 .54809 Mdot
.986 .54823 Mdot
.986 .5488 Mdot
.986 .54911 Mdot
.986 .54911 Mdot
.986 .54922 Mdot
.986 .55131 Mdot
.986 .55131 Mdot
.986 .55196 Mdot
.986 .55244 Mdot
.986 .55609 Mdot
.986 .55696 Mdot
.986 .55702 Mdot
.986 .55712 Mdot
.986 .55933 Mdot
.986 .56027 Mdot
.986 .56119 Mdot
.986 .56121 Mdot
.986 .56206 Mdot
.986 .56217 Mdot
.986 .56286 Mdot
.986 .56307 Mdot
.986 .56315 Mdot
.986 .56334 Mdot
.986 .56339 Mdot
.986 .56428 Mdot
.986 .56429 Mdot
.986 .56481 Mdot
.986 .56497 Mdot
.986 .56666 Mdot
.986 .56747 Mdot
.986 .56803 Mdot
.986 .56888 Mdot
.986 .56921 Mdot
.986 .57083 Mdot
.986 .57245 Mdot
.986 .57265 Mdot
.986 .57304 Mdot
.986 .57483 Mdot
.986 .57559 Mdot
.986 .5762 Mdot
.986 .57847 Mdot
.986 .57911 Mdot
.986 .57981 Mdot
.986 .57997 Mdot
.986 .58025 Mdot
.986 .58026 Mdot
.986 .58087 Mdot
.986 .58094 Mdot
.986 .58123 Mdot
.986 .58139 Mdot
.986 .5825 Mdot
.986 .58657 Mdot
.986 .58796 Mdot
.986 .58836 Mdot
.986 .58846 Mdot
.986 .58851 Mdot
.986 .5886 Mdot
.986 .58935 Mdot
.986 .59029 Mdot
.986 .5907 Mdot
.986 .59141 Mdot
.986 .5924 Mdot
.986 .59333 Mdot
.986 .59481 Mdot
.986 .59512 Mdot
.986 .59628 Mdot
.986 .59696 Mdot
.986 .59704 Mdot
.986 .59718 Mdot
.986 .59718 Mdot
.986 .59753 Mdot
.986 .59768 Mdot
.988 .01668 Mdot
.988 .0186 Mdot
.988 .02239 Mdot
.988 .02265 Mdot
.988 .02284 Mdot
.988 .02315 Mdot
.988 .02491 Mdot
.988 .02523 Mdot
.988 .02816 Mdot
.988 .02854 Mdot
.988 .02884 Mdot
.988 .02988 Mdot
.988 .03039 Mdot
.988 .03076 Mdot
.988 .03139 Mdot
.988 .03167 Mdot
.988 .03286 Mdot
.988 .03486 Mdot
.988 .03549 Mdot
.988 .03567 Mdot
.988 .03646 Mdot
.988 .03668 Mdot
.988 .03668 Mdot
.988 .03729 Mdot
.988 .03762 Mdot
.988 .04127 Mdot
.988 .04203 Mdot
.988 .04225 Mdot
.988 .04263 Mdot
.988 .04322 Mdot
.988 .04389 Mdot
.988 .04415 Mdot
.988 .04469 Mdot
.988 .04486 Mdot
.988 .04568 Mdot
.988 .04613 Mdot
.988 .04632 Mdot
.988 .04643 Mdot
.988 .04766 Mdot
.988 .04821 Mdot
.988 .05058 Mdot
.988 .05088 Mdot
.988 .05287 Mdot
.988 .05452 Mdot
.988 .05495 Mdot
.988 .05577 Mdot
.988 .05613 Mdot
.988 .05638 Mdot
.988 .05657 Mdot
.988 .05748 Mdot
.988 .05767 Mdot
.988 .05812 Mdot
.988 .05812 Mdot
.988 .0584 Mdot
.988 .05922 Mdot
.988 .05932 Mdot
.988 .05998 Mdot
.988 .06004 Mdot
.988 .06031 Mdot
.988 .06041 Mdot
.988 .06061 Mdot
.988 .06157 Mdot
.988 .06179 Mdot
.988 .06281 Mdot
.988 .06385 Mdot
.988 .06485 Mdot
.988 .0656 Mdot
.988 .06713 Mdot
.988 .0672 Mdot
.988 .06764 Mdot
.988 .06816 Mdot
.988 .06854 Mdot
.988 .06864 Mdot
.988 .06869 Mdot
.988 .06912 Mdot
.988 .06987 Mdot
.988 .06988 Mdot
.988 .07019 Mdot
.988 .07104 Mdot
.988 .07119 Mdot
.988 .07129 Mdot
.988 .07237 Mdot
.988 .07288 Mdot
.988 .07394 Mdot
.988 .07395 Mdot
.988 .07427 Mdot
.988 .07459 Mdot
.988 .0759 Mdot
.988 .07679 Mdot
.988 .07684 Mdot
.988 .07716 Mdot
.988 .07738 Mdot
.988 .07961 Mdot
.988 .07981 Mdot
.988 .08091 Mdot
.988 .08249 Mdot
.988 .08362 Mdot
.988 .0844 Mdot
.988 .08494 Mdot
.988 .085 Mdot
.988 .0854 Mdot
.988 .08558 Mdot
.988 .08619 Mdot
.988 .0901 Mdot
.988 .09223 Mdot
.988 .09337 Mdot
.988 .09341 Mdot
.988 .09422 Mdot
.988 .09454 Mdot
.988 .09584 Mdot
.988 .09635 Mdot
.988 .09639 Mdot
.988 .09654 Mdot
.988 .09704 Mdot
.988 .09742 Mdot
.988 .09923 Mdot
.988 .09947 Mdot
.988 .0996 Mdot
.988 .10049 Mdot
.988 .10103 Mdot
.988 .10178 Mdot
.988 .1018 Mdot
.988 .10223 Mdot
.988 .10233 Mdot
.988 .10265 Mdot
.988 .10286 Mdot
.988 .10417 Mdot
.988 .10428 Mdot
.988 .10466 Mdot
.988 .1047 Mdot
.988 .1048 Mdot
.988 .105 Mdot
.988 .10541 Mdot
.988 .10563 Mdot
.988 .10642 Mdot
.988 .10729 Mdot
.988 .10742 Mdot
.988 .10774 Mdot
.988 .10821 Mdot
.988 .10882 Mdot
.988 .10892 Mdot
.988 .10975 Mdot
.988 .11053 Mdot
.988 .11081 Mdot
.988 .1118 Mdot
.988 .11296 Mdot
.988 .11377 Mdot
.988 .11526 Mdot
.988 .11568 Mdot
.988 .11705 Mdot
.988 .11769 Mdot
.988 .11789 Mdot
.988 .11828 Mdot
.988 .1183 Mdot
.988 .11842 Mdot
.988 .11928 Mdot
.988 .11929 Mdot
.988 .11996 Mdot
.988 .12018 Mdot
.988 .12033 Mdot
.988 .1206 Mdot
.988 .12069 Mdot
.988 .12108 Mdot
.988 .12127 Mdot
.988 .12137 Mdot
.988 .12145 Mdot
.988 .12184 Mdot
.988 .12221 Mdot
.988 .12272 Mdot
.988 .12275 Mdot
.988 .1237 Mdot
.988 .12372 Mdot
.988 .12433 Mdot
.988 .12442 Mdot
.988 .1247 Mdot
.988 .12476 Mdot
.988 .12548 Mdot
.988 .12551 Mdot
.988 .12552 Mdot
.988 .12601 Mdot
.988 .12632 Mdot
.988 .1265 Mdot
.988 .12704 Mdot
.988 .12706 Mdot
.988 .12822 Mdot
.988 .12864 Mdot
.988 .12965 Mdot
.988 .13021 Mdot
.988 .13057 Mdot
.988 .13127 Mdot
.988 .13174 Mdot
.988 .13176 Mdot
.988 .13192 Mdot
.988 .1324 Mdot
.988 .13302 Mdot
.988 .13328 Mdot
.988 .13562 Mdot
.988 .13621 Mdot
.988 .13738 Mdot
.988 .13748 Mdot
.988 .13801 Mdot
.988 .13811 Mdot
.988 .13855 Mdot
.988 .13949 Mdot
.988 .14262 Mdot
.988 .14294 Mdot
.988 .14311 Mdot
.988 .14335 Mdot
.988 .14406 Mdot
.988 .14473 Mdot
.988 .14519 Mdot
.988 .14551 Mdot
.988 .14568 Mdot
.988 .14599 Mdot
.988 .14603 Mdot
.988 .14694 Mdot
.988 .1475 Mdot
.988 .14815 Mdot
.988 .14863 Mdot
.988 .14979 Mdot
.988 .14999 Mdot
.988 .15087 Mdot
.988 .15184 Mdot
.988 .15241 Mdot
.988 .15348 Mdot
.988 .15361 Mdot
.988 .15372 Mdot
.988 .15439 Mdot
.988 .15475 Mdot
.988 .15567 Mdot
.988 .15594 Mdot
.988 .15652 Mdot
.988 .15725 Mdot
.988 .15729 Mdot
.988 .15882 Mdot
.988 .16368 Mdot
.988 .16371 Mdot
.988 .16384 Mdot
.988 .16388 Mdot
.988 .16704 Mdot
.988 .16789 Mdot
.988 .16972 Mdot
.988 .17013 Mdot
.988 .17022 Mdot
.988 .17165 Mdot
.988 .17182 Mdot
.988 .17189 Mdot
.988 .17245 Mdot
.988 .17502 Mdot
.988 .17507 Mdot
.988 .17554 Mdot
.988 .17575 Mdot
.988 .17603 Mdot
.988 .17611 Mdot
.988 .17641 Mdot
.988 .17738 Mdot
.988 .17791 Mdot
.988 .17804 Mdot
.988 .17814 Mdot
.988 .17816 Mdot
.988 .17882 Mdot
.988 .17952 Mdot
.988 .18171 Mdot
.988 .1822 Mdot
.988 .18234 Mdot
.988 .18246 Mdot
.988 .1842 Mdot
.988 .18479 Mdot
.988 .18527 Mdot
.988 .18676 Mdot
.988 .18679 Mdot
.988 .18764 Mdot
.988 .18784 Mdot
.988 .18845 Mdot
.988 .18848 Mdot
.988 .18889 Mdot
.988 .18951 Mdot
.988 .19077 Mdot
.988 .19088 Mdot
.988 .19147 Mdot
.988 .19169 Mdot
.988 .19202 Mdot
.988 .19245 Mdot
.988 .19252 Mdot
.988 .19254 Mdot
.988 .19273 Mdot
.988 .19312 Mdot
.988 .19312 Mdot
.988 .19393 Mdot
.988 .19437 Mdot
.988 .19472 Mdot
.988 .19593 Mdot
.988 .19723 Mdot
.988 .19765 Mdot
.988 .19789 Mdot
.988 .19797 Mdot
.988 .19853 Mdot
.988 .199 Mdot
.988 .19947 Mdot
.988 .20067 Mdot
.988 .20087 Mdot
.988 .20126 Mdot
.988 .20251 Mdot
.988 .20255 Mdot
.988 .20405 Mdot
.988 .20461 Mdot
.988 .20559 Mdot
.988 .20618 Mdot
.988 .20656 Mdot
.988 .20791 Mdot
.988 .20885 Mdot
.988 .20947 Mdot
.988 .20989 Mdot
.988 .21004 Mdot
.988 .21045 Mdot
.988 .21324 Mdot
.988 .21339 Mdot
.988 .21423 Mdot
.988 .21438 Mdot
.988 .21692 Mdot
.988 .2182 Mdot
.988 .21824 Mdot
.988 .21833 Mdot
.988 .21858 Mdot
.988 .21937 Mdot
.988 .2194 Mdot
.988 .21963 Mdot
.988 .21998 Mdot
.988 .22077 Mdot
.988 .22134 Mdot
.988 .22136 Mdot
.988 .22267 Mdot
.988 .22311 Mdot
.988 .2234 Mdot
.988 .22395 Mdot
.988 .22413 Mdot
.988 .22488 Mdot
.988 .22496 Mdot
.988 .22515 Mdot
.988 .22526 Mdot
.988 .22547 Mdot
.988 .22549 Mdot
.988 .22562 Mdot
.988 .22591 Mdot
.988 .2264 Mdot
.988 .22646 Mdot
.988 .22713 Mdot
.988 .22813 Mdot
.988 .22819 Mdot
.988 .22952 Mdot
.988 .22964 Mdot
.988 .23007 Mdot
.988 .23011 Mdot
.988 .23057 Mdot
.988 .23084 Mdot
.988 .23131 Mdot
.988 .23149 Mdot
.988 .23192 Mdot
.988 .23206 Mdot
.988 .23217 Mdot
.988 .2334 Mdot
.988 .23358 Mdot
.988 .23366 Mdot
.988 .23366 Mdot
.988 .23415 Mdot
.988 .23463 Mdot
.988 .23502 Mdot
.988 .23524 Mdot
.988 .2356 Mdot
.988 .23612 Mdot
.988 .23666 Mdot
.988 .23671 Mdot
.988 .23711 Mdot
.988 .23725 Mdot
.988 .2373 Mdot
.988 .23901 Mdot
.988 .23931 Mdot
.988 .23983 Mdot
.988 .24111 Mdot
.988 .24113 Mdot
.988 .24182 Mdot
.988 .24243 Mdot
.988 .24292 Mdot
.988 .24293 Mdot
.988 .24365 Mdot
.988 .24415 Mdot
.988 .24502 Mdot
.988 .24529 Mdot
.988 .24562 Mdot
.988 .24595 Mdot
.988 .246 Mdot
.988 .24631 Mdot
.988 .24727 Mdot
.988 .24741 Mdot
.988 .24784 Mdot
.988 .24813 Mdot
.988 .24849 Mdot
.988 .24901 Mdot
.988 .24919 Mdot
.988 .25106 Mdot
.988 .25136 Mdot
.988 .25209 Mdot
.988 .2522 Mdot
.988 .25253 Mdot
.988 .25334 Mdot
.988 .25342 Mdot
.988 .25363 Mdot
.988 .25396 Mdot
.988 .25479 Mdot
.988 .25509 Mdot
.988 .25583 Mdot
.988 .25684 Mdot
.988 .25699 Mdot
.988 .2571 Mdot
.988 .25722 Mdot
.988 .25729 Mdot
.988 .25809 Mdot
.988 .25835 Mdot
.988 .25855 Mdot
.988 .25941 Mdot
.988 .25982 Mdot
.988 .26126 Mdot
.988 .26373 Mdot
.988 .26396 Mdot
.988 .26512 Mdot
.988 .26538 Mdot
.988 .26647 Mdot
.988 .26679 Mdot
.988 .26745 Mdot
.988 .26809 Mdot
.988 .26842 Mdot
.988 .26852 Mdot
.988 .2689 Mdot
.988 .26919 Mdot
.988 .26966 Mdot
.988 .27001 Mdot
.988 .27029 Mdot
.988 .27086 Mdot
.988 .27133 Mdot
.988 .27146 Mdot
.988 .27162 Mdot
.988 .27253 Mdot
.988 .27257 Mdot
.988 .27317 Mdot
.988 .27328 Mdot
.988 .2735 Mdot
.988 .27411 Mdot
.988 .2742 Mdot
.988 .27433 Mdot
.988 .27598 Mdot
.988 .27618 Mdot
.988 .27686 Mdot
.988 .27711 Mdot
.988 .27727 Mdot
.988 .27795 Mdot
.988 .27839 Mdot
.988 .27853 Mdot
.988 .27895 Mdot
.988 .27907 Mdot
.988 .27933 Mdot
.988 .27951 Mdot
.988 .28162 Mdot
.988 .28202 Mdot
.988 .28376 Mdot
.988 .2843 Mdot
.988 .28502 Mdot
.988 .28532 Mdot
.988 .28535 Mdot
.988 .28567 Mdot
.988 .28679 Mdot
.988 .28726 Mdot
.988 .2887 Mdot
.988 .28892 Mdot
.988 .28911 Mdot
.988 .28917 Mdot
.988 .2894 Mdot
.988 .28987 Mdot
.988 .28995 Mdot
.988 .29064 Mdot
.988 .29072 Mdot
.988 .29142 Mdot
.988 .2915 Mdot
.988 .29175 Mdot
.988 .29292 Mdot
.988 .29325 Mdot
.988 .29325 Mdot
.988 .29378 Mdot
.988 .29491 Mdot
.988 .29494 Mdot
.988 .29637 Mdot
.988 .29645 Mdot
.988 .29705 Mdot
.988 .29724 Mdot
.988 .29852 Mdot
.988 .2988 Mdot
.988 .299 Mdot
.988 .29935 Mdot
.988 .29946 Mdot
.988 .29954 Mdot
.988 .30041 Mdot
.988 .30166 Mdot
.988 .30194 Mdot
.988 .30388 Mdot
.988 .30622 Mdot
.988 .30693 Mdot
.988 .30739 Mdot
.988 .30907 Mdot
.988 .30912 Mdot
.988 .30938 Mdot
.988 .30942 Mdot
.988 .30947 Mdot
.988 .31031 Mdot
.988 .31139 Mdot
.988 .31441 Mdot
.988 .31451 Mdot
.988 .31467 Mdot
.988 .31556 Mdot
.988 .31572 Mdot
.988 .3172 Mdot
.988 .31739 Mdot
.988 .31755 Mdot
.988 .31898 Mdot
.988 .31958 Mdot
.988 .321 Mdot
.988 .3214 Mdot
.988 .32151 Mdot
.988 .32151 Mdot
.988 .32182 Mdot
.988 .32199 Mdot
.988 .32433 Mdot
.988 .32482 Mdot
.988 .32516 Mdot
.988 .32529 Mdot
.988 .32565 Mdot
.988 .32629 Mdot
.988 .32639 Mdot
.988 .3287 Mdot
.988 .3297 Mdot
.988 .33076 Mdot
.988 .33148 Mdot
.988 .33158 Mdot
.988 .33204 Mdot
.988 .3325 Mdot
.988 .33292 Mdot
.988 .33333 Mdot
.988 .33347 Mdot
.988 .33352 Mdot
.988 .33362 Mdot
.988 .33411 Mdot
.988 .33422 Mdot
.988 .33474 Mdot
.988 .33526 Mdot
.988 .33577 Mdot
.988 .33615 Mdot
.988 .33692 Mdot
.988 .33718 Mdot
.988 .33744 Mdot
.988 .33764 Mdot
.988 .33768 Mdot
.988 .33831 Mdot
.988 .33847 Mdot
.988 .33898 Mdot
.988 .33903 Mdot
.988 .34037 Mdot
.988 .3407 Mdot
.988 .34184 Mdot
.988 .34324 Mdot
.988 .34469 Mdot
.988 .34527 Mdot
.988 .34566 Mdot
.988 .34594 Mdot
.988 .34597 Mdot
.988 .34617 Mdot
.988 .34963 Mdot
.988 .35022 Mdot
.988 .35079 Mdot
.988 .35171 Mdot
.988 .35173 Mdot
.988 .35329 Mdot
.988 .35446 Mdot
.988 .35447 Mdot
.988 .35468 Mdot
.988 .35473 Mdot
.988 .35592 Mdot
.988 .35593 Mdot
.988 .35641 Mdot
.988 .35681 Mdot
.988 .35731 Mdot
.988 .35771 Mdot
.988 .35802 Mdot
.988 .35807 Mdot
.988 .35889 Mdot
.988 .35903 Mdot
.988 .36012 Mdot
.988 .36149 Mdot
.988 .36218 Mdot
.988 .36251 Mdot
.988 .36261 Mdot
.988 .36282 Mdot
.988 .36332 Mdot
.988 .36366 Mdot
.988 .36377 Mdot
.988 .36398 Mdot
.988 .36403 Mdot
.988 .36441 Mdot
.988 .36461 Mdot
.988 .36505 Mdot
.988 .36507 Mdot
.988 .36591 Mdot
.988 .36606 Mdot
.988 .36609 Mdot
.988 .36645 Mdot
.988 .36647 Mdot
.988 .36647 Mdot
.988 .36724 Mdot
.988 .36725 Mdot
.988 .36784 Mdot
.988 .36884 Mdot
.988 .36903 Mdot
.988 .36938 Mdot
.988 .36971 Mdot
.988 .3704 Mdot
.988 .37188 Mdot
.988 .37279 Mdot
.988 .37354 Mdot
.988 .37512 Mdot
.988 .37537 Mdot
.988 .37585 Mdot
.988 .37619 Mdot
.988 .37643 Mdot
.988 .37667 Mdot
.988 .37683 Mdot
.988 .37685 Mdot
.988 .37731 Mdot
.988 .3776 Mdot
.988 .37793 Mdot
.988 .37875 Mdot
.988 .37886 Mdot
.988 .37979 Mdot
.988 .38074 Mdot
.988 .38173 Mdot
.988 .38216 Mdot
.988 .38253 Mdot
.988 .38255 Mdot
.988 .38332 Mdot
.988 .3858 Mdot
.988 .38586 Mdot
.988 .38589 Mdot
.988 .38749 Mdot
.988 .38884 Mdot
.988 .38982 Mdot
.988 .38994 Mdot
.988 .39155 Mdot
.988 .39178 Mdot
.988 .39189 Mdot
.988 .39298 Mdot
.988 .39305 Mdot
.988 .39311 Mdot
.988 .39344 Mdot
.988 .3938 Mdot
.988 .39523 Mdot
.988 .39647 Mdot
.988 .39832 Mdot
.988 .39886 Mdot
.988 .39949 Mdot
.988 .39955 Mdot
.988 .40012 Mdot
.988 .40039 Mdot
.988 .40068 Mdot
.988 .40149 Mdot
.988 .40276 Mdot
.988 .40314 Mdot
.988 .40366 Mdot
.988 .4048 Mdot
.988 .40546 Mdot
.988 .40699 Mdot
.988 .40729 Mdot
.988 .40817 Mdot
.988 .40896 Mdot
.988 .40917 Mdot
.988 .40925 Mdot
.988 .41086 Mdot
.988 .41144 Mdot
.988 .4134 Mdot
.988 .41344 Mdot
.988 .41427 Mdot
.988 .41468 Mdot
.988 .4168 Mdot
.988 .41689 Mdot
.988 .41706 Mdot
.988 .41728 Mdot
.988 .41755 Mdot
.988 .41911 Mdot
.988 .41917 Mdot
.988 .41964 Mdot
.988 .41977 Mdot
.988 .42032 Mdot
.988 .42106 Mdot
.988 .42145 Mdot
.988 .42189 Mdot
.988 .42244 Mdot
.988 .42294 Mdot
.988 .42301 Mdot
.988 .42304 Mdot
.988 .42406 Mdot
.988 .42497 Mdot
.988 .42498 Mdot
.988 .42564 Mdot
.988 .42589 Mdot
.988 .42651 Mdot
.988 .42709 Mdot
.988 .42725 Mdot
.988 .42816 Mdot
.988 .42837 Mdot
.988 .42852 Mdot
.988 .42906 Mdot
.988 .43001 Mdot
.988 .43016 Mdot
.988 .43053 Mdot
.988 .43058 Mdot
.988 .43075 Mdot
.988 .43116 Mdot
.988 .4312 Mdot
.988 .43147 Mdot
.988 .43205 Mdot
.988 .43242 Mdot
.988 .43293 Mdot
.988 .433 Mdot
.988 .43312 Mdot
.988 .43356 Mdot
.988 .43444 Mdot
.988 .43642 Mdot
.988 .43653 Mdot
.988 .43712 Mdot
.988 .43725 Mdot
.988 .4378 Mdot
.988 .43796 Mdot
.988 .43884 Mdot
.988 .43918 Mdot
.988 .43942 Mdot
.988 .43959 Mdot
.988 .44002 Mdot
.988 .44026 Mdot
.988 .44033 Mdot
.988 .44089 Mdot
.988 .44125 Mdot
.988 .44178 Mdot
.988 .44272 Mdot
.988 .44306 Mdot
.988 .44327 Mdot
.988 .44361 Mdot
.988 .44391 Mdot
.988 .44412 Mdot
.988 .44418 Mdot
.988 .4444 Mdot
.988 .44683 Mdot
.988 .44719 Mdot
.988 .44734 Mdot
.988 .44736 Mdot
.988 .44832 Mdot
.988 .44905 Mdot
.988 .44926 Mdot
.988 .44964 Mdot
.988 .44968 Mdot
.988 .45003 Mdot
.988 .45047 Mdot
.988 .4506 Mdot
.988 .45119 Mdot
.988 .45136 Mdot
.988 .45221 Mdot
.988 .45328 Mdot
.988 .45337 Mdot
.988 .45402 Mdot
.988 .45416 Mdot
.988 .45426 Mdot
.988 .45444 Mdot
.988 .45454 Mdot
.988 .45498 Mdot
.988 .45561 Mdot
.988 .45575 Mdot
.988 .45673 Mdot
.988 .45792 Mdot
.988 .45828 Mdot
.988 .45851 Mdot
.988 .45954 Mdot
.988 .45999 Mdot
.988 .46054 Mdot
.988 .46206 Mdot
.988 .46211 Mdot
.988 .46219 Mdot
.988 .46264 Mdot
.988 .46347 Mdot
.988 .46365 Mdot
.988 .46437 Mdot
.988 .46468 Mdot
.988 .4656 Mdot
.988 .46566 Mdot
.988 .46566 Mdot
.988 .46708 Mdot
.988 .46775 Mdot
.988 .46808 Mdot
.988 .4693 Mdot
.988 .4698 Mdot
.988 .47034 Mdot
.988 .47099 Mdot
.988 .47164 Mdot
.988 .47173 Mdot
.988 .47203 Mdot
.988 .47235 Mdot
.988 .47262 Mdot
.988 .47287 Mdot
.988 .47346 Mdot
.988 .47416 Mdot
.988 .47424 Mdot
.988 .47452 Mdot
.988 .47537 Mdot
.988 .47594 Mdot
.988 .47665 Mdot
.988 .47768 Mdot
.988 .47803 Mdot
.988 .48019 Mdot
.988 .48094 Mdot
.988 .48174 Mdot
.988 .48233 Mdot
.988 .48233 Mdot
.988 .48307 Mdot
.988 .48308 Mdot
.988 .48377 Mdot
.988 .48398 Mdot
.988 .48464 Mdot
.988 .48589 Mdot
.988 .48624 Mdot
.988 .48641 Mdot
.988 .48681 Mdot
.988 .48699 Mdot
.988 .48704 Mdot
.988 .48717 Mdot
.988 .48747 Mdot
.988 .48769 Mdot
.988 .4884 Mdot
.988 .48841 Mdot
.988 .4891 Mdot
.988 .4897 Mdot
.988 .48988 Mdot
.988 .49115 Mdot
.988 .49199 Mdot
.988 .49279 Mdot
.988 .49316 Mdot
.988 .49345 Mdot
.988 .49366 Mdot
.988 .4939 Mdot
.988 .49404 Mdot
.988 .49463 Mdot
.988 .49563 Mdot
.988 .49613 Mdot
.988 .49654 Mdot
.988 .49822 Mdot
.988 .49905 Mdot
.988 .50023 Mdot
.988 .5011 Mdot
.988 .50122 Mdot
.988 .50183 Mdot
.988 .50189 Mdot
.988 .50206 Mdot
.988 .50296 Mdot
.988 .5048 Mdot
.988 .50512 Mdot
.988 .50678 Mdot
.988 .50697 Mdot
.988 .50723 Mdot
.988 .50781 Mdot
.988 .50814 Mdot
.988 .50951 Mdot
.988 .51002 Mdot
.988 .51088 Mdot
.988 .51117 Mdot
.988 .51216 Mdot
.988 .51218 Mdot
.988 .51281 Mdot
.988 .51412 Mdot
.988 .51538 Mdot
.988 .51604 Mdot
.988 .51623 Mdot
.988 .51674 Mdot
.988 .51699 Mdot
.988 .51755 Mdot
.988 .51801 Mdot
.988 .51802 Mdot
.988 .51848 Mdot
.988 .51917 Mdot
.988 .51974 Mdot
.988 .52008 Mdot
.988 .52085 Mdot
.988 .52178 Mdot
.988 .52204 Mdot
.988 .52236 Mdot
.988 .52416 Mdot
.988 .52423 Mdot
.988 .52451 Mdot
.988 .52459 Mdot
.988 .52503 Mdot
.988 .52541 Mdot
.988 .52563 Mdot
.988 .52607 Mdot
.988 .52728 Mdot
.988 .52745 Mdot
.988 .52771 Mdot
.988 .5302 Mdot
.988 .5305 Mdot
.988 .53052 Mdot
.988 .53098 Mdot
.988 .53137 Mdot
.988 .53272 Mdot
.988 .53284 Mdot
.988 .5332 Mdot
.988 .53352 Mdot
.988 .53359 Mdot
.988 .53409 Mdot
.988 .53487 Mdot
.988 .53574 Mdot
.988 .53601 Mdot
.988 .53685 Mdot
.988 .53708 Mdot
.988 .53759 Mdot
.988 .53796 Mdot
.988 .53858 Mdot
.988 .53967 Mdot
.988 .54045 Mdot
.988 .54183 Mdot
.988 .54213 Mdot
.988 .54226 Mdot
.988 .54255 Mdot
.988 .54291 Mdot
.988 .54596 Mdot
.988 .54634 Mdot
.988 .54704 Mdot
.988 .54742 Mdot
.988 .54742 Mdot
.988 .54885 Mdot
.988 .5494 Mdot
.988 .54943 Mdot
.988 .5495 Mdot
.988 .54976 Mdot
.988 .55011 Mdot
.988 .55012 Mdot
.988 .55087 Mdot
.988 .55193 Mdot
.988 .55234 Mdot
.988 .55327 Mdot
.988 .5561 Mdot
.988 .55654 Mdot
.988 .5566 Mdot
.988 .55691 Mdot
.988 .55703 Mdot
.988 .55748 Mdot
.988 .55841 Mdot
.988 .55858 Mdot
.988 .55951 Mdot
.988 .55994 Mdot
.988 .56011 Mdot
.988 .56149 Mdot
.988 .56164 Mdot
.988 .56214 Mdot
.988 .56446 Mdot
.988 .5651 Mdot
.988 .5651 Mdot
.988 .56615 Mdot
.988 .56839 Mdot
.988 .56843 Mdot
.988 .56865 Mdot
.988 .57127 Mdot
.988 .57142 Mdot
.988 .57143 Mdot
.988 .5726 Mdot
.988 .57299 Mdot
.988 .57324 Mdot
.988 .57551 Mdot
.988 .57606 Mdot
.988 .57645 Mdot
.988 .57716 Mdot
.988 .57737 Mdot
.988 .57752 Mdot
.988 .57924 Mdot
.988 .57979 Mdot
.988 .57998 Mdot
.988 .58099 Mdot
.988 .58117 Mdot
.988 .58135 Mdot
.988 .58173 Mdot
.988 .58227 Mdot
.988 .58463 Mdot
.988 .5861 Mdot
.988 .59073 Mdot
.988 .59214 Mdot
.988 .59305 Mdot
.988 .59637 Mdot
.988 .59646 Mdot
.988 .59697 Mdot
.988 .59706 Mdot
.988 .59715 Mdot
.988 .59882 Mdot
.99 .01563 Mdot
.99 .01605 Mdot
.99 .01653 Mdot
.99 .01736 Mdot
.99 .01813 Mdot
.99 .0183 Mdot
.99 .01937 Mdot
.99 .01952 Mdot
.99 .01994 Mdot
.99 .02059 Mdot
.99 .02148 Mdot
.99 .02165 Mdot
.99 .02182 Mdot
.99 .02233 Mdot
.99 .02393 Mdot
.99 .02393 Mdot
.99 .02423 Mdot
.99 .02435 Mdot
.99 .02507 Mdot
.99 .0254 Mdot
.99 .02544 Mdot
.99 .02589 Mdot
.99 .02634 Mdot
.99 .02812 Mdot
.99 .02844 Mdot
.99 .02878 Mdot
.99 .02913 Mdot
.99 .02979 Mdot
.99 .03001 Mdot
.99 .03105 Mdot
.99 .03158 Mdot
.99 .03222 Mdot
.99 .03295 Mdot
.99 .03297 Mdot
.99 .03355 Mdot
.99 .03378 Mdot
.99 .03521 Mdot
.99 .03547 Mdot
.99 .03587 Mdot
.99 .03594 Mdot
.99 .03664 Mdot
.99 .03683 Mdot
.99 .03774 Mdot
.99 .03921 Mdot
.99 .04081 Mdot
.99 .04106 Mdot
.99 .04125 Mdot
.99 .04152 Mdot
.99 .04189 Mdot
.99 .04224 Mdot
.99 .04238 Mdot
.99 .04257 Mdot
.99 .04325 Mdot
.99 .04451 Mdot
.99 .04456 Mdot
.99 .04499 Mdot
.99 .04629 Mdot
.99 .04687 Mdot
.99 .04705 Mdot
.99 .04768 Mdot
.99 .0481 Mdot
.99 .04901 Mdot
.99 .04937 Mdot
.99 .05083 Mdot
.99 .05086 Mdot
.99 .05093 Mdot
.99 .05202 Mdot
.99 .05247 Mdot
.99 .05256 Mdot
.99 .05275 Mdot
.99 .05303 Mdot
.99 .05452 Mdot
.99 .0553 Mdot
.99 .05582 Mdot
.99 .05649 Mdot
.99 .0566 Mdot
.99 .05674 Mdot
.99 .05687 Mdot
.99 .05708 Mdot
.99 .0573 Mdot
.99 .05812 Mdot
.99 .05824 Mdot
.99 .05851 Mdot
.99 .0594 Mdot
.99 .0603 Mdot
.99 .06079 Mdot
.99 .061 Mdot
.99 .06233 Mdot
.99 .06276 Mdot
.99 .06322 Mdot
.99 .06338 Mdot
.99 .06355 Mdot
.99 .06531 Mdot
.99 .06597 Mdot
.99 .06638 Mdot
.99 .0664 Mdot
.99 .06688 Mdot
.99 .06726 Mdot
.99 .06779 Mdot
.99 .06844 Mdot
.99 .06852 Mdot
.99 .06921 Mdot
.99 .06923 Mdot
.99 .06948 Mdot
.99 .06986 Mdot
.99 .07113 Mdot
.99 .07121 Mdot
.99 .07126 Mdot
.99 .07187 Mdot
.99 .07295 Mdot
.99 .07371 Mdot
.99 .07381 Mdot
.99 .07392 Mdot
.99 .07466 Mdot
.99 .0752 Mdot
.99 .07558 Mdot
.99 .07579 Mdot
.99 .07632 Mdot
.99 .07709 Mdot
.99 .0772 Mdot
.99 .07724 Mdot
.99 .07758 Mdot
.99 .07837 Mdot
.99 .07854 Mdot
.99 .07865 Mdot
.99 .07874 Mdot
.99 .07887 Mdot
.99 .07998 Mdot
.99 .08007 Mdot
.99 .08045 Mdot
.99 .08082 Mdot
.99 .08165 Mdot
.99 .08261 Mdot
.99 .08334 Mdot
.99 .08384 Mdot
.99 .08622 Mdot
.99 .08628 Mdot
.99 .08642 Mdot
.99 .08843 Mdot
.99 .08857 Mdot
.99 .08857 Mdot
.99 .08902 Mdot
.99 .08947 Mdot
.99 .08964 Mdot
.99 .09002 Mdot
.99 .09058 Mdot
.99 .09132 Mdot
.99 .09353 Mdot
.99 .0942 Mdot
.99 .09428 Mdot
.99 .09507 Mdot
.99 .0961 Mdot
.99 .09643 Mdot
.99 .09716 Mdot
.99 .09742 Mdot
.99 .09764 Mdot
.99 .09793 Mdot
.99 .09817 Mdot
.99 .09819 Mdot
.99 .0986 Mdot
.99 .09904 Mdot
.99 .10066 Mdot
.99 .10089 Mdot
.99 .10142 Mdot
.99 .10231 Mdot
.99 .1032 Mdot
.99 .10477 Mdot
.99 .10498 Mdot
.99 .10593 Mdot
.99 .10635 Mdot
.99 .109 Mdot
.99 .10924 Mdot
.99 .10953 Mdot
.99 .10962 Mdot
.99 .10985 Mdot
.99 .11006 Mdot
.99 .11076 Mdot
.99 .1108 Mdot
.99 .11107 Mdot
.99 .1114 Mdot
.99 .11334 Mdot
.99 .114 Mdot
.99 .1149 Mdot
.99 .11613 Mdot
.99 .11621 Mdot
.99 .11702 Mdot
.99 .11704 Mdot
.99 .118 Mdot
.99 .11875 Mdot
.99 .11928 Mdot
.99 .1198 Mdot
.99 .11983 Mdot
.99 .11989 Mdot
.99 .12108 Mdot
.99 .12125 Mdot
.99 .1222 Mdot
.99 .12262 Mdot
.99 .12266 Mdot
.99 .12316 Mdot
.99 .12391 Mdot
.99 .12462 Mdot
.99 .12527 Mdot
.99 .12641 Mdot
.99 .12658 Mdot
.99 .12668 Mdot
.99 .12673 Mdot
.99 .12761 Mdot
.99 .12789 Mdot
.99 .12829 Mdot
.99 .12853 Mdot
.99 .12861 Mdot
.99 .12993 Mdot
.99 .13003 Mdot
.99 .13139 Mdot
.99 .13152 Mdot
.99 .13172 Mdot
.99 .13195 Mdot
.99 .13238 Mdot
.99 .1324 Mdot
.99 .1334 Mdot
.99 .13448 Mdot
.99 .13464 Mdot
.99 .13522 Mdot
.99 .13552 Mdot
.99 .13564 Mdot
.99 .13669 Mdot
.99 .13735 Mdot
.99 .13822 Mdot
.99 .13844 Mdot
.99 .13851 Mdot
.99 .13896 Mdot
.99 .13982 Mdot
.99 .1406 Mdot
.99 .14076 Mdot
.99 .14108 Mdot
.99 .14131 Mdot
.99 .14149 Mdot
.99 .14175 Mdot
.99 .14394 Mdot
.99 .14413 Mdot
.99 .14434 Mdot
.99 .14482 Mdot
.99 .14486 Mdot
.99 .1449 Mdot
.99 .14561 Mdot
.99 .14725 Mdot
.99 .14725 Mdot
.99 .14915 Mdot
.99 .15058 Mdot
.99 .15158 Mdot
.99 .1523 Mdot
.99 .15488 Mdot
.99 .15541 Mdot
.99 .1563 Mdot
.99 .15641 Mdot
.99 .1567 Mdot
.99 .15789 Mdot
.99 .16067 Mdot
.99 .16095 Mdot
.99 .16095 Mdot
.99 .16114 Mdot
.99 .16172 Mdot
.99 .16185 Mdot
.99 .16273 Mdot
.99 .16301 Mdot
.99 .16307 Mdot
.99 .16382 Mdot
.99 .16439 Mdot
.99 .16492 Mdot
.99 .16527 Mdot
.99 .16599 Mdot
.99 .1664 Mdot
.99 .16651 Mdot
.99 .16677 Mdot
.99 .16772 Mdot
.99 .16835 Mdot
.99 .16934 Mdot
.99 .16964 Mdot
.99 .17077 Mdot
.99 .17107 Mdot
.99 .17165 Mdot
.99 .1721 Mdot
.99 .17225 Mdot
.99 .17246 Mdot
.99 .1728 Mdot
.99 .17382 Mdot
.99 .1747 Mdot
.99 .1748 Mdot
.99 .17515 Mdot
.99 .17585 Mdot
.99 .1765 Mdot
.99 .17723 Mdot
.99 .17795 Mdot
.99 .17844 Mdot
.99 .17847 Mdot
.99 .1789 Mdot
.99 .17948 Mdot
.99 .17963 Mdot
.99 .17976 Mdot
.99 .17996 Mdot
.99 .17999 Mdot
.99 .18036 Mdot
.99 .18082 Mdot
.99 .18168 Mdot
.99 .18285 Mdot
.99 .18432 Mdot
.99 .18489 Mdot
.99 .18534 Mdot
.99 .18639 Mdot
.99 .18816 Mdot
.99 .18992 Mdot
.99 .19088 Mdot
.99 .19225 Mdot
.99 .19284 Mdot
.99 .19302 Mdot
.99 .19308 Mdot
.99 .19344 Mdot
.99 .19486 Mdot
.99 .19533 Mdot
.99 .19616 Mdot
.99 .19914 Mdot
.99 .19994 Mdot
.99 .2014 Mdot
.99 .20188 Mdot
.99 .20223 Mdot
.99 .20245 Mdot
.99 .20264 Mdot
.99 .20308 Mdot
.99 .20349 Mdot
.99 .20393 Mdot
.99 .20486 Mdot
.99 .20488 Mdot
.99 .20497 Mdot
.99 .2055 Mdot
.99 .20615 Mdot
.99 .20694 Mdot
.99 .20731 Mdot
.99 .21 Mdot
.99 .21129 Mdot
.99 .21231 Mdot
.99 .21308 Mdot
.99 .21551 Mdot
.99 .21567 Mdot
.99 .21579 Mdot
.99 .21645 Mdot
.99 .2171 Mdot
.99 .21727 Mdot
.99 .21732 Mdot
.99 .21756 Mdot
.99 .2186 Mdot
.99 .21923 Mdot
.99 .22015 Mdot
.99 .2207 Mdot
.99 .22096 Mdot
.99 .22173 Mdot
.99 .22175 Mdot
.99 .22257 Mdot
.99 .22269 Mdot
.99 .22278 Mdot
.99 .22285 Mdot
.99 .22296 Mdot
.99 .22338 Mdot
.99 .22358 Mdot
.99 .22449 Mdot
.99 .22464 Mdot
.99 .22532 Mdot
.99 .22566 Mdot
.99 .22717 Mdot
.99 .22724 Mdot
.99 .22754 Mdot
.99 .22836 Mdot
.99 .22844 Mdot
.99 .22858 Mdot
.99 .22943 Mdot
.99 .22964 Mdot
.99 .22973 Mdot
.99 .23092 Mdot
.99 .23104 Mdot
.99 .23135 Mdot
.99 .23232 Mdot
.99 .23361 Mdot
.99 .23381 Mdot
.99 .23466 Mdot
.99 .23584 Mdot
.99 .23588 Mdot
.99 .23621 Mdot
.99 .23639 Mdot
.99 .2364 Mdot
.99 .2365 Mdot
.99 .2368 Mdot
.99 .23782 Mdot
.99 .23824 Mdot
.99 .23879 Mdot
.99 .23959 Mdot
.99 .24007 Mdot
.99 .24023 Mdot
.99 .24036 Mdot
.99 .24085 Mdot
.99 .24091 Mdot
.99 .24157 Mdot
.99 .24173 Mdot
.99 .24283 Mdot
.99 .24292 Mdot
.99 .24303 Mdot
.99 .24414 Mdot
.99 .2446 Mdot
.99 .24496 Mdot
.99 .24523 Mdot
.99 .24566 Mdot
.99 .24574 Mdot
.99 .24599 Mdot
.99 .24639 Mdot
.99 .24683 Mdot
.99 .24731 Mdot
.99 .24769 Mdot
.99 .24774 Mdot
.99 .24809 Mdot
.99 .24972 Mdot
.99 .25009 Mdot
.99 .25169 Mdot
.99 .25185 Mdot
.99 .25218 Mdot
.99 .25226 Mdot
.99 .25301 Mdot
.99 .25332 Mdot
.99 .2539 Mdot
.99 .25414 Mdot
.99 .25463 Mdot
.99 .25492 Mdot
.99 .25617 Mdot
.99 .25623 Mdot
.99 .25624 Mdot
.99 .25654 Mdot
.99 .25753 Mdot
.99 .25906 Mdot
.99 .25926 Mdot
.99 .25943 Mdot
.99 .25969 Mdot
.99 .25979 Mdot
.99 .25984 Mdot
.99 .26072 Mdot
.99 .26216 Mdot
.99 .26234 Mdot
.99 .26242 Mdot
.99 .26245 Mdot
.99 .26363 Mdot
.99 .26397 Mdot
.99 .26428 Mdot
.99 .26493 Mdot
.99 .26537 Mdot
.99 .26574 Mdot
.99 .26614 Mdot
.99 .26625 Mdot
.99 .26684 Mdot
.99 .26685 Mdot
.99 .26716 Mdot
.99 .2677 Mdot
.99 .26803 Mdot
.99 .26887 Mdot
.99 .26979 Mdot
.99 .27038 Mdot
.99 .27058 Mdot
.99 .27095 Mdot
.99 .271 Mdot
.99 .27104 Mdot
.99 .27137 Mdot
.99 .27186 Mdot
.99 .27221 Mdot
.99 .27233 Mdot
.99 .27241 Mdot
.99 .27249 Mdot
.99 .27388 Mdot
.99 .27688 Mdot
.99 .27714 Mdot
.99 .27714 Mdot
.99 .27733 Mdot
.99 .27856 Mdot
.99 .2809 Mdot
.99 .28165 Mdot
.99 .28181 Mdot
.99 .28237 Mdot
.99 .28342 Mdot
.99 .28374 Mdot
.99 .2857 Mdot
.99 .28688 Mdot
.99 .28713 Mdot
.99 .28744 Mdot
.99 .28821 Mdot
.99 .28834 Mdot
.99 .29155 Mdot
.99 .29195 Mdot
.99 .29224 Mdot
.99 .2933 Mdot
.99 .29397 Mdot
.99 .29504 Mdot
.99 .29527 Mdot
.99 .2956 Mdot
.99 .29573 Mdot
.99 .29584 Mdot
.99 .29617 Mdot
.99 .29631 Mdot
.99 .2976 Mdot
.99 .29819 Mdot
.99 .29831 Mdot
.99 .29836 Mdot
.99 .29875 Mdot
.99 .29993 Mdot
.99 .30067 Mdot
.99 .30286 Mdot
.99 .3037 Mdot
.99 .30392 Mdot
.99 .30425 Mdot
.99 .30426 Mdot
.99 .30463 Mdot
.99 .30512 Mdot
.99 .30557 Mdot
.99 .30579 Mdot
.99 .30603 Mdot
.99 .30714 Mdot
.99 .30715 Mdot
.99 .30775 Mdot
.99 .30779 Mdot
.99 .30834 Mdot
.99 .30845 Mdot
.99 .30858 Mdot
.99 .30994 Mdot
.99 .31086 Mdot
.99 .31107 Mdot
.99 .31212 Mdot
.99 .31275 Mdot
.99 .31282 Mdot
.99 .31336 Mdot
.99 .3139 Mdot
.99 .31424 Mdot
.99 .31505 Mdot
.99 .31526 Mdot
.99 .31579 Mdot
.99 .31581 Mdot
.99 .31604 Mdot
.99 .31767 Mdot
.99 .31812 Mdot
.99 .31864 Mdot
.99 .31891 Mdot
.99 .31924 Mdot
.99 .32088 Mdot
.99 .32147 Mdot
.99 .32277 Mdot
.99 .32358 Mdot
.99 .3237 Mdot
.99 .32393 Mdot
.99 .3243 Mdot
.99 .32437 Mdot
.99 .32544 Mdot
.99 .32634 Mdot
.99 .32663 Mdot
.99 .32704 Mdot
.99 .32771 Mdot
.99 .32869 Mdot
.99 .32951 Mdot
.99 .3296 Mdot
.99 .32975 Mdot
.99 .3305 Mdot
.99 .33149 Mdot
.99 .33168 Mdot
.99 .33179 Mdot
.99 .33191 Mdot
.99 .33238 Mdot
.99 .33297 Mdot
.99 .33366 Mdot
.99 .33377 Mdot
.99 .33445 Mdot
.99 .33466 Mdot
.99 .33497 Mdot
.99 .33506 Mdot
.99 .33595 Mdot
.99 .33628 Mdot
.99 .3365 Mdot
.99 .33753 Mdot
.99 .33793 Mdot
.99 .33889 Mdot
.99 .33896 Mdot
.99 .33926 Mdot
.99 .33981 Mdot
.99 .3403 Mdot
.99 .34095 Mdot
.99 .34113 Mdot
.99 .34124 Mdot
.99 .34151 Mdot
.99 .3419 Mdot
.99 .34195 Mdot
.99 .34215 Mdot
.99 .34263 Mdot
.99 .34269 Mdot
.99 .3428 Mdot
.99 .34341 Mdot
.99 .34359 Mdot
.99 .3442 Mdot
.99 .34531 Mdot
.99 .34762 Mdot
.99 .3477 Mdot
.99 .34793 Mdot
.99 .34909 Mdot
.99 .35054 Mdot
.99 .35058 Mdot
.99 .35166 Mdot
.99 .35203 Mdot
.99 .35255 Mdot
.99 .35464 Mdot
.99 .35588 Mdot
.99 .35814 Mdot
.99 .35828 Mdot
.99 .35833 Mdot
.99 .35855 Mdot
.99 .35893 Mdot
.99 .36021 Mdot
.99 .36054 Mdot
.99 .36161 Mdot
.99 .36349 Mdot
.99 .36351 Mdot
.99 .36468 Mdot
.99 .3659 Mdot
.99 .36623 Mdot
.99 .36697 Mdot
.99 .36741 Mdot
.99 .36776 Mdot
.99 .36788 Mdot
.99 .36792 Mdot
.99 .36858 Mdot
.99 .36932 Mdot
.99 .36982 Mdot
.99 .36983 Mdot
.99 .37097 Mdot
.99 .37141 Mdot
.99 .37233 Mdot
.99 .37314 Mdot
.99 .37358 Mdot
.99 .37397 Mdot
.99 .37586 Mdot
.99 .37611 Mdot
.99 .37615 Mdot
.99 .37734 Mdot
.99 .37988 Mdot
.99 .38119 Mdot
.99 .38146 Mdot
.99 .3827 Mdot
.99 .38435 Mdot
.99 .38464 Mdot
.99 .38529 Mdot
.99 .38599 Mdot
.99 .38644 Mdot
.99 .3868 Mdot
.99 .38706 Mdot
.99 .38719 Mdot
.99 .38767 Mdot
.99 .38799 Mdot
.99 .38849 Mdot
.99 .38864 Mdot
.99 .38936 Mdot
.99 .38966 Mdot
.99 .39006 Mdot
.99 .39023 Mdot
.99 .3912 Mdot
.99 .39125 Mdot
.99 .39142 Mdot
.99 .39248 Mdot
.99 .39308 Mdot
.99 .39368 Mdot
.99 .39375 Mdot
.99 .39405 Mdot
.99 .39531 Mdot
.99 .39606 Mdot
.99 .39937 Mdot
.99 .40006 Mdot
.99 .40036 Mdot
.99 .40048 Mdot
.99 .40138 Mdot
.99 .40354 Mdot
.99 .40394 Mdot
.99 .4051 Mdot
.99 .40596 Mdot
.99 .40643 Mdot
.99 .40748 Mdot
.99 .40767 Mdot
.99 .41019 Mdot
.99 .41195 Mdot
.99 .41228 Mdot
.99 .41261 Mdot
.99 .41284 Mdot
.99 .41337 Mdot
.99 .41415 Mdot
.99 .41456 Mdot
.99 .41495 Mdot
.99 .41537 Mdot
.99 .41543 Mdot
.99 .41578 Mdot
.99 .41588 Mdot
.99 .41635 Mdot
.99 .41642 Mdot
.99 .4177 Mdot
.99 .41773 Mdot
.99 .41841 Mdot
.99 .41894 Mdot
.99 .41899 Mdot
.99 .41965 Mdot
.99 .41981 Mdot
.99 .42105 Mdot
.99 .42148 Mdot
.99 .42208 Mdot
.99 .42235 Mdot
.99 .42256 Mdot
.99 .42307 Mdot
.99 .42436 Mdot
.99 .42461 Mdot
.99 .42464 Mdot
.99 .42497 Mdot
.99 .42505 Mdot
.99 .42565 Mdot
.99 .42627 Mdot
.99 .4265 Mdot
.99 .42668 Mdot
.99 .42682 Mdot
.99 .42703 Mdot
.99 .42787 Mdot
.99 .42826 Mdot
.99 .42927 Mdot
.99 .43008 Mdot
.99 .43037 Mdot
.99 .43075 Mdot
.99 .43157 Mdot
.99 .43171 Mdot
.99 .43234 Mdot
.99 .43238 Mdot
.99 .43253 Mdot
.99 .4338 Mdot
.99 .43399 Mdot
.99 .43417 Mdot
.99 .43537 Mdot
.99 .43546 Mdot
.99 .43551 Mdot
.99 .43611 Mdot
.99 .43738 Mdot
.99 .43773 Mdot
.99 .43774 Mdot
.99 .43789 Mdot
.99 .43816 Mdot
.99 .43833 Mdot
.99 .43876 Mdot
.99 .43922 Mdot
.99 .43952 Mdot
.99 .43983 Mdot
.99 .43985 Mdot
.99 .44027 Mdot
.99 .44045 Mdot
.99 .4428 Mdot
.99 .44303 Mdot
.99 .44365 Mdot
.99 .44521 Mdot
.99 .44529 Mdot
.99 .44557 Mdot
.99 .44611 Mdot
.99 .44785 Mdot
.99 .44813 Mdot
.99 .44853 Mdot
.99 .44859 Mdot
.99 .45021 Mdot
.99 .45041 Mdot
.99 .45143 Mdot
.99 .45226 Mdot
.99 .45232 Mdot
.99 .45254 Mdot
.99 .45262 Mdot
.99 .45327 Mdot
.99 .45363 Mdot
.99 .45365 Mdot
.99 .45385 Mdot
.99 .45445 Mdot
.99 .45482 Mdot
.99 .45592 Mdot
.99 .45646 Mdot
.99 .45707 Mdot
.99 .45729 Mdot
.99 .45809 Mdot
.99 .45809 Mdot
.99 .45839 Mdot
.99 .45881 Mdot
.99 .45996 Mdot
.99 .46092 Mdot
.99 .46123 Mdot
.99 .4615 Mdot
.99 .46246 Mdot
.99 .46258 Mdot
.99 .46363 Mdot
.99 .4639 Mdot
.99 .46419 Mdot
.99 .46598 Mdot
.99 .46639 Mdot
.99 .46657 Mdot
.99 .46679 Mdot
.99 .46897 Mdot
.99 .46938 Mdot
.99 .46943 Mdot
.99 .46988 Mdot
.99 .47054 Mdot
.99 .47059 Mdot
.99 .47113 Mdot
.99 .47148 Mdot
.99 .47188 Mdot
.99 .47199 Mdot
.99 .47214 Mdot
.99 .47264 Mdot
.99 .47281 Mdot
.99 .47343 Mdot
.99 .47431 Mdot
.99 .47483 Mdot
.99 .47525 Mdot
.99 .47577 Mdot
.99 .47601 Mdot
.99 .4761 Mdot
.99 .4764 Mdot
.99 .4768 Mdot
.99 .47857 Mdot
.99 .47868 Mdot
.99 .47927 Mdot
.99 .48002 Mdot
.99 .48076 Mdot
.99 .4827 Mdot
.99 .48392 Mdot
.99 .48394 Mdot
.99 .48405 Mdot
.99 .48424 Mdot
.99 .48489 Mdot
.99 .48505 Mdot
.99 .48654 Mdot
.99 .48715 Mdot
.99 .48776 Mdot
.99 .4883 Mdot
.99 .48878 Mdot
.99 .48949 Mdot
.99 .48974 Mdot
.99 .48975 Mdot
.99 .49032 Mdot
.99 .49142 Mdot
.99 .49164 Mdot
.99 .49279 Mdot
.99 .49292 Mdot
.99 .49294 Mdot
.99 .49354 Mdot
.99 .49548 Mdot
.99 .49625 Mdot
.99 .49723 Mdot
.99 .49845 Mdot
.99 .49852 Mdot
.99 .49892 Mdot
.99 .49925 Mdot
.99 .49976 Mdot
.99 .49997 Mdot
.99 .50005 Mdot
.99 .50149 Mdot
.99 .5018 Mdot
.99 .50198 Mdot
.99 .50466 Mdot
.99 .50501 Mdot
.99 .50517 Mdot
.99 .50523 Mdot
.99 .50677 Mdot
.99 .50756 Mdot
.99 .50823 Mdot
.99 .50886 Mdot
.99 .51013 Mdot
.99 .51102 Mdot
.99 .51174 Mdot
.99 .51234 Mdot
.99 .51253 Mdot
.99 .51275 Mdot
.99 .51328 Mdot
.99 .51392 Mdot
.99 .51394 Mdot
.99 .51455 Mdot
.99 .51458 Mdot
.99 .51499 Mdot
.99 .51562 Mdot
.99 .51613 Mdot
.99 .51627 Mdot
.99 .51729 Mdot
.99 .5176 Mdot
.99 .51763 Mdot
.99 .51794 Mdot
.99 .51977 Mdot
.99 .52051 Mdot
.99 .52093 Mdot
.99 .52132 Mdot
.99 .52141 Mdot
.99 .52206 Mdot
.99 .52215 Mdot
.99 .52224 Mdot
.99 .52289 Mdot
.99 .52386 Mdot
.99 .52404 Mdot
.99 .52434 Mdot
.99 .52456 Mdot
.99 .52479 Mdot
.99 .52494 Mdot
.99 .5251 Mdot
.99 .52782 Mdot
.99 .52786 Mdot
.99 .52827 Mdot
.99 .52915 Mdot
.99 .52952 Mdot
.99 .53045 Mdot
.99 .53096 Mdot
.99 .53138 Mdot
.99 .53141 Mdot
.99 .53267 Mdot
.99 .53323 Mdot
.99 .53381 Mdot
.99 .53432 Mdot
.99 .53432 Mdot
.99 .53469 Mdot
.99 .53712 Mdot
.99 .53831 Mdot
.99 .54003 Mdot
.99 .54005 Mdot
.99 .54061 Mdot
.99 .54109 Mdot
.99 .54129 Mdot
.99 .54175 Mdot
.99 .54278 Mdot
.99 .54325 Mdot
.99 .54357 Mdot
.99 .54467 Mdot
.99 .54472 Mdot
.99 .54502 Mdot
.99 .54675 Mdot
.99 .54738 Mdot
.99 .54743 Mdot
.99 .54931 Mdot
.99 .55018 Mdot
.99 .55031 Mdot
.99 .55116 Mdot
.99 .55127 Mdot
.99 .5536 Mdot
.99 .55409 Mdot
.99 .55471 Mdot
.99 .55624 Mdot
.99 .55649 Mdot
.99 .55891 Mdot
.99 .56172 Mdot
.99 .5622 Mdot
.99 .56285 Mdot
.99 .56306 Mdot
.99 .56364 Mdot
.99 .56422 Mdot
.99 .56438 Mdot
.99 .5644 Mdot
.99 .56585 Mdot
.99 .56631 Mdot
.99 .56763 Mdot
.99 .56778 Mdot
.99 .56954 Mdot
.99 .56977 Mdot
.99 .57021 Mdot
.99 .5704 Mdot
.99 .57087 Mdot
.99 .57113 Mdot
.99 .57134 Mdot
.99 .57135 Mdot
.99 .57199 Mdot
.99 .57227 Mdot
.99 .57484 Mdot
.99 .5757 Mdot
.99 .57572 Mdot
.99 .576 Mdot
.99 .57624 Mdot
.99 .57634 Mdot
.99 .57709 Mdot
.99 .57808 Mdot
.99 .57823 Mdot
.99 .57945 Mdot
.99 .58039 Mdot
.99 .58083 Mdot
.99 .5809 Mdot
.99 .58133 Mdot
.99 .58524 Mdot
.99 .58666 Mdot
.99 .5869 Mdot
.99 .58734 Mdot
.99 .588 Mdot
.99 .58801 Mdot
.99 .58875 Mdot
.99 .58972 Mdot
.99 .59061 Mdot
.99 .59105 Mdot
.99 .59153 Mdot
.99 .59372 Mdot
.99 .59373 Mdot
.99 .59492 Mdot
.99 .595 Mdot
.99 .59609 Mdot
.99 .59631 Mdot
.99 .59656 Mdot
.99 .59926 Mdot
.992 .01669 Mdot
.992 .01696 Mdot
.992 .01863 Mdot
.992 .01917 Mdot
.992 .02018 Mdot
.992 .02137 Mdot
.992 .02181 Mdot
.992 .02248 Mdot
.992 .02355 Mdot
.992 .02483 Mdot
.992 .02491 Mdot
.992 .02556 Mdot
.992 .02564 Mdot
.992 .02664 Mdot
.992 .02665 Mdot
.992 .02785 Mdot
.992 .02793 Mdot
.992 .02879 Mdot
.992 .02909 Mdot
.992 .03012 Mdot
.992 .03026 Mdot
.992 .03095 Mdot
.992 .031 Mdot
.992 .03207 Mdot
.992 .03223 Mdot
.992 .03368 Mdot
.992 .03477 Mdot
.992 .03494 Mdot
.992 .03535 Mdot
.992 .03623 Mdot
.992 .0364 Mdot
.992 .03762 Mdot
.992 .03838 Mdot
.992 .0384 Mdot
.992 .04078 Mdot
.992 .04093 Mdot
.992 .04172 Mdot
.992 .04211 Mdot
.992 .04263 Mdot
.992 .04313 Mdot
.992 .04324 Mdot
.992 .04328 Mdot
.992 .04329 Mdot
.992 .04338 Mdot
.992 .04376 Mdot
.992 .04425 Mdot
.992 .04471 Mdot
.992 .04529 Mdot
.992 .04533 Mdot
.992 .04556 Mdot
.992 .04692 Mdot
.992 .04702 Mdot
.992 .04767 Mdot
.992 .04915 Mdot
.992 .04947 Mdot
.992 .04984 Mdot
.992 .05025 Mdot
.992 .05064 Mdot
.992 .05168 Mdot
.992 .05176 Mdot
.992 .05235 Mdot
.992 .05272 Mdot
.992 .05323 Mdot
.992 .05451 Mdot
.992 .05484 Mdot
.992 .05565 Mdot
.992 .05741 Mdot
.992 .05761 Mdot
.992 .05773 Mdot
.992 .05946 Mdot
.992 .05965 Mdot
.992 .05977 Mdot
.992 .06016 Mdot
.992 .06166 Mdot
.992 .06169 Mdot
.992 .0617 Mdot
.992 .06241 Mdot
.992 .06431 Mdot
.992 .06524 Mdot
.992 .06571 Mdot
.992 .06639 Mdot
.992 .06643 Mdot
.992 .06672 Mdot
.992 .06709 Mdot
.992 .0683 Mdot
.992 .06864 Mdot
.992 .06906 Mdot
.992 .07009 Mdot
.992 .0701 Mdot
.992 .07108 Mdot
.992 .0712 Mdot
.992 .0713 Mdot
.992 .07139 Mdot
.992 .07141 Mdot
.992 .07158 Mdot
.992 .07233 Mdot
.992 .07259 Mdot
.992 .07332 Mdot
.992 .07422 Mdot
.992 .07537 Mdot
.992 .07546 Mdot
.992 .07592 Mdot
.992 .07854 Mdot
.992 .0786 Mdot
.992 .0788 Mdot
.992 .07924 Mdot
.992 .07927 Mdot
.992 .08009 Mdot
.992 .08182 Mdot
.992 .08275 Mdot
.992 .08304 Mdot
.992 .08328 Mdot
.992 .08367 Mdot
.992 .0844 Mdot
.992 .08521 Mdot
.992 .08533 Mdot
.992 .08599 Mdot
.992 .08677 Mdot
.992 .08806 Mdot
.992 .08821 Mdot
.992 .08935 Mdot
.992 .08936 Mdot
.992 .08938 Mdot
.992 .08955 Mdot
.992 .09009 Mdot
.992 .09012 Mdot
.992 .09113 Mdot
.992 .09136 Mdot
.992 .09167 Mdot
.992 .09206 Mdot
.992 .09277 Mdot
.992 .09329 Mdot
.992 .09334 Mdot
.992 .09349 Mdot
.992 .09355 Mdot
.992 .09367 Mdot
.992 .09433 Mdot
.992 .09458 Mdot
.992 .09594 Mdot
.992 .09801 Mdot
.992 .0981 Mdot
.992 .09942 Mdot
.992 .09969 Mdot
.992 .09983 Mdot
.992 .09993 Mdot
.992 .10006 Mdot
.992 .10348 Mdot
.992 .10387 Mdot
.992 .10411 Mdot
.992 .10443 Mdot
.992 .10488 Mdot
.992 .10606 Mdot
.992 .10614 Mdot
.992 .10623 Mdot
.992 .10786 Mdot
.992 .10791 Mdot
.992 .10793 Mdot
.992 .10863 Mdot
.992 .10934 Mdot
.992 .11056 Mdot
.992 .11101 Mdot
.992 .11134 Mdot
.992 .11163 Mdot
.992 .11311 Mdot
.992 .11496 Mdot
.992 .11588 Mdot
.992 .11724 Mdot
.992 .11731 Mdot
.992 .11789 Mdot
.992 .11862 Mdot
.992 .12081 Mdot
.992 .12102 Mdot
.992 .12133 Mdot
.992 .1217 Mdot
.992 .12218 Mdot
.992 .12231 Mdot
.992 .12254 Mdot
.992 .12436 Mdot
.992 .12458 Mdot
.992 .1246 Mdot
.992 .12621 Mdot
.992 .12655 Mdot
.992 .12678 Mdot
.992 .12698 Mdot
.992 .12716 Mdot
.992 .1272 Mdot
.992 .12753 Mdot
.992 .1284 Mdot
.992 .12874 Mdot
.992 .12874 Mdot
.992 .12903 Mdot
.992 .12954 Mdot
.992 .1296 Mdot
.992 .13099 Mdot
.992 .13143 Mdot
.992 .13225 Mdot
.992 .13256 Mdot
.992 .13278 Mdot
.992 .13319 Mdot
.992 .13505 Mdot
.992 .13523 Mdot
.992 .13615 Mdot
.992 .13705 Mdot
.992 .13802 Mdot
.992 .14107 Mdot
.992 .14135 Mdot
.992 .14143 Mdot
.992 .14147 Mdot
.992 .14187 Mdot
.992 .14209 Mdot
.992 .14272 Mdot
.992 .14278 Mdot
.992 .14279 Mdot
.992 .14378 Mdot
.992 .14441 Mdot
.992 .14543 Mdot
.992 .14566 Mdot
.992 .14606 Mdot
.992 .14728 Mdot
.992 .14785 Mdot
.992 .1497 Mdot
.992 .15028 Mdot
.992 .15076 Mdot
.992 .15153 Mdot
.992 .15298 Mdot
.992 .15334 Mdot
.992 .15458 Mdot
.992 .15481 Mdot
.992 .15552 Mdot
.992 .15591 Mdot
.992 .15606 Mdot
.992 .15612 Mdot
.992 .15766 Mdot
.992 .15896 Mdot
.992 .15964 Mdot
.992 .1597 Mdot
.992 .16022 Mdot
.992 .16053 Mdot
.992 .16081 Mdot
.992 .16113 Mdot
.992 .16148 Mdot
.992 .162 Mdot
.992 .16278 Mdot
.992 .16282 Mdot
.992 .16286 Mdot
.992 .16319 Mdot
.992 .16425 Mdot
.992 .16432 Mdot
.992 .16544 Mdot
.992 .16555 Mdot
.992 .16632 Mdot
.992 .16634 Mdot
.992 .16678 Mdot
.992 .16709 Mdot
.992 .1674 Mdot
.992 .16816 Mdot
.992 .16957 Mdot
.992 .17061 Mdot
.992 .17071 Mdot
.992 .171 Mdot
.992 .17101 Mdot
.992 .17113 Mdot
.992 .17137 Mdot
.992 .17267 Mdot
.992 .17278 Mdot
.992 .17316 Mdot
.992 .1734 Mdot
.992 .17465 Mdot
.992 .17519 Mdot
.992 .17586 Mdot
.992 .17658 Mdot
.992 .17782 Mdot
.992 .1781 Mdot
.992 .17996 Mdot
.992 .18014 Mdot
.992 .18015 Mdot
.992 .18117 Mdot
.992 .18271 Mdot
.992 .18276 Mdot
.992 .1833 Mdot
.992 .18358 Mdot
.992 .18378 Mdot
.992 .18404 Mdot
.992 .18491 Mdot
.992 .18493 Mdot
.992 .18533 Mdot
.992 .18761 Mdot
.992 .18821 Mdot
.992 .1883 Mdot
.992 .18837 Mdot
.992 .19083 Mdot
.992 .1916 Mdot
.992 .19207 Mdot
.992 .19272 Mdot
.992 .19293 Mdot
.992 .19361 Mdot
.992 .19594 Mdot
.992 .19611 Mdot
.992 .19628 Mdot
.992 .19654 Mdot
.992 .19696 Mdot
.992 .19712 Mdot
.992 .19743 Mdot
.992 .19952 Mdot
.992 .19962 Mdot
.992 .19966 Mdot
.992 .20039 Mdot
.992 .20095 Mdot
.992 .20103 Mdot
.992 .20207 Mdot
.992 .20246 Mdot
.992 .2039 Mdot
.992 .20487 Mdot
.992 .20518 Mdot
.992 .20525 Mdot
.992 .20577 Mdot
.992 .20643 Mdot
.992 .20699 Mdot
.992 .20767 Mdot
.992 .20782 Mdot
.992 .20994 Mdot
.992 .21005 Mdot
.992 .21017 Mdot
.992 .21092 Mdot
.992 .21181 Mdot
.992 .21281 Mdot
.992 .21359 Mdot
.992 .21382 Mdot
.992 .21493 Mdot
.992 .21544 Mdot
.992 .21617 Mdot
.992 .2165 Mdot
.992 .21651 Mdot
.992 .21812 Mdot
.992 .21817 Mdot
.992 .21827 Mdot
.992 .21942 Mdot
.992 .22087 Mdot
.992 .22108 Mdot
.992 .22195 Mdot
.992 .22237 Mdot
.992 .2224 Mdot
.992 .2252 Mdot
.992 .22563 Mdot
.992 .22623 Mdot
.992 .22624 Mdot
.992 .22634 Mdot
.992 .22697 Mdot
.992 .22758 Mdot
.992 .22792 Mdot
.992 .22817 Mdot
.992 .22819 Mdot
.992 .22864 Mdot
.992 .22874 Mdot
.992 .22894 Mdot
.992 .22931 Mdot
.992 .23092 Mdot
.992 .2316 Mdot
.992 .23225 Mdot
.992 .23269 Mdot
.992 .23273 Mdot
.992 .23386 Mdot
.992 .2343 Mdot
.992 .23592 Mdot
.992 .23659 Mdot
.992 .23681 Mdot
.992 .23704 Mdot
.992 .23746 Mdot
.992 .2378 Mdot
.992 .23783 Mdot
.992 .23788 Mdot
.992 .23855 Mdot
.992 .23957 Mdot
.992 .24026 Mdot
.992 .24039 Mdot
.992 .24094 Mdot
.992 .24095 Mdot
.992 .24129 Mdot
.992 .24151 Mdot
.992 .24254 Mdot
.992 .24265 Mdot
.992 .24279 Mdot
.992 .24347 Mdot
.992 .2438 Mdot
.992 .24462 Mdot
.992 .24522 Mdot
.992 .24539 Mdot
.992 .24548 Mdot
.992 .24557 Mdot
.992 .24628 Mdot
.992 .24758 Mdot
.992 .24791 Mdot
.992 .24809 Mdot
.992 .24842 Mdot
.992 .24852 Mdot
.992 .24868 Mdot
.992 .24893 Mdot
.992 .24895 Mdot
.992 .24978 Mdot
.992 .25058 Mdot
.992 .25347 Mdot
.992 .25381 Mdot
.992 .25395 Mdot
.992 .25465 Mdot
.992 .25563 Mdot
.992 .25662 Mdot
.992 .25743 Mdot
.992 .25817 Mdot
.992 .25828 Mdot
.992 .25887 Mdot
.992 .25919 Mdot
.992 .25934 Mdot
.992 .26066 Mdot
.992 .26071 Mdot
.992 .26109 Mdot
.992 .26169 Mdot
.992 .26222 Mdot
.992 .26357 Mdot
.992 .26389 Mdot
.992 .2654 Mdot
.992 .26595 Mdot
.992 .26596 Mdot
.992 .26612 Mdot
.992 .2662 Mdot
.992 .26664 Mdot
.992 .26698 Mdot
.992 .2673 Mdot
.992 .26743 Mdot
.992 .26816 Mdot
.992 .2683 Mdot
.992 .26838 Mdot
.992 .26868 Mdot
.992 .26879 Mdot
.992 .26882 Mdot
.992 .26886 Mdot
.992 .27013 Mdot
.992 .27056 Mdot
.992 .27077 Mdot
.992 .27132 Mdot
.992 .27204 Mdot
.992 .27238 Mdot
.992 .27279 Mdot
.992 .27379 Mdot
.992 .27406 Mdot
.992 .27452 Mdot
.992 .27531 Mdot
.992 .27643 Mdot
.992 .27773 Mdot
.992 .27885 Mdot
.992 .27911 Mdot
.992 .27961 Mdot
.992 .2818 Mdot
.992 .28252 Mdot
.992 .28357 Mdot
.992 .28367 Mdot
.992 .28406 Mdot
.992 .28437 Mdot
.992 .28462 Mdot
.992 .28608 Mdot
.992 .28616 Mdot
.992 .28623 Mdot
.992 .28747 Mdot
.992 .28902 Mdot
.992 .28958 Mdot
.992 .28975 Mdot
.992 .29068 Mdot
.992 .29221 Mdot
.992 .29244 Mdot
.992 .29251 Mdot
.992 .29267 Mdot
.992 .29313 Mdot
.992 .29408 Mdot
.992 .29484 Mdot
.992 .29513 Mdot
.992 .29526 Mdot
.992 .29541 Mdot
.992 .29833 Mdot
.992 .29878 Mdot
.992 .29931 Mdot
.992 .29992 Mdot
.992 .30089 Mdot
.992 .30146 Mdot
.992 .3019 Mdot
.992 .30225 Mdot
.992 .30232 Mdot
.992 .30237 Mdot
.992 .30323 Mdot
.992 .3034 Mdot
.992 .30359 Mdot
.992 .30401 Mdot
.992 .30419 Mdot
.992 .30457 Mdot
.992 .30485 Mdot
.992 .30521 Mdot
.992 .30589 Mdot
.992 .3062 Mdot
.992 .30631 Mdot
.992 .30653 Mdot
.992 .30693 Mdot
.992 .307 Mdot
.992 .30806 Mdot
.992 .30848 Mdot
.992 .30855 Mdot
.992 .30863 Mdot
.992 .30914 Mdot
.992 .3093 Mdot
.992 .31139 Mdot
.992 .31153 Mdot
.992 .31315 Mdot
.992 .31375 Mdot
.992 .31397 Mdot
.992 .31549 Mdot
.992 .31553 Mdot
.992 .3159 Mdot
.992 .31641 Mdot
.992 .31641 Mdot
.992 .31702 Mdot
.992 .31764 Mdot
.992 .31823 Mdot
.992 .31858 Mdot
.992 .3186 Mdot
.992 .31915 Mdot
.992 .31996 Mdot
.992 .3208 Mdot
.992 .32194 Mdot
.992 .32401 Mdot
.992 .3242 Mdot
.992 .32472 Mdot
.992 .32479 Mdot
.992 .3248 Mdot
.992 .32484 Mdot
.992 .32503 Mdot
.992 .32528 Mdot
.992 .32551 Mdot
.992 .32583 Mdot
.992 .327 Mdot
.992 .3281 Mdot
.992 .32831 Mdot
.992 .3285 Mdot
.992 .32903 Mdot
.992 .32907 Mdot
.992 .32955 Mdot
.992 .32981 Mdot
.992 .33202 Mdot
.992 .33295 Mdot
.992 .33305 Mdot
.992 .33311 Mdot
.992 .33407 Mdot
.992 .33444 Mdot
.992 .33539 Mdot
.992 .33586 Mdot
.992 .3361 Mdot
.992 .33644 Mdot
.992 .33679 Mdot
.992 .33758 Mdot
.992 .33831 Mdot
.992 .33887 Mdot
.992 .33957 Mdot
.992 .34257 Mdot
.992 .34292 Mdot
.992 .34293 Mdot
.992 .34422 Mdot
.992 .34469 Mdot
.992 .34496 Mdot
.992 .34599 Mdot
.992 .34671 Mdot
.992 .34801 Mdot
.992 .34802 Mdot
.992 .34812 Mdot
.992 .34839 Mdot
.992 .34903 Mdot
.992 .34919 Mdot
.992 .34938 Mdot
.992 .34974 Mdot
.992 .35 Mdot
.992 .35003 Mdot
.992 .3501 Mdot
.992 .35013 Mdot
.992 .35065 Mdot
.992 .35238 Mdot
.992 .35242 Mdot
.992 .35322 Mdot
.992 .35335 Mdot
.992 .35562 Mdot
.992 .35644 Mdot
.992 .35648 Mdot
.992 .35652 Mdot
.992 .35773 Mdot
.992 .3587 Mdot
.992 .35893 Mdot
.992 .3591 Mdot
.992 .35924 Mdot
.992 .36387 Mdot
.992 .36413 Mdot
.992 .36456 Mdot
.992 .36463 Mdot
.992 .36566 Mdot
.992 .36659 Mdot
.992 .3677 Mdot
.992 .36787 Mdot
.992 .36787 Mdot
.992 .3683 Mdot
.992 .36922 Mdot
.992 .36964 Mdot
.992 .36979 Mdot
.992 .37011 Mdot
.992 .37206 Mdot
.992 .37254 Mdot
.992 .37408 Mdot
.992 .37427 Mdot
.992 .3746 Mdot
.992 .37494 Mdot
.992 .37545 Mdot
.992 .37628 Mdot
.992 .3764 Mdot
.992 .3766 Mdot
.992 .37721 Mdot
.992 .38027 Mdot
.992 .38137 Mdot
.992 .38156 Mdot
.992 .38164 Mdot
.992 .3831 Mdot
.992 .38345 Mdot
.992 .38348 Mdot
.992 .38403 Mdot
.992 .3842 Mdot
.992 .38437 Mdot
.992 .38463 Mdot
.992 .38637 Mdot
.992 .38642 Mdot
.992 .38682 Mdot
.992 .3872 Mdot
.992 .38915 Mdot
.992 .38917 Mdot
.992 .39006 Mdot
.992 .39038 Mdot
.992 .39101 Mdot
.992 .39128 Mdot
.992 .39198 Mdot
.992 .3926 Mdot
.992 .39275 Mdot
.992 .39378 Mdot
.992 .39429 Mdot
.992 .39507 Mdot
.992 .39618 Mdot
.992 .39619 Mdot
.992 .39639 Mdot
.992 .39754 Mdot
.992 .39784 Mdot
.992 .39789 Mdot
.992 .39792 Mdot
.992 .40022 Mdot
.992 .40204 Mdot
.992 .40225 Mdot
.992 .40233 Mdot
.992 .40249 Mdot
.992 .40398 Mdot
.992 .40426 Mdot
.992 .40483 Mdot
.992 .40575 Mdot
.992 .4064 Mdot
.992 .40643 Mdot
.992 .40765 Mdot
.992 .40773 Mdot
.992 .40885 Mdot
.992 .40891 Mdot
.992 .40929 Mdot
.992 .40974 Mdot
.992 .41024 Mdot
.992 .41075 Mdot
.992 .41131 Mdot
.992 .41194 Mdot
.992 .4121 Mdot
.992 .41211 Mdot
.992 .41294 Mdot
.992 .41441 Mdot
.992 .41485 Mdot
.992 .41506 Mdot
.992 .41507 Mdot
.992 .41701 Mdot
.992 .41706 Mdot
.992 .41769 Mdot
.992 .41799 Mdot
.992 .41827 Mdot
.992 .41837 Mdot
.992 .41856 Mdot
.992 .41937 Mdot
.992 .41971 Mdot
.992 .42085 Mdot
.992 .42108 Mdot
.992 .42234 Mdot
.992 .42285 Mdot
.992 .42373 Mdot
.992 .42415 Mdot
.992 .4246 Mdot
.992 .42535 Mdot
.992 .42569 Mdot
.992 .42586 Mdot
.992 .42628 Mdot
.992 .42658 Mdot
.992 .42671 Mdot
.992 .42676 Mdot
.992 .42777 Mdot
.992 .42803 Mdot
.992 .42819 Mdot
.992 .42832 Mdot
.992 .42845 Mdot
.992 .42928 Mdot
.992 .43098 Mdot
.992 .43133 Mdot
.992 .43232 Mdot
.992 .4331 Mdot
.992 .43316 Mdot
.992 .43346 Mdot
.992 .43362 Mdot
.992 .43436 Mdot
.992 .43439 Mdot
.992 .43458 Mdot
.992 .43488 Mdot
.992 .43515 Mdot
.992 .43583 Mdot
.992 .43599 Mdot
.992 .43703 Mdot
.992 .43737 Mdot
.992 .43771 Mdot
.992 .43814 Mdot
.992 .43821 Mdot
.992 .43825 Mdot
.992 .43849 Mdot
.992 .43913 Mdot
.992 .43935 Mdot
.992 .43973 Mdot
.992 .44027 Mdot
.992 .44047 Mdot
.992 .44098 Mdot
.992 .44231 Mdot
.992 .44366 Mdot
.992 .44391 Mdot
.992 .44501 Mdot
.992 .44591 Mdot
.992 .44616 Mdot
.992 .44631 Mdot
.992 .44717 Mdot
.992 .44725 Mdot
.992 .44787 Mdot
.992 .44894 Mdot
.992 .44949 Mdot
.992 .45038 Mdot
.992 .45041 Mdot
.992 .45073 Mdot
.992 .45188 Mdot
.992 .45358 Mdot
.992 .45384 Mdot
.992 .45415 Mdot
.992 .45492 Mdot
.992 .45515 Mdot
.992 .45536 Mdot
.992 .45582 Mdot
.992 .456 Mdot
.992 .4563 Mdot
.992 .45663 Mdot
.992 .45731 Mdot
.992 .45737 Mdot
.992 .45748 Mdot
.992 .45825 Mdot
.992 .4588 Mdot
.992 .46082 Mdot
.992 .46221 Mdot
.992 .46246 Mdot
.992 .46338 Mdot
.992 .46355 Mdot
.992 .46357 Mdot
.992 .46425 Mdot
.992 .46467 Mdot
.992 .46665 Mdot
.992 .46671 Mdot
.992 .46693 Mdot
.992 .46721 Mdot
.992 .4678 Mdot
.992 .46856 Mdot
.992 .46882 Mdot
.992 .46921 Mdot
.992 .4708 Mdot
.992 .47085 Mdot
.992 .47136 Mdot
.992 .47203 Mdot
.992 .47238 Mdot
.992 .47256 Mdot
.992 .47273 Mdot
.992 .47313 Mdot
.992 .47413 Mdot
.992 .47648 Mdot
.992 .47671 Mdot
.992 .47737 Mdot
.992 .47773 Mdot
.992 .47839 Mdot
.992 .47858 Mdot
.992 .4789 Mdot
.992 .47908 Mdot
.992 .47939 Mdot
.992 .4794 Mdot
.992 .47944 Mdot
.992 .48108 Mdot
.992 .48222 Mdot
.992 .48263 Mdot
.992 .48266 Mdot
.992 .48268 Mdot
.992 .48378 Mdot
.992 .48638 Mdot
.992 .48673 Mdot
.992 .48676 Mdot
.992 .48831 Mdot
.992 .4884 Mdot
.992 .48908 Mdot
.992 .48937 Mdot
.992 .48953 Mdot
.992 .49051 Mdot
.992 .49075 Mdot
.992 .49153 Mdot
.992 .4927 Mdot
.992 .49465 Mdot
.992 .49625 Mdot
.992 .49626 Mdot
.992 .49654 Mdot
.992 .49685 Mdot
.992 .49772 Mdot
.992 .49795 Mdot
.992 .49912 Mdot
.992 .49913 Mdot
.992 .49974 Mdot
.992 .50006 Mdot
.992 .5002 Mdot
.992 .50172 Mdot
.992 .50267 Mdot
.992 .50277 Mdot
.992 .50353 Mdot
.992 .50355 Mdot
.992 .50471 Mdot
.992 .50577 Mdot
.992 .50674 Mdot
.992 .50703 Mdot
.992 .50782 Mdot
.992 .50784 Mdot
.992 .50845 Mdot
.992 .50905 Mdot
.992 .50908 Mdot
.992 .50975 Mdot
.992 .51001 Mdot
.992 .51029 Mdot
.992 .51069 Mdot
.992 .51069 Mdot
.992 .51208 Mdot
.992 .51316 Mdot
.992 .51319 Mdot
.992 .51351 Mdot
.992 .51366 Mdot
.992 .51435 Mdot
.992 .51453 Mdot
.992 .51521 Mdot
.992 .51585 Mdot
.992 .51611 Mdot
.992 .51699 Mdot
.992 .51737 Mdot
.992 .51754 Mdot
.992 .51784 Mdot
.992 .51799 Mdot
.992 .51859 Mdot
.992 .51872 Mdot
.992 .5188 Mdot
.992 .51887 Mdot
.992 .51893 Mdot
.992 .51935 Mdot
.992 .52021 Mdot
.992 .52038 Mdot
.992 .52128 Mdot
.992 .52146 Mdot
.992 .52154 Mdot
.992 .52217 Mdot
.992 .52231 Mdot
.992 .52273 Mdot
.992 .52343 Mdot
.992 .52382 Mdot
.992 .52399 Mdot
.992 .52489 Mdot
.992 .52525 Mdot
.992 .52592 Mdot
.992 .52673 Mdot
.992 .52773 Mdot
.992 .52786 Mdot
.992 .52872 Mdot
.992 .52926 Mdot
.992 .53 Mdot
.992 .53016 Mdot
.992 .53074 Mdot
.992 .53173 Mdot
.992 .53188 Mdot
.992 .53239 Mdot
.992 .53282 Mdot
.992 .53297 Mdot
.992 .53395 Mdot
.992 .53654 Mdot
.992 .53818 Mdot
.992 .53877 Mdot
.992 .53928 Mdot
.992 .54028 Mdot
.992 .54056 Mdot
.992 .54145 Mdot
.992 .54314 Mdot
.992 .54445 Mdot
.992 .54461 Mdot
.992 .54603 Mdot
.992 .54624 Mdot
.992 .54625 Mdot
.992 .54682 Mdot
.992 .54813 Mdot
.992 .54831 Mdot
.992 .54832 Mdot
.992 .5491 Mdot
.992 .54972 Mdot
.992 .55021 Mdot
.992 .55073 Mdot
.992 .5531 Mdot
.992 .55325 Mdot
.992 .55341 Mdot
.992 .55456 Mdot
.992 .5551 Mdot
.992 .55586 Mdot
.992 .55678 Mdot
.992 .55839 Mdot
.992 .55854 Mdot
.992 .55894 Mdot
.992 .55894 Mdot
.992 .55956 Mdot
.992 .55991 Mdot
.992 .56004 Mdot
.992 .56018 Mdot
.992 .56038 Mdot
.992 .56039 Mdot
.992 .56223 Mdot
.992 .56356 Mdot
.992 .56375 Mdot
.992 .56443 Mdot
.992 .56475 Mdot
.992 .56518 Mdot
.992 .56527 Mdot
.992 .56572 Mdot
.992 .56585 Mdot
.992 .56617 Mdot
.992 .5668 Mdot
.992 .56709 Mdot
.992 .56754 Mdot
.992 .56897 Mdot
.992 .56904 Mdot
.992 .57012 Mdot
.992 .57049 Mdot
.992 .57107 Mdot
.992 .57132 Mdot
.992 .57154 Mdot
.992 .57161 Mdot
.992 .57424 Mdot
.992 .57544 Mdot
.992 .57589 Mdot
.992 .57674 Mdot
.992 .5774 Mdot
.992 .5783 Mdot
.992 .57831 Mdot
.992 .57859 Mdot
.992 .57934 Mdot
.992 .58056 Mdot
.992 .58249 Mdot
.992 .58277 Mdot
.992 .58362 Mdot
.992 .58443 Mdot
.992 .5845 Mdot
.992 .5847 Mdot
.992 .58501 Mdot
.992 .58519 Mdot
.992 .58533 Mdot
.992 .58543 Mdot
.992 .58703 Mdot
.992 .58713 Mdot
.992 .58747 Mdot
.992 .58763 Mdot
.992 .58785 Mdot
.992 .58867 Mdot
.992 .58904 Mdot
.992 .58979 Mdot
.992 .59034 Mdot
.992 .59105 Mdot
.992 .59242 Mdot
.992 .59302 Mdot
.992 .59325 Mdot
.992 .59367 Mdot
.992 .59446 Mdot
.992 .59461 Mdot
.992 .59671 Mdot
.992 .59755 Mdot
.992 .59769 Mdot
.992 .59785 Mdot
.992 .59886 Mdot
.992 .59916 Mdot
.994 .01552 Mdot
.994 .01631 Mdot
.994 .01784 Mdot
.994 .01788 Mdot
.994 .01821 Mdot
.994 .01892 Mdot
.994 .02059 Mdot
.994 .02092 Mdot
.994 .021 Mdot
.994 .02166 Mdot
.994 .02182 Mdot
.994 .02232 Mdot
.994 .02234 Mdot
.994 .02307 Mdot
.994 .02324 Mdot
.994 .02363 Mdot
.994 .0247 Mdot
.994 .02578 Mdot
.994 .02639 Mdot
.994 .02664 Mdot
.994 .02706 Mdot
.994 .02722 Mdot
.994 .02811 Mdot
.994 .02843 Mdot
.994 .02852 Mdot
.994 .02884 Mdot
.994 .02984 Mdot
.994 .02986 Mdot
.994 .03132 Mdot
.994 .03167 Mdot
.994 .03189 Mdot
.994 .03243 Mdot
.994 .03456 Mdot
.994 .03552 Mdot
.994 .03672 Mdot
.994 .03747 Mdot
.994 .03792 Mdot
.994 .03842 Mdot
.994 .03925 Mdot
.994 .03957 Mdot
.994 .03974 Mdot
.994 .04106 Mdot
.994 .04135 Mdot
.994 .04141 Mdot
.994 .04182 Mdot
.994 .04199 Mdot
.994 .04216 Mdot
.994 .04238 Mdot
.994 .0428 Mdot
.994 .04311 Mdot
.994 .04345 Mdot
.994 .04464 Mdot
.994 .04478 Mdot
.994 .04483 Mdot
.994 .04569 Mdot
.994 .04773 Mdot
.994 .04813 Mdot
.994 .04842 Mdot
.994 .04885 Mdot
.994 .04893 Mdot
.994 .04993 Mdot
.994 .05025 Mdot
.994 .05082 Mdot
.994 .05151 Mdot
.994 .05262 Mdot
.994 .05417 Mdot
.994 .05511 Mdot
.994 .05578 Mdot
.994 .05608 Mdot
.994 .0576 Mdot
.994 .05762 Mdot
.994 .0579 Mdot
.994 .05838 Mdot
.994 .05846 Mdot
.994 .05995 Mdot
.994 .05997 Mdot
.994 .06084 Mdot
.994 .06185 Mdot
.994 .06306 Mdot
.994 .06324 Mdot
.994 .06349 Mdot
.994 .06372 Mdot
.994 .06377 Mdot
.994 .06407 Mdot
.994 .06412 Mdot
.994 .06446 Mdot
.994 .06559 Mdot
.994 .06635 Mdot
.994 .06641 Mdot
.994 .06697 Mdot
.994 .06709 Mdot
.994 .06725 Mdot
.994 .06767 Mdot
.994 .06779 Mdot
.994 .06795 Mdot
.994 .06826 Mdot
.994 .06859 Mdot
.994 .06859 Mdot
.994 .06876 Mdot
.994 .06893 Mdot
.994 .06897 Mdot
.994 .06922 Mdot
.994 .06928 Mdot
.994 .06971 Mdot
.994 .07055 Mdot
.994 .07117 Mdot
.994 .0713 Mdot
.994 .07151 Mdot
.994 .07152 Mdot
.994 .07152 Mdot
.994 .07183 Mdot
.994 .07294 Mdot
.994 .07297 Mdot
.994 .07382 Mdot
.994 .07402 Mdot
.994 .0742 Mdot
.994 .07431 Mdot
.994 .07449 Mdot
.994 .07459 Mdot
.994 .07629 Mdot
.994 .07676 Mdot
.994 .07935 Mdot
.994 .07979 Mdot
.994 .08003 Mdot
.994 .08036 Mdot
.994 .08114 Mdot
.994 .0815 Mdot
.994 .08172 Mdot
.994 .08185 Mdot
.994 .08258 Mdot
.994 .08273 Mdot
.994 .08471 Mdot
.994 .08473 Mdot
.994 .08535 Mdot
.994 .08648 Mdot
.994 .08715 Mdot
.994 .08786 Mdot
.994 .08806 Mdot
.994 .09007 Mdot
.994 .09062 Mdot
.994 .0908 Mdot
.994 .09314 Mdot
.994 .09334 Mdot
.994 .09347 Mdot
.994 .09503 Mdot
.994 .09634 Mdot
.994 .09673 Mdot
.994 .09676 Mdot
.994 .09694 Mdot
.994 .09695 Mdot
.994 .09705 Mdot
.994 .09712 Mdot
.994 .09743 Mdot
.994 .09803 Mdot
.994 .09921 Mdot
.994 .09997 Mdot
.994 .09997 Mdot
.994 .1 Mdot
.994 .10002 Mdot
.994 .10057 Mdot
.994 .10083 Mdot
.994 .10147 Mdot
.994 .10152 Mdot
.994 .10167 Mdot
.994 .10346 Mdot
.994 .10464 Mdot
.994 .10469 Mdot
.994 .10529 Mdot
.994 .10642 Mdot
.994 .10778 Mdot
.994 .10842 Mdot
.994 .10856 Mdot
.994 .10884 Mdot
.994 .10889 Mdot
.994 .1101 Mdot
.994 .11018 Mdot
.994 .11082 Mdot
.994 .11118 Mdot
.994 .11168 Mdot
.994 .11214 Mdot
.994 .11224 Mdot
.994 .11284 Mdot
.994 .11293 Mdot
.994 .11317 Mdot
.994 .11328 Mdot
.994 .1136 Mdot
.994 .11365 Mdot
.994 .11434 Mdot
.994 .11457 Mdot
.994 .11585 Mdot
.994 .11737 Mdot
.994 .11744 Mdot
.994 .11748 Mdot
.994 .1186 Mdot
.994 .11865 Mdot
.994 .11869 Mdot
.994 .11883 Mdot
.994 .11886 Mdot
.994 .11916 Mdot
.994 .11998 Mdot
.994 .12023 Mdot
.994 .12054 Mdot
.994 .12103 Mdot
.994 .12115 Mdot
.994 .12182 Mdot
.994 .12183 Mdot
.994 .12215 Mdot
.994 .1225 Mdot
.994 .12257 Mdot
.994 .12307 Mdot
.994 .12319 Mdot
.994 .12326 Mdot
.994 .12382 Mdot
.994 .12404 Mdot
.994 .12409 Mdot
.994 .12416 Mdot
.994 .12435 Mdot
.994 .12572 Mdot
.994 .12694 Mdot
.994 .12722 Mdot
.994 .12762 Mdot
.994 .12765 Mdot
.994 .12765 Mdot
.994 .12826 Mdot
.994 .129 Mdot
.994 .13026 Mdot
.994 .13047 Mdot
.994 .13053 Mdot
.994 .13202 Mdot
.994 .13221 Mdot
.994 .13262 Mdot
.994 .13296 Mdot
.994 .13319 Mdot
.994 .13347 Mdot
.994 .1335 Mdot
.994 .13354 Mdot
.994 .13374 Mdot
.994 .13383 Mdot
.994 .13397 Mdot
.994 .13713 Mdot
.994 .13797 Mdot
.994 .13807 Mdot
.994 .13856 Mdot
.994 .14321 Mdot
.994 .14326 Mdot
.994 .14409 Mdot
.994 .14455 Mdot
.994 .14521 Mdot
.994 .14676 Mdot
.994 .14683 Mdot
.994 .1474 Mdot
.994 .14748 Mdot
.994 .14792 Mdot
.994 .14818 Mdot
.994 .14875 Mdot
.994 .14876 Mdot
.994 .14962 Mdot
.994 .14993 Mdot
.994 .15067 Mdot
.994 .15314 Mdot
.994 .15325 Mdot
.994 .15352 Mdot
.994 .15386 Mdot
.994 .1539 Mdot
.994 .15514 Mdot
.994 .15675 Mdot
.994 .15739 Mdot
.994 .15806 Mdot
.994 .15872 Mdot
.994 .16012 Mdot
.994 .16052 Mdot
.994 .16094 Mdot
.994 .16137 Mdot
.994 .16284 Mdot
.994 .16309 Mdot
.994 .16424 Mdot
.994 .16433 Mdot
.994 .16451 Mdot
.994 .16561 Mdot
.994 .1657 Mdot
.994 .16597 Mdot
.994 .16625 Mdot
.994 .16647 Mdot
.994 .16684 Mdot
.994 .16978 Mdot
.994 .17011 Mdot
.994 .1702 Mdot
.994 .17031 Mdot
.994 .17063 Mdot
.994 .17102 Mdot
.994 .17129 Mdot
.994 .17244 Mdot
.994 .17431 Mdot
.994 .17438 Mdot
.994 .17573 Mdot
.994 .17586 Mdot
.994 .17632 Mdot
.994 .17692 Mdot
.994 .177 Mdot
.994 .17708 Mdot
.994 .17777 Mdot
.994 .17782 Mdot
.994 .17782 Mdot
.994 .17818 Mdot
.994 .17819 Mdot
.994 .1784 Mdot
.994 .17853 Mdot
.994 .17915 Mdot
.994 .18035 Mdot
.994 .18201 Mdot
.994 .1827 Mdot
.994 .18348 Mdot
.994 .1842 Mdot
.994 .18421 Mdot
.994 .18425 Mdot
.994 .1843 Mdot
.994 .18453 Mdot
.994 .18483 Mdot
.994 .18503 Mdot
.994 .18524 Mdot
.994 .1854 Mdot
.994 .1859 Mdot
.994 .18719 Mdot
.994 .18728 Mdot
.994 .18758 Mdot
.994 .18871 Mdot
.994 .18976 Mdot
.994 .19105 Mdot
.994 .19114 Mdot
.994 .19237 Mdot
.994 .19268 Mdot
.994 .19313 Mdot
.994 .1935 Mdot
.994 .19359 Mdot
.994 .19478 Mdot
.994 .19702 Mdot
.994 .19736 Mdot
.994 .19785 Mdot
.994 .19857 Mdot
.994 .19972 Mdot
.994 .20045 Mdot
.994 .20056 Mdot
.994 .20099 Mdot
.994 .20128 Mdot
.994 .20131 Mdot
.994 .20185 Mdot
.994 .20194 Mdot
.994 .20279 Mdot
.994 .20383 Mdot
.994 .20419 Mdot
.994 .20434 Mdot
.994 .20449 Mdot
.994 .20453 Mdot
.994 .20578 Mdot
.994 .20649 Mdot
.994 .20659 Mdot
.994 .20747 Mdot
.994 .20807 Mdot
.994 .2084 Mdot
.994 .20859 Mdot
.994 .20966 Mdot
.994 .20979 Mdot
.994 .20997 Mdot
.994 .21044 Mdot
.994 .21047 Mdot
.994 .21066 Mdot
.994 .2113 Mdot
.994 .21139 Mdot
.994 .21148 Mdot
.994 .21278 Mdot
.994 .21323 Mdot
.994 .21576 Mdot
.994 .2188 Mdot
.994 .21893 Mdot
.994 .21901 Mdot
.994 .21909 Mdot
.994 .22123 Mdot
.994 .22133 Mdot
.994 .22142 Mdot
.994 .22147 Mdot
.994 .22169 Mdot
.994 .22175 Mdot
.994 .22234 Mdot
.994 .22398 Mdot
.994 .22447 Mdot
.994 .22509 Mdot
.994 .22607 Mdot
.994 .22632 Mdot
.994 .22735 Mdot
.994 .22764 Mdot
.994 .22766 Mdot
.994 .22829 Mdot
.994 .22898 Mdot
.994 .22913 Mdot
.994 .23012 Mdot
.994 .23037 Mdot
.994 .23049 Mdot
.994 .23162 Mdot
.994 .23171 Mdot
.994 .23205 Mdot
.994 .23214 Mdot
.994 .23229 Mdot
.994 .23267 Mdot
.994 .23347 Mdot
.994 .23364 Mdot
.994 .23398 Mdot
.994 .23418 Mdot
.994 .23429 Mdot
.994 .2346 Mdot
.994 .2354 Mdot
.994 .23688 Mdot
.994 .23782 Mdot
.994 .23837 Mdot
.994 .23917 Mdot
.994 .23923 Mdot
.994 .23923 Mdot
.994 .24045 Mdot
.994 .24192 Mdot
.994 .24252 Mdot
.994 .24309 Mdot
.994 .24349 Mdot
.994 .24382 Mdot
.994 .24402 Mdot
.994 .24442 Mdot
.994 .24484 Mdot
.994 .24491 Mdot
.994 .24495 Mdot
.994 .24514 Mdot
.994 .24517 Mdot
.994 .24748 Mdot
.994 .24792 Mdot
.994 .24829 Mdot
.994 .24911 Mdot
.994 .24979 Mdot
.994 .25011 Mdot
.994 .25024 Mdot
.994 .25079 Mdot
.994 .25081 Mdot
.994 .25086 Mdot
.994 .25094 Mdot
.994 .25134 Mdot
.994 .25149 Mdot
.994 .25152 Mdot
.994 .25179 Mdot
.994 .25208 Mdot
.994 .25395 Mdot
.994 .25588 Mdot
.994 .2559 Mdot
.994 .25712 Mdot
.994 .25755 Mdot
.994 .25807 Mdot
.994 .25834 Mdot
.994 .25974 Mdot
.994 .25994 Mdot
.994 .26054 Mdot
.994 .26091 Mdot
.994 .2622 Mdot
.994 .26318 Mdot
.994 .26533 Mdot
.994 .2662 Mdot
.994 .26726 Mdot
.994 .26822 Mdot
.994 .2684 Mdot
.994 .26847 Mdot
.994 .27016 Mdot
.994 .27027 Mdot
.994 .271 Mdot
.994 .27191 Mdot
.994 .27191 Mdot
.994 .27283 Mdot
.994 .27372 Mdot
.994 .27414 Mdot
.994 .27431 Mdot
.994 .27723 Mdot
.994 .27735 Mdot
.994 .27821 Mdot
.994 .27848 Mdot
.994 .27864 Mdot
.994 .27903 Mdot
.994 .27906 Mdot
.994 .2792 Mdot
.994 .27953 Mdot
.994 .27969 Mdot
.994 .28003 Mdot
.994 .28008 Mdot
.994 .28093 Mdot
.994 .28117 Mdot
.994 .28119 Mdot
.994 .28292 Mdot
.994 .28353 Mdot
.994 .28413 Mdot
.994 .28448 Mdot
.994 .28499 Mdot
.994 .28582 Mdot
.994 .28585 Mdot
.994 .28621 Mdot
.994 .28634 Mdot
.994 .28677 Mdot
.994 .28828 Mdot
.994 .28898 Mdot
.994 .28991 Mdot
.994 .29012 Mdot
.994 .29065 Mdot
.994 .29134 Mdot
.994 .29142 Mdot
.994 .29144 Mdot
.994 .29213 Mdot
.994 .29294 Mdot
.994 .29326 Mdot
.994 .29346 Mdot
.994 .29389 Mdot
.994 .29428 Mdot
.994 .29469 Mdot
.994 .29572 Mdot
.994 .29593 Mdot
.994 .29658 Mdot
.994 .29708 Mdot
.994 .2979 Mdot
.994 .29835 Mdot
.994 .29908 Mdot
.994 .29969 Mdot
.994 .30101 Mdot
.994 .30182 Mdot
.994 .30379 Mdot
.994 .30457 Mdot
.994 .30495 Mdot
.994 .3054 Mdot
.994 .30627 Mdot
.994 .30833 Mdot
.994 .30865 Mdot
.994 .30919 Mdot
.994 .30969 Mdot
.994 .3108 Mdot
.994 .31197 Mdot
.994 .31215 Mdot
.994 .31251 Mdot
.994 .31335 Mdot
.994 .31397 Mdot
.994 .31422 Mdot
.994 .31423 Mdot
.994 .31469 Mdot
.994 .31488 Mdot
.994 .31542 Mdot
.994 .31596 Mdot
.994 .3164 Mdot
.994 .31714 Mdot
.994 .3173 Mdot
.994 .31903 Mdot
.994 .32086 Mdot
.994 .32184 Mdot
.994 .32298 Mdot
.994 .32365 Mdot
.994 .32383 Mdot
.994 .32403 Mdot
.994 .32431 Mdot
.994 .32468 Mdot
.994 .32485 Mdot
.994 .32545 Mdot
.994 .32598 Mdot
.994 .3272 Mdot
.994 .32761 Mdot
.994 .32827 Mdot
.994 .32856 Mdot
.994 .3289 Mdot
.994 .32946 Mdot
.994 .33072 Mdot
.994 .33105 Mdot
.994 .33197 Mdot
.994 .33198 Mdot
.994 .33212 Mdot
.994 .33236 Mdot
.994 .33316 Mdot
.994 .33471 Mdot
.994 .3348 Mdot
.994 .33505 Mdot
.994 .33507 Mdot
.994 .33522 Mdot
.994 .33598 Mdot
.994 .33637 Mdot
.994 .3364 Mdot
.994 .33668 Mdot
.994 .33682 Mdot
.994 .33717 Mdot
.994 .33733 Mdot
.994 .3375 Mdot
.994 .33758 Mdot
.994 .33769 Mdot
.994 .33781 Mdot
.994 .33886 Mdot
.994 .33896 Mdot
.994 .33897 Mdot
.994 .33897 Mdot
.994 .33969 Mdot
.994 .3397 Mdot
.994 .34012 Mdot
.994 .34023 Mdot
.994 .34037 Mdot
.994 .34161 Mdot
.994 .34291 Mdot
.994 .34313 Mdot
.994 .34325 Mdot
.994 .34399 Mdot
.994 .34417 Mdot
.994 .3456 Mdot
.994 .34683 Mdot
.994 .34729 Mdot
.994 .34858 Mdot
.994 .34867 Mdot
.994 .34995 Mdot
.994 .35001 Mdot
.994 .35022 Mdot
.994 .35165 Mdot
.994 .35167 Mdot
.994 .35176 Mdot
.994 .35181 Mdot
.994 .35185 Mdot
.994 .352 Mdot
.994 .35231 Mdot
.994 .3529 Mdot
.994 .35328 Mdot
.994 .35329 Mdot
.994 .35371 Mdot
.994 .35404 Mdot
.994 .35504 Mdot
.994 .35596 Mdot
.994 .35721 Mdot
.994 .3576 Mdot
.994 .35775 Mdot
.994 .35777 Mdot
.994 .35838 Mdot
.994 .35841 Mdot
.994 .35992 Mdot
.994 .35998 Mdot
.994 .36016 Mdot
.994 .36051 Mdot
.994 .36063 Mdot
.994 .36207 Mdot
.994 .36268 Mdot
.994 .3627 Mdot
.994 .36278 Mdot
.994 .36387 Mdot
.994 .36499 Mdot
.994 .36528 Mdot
.994 .36541 Mdot
.994 .36545 Mdot
.994 .36554 Mdot
.994 .36789 Mdot
.994 .36852 Mdot
.994 .3694 Mdot
.994 .37013 Mdot
.994 .37015 Mdot
.994 .37031 Mdot
.994 .37038 Mdot
.994 .37239 Mdot
.994 .37269 Mdot
.994 .37506 Mdot
.994 .37685 Mdot
.994 .37714 Mdot
.994 .37782 Mdot
.994 .37782 Mdot
.994 .37878 Mdot
.994 .38003 Mdot
.994 .38008 Mdot
.994 .38022 Mdot
.994 .38184 Mdot
.994 .3825 Mdot
.994 .38395 Mdot
.994 .38417 Mdot
.994 .38491 Mdot
.994 .38503 Mdot
.994 .38561 Mdot
.994 .38566 Mdot
.994 .38635 Mdot
.994 .38662 Mdot
.994 .38673 Mdot
.994 .38692 Mdot
.994 .3884 Mdot
.994 .38856 Mdot
.994 .38861 Mdot
.994 .38866 Mdot
.994 .38973 Mdot
.994 .39067 Mdot
.994 .39139 Mdot
.994 .39146 Mdot
.994 .39169 Mdot
.994 .39199 Mdot
.994 .39207 Mdot
.994 .39244 Mdot
.994 .39455 Mdot
.994 .39529 Mdot
.994 .39582 Mdot
.994 .39597 Mdot
.994 .39607 Mdot
.994 .39617 Mdot
.994 .39792 Mdot
.994 .39845 Mdot
.994 .3991 Mdot
.994 .39976 Mdot
.994 .39992 Mdot
.994 .40014 Mdot
.994 .40227 Mdot
.994 .40252 Mdot
.994 .40288 Mdot
.994 .40382 Mdot
.994 .40388 Mdot
.994 .40425 Mdot
.994 .405 Mdot
.994 .40552 Mdot
.994 .4057 Mdot
.994 .40588 Mdot
.994 .40691 Mdot
.994 .40766 Mdot
.994 .40846 Mdot
.994 .40886 Mdot
.994 .40937 Mdot
.994 .4132 Mdot
.994 .4144 Mdot
.994 .41735 Mdot
.994 .41955 Mdot
.994 .42043 Mdot
.994 .42052 Mdot
.994 .42069 Mdot
.994 .42079 Mdot
.994 .42085 Mdot
.994 .421 Mdot
.994 .42215 Mdot
.994 .42498 Mdot
.994 .42527 Mdot
.994 .42547 Mdot
.994 .42564 Mdot
.994 .42574 Mdot
.994 .42619 Mdot
.994 .4263 Mdot
.994 .42632 Mdot
.994 .42748 Mdot
.994 .4288 Mdot
.994 .42916 Mdot
.994 .4295 Mdot
.994 .42979 Mdot
.994 .43074 Mdot
.994 .43171 Mdot
.994 .43171 Mdot
.994 .43233 Mdot
.994 .43255 Mdot
.994 .43294 Mdot
.994 .43405 Mdot
.994 .43489 Mdot
.994 .43538 Mdot
.994 .43646 Mdot
.994 .4369 Mdot
.994 .43743 Mdot
.994 .43792 Mdot
.994 .438 Mdot
.994 .43804 Mdot
.994 .43931 Mdot
.994 .43977 Mdot
.994 .44068 Mdot
.994 .44098 Mdot
.994 .44294 Mdot
.994 .44335 Mdot
.994 .44336 Mdot
.994 .44344 Mdot
.994 .44369 Mdot
.994 .44388 Mdot
.994 .44431 Mdot
.994 .44592 Mdot
.994 .44609 Mdot
.994 .44677 Mdot
.994 .44678 Mdot
.994 .44696 Mdot
.994 .44703 Mdot
.994 .44724 Mdot
.994 .448 Mdot
.994 .44836 Mdot
.994 .4496 Mdot
.994 .44994 Mdot
.994 .45035 Mdot
.994 .45051 Mdot
.994 .45061 Mdot
.994 .45102 Mdot
.994 .45123 Mdot
.994 .45175 Mdot
.994 .45185 Mdot
.994 .45218 Mdot
.994 .45284 Mdot
.994 .45344 Mdot
.994 .45481 Mdot
.994 .45639 Mdot
.994 .45809 Mdot
.994 .45825 Mdot
.994 .45933 Mdot
.994 .46061 Mdot
.994 .46093 Mdot
.994 .46105 Mdot
.994 .46106 Mdot
.994 .4626 Mdot
.994 .46347 Mdot
.994 .46439 Mdot
.994 .46489 Mdot
.994 .46613 Mdot
.994 .4664 Mdot
.994 .46758 Mdot
.994 .46779 Mdot
.994 .46826 Mdot
.994 .46844 Mdot
.994 .46872 Mdot
.994 .46935 Mdot
.994 .46952 Mdot
.994 .46998 Mdot
.994 .47018 Mdot
.994 .47058 Mdot
.994 .47136 Mdot
.994 .47153 Mdot
.994 .47162 Mdot
.994 .4722 Mdot
.994 .47221 Mdot
.994 .47235 Mdot
.994 .47242 Mdot
.994 .4728 Mdot
.994 .47286 Mdot
.994 .47292 Mdot
.994 .4735 Mdot
.994 .47414 Mdot
.994 .47548 Mdot
.994 .4756 Mdot
.994 .47565 Mdot
.994 .47612 Mdot
.994 .47684 Mdot
.994 .47746 Mdot
.994 .47833 Mdot
.994 .47902 Mdot
.994 .47906 Mdot
.994 .47996 Mdot
.994 .48006 Mdot
.994 .4807 Mdot
.994 .48205 Mdot
.994 .48268 Mdot
.994 .48295 Mdot
.994 .48328 Mdot
.994 .48404 Mdot
.994 .48407 Mdot
.994 .48416 Mdot
.994 .48434 Mdot
.994 .48512 Mdot
.994 .48543 Mdot
.994 .48548 Mdot
.994 .48603 Mdot
.994 .48659 Mdot
.994 .4868 Mdot
.994 .48687 Mdot
.994 .48918 Mdot
.994 .4893 Mdot
.994 .49032 Mdot
.994 .49166 Mdot
.994 .49256 Mdot
.994 .49305 Mdot
.994 .49416 Mdot
.994 .49418 Mdot
.994 .49507 Mdot
.994 .49661 Mdot
.994 .49733 Mdot
.994 .49747 Mdot
.994 .49836 Mdot
.994 .49845 Mdot
.994 .4985 Mdot
.994 .49904 Mdot
.994 .4999 Mdot
.994 .5004 Mdot
.994 .50183 Mdot
.994 .5021 Mdot
.994 .50222 Mdot
.994 .50342 Mdot
.994 .50416 Mdot
.994 .50672 Mdot
.994 .50768 Mdot
.994 .50805 Mdot
.994 .50866 Mdot
.994 .51084 Mdot
.994 .51293 Mdot
.994 .51403 Mdot
.994 .51452 Mdot
.994 .51466 Mdot
.994 .51534 Mdot
.994 .51677 Mdot
.994 .51744 Mdot
.994 .51869 Mdot
.994 .51887 Mdot
.994 .51904 Mdot
.994 .51919 Mdot
.994 .52015 Mdot
.994 .52046 Mdot
.994 .52057 Mdot
.994 .52133 Mdot
.994 .52254 Mdot
.994 .52276 Mdot
.994 .52327 Mdot
.994 .52421 Mdot
.994 .52601 Mdot
.994 .52601 Mdot
.994 .52627 Mdot
.994 .52649 Mdot
.994 .52773 Mdot
.994 .52786 Mdot
.994 .52853 Mdot
.994 .52953 Mdot
.994 .52961 Mdot
.994 .53023 Mdot
.994 .53045 Mdot
.994 .53078 Mdot
.994 .53177 Mdot
.994 .53342 Mdot
.994 .53469 Mdot
.994 .53569 Mdot
.994 .53659 Mdot
.994 .53684 Mdot
.994 .53747 Mdot
.994 .5383 Mdot
.994 .53854 Mdot
.994 .53863 Mdot
.994 .53909 Mdot
.994 .5394 Mdot
.994 .54018 Mdot
.994 .54023 Mdot
.994 .54052 Mdot
.994 .54088 Mdot
.994 .54117 Mdot
.994 .54149 Mdot
.994 .54217 Mdot
.994 .54223 Mdot
.994 .54226 Mdot
.994 .54249 Mdot
.994 .54285 Mdot
.994 .54395 Mdot
.994 .54442 Mdot
.994 .54447 Mdot
.994 .54609 Mdot
.994 .54786 Mdot
.994 .5479 Mdot
.994 .54906 Mdot
.994 .54912 Mdot
.994 .55031 Mdot
.994 .55076 Mdot
.994 .55101 Mdot
.994 .55202 Mdot
.994 .55316 Mdot
.994 .55368 Mdot
.994 .55372 Mdot
.994 .55445 Mdot
.994 .5547 Mdot
.994 .55556 Mdot
.994 .55837 Mdot
.994 .55855 Mdot
.994 .55996 Mdot
.994 .56156 Mdot
.994 .56181 Mdot
.994 .56222 Mdot
.994 .56328 Mdot
.994 .56399 Mdot
.994 .56464 Mdot
.994 .5648 Mdot
.994 .56485 Mdot
.994 .56523 Mdot
.994 .56621 Mdot
.994 .56772 Mdot
.994 .56783 Mdot
.994 .56845 Mdot
.994 .56885 Mdot
.994 .56936 Mdot
.994 .56971 Mdot
.994 .57049 Mdot
.994 .57132 Mdot
.994 .57195 Mdot
.994 .57246 Mdot
.994 .57335 Mdot
.994 .57377 Mdot
.994 .57393 Mdot
.994 .57507 Mdot
.994 .57574 Mdot
.994 .57588 Mdot
.994 .57606 Mdot
.994 .57769 Mdot
.994 .57858 Mdot
.994 .57918 Mdot
.994 .58004 Mdot
.994 .58124 Mdot
.994 .58386 Mdot
.994 .58547 Mdot
.994 .58669 Mdot
.994 .58732 Mdot
.994 .58857 Mdot
.994 .58939 Mdot
.994 .5907 Mdot
.994 .59095 Mdot
.994 .59169 Mdot
.994 .5926 Mdot
.994 .59267 Mdot
.994 .59433 Mdot
.994 .59842 Mdot
.994 .59905 Mdot
.994 .60013 Mdot
.994 .60112 Mdot
.996 .01544 Mdot
.996 .01616 Mdot
.996 .01634 Mdot
.996 .01638 Mdot
.996 .01735 Mdot
.996 .01752 Mdot
.996 .01759 Mdot
.996 .01778 Mdot
.996 .01796 Mdot
.996 .01802 Mdot
.996 .01827 Mdot
.996 .01937 Mdot
.996 .01997 Mdot
.996 .02008 Mdot
.996 .02026 Mdot
.996 .0203 Mdot
.996 .02044 Mdot
.996 .0206 Mdot
.996 .02081 Mdot
.996 .02117 Mdot
.996 .0213 Mdot
.996 .02179 Mdot
.996 .02243 Mdot
.996 .0226 Mdot
.996 .0233 Mdot
.996 .0234 Mdot
.996 .02398 Mdot
.996 .02468 Mdot
.996 .02493 Mdot
.996 .02504 Mdot
.996 .02519 Mdot
.996 .02541 Mdot
.996 .02549 Mdot
.996 .02577 Mdot
.996 .02584 Mdot
.996 .02611 Mdot
.996 .02644 Mdot
.996 .02665 Mdot
.996 .02686 Mdot
.996 .02758 Mdot
.996 .02784 Mdot
.996 .02881 Mdot
.996 .02889 Mdot
.996 .02895 Mdot
.996 .03008 Mdot
.996 .03042 Mdot
.996 .03181 Mdot
.996 .03202 Mdot
.996 .03318 Mdot
.996 .03456 Mdot
.996 .03506 Mdot
.996 .03527 Mdot
.996 .03557 Mdot
.996 .03602 Mdot
.996 .03617 Mdot
.996 .03673 Mdot
.996 .03687 Mdot
.996 .03741 Mdot
.996 .03808 Mdot
.996 .03834 Mdot
.996 .03848 Mdot
.996 .03891 Mdot
.996 .04034 Mdot
.996 .04085 Mdot
.996 .04279 Mdot
.996 .04295 Mdot
.996 .04301 Mdot
.996 .04308 Mdot
.996 .04383 Mdot
.996 .04405 Mdot
.996 .04533 Mdot
.996 .046 Mdot
.996 .04637 Mdot
.996 .0464 Mdot
.996 .04699 Mdot
.996 .04811 Mdot
.996 .04876 Mdot
.996 .0492 Mdot
.996 .04924 Mdot
.996 .04973 Mdot
.996 .05091 Mdot
.996 .05102 Mdot
.996 .05149 Mdot
.996 .05424 Mdot
.996 .05487 Mdot
.996 .0551 Mdot
.996 .05525 Mdot
.996 .05567 Mdot
.996 .05626 Mdot
.996 .05715 Mdot
.996 .05746 Mdot
.996 .05792 Mdot
.996 .05835 Mdot
.996 .05858 Mdot
.996 .05875 Mdot
.996 .05885 Mdot
.996 .05944 Mdot
.996 .05993 Mdot
.996 .06037 Mdot
.996 .06125 Mdot
.996 .06164 Mdot
.996 .06178 Mdot
.996 .06206 Mdot
.996 .0629 Mdot
.996 .06336 Mdot
.996 .06363 Mdot
.996 .06395 Mdot
.996 .06412 Mdot
.996 .06548 Mdot
.996 .06576 Mdot
.996 .06679 Mdot
.996 .06696 Mdot
.996 .06784 Mdot
.996 .06792 Mdot
.996 .07053 Mdot
.996 .07064 Mdot
.996 .07069 Mdot
.996 .07095 Mdot
.996 .07108 Mdot
.996 .07115 Mdot
.996 .07122 Mdot
.996 .07123 Mdot
.996 .07229 Mdot
.996 .07269 Mdot
.996 .0727 Mdot
.996 .07316 Mdot
.996 .07372 Mdot
.996 .07415 Mdot
.996 .0757 Mdot
.996 .07617 Mdot
.996 .07624 Mdot
.996 .07704 Mdot
.996 .07736 Mdot
.996 .07777 Mdot
.996 .07782 Mdot
.996 .07884 Mdot
.996 .07901 Mdot
.996 .07993 Mdot
.996 .08016 Mdot
.996 .08123 Mdot
.996 .08125 Mdot
.996 .08139 Mdot
.996 .08209 Mdot
.996 .0822 Mdot
.996 .08254 Mdot
.996 .08272 Mdot
.996 .08283 Mdot
.996 .0834 Mdot
.996 .08348 Mdot
.996 .08446 Mdot
.996 .08542 Mdot
.996 .08638 Mdot
.996 .08682 Mdot
.996 .08703 Mdot
.996 .08797 Mdot
.996 .089 Mdot
.996 .08956 Mdot
.996 .08958 Mdot
.996 .08968 Mdot
.996 .09032 Mdot
.996 .09054 Mdot
.996 .09222 Mdot
.996 .09291 Mdot
.996 .09345 Mdot
.996 .09381 Mdot
.996 .09382 Mdot
.996 .09434 Mdot
.996 .0947 Mdot
.996 .09517 Mdot
.996 .09538 Mdot
.996 .09546 Mdot
.996 .09629 Mdot
.996 .09748 Mdot
.996 .09775 Mdot
.996 .09871 Mdot
.996 .09924 Mdot
.996 .09924 Mdot
.996 .09944 Mdot
.996 .09986 Mdot
.996 .10054 Mdot
.996 .10079 Mdot
.996 .10163 Mdot
.996 .10209 Mdot
.996 .10244 Mdot
.996 .10264 Mdot
.996 .103 Mdot
.996 .10374 Mdot
.996 .10381 Mdot
.996 .10411 Mdot
.996 .10479 Mdot
.996 .10565 Mdot
.996 .10605 Mdot
.996 .10616 Mdot
.996 .10741 Mdot
.996 .10818 Mdot
.996 .10846 Mdot
.996 .10902 Mdot
.996 .11038 Mdot
.996 .1107 Mdot
.996 .11146 Mdot
.996 .11161 Mdot
.996 .11215 Mdot
.996 .11219 Mdot
.996 .11275 Mdot
.996 .11279 Mdot
.996 .11313 Mdot
.996 .11553 Mdot
.996 .11584 Mdot
.996 .11625 Mdot
.996 .11637 Mdot
.996 .11639 Mdot
.996 .11648 Mdot
.996 .11751 Mdot
.996 .11791 Mdot
.996 .11839 Mdot
.996 .11844 Mdot
.996 .11879 Mdot
.996 .1191 Mdot
.996 .11924 Mdot
.996 .12054 Mdot
.996 .12069 Mdot
.996 .1207 Mdot
.996 .1229 Mdot
.996 .12352 Mdot
.996 .12508 Mdot
.996 .1259 Mdot
.996 .12613 Mdot
.996 .12621 Mdot
.996 .12674 Mdot
.996 .12699 Mdot
.996 .12714 Mdot
.996 .12727 Mdot
.996 .12729 Mdot
.996 .1274 Mdot
.996 .12754 Mdot
.996 .12941 Mdot
.996 .12943 Mdot
.996 .12996 Mdot
.996 .13019 Mdot
.996 .13023 Mdot
.996 .13092 Mdot
.996 .13113 Mdot
.996 .13144 Mdot
.996 .13224 Mdot
.996 .13229 Mdot
.996 .1331 Mdot
.996 .1362 Mdot
.996 .13663 Mdot
.996 .13686 Mdot
.996 .13713 Mdot
.996 .13728 Mdot
.996 .13769 Mdot
.996 .13886 Mdot
.996 .13951 Mdot
.996 .1402 Mdot
.996 .14033 Mdot
.996 .14043 Mdot
.996 .14246 Mdot
.996 .14278 Mdot
.996 .14372 Mdot
.996 .14452 Mdot
.996 .14462 Mdot
.996 .14474 Mdot
.996 .14509 Mdot
.996 .14576 Mdot
.996 .14722 Mdot
.996 .14725 Mdot
.996 .14738 Mdot
.996 .14754 Mdot
.996 .14758 Mdot
.996 .1477 Mdot
.996 .1478 Mdot
.996 .14852 Mdot
.996 .14893 Mdot
.996 .14914 Mdot
.996 .14982 Mdot
.996 .15017 Mdot
.996 .15041 Mdot
.996 .15058 Mdot
.996 .15141 Mdot
.996 .15154 Mdot
.996 .1517 Mdot
.996 .15285 Mdot
.996 .15366 Mdot
.996 .15556 Mdot
.996 .15748 Mdot
.996 .15834 Mdot
.996 .15843 Mdot
.996 .15876 Mdot
.996 .16065 Mdot
.996 .1612 Mdot
.996 .1627 Mdot
.996 .16333 Mdot
.996 .16357 Mdot
.996 .16381 Mdot
.996 .16386 Mdot
.996 .16392 Mdot
.996 .16404 Mdot
.996 .1645 Mdot
.996 .16463 Mdot
.996 .16531 Mdot
.996 .16534 Mdot
.996 .16575 Mdot
.996 .16674 Mdot
.996 .1691 Mdot
.996 .17028 Mdot
.996 .17049 Mdot
.996 .17113 Mdot
.996 .17128 Mdot
.996 .17156 Mdot
.996 .17185 Mdot
.996 .17197 Mdot
.996 .17227 Mdot
.996 .1723 Mdot
.996 .17333 Mdot
.996 .17404 Mdot
.996 .17497 Mdot
.996 .17541 Mdot
.996 .17548 Mdot
.996 .17556 Mdot
.996 .1756 Mdot
.996 .17656 Mdot
.996 .17721 Mdot
.996 .17931 Mdot
.996 .17958 Mdot
.996 .17995 Mdot
.996 .18013 Mdot
.996 .18187 Mdot
.996 .18204 Mdot
.996 .18226 Mdot
.996 .18268 Mdot
.996 .18308 Mdot
.996 .18309 Mdot
.996 .18348 Mdot
.996 .18432 Mdot
.996 .18445 Mdot
.996 .18568 Mdot
.996 .18617 Mdot
.996 .18726 Mdot
.996 .18785 Mdot
.996 .18856 Mdot
.996 .18874 Mdot
.996 .18877 Mdot
.996 .18906 Mdot
.996 .18945 Mdot
.996 .18949 Mdot
.996 .18986 Mdot
.996 .19041 Mdot
.996 .19057 Mdot
.996 .19158 Mdot
.996 .19206 Mdot
.996 .19219 Mdot
.996 .19244 Mdot
.996 .19278 Mdot
.996 .19393 Mdot
.996 .19414 Mdot
.996 .19566 Mdot
.996 .19586 Mdot
.996 .19592 Mdot
.996 .19617 Mdot
.996 .19666 Mdot
.996 .19687 Mdot
.996 .19739 Mdot
.996 .19937 Mdot
.996 .20007 Mdot
.996 .2006 Mdot
.996 .20066 Mdot
.996 .2009 Mdot
.996 .20093 Mdot
.996 .20146 Mdot
.996 .20257 Mdot
.996 .20275 Mdot
.996 .20366 Mdot
.996 .20527 Mdot
.996 .20592 Mdot
.996 .20663 Mdot
.996 .20709 Mdot
.996 .20719 Mdot
.996 .20743 Mdot
.996 .20772 Mdot
.996 .20794 Mdot
.996 .20831 Mdot
.996 .20875 Mdot
.996 .20881 Mdot
.996 .20888 Mdot
.996 .20919 Mdot
.996 .21 Mdot
.996 .21008 Mdot
.996 .21077 Mdot
.996 .21194 Mdot
.996 .21555 Mdot
.996 .21615 Mdot
.996 .21697 Mdot
.996 .21722 Mdot
.996 .21725 Mdot
.996 .21728 Mdot
.996 .21733 Mdot
.996 .21743 Mdot
.996 .21807 Mdot
.996 .21895 Mdot
.996 .21948 Mdot
.996 .22027 Mdot
.996 .22123 Mdot
.996 .22133 Mdot
.996 .22151 Mdot
.996 .22204 Mdot
.996 .22263 Mdot
.996 .22264 Mdot
.996 .22293 Mdot
.996 .22502 Mdot
.996 .22552 Mdot
.996 .22582 Mdot
.996 .22585 Mdot
.996 .22829 Mdot
.996 .2283 Mdot
.996 .22927 Mdot
.996 .22941 Mdot
.996 .22949 Mdot
.996 .22969 Mdot
.996 .23009 Mdot
.996 .23023 Mdot
.996 .23031 Mdot
.996 .23145 Mdot
.996 .23187 Mdot
.996 .23265 Mdot
.996 .23345 Mdot
.996 .23456 Mdot
.996 .23612 Mdot
.996 .23619 Mdot
.996 .23665 Mdot
.996 .23681 Mdot
.996 .23787 Mdot
.996 .23825 Mdot
.996 .23837 Mdot
.996 .23864 Mdot
.996 .23866 Mdot
.996 .23892 Mdot
.996 .23896 Mdot
.996 .23917 Mdot
.996 .23946 Mdot
.996 .24138 Mdot
.996 .24318 Mdot
.996 .24324 Mdot
.996 .24427 Mdot
.996 .24475 Mdot
.996 .24481 Mdot
.996 .24518 Mdot
.996 .24559 Mdot
.996 .2462 Mdot
.996 .24628 Mdot
.996 .24661 Mdot
.996 .24723 Mdot
.996 .24774 Mdot
.996 .24838 Mdot
.996 .24852 Mdot
.996 .24883 Mdot
.996 .24893 Mdot
.996 .25054 Mdot
.996 .25072 Mdot
.996 .25078 Mdot
.996 .25192 Mdot
.996 .25672 Mdot
.996 .25735 Mdot
.996 .25756 Mdot
.996 .25802 Mdot
.996 .25857 Mdot
.996 .25886 Mdot
.996 .25966 Mdot
.996 .25968 Mdot
.996 .26022 Mdot
.996 .26202 Mdot
.996 .26211 Mdot
.996 .26221 Mdot
.996 .2633 Mdot
.996 .26339 Mdot
.996 .2635 Mdot
.996 .26383 Mdot
.996 .26469 Mdot
.996 .26494 Mdot
.996 .26514 Mdot
.996 .26896 Mdot
.996 .26918 Mdot
.996 .26983 Mdot
.996 .2717 Mdot
.996 .27318 Mdot
.996 .27319 Mdot
.996 .27324 Mdot
.996 .27328 Mdot
.996 .27348 Mdot
.996 .27351 Mdot
.996 .27373 Mdot
.996 .27442 Mdot
.996 .27576 Mdot
.996 .27708 Mdot
.996 .27762 Mdot
.996 .27797 Mdot
.996 .27866 Mdot
.996 .27873 Mdot
.996 .27875 Mdot
.996 .27898 Mdot
.996 .2793 Mdot
.996 .27939 Mdot
.996 .27962 Mdot
.996 .27983 Mdot
.996 .28035 Mdot
.996 .28088 Mdot
.996 .28122 Mdot
.996 .28126 Mdot
.996 .28208 Mdot
.996 .28248 Mdot
.996 .28375 Mdot
.996 .28384 Mdot
.996 .28455 Mdot
.996 .28502 Mdot
.996 .28535 Mdot
.996 .28574 Mdot
.996 .28701 Mdot
.996 .28726 Mdot
.996 .28742 Mdot
.996 .2876 Mdot
.996 .28987 Mdot
.996 .29048 Mdot
.996 .29149 Mdot
.996 .29366 Mdot
.996 .29528 Mdot
.996 .29547 Mdot
.996 .29554 Mdot
.996 .29594 Mdot
.996 .29624 Mdot
.996 .29785 Mdot
.996 .29808 Mdot
.996 .29809 Mdot
.996 .2991 Mdot
.996 .29978 Mdot
.996 .30082 Mdot
.996 .30099 Mdot
.996 .30166 Mdot
.996 .30426 Mdot
.996 .30453 Mdot
.996 .30523 Mdot
.996 .30541 Mdot
.996 .30636 Mdot
.996 .30652 Mdot
.996 .30702 Mdot
.996 .30742 Mdot
.996 .3095 Mdot
.996 .31076 Mdot
.996 .31121 Mdot
.996 .31123 Mdot
.996 .31172 Mdot
.996 .3118 Mdot
.996 .31193 Mdot
.996 .31218 Mdot
.996 .31273 Mdot
.996 .31309 Mdot
.996 .31318 Mdot
.996 .31335 Mdot
.996 .31427 Mdot
.996 .31435 Mdot
.996 .3147 Mdot
.996 .31476 Mdot
.996 .3154 Mdot
.996 .31552 Mdot
.996 .31558 Mdot
.996 .3158 Mdot
.996 .31639 Mdot
.996 .31751 Mdot
.996 .31754 Mdot
.996 .32226 Mdot
.996 .3246 Mdot
.996 .32501 Mdot
.996 .32512 Mdot
.996 .32629 Mdot
.996 .3263 Mdot
.996 .3266 Mdot
.996 .32716 Mdot
.996 .32773 Mdot
.996 .32797 Mdot
.996 .32857 Mdot
.996 .32862 Mdot
.996 .33055 Mdot
.996 .33067 Mdot
.996 .33209 Mdot
.996 .3323 Mdot
.996 .3325 Mdot
.996 .33285 Mdot
.996 .33331 Mdot
.996 .33395 Mdot
.996 .33481 Mdot
.996 .33495 Mdot
.996 .33511 Mdot
.996 .3352 Mdot
.996 .33588 Mdot
.996 .33662 Mdot
.996 .33707 Mdot
.996 .33711 Mdot
.996 .33841 Mdot
.996 .33849 Mdot
.996 .33873 Mdot
.996 .33877 Mdot
.996 .3393 Mdot
.996 .3395 Mdot
.996 .34001 Mdot
.996 .34023 Mdot
.996 .34125 Mdot
.996 .34128 Mdot
.996 .34184 Mdot
.996 .34259 Mdot
.996 .34313 Mdot
.996 .34325 Mdot
.996 .3438 Mdot
.996 .34387 Mdot
.996 .34422 Mdot
.996 .34427 Mdot
.996 .34453 Mdot
.996 .34459 Mdot
.996 .34589 Mdot
.996 .34637 Mdot
.996 .34769 Mdot
.996 .34797 Mdot
.996 .34798 Mdot
.996 .34803 Mdot
.996 .34835 Mdot
.996 .34846 Mdot
.996 .3493 Mdot
.996 .34965 Mdot
.996 .3501 Mdot
.996 .35011 Mdot
.996 .35037 Mdot
.996 .35089 Mdot
.996 .35208 Mdot
.996 .35256 Mdot
.996 .35283 Mdot
.996 .35293 Mdot
.996 .35348 Mdot
.996 .35471 Mdot
.996 .35509 Mdot
.996 .35527 Mdot
.996 .35625 Mdot
.996 .3563 Mdot
.996 .35842 Mdot
.996 .35896 Mdot
.996 .35933 Mdot
.996 .35961 Mdot
.996 .36101 Mdot
.996 .36137 Mdot
.996 .36143 Mdot
.996 .36148 Mdot
.996 .362 Mdot
.996 .3622 Mdot
.996 .36244 Mdot
.996 .3628 Mdot
.996 .36287 Mdot
.996 .3636 Mdot
.996 .36471 Mdot
.996 .36502 Mdot
.996 .3658 Mdot
.996 .36696 Mdot
.996 .36703 Mdot
.996 .36799 Mdot
.996 .36825 Mdot
.996 .36873 Mdot
.996 .36899 Mdot
.996 .36942 Mdot
.996 .3716 Mdot
.996 .37171 Mdot
.996 .37213 Mdot
.996 .37339 Mdot
.996 .37516 Mdot
.996 .37556 Mdot
.996 .37567 Mdot
.996 .37618 Mdot
.996 .37699 Mdot
.996 .3771 Mdot
.996 .37716 Mdot
.996 .37721 Mdot
.996 .37757 Mdot
.996 .3786 Mdot
.996 .37902 Mdot
.996 .37974 Mdot
.996 .38254 Mdot
.996 .38393 Mdot
.996 .385 Mdot
.996 .38512 Mdot
.996 .3853 Mdot
.996 .38559 Mdot
.996 .38566 Mdot
.996 .38601 Mdot
.996 .38671 Mdot
.996 .38849 Mdot
.996 .38892 Mdot
.996 .38899 Mdot
.996 .38928 Mdot
.996 .38934 Mdot
.996 .3911 Mdot
.996 .39116 Mdot
.996 .39164 Mdot
.996 .39302 Mdot
.996 .39335 Mdot
.996 .39431 Mdot
.996 .3945 Mdot
.996 .39472 Mdot
.996 .3956 Mdot
.996 .39701 Mdot
.996 .39767 Mdot
.996 .39776 Mdot
.996 .39792 Mdot
.996 .39813 Mdot
.996 .3986 Mdot
.996 .39918 Mdot
.996 .39961 Mdot
.996 .40036 Mdot
.996 .40123 Mdot
.996 .40136 Mdot
.996 .40149 Mdot
.996 .4021 Mdot
.996 .40344 Mdot
.996 .40371 Mdot
.996 .40374 Mdot
.996 .40388 Mdot
.996 .40479 Mdot
.996 .40525 Mdot
.996 .40674 Mdot
.996 .40697 Mdot
.996 .40702 Mdot
.996 .4074 Mdot
.996 .40758 Mdot
.996 .4078 Mdot
.996 .40802 Mdot
.996 .4094 Mdot
.996 .41208 Mdot
.996 .41211 Mdot
.996 .41248 Mdot
.996 .41292 Mdot
.996 .41421 Mdot
.996 .41477 Mdot
.996 .41597 Mdot
.996 .41761 Mdot
.996 .41762 Mdot
.996 .4181 Mdot
.996 .41817 Mdot
.996 .41822 Mdot
.996 .41832 Mdot
.996 .41852 Mdot
.996 .41863 Mdot
.996 .41941 Mdot
.996 .4198 Mdot
.996 .4202 Mdot
.996 .42154 Mdot
.996 .42261 Mdot
.996 .42281 Mdot
.996 .42418 Mdot
.996 .42609 Mdot
.996 .4263 Mdot
.996 .42664 Mdot
.996 .42738 Mdot
.996 .4277 Mdot
.996 .42777 Mdot
.996 .42887 Mdot
.996 .4289 Mdot
.996 .42947 Mdot
.996 .4322 Mdot
.996 .43336 Mdot
.996 .43364 Mdot
.996 .43459 Mdot
.996 .43464 Mdot
.996 .43523 Mdot
.996 .43529 Mdot
.996 .43545 Mdot
.996 .43803 Mdot
.996 .44015 Mdot
.996 .44015 Mdot
.996 .44018 Mdot
.996 .44032 Mdot
.996 .44211 Mdot
.996 .44238 Mdot
.996 .44255 Mdot
.996 .44295 Mdot
.996 .44374 Mdot
.996 .44401 Mdot
.996 .44418 Mdot
.996 .44546 Mdot
.996 .44645 Mdot
.996 .4473 Mdot
.996 .44883 Mdot
.996 .45043 Mdot
.996 .45134 Mdot
.996 .45137 Mdot
.996 .45157 Mdot
.996 .45172 Mdot
.996 .45253 Mdot
.996 .45265 Mdot
.996 .45265 Mdot
.996 .4535 Mdot
.996 .45575 Mdot
.996 .45589 Mdot
.996 .45624 Mdot
.996 .4568 Mdot
.996 .45714 Mdot
.996 .45734 Mdot
.996 .45924 Mdot
.996 .46 Mdot
.996 .46023 Mdot
.996 .46077 Mdot
.996 .46082 Mdot
.996 .46134 Mdot
.996 .4614 Mdot
.996 .46154 Mdot
.996 .46184 Mdot
.996 .4624 Mdot
.996 .46622 Mdot
.996 .46681 Mdot
.996 .46895 Mdot
.996 .46983 Mdot
.996 .46993 Mdot
.996 .4701 Mdot
.996 .47033 Mdot
.996 .47162 Mdot
.996 .472 Mdot
.996 .47222 Mdot
.996 .47294 Mdot
.996 .47305 Mdot
.996 .47307 Mdot
.996 .47334 Mdot
.996 .47344 Mdot
.996 .47381 Mdot
.996 .47432 Mdot
.996 .47434 Mdot
.996 .47462 Mdot
.996 .47532 Mdot
.996 .4756 Mdot
.996 .47584 Mdot
.996 .47597 Mdot
.996 .476 Mdot
.996 .47665 Mdot
.996 .47689 Mdot
.996 .47769 Mdot
.996 .4777 Mdot
.996 .47788 Mdot
.996 .47854 Mdot
.996 .4789 Mdot
.996 .47976 Mdot
.996 .48018 Mdot
.996 .48046 Mdot
.996 .48108 Mdot
.996 .48127 Mdot
.996 .48188 Mdot
.996 .48321 Mdot
.996 .48339 Mdot
.996 .48448 Mdot
.996 .48484 Mdot
.996 .48496 Mdot
.996 .48664 Mdot
.996 .48723 Mdot
.996 .48825 Mdot
.996 .48955 Mdot
.996 .49045 Mdot
.996 .49226 Mdot
.996 .49232 Mdot
.996 .49237 Mdot
.996 .49328 Mdot
.996 .49364 Mdot
.996 .49643 Mdot
.996 .49679 Mdot
.996 .49803 Mdot
.996 .49829 Mdot
.996 .49846 Mdot
.996 .49938 Mdot
.996 .49962 Mdot
.996 .50031 Mdot
.996 .50047 Mdot
.996 .50105 Mdot
.996 .50116 Mdot
.996 .50264 Mdot
.996 .50269 Mdot
.996 .50376 Mdot
.996 .50554 Mdot
.996 .50569 Mdot
.996 .50622 Mdot
.996 .5072 Mdot
.996 .50731 Mdot
.996 .50734 Mdot
.996 .50752 Mdot
.996 .50773 Mdot
.996 .50784 Mdot
.996 .50853 Mdot
.996 .50988 Mdot
.996 .50989 Mdot
.996 .51008 Mdot
.996 .5103 Mdot
.996 .51094 Mdot
.996 .51266 Mdot
.996 .51316 Mdot
.996 .51356 Mdot
.996 .51395 Mdot
.996 .51526 Mdot
.996 .51755 Mdot
.996 .51775 Mdot
.996 .51998 Mdot
.996 .52056 Mdot
.996 .52118 Mdot
.996 .52161 Mdot
.996 .5229 Mdot
.996 .52397 Mdot
.996 .52405 Mdot
.996 .52663 Mdot
.996 .52958 Mdot
.996 .5296 Mdot
.996 .5297 Mdot
.996 .52978 Mdot
.996 .53018 Mdot
.996 .53024 Mdot
.996 .53067 Mdot
.996 .53204 Mdot
.996 .5326 Mdot
.996 .53471 Mdot
.996 .53735 Mdot
.996 .53843 Mdot
.996 .539 Mdot
.996 .53912 Mdot
.996 .53977 Mdot
.996 .54007 Mdot
.996 .54049 Mdot
.996 .54063 Mdot
.996 .54068 Mdot
.996 .54112 Mdot
.996 .54113 Mdot
.996 .54163 Mdot
.996 .54176 Mdot
.996 .54195 Mdot
.996 .54241 Mdot
.996 .54281 Mdot
.996 .54282 Mdot
.996 .54324 Mdot
.996 .54385 Mdot
.996 .54491 Mdot
.996 .54558 Mdot
.996 .54568 Mdot
.996 .54731 Mdot
.996 .54811 Mdot
.996 .54877 Mdot
.996 .54922 Mdot
.996 .55013 Mdot
.996 .55016 Mdot
.996 .55018 Mdot
.996 .55064 Mdot
.996 .55082 Mdot
.996 .55222 Mdot
.996 .55315 Mdot
.996 .55382 Mdot
.996 .55417 Mdot
.996 .5546 Mdot
.996 .55679 Mdot
.996 .55687 Mdot
.996 .55713 Mdot
.996 .55763 Mdot
.996 .55768 Mdot
.996 .55795 Mdot
.996 .5583 Mdot
.996 .55897 Mdot
.996 .56102 Mdot
.996 .56167 Mdot
.996 .56283 Mdot
.996 .56293 Mdot
.996 .56404 Mdot
.996 .56433 Mdot
.996 .56604 Mdot
.996 .56609 Mdot
.996 .57038 Mdot
.996 .57359 Mdot
.996 .57398 Mdot
.996 .57413 Mdot
.996 .57466 Mdot
.996 .57491 Mdot
.996 .57551 Mdot
.996 .57572 Mdot
.996 .5785 Mdot
.996 .57872 Mdot
.996 .57918 Mdot
.996 .57919 Mdot
.996 .57921 Mdot
.996 .58121 Mdot
.996 .58252 Mdot
.996 .58256 Mdot
.996 .58297 Mdot
.996 .58362 Mdot
.996 .58464 Mdot
.996 .58497 Mdot
.996 .5856 Mdot
.996 .58631 Mdot
.996 .58719 Mdot
.996 .59149 Mdot
.996 .59202 Mdot
.996 .59342 Mdot
.996 .59377 Mdot
.996 .59544 Mdot
.996 .59566 Mdot
.996 .59599 Mdot
.996 .59699 Mdot
.996 .59778 Mdot
.996 .60193 Mdot
.998 .0156 Mdot
.998 .01649 Mdot
.998 .01677 Mdot
.998 .01768 Mdot
.998 .01826 Mdot
.998 .01881 Mdot
.998 .01947 Mdot
.998 .02063 Mdot
.998 .02084 Mdot
.998 .02178 Mdot
.998 .0229 Mdot
.998 .0242 Mdot
.998 .0243 Mdot
.998 .02434 Mdot
.998 .02459 Mdot
.998 .02652 Mdot
.998 .02683 Mdot
.998 .02694 Mdot
.998 .02763 Mdot
.998 .02802 Mdot
.998 .02883 Mdot
.998 .02903 Mdot
.998 .02935 Mdot
.998 .0308 Mdot
.998 .03105 Mdot
.998 .03106 Mdot
.998 .03253 Mdot
.998 .03294 Mdot
.998 .03365 Mdot
.998 .03385 Mdot
.998 .03386 Mdot
.998 .03392 Mdot
.998 .03442 Mdot
.998 .03691 Mdot
.998 .03827 Mdot
.998 .03843 Mdot
.998 .03889 Mdot
.998 .03911 Mdot
.998 .03941 Mdot
.998 .0405 Mdot
.998 .04127 Mdot
.998 .04288 Mdot
.998 .04329 Mdot
.998 .0433 Mdot
.998 .04393 Mdot
.998 .04423 Mdot
.998 .04444 Mdot
.998 .04491 Mdot
.998 .04621 Mdot
.998 .04681 Mdot
.998 .04731 Mdot
.998 .04734 Mdot
.998 .04822 Mdot
.998 .04879 Mdot
.998 .04893 Mdot
.998 .04952 Mdot
.998 .05006 Mdot
.998 .05028 Mdot
.998 .05077 Mdot
.998 .05108 Mdot
.998 .0525 Mdot
.998 .05291 Mdot
.998 .05293 Mdot
.998 .05305 Mdot
.998 .05376 Mdot
.998 .05404 Mdot
.998 .05405 Mdot
.998 .05566 Mdot
.998 .05634 Mdot
.998 .05736 Mdot
.998 .05829 Mdot
.998 .05901 Mdot
.998 .05938 Mdot
.998 .06173 Mdot
.998 .06205 Mdot
.998 .06219 Mdot
.998 .06234 Mdot
.998 .06296 Mdot
.998 .06342 Mdot
.998 .06402 Mdot
.998 .06509 Mdot
.998 .06568 Mdot
.998 .06608 Mdot
.998 .06619 Mdot
.998 .06628 Mdot
.998 .06754 Mdot
.998 .06772 Mdot
.998 .06774 Mdot
.998 .06839 Mdot
.998 .07093 Mdot
.998 .07176 Mdot
.998 .07177 Mdot
.998 .07263 Mdot
.998 .07303 Mdot
.998 .07303 Mdot
.998 .07363 Mdot
.998 .07405 Mdot
.998 .07449 Mdot
.998 .07473 Mdot
.998 .07498 Mdot
.998 .07512 Mdot
.998 .07757 Mdot
.998 .07878 Mdot
.998 .07907 Mdot
.998 .07978 Mdot
.998 .07983 Mdot
.998 .08112 Mdot
.998 .08126 Mdot
.998 .08159 Mdot
.998 .08273 Mdot
.998 .083 Mdot
.998 .08382 Mdot
.998 .08412 Mdot
.998 .08419 Mdot
.998 .08465 Mdot
.998 .08509 Mdot
.998 .08526 Mdot
.998 .08529 Mdot
.998 .0857 Mdot
.998 .08646 Mdot
.998 .08665 Mdot
.998 .08668 Mdot
.998 .08701 Mdot
.998 .0873 Mdot
.998 .08747 Mdot
.998 .08752 Mdot
.998 .0876 Mdot
.998 .08795 Mdot
.998 .0883 Mdot
.998 .09014 Mdot
.998 .09073 Mdot
.998 .09095 Mdot
.998 .09099 Mdot
.998 .09122 Mdot
.998 .09134 Mdot
.998 .09253 Mdot
.998 .09264 Mdot
.998 .09322 Mdot
.998 .09323 Mdot
.998 .09408 Mdot
.998 .09417 Mdot
.998 .09441 Mdot
.998 .09455 Mdot
.998 .09568 Mdot
.998 .09645 Mdot
.998 .09781 Mdot
.998 .09857 Mdot
.998 .09948 Mdot
.998 .09984 Mdot
.998 .10137 Mdot
.998 .10143 Mdot
.998 .10143 Mdot
.998 .10169 Mdot
.998 .10314 Mdot
.998 .10342 Mdot
.998 .10386 Mdot
.998 .10645 Mdot
.998 .10855 Mdot
.998 .10919 Mdot
.998 .10923 Mdot
.998 .10947 Mdot
.998 .10966 Mdot
.998 .10977 Mdot
.998 .10984 Mdot
.998 .11002 Mdot
.998 .11081 Mdot
.998 .11102 Mdot
.998 .11192 Mdot
.998 .11292 Mdot
.998 .11312 Mdot
.998 .11321 Mdot
.998 .1136 Mdot
.998 .1141 Mdot
.998 .11413 Mdot
.998 .11472 Mdot
.998 .11525 Mdot
.998 .11587 Mdot
.998 .11617 Mdot
.998 .11644 Mdot
.998 .11724 Mdot
.998 .11745 Mdot
.998 .11764 Mdot
.998 .11765 Mdot
.998 .11773 Mdot
.998 .11989 Mdot
.998 .12016 Mdot
.998 .12051 Mdot
.998 .12055 Mdot
.998 .12171 Mdot
.998 .12186 Mdot
.998 .12214 Mdot
.998 .12387 Mdot
.998 .12396 Mdot
.998 .12437 Mdot
.998 .12617 Mdot
.998 .12641 Mdot
.998 .12693 Mdot
.998 .12767 Mdot
.998 .12857 Mdot
.998 .12859 Mdot
.998 .12929 Mdot
.998 .1299 Mdot
.998 .13031 Mdot
.998 .13071 Mdot
.998 .13073 Mdot
.998 .13111 Mdot
.998 .13112 Mdot
.998 .1323 Mdot
.998 .13249 Mdot
.998 .13315 Mdot
.998 .13342 Mdot
.998 .13402 Mdot
.998 .1345 Mdot
.998 .13482 Mdot
.998 .135 Mdot
.998 .13529 Mdot
.998 .13791 Mdot
.998 .13895 Mdot
.998 .14014 Mdot
.998 .14017 Mdot
.998 .14147 Mdot
.998 .14258 Mdot
.998 .14317 Mdot
.998 .14459 Mdot
.998 .14469 Mdot
.998 .14677 Mdot
.998 .14707 Mdot
.998 .14714 Mdot
.998 .14726 Mdot
.998 .14754 Mdot
.998 .14778 Mdot
.998 .14819 Mdot
.998 .15037 Mdot
.998 .15047 Mdot
.998 .15102 Mdot
.998 .15265 Mdot
.998 .15285 Mdot
.998 .15286 Mdot
.998 .15326 Mdot
.998 .15338 Mdot
.998 .15403 Mdot
.998 .15423 Mdot
.998 .15431 Mdot
.998 .15517 Mdot
.998 .15553 Mdot
.998 .15558 Mdot
.998 .15577 Mdot
.998 .1564 Mdot
.998 .15793 Mdot
.998 .15829 Mdot
.998 .15835 Mdot
.998 .15902 Mdot
.998 .1596 Mdot
.998 .15993 Mdot
.998 .16004 Mdot
.998 .16019 Mdot
.998 .16032 Mdot
.998 .16089 Mdot
.998 .16105 Mdot
.998 .16159 Mdot
.998 .16176 Mdot
.998 .1636 Mdot
.998 .16527 Mdot
.998 .16619 Mdot
.998 .16645 Mdot
.998 .16689 Mdot
.998 .16695 Mdot
.998 .16743 Mdot
.998 .16766 Mdot
.998 .17003 Mdot
.998 .17026 Mdot
.998 .17043 Mdot
.998 .17076 Mdot
.998 .1714 Mdot
.998 .17144 Mdot
.998 .17313 Mdot
.998 .1733 Mdot
.998 .17379 Mdot
.998 .17406 Mdot
.998 .17564 Mdot
.998 .1758 Mdot
.998 .17616 Mdot
.998 .17633 Mdot
.998 .17749 Mdot
.998 .17785 Mdot
.998 .17801 Mdot
.998 .17952 Mdot
.998 .1802 Mdot
.998 .18041 Mdot
.998 .18052 Mdot
.998 .18057 Mdot
.998 .181 Mdot
.998 .18111 Mdot
.998 .18113 Mdot
.998 .18208 Mdot
.998 .18238 Mdot
.998 .18317 Mdot
.998 .1839 Mdot
.998 .18413 Mdot
.998 .1846 Mdot
.998 .18462 Mdot
.998 .18462 Mdot
.998 .18673 Mdot
.998 .18677 Mdot
.998 .18767 Mdot
.998 .1878 Mdot
.998 .18781 Mdot
.998 .18832 Mdot
.998 .18871 Mdot
.998 .19037 Mdot
.998 .19083 Mdot
.998 .1912 Mdot
.998 .19176 Mdot
.998 .19241 Mdot
.998 .19265 Mdot
.998 .193 Mdot
.998 .19377 Mdot
.998 .19467 Mdot
.998 .196 Mdot
.998 .19609 Mdot
.998 .19752 Mdot
.998 .19782 Mdot
.998 .20194 Mdot
.998 .20202 Mdot
.998 .20328 Mdot
.998 .20338 Mdot
.998 .20384 Mdot
.998 .20422 Mdot
.998 .20444 Mdot
.998 .20447 Mdot
.998 .20459 Mdot
.998 .20494 Mdot
.998 .20549 Mdot
.998 .20603 Mdot
.998 .20652 Mdot
.998 .20694 Mdot
.998 .20706 Mdot
.998 .2078 Mdot
.998 .20874 Mdot
.998 .21074 Mdot
.998 .21087 Mdot
.998 .21113 Mdot
.998 .21132 Mdot
.998 .21209 Mdot
.998 .21271 Mdot
.998 .21309 Mdot
.998 .21315 Mdot
.998 .21334 Mdot
.998 .21357 Mdot
.998 .21432 Mdot
.998 .21488 Mdot
.998 .21512 Mdot
.998 .21539 Mdot
.998 .21585 Mdot
.998 .21662 Mdot
.998 .21678 Mdot
.998 .21723 Mdot
.998 .21776 Mdot
.998 .2185 Mdot
.998 .21936 Mdot
.998 .21976 Mdot
.998 .21978 Mdot
.998 .22016 Mdot
.998 .22017 Mdot
.998 .22032 Mdot
.998 .22118 Mdot
.998 .22198 Mdot
.998 .22295 Mdot
.998 .22403 Mdot
.998 .22465 Mdot
.998 .22518 Mdot
.998 .22585 Mdot
.998 .22589 Mdot
.998 .22597 Mdot
.998 .22683 Mdot
.998 .22828 Mdot
.998 .22857 Mdot
.998 .22891 Mdot
.998 .22913 Mdot
.998 .22958 Mdot
.998 .23135 Mdot
.998 .23258 Mdot
.998 .23277 Mdot
.998 .23349 Mdot
.998 .23358 Mdot
.998 .23642 Mdot
.998 .23718 Mdot
.998 .23733 Mdot
.998 .23767 Mdot
.998 .23784 Mdot
.998 .23827 Mdot
.998 .23869 Mdot
.998 .23986 Mdot
.998 .24005 Mdot
.998 .24017 Mdot
.998 .24145 Mdot
.998 .24151 Mdot
.998 .24198 Mdot
.998 .24201 Mdot
.998 .24243 Mdot
.998 .24304 Mdot
.998 .24306 Mdot
.998 .2434 Mdot
.998 .24353 Mdot
.998 .24371 Mdot
.998 .24462 Mdot
.998 .24544 Mdot
.998 .24609 Mdot
.998 .24623 Mdot
.998 .24628 Mdot
.998 .24705 Mdot
.998 .24706 Mdot
.998 .24711 Mdot
.998 .24942 Mdot
.998 .24979 Mdot
.998 .2503 Mdot
.998 .25112 Mdot
.998 .25165 Mdot
.998 .25284 Mdot
.998 .2538 Mdot
.998 .25413 Mdot
.998 .25444 Mdot
.998 .25481 Mdot
.998 .25538 Mdot
.998 .258 Mdot
.998 .25825 Mdot
.998 .25837 Mdot
.998 .25843 Mdot
.998 .26061 Mdot
.998 .26093 Mdot
.998 .2627 Mdot
.998 .26303 Mdot
.998 .26506 Mdot
.998 .26513 Mdot
.998 .26518 Mdot
.998 .2657 Mdot
.998 .26587 Mdot
.998 .26617 Mdot
.998 .26771 Mdot
.998 .2696 Mdot
.998 .26994 Mdot
.998 .27111 Mdot
.998 .27152 Mdot
.998 .27195 Mdot
.998 .27342 Mdot
.998 .27394 Mdot
.998 .27415 Mdot
.998 .27537 Mdot
.998 .27612 Mdot
.998 .27652 Mdot
.998 .2779 Mdot
.998 .27831 Mdot
.998 .27878 Mdot
.998 .27889 Mdot
.998 .27904 Mdot
.998 .27927 Mdot
.998 .27984 Mdot
.998 .28031 Mdot
.998 .28055 Mdot
.998 .28113 Mdot
.998 .28113 Mdot
.998 .28439 Mdot
.998 .28468 Mdot
.998 .28509 Mdot
.998 .28545 Mdot
.998 .28548 Mdot
.998 .28568 Mdot
.998 .28678 Mdot
.998 .28762 Mdot
.998 .28845 Mdot
.998 .28867 Mdot
.998 .29003 Mdot
.998 .29043 Mdot
.998 .29046 Mdot
.998 .29124 Mdot
.998 .2915 Mdot
.998 .29208 Mdot
.998 .29251 Mdot
.998 .29278 Mdot
.998 .29319 Mdot
.998 .29326 Mdot
.998 .29334 Mdot
.998 .29507 Mdot
.998 .29578 Mdot
.998 .29588 Mdot
.998 .29613 Mdot
.998 .29626 Mdot
.998 .2965 Mdot
.998 .29752 Mdot
.998 .29766 Mdot
.998 .30057 Mdot
.998 .30129 Mdot
.998 .30141 Mdot
.998 .30274 Mdot
.998 .30377 Mdot
.998 .30391 Mdot
.998 .30453 Mdot
.998 .30457 Mdot
.998 .30479 Mdot
.998 .30506 Mdot
.998 .30508 Mdot
.998 .30534 Mdot
.998 .30648 Mdot
.998 .3068 Mdot
.998 .30781 Mdot
.998 .30787 Mdot
.998 .30794 Mdot
.998 .30821 Mdot
.998 .30882 Mdot
.998 .30961 Mdot
.998 .31084 Mdot
.998 .31143 Mdot
.998 .31188 Mdot
.998 .31278 Mdot
.998 .31346 Mdot
.998 .3152 Mdot
.998 .31522 Mdot
.998 .31534 Mdot
.998 .31646 Mdot
.998 .31687 Mdot
.998 .31706 Mdot
.998 .31757 Mdot
.998 .31773 Mdot
.998 .31845 Mdot
.998 .31859 Mdot
.998 .31932 Mdot
.998 .31952 Mdot
.998 .31999 Mdot
.998 .32152 Mdot
.998 .32228 Mdot
.998 .32277 Mdot
.998 .32472 Mdot
.998 .32518 Mdot
.998 .32529 Mdot
.998 .32552 Mdot
.998 .32617 Mdot
.998 .32718 Mdot
.998 .32747 Mdot
.998 .32754 Mdot
.998 .32783 Mdot
.998 .3281 Mdot
.998 .32846 Mdot
.998 .32996 Mdot
.998 .3301 Mdot
.998 .33091 Mdot
.998 .33125 Mdot
.998 .33176 Mdot
.998 .33223 Mdot
.998 .33277 Mdot
.998 .33418 Mdot
.998 .33425 Mdot
.998 .33563 Mdot
.998 .33593 Mdot
.998 .33613 Mdot
.998 .33623 Mdot
.998 .33686 Mdot
.998 .33696 Mdot
.998 .33729 Mdot
.998 .33941 Mdot
.998 .33961 Mdot
.998 .34034 Mdot
.998 .34046 Mdot
.998 .34066 Mdot
.998 .34264 Mdot
.998 .34367 Mdot
.998 .34374 Mdot
.998 .34502 Mdot
.998 .34517 Mdot
.998 .34543 Mdot
.998 .34565 Mdot
.998 .34575 Mdot
.998 .34634 Mdot
.998 .34643 Mdot
.998 .34662 Mdot
.998 .34685 Mdot
.998 .34687 Mdot
.998 .34691 Mdot
.998 .34709 Mdot
.998 .34726 Mdot
.998 .34848 Mdot
.998 .34879 Mdot
.998 .34938 Mdot
.998 .35016 Mdot
.998 .3502 Mdot
.998 .35032 Mdot
.998 .35039 Mdot
.998 .35096 Mdot
.998 .35241 Mdot
.998 .35286 Mdot
.998 .35381 Mdot
.998 .35384 Mdot
.998 .35384 Mdot
.998 .35484 Mdot
.998 .35636 Mdot
.998 .35775 Mdot
.998 .35796 Mdot
.998 .35806 Mdot
.998 .35814 Mdot
.998 .35854 Mdot
.998 .3596 Mdot
.998 .35974 Mdot
.998 .35994 Mdot
.998 .36019 Mdot
.998 .3602 Mdot
.998 .3605 Mdot
.998 .36107 Mdot
.998 .36123 Mdot
.998 .36197 Mdot
.998 .362 Mdot
.998 .36309 Mdot
.998 .364 Mdot
.998 .36422 Mdot
.998 .36508 Mdot
.998 .36513 Mdot
.998 .36533 Mdot
.998 .36624 Mdot
.998 .36636 Mdot
.998 .36699 Mdot
.998 .3678 Mdot
.998 .3681 Mdot
.998 .36851 Mdot
.998 .36852 Mdot
.998 .3694 Mdot
.998 .36987 Mdot
.998 .37057 Mdot
.998 .37212 Mdot
.998 .37264 Mdot
.998 .37323 Mdot
.998 .3739 Mdot
.998 .37656 Mdot
.998 .3767 Mdot
.998 .37674 Mdot
.998 .37706 Mdot
.998 .37836 Mdot
.998 .3796 Mdot
.998 .37961 Mdot
.998 .38019 Mdot
.998 .38106 Mdot
.998 .38334 Mdot
.998 .38371 Mdot
.998 .38406 Mdot
.998 .38499 Mdot
.998 .38629 Mdot
.998 .38841 Mdot
.998 .38857 Mdot
.998 .39102 Mdot
.998 .3911 Mdot
.998 .39128 Mdot
.998 .39195 Mdot
.998 .39221 Mdot
.998 .39296 Mdot
.998 .3933 Mdot
.998 .39341 Mdot
.998 .39346 Mdot
.998 .3937 Mdot
.998 .39376 Mdot
.998 .39377 Mdot
.998 .3944 Mdot
.998 .39479 Mdot
.998 .39527 Mdot
.998 .39551 Mdot
.998 .39552 Mdot
.998 .39658 Mdot
.998 .3966 Mdot
.998 .39757 Mdot
.998 .3984 Mdot
.998 .39863 Mdot
.998 .39942 Mdot
.998 .39972 Mdot
.998 .40011 Mdot
.998 .40055 Mdot
.998 .40122 Mdot
.998 .40127 Mdot
.998 .40198 Mdot
.998 .40419 Mdot
.998 .40546 Mdot
.998 .40598 Mdot
.998 .40624 Mdot
.998 .40676 Mdot
.998 .40713 Mdot
.998 .40867 Mdot
.998 .40959 Mdot
.998 .40991 Mdot
.998 .41002 Mdot
.998 .41068 Mdot
.998 .4108 Mdot
.998 .41116 Mdot
.998 .41163 Mdot
.998 .41249 Mdot
.998 .41313 Mdot
.998 .41384 Mdot
.998 .41424 Mdot
.998 .41472 Mdot
.998 .41526 Mdot
.998 .41618 Mdot
.998 .41667 Mdot
.998 .41771 Mdot
.998 .41804 Mdot
.998 .41893 Mdot
.998 .42 Mdot
.998 .42147 Mdot
.998 .42193 Mdot
.998 .42218 Mdot
.998 .4224 Mdot
.998 .42319 Mdot
.998 .42329 Mdot
.998 .42399 Mdot
.998 .42402 Mdot
.998 .42448 Mdot
.998 .42479 Mdot
.998 .4248 Mdot
.998 .42503 Mdot
.998 .42511 Mdot
.998 .42512 Mdot
.998 .42632 Mdot
.998 .42683 Mdot
.998 .42842 Mdot
.998 .43034 Mdot
.998 .43228 Mdot
.998 .43241 Mdot
.998 .43247 Mdot
.998 .4325 Mdot
.998 .43375 Mdot
.998 .4348 Mdot
.998 .43588 Mdot
.998 .43614 Mdot
.998 .43622 Mdot
.998 .43637 Mdot
.998 .43809 Mdot
.998 .43906 Mdot
.998 .43927 Mdot
.998 .44001 Mdot
.998 .44099 Mdot
.998 .44136 Mdot
.998 .44156 Mdot
.998 .44225 Mdot
.998 .44269 Mdot
.998 .44358 Mdot
.998 .44387 Mdot
.998 .4455 Mdot
.998 .44565 Mdot
.998 .44586 Mdot
.998 .44603 Mdot
.998 .44712 Mdot
.998 .44754 Mdot
.998 .44765 Mdot
.998 .44936 Mdot
.998 .44957 Mdot
.998 .44995 Mdot
.998 .45139 Mdot
.998 .45157 Mdot
.998 .45215 Mdot
.998 .45521 Mdot
.998 .45559 Mdot
.998 .45586 Mdot
.998 .45724 Mdot
.998 .4573 Mdot
.998 .45774 Mdot
.998 .45814 Mdot
.998 .45876 Mdot
.998 .45905 Mdot
.998 .45973 Mdot
.998 .46007 Mdot
.998 .46094 Mdot
.998 .46101 Mdot
.998 .46157 Mdot
.998 .46178 Mdot
.998 .46221 Mdot
.998 .46301 Mdot
.998 .4641 Mdot
.998 .46448 Mdot
.998 .46473 Mdot
.998 .46599 Mdot
.998 .46694 Mdot
.998 .46727 Mdot
.998 .4674 Mdot
.998 .46758 Mdot
.998 .46833 Mdot
.998 .4684 Mdot
.998 .46924 Mdot
.998 .47045 Mdot
.998 .47049 Mdot
.998 .47118 Mdot
.998 .47143 Mdot
.998 .47179 Mdot
.998 .47307 Mdot
.998 .4736 Mdot
.998 .47469 Mdot
.998 .47524 Mdot
.998 .47595 Mdot
.998 .47654 Mdot
.998 .47659 Mdot
.998 .47683 Mdot
.998 .47692 Mdot
.998 .477 Mdot
.998 .47761 Mdot
.998 .47845 Mdot
.998 .47848 Mdot
.998 .47854 Mdot
.998 .47857 Mdot
.998 .4808 Mdot
.998 .48156 Mdot
.998 .48226 Mdot
.998 .48236 Mdot
.998 .48265 Mdot
.998 .48318 Mdot
.998 .48326 Mdot
.998 .48363 Mdot
.998 .48392 Mdot
.998 .48437 Mdot
.998 .48493 Mdot
.998 .48539 Mdot
.998 .4855 Mdot
.998 .48593 Mdot
.998 .48595 Mdot
.998 .48657 Mdot
.998 .48729 Mdot
.998 .48765 Mdot
.998 .48765 Mdot
.998 .48972 Mdot
.998 .49001 Mdot
.998 .49175 Mdot
.998 .49193 Mdot
.998 .49258 Mdot
.998 .49321 Mdot
.998 .49394 Mdot
.998 .49508 Mdot
.998 .49526 Mdot
.998 .49544 Mdot
.998 .4959 Mdot
.998 .49655 Mdot
.998 .49893 Mdot
.998 .49939 Mdot
.998 .50007 Mdot
.998 .5003 Mdot
.998 .5003 Mdot
.998 .50082 Mdot
.998 .50106 Mdot
.998 .50118 Mdot
.998 .50172 Mdot
.998 .50314 Mdot
.998 .50328 Mdot
.998 .5037 Mdot
.998 .50404 Mdot
.998 .50406 Mdot
.998 .50553 Mdot
.998 .50616 Mdot
.998 .50823 Mdot
.998 .50845 Mdot
.998 .50968 Mdot
.998 .51036 Mdot
.998 .51177 Mdot
.998 .51441 Mdot
.998 .51454 Mdot
.998 .51465 Mdot
.998 .51509 Mdot
.998 .51569 Mdot
.998 .51597 Mdot
.998 .51601 Mdot
.998 .51661 Mdot
.998 .5196 Mdot
.998 .51966 Mdot
.998 .51969 Mdot
.998 .5214 Mdot
.998 .52299 Mdot
.998 .5231 Mdot
.998 .52347 Mdot
.998 .52415 Mdot
.998 .5254 Mdot
.998 .52622 Mdot
.998 .52629 Mdot
.998 .5264 Mdot
.998 .52649 Mdot
.998 .52724 Mdot
.998 .5273 Mdot
.998 .52815 Mdot
.998 .52955 Mdot
.998 .53109 Mdot
.998 .53128 Mdot
.998 .53141 Mdot
.998 .53213 Mdot
.998 .53235 Mdot
.998 .53255 Mdot
.998 .53399 Mdot
.998 .53427 Mdot
.998 .53459 Mdot
.998 .53499 Mdot
.998 .53649 Mdot
.998 .53696 Mdot
.998 .53728 Mdot
.998 .54003 Mdot
.998 .54084 Mdot
.998 .54148 Mdot
.998 .5418 Mdot
.998 .542 Mdot
.998 .54231 Mdot
.998 .54277 Mdot
.998 .5439 Mdot
.998 .54429 Mdot
.998 .54464 Mdot
.998 .54469 Mdot
.998 .54483 Mdot
.998 .54514 Mdot
.998 .54533 Mdot
.998 .54569 Mdot
.998 .5462 Mdot
.998 .54626 Mdot
.998 .54648 Mdot
.998 .54649 Mdot
.998 .54716 Mdot
.998 .54734 Mdot
.998 .54837 Mdot
.998 .54939 Mdot
.998 .55115 Mdot
.998 .55124 Mdot
.998 .55147 Mdot
.998 .5518 Mdot
.998 .55299 Mdot
.998 .55322 Mdot
.998 .55356 Mdot
.998 .55367 Mdot
.998 .55439 Mdot
.998 .5551 Mdot
.998 .55517 Mdot
.998 .55538 Mdot
.998 .55555 Mdot
.998 .55556 Mdot
.998 .55765 Mdot
.998 .55776 Mdot
.998 .55942 Mdot
.998 .56109 Mdot
.998 .56152 Mdot
.998 .56334 Mdot
.998 .56338 Mdot
.998 .56425 Mdot
.998 .56504 Mdot
.998 .5651 Mdot
.998 .56625 Mdot
.998 .56666 Mdot
.998 .5667 Mdot
.998 .56675 Mdot
.998 .56717 Mdot
.998 .56833 Mdot
.998 .56919 Mdot
.998 .56926 Mdot
.998 .56973 Mdot
.998 .57055 Mdot
.998 .5707 Mdot
.998 .57085 Mdot
.998 .57204 Mdot
.998 .57431 Mdot
.998 .57571 Mdot
.998 .57589 Mdot
.998 .57591 Mdot
.998 .57614 Mdot
.998 .57642 Mdot
.998 .57667 Mdot
.998 .5767 Mdot
.998 .57715 Mdot
.998 .57724 Mdot
.998 .57776 Mdot
.998 .57827 Mdot
.998 .57915 Mdot
.998 .5792 Mdot
.998 .57931 Mdot
.998 .57948 Mdot
.998 .58019 Mdot
.998 .58042 Mdot
.998 .58127 Mdot
.998 .58135 Mdot
.998 .58241 Mdot
.998 .58526 Mdot
.998 .58528 Mdot
.998 .58672 Mdot
.998 .58694 Mdot
.998 .58697 Mdot
.998 .58822 Mdot
.998 .58962 Mdot
.998 .59154 Mdot
.998 .59167 Mdot
.998 .59195 Mdot
.998 .59222 Mdot
.998 .59248 Mdot
.998 .59274 Mdot
.998 .59318 Mdot
.998 .59326 Mdot
.998 .5937 Mdot
.998 .59381 Mdot
.998 .59424 Mdot
.998 .59428 Mdot
.998 .59481 Mdot
.998 .59624 Mdot
.998 .59708 Mdot
.998 .59773 Mdot
.998 .59939 Mdot
.998 .59973 Mdot
.998 .59986 Mdot
.998 .59999 Mdot
.998 .60053 Mdot
.998 .60174 Mdot
.998 .60332 Mdot
1 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[53]:=",
  ImageSize->{740.75, 457.813},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000AG0002[R000`400?l00000o`00003oo`3ooooo
0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0
ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3o
oomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?oo
o`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00l@3o
ool4000000H0oooo0P0000050?ooo`H00000_P3oool4000000H0oooo0P0000070?ooo`@00000_`3o
ool4000000H0oooo0P0000070?ooo`@00000_P3oool4000000H0oooo0P0000060?ooo`@00000a`3o
ool700000080oooo003`0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2
000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool2000000T0oooo00<000000?ooo`3oool0_@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0a`3oool0
0`000000oooo0?ooo`030?ooo`00l03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool00`3oool00?00oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`H00000_P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo0P0000030?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0a`3oool00`000000
oooo0?ooo`030?ooo`00l03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00@000000?ooo`3oool00000_`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`0000000P00002m0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool400000<X0oooo00<000000?ooo`3oool00`3oool00?00oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo00000;l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0a`3oool00`000000oooo0?ooo`030?ooo`00l03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2k0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002o0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2n0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0<L0oooo00<000000?ooo`3oool00`3oool00?00oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0^`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000_`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0_@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`350?ooo`<000001@3oool00?40oooo1000000>0?ooo`@00000_`3oool4
00000100oooo0P0000300?ooo`@000004@3oool300000;d0oooo1000000>0?ooo`@00000bP3oool0
0`000000oooo0?ooo`030?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3o
ool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000060?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo
000000030?ooo`060000003oool0oooo0000003oool000001@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0
000000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool02@000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool00`000000oooo00000003
0?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`050000003o
ool000000?ooo`0000001P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000003
0?ooo`060000003oool0oooo0000003oool000000`3oool01@000000oooo0000003oool0000000H0
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000060?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0000
00030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?oo
o`0000001@3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00L000000?oo
o`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool01@000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000
003oool0oooo00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000
003oool0000000D0oooo00<000000?ooo`000000103oool00`000000oooo000000050?ooo`070000
003oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000003P3oool01@000000oooo0?oo
o`3oool0000000D0oooo000X0?ooool00000o`00003o00000?l00000;P0000050?ooo`00:03oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000001P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
1@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000050?ooo`00:03oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
000000030?ooo`050000003oool000000?ooo`000000103oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`07
0000003oool000000?ooo`000000oooo000000050?ooo`00:03oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000030?oo
o`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`00
00001@3oool002P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool040000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00D0oooo00<000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000001@3o
ool002P0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0
oooo06X0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
00050?ooo`00:03oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo0=80oooo00<00000
0?ooo`3oool0JP3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0;
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool030000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000000`3oool00`000000oooo
000000030?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool00000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00L000000?ooo`3o
ool0oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000T0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000060?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000@0oooo00/000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000030?ooo`0:
0000003oool0oooo0000003oool000000?ooo`000000oooo000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`3oool00`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`0000070?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0oooo5P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00@000000?oo
o`3oool000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`05
0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
4P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo
00D000000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003o
ool000000`3oool00`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000`3oool040000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`030000003oool0000000<0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`0=0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
1`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L0
00000?ooo`3oool0oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo00000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?oooaH0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`030000003oool0oooo00<0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000D0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`050?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001@3o
ool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo01800000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000009
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000203oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool0
0`000000oooo0?ooo`040?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
0`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000070?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo00<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?oo
o`3oool01P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaH0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000203oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000050?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000050?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo0000
00050?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00P00000
0?ooo`3oool000000?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000
oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool00P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool0
oooo0?ooo`0000001@3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool03`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?oo
o`00:03oool500000?l0ooooo`3ooolD0?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000060?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooaH0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool0000000H0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool0
1@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000H0oooo00l000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
1@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool02P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`0000070?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000001P3oool00`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`05
0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3o
ool00`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000<0oooo00P00000
0?ooo`3oool000000?ooo`000000oooo000000T0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooolF0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000050?ooo`040000003oool0oooo000000L0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D00000
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000060?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00X000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000`3oool01@000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool0000000@0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000070?ooo`050000003oool000000?oo
o`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000
00070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000040?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
1`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000060?ooo`050000003oool000000?ooo`0000001@3oool040000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`080000
003oool0oooo0000003oool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000103o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oolF0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00040?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0000
00030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0oooo00<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?oooaH0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool01@000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000203oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?oooaH0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo010000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
40000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00H0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000L0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool02`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
000000H0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooolF0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool0
1@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool00000103oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
00H0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo00`000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`0B0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000050?ooo`0:0000003oool0oooo0000003o
ool000000?ooo`000000oooo000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00D000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000070?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo00000007
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool00000103oool01@000000oooo0000003oool0000000T0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000004
0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?oooaH0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool00P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`D00000
o`3ooooo0?oooa@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool01@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000
003oool0oooo0?ooo`0000001@3oool01@000000oooo0000003oool0000000@0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000030?ooo`0B0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`0;0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000`3oool04P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
5P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000070?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000050?ooo`050000003oool000000?ooo`000000103oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo
000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool00000103oool01@000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000007
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool01@000000oooo0?ooo`3oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000003
0?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo00000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000050?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo
0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooaH0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000`3oool03P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000`3oool04P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000P0oooo00D00000
0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000`3oool02P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`0000070?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0oooo5P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000
003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00D0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?oo
o`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000
003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooaH0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000050?ooo`060000003oool0oooo0000003oool000000`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool0000000D0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool00`000000oooo000000030?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000P0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0oooo5P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`060000003oool0oooo0000003oool000000`3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool00`000000
oooo0?ooo`020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0000000@0oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000050?ooo`030000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000050?ooo`0>0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
oooo0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool00000
0?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00D000000?ooo`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000
oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000000`3oool0
1@000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000
003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000001P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000D0oooo00@000000?ooo`3oool000000`3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00D000000?oo
o`000000oooo000000040?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000090?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?oo
o`3oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo00<000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000060?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?oooaH0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool00P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00H0oooo00<000000?ooo`3oool01`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0
oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000
003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo0000
00020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`D0
0000o`3ooooo0?oooa@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`07
0000003oool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0oooo5P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
4P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo
000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`070000003oool0
oooo0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000060?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
2@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?oo
o`050000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
1P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0oooo00D0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000H0oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0oooo
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00L0
00000?ooo`000000oooo0000003oool0000000D0oooo018000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000T0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000050?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000030?ooo`030000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00<0
00000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1@3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00001@3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0
000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`070000003oool000000?ooo`000000oooo
000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000H0oooo00D000000?ooo`000000oooo000000070?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0oooo5P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000`3oool01@000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000001P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
1@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
1@000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00D000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000050?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo
0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00`000000oooo0000
00030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000001P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo
000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000D0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`03
0000003oool0000000D0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0
oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00d000000?oo
o`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?oo
o`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
oooo5P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003o
ool000000?ooo`000000oooo000000D0oooo00<000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool02000
0000oooo0?ooo`000000oooo0000003oool000000`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0000000H0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000
003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo000000040?ooo`030000003oool0000000T0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0oooo5P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool0000000H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool04P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003o
ool000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000050?ooo`050000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0000000D0oooo00D0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000040?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`00
00030?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00060?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooolF0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003o
ool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000H0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003o
ool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo0180
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`050000
003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000050?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0oooo5P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000050?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo00@0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00000`3oool01`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo000000060?ooo`0=0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo0180
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool00P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00001@3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`030000003oool0000000<0oooo00h000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000D0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0oooo5P3oool00`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool00000
0?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo
000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000
oooo000000070?ooo`000P3oool4000000H0oooo0P0000050?ooo`H000003`3oool00`000000oooo
0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000030?ooo`080000003o
ool0oooo0000003oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool0103oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`000000103o
ool01@000000oooo0000003oool0000000L0oooo00000`3oool000000?ooo`030?ooo`030000003o
ool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo
0000003oool0000000L0oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000001@3oool04P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000050?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000070?ooo`0000<0oooo0000003oool00`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`040000
003oool0oooo000000<0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo01800000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`030000003oool0000000D0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000L0oooo00000`3oool000000?ooo`030?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03`3oool700000?l0ooooo`3ooolB0?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`05
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000
oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000070?oo
o`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00<000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool0000000H0oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo
000000050?ooo`030000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
1@3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000060?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0@0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`3oool0oooo000000090?ooo`0000<0oooo0000003o
ool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000002@3oool00080oooo1000
000>0?ooo`@00000403oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00`000000oooo0000
00030?ooo`050000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000203oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool00`000000oooo000000030?ooo`030000003oool00000
00<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000050?oo
o`040000003oool0oooo000000<0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000040?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaH0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000050?oo
o`030000003oool0000000@0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool00`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0oooo5P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00L0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooolF0?ooo`050000003oool000000?ooo`0000000`3oool01@000000
oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01@00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00D0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0000000<0oooo00L000000?oo
o`3oool0oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`030000
003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3o
ool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`3oool01`3oool01@000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000050?ooo`050000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool01@000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000103o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01@000000
oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool00000103oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000L0oooo00<000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool02`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000
oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000050?ooo`030000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaH0oooo00<000000?ooo`0000001@3oool01@000000oooo0000003oool0000000@0oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?oo
o`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`070?oo
o`050000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000D0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?oooaH0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`040000003oool0oooo000000<0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo00000006
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?oooaH0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo00000003
0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool0
0`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool0
0`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0
oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool00000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`04
0000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000060?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?oooaH0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000D0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003o
ool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000103oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?oo
o`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool00`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
000000050?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00l00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo
0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000H0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
0`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000@0oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000
003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003o
ool0000000D0oooo00<000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000001@3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000001P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo
000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool01@000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00@000000?ooo`3oool000000`3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000H0oooo00<000000?ooo`3oool01`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?oooaH0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0
000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000060?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000
oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003o
ool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0
000000D0oooo00D000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`000000103oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000<0oooo018000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00D00000
0?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`07
0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000001`3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`030000003oool0000000<0oooo00P000000?ooo`3oool000000?oo
o`000000oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0oooo00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0oooo5P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool04000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000D0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000007
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000D0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00<00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
2P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000070?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000D0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000D0
oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0000
003oool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
2P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000070?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0oooo5P3oool00`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo00H0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool03`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000002@3oool002P0oooo1@00003o0?ooool0oooo503oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo
00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo
0000003oool0000000D0oooo00<000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool00`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01`000000
oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaH0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`050000003oool000000?ooo`0000001`3oool030000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000D0oooo018000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`050000
003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo010000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool00000103oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00L0
00000?ooo`3oool0oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool01@000000oooo0000003oool0000000H0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000D0oooo
00@000000?ooo`3oool000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?oo
o`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:0000
003oool0oooo0000003oool000000?ooo`000000oooo000000L0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooolF0?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`050000
003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
00050?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool020000000oooo0?oo
o`000000oooo0000003oool000000`3oool01@000000oooo0000003oool000000080oooo00<00000
0?ooo`0000001`3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0<0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000001@3oool040000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000
003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000050?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000@0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`05
0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`000000203oool02`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`050000003oool000000?ooo`000000
0`3oool01@000000oooo0?ooo`3oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaH0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`05
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000003
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`070?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<0
00000?ooo`3oool00`3oool01`000000oooo0000003oool000000?ooo`000000103oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`00
0000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080
oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?oooaH0oooo00<000000?ooo`0000002@3oool03P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000`3oool04P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?oo
o`000000oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000001@3oool00`000000oooo000000060?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool0
oooo0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool00000103oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo00000003
0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000001P3oool0
3`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0000000D0oooo00<000000?ooo`00
00001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`060000003o
ool0oooo0000003oool000001@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`05
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool03@000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`030000
003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`050000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000L0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01`000000
oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`050000003oool0
00000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool010000000
oooo0?ooo`0000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001@3oool02P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo00P0oooo00L000000?oo
o`000000oooo0000003oool0000000H0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000T0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolF0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`030000003o
ool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000P0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`00
00030?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`0B0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0oooo5P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0@
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
1P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000080?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00D000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000050?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0
000000D0oooo00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
1@3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0000000<0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`05
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000D0oooo00<00000
0?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000030?ooo`060000003oool0oooo
0000003oool000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaH0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000001P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<00000
0?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000<0oooo00P00000
0?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool01P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00060?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000001@3oool02P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000001P3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000060?ooo`0;0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000L0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000050?oo
o`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`0000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
5P3oool00`000000oooo000000050?ooo`030000003oool0000000H0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00@0oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000070?oo
o`030000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00D0oooo00<000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
000000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool01@3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000001P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000000`3o
ool010000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
1@000000oooo0000003oool0000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`03
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo
00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool0
0`000000oooo000000050?ooo`050000003oool000000?ooo`000000103oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?oo
o`030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0oooo0?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo010000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000103o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`0:0000003oool0oooo
0000003oool000000?ooo`000000oooo000000L0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooolF0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000001@3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooaH0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`0:
0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000
1P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000D0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000040?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oolF0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000
003oool000000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool03@000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000050?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0?oo
o`3oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00`000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`0B0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000
oooo000000080?ooo`030000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooolF0?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`0?
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool0
1@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000
003oool0oooo0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003o
ool0oooo0?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00d0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000P0oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool04P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo00000004
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00<000000?oo
o`0000001@3oool01@000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`0000050?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool01@000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000050?ooo`03
0000003oool0000000@0oooo00<000000?ooo`0000001@3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
0`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000002@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000001P3oool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool0
4P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00L000000?ooo`000000oooo0000003oool0000000P0oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool00000
00<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0000000D0oooo00<00000
0?ooo`000000103oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000040?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo
0?ooo`0000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`060000003oool0oooo0000003oool000000`3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00002P3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`00
0000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000
103oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`060000003oool0
oooo0000003oool000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo1@00003o0?ooool0oooo
503oool00`000000oooo0?ooo`030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000L0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
1P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000001@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00D000000?ooo`000000
oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000
oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003o
ool0000000D0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000060?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`050000003oool0oooo0?ooo`000000103oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool00P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
00P0oooo00<000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0
oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00<000000?oo
o`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool03@000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000`3oool00`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`000003
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?oo
o`0000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0
oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000001P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0
oooo00<000000?ooo`0000001`3oool00`000000oooo000000020?ooo`030000003oool0000000<0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?oo
o`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000`3oool01@000000oooo0000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00L000000?ooo`000000oooo0000003oool00000
00L0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool01@000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000D0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`0;0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`000000103oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000D0
oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000001`3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00<000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00001`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?oo
o`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`0000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`05
0000003oool0oooo0?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000040?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103o
ool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`080000003oool0
oooo0000003oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool03`00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3o
ool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000
oooo0000003oool0000000@0oooo00<000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooaH0oooo00<000000?ooo`0000001@3oool01@000000oooo0000003oool00000
00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00`3o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`060000003oool0oooo0000003oool000000`3oool01`000000oooo0?ooo`3oool0
00000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo00000005
0?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`03
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool01@00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool04P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0oooo
00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool01@00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000090?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0oooo5P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000<0oooo00H000000?ooo`3oool000000?ooo`0000070?ooo`030000003oool0000000@0oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00001P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool02P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000030?ooo`030000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool040000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
00H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`03
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000L0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooolC0?ooo`080000003oool0oooo0000003oool00000
0?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`3oool0
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3o
ool00`000000oooo0?ooo`050?ooo`050000003oool000000?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`030000003oool00000
00D0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`0000030?ooo`030000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00<000000?ooo`0000001@3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000050?ooo`0B0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01`000000
oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaH0oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`050?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool04P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`0@0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo
0000003oool0000000@0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`08
0000003oool0oooo0000003oool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000001@3oool01@000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool00`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
1@3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool0oooo00@0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000070?ooo`050000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000060?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003o
ool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool00`000000oooo000000050?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`040000
003oool0oooo000000<0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooolF0?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00/000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01`000000oooo0000
003oool000000?ooo`000000103oool00`000000oooo000000050?ooo`050000003oool0oooo0?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool0
0`000000oooo0?ooo`040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000001P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000H0oooo00D0
00000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3o
ool00`000000oooo0?ooo`050?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo
000000050?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo00L0
00000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000D0oooo00D0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000D0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool00P3oool03@000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`000000oooo0000000:
0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000060?ooo`030000003o
ool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooolF0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000040?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0000003oool0000000L0oooo00<000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000D0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`0000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool0000000@0oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000D0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`040000003oool0oooo000000<0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00L000000?oo
o`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000060?ooo`0;0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool0
0`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0
oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000001`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooaH0oooo00D000000?ooo`000000oooo0000000<0?ooo`070000
003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`070000
003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00l000000?oo
o`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`3oool01@3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo000000030?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000
oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000050?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000030?ooo`060000003oool0oooo0000003oool000000`3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`070000003oool000000?oo
o`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000060?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000070?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0oooo5P3oool00`000000oooo000000050?ooo`050000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`000000103oool0
1@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000001P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000001`3oool04P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0
oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0oooo
00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool00000
1@3oool01`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`00
0000oooo000000<0oooo00<000000?ooo`3oool00P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003o
ool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000P0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@00
0000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00D000000?ooo`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`03
0000003oool0oooo00D0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool0000000D0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool01@000000oooo0000003oool0000000<0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000001@3oool03P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool00000103oool03`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00050?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?oo
o`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000
003oool000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00L000000?oo
o`000000oooo0000003oool0000000P0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00050?ooo`040000003oool0oooo000000<0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L00000
0?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo
000000040?ooo`030000003oool0oooo00L0oooo00D000000?ooo`000000oooo000000020?ooo`03
0000003oool0oooo00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000D0oooo00<000000?ooo`000000103oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0
000000D0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`0000050?ooo`040000003oool0oooo000000<0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0000000D0oooo00D000000?oo
o`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`080000
003oool0oooo0000003oool000000?ooo`0000030?ooo`050000003oool000000?ooo`000000103o
ool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo010000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool00P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000L0oooo00<000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`030000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooolF0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`000000
1P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo000000050?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000203oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000050?ooo`030000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
3`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool0
1@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000050?ooo`030000
003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool000000?ooo`000000103oool02`000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`3oool00`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00040?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000
003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaH0oooo00D000000?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000103oool0
1@000000oooo0000003oool0000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool000000080
oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00<000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000070?ooo`00:03oool500000?l0ooooo`3ooolD0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`0000001P3oool01@000000oooo0000003oool0000000`0oooo00d0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0
000000<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000D0oooo00D000000?ooo`000000oooo000000060?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000
003oool000000?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo
000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo
00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000090?ooo`030000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000103oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool00000
0080oooo00<000000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`03
0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`070000
003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo
0?ooo`3oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3o
ool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool00000
00X0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool00P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`050000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000003
0?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000070?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0oooo5P3oool00`000000oooo000000050?ooo`050000003oool0
oooo0?ooo`000000203oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0
1@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo000000030?ooo`030000003oool0000000@0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0?oo
o`3oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`050000003oool0oooo0?ooo`000000103oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?oo
o`0000030?ooo`030000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool01@000000oooo0000003oool0
000000D0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`060000003oool0oooo0000003oool000000`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000L0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`070000003oool0oooo0?ooo`00
0000oooo000000050?ooo`040000003oool0oooo000000<0oooo00/000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000001@3oool00`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000001P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo
00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`00
00000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool02`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaH0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000P0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?oo
o`0000000`3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00X000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00@0
00000?ooo`3oool000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
5P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0000000<0oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000050?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo00000002
0?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?oo
o`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00`000000oooo0?ooo`030?ooo`070000003o
ool000000?ooo`000000oooo000000040?ooo`030000003oool0000000D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00001P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001`3oool00`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`030000003o
ool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool02P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`050000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00L000000?ooo`3oool0oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`06
0000003oool0oooo0000003oool000000`3oool01@000000oooo0000003oool0000000<0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`070000003oool0oooo0?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooolF0?ooo`050000003oool000000?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0
oooo000000D0oooo00D000000?ooo`3oool0oooo000000040?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`000000103oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo000000050?ooo`040000003o
ool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool000000080
oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo000000040?ooo`030000003oool0000000<0oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooolF0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
0`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00L00000
0?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000P0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000
oooo0?ooo`3oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`0000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00`00
0000oooo000000030?ooo`050000003oool000000?ooo`000000103oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000002P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool00P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
40000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool0000000D0oooo
00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00/000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000D0
oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000001@3oool00`000000oooo0?ooo`040?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00D00000
0?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000T0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0000000D0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0000000D0oooo00D000000?ooo`000000oooo
000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool0103oool01`000000oooo
0000003oool000000?ooo`0000001P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`07
0000003oool0oooo0?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000`3oool010000000oooo0?ooo`0000050?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000070?oo
o`030000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000003
0?ooo`030000003oool0oooo0080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000002`3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00<000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`050000003oool0
00000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool01@000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool00000103oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool0
1@000000oooo0000003oool0000000L0oooo00<000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo
00L000000?ooo`3oool0oooo0000003oool0000000P0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000203oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`000000103oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`030000003oool0oooo00D0oooo00L000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000D0oooo
00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0
000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`3oool00`3oool01`000000oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000D0oooo00X000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo
00<000000?ooo`3oool01@3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`00
00002P3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000103oool01@000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000050?ooo`080000003oool0oooo0000003oool000000?ooo`00
00030?ooo`050000003oool0oooo0?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000001P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<00000
0?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?oo
o`000000oooo000000080?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
000:0?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000H0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`000000103oool03@000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo000000030?oo
o`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool01@3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0oooo00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo01800000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0
oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`05
0000003oool000000?ooo`0000001`3oool03P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool00000203oool00`000000oooo000000030?ooo`050000003oool0
00000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00D0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool00`000000oooo000000050?ooo`050000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000
oooo000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
5P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000080?oo
o`050000003oool0oooo0?ooo`0000001P3oool03`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000001P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000
003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00`000000oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000L0oooo
00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000050?ooo`050000003o
ool0oooo0?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000060?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000050?ooo`0@0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`030000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooolF0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo
00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000`3oool0
10000000oooo0?ooo`0000030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00H0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000050?ooo`080000003oool0oooo0000003oool0
00000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`00
00000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
5P3oool00`000000oooo000000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool01@000000oooo0?ooo`3oool0000000@0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000020?oo
o`030000003oool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`050000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`00
00001@3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000D0
oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000D0
oooo00<000000?ooo`3oool00P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000
003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo
00D000000?ooo`000000oooo0000000:0?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`00
00001@3oool00`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`00
0000oooo000000040?ooo`030000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo0000003o
ool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool040000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`03
0000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000060?ooo`030000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oolF0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
3@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000050?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool00`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000090?ooo`000P3oool4000000H0oooo0P0000070?ooo`@000003`3oool00`000000oooo
0?ooo`3o0?ooool0oooo5P3oool00`000000oooo0?ooo`030?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool010000000oooo0?ooo`0000030?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00h000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`000000
1@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
0000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`00
0000oooo0000003oool000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
2P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool00000
00@0oooo00D000000?ooo`000000oooo000000090?ooo`0000<0oooo0000003oool00`3oool00`00
0000oooo0?ooo`030?ooo`8000002@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0?l0ooooo`3ooolF0?ooo`030000003oool0000000D0oooo00D000000?ooo`000000oooo00000002
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003o
ool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool02`00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool01@000000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000
003oool0oooo00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool040000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`050?oo
o`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00D000000?ooo`3oool0oooo000000050?oo
o`030000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0
000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000030?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool01@3oool02P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?oo
o`0000001`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00000<0?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0000000D0oooo
00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo
00000`3oool000000?ooo`030?ooo`030000003oool0oooo00X0oooo1P00000?0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool00000
0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000001@3oool030000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0
000000D0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000040?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo
00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000H0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`080?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`040000003oool0oooo000000D0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo0000
00050?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool00000103oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00D000000?ooo`000000oooo000000070?ooo`0000<0oooo0000003oool00`3oool00`00
0000oooo0?ooo`0;0?ooo`040000003oool0oooo00000100oooo1`00003o0?ooool0oooo4P3oool0
0`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000001P3oool01@000000oooo0?oo
o`3oool0000000D0oooo00<000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001@3o
ool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
00D0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`000000
103oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`030000003oool0000000D0oooo00D000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo0080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000H0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0
000000H0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000<0oooo00X000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000`3oool01@000000oooo0?ooo`3oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000L0oooo00000`3oool000000?ooo`030?oo
o`030000003oool0oooo00/0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`3o
0?ooool0oooo5P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool01P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00L00000
0?ooo`3oool0oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`07
0000003oool0oooo0?ooo`000000oooo000000050?ooo`080000003oool0oooo0000003oool00000
0?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?oo
o`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool000000100
oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00<000000?ooo`3oool01@3oool00`000000
oooo000000040?ooo`030000003oool0oooo00<0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000
1P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000030?ooo`0>0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`0<0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000001P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?oo
o`000000oooo000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00/00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000L0oooo00<0
00000?ooo`000000203oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000H0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool01@3oool000030?ooo`000000oooo00<0oooo00<000000?oo
o`3oool0303oool00`000000oooo0000000@0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?oo
o`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0000000<0oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`00
00001@3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool00`000000oooo00000003
0?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000001P3oool01@000000oooo0000003oool0000000<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000060?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00H0oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`03
0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`000P3oool400000100
oooo0P00000@0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`070000003oool0oooo0?oo
o`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000080?ooo`030000003oool0000000L0oooo00<000000?ooo`000000103oool0
0`000000oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001@3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000080?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00D000000?oo
o`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000/0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0000000D0oooo00D000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool01@000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo
00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo000000040?ooo`0;0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000203oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool0103oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000080?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo00000003
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000050?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00`000000
oooo0?ooo`050?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`0000030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@00
0000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`050000
003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`3oool01@3oool01@000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00<0
00000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo000000030?oo
o`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`050000003o
ool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`0;0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`070000003oool000000?oo
o`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?oo
o`3oool0oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000060?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0>0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`08
0000003oool0oooo0000003oool000000?ooo`0000050?ooo`050000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooolF0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo
00H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo
0000003oool000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000060?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`000000103oool00`000000oooo000000050?ooo`070000003oool0oooo0?ooo`000000
oooo000000040?ooo`030000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
1@3oool01P000000oooo0?ooo`000000oooo000000D0oooo00D000000?ooo`000000oooo00000004
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`0000002@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?oooaH0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000060?ooo`0=0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`0=0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000P0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`060000003oool0oooo0000003oool000000`3oool01`000000oooo0000003oool00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`03
0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000L0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?oo
o`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooaH0oooo00<000000?ooo`3oool01@3oool01@000000oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000040?ooo`030000003oool0000000D0oooo00D000000?ooo`000000oooo000000040?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000`3oool00`000000oooo000000060?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo00000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`070000003o
ool0oooo0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000D0oooo00P000000?ooo`3oool000000?ooo`00
0000oooo000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`00
0000oooo000000050?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0
oooo00<000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00060?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000
oooo000000D0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00`000000
oooo0?ooo`090?ooo`060000003oool0oooo0000003oool000000`3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000L0oooo00D000000?ooo`00
0000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo00000004
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000L0oooo00`000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000030?ooo`030000003oool000000080oooo00l000000?oo
o`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`0000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000050?oo
o`050000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool0
00000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000001@3oool010000000oooo0?ooo`0000030?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000090?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0oooo5P3oool00`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00D000000?ooo`3oool0
oooo0000000:0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00<0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000@0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000000:0?ooo`030000003o
ool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
00030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo
0000003oool000000?ooo`0000001P3oool00`000000oooo000000070?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0oooo5P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool0
2`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?oo
o`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0000000D0oooo00<000000?ooo`0000001P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`060000
003oool0oooo0000003oool000001@3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooaH0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000
003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000H0
oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000L0oooo00<000000?ooo`3oool00P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00D000000?oo
o`3oool0oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool01@000000oooo
0000003oool0000000P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo000000040?ooo`05
0000003oool000000?ooo`000000203oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?oo
o`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`000000
0`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000001`3oool01@000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`050000003oool0
oooo0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00`000000oooo
000000030?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0000003oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000P0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`05
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`070000003oool00000
0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`08
0000003oool0oooo0000003oool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`000000
1@3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool03@000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000203oool01@000000oooo0?ooo`3oool00000
00H0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000103o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000050?ooo`060000003oool0
oooo0000003oool000001@3oool01@000000oooo0000003oool0000000@0oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000001@3oool04P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0000
00050?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000/0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0000000D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000040?ooo`070000003oool0oooo0?ooo`000000oooo0000
00030?ooo`030000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000D0
oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000030?ooo`0>0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool0
oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`030000003oool0000000D0oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?oo
o`030000003oool0000000D0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000050?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000001P3oool0
0`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo803oool00`00
0000oooo0?ooo`040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool00`000000oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo
00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000
003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
1@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?oooaH0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool01P00
0000oooo0?ooo`000000oooo000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`030?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3o
ool01@000000oooo0000003oool0000000@0oooo00l000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000070?ooo`030000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000001P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
00P0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`0@0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`050?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo0000003oool0000000P0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00`000000oooo0?ooo`030?ooo`07
0000003oool0oooo0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00d000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000203oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103o
ool00`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000`3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`060000003oool0oooo0000
003oool000001@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000060?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool00000
00D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool0
0`000000oooo000000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000080?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L00000
0?ooo`000000oooo0000003oool0000000D0oooo00@000000?ooo`3oool000001`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000020?oo
o`030000003oool0000000D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`3oool01@3oool00`000000oooo000000040?ooo`0?0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`00
00000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?oo
o`0000001@3oool00`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000@0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`070000003oool0oooo
0?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo0000000:0?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000001@3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000001@3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3o
ool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo
0000003oool000000?ooo`000000203oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000L0oooo00<000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`070000003oool0
oooo0?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000001P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
5P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001`3oool00`000000oooo0?ooo`040?oo
o`070000003oool000000?ooo`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00X0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00<000000?ooo`0000001@3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool010000000
oooo0?ooo`0000030?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo000000060?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo00000002
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool03000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000P0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
oooo803oool00`000000oooo000000060?ooo`030000003oool0000000D0oooo00<000000?ooo`00
00000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool00`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo000000080?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool01@00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000D0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
0000103oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000000:0?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000080?ooo`030000003oool0000000L0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolL0?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0000000P0oooo00<0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`000000
0`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000D0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000P0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?oo
o`0000001@3oool01@000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?oo
o`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oolH0?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000001`3oool00`000000oooo000000040?ooo`030000003oool0000000<0
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000
00050?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo
0?ooo`3oool000000?ooo`000000103oool00`000000oooo000000050?ooo`030000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`030000003oool0000000D0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool00`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
000000@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000<0oooo0100
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`00
0000oooo000000060?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`02
0?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool03000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooob00oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`050000
003oool000000?ooo`000000203oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool0
40000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000020?ooo`030000003oool0000000D0oooo00L000000?ooo`3oool0oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo
000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0000000<0oooo018000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo
00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0
oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0
oooo00D000000?ooo`3oool0oooo000000050?ooo`0:0000003oool0oooo0000003oool000000?oo
o`000000oooo000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00d000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolH0?ooo`0;0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`03
0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`04
0000003oool0oooo000000L0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000203oool01@000000
oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000001P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
1@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
2`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
1`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?oooaX0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool0000000H0oooo00<000000?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0oooo0?ooo`00
0000oooo000000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3o
ool000000?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`030000
003oool0oooo00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`050000003o
ool000000?ooo`0000001`3oool002P0oooo1@00003o0?ooool0oooo5P3oool00`000000oooo0?oo
o`0<0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00<000000?ooo`3oool00`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000
003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000001P3oool00`000000oooo000000050?ooo`050000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000`3oool0
10000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`0000000`3oool04P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000001@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolN0?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`0000050?oo
o`050000003oool000000?ooo`000000103oool00`000000oooo000000070?ooo`030000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000040?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<0
00000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool00`3oool01`000000oooo0000003oool000000?ooo`000000103oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000050?ooo`030000003oool0000000@0oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool03`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo
00D000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`00
00090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo603oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000D0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00P000000?ooo`3oool000000?ooo`000000oooo000000T0oooo00@000000?ooo`3oool00000
0`3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000050?ooo`060000003oool0oooo0000003oool0
00000`3oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool000000`3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000000:0?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0000000P0oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo
000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oolJ0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
00050?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00<00000
0?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00H0oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000103o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D00000
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool03@000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`07
0000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0oooo703oool01`000000oooo0000003oool000000?ooo`0000001P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000000`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?oo
o`000000oooo000000080?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000`3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo
00<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000050?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo00@0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0?ooo`030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000
00070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo603oool00`000000oooo0?ooo`05
0?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool0103oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`050000003oool000000?ooo`0000001`3oool04P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool00000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000
oooo000000D0oooo00D000000?ooo`3oool0oooo000000040?ooo`070000003oool000000?ooo`00
0000oooo000000050?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00030?ooo`030000003oool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000L0oooo00<000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000
00040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`0000050?ooo`080000003oool0oooo0000003oool00000
0?ooo`0000030?ooo`050000003oool000000?ooo`000000103oool00`000000oooo000000030?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`0000002`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?oooaX0oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000030?ooo`080000003oool0oooo0000003oool00000
0?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000
oooo000000050?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000
oooo000000D0oooo00<000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00D0oooo
00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000005
0?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`3o
ool0oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000060?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo00000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolH0?ooo`070000003oool0oooo0?ooo`000000oooo00000006
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
00002P3oool00`000000oooo0?ooo`030?ooo`0>0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000040?ooo`030000003oool0000000<0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo0000
00060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000203oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0000000D0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000080?ooo`070000003oool000000?ooo`000000
oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
1P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000
oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool0
00000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@00
0000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool03`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolL0?ooo`050000003oool000000?oo
o`000000103oool00`000000oooo000000050?ooo`070000003oool000000?ooo`000000oooo0000
00040?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool000000080
oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000001P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool0000000D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000`3oool00`000000oooo0?ooo`040?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`05
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo603oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000`3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000050?oo
o`030000003oool0000000H0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo00<0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolJ0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000070?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo
000000050?ooo`030000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000`3oool00`000000oooo000000060?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000050?ooo`030000003oool0oooo00P0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo000000030?ooo`050000003oool000000?ooo`000000103oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`000000103oool00`000000oooo00000003
0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolL0?oo
o`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool00000203oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`030?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00<000000?ooo`0000001`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000080?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00D000000?ooo`000000oooo000000050?ooo`040000003oool0oooo000000<0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool0
00000?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolH0?oo
o`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000`0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01@000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000
103oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0
00000080oooo00<000000?ooo`3oool02@3oool02P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`0000030?ooo`050000003oool000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo
000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0`3oool010000000oooo0?ooo`0000030?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000D0oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
0000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`070000003o
ool000000?ooo`000000oooo000000070?ooo`0B0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0000
00030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolJ
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000001P3oool01@000000oooo0000003o
ool0000000D0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`050000003oool000000?oo
o`0000001P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
0`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000080?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3o
ool00`000000oooo000000060?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`03
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`030000003oool0000000D0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolH0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000001P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`000000103oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool0
103oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`0@0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`0000001P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo
00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?oooah0oooo00<000000?ooo`0000001P3oool02`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01`000000oooo0000003oool0
00000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool04P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000060?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000050?ooo`040000003oool0oooo000000<0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`07
0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0
000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000001`3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?oooaP0oooo00D000000?ooo`3oool0oooo000000080?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`0000001P3oool01`000000
oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
1@3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool01@000000
oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool0
00000?ooo`000000103oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0000000H0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`3oool0oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool03@000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000D0oooo00`000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000030?ooo`030000003oool0000000@0oooo00D000000?oo
o`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo6P3oool00`00
0000oooo0?ooo`0:0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003o
ool000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000050?ooo`080000003oool0oooo0000003oool000000?oo
o`0000030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00D0
00000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool01`000000oooo0000003oool000000?ooo`00
00001`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool00P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000
00070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo703oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool00P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3o
ool01@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000050?ooo`040000003oool0oooo0000
00<0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`07
0000003oool000000?ooo`000000oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool00000
00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool0000000D0oooo00D0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolH0?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool000000080oooo00l000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000002P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool00000
0`3oool01`000000oooo0000003oool000000?ooo`0000001P3oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00d000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`000000103oool00`000000oooo000000050?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo000000050?ooo`030000003oool000000080oooo00<0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00L0
00000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo000000050?ooo`030000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`070000003o
ool000000?ooo`000000oooo000000080?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`070000
003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool00000
00T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolJ0?ooo`070000003oool0oooo0?oo
o`000000oooo000000040?ooo`030000003oool0000000L0oooo00D000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool0000000H0oooo00d000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo0000
00050?ooo`060000003oool0oooo0000003oool000000`3oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool0000000D0oooo00@000000?ooo`3oool00000
0`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0
000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0
0`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0
000000D0oooo00<000000?ooo`000000103oool02`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000050?oo
o`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000004
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo00000002
0?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0oooo603oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01P000000
oooo0?ooo`000000oooo000000L0oooo00<000000?ooo`3oool0303oool01`000000oooo0000003o
ool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo
00D000000?ooo`000000oooo0000000:0?ooo`030000003oool0000000<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00001@3oool010000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0000
00030?ooo`060000003oool0oooo0000003oool000000`3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00D0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`3oool0oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool00000103oool03@000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000007
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo703oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool00`000000
oooo0?ooo`030?ooo`050000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003o
ool0000000D0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool03@00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000`3oool02P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000030?ooo`030000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`0000030?ooo`050000003oool000000?ooo`000000103o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo0000000;0?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo9`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool0000000L0oooo00<00000
0?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`000000203o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000050?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000H0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo
000000D0oooo00<000000?ooo`3oool00P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000
oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000050?ooo`070000003o
ool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000050?ooo`030000
003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00050?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool01@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooaP0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00L000000?ooo`3oool0oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`3oool0oooo0000003oool0000000P0oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000D0oooo00D000000?oo
o`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000
003oool0000000@0oooo00<000000?ooo`0000001@3oool01@000000oooo0000003oool000000080
oooo00<000000?ooo`0000001@3oool00`000000oooo000000030?ooo`0@0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo
0?ooo`0000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000001`3oool00`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0
000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooolN0?ooo`030000003oool0000000P0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0
oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo000000060?oo
o`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool02`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000080?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000060?oo
o`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool02`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3o
ool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool01@000000
oooo0?ooo`3oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooolH0?ooo`0;0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool00000
00<0oooo00<000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000050?ooo`040000003oool0oooo
000000<0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000050?ooo`0:0000003oool0oooo0000003oool0
00000?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`000000203oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003o
ool0000000H0oooo00D000000?ooo`000000oooo000000080?ooo`0=0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool00000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool010000000oooo0?ooo`0000030?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0oooo
0?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01`000000oooo
0?ooo`3oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000002@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooa`0oooo00<000000?ooo`0000000`3oool010000000oooo0?oo
o`0000090?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`050000003oool0oooo
0?ooo`000000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`000000103oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
00<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000
0`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool000000?ooo`00
00001P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000D0oooo00D000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00<0oooo00D000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003o
ool000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
00050?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0
oooo00L000000?ooo`3oool0oooo0000003oool0000000X0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0oooo6P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`0000001@3oool00`000000oooo000000030?ooo`060000003oool0oooo0000003o
ool000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`050000003oool0oooo0?oo
o`0000001P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool00P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000070?ooo`080000003oool0oooo0000003oool000000?oo
o`0000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`000000103oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo
0000003oool000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaP0oooo00<00000
0?ooo`3oool01`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000090?ooo`030000003oool0
oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000P0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`000000
0`3oool01@000000oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool0000000H0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool04P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000050?ooo`0B0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
0`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000
003oool000001@3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0000003oool00000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool01@000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000D0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000001P3oool03@000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolN0?ooo`050000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
103oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`070000003oool0
oooo0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000001@3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000001P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000001`3oool00`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`030000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000007
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo603oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000<0oooo00@000000?ooo`3oool000001`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`00
0000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000030?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`060000
003oool0oooo0000003oool000000`3oool01@000000oooo0000003oool0000000@0oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`030000003oool0000000<0oooo018000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00D000000?ooo`000000oooo000000070?ooo`00:03oool500000?l0ooooo`3ooolJ
0?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`050000003o
ool000000?ooo`000000203oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`080?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`3oool00`3oool01`00
0000oooo0?ooo`3oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool01`000000oooo0?oo
o`3oool000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0000000<0
oooo00@000000?ooo`3oool000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool01`3oool01@000000oooo
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`000000oooo
000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`08
0000003oool0oooo0000003oool000000?ooo`0000030?ooo`050000003oool000000?ooo`000000
103oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooob/0oooo00L000000?ooo`3oool0oooo0000003oool0000000h0oooo00<00000
0?ooo`3oool0103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000030?ooo`0>
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000060?oo
o`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0000000<0oooo010000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`00
0000oooo0000003oool000000`3oool00`000000oooo000000060?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000
003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooah0oooo
00<000000?ooo`000000103oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`070000003oool000000?ooo`00
0000oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000P0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000005
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool00000
0?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000<0oooo00<000000?ooo`3oool00P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00D0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000D0oooo00D0
00000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000007
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo803oool00`000000oooo0000000<0?oo
o`050000003oool0oooo0?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo000000020?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0000000H0oooo00<000000?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool00`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000003
0?ooo`030000003oool0oooo0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000001@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000`3o
ool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000080oooo00D000000?ooo`000000oooo000000090?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0oooo703oool00`000000oooo000000030?ooo`040000003oool0
oooo000000d0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00D000000?oo
o`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo00h000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000P0oooo00<00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3o
ool00`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000050?oo
o`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool000000080oooo00<000000?ooo`0000002`3oool010000000oooo0?ooo`0000030?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000
00050?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo0000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0oooo803oool00`000000oooo0?ooo`020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000P0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool01P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000070?ooo`030000
003oool0oooo0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool01@000000oooo0000
003oool0000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000@0oooo00l000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000050?oo
o`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000L0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooolR0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000050?oo
o`030000003oool0oooo0080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`050000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000P0oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000203oool00`000000oooo000000070?ooo`030000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?oo
o`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0
oooo0000003oool000000?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooob80oooo00<000000?ooo`3oool00P3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`000009
0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000070?ooo`060000003oool0oooo0000
003oool000001@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool03@000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000001P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool000000?ooo`000000103oool00`000000oooo000000050?ooo`070000003oool0
oooo0?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000000:0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?oo
o`070000003oool0oooo0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`000000
1@3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000050?oo
o`030000003oool0oooo0080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool03@000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooobD0oooo00<000000?ooo`000000
1@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0
000000@0oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo0080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`000000203oool00`000000oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000
oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00D000000?ooo`3oool0oooo000000050?ooo`050000003oool000000?ooo`000000
1P3oool00`000000oooo000000070?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000
oooo000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool0000000P0oooo00L000000?ooo`000000oooo0000003o
ool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo
00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`0000001@3oool00`000000oooo000000040?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooobD0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
00001P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000001P3oool00`00
0000oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool0103oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo
00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000D0
oooo00@000000?ooo`3oool000001@3oool01`000000oooo0000003oool000000?ooo`0000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000203oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool0000000P0oooo00D000000?ooo`3oool0oooo000000030?ooo`0@
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0
000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0oooo9`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<00000
0?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool00`000000oooo
000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool00000
00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?oo
o`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000080?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000H0oooo00<000000?ooo`0000001@3oool00`000000oooo000000040?ooo`030000003oool0
000000T0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooobT0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0
00000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000050?ooo`030000003oool000000080oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000001@3oool02P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`0000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000001@3oool010000000oooo0?ooo`0000030?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000070?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo000000030?ooo`030000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00<000000?ooo`0000001@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3oool[0?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo0?oo
o`000000oooo000000/0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`030000003oool0
oooo00@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool03@000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0=0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000030?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000P0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000000:
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000070?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0oooo;@3oool00`000000oooo0?ooo`030?ooo`0B0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000001P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo00000005
0?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
0000103oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`000000oooo00000006
0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0000003oool0000000H0oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000T0
oooo00H000000?ooo`3oool000000?ooo`00000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0oooo;`3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000030?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`000000oooo
000000060?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000001P3o
ool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000001P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3o
ool010000000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`040000003oool0oooo000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`0?0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`00000:0?ooo`030000003oool0000000H0
oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0oooo;`3oool00`000000oooo000000060?ooo`030000003oool0oooo00<0oooo
00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
1@000000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00<000000?oo
o`000000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000060?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000
003oool000000`3oool01`000000oooo0000003oool000000?ooo`0000001P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
0000000:0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool00000
00@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo
0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooc40oooo00<000000?ooo`0000000P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000060?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool00`000000oooo000000030?ooo`040000003oool0oooo000000L0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000060?ooo`070000003oool0oooo0?ooo`000000oooo000000030?oo
o`030000003oool0oooo00H0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00D000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000060?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo
000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`030000003oool0000000<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000D0oooo00D000000?ooo`000000oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooocH0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`060000003oool0oooo0000003oool0
00002`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000050?ooo`030000
003oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0000000D0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0
00000?ooo`0000001@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool00`00
0000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo00H0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`04
0000003oool0oooo000000D0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000@0oooo00D000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0oooo=P3oool00`000000oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0000000<0oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000001P3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo
0?ooo`030?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`070000003oool00000
0?ooo`000000oooo000000050?ooo`060000003oool0oooo0000003oool000001@3oool00`000000
oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000030?oo
o`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`070000003oool0oooo0?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?oo
o`0000001@3oool010000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooocP0oooo00<000000?ooo`3oool0
0`3oool01`000000oooo0000003oool000000?ooo`000000203oool01`000000oooo0000003oool0
00000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`050000003oool000000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000
oooo000000L0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`060?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool0103oool01`000000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo00000002
0?ooo`030000003oool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?oo
o`3oool0oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?oo
o`000000oooo000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo?P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00040?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`030000003oool0oooo00@0
oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000`3oool00`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000<0oooo00<000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0
oooo00@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?oo
o`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo000000040?oo
o`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
och0oooo00D000000?ooo`3oool0oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo
000000<0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool01@000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
1P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`000000
0`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000030?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@00
0000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3oooll0?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000001@3oool00`000000
oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`030000003oool0
oooo0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000
oooo000000030?ooo`030000003oool0000000P0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0
000000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool00`000000oooo000000050?ooo`050000003oool000000?ooo`0000001P3oool00`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool0000000@0oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo?P3oool01`000000
oooo0?ooo`3oool000000?ooo`000000103oool01@000000oooo0000003oool0000000D0oooo00<0
00000?ooo`3oool00P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`000000
oooo000000020?ooo`030000003oool0000000D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<0
00000?ooo`0000001`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000
oooo000000030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`000000oooo000000050?oo
o`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0
000000<0oooo00<000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo@03oool00`000000oooo
0?ooo`040?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool010000000oooo
0?ooo`0000030?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00`3oool020000000
oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`050000003o
ool000000?ooo`0000001@3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3o
ool0oooo000000070?ooo`030000003oool000000080oooo00d000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000005
0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000H0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo
018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo0000
00040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000
003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool000000080
oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0000003oool0000000D0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo
0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooom00?ooo`050000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00<000000?oo
o`3oool01P3oool01@000000oooo0000003oool0000000P0oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?oo
o`0000001P3oool00`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00040?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`050000003oool0oooo0?ooo`000000203oool01`000000oooo0000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000P0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000001@3oool01@000000oooo
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000P0oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000060?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo
0000003oool0000000<0oooo00<000000?ooo`3oool0103oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo000000080?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`05
0000003oool0oooo0?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000T0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooom20?ooo`030000003oool0oooo0080oooo00D000000?oo
o`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00P00000
0?ooo`3oool000000?ooo`000000oooo000000D0oooo00<000000?ooo`0000001P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool03`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000203oool01@000000oooo0000003oool0
000000D0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`00
00001P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool0000000P0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003o
ool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`00
00000`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`00
0000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000001@3oool01@000000oooo0?ooo`3oool000000080oooo00l000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooom40?ooo`060000003o
ool0oooo0000003oool000000`3oool01`000000oooo0000003oool000000?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool01`000000oooo0?oo
o`3oool000000?ooo`0000001@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0000000D0oooo00X00000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool01@3oool01@000000oooo0000003oool000000080oooo00l0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00d0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000050?ooo`050000003oool0oooo0?ooo`000000103oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000050?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool0
1@000000oooo0000003oool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooodd0oooo00<000000?ooo`0000000`3oool04P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000203oool00`000000oooo0?oo
o`030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000001@3oool0
0`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000`3oool00`000000oooo0?ooo`060?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00<000000?ooo`3oool01@3oool01@000000oooo0000003oool00000
0080oooo00<000000?ooo`0000001@3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00H0oooo00D00000
0?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000
oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000070?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000/0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooom90?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool02P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`0000070?ooo`030000003oool0oooo0080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000001`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00050?ooo`030000003oool0000000P0oooo00D000000?ooo`000000oooo000000030?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo000000030?ooo`030000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo010000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000004
0?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooom;0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool0
oooo0?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000080?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000001@3oool01@000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo000000050?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000L0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`050000003oool0oooo0?ooo`00
00001@3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003o
ool000001@3oool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000L0oooo000X0?ooo`D00000o`3ooooo0?oood/0oooo00D000000?ooo`000000oooo
000000060?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`0=
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo00@0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool02@000000
oooo0000003oool000000?ooo`000000oooo000000050?ooo`030000003oool0oooo0080oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`0000050?ooo`030000003oool0oooo0080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?oo
o`3oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool00`3oool04P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0000000@0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000001@3oool040000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool0oooo
00D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000050?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo000000040?ooo`030000003oool0000000D0oooo00<000000?ooo`000000
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
odd0oooo00<000000?ooo`3oool02P3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`000000103oool00`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool020000000oooo
0?ooo`000000oooo0000003oool000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000060?ooo`070000003oool0oooo0?ooo`000000
oooo0000000:0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo00@000000?ooo`3oool0
00000`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003o
ool0oooo00@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
00001P3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00X000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000001`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?oooe<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0000000:0?ooo`030000
003oool0000000<0oooo00D000000?ooo`000000oooo000000080?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00/000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000050?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`08
0000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo00H0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
1@3oool00`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
000000D0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000040?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000001`3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`0000000P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool0000000P0oooo00<000000?ooo`0000001@3oool020000000
oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`00
0000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000040?ooo`050000003oool000000?ooo`0000001@3oool01@000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01@000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000002@3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?oooeH0oooo00D000000?ooo`3oool0oooo00000007
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool00`000000oooo00000003
0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool0
30000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000X0oooo00D00000
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo
000000050?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000D0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`00
00000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool00000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool0
40000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`050000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooEP3oool01@000000oooo0000003o
ool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000000:0?ooo`030000003o
ool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool00`000000oooo000000050?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000D0oooo00D000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`060000003oool0oooo0000003o
ool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00/000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?oo
o`000000oooo000000060?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`000000203oool00`000000oooo000000030?ooo`0:0000003oool0oooo0000
003oool000000?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool040000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool04P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool01`000000oooo0?ooo`3oool000000?ooo`0000001`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?oooeH0oooo00<000000?ooo`0000000`3oool00`000000oooo000000050?oo
o`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000001@3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo00000006
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00001@3oool01@000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001`3oool01@00
0000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`00
0000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000002@3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool0000000D0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000040?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000
003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
10000000oooo0?ooo`0000050?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000
oooo0?ooo`030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooF03o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000001`3oool010000000oooo0?ooo`0000030?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`00
0000oooo000000030?ooo`030000003oool0oooo00@0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo00000005
0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0000003oool0000000@0
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`0B0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`03
0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
00<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?oooe`0oooo00<000000?ooo`000000303oool01@000000oooo
0000003oool0000000`0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000080?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
000000040?ooo`030000003oool0oooo00<0oooo00L000000?ooo`000000oooo0000003oool00000
00H0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000`3oool01@000000oooo0000003oool0000000@0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`00
0000oooo000000050?ooo`080000003oool0oooo0000003oool000000?ooo`0000070?ooo`030000
003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo000000040?ooo`0?0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000D0oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooomL0?ooo`070000003oool000000?ooo`000000oooo0000000:0?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000303oool00`00
0000oooo0?ooo`030?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`00
0000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00P0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool03P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool0
0`000000oooo0?ooo`040?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000060?ooo`050000
003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`0000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo
0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomN0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool03@000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000
003oool0000000H0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00L000000?ooo`000000oooo0000
003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`050000003oool000000?ooo`0000001@3oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000001P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?oo
o`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00050?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`050000003oool00000
0?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`000000103o
ool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooHP3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`050000003oool000000?ooo`0000001P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000001P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0oooo0?oo
o`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000001@3oool0
0`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000<0oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`030000003oool0000000<0oooo018000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`050000003oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<0
00000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0
000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
of80oooo00<000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000001@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00D000000?ooo`000000oooo000000050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`0000001@3oool00`000000oooo000000030?oo
o`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000060?ooo`030000003oool0000000D0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooHP3oool00`00
0000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00`3oool01P00
0000oooo0?ooo`000000oooo000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool0
3@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`0000001@3oool00`000000oooo0000000:0?ooo`070000003oool0oooo0?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool0
0`000000oooo000000050?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo018000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`07
0000003oool000000?ooo`000000oooo000000050?ooo`040000003oool0oooo000000D0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0000000<0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool000000?ooo`0000001`3oool00`000000
oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000P0oooo00D000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooI03oool01P000000oooo0?ooo`000000oooo000000<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000080?ooo`050000
003oool000000?ooo`0000002P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00@0oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0000
00040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00060?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000
003oool000000?ooo`0000030?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000001`3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooofT0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0000000P0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000050?ooo`070000003oool0oooo0?ooo`00
0000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo00000008
0?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01@000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`080000003oool0oooo0000003oool000000?ooo`0000050?ooo`050000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
00<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?oo
o`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooJ@3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`000000203oool00`000000oooo000000050?ooo`060000003oool0oooo0000003oool00000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0000003oool0000000L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000030?ooo`080000003o
ool0oooo0000003oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000
003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?oo
o`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00<000000?ooo`000000103oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo0080oooo00d000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool01@3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00/000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo
000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooJ@3oool00`000000oooo0?oo
o`050?ooo`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo000000040?ooo`030000003oool0000000D0oooo00D000000?oo
o`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?oo
o`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?oo
o`030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000050?ooo`030000003oool0000000H0oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000000`3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooK@3oool01`000000oooo0000003oool000000?ooo`000000103oool0
0`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000030?ooo`030000003oool0000000H0oooo00<000000?ooo`0000000`3oool0
1@000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000070?ooo`03
0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000050?ooo`03
0000003oool0oooo0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3o
ool010000000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000040?oo
o`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000H0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003o
ool0000000P0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`040000003oool0oooo000000<0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooom_0?ooo`030000003oool0000000<0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo000000080?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool000000?oo
o`0000001@3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`000000103oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000
003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?oo
o`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
10000000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool000000?ooo`000000103o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooom]0?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000090?oo
o`030000003oool0oooo00@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`050000003oool0
00000?ooo`0000000`3oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`000000
oooo000000060?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000030?oo
o`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000030?ooo`040000003o
ool0oooo000000T0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001@3oool0
1@000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`03
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`050000003oool0oooo0?ooo`0000001`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooog40oooo00<000000?ooo`3oool01P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000H0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00X0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000001@3oool020000000oooo0?ooo`000000oooo0000003oool00000
0`3oool01@000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000
oooo000000030?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`000000oooo00000003
0?ooo`080000003oool0oooo0000003oool000000?ooo`0000090?ooo`040000003oool0oooo0000
00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000L0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool01@000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo
0000003oool000001@3oool010000000oooo0?ooo`0000030?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo000000040?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000<0oooo
00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000
003oool0000000H0oooo00<000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooog40oooo00<000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000001P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000003
0?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000`0oooo00D000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000
003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000001@3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000060?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`030000003oool00000
00<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`070000003oool00000
0?ooo`000000oooo000000080?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo
000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00P00000
0?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000`3oool03P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000001P3oool00`00
0000oooo000000050?ooo`050000003oool0oooo0?ooo`0000000P3oool03`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00000`3oool01`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003o
ool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomc0?ooo`030000003oool0
oooo00P0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000P0oooo00<000000?ooo`0000001`3oool00`000000oooo000000040?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool000000080oooo00<000000?ooo`000000
1`3oool01@000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool01@000000
oooo0?ooo`3oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`0000000`3oool03P00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`0<0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool00`000000oooo
000000060?ooo`030000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oome0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool00000
0?ooo`000000203oool01`000000oooo0000003oool000000?ooo`0000000`3oool03P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000001P3oool01`000000
oooo0000003oool000000?ooo`0000001@3oool010000000oooo0?ooo`0000050?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00`3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000005
0?ooo`030000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000005
0?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo000000060?ooo`050000003o
ool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`030000003oool0000000<0oooo018000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo
00D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000050?ooo`050000003oool000000?ooo`000000103oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo
0000003oool0000000<0oooo00@000000?ooo`3oool000001@3oool01`000000oooo0000003oool0
00000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooomh0?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000001@3oool01@000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`000000203oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo
0?ooo`0000030?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000040?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0
000000D0oooo00D000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo00000005
0?ooo`050000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000L0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomn0?ooo`050000003oool000000?ooo`000000
103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000001`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000D0oooo00L000000?ooo`00
0000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000060?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`00
00030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`030000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000203oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001`3oool00080oooo10000006
0?ooo`8000001`3oool4000000l0oooo00<000000?ooo`3oool0o`3ooooo0?ooog`0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001@3o
ool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?oo
o`030000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<0
00000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000
oooo000000070?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`030?ooo`800000
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
o`3ooooo0?ooogh0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3o
ool00`000000oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo
0000003oool0000000P0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool00000
00<0oooo00@000000?ooo`3oool000001`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
1P3oool00`000000oooo0?ooo`0:0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000
oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000001`3oool00`000000oooo0?ooo`040?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo000000060?ooo`070000003oool0
oooo0?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`3oool01@3oool01@00
0000oooo0000003oool000000080oooo00<000000?ooo`0000001`3oool01@000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo00000008
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`0000<0oooo0000003oool00`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`3o0?ooool0ooooP03oool00`000000oooo0?ooo`040?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
00030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00L000000?ooo`3oool0oooo0000003oool00000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000D0oooo00L00000
0?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo
000000060?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000050?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool00000
00L0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000080?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
00@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool000030?ooo`00
0000oooo00<0oooo00<000000?ooo`3oool02`3oool2000000<0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`3o0?ooool0ooooOP3oool01@000000oooo0000003oool0000000P0oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000H0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003o
ool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`0;0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo00000005
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo00000007
0?ooo`030000003oool0000000@0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00001P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`3oool01@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000060?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000070?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool00000008000003`3oool700000?l0ooooo`3ooon30?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool01@000000oooo0000003oool0000000X0oooo00L000000?ooo`3oool0oooo0000003oool00000
00<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000070?ooo`030000003oool0000000@0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000D0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`000000
0`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo00000007
0?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0o`3ooooo0?ooohd0oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000080?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`09
0?ooo`030000003oool000000080oooo00<000000?ooo`0000001@3oool01@000000oooo0000003o
ool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo000000080?ooo`050000003oool000000?ooo`0000001P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00l000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000<0oooo00X000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000`3oool00`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000080?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?oo
o`0000001`3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooo`3ooon;0?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool000000?ooo`0000001@3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0000000H0oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`0000001@3o
ool01@000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool00000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001`3o
ool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01`000000oooo
0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000203o
ool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`000000103oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo000000050?ooo`07
0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool00000
00D0oooo00<000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo
00D0oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`3o0?ooool0ooooQ`3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000050?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo
000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool0000000X0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000
oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool00`000000oooo000000050?ooo`070000003oool0oooo0?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000000`3oool01@000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000P0
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00d000000?oo
o`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000080?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000001`3o
ool00080oooo1000000A0?ooo`<000003P3oool00`000000oooo0?ooo`3o0?ooool0ooooQ`3oool0
1@000000oooo0?ooo`3oool0000000T0oooo00@000000?ooo`3oool000000`3oool01@000000oooo
0000003oool0000000D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000050?oo
o`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo000000040?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003o
ool0oooo00<0oooo00D000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000060?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo000000030?ooo`030000003oool0000000D0oooo
00<000000?ooo`3oool00P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool01P00
0000oooo0?ooo`000000oooo000000L0oooo00D000000?ooo`000000oooo000000040?ooo`030000
003oool0000000D0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000080?ooo`030000003oool0oooo00/0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooon90?ooo`030000003oool0000000`0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003o
ool000000`3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00d000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`000000203oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000<0
oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000040?ooo`050000003oool000000?ooo`0000002P3oool01@000000oooo
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo
00D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooh/0oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000000:0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000X0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000050?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000`3oool00`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo
000000070?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
000000060?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0000000H0oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooS@3oool00`000000oooo0?ooo`080?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo000000080?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000`3oool04P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0203o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo
000000<0oooo00D000000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
1@3oool010000000oooo0?ooo`0000030?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000H0oooo
00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooonE0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`04
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo0?ooo`030?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`030000003o
ool0000000D0oooo00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00001@3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`000000103oool02`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo00@0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool000000?ooo`00
00001P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`00
00001@3oool00`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool0
1`000000oooo0000003oool000000?ooo`0000001P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo0000
00030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool00000
00<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool00`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooonA0?ooo`050000003oool000000?ooo`0000002P3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`000000103oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01`000000
oooo0?ooo`3oool000000?ooo`0000002P3oool01@000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`030000003oool0oooo00<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000050?ooo`030000003o
ool0000000P0oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
00000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0oooo
00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?oooiD0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`050000003oool0
00000?ooo`000000103oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<0
00000?ooo`000000303oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`3oool0
oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00<0
00000?ooo`3oool01`3oool01@000000oooo0000003oool000000080oooo00d000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000080?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`000000
oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooonC0?ooo`030000003oool0oooo00@0oooo00d000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo
0000003oool0000000H0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`000000203oool01`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000050?ooo`03
0000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo0180
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0000
00060?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooU@3oool00`000000oooo0?ooo`020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool0
1`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000D0
oooo00<000000?ooo`000000203oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0000000D0oooo00D000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000P0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000203oool02`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000
003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo010000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool00`00
0000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooW03oool00`000000
oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool01@000000
oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo000000030?oo
o`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000203oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo
00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool02@00
0000oooo0000003oool000000?ooo`000000oooo0000000:0?ooo`050000003oool000000?ooo`00
00001P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`00
0000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000D0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool02000
0000oooo0?ooo`000000oooo0000003oool000000`3oool01@000000oooo0000003oool0000000@0
oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000D0oooo00D000000?ooo`000000oooo000000060?ooo`0=0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooiP0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo00000003
0?ooo`060000003oool0oooo0000003oool000000`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0000
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`000000103oool01@000000oooo0000003oool0000000D0oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000030?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`0000001`3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00D000000?ooo`000000oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0oooo0?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0
oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000001`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooi`0oooo00/000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000H0oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000001@3oool01`000000oooo
0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
000000060?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`050000003oool000000?ooo`0000001P3o
ool01`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`050?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo
000000030?ooo`060000003oool0oooo0000003oool000001@3oool01@000000oooo0000003oool0
00000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
1P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`0000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
W03oool00`000000oooo0?ooo`050?ooo`030000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000D0oooo00<000000?ooo`3oool0103oool03`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000050?oo
o`080000003oool0oooo0000003oool000000?ooo`0000070?ooo`030000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo0000000<0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool00P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo00@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080
oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooWP3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000H0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000P0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003o
ool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`3oool00`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000H0oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo0000
003oool000000?ooo`000000oooo000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oonP0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000030?ooo`080000003oool0oooo0000003oool00000
0?ooo`0000030?ooo`030000003oool0000000H0oooo00<000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000X0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0
000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool00`000000
oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo00/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooonR0?ooo`05
0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0>0?ooo`050000003oool000000?ooo`0000000`3o
ool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`050000003oool00000
0?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L00000
0?ooo`000000oooo0000003oool0000000L0oooo010000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool00000203oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`080000003oool0oooo0000003oool000000?ooo`0000050?ooo`050000003oool000000?ooo`00
00000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
00001P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?oooj80oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000`3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00002P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00L000000?ooo`000000oooo0000003oool0000000P0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003o
ool0000000@0oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool00`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0000000>0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0000000`0oooo
00<000000?ooo`000000203oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000T0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooonY0?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?oo
o`050000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`000000203oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo000000050?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
oooo0?ooo`000000oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool01@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool00`00
0000oooo000000060?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000050?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`00000;0?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooYP3oool030000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000`3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3o
ool01@3oool01@000000oooo0?ooo`3oool0000000@0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
00030?ooo`050000003oool000000?ooo`0000001P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool0103oool01`000000oooo0000003oool000000?ooo`000000203oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`0000050?ooo`040000003oool0oooo000000<0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool01P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool040000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000004
0?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool03P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool01P000000oooo0?oo
o`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooojT0
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000001@3oool0
1@000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000H0
oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000001@3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000001P3oool00`000000oooo000000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000001`3oool00`000000oooo0000
00020?ooo`030000003oool0000000L0oooo00<000000?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool01@000000oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?oooj/0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`060?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
000000040?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00D000000?ooo`000000
oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00D000000?ooo`3oool0oooo0000000:0?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000D0oooo00@000000?ooo`3oool000000`3oool02`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool00P3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000001`3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooojd0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`060?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo000000030?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00d00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00/00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000003oool00000
0?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000D0oooo00<000000?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`050?ooo`03
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooojl0oooo00D000000?ooo`3oool0oooo000000040?ooo`05
0000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000103o
ool01@000000oooo0?ooo`3oool0000000L0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`070000003oool000000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool01@3oool00`000000oooo000000060?ooo`070000003oool0
oooo0?ooo`000000oooo000000050?ooo`030000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000002P3oool01@000000oooo0000003oool0
000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0
000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooonc0?ooo`03
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000080?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`060000003oool0oooo
0000003oool000001@3oool00`000000oooo0000000:0?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000050?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000L0oooo00D000000?ooo`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000050?ooo`030000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool0
00000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000P0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0
00000080oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ok40oooo00<000000?ooo`0000003P3oool01@000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000080?ooo`05
0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000D0oooo00<00000
0?ooo`3oool00P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?oo
o`040000003oool0oooo000000L0oooo00D000000?ooo`000000oooo000000040?ooo`0=0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`05
0?ooo`050000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oook40oooo
00D000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool01@00
0000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo
00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo000000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo00000004
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo010000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
0`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`0000001P3oool00`000000oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool0
0`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0
oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`030000003oool0000000D0oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo
0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool00000
0?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0oooo/`3oool00`000000oooo000000040?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool0000000H0oooo00<000000?ooo`0000000`3oool01@000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo000000020?ooo`030000
003oool0000000D0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?oo
o`000000oooo000000050?ooo`030000003oool0000000@0oooo00<000000?ooo`0000002@3oool0
2P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo
0080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool00P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000001@3oool00`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`000000203oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`050000003oool000000?ooo`0000001`3oool002P0oooo1@00003o0?ooool0oooo/`3oool01000
0000oooo0?ooo`0000070?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000080?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo00@000000?oo
o`3oool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000060?ooo`05
0000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003oool00000
00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool00000
00<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000060?ooo`030000003oool0000000D0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000D0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0oooo_P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
1P3oool01@000000oooo0000003oool0000000`0oooo00<000000?ooo`0000000`3oool00`000000
oooo0000000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00@000000?ooo`3o
ool000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000080?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000H0oooo00<000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?oookh0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000P0oooo00L000000?ooo`3oool0oooo0000003oool0000000L0
oooo00<000000?ooo`3oool00P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00D000000?oo
o`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000080?ooo`050000003oool0oooo0?oo
o`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`030000003oool000000080
oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3oooo00?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`0?0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool00`00
0000oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo000000070?ooo`050000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo00@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000D0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`080000
003oool0oooo0000003oool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000060?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0
000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooonl0?ooo`070000003oool0oooo
0?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0oooo00<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<00000
0?ooo`0000001`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooonn0?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000070?ooo`050000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo
000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
000000070?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool0
oooo0?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool02P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`050000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool030000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000<0oooo00X000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000`3oool01@000000oooo0000003oool000000080oooo00/00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000060?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo
000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`0?0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo`03oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
00P0oooo00<000000?ooo`0000000`3oool00`000000oooo000000060?ooo`050000003oool00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo000000030?ooo`05
0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000H0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo00000080oooo00D000000?ooo`000000oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo00H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo00000003
0?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00<00000
0?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0oooo`03oool00`000000oooo000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000D0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`070?ooo`050000
003oool000000?ooo`000000103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`050000003oool00000
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000D0oooo00D000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo
000000070?ooo`040000003oool0oooo000000<0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000030?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo00000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooa03oool00`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`030000003o
ool0oooo0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000D0oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo00@000000?ooo`3o
ool000000`3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`3oool0oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo0000
00040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3oooo60?ooo`0>0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000060?ooo`030000003oool0oooo00<0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool01`000000oooo0000
003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00<00000
0?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000P0oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`080000003oool0
oooo0000003oool000000?ooo`0000050?ooo`050000003oool000000?ooo`0000000P3oool00`00
0000oooo000000050?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`00
0000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?oo
o`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
0`000000oooo000000030?ooo`030000003oool0000000@0oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000
003oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000001P3oool01@000000oooo
0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3oooo60?ooo`080000
003oool0oooo0000003oool000000?ooo`0000050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00L000000?ooo`3oool0oooo
0000003oool0000000P0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`050000003oool000000?ooo`0000000P3o
ool00`000000oooo000000050?ooo`030000003oool0000000H0oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00D0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
00<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3oooo=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000P3oool03@000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000L0oooo00<000000?ooo`3oool0103oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`000000
203oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
0`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`3oool0
oooo0000003oool0000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo000000070?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool020000000
oooo0?ooo`000000oooo0000003oool000000`3oool01`000000oooo0000003oool000000?ooo`00
0000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?oool/0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
2`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0000000H0oooo00L000000?ooo`3oool0oooo0000003oool0000000L0
oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000103o
ool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000001@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooob`3oool0
1@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000303oool01`000000oooo0?oo
o`3oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000002P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`000007
0?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0000000H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000001@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`0000001@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000060?ooo`030000003o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00001`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`050000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00050?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000001`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooll0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool0
0`000000oooo000000030?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0000003oool000000180oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000001@3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000`0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000P0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooood@3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000060?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`070000003o
ool0oooo0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000D0oooo
00D000000?ooo`3oool0oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooood@3oool00`000000oooo000000030?ooo`040000003oool0
oooo000000D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000002P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`0000001P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000103oool00`00
0000oooo000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003o
ool000001@3oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0000
00030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`0000050?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooomD0oooo00<00000
0?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo
000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool00000
0`3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000203oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooC0?ooo`050000003oool00000
0?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`0000001P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00L00000
0?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool01@000000oooo
0000003oool0000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000060?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo
0000003oool000001@3oool00`000000oooo000000040?ooo`030000003oool0000000L0oooo0180
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo000000060?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000050?ooo`0B0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooom`0oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000002P3oool0
0`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00L000000?ooo`000000oooo0000
003oool0000000H0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?oo
o`3oool0oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000@0oooo00<000000?oo
o`0000001@3oool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`000000103oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooG
0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool020000000oooo
0?ooo`000000oooo0000003oool000000`3oool01@000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`000000203oool01`000000oooo0000003oool0
00000?ooo`000000203oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000060?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`0:0000003oool0
oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0oooofP3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo00000008
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`00
00001@3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0000003o
ool0000000H0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo0000000<0?ooo`050000003oool000000?ooo`00
00001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0000000H0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooT0?ooo`030000003oool0
000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0
000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000080?oo
o`030000003oool0000000D0oooo00@000000?ooo`3oool000001@3oool00`000000oooo00000003
0?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000001@3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000040?ooo`050000003oool000000?ooo`0000002@3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooom`0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000D0oooo00D000000?ooo`000000oooo00000006
0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`0000001P3oool01`000000oooo0000003o
ool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`00
0000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000203oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000203oool00`000000oooo000000030?ooo`070000003o
ool0oooo0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool03@000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooN0?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00D000000?ooo`000000oooo0000000:0?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000050?ooo`030000003oool000000080oooo00<0
00000?ooo`0000001`3oool01@000000oooo0000003oool0000000H0oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000@0oooo00<000000?ooo`0000000`3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000H0
oooo00D000000?ooo`000000oooo000000090?ooo`030000003oool0oooo00@0oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool0000000`0oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00<000000?ooo`3oool01@3oool01@000000oooo0000003oool0000000@0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooP
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00D000000?ooo`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00D000000?ooo`00
0000oooo0000000:0?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool0
1@000000oooo0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool00P3oool03@000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`000000
1@3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooT0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`03
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000X0oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`000000103oool03@000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`090?ooo`04
0000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00L0
00000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooV0?ooo`060000003oool0oooo0000003oool000001@3oool00`000000oooo000000060?oo
o`050000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`0;0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo000000070?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool01@000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000
003oool000000080oooo00<000000?ooo`3oool01@3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooT0?ooo`030000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000T0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool01@000000oooo0000003o
ool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000005
0?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000040?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000005
0?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooonH0oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00L000000?ooo`3oool0oooo0000003oool00000
00<0oooo00<000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool01@000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooj@3oool01`000000oooo0000003oool000000?ooo`0000001@3o
ool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo000000050?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3o
ool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000001@3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000060?oo
o`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<0
00000?ooo`0000000`3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool0
00001@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
k@3oool01@000000oooo0000003oool0000000P0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`030?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?oo
o`050000003oool0oooo0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
000000P0oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000001P3oool00`000000oooo000000050?oo
o`030000003oool0000000X0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool01@000000oooo0?ooo`3oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000T0oooo000X0?ooo`D00000o`3o
oooo0?ooond0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000002P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000002P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo00000003
0?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool000000`3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0000003oool0000000P0oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?oo
o`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
3`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`0B0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooond0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00P000000?oo
o`3oool000000?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool00000
00@0oooo00D000000?ooo`3oool0oooo000000050?ooo`060000003oool0oooo0000003oool00000
1@3oool00`000000oooo0?ooo`080?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool01@000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`050000003oool000000?ooo`0000001`3oool00`000000oooo000000040?oo
o`050000003oool000000?ooo`0000002P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`000000
2`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooonl0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo0000000:0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0000000H0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00D000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000H0oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool0000000H0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000T0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooc0?ooo`050000003oool000000?ooo`00
00001P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000090?ooo`060000003oool0oooo0000003oool000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool01`000000oooo0000003oool000000?ooo`000000
1`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000020?ooo`030000003oool0000000T0oooo00H000000?ooo`3oool000000?ooo`00
00050?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000080?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool0
0`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooool`3oool00`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`00
00000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00003P3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01`00
0000oooo0?ooo`3oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`00
00001@3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooom@3oool00`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0000000<0oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@00
0000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0000000<0oooo00<000000?oo
o`0000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000050?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooonP3oool01@000000oooo0000
003oool0000000T0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000001`3oool00`000000
oooo0?ooo`080?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000001@3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`000000
1@3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`000000503oool00`000000oooo0?ooo`040?ooo`070000003oool000000?ooo`000000
oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0000003oool0000000L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo00X000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooooL0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00001P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000H0oooo
00D000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000060?ooo`030000003oool0000000<0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`000000203oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000002P3oool03@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo`40oooo
00<000000?ooo`3oool0203oool00`000000oooo000000050?ooo`050000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo00000002
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000001P3oool00`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000001P3oool01`000000oooo0000003o
ool000000?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`00
0000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool0000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool00`00
0000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo03oool02@000000
oooo0000003oool000000?ooo`000000oooo000000060?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0
000000@0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
oooo0?ooo`000000oooo0000000:0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01@000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
0000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`030000003oool0000000D0oooo00L000000?ooo`000000oooo0000003oool0000000P0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooo`0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000080?ooo`070000003oool0oooo0?ooo`000000
oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000080?oo
o`030000003oool0000000D0oooo00<000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000D0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000L0oooo00<0
00000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool000000?ooo`0000001`3oool00`000000oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`030000003oool0000000L0oooo00<000000?ooo`000000103oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?oo
o`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooooh0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool02`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000070?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool01P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000004
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0000000X0oooo00D000000?ooo`000000oooo000000070?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool000000080oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo000000050?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000203oool02@000000oooo0000003oool000000?ooo`000000oooo00000006
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0oooo0`3oool00`000000oooo000000060?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3o
ool01`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3o
ool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`05
0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool30?ooo`050000003o
ool000000?ooo`000000203oool00`000000oooo000000030?ooo`030000003oool000000080oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool00`000000oooo000000070?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`030000003oool0000000@0oooo00L000000?ooo`000000oooo0000003o
ool0000000D0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000D0
oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000050?ooo`03
0000003oool0oooo00H0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0000000D0oooo00@000000?ooo`3oool000000`3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo00000007
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool70?ooo`030000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000X0oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000001`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000L0oooo00<000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool00000
0080oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000X0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000001`3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo1@3oool00`000000oooo00000004
0?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo
00D000000?ooo`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool01P3oool02`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`0@0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooo`T0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000P0oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool0103oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0oooo00<0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool0
1@000000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000003@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooo3P3oool02`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo00000003
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`0:0000003oool0oooo0000
003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000103oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000060?ooo`050000003oool000000?ooo`0000001@3o
ool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000050?ooo`0:
0000003oool0oooo0000003oool000000?ooo`000000oooo000000P0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000030?ooo`050000003oool000000?ooo`000000103oool00`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`0000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool<0?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool02`000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool0000000P0oooo00/000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000080?ooo`030000003oool0oooo00X0oooo00D000000?ooo`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool00000
0?ooo`0000001@3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?oo
o`050000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000070?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool<0?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000D0oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000050?oo
o`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000001@3oool040000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000060?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000001@3o
ool00`000000oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000000P3o
ool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`060000003oool0oooo
0000003oool000001@3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`050000003oool000000?ooo`000000103oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0?0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooa00oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00H0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000`3oool00`000000oooo000000060?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000001P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?oo
o`3oool0oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000060?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool00`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
00@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooolD0?ooo`050000003oool000000?ooo`000000103oool00`000000oooo00000007
0?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000<0oooo018000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`000000103oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00D000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003oool00000
0?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`000000
0`3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolB0?ooo`030000
003oool0000000X0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000H0
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool03P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000001P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3oool03@000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0000000@0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000001P3oool00`000000oooo000000050?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0oooo5P3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo
00D000000?ooo`3oool0oooo000000060?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000H0oooo
00<000000?ooo`0000001@3oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa@0oooo00<0
00000?ooo`3oool0103oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`3oool0
oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000@0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool01P000000
oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000<0oooo00@000000?ooo`3o
ool000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000
00040?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0oooo5P3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`000003
0?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000T0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaP0oooo00@000000?ooo`3oool0
00002@3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000
00030?ooo`030000003oool0oooo00P0oooo00D000000?ooo`000000oooo000000030?ooo`0:0000
003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`000000103o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000001@3o
ool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3o
ool010000000oooo0?ooo`0000050?ooo`050000003oool000000?ooo`0000000`3oool020000000
oooo0?ooo`000000oooo0000003oool000000`3oool01@000000oooo0000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`3oool02`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo6`3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`0=
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000001@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`050000003oool000000?ooo`0000001P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000001@3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?oo
o`050000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000000:0?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
1P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?oo
o`030000003oool0oooo00<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?oooad0oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00030?ooo`060000003oool0oooo0000003oool000001@3oool01`000000oooo0000003oool00000
0?ooo`000000103oool00`000000oooo000000050?ooo`030000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00L00000
0?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool00000
00@0oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003oool000000?ooo`000000103o
ool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`07
0000003oool000000?ooo`000000oooo000000050?ooo`030000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?oooal0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00001@3oool01@000000oooo0?ooo`3oool0000000@0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000007
0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000030?ooo`040000
003oool0oooo000000D0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00L00000
0?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00L00000
0?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooob<0oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0000000D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0000000<0oooo
00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000001P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00P000000?oo
o`3oool000000?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000040?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`000000
oooo000000030?ooo`050000003oool000000?ooo`000000103oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000
oooo0?ooo`3oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`050?ooo`00:03oool500000?l0ooooo`3ooooo0?oooal0oooo00D000000?ooo`000000
oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`050000003o
ool0oooo0?ooo`000000103oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`000000203oool00`000000oooo000000080?ooo`0;0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0000000<0oooo00X000000?ooo`3oool000000?oo
o`000000oooo0000003oool000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
oooo9@3oool00`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?oo
o`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?oo
o`050?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000001P3oool00`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooolS0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0203oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00L000000?ooo`3oool0
oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00<0
00000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`000000
1P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000
1P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
1P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0oooo:@3oool010000000oooo0?ooo`0000050?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`040000003oool0oooo000000D0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000001P3oool00`000000oooo000000080?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`030?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo00000080oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo
00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000203oool01`000000oooo0000
003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0000000D0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?oo
o`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo9`3oool00`000000
oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?oo
o`030000003oool0oooo00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?oo
o`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`050000003oool0
00000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooob`0oooo00l000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool0
1@000000oooo0000003oool0000000H0oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000X0oooo00<000000?oo
o`0000000`3oool00`000000oooo000000080?ooo`070000003oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00l000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`0B0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3o
ool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooob`0oooo00<000000?ooo`0000000`3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00001P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`00
00050?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool0
1@000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0oooo<03oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000
0P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool04P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000H0oooo
00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000P0oooo00<000000?ooo`3oool01@3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0oooo<03oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool0000000@0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`0000001`3oool00`000000oooo000000040?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000000`3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo
00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000000D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000001`3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo<P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool01P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`00
0000oooo0?ooo`030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000203oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooc80oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000001@3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000D0oooo00D000000?ooo`000000
oooo000000040?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0
oooo00<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`050000003o
ool000000?ooo`000000203oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000003
0?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`060?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooocH0oooo00<000000?ooo`0000001P3oool00`000000oooo000000030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000
oooo0?ooo`3oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
000000P0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`000000
0`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000
oooo000000<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003o
ool0000000P0oooo00D000000?ooo`000000oooo000000070?ooo`030000003oool000000080oooo
00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooocX0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000P0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool00`000000oooo000000070?ooo`030000003oool000000080oooo00<000000?ooo`000000
1@3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
0`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`000000
1P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`050000003oool000000?ooo`0000001`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0oooo>P3oool00`000000oooo0?ooo`020?ooo`0;0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool00000
00D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000070?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000080?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`030?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolh0?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000001@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000040?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000203oool00`000000oooo0000
00030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool01`000000oooo0000
003oool000000?ooo`0000001P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00060?ooo`030000003oool0oooo00<0oooo00L000000?ooo`000000oooo0000003oool0000000@0
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool0
0`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00l000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
>P3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo0080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool00`000000oooo00000007
0?ooo`060000003oool0oooo0000003oool000000`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolm0?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<0
00000?ooo`0000001@3oool00`000000oooo000000020?ooo`0?0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`000000
0`3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000070?oo
o`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0000000<0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000040?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolm0?ooo`030000003oool0000000L0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?oo
o`030000003oool0000000<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
1P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo000000060?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0000000H0oooo00d000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000001`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0oooo?`3oool00`000000oooo000000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000000`3oool0
20000000oooo0?ooo`000000oooo0000003oool000001@3oool00`000000oooo0?ooo`020?ooo`05
0000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`0?
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000D0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool00000
0?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo@@3oool01@00
0000oooo0?ooo`3oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0
oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01@000000oooo0?oo
o`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool000000?oo
o`000000103oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool0
10000000oooo0?ooo`0000030?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooo@`3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo00000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000070?ooo`030000003oool0000000H0oooo00<000000?oo
o`0000001`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0
oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo0000
00070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom50?ooo`030000003oool0
000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`000000
oooo000000050?ooo`040000003oool0oooo000000<0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0000000H0oooo
00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`000000103oool03`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool03`00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`0:0000003o
ool0oooo0000003oool000000?ooo`000000oooo000000L0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooodD0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0
000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`050000003oool0
00000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000T0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooodL0oooo00<000000?ooo`000000103oool0
3@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`030000003oool0oooo00H0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`000000203oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3o
ool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000070?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom>0?ooo`050000003oool0oooo0?ooo`00
00001`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0000000@0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000080?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`000000303oool00`000000oooo000000020?ooo`0?0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0000000<0oooo010000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool0oooo
0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom@
0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`0000001P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000P0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000T0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000
00030?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool01P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooodh0oooo00<000000?ooo`000000
0`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`00
0000oooo0000000:0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000000:0?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01`00
0000oooo0000003oool000000?ooo`000000103oool03@000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`00
00001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooCP3oool03@000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool000001@3oool01`000000
oooo0?ooo`3oool000000?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool010000000oooo0?ooo`0000030?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000P0oooo00D000000?ooo`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000001`3oool00080oooo100000060?ooo`8000001P3oool400000100oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooD03oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool0oooo0?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo00000007
0?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`050000003oool000000?ooo`000000103oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`00
0000oooo000000070?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`030?ooo`80
00001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooDP3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00060?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`0000001@3oool030000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo000000060?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool0000000H0oooo00D000000?ooo`000000oooo000000080?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000070?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3ooomD0?ooo`030000003oool0000000H0oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo000000080?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000P3oool0
3`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool00000103oool00`000000oooo0?ooo`030?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000070?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooomD0?ooo`030000003oool0oooo00<0oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000
oooo000000050?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`050000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0
000000L0oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00/0oooo1000000@0?oo
o`L00000o`3ooooo0?ooool0ooooDP3oool00`000000oooo000000040?ooo`050000003oool00000
0?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00l000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`0<0?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo00`000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool000000080oooo
00<000000?ooo`0000002`3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooF03oool00`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`080?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
4`3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool00`3oool01`000000oooo0000003oool000000?ooo`000000103oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool0
00000`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000001`3oool000030?ooo`000000oooo00<0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0ooooFP3oool030000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`000000103oool03`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`00
00002P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo000000030?ooo`030000003oool0oooo00@0oooo00d000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool01@00
0000oooo0000003oool0000000@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`050000003oool000000?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000T0oooo00000`3oool000000?ooo`030?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?oooel0oooo00D000000?ooo`000000oooo00000003
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`050000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000P0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000060?ooo`050000
003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`0=0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`07
0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000001`3oool00080oooo1000000>0?ooo`@00000403oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooomO0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool01@00
0000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`070000003o
ool0oooo0?ooo`000000oooo000000080?ooo`030000003oool0000000<0oooo00L000000?ooo`00
0000oooo0000003oool0000000H0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01@000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000P0oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooH@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000001@3o
ool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0
oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`030?oo
o`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000003
0?ooo`060000003oool0oooo0000003oool000000`3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooofD0oooo00D000000?ooo`000000oooo000000040?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000203oool00`000000oooo000000070?oo
o`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo000000060?ooo`0?0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooI@3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000P0oooo00D00000
0?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo000000050?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`3oool01@3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooI`3oool00`000000oooo000000040?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool040000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000080?ooo`070000003oool0
oooo0?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo00<000000?ooo`3oool0
0P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`030000003oool0000000P0oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooooJ`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool01@3oool01@000000oooo0000003oool0000000@0oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000P0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000/0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooofL0oooo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000000<0oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool02P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo000000030?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000001@3oool01@00
0000oooo0000003oool0000000@0oooo00<000000?ooo`0000002@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooJ@3oool00`000000oooo0?ooo`020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`000000oooo000000050?ooo`060000003oool0oooo0000003oool000000`3oool01@000000
oooo0?ooo`3oool0000000H0oooo00<000000?ooo`0000001@3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`050000003oool000000?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000
oooo000000D0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooJ`3o
ool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01@000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0
000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo000000030?ooo`030000003oool0000000P0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom[0?ooo`040000003oool0oooo000000<0oooo
00D000000?ooo`3oool0oooo000000060?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
00050?ooo`030000003oool0oooo0080oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00<000000?oo
o`000000103oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`020?ooo`050000003oool000000?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0
oooo00<000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
L03oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
0`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00<000000?ooo`0000001@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooL03oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
00@0oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000203oool02@000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000002P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo
000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool0
00000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oomb0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`3oool00`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`0=0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000
003oool000000?ooo`0000001`3oool010000000oooo0?ooo`0000050?ooo`030000003oool00000
00D0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`000000
1P3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00H000000?ooo`3oool0
00000?ooo`0000070?ooo`030000003oool0000000@0oooo00/000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00002P3oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooog@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<00000
0?ooo`0000001`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0
000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool0000000P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0000000:0?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool0
1@000000oooo0000003oool000000080oooo00<000000?ooo`3oool02`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0ooooN03oool00`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool0000000H0oooo00D000000?ooo`3oool0
oooo000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`000000
203oool00`000000oooo000000060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000
1P3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000203oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000060?ooo`070000003oool0oooo0?ooo`000000
oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomh0?ooo`030000
003oool0oooo0080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
003oool0000000`0oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0000000<0oooo00<00000
0?ooo`000000103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000002@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooNP3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool000000?oo
o`0000001@3oool00`000000oooo0?ooo`040?ooo`070000003oool000000?ooo`000000oooo0000
00050?ooo`060000003oool0oooo0000003oool000001@3oool01@000000oooo0000003oool00000
00@0oooo00<000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000<0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0oooo00<0
00000?ooo`0000001@3oool00`000000oooo000000060?ooo`0?0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooogX0
oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool01@000000oooo
0?ooo`3oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000060?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`08
0000003oool0oooo0000003oool000000?ooo`0000050?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool000000?ooo`000000103oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`030000003oool0000000P0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000001`3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooO@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003o
ool000000?ooo`000000103oool00`000000oooo000000050?ooo`070000003oool0oooo0?ooo`00
0000oooo000000020?ooo`030000003oool0oooo00D0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool000000080oooo
00D000000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0000003oool0000000D0oooo00<000000?ooo`0000001P3oool00`000000oooo00000005
0?ooo`030000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`00
0000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon10?ooo`05
0000003oool000000?ooo`0000001@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0000003oool0000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?oo
o`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000050?ooo`030000003oool0000000<0oooo00h000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000050?ooo`030000003oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooO`3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000
1P3oool00`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000050?ooo`050000003oool0
oooo0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool01@00
0000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000203oool00`000000oooo0?ooo`050?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooon30?ooo`070000003oool000000?ooo`000000oooo
000000060?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo
00X0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000002P3o
ool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000050?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00D000000?ooo`000000
oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon30?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`060000003oool0oooo0000003oool000001@3oool00`000000oooo
000000060?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool00000
0`3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000`0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00L0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooohD0oooo00<000000?ooo`0000000`3o
ool020000000oooo0?ooo`000000oooo0000003oool000000`3oool01@000000oooo0000003oool0
00000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000H0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool0
00000?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01@000000
oooo0?ooo`3oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
1`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooQ`3oool01@000000oooo0000
003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000`0oooo00<000000?oo
o`0000001@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00<0oooo00L000000?ooo`000000oooo0000003oool00000
00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00D0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000060?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon>0?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`00
00001@3oool00`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool0203oool01@000000oooo0000003oool0000000P0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000080?ooo`030000003oool0000000H0oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?oooh/0oooo010000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool00000103oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001@3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo00000008
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`050?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000090?ooo`00:03oool500000?l0ooooo`3o
oooo0?ooohT0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000005
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool01`000000oooo0000003o
ool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000001P3oool00`00
0000oooo000000030?ooo`030000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`00
0000oooo000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000030?ooo`030000
003oool0000000<0oooo00@000000?ooo`3oool000000`3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooohh0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000L0oooo00<000000?ooo`3oool00P3oool03@000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000403oool01P000000oooo0?ooo`000000oooo000000D0
oooo00<000000?ooo`3oool0203oool03@000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000
003oool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
0`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon@0?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000
oooo0?ooo`030?ooo`050000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0000000D0oooo00<000000?ooo`000000
1P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool00`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool010000000
oooo0?ooo`0000030?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooTP3oool01`000000oooo0000003oool000000?ooo`0000001P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool00000
0?ooo`0000050?ooo`030000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000
oooo0000003oool00000203oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`00
0000oooo000000040?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000080?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool000000`3oool0
2`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000
003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooonH0?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000050?ooo`050000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0`3oool010000000oooo0?ooo`0000050?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`3oool0oooo000000090?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooonD0?ooo`050000003oool000000?ooo`000000103oool00`000000oooo
000000030?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo000000030?ooo`05
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`080?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000070?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooonF0?ooo`050000003oool000000?ooo`0000000P3oool0
3@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000080?ooo`050000003oool000000?oo
o`0000001`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0103oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`070000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooonJ0?ooo`060000003oool0oooo0000003oool000001@3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`00
0000203oool00`000000oooo0?ooo`050?ooo`030000003oool0000000@0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo
00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000060?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool02`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooVP3oool01P000000oooo0?ooo`000000oooo000000D0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000002@3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000040?oo
o`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0
000000`0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3ooonM0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool0000000P0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000H0
oooo00D000000?ooo`3oool0oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`050000003oool00000
0?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000080?ooo`07
0000003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooonM0?ooo`050000003oool0oooo0?ooo`0000002@3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00D000000?ooo`3oool0oooo000000080?ooo`0;0000003oool0oooo0?oo
o`000000oooo0000003oool000000?ooo`0000001P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000
003oool000000080oooo00<000000?ooo`3oool01@3oool01`000000oooo0?ooo`3oool000000?oo
o`0000001P3oool00`000000oooo000000050?ooo`030000003oool000000080oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooonO0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000P0oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool01`000000
oooo0?ooo`3oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool00`000000oooo000000050?ooo`030000003oool0
000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00D0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooil0oooo00<000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000000`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00X0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000001`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooZ@3oool00`000000oooo000000080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`000000203o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`05
0000003oool000000?ooo`0000001`3oool02P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`0000030?ooo`030000003oool0000000P0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`050000003oool000000?ooo`0000002@3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooY@3oool01`000000oooo0000003oool000000?ooo`0000001P3oool0
0`000000oooo000000050?ooo`030000003oool0000000@0oooo00<000000?ooo`0000001@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00L000000?ooo`3oool0oooo0000
003oool000000080oooo00<000000?ooo`0000001@3oool01`000000oooo0000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000D0oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooonU0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool0oooo0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000002P3oool01@00
0000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`06
0?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`060000003oool0oooo0000003o
ool000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0
oooo00<000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`0000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonW0?ooo`050000003o
ool000000?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`000000303oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`00
00000P3oool00`000000oooo000000050?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooY`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
000000L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003o
ool0000000@0oooo00<000000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000H0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooZ`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00L000000?ooo`000000
oooo0000003oool0000000@0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`000000
103oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?oooj/0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`03
0000003oool0000000D0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0000003oool0
000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo000000060?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001@3oool01`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`09
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon^0?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`0000002@3oool00`000000oooo
0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000X0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000070?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000030?oo
o`030000003oool0oooo0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
1`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo/P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000060?ooo`030000003oool0000000D0oooo00<000000?oo
o`0000001P3oool00`000000oooo000000030?ooo`030000003oool0000000P0oooo00<000000?oo
o`3oool01`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0000000H0oooo00d00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oook80oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo0000000:0?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool0000000H0oooo00<000000?ooo`0000001@3oool01`000000oooo0000003oool000000?ooo`00
0000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo00000009
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonb0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000050?ooo`050000003oool00000
0?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000000`3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
0P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`030000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?oook@0oooo00D000000?ooo`000000oooo000000030?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool01@3oool020000000oooo0?ooo`000000oooo
0000003oool000000`3oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`000000
1@3oool00`000000oooo000000080?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`070000003o
ool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooonh0?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo0000000>0?ooo`03
0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool00000
00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`000000103oool01@000000oooo0000003oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool01@3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo^03oool01@00
0000oooo0?ooo`3oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000H0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`0000001`3oool00`000000oooo000000060?ooo`070000003o
ool0oooo0?ooo`000000oooo000000060?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0=0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`00
00001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo^03oool00`000000oooo
000000060?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`000000103oool03@000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oookl0oooo00<000000?ooo`00
00001`3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo
0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0oooo_`3oool01@000000oooo0000003oool0000000D0oooo00<000000?oo
o`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0000000P0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`060?ooo`070000003oool0oooo0?ooo`000000oooo0000
00050?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000001@3oool02P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000
1P3oool00`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oono0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0000000L0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`030000
003oool0000000H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooono0?ooo`090000003oool000000?ooo`000000
oooo0000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000@0oooo00D0
00000?ooo`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00L0
00000?ooo`3oool0oooo0000003oool0000000L0oooo000X0?ooo`D00000o`3ooooo0?ooool0oooo
a@3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`000000303oool01`000000oooo0000003oool000000?ooo`0000001P3oool01@000000
oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool0
00000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo``3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`0000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3o
ool01`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooa@3oool00`00
0000oooo0?ooo`030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`07
0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000T0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?oool/0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00d000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000
00070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo90?ooo`030000003oool0
000000h0oooo00<000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000050?ooo`060000003oool0oooo0000003oool000001`3oool00`000000oooo00000002
0?ooo`030000003oool0000000L0oooo00D000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003o
ool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooocP3o
ool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool00000
0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000H0oooo00D00000
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
oooocP3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000H0oooo
00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000001@3oool02P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3oooo>0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
00000`3oool01@000000oooo0?ooo`3oool0000000X0oooo00D000000?ooo`3oool0oooo00000005
0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000001@3oool0
2P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000070?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3oooo@0?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool01@00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo00<000000?ooo`3o
ool00P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooooB0?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103o
ool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooH
0?ooo`050000003oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool0103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000<0oooo
00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo0000
00080?ooo`030000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooom@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000040?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?oo
o`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooomX0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000D0
oooo00<000000?ooo`3oool0103oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00060?ooo`050000003oool0oooo0?ooo`0000002@3oool01P000000oooo0?ooo`000000oooo0000
00L0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooomX0oooo00<000000?ooo`3o
ool00P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`00
0000103oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooooJ0?ooo`030000003oool000000080oooo00<000000?ooo`0000001`3oool00`000000oooo
0?ooo`0:0?ooo`050000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0?0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo
000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooL0?ooo`030000003o
ool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000001P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool00`3oool02P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo
0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooO0?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000X0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003o
ool0oooo0000003oool000000?ooo`000000oooo000000L0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooon40oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000003P3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000005
0?ooo`030000003oool0oooo0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooog`3oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo
000000L0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`070000003oool0
oooo0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooS0?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooonD0oooo00D000000?ooo`3oool0oooo000000030?oo
o`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000P0oooo00D000000?ooo`3oool0oooo000000060?ooo`0;0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooonT0oooo00<00000
0?ooo`3oool0103oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo
000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooooi`3oool00`000000oooo0000000:0?ooo`030000003oool0000000D0oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
ooooj@3oool00`000000oooo000000040?ooo`030000003oool0000000L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooonT0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00D0
00000?ooo`000000oooo000000060?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000001`3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooj`3oool00`000000oooo000000020?ooo`07
0000003oool0oooo0?ooo`000000oooo0000000:0?ooo`050000003oool000000?ooo`0000000`3o
ool01@000000oooo0000003oool0000000P0oooo00<000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooom03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000P0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo0?ooo`090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooob0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool00000
00D0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000090?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3oooo`0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`000000203oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0oooom03oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool0203oool00`000000oooo000000080?ooo`0=0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooh0?ooo`050000003o
ool000000?ooo`000000203oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`D00000
o`3ooooo0?ooool0oooom03oool01`000000oooo0000003oool000000?ooo`0000003P3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooon03oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003oool000000?ooo`000000203o
ool01@000000oooo0?ooo`3oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo
0000003oool000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooon03oool0
0`000000oooo000000080?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0
oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0ooooo03oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool20?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool00`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`0000030?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo00D000000?ooo`00
0000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooo`80oooo00<000000?ooo`0000003P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000060?ooo`050000003oool0oooo0?oo
o`0000002@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool40?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`000000103oool01`000000oooo0?ooo`3oool00000
0?ooo`000000203oool01@000000oooo0000003oool0000000T0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooool0oooo103oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000002@3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooo`3oool60?ooo`050000003oool000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
1`000000oooo0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooo`3oool:0?ooo`030000003oool0000000@0oooo00L000000?ooo`000000oooo
0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo
0?ooo`X0oooo00<000000?ooo`0000001P3oool00`000000oooo000000050?ooo`050000003oool0
oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000T0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooool0oooo3P3oool00`000000oooo0?ooo`0:0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo303oool00`000000oooo0?oo
o`040?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool01P000000oooo0?oo
o`000000oooo000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooooo`3ooolA0?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooa40oooo00<000000?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolE0?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo
0000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo
5`3oool01`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolG
0?ooo`030000003oool0oooo00D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003o
ool000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolG0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool00000
00L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo6@3oool01`000000
oooo0000003oool000000?ooo`0000001P3oool00`000000oooo000000070?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooa/0oooo00D000000?ooo`000000oooo00000002
0?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooooo0?oooa/0oooo00<000000?ooo`3oool0103oool01`000000oooo0?oo
o`3oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3ooolM0?ooo`030000003oool000000080oooo00<000000?ooo`0000002`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolT0?ooo`050000003oool0oooo0?ooo`000000
1`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolT0?ooo`050000003o
ool0oooo0?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3o
oolV0?ooo`030000003oool0000000L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooool0oooo<03oool001<0oooo1`00000>0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
ool0oooo:03oool00`000000oooo0?ooo`050?ooo`005P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool001H0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000F0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`005P3oool0
0`000000oooo0?ooo`0?0?ooo`L00000o`3ooooo0?ooool0ooooo`3oool/0?ooo`005P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool001H0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00
oooo000D0?ooo`<000004@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo
000F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3o
ool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooool0oooo<03oool00?l0ooooo`3ooooo0?ooool0ooooF`3oool00?l0ooooo`3o
oooo0?ooool0ooooF`3oool00?l0ooooo`3ooooo0?ooool0ooooF`3oool00?l0ooooo`3ooooo0?oo
ool0ooooF`3oool00?l0ooooo`3ooooo0?ooool0ooooF`3oool00?l0ooooo`3ooooo0?ooool0oooo
F`3oool00?l0ooooo`3ooooo0?ooool0ooooF`3oool00?l0ooooo`3ooooo0?ooool0ooooF`3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 1110.13}, {685.688, 0}} -> {-0.0378501, -0.0553896, \
0.00140806, 0.00238104}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BifuractionDiagram[WildMap[r], \ {r, 0, 1}];\)\)], "Input",
  CellLabel->"In[54]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.0147151 0.629427 [
[.2 .00222 -9 -9 ]
[.2 .00222 9 0 ]
[.4 .00222 -9 -9 ]
[.4 .00222 9 0 ]
[.6 .00222 -9 -9 ]
[.6 .00222 9 0 ]
[.8 .00222 -9 -9 ]
[.8 .00222 9 0 ]
[1 .00222 -3 -9 ]
[1 .00222 3 0 ]
[-0.0125 .1406 -18 -4.5 ]
[-0.0125 .1406 0 4.5 ]
[-0.0125 .26649 -18 -4.5 ]
[-0.0125 .26649 0 4.5 ]
[-0.0125 .39237 -18 -4.5 ]
[-0.0125 .39237 0 4.5 ]
[-0.0125 .51826 -18 -4.5 ]
[-0.0125 .51826 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .01472 m
.2 .02097 L
s
[(0.2)] .2 .00222 0 1 Mshowa
.4 .01472 m
.4 .02097 L
s
[(0.4)] .4 .00222 0 1 Mshowa
.6 .01472 m
.6 .02097 L
s
[(0.6)] .6 .00222 0 1 Mshowa
.8 .01472 m
.8 .02097 L
s
[(0.8)] .8 .00222 0 1 Mshowa
1 .01472 m
1 .02097 L
s
[(1)] 1 .00222 0 1 Mshowa
.125 Mabswid
.05 .01472 m
.05 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.15 .01472 m
.15 .01847 L
s
.25 .01472 m
.25 .01847 L
s
.3 .01472 m
.3 .01847 L
s
.35 .01472 m
.35 .01847 L
s
.45 .01472 m
.45 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.55 .01472 m
.55 .01847 L
s
.65 .01472 m
.65 .01847 L
s
.7 .01472 m
.7 .01847 L
s
.75 .01472 m
.75 .01847 L
s
.85 .01472 m
.85 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.95 .01472 m
.95 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
0 .1406 m
.00625 .1406 L
s
[(0.2)] -0.0125 .1406 1 0 Mshowa
0 .26649 m
.00625 .26649 L
s
[(0.4)] -0.0125 .26649 1 0 Mshowa
0 .39237 m
.00625 .39237 L
s
[(0.6)] -0.0125 .39237 1 0 Mshowa
0 .51826 m
.00625 .51826 L
s
[(0.8)] -0.0125 .51826 1 0 Mshowa
.125 Mabswid
0 .04619 m
.00375 .04619 L
s
0 .07766 m
.00375 .07766 L
s
0 .10913 m
.00375 .10913 L
s
0 .17207 m
.00375 .17207 L
s
0 .20354 m
.00375 .20354 L
s
0 .23501 m
.00375 .23501 L
s
0 .29796 m
.00375 .29796 L
s
0 .32943 m
.00375 .32943 L
s
0 .3609 m
.00375 .3609 L
s
0 .42384 m
.00375 .42384 L
s
0 .45531 m
.00375 .45531 L
s
0 .48679 m
.00375 .48679 L
s
0 .54973 m
.00375 .54973 L
s
0 .5812 m
.00375 .5812 L
s
0 .61267 m
.00375 .61267 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
0 .01472 Mdot
.002 .01472 Mdot
.004 .01472 Mdot
.006 .01472 Mdot
.008 .01472 Mdot
.01 .01472 Mdot
.012 .01472 Mdot
.014 .01472 Mdot
.016 .01472 Mdot
.018 .01472 Mdot
.02 .01472 Mdot
.022 .01472 Mdot
.024 .01472 Mdot
.026 .01472 Mdot
.028 .01472 Mdot
.03 .01472 Mdot
.032 .01472 Mdot
.034 .01472 Mdot
.036 .01472 Mdot
.038 .01472 Mdot
.04 .01472 Mdot
.042 .01472 Mdot
.044 .01472 Mdot
.046 .01472 Mdot
.048 .01472 Mdot
.05 .01472 Mdot
.052 .01472 Mdot
.054 .01472 Mdot
.056 .01472 Mdot
.058 .01472 Mdot
.06 .01472 Mdot
.062 .01472 Mdot
.064 .01472 Mdot
.066 .01472 Mdot
.068 .01472 Mdot
.07 .01472 Mdot
.072 .01472 Mdot
.074 .01472 Mdot
.076 .01472 Mdot
.078 .01472 Mdot
.08 .01472 Mdot
.082 .01472 Mdot
.084 .01472 Mdot
.086 .01472 Mdot
.088 .01472 Mdot
.09 .01472 Mdot
.092 .01472 Mdot
.094 .01472 Mdot
.096 .01472 Mdot
.098 .01472 Mdot
.1 .01472 Mdot
.102 .01472 Mdot
.104 .01472 Mdot
.106 .01472 Mdot
.108 .01472 Mdot
.11 .01472 Mdot
.112 .01472 Mdot
.114 .01472 Mdot
.116 .01472 Mdot
.118 .01472 Mdot
.12 .01472 Mdot
.122 .01472 Mdot
.124 .01472 Mdot
.126 .01472 Mdot
.128 .01472 Mdot
.13 .01472 Mdot
.132 .01472 Mdot
.134 .01472 Mdot
.136 .01472 Mdot
.138 .01472 Mdot
.14 .01472 Mdot
.142 .01472 Mdot
.144 .01472 Mdot
.146 .01472 Mdot
.148 .01472 Mdot
.15 .01472 Mdot
.152 .01472 Mdot
.154 .01472 Mdot
.156 .01472 Mdot
.158 .01472 Mdot
.16 .01472 Mdot
.162 .01472 Mdot
.164 .01472 Mdot
.166 .01472 Mdot
.168 .01472 Mdot
.17 .01472 Mdot
.172 .01472 Mdot
.174 .01472 Mdot
.176 .01472 Mdot
.178 .01472 Mdot
.18 .01472 Mdot
.182 .01472 Mdot
.184 .01819 Mdot
.186 .0215 Mdot
.188 .02364 Mdot
.19 .02534 Mdot
.192 .02678 Mdot
.194 .02806 Mdot
.196 .02922 Mdot
.198 .03027 Mdot
.2 .03126 Mdot
.202 .03217 Mdot
.204 .03303 Mdot
.206 .03385 Mdot
.208 .03462 Mdot
.21 .03536 Mdot
.212 .03607 Mdot
.214 .03674 Mdot
.216 .03739 Mdot
.218 .03802 Mdot
.22 .03862 Mdot
.222 .03921 Mdot
.224 .03977 Mdot
.226 .04032 Mdot
.228 .04085 Mdot
.23 .04137 Mdot
.232 .04187 Mdot
.234 .04236 Mdot
.236 .04284 Mdot
.238 .0433 Mdot
.24 .04376 Mdot
.242 .0442 Mdot
.244 .04463 Mdot
.246 .04506 Mdot
.248 .04547 Mdot
.25 .04588 Mdot
.252 .04628 Mdot
.254 .04667 Mdot
.256 .04705 Mdot
.258 .04742 Mdot
.26 .04779 Mdot
.262 .04815 Mdot
.264 .04851 Mdot
.266 .04885 Mdot
.268 .0492 Mdot
.27 .04953 Mdot
.272 .04987 Mdot
.274 .05019 Mdot
.276 .05051 Mdot
.278 .05083 Mdot
.28 .05114 Mdot
.282 .05145 Mdot
.284 .05175 Mdot
.286 .05205 Mdot
.288 .05234 Mdot
.29 .05263 Mdot
.292 .05291 Mdot
.294 .0532 Mdot
.296 .05347 Mdot
.298 .05375 Mdot
.3 .05402 Mdot
.302 .05429 Mdot
.304 .05455 Mdot
.306 .05481 Mdot
.308 .05507 Mdot
.31 .05532 Mdot
.312 .05557 Mdot
.314 .05582 Mdot
.316 .05607 Mdot
.318 .05631 Mdot
.32 .05655 Mdot
.322 .05679 Mdot
.324 .05702 Mdot
.326 .05726 Mdot
.328 .05749 Mdot
.33 .05771 Mdot
.332 .05794 Mdot
.334 .05816 Mdot
.336 .05838 Mdot
.338 .0586 Mdot
.34 .05882 Mdot
.342 .05903 Mdot
.344 .05925 Mdot
.346 .05946 Mdot
.348 .05967 Mdot
.35 .05987 Mdot
.352 .06008 Mdot
.354 .06028 Mdot
.356 .06048 Mdot
.358 .06068 Mdot
.36 .06088 Mdot
.362 .06108 Mdot
.364 .06127 Mdot
.366 .06146 Mdot
.368 .06165 Mdot
.37 .06184 Mdot
.372 .06203 Mdot
.374 .06222 Mdot
.376 .0624 Mdot
.378 .06259 Mdot
.38 .06277 Mdot
.382 .06295 Mdot
.384 .06313 Mdot
.386 .06331 Mdot
.388 .06349 Mdot
.39 .06366 Mdot
.392 .06384 Mdot
.394 .06401 Mdot
.396 .06418 Mdot
.398 .06436 Mdot
.4 .06453 Mdot
.402 .06469 Mdot
.404 .06486 Mdot
.406 .06503 Mdot
.408 .0652 Mdot
.41 .15807 Mdot
.412 .16046 Mdot
.414 .16205 Mdot
.416 .16334 Mdot
.418 .16445 Mdot
.42 .16545 Mdot
.422 .16636 Mdot
.424 .16721 Mdot
.426 .16801 Mdot
.428 .16876 Mdot
.43 .16947 Mdot
.432 .17016 Mdot
.434 .17081 Mdot
.436 .17144 Mdot
.438 .17206 Mdot
.44 .17265 Mdot
.442 .17323 Mdot
.444 .17379 Mdot
.446 .17433 Mdot
.448 .17487 Mdot
.45 .17539 Mdot
.452 .1759 Mdot
.454 .1764 Mdot
.456 .1769 Mdot
.458 .17738 Mdot
.46 .17786 Mdot
.462 .17833 Mdot
.464 .17879 Mdot
.466 .17925 Mdot
.468 .1797 Mdot
.47 .18014 Mdot
.472 .18059 Mdot
.474 .18102 Mdot
.476 .18145 Mdot
.478 .18188 Mdot
.48 .1823 Mdot
.482 .18272 Mdot
.484 .18314 Mdot
.486 .18355 Mdot
.488 .18396 Mdot
.49 .18437 Mdot
.492 .18477 Mdot
.494 .18518 Mdot
.496 .18558 Mdot
.498 .18598 Mdot
.5 .18638 Mdot
.502 .18677 Mdot
.504 .18717 Mdot
.506 .18756 Mdot
.508 .18796 Mdot
.51 .18835 Mdot
.512 .18874 Mdot
.514 .18914 Mdot
.516 .18953 Mdot
.518 .18992 Mdot
.52 .19032 Mdot
.522 .19071 Mdot
.524 .19111 Mdot
.526 .1915 Mdot
.528 .1919 Mdot
.53 .1923 Mdot
.532 .1927 Mdot
.534 .1931 Mdot
.536 .19351 Mdot
.538 .19392 Mdot
.54 .19433 Mdot
.542 .19474 Mdot
.544 .19516 Mdot
.546 .19558 Mdot
.548 .19601 Mdot
.55 .19644 Mdot
.552 .19688 Mdot
.554 .19733 Mdot
.556 .19778 Mdot
.558 .19824 Mdot
.56 .19871 Mdot
.562 .19918 Mdot
.564 .19967 Mdot
.566 .20018 Mdot
.568 .20069 Mdot
.57 .20122 Mdot
.572 .20177 Mdot
.574 .20234 Mdot
.576 .20294 Mdot
.578 .20357 Mdot
.58 .20423 Mdot
.582 .20494 Mdot
.584 .2057 Mdot
.586 .20655 Mdot
.588 .2075 Mdot
.59 .20864 Mdot
.592 .21016 Mdot
.594 .34592 Mdot
.596 .34816 Mdot
.598 .35146 Mdot
.6 .35804 Mdot
.602 .36475 Mdot
.604 .36815 Mdot
.606 .37046 Mdot
.608 .37226 Mdot
.61 .37376 Mdot
.612 .37505 Mdot
.614 .37621 Mdot
.616 .37725 Mdot
.618 .37821 Mdot
.62 .37909 Mdot
.622 .37992 Mdot
.624 .38069 Mdot
.626 .38143 Mdot
.628 .38212 Mdot
.63 .38279 Mdot
.632 .38342 Mdot
.634 .38403 Mdot
.636 .38157 Mdot
.636 .38719 Mdot
.638 .37893 Mdot
.638 .38973 Mdot
.64 .37716 Mdot
.64 .39139 Mdot
.642 .37573 Mdot
.642 .39272 Mdot
.644 .37448 Mdot
.644 .39386 Mdot
.646 .37335 Mdot
.646 .39487 Mdot
.648 .37232 Mdot
.648 .3958 Mdot
.65 .37135 Mdot
.65 .39665 Mdot
.652 .36751 Mdot
.652 .37443 Mdot
.652 .39584 Mdot
.652 .39856 Mdot
.654 .36537 Mdot
.654 .37639 Mdot
.654 .39548 Mdot
.654 .39974 Mdot
.656 .363 Mdot
.656 .36532 Mdot
.656 .37477 Mdot
.656 .37935 Mdot
.656 .39468 Mdot
.656 .3966 Mdot
.656 .40014 Mdot
.656 .40095 Mdot
.658 .36049 Mdot
.658 .3605 Mdot
.658 .3605 Mdot
.658 .3605 Mdot
.658 .3605 Mdot
.658 .36051 Mdot
.658 .36051 Mdot
.658 .36051 Mdot
.658 .36052 Mdot
.658 .36053 Mdot
.658 .36053 Mdot
.658 .36053 Mdot
.658 .36054 Mdot
.658 .36055 Mdot
.658 .36057 Mdot
.658 .3606 Mdot
.658 .36062 Mdot
.658 .36062 Mdot
.658 .36062 Mdot
.658 .36063 Mdot
.658 .36063 Mdot
.658 .36065 Mdot
.658 .36065 Mdot
.658 .36068 Mdot
.658 .36068 Mdot
.658 .3607 Mdot
.658 .36071 Mdot
.658 .36072 Mdot
.658 .36077 Mdot
.658 .36077 Mdot
.658 .36081 Mdot
.658 .36081 Mdot
.658 .36083 Mdot
.658 .36084 Mdot
.658 .36085 Mdot
.658 .36091 Mdot
.658 .36093 Mdot
.658 .36093 Mdot
.658 .36094 Mdot
.658 .36095 Mdot
.658 .36096 Mdot
.658 .36111 Mdot
.658 .36113 Mdot
.658 .36114 Mdot
.658 .36117 Mdot
.658 .36122 Mdot
.658 .36124 Mdot
.658 .36126 Mdot
.658 .36127 Mdot
.658 .36131 Mdot
.658 .36134 Mdot
.658 .36136 Mdot
.658 .36138 Mdot
.658 .36139 Mdot
.658 .36139 Mdot
.658 .36144 Mdot
.658 .36144 Mdot
.658 .36145 Mdot
.658 .36145 Mdot
.658 .36148 Mdot
.658 .36149 Mdot
.658 .36152 Mdot
.658 .36153 Mdot
.658 .3616 Mdot
.658 .3616 Mdot
.658 .36161 Mdot
.658 .36164 Mdot
.658 .36165 Mdot
.658 .36167 Mdot
.658 .3617 Mdot
.658 .36172 Mdot
.658 .36172 Mdot
.658 .36172 Mdot
.658 .36174 Mdot
.658 .36177 Mdot
.658 .36177 Mdot
.658 .36178 Mdot
.658 .36189 Mdot
.658 .3619 Mdot
.658 .36192 Mdot
.658 .36192 Mdot
.658 .36208 Mdot
.658 .36208 Mdot
.658 .36212 Mdot
.658 .36228 Mdot
.658 .36228 Mdot
.658 .36229 Mdot
.658 .36251 Mdot
.658 .36268 Mdot
.658 .3627 Mdot
.658 .36275 Mdot
.658 .36283 Mdot
.658 .36284 Mdot
.658 .36285 Mdot
.658 .36289 Mdot
.658 .36293 Mdot
.658 .36294 Mdot
.658 .36297 Mdot
.658 .36307 Mdot
.658 .36312 Mdot
.658 .36314 Mdot
.658 .36317 Mdot
.658 .36328 Mdot
.658 .3633 Mdot
.658 .3634 Mdot
.658 .36341 Mdot
.658 .36343 Mdot
.658 .36347 Mdot
.658 .36356 Mdot
.658 .36359 Mdot
.658 .36366 Mdot
.658 .36387 Mdot
.658 .36388 Mdot
.658 .36395 Mdot
.658 .36397 Mdot
.658 .36399 Mdot
.658 .364 Mdot
.658 .36403 Mdot
.658 .36407 Mdot
.658 .3642 Mdot
.658 .36427 Mdot
.658 .36431 Mdot
.658 .36434 Mdot
.658 .36436 Mdot
.658 .36439 Mdot
.658 .36445 Mdot
.658 .36451 Mdot
.658 .36453 Mdot
.658 .36453 Mdot
.658 .36454 Mdot
.658 .36455 Mdot
.658 .36459 Mdot
.658 .36459 Mdot
.658 .36463 Mdot
.658 .36467 Mdot
.658 .36469 Mdot
.658 .36476 Mdot
.658 .3648 Mdot
.658 .36484 Mdot
.658 .3649 Mdot
.658 .36492 Mdot
.658 .36493 Mdot
.658 .36493 Mdot
.658 .3651 Mdot
.658 .36517 Mdot
.658 .36519 Mdot
.658 .3652 Mdot
.658 .36523 Mdot
.658 .36526 Mdot
.658 .36527 Mdot
.658 .36529 Mdot
.658 .36529 Mdot
.658 .36532 Mdot
.658 .36533 Mdot
.658 .36535 Mdot
.658 .36536 Mdot
.658 .36538 Mdot
.658 .36543 Mdot
.658 .36546 Mdot
.658 .36547 Mdot
.658 .36549 Mdot
.658 .3655 Mdot
.658 .3655 Mdot
.658 .3655 Mdot
.658 .36551 Mdot
.658 .36553 Mdot
.658 .36553 Mdot
.658 .3656 Mdot
.658 .36562 Mdot
.658 .3657 Mdot
.658 .3657 Mdot
.658 .36573 Mdot
.658 .36581 Mdot
.658 .36581 Mdot
.658 .36588 Mdot
.658 .36592 Mdot
.658 .366 Mdot
.658 .36601 Mdot
.658 .36604 Mdot
.658 .3661 Mdot
.658 .36612 Mdot
.658 .36612 Mdot
.658 .36614 Mdot
.658 .36618 Mdot
.658 .3662 Mdot
.658 .36621 Mdot
.658 .36622 Mdot
.658 .36628 Mdot
.658 .36633 Mdot
.658 .36635 Mdot
.658 .36638 Mdot
.658 .3664 Mdot
.658 .36643 Mdot
.658 .36656 Mdot
.658 .36656 Mdot
.658 .36657 Mdot
.658 .36659 Mdot
.658 .36664 Mdot
.658 .36666 Mdot
.658 .36671 Mdot
.658 .36677 Mdot
.658 .36677 Mdot
.658 .36679 Mdot
.658 .3668 Mdot
.658 .36682 Mdot
.658 .36688 Mdot
.658 .36691 Mdot
.658 .36697 Mdot
.658 .367 Mdot
.658 .36712 Mdot
.658 .36715 Mdot
.658 .36726 Mdot
.658 .3673 Mdot
.658 .36732 Mdot
.658 .3674 Mdot
.658 .36743 Mdot
.658 .36747 Mdot
.658 .3675 Mdot
.658 .36754 Mdot
.658 .36755 Mdot
.658 .36758 Mdot
.658 .36761 Mdot
.658 .36762 Mdot
.658 .36766 Mdot
.658 .36767 Mdot
.658 .3677 Mdot
.658 .36777 Mdot
.658 .36783 Mdot
.658 .36784 Mdot
.658 .36789 Mdot
.658 .3679 Mdot
.658 .36791 Mdot
.658 .36791 Mdot
.658 .36791 Mdot
.658 .36791 Mdot
.658 .36792 Mdot
.658 .36793 Mdot
.658 .36795 Mdot
.658 .36796 Mdot
.658 .36799 Mdot
.658 .36803 Mdot
.658 .36805 Mdot
.658 .36808 Mdot
.658 .36808 Mdot
.658 .36816 Mdot
.658 .36821 Mdot
.658 .36825 Mdot
.658 .36826 Mdot
.658 .36829 Mdot
.658 .36835 Mdot
.658 .36837 Mdot
.658 .36844 Mdot
.658 .36845 Mdot
.658 .36849 Mdot
.658 .36851 Mdot
.658 .36856 Mdot
.658 .36856 Mdot
.658 .36857 Mdot
.658 .36858 Mdot
.658 .36865 Mdot
.658 .36868 Mdot
.658 .36869 Mdot
.658 .3687 Mdot
.658 .36878 Mdot
.658 .3688 Mdot
.658 .36881 Mdot
.658 .36884 Mdot
.658 .36892 Mdot
.658 .36892 Mdot
.658 .36896 Mdot
.658 .36897 Mdot
.658 .36897 Mdot
.658 .36898 Mdot
.658 .36903 Mdot
.658 .36904 Mdot
.658 .3691 Mdot
.658 .36917 Mdot
.658 .36929 Mdot
.658 .3693 Mdot
.658 .36935 Mdot
.658 .36935 Mdot
.658 .36937 Mdot
.658 .36937 Mdot
.658 .36939 Mdot
.658 .36941 Mdot
.658 .36946 Mdot
.658 .36947 Mdot
.658 .36948 Mdot
.658 .36951 Mdot
.658 .36951 Mdot
.658 .36952 Mdot
.658 .36953 Mdot
.658 .36954 Mdot
.658 .36959 Mdot
.658 .36963 Mdot
.658 .36975 Mdot
.658 .36981 Mdot
.658 .36993 Mdot
.658 .36996 Mdot
.658 .36998 Mdot
.658 .37001 Mdot
.658 .37002 Mdot
.658 .37013 Mdot
.658 .37022 Mdot
.658 .37027 Mdot
.658 .37036 Mdot
.658 .37039 Mdot
.658 .37042 Mdot
.658 .37042 Mdot
.658 .37068 Mdot
.658 .37074 Mdot
.658 .37076 Mdot
.658 .37083 Mdot
.658 .37087 Mdot
.658 .37097 Mdot
.658 .37108 Mdot
.658 .37111 Mdot
.658 .37112 Mdot
.658 .37116 Mdot
.658 .37125 Mdot
.658 .37128 Mdot
.658 .37128 Mdot
.658 .37132 Mdot
.658 .37145 Mdot
.658 .3715 Mdot
.658 .37151 Mdot
.658 .37167 Mdot
.658 .37189 Mdot
.658 .3719 Mdot
.658 .37207 Mdot
.658 .37211 Mdot
.658 .37211 Mdot
.658 .37229 Mdot
.658 .37231 Mdot
.658 .37246 Mdot
.658 .37246 Mdot
.658 .3725 Mdot
.658 .37252 Mdot
.658 .37252 Mdot
.658 .37253 Mdot
.658 .37255 Mdot
.658 .37258 Mdot
.658 .37261 Mdot
.658 .37267 Mdot
.658 .37276 Mdot
.658 .37281 Mdot
.658 .37283 Mdot
.658 .37288 Mdot
.658 .37288 Mdot
.658 .37295 Mdot
.658 .37296 Mdot
.658 .37299 Mdot
.658 .37302 Mdot
.658 .37306 Mdot
.658 .37313 Mdot
.658 .37315 Mdot
.658 .3732 Mdot
.658 .37334 Mdot
.658 .37369 Mdot
.658 .3737 Mdot
.658 .37371 Mdot
.658 .37375 Mdot
.658 .37387 Mdot
.658 .37395 Mdot
.658 .37405 Mdot
.658 .37418 Mdot
.658 .37422 Mdot
.658 .37431 Mdot
.658 .37438 Mdot
.658 .37439 Mdot
.658 .37447 Mdot
.658 .3745 Mdot
.658 .37451 Mdot
.658 .37451 Mdot
.658 .37457 Mdot
.658 .37468 Mdot
.658 .37481 Mdot
.658 .37488 Mdot
.658 .37491 Mdot
.658 .37498 Mdot
.658 .37507 Mdot
.658 .37522 Mdot
.658 .37547 Mdot
.658 .37557 Mdot
.658 .37563 Mdot
.658 .37564 Mdot
.658 .3757 Mdot
.658 .37573 Mdot
.658 .37587 Mdot
.658 .3759 Mdot
.658 .37633 Mdot
.658 .3765 Mdot
.658 .37656 Mdot
.658 .37674 Mdot
.658 .37683 Mdot
.658 .37688 Mdot
.658 .3769 Mdot
.658 .3771 Mdot
.658 .37713 Mdot
.658 .37738 Mdot
.658 .37744 Mdot
.658 .37748 Mdot
.658 .37758 Mdot
.658 .37779 Mdot
.658 .37786 Mdot
.658 .37787 Mdot
.658 .37796 Mdot
.658 .37806 Mdot
.658 .37806 Mdot
.658 .3781 Mdot
.658 .37826 Mdot
.658 .37838 Mdot
.658 .3784 Mdot
.658 .37876 Mdot
.658 .37924 Mdot
.658 .37925 Mdot
.658 .37925 Mdot
.658 .37959 Mdot
.658 .37967 Mdot
.658 .37968 Mdot
.658 .38 Mdot
.658 .38001 Mdot
.658 .38006 Mdot
.658 .38007 Mdot
.658 .38029 Mdot
.658 .38031 Mdot
.658 .38032 Mdot
.658 .38038 Mdot
.658 .38042 Mdot
.658 .38043 Mdot
.658 .38043 Mdot
.658 .38047 Mdot
.658 .38053 Mdot
.658 .38057 Mdot
.658 .3806 Mdot
.658 .38066 Mdot
.658 .38067 Mdot
.658 .38067 Mdot
.658 .38083 Mdot
.658 .38083 Mdot
.658 .3809 Mdot
.658 .38093 Mdot
.658 .38098 Mdot
.658 .38099 Mdot
.658 .381 Mdot
.658 .38101 Mdot
.658 .38111 Mdot
.658 .38111 Mdot
.658 .38112 Mdot
.658 .38117 Mdot
.658 .38121 Mdot
.658 .38128 Mdot
.658 .38137 Mdot
.658 .38139 Mdot
.658 .38142 Mdot
.658 .38146 Mdot
.658 .38157 Mdot
.658 .38162 Mdot
.658 .38164 Mdot
.658 .38169 Mdot
.658 .38199 Mdot
.658 .38203 Mdot
.658 .38205 Mdot
.658 .38205 Mdot
.658 .38207 Mdot
.658 .3821 Mdot
.658 .38222 Mdot
.658 .38224 Mdot
.658 .38226 Mdot
.658 .3823 Mdot
.658 .3823 Mdot
.658 .38238 Mdot
.658 .38238 Mdot
.658 .38249 Mdot
.658 .38252 Mdot
.658 .38253 Mdot
.658 .38257 Mdot
.658 .38258 Mdot
.658 .38262 Mdot
.658 .38263 Mdot
.658 .38268 Mdot
.658 .38268 Mdot
.658 .3827 Mdot
.658 .3827 Mdot
.658 .3827 Mdot
.658 .38273 Mdot
.658 .38279 Mdot
.658 .38284 Mdot
.658 .38286 Mdot
.658 .38287 Mdot
.658 .38287 Mdot
.658 .38288 Mdot
.658 .38289 Mdot
.658 .38291 Mdot
.658 .38291 Mdot
.658 .38292 Mdot
.658 .38293 Mdot
.658 .38293 Mdot
.658 .38294 Mdot
.658 .38294 Mdot
.658 .38295 Mdot
.658 .39356 Mdot
.658 .39357 Mdot
.658 .39357 Mdot
.658 .39357 Mdot
.658 .39357 Mdot
.658 .39357 Mdot
.658 .39358 Mdot
.658 .39358 Mdot
.658 .39359 Mdot
.658 .39359 Mdot
.658 .3936 Mdot
.658 .3936 Mdot
.658 .3936 Mdot
.658 .39361 Mdot
.658 .39364 Mdot
.658 .39366 Mdot
.658 .39368 Mdot
.658 .39368 Mdot
.658 .39368 Mdot
.658 .39369 Mdot
.658 .39369 Mdot
.658 .39371 Mdot
.658 .39371 Mdot
.658 .39373 Mdot
.658 .39373 Mdot
.658 .39376 Mdot
.658 .39376 Mdot
.658 .39377 Mdot
.658 .39382 Mdot
.658 .39382 Mdot
.658 .39386 Mdot
.658 .39386 Mdot
.658 .39388 Mdot
.658 .39389 Mdot
.658 .39389 Mdot
.658 .39395 Mdot
.658 .39397 Mdot
.658 .39397 Mdot
.658 .39397 Mdot
.658 .39398 Mdot
.658 .394 Mdot
.658 .39413 Mdot
.658 .39416 Mdot
.658 .39417 Mdot
.658 .39419 Mdot
.658 .39424 Mdot
.658 .39426 Mdot
.658 .39427 Mdot
.658 .39428 Mdot
.658 .39432 Mdot
.658 .39435 Mdot
.658 .39437 Mdot
.658 .39439 Mdot
.658 .39439 Mdot
.658 .39439 Mdot
.658 .39444 Mdot
.658 .39444 Mdot
.658 .39445 Mdot
.658 .39445 Mdot
.658 .39447 Mdot
.658 .39449 Mdot
.658 .39452 Mdot
.658 .39452 Mdot
.658 .39459 Mdot
.658 .39459 Mdot
.658 .39459 Mdot
.658 .39462 Mdot
.658 .39463 Mdot
.658 .39465 Mdot
.658 .39468 Mdot
.658 .39469 Mdot
.658 .39469 Mdot
.658 .3947 Mdot
.658 .39472 Mdot
.658 .39474 Mdot
.658 .39474 Mdot
.658 .39475 Mdot
.658 .39485 Mdot
.658 .39486 Mdot
.658 .39488 Mdot
.658 .39488 Mdot
.658 .39502 Mdot
.658 .39502 Mdot
.658 .39506 Mdot
.658 .3952 Mdot
.658 .3952 Mdot
.658 .39521 Mdot
.658 .39541 Mdot
.658 .39556 Mdot
.658 .39557 Mdot
.658 .39562 Mdot
.658 .39569 Mdot
.658 .3957 Mdot
.658 .39571 Mdot
.658 .39575 Mdot
.658 .39578 Mdot
.658 .39579 Mdot
.658 .39582 Mdot
.658 .3959 Mdot
.658 .39595 Mdot
.658 .39596 Mdot
.658 .39599 Mdot
.658 .39609 Mdot
.658 .3961 Mdot
.658 .39618 Mdot
.658 .39619 Mdot
.658 .39621 Mdot
.658 .39625 Mdot
.658 .39632 Mdot
.658 .39635 Mdot
.658 .39641 Mdot
.658 .39659 Mdot
.658 .3966 Mdot
.658 .39665 Mdot
.658 .39667 Mdot
.658 .39669 Mdot
.658 .39669 Mdot
.658 .39672 Mdot
.658 .39676 Mdot
.658 .39686 Mdot
.658 .39692 Mdot
.658 .39695 Mdot
.658 .39698 Mdot
.658 .39699 Mdot
.658 .39702 Mdot
.658 .39707 Mdot
.658 .39711 Mdot
.658 .39714 Mdot
.658 .39714 Mdot
.658 .39714 Mdot
.658 .39715 Mdot
.658 .39718 Mdot
.658 .39719 Mdot
.658 .39722 Mdot
.658 .39725 Mdot
.658 .39726 Mdot
.658 .39732 Mdot
.658 .39735 Mdot
.658 .39739 Mdot
.658 .39743 Mdot
.658 .39745 Mdot
.658 .39745 Mdot
.658 .39745 Mdot
.658 .39759 Mdot
.658 .39765 Mdot
.658 .39767 Mdot
.658 .39767 Mdot
.658 .3977 Mdot
.658 .39772 Mdot
.658 .39772 Mdot
.658 .39774 Mdot
.658 .39774 Mdot
.658 .39777 Mdot
.658 .39777 Mdot
.658 .39779 Mdot
.658 .39779 Mdot
.658 .39781 Mdot
.658 .39785 Mdot
.658 .39787 Mdot
.658 .39788 Mdot
.658 .39789 Mdot
.658 .3979 Mdot
.658 .3979 Mdot
.658 .39791 Mdot
.658 .39791 Mdot
.658 .39793 Mdot
.658 .39793 Mdot
.658 .39798 Mdot
.658 .39799 Mdot
.658 .39806 Mdot
.658 .39806 Mdot
.658 .39808 Mdot
.658 .39814 Mdot
.658 .39814 Mdot
.658 .39822 Mdot
.658 .39828 Mdot
.658 .39829 Mdot
.658 .39831 Mdot
.658 .39836 Mdot
.658 .39837 Mdot
.658 .39837 Mdot
.658 .39838 Mdot
.658 .39841 Mdot
.658 .39843 Mdot
.658 .39844 Mdot
.658 .39844 Mdot
.658 .39849 Mdot
.658 .39853 Mdot
.658 .39854 Mdot
.658 .39856 Mdot
.658 .39857 Mdot
.658 .3986 Mdot
.658 .39869 Mdot
.658 .39869 Mdot
.658 .3987 Mdot
.658 .39871 Mdot
.658 .39874 Mdot
.658 .39876 Mdot
.658 .3988 Mdot
.658 .39884 Mdot
.658 .39884 Mdot
.658 .39885 Mdot
.658 .39886 Mdot
.658 .39887 Mdot
.658 .39891 Mdot
.658 .39894 Mdot
.658 .39898 Mdot
.658 .399 Mdot
.658 .39901 Mdot
.658 .39902 Mdot
.658 .39902 Mdot
.658 .39902 Mdot
.658 .39902 Mdot
.658 .39903 Mdot
.658 .39904 Mdot
.658 .39904 Mdot
.658 .39906 Mdot
.658 .39907 Mdot
.658 .39908 Mdot
.658 .39908 Mdot
.658 .39908 Mdot
.658 .39908 Mdot
.658 .3991 Mdot
.658 .3991 Mdot
.658 .39915 Mdot
.658 .39917 Mdot
.658 .39919 Mdot
.658 .3992 Mdot
.658 .39921 Mdot
.658 .39922 Mdot
.658 .39922 Mdot
.658 .39922 Mdot
.658 .39924 Mdot
.658 .39924 Mdot
.658 .39927 Mdot
.658 .39928 Mdot
.658 .39928 Mdot
.658 .39929 Mdot
.658 .39932 Mdot
.658 .39932 Mdot
.658 .39932 Mdot
.658 .39933 Mdot
.658 .39936 Mdot
.658 .39936 Mdot
.658 .39937 Mdot
.658 .39937 Mdot
.658 .39939 Mdot
.658 .39939 Mdot
.658 .39941 Mdot
.658 .39941 Mdot
.658 .39944 Mdot
.658 .39944 Mdot
.658 .39947 Mdot
.658 .39947 Mdot
.658 .39948 Mdot
.658 .39951 Mdot
.658 .39954 Mdot
.658 .39954 Mdot
.658 .39955 Mdot
.658 .39956 Mdot
.658 .39957 Mdot
.658 .39958 Mdot
.658 .39959 Mdot
.658 .3996 Mdot
.658 .3996 Mdot
.658 .3996 Mdot
.658 .3996 Mdot
.658 .3996 Mdot
.658 .3996 Mdot
.658 .3996 Mdot
.658 .39961 Mdot
.658 .39962 Mdot
.658 .39963 Mdot
.658 .39965 Mdot
.658 .39968 Mdot
.658 .39969 Mdot
.658 .39969 Mdot
.658 .39971 Mdot
.658 .39971 Mdot
.658 .39972 Mdot
.658 .39973 Mdot
.658 .39973 Mdot
.658 .39975 Mdot
.658 .39976 Mdot
.658 .39977 Mdot
.658 .39978 Mdot
.658 .39981 Mdot
.658 .39982 Mdot
.658 .39983 Mdot
.658 .39987 Mdot
.658 .39988 Mdot
.658 .39993 Mdot
.658 .39993 Mdot
.658 .39996 Mdot
.658 .39997 Mdot
.658 .39999 Mdot
.658 .39999 Mdot
.658 .4 Mdot
.658 .4 Mdot
.658 .40001 Mdot
.658 .40003 Mdot
.658 .40004 Mdot
.658 .40005 Mdot
.658 .40007 Mdot
.658 .40007 Mdot
.658 .40008 Mdot
.658 .40008 Mdot
.658 .40013 Mdot
.658 .40014 Mdot
.658 .40014 Mdot
.658 .40015 Mdot
.658 .40016 Mdot
.658 .40018 Mdot
.658 .4002 Mdot
.658 .4002 Mdot
.658 .4002 Mdot
.658 .40021 Mdot
.658 .40023 Mdot
.658 .40023 Mdot
.658 .40023 Mdot
.658 .40024 Mdot
.658 .40026 Mdot
.658 .40027 Mdot
.658 .40027 Mdot
.658 .4003 Mdot
.658 .40032 Mdot
.658 .40034 Mdot
.658 .40034 Mdot
.658 .40037 Mdot
.658 .40038 Mdot
.658 .40038 Mdot
.658 .40041 Mdot
.658 .40041 Mdot
.658 .40044 Mdot
.658 .40044 Mdot
.658 .40044 Mdot
.658 .40045 Mdot
.658 .40045 Mdot
.658 .40045 Mdot
.658 .40045 Mdot
.658 .40046 Mdot
.658 .40046 Mdot
.658 .40047 Mdot
.658 .40049 Mdot
.658 .4005 Mdot
.658 .4005 Mdot
.658 .40051 Mdot
.658 .40051 Mdot
.658 .40052 Mdot
.658 .40052 Mdot
.658 .40053 Mdot
.658 .40053 Mdot
.658 .40054 Mdot
.658 .40055 Mdot
.658 .40056 Mdot
.658 .40056 Mdot
.658 .40059 Mdot
.658 .40065 Mdot
.658 .40065 Mdot
.658 .40065 Mdot
.658 .40066 Mdot
.658 .40068 Mdot
.658 .40069 Mdot
.658 .40071 Mdot
.658 .40073 Mdot
.658 .40074 Mdot
.658 .40075 Mdot
.658 .40076 Mdot
.658 .40076 Mdot
.658 .40078 Mdot
.658 .40078 Mdot
.658 .40078 Mdot
.658 .40078 Mdot
.658 .40079 Mdot
.658 .40081 Mdot
.658 .40083 Mdot
.658 .40084 Mdot
.658 .40085 Mdot
.658 .40086 Mdot
.658 .40087 Mdot
.658 .4009 Mdot
.658 .40094 Mdot
.658 .40096 Mdot
.658 .40097 Mdot
.658 .40097 Mdot
.658 .40098 Mdot
.658 .40098 Mdot
.658 .40101 Mdot
.658 .40101 Mdot
.658 .40108 Mdot
.658 .40111 Mdot
.658 .40112 Mdot
.658 .40115 Mdot
.658 .40116 Mdot
.658 .40117 Mdot
.658 .40117 Mdot
.658 .40121 Mdot
.658 .40121 Mdot
.658 .40125 Mdot
.658 .40126 Mdot
.658 .40127 Mdot
.658 .40128 Mdot
.658 .40132 Mdot
.658 .40133 Mdot
.658 .40133 Mdot
.658 .40134 Mdot
.658 .40136 Mdot
.658 .40136 Mdot
.658 .40136 Mdot
.658 .40139 Mdot
.658 .40141 Mdot
.658 .40141 Mdot
.658 .40147 Mdot
.658 .40155 Mdot
.658 .40155 Mdot
.658 .40155 Mdot
.658 .4016 Mdot
.658 .40162 Mdot
.658 .40162 Mdot
.658 .40167 Mdot
.658 .40167 Mdot
.658 .40168 Mdot
.658 .40168 Mdot
.658 .40172 Mdot
.658 .40172 Mdot
.658 .40172 Mdot
.658 .40173 Mdot
.658 .40174 Mdot
.658 .40174 Mdot
.658 .40174 Mdot
.658 .40174 Mdot
.658 .40175 Mdot
.658 .40176 Mdot
.658 .40176 Mdot
.658 .40177 Mdot
.658 .40178 Mdot
.658 .40178 Mdot
.658 .4018 Mdot
.658 .4018 Mdot
.658 .40181 Mdot
.658 .40182 Mdot
.658 .40183 Mdot
.658 .40183 Mdot
.658 .40183 Mdot
.658 .40183 Mdot
.658 .40185 Mdot
.658 .40185 Mdot
.658 .40185 Mdot
.658 .40186 Mdot
.658 .40186 Mdot
.658 .40187 Mdot
.658 .40189 Mdot
.658 .40189 Mdot
.658 .4019 Mdot
.658 .4019 Mdot
.658 .40192 Mdot
.658 .40193 Mdot
.658 .40193 Mdot
.658 .40194 Mdot
.658 .40199 Mdot
.658 .40199 Mdot
.658 .402 Mdot
.658 .402 Mdot
.658 .402 Mdot
.658 .40201 Mdot
.658 .40203 Mdot
.658 .40203 Mdot
.658 .40203 Mdot
.658 .40204 Mdot
.658 .40204 Mdot
.658 .40205 Mdot
.658 .40205 Mdot
.658 .40207 Mdot
.658 .40207 Mdot
.658 .40208 Mdot
.658 .40208 Mdot
.658 .40208 Mdot
.658 .40209 Mdot
.658 .40209 Mdot
.658 .4021 Mdot
.658 .4021 Mdot
.658 .4021 Mdot
.658 .4021 Mdot
.658 .4021 Mdot
.658 .40211 Mdot
.658 .40212 Mdot
.658 .40213 Mdot
.658 .40213 Mdot
.658 .40213 Mdot
.658 .40213 Mdot
.658 .40213 Mdot
.658 .40214 Mdot
.658 .40214 Mdot
.658 .40214 Mdot
.658 .40214 Mdot
.658 .40214 Mdot
.658 .40214 Mdot
.658 .40214 Mdot
.658 .40214 Mdot
.658 .40214 Mdot
.66 .35792 Mdot
.66 .35792 Mdot
.66 .35792 Mdot
.66 .35792 Mdot
.66 .35792 Mdot
.66 .35792 Mdot
.66 .35792 Mdot
.66 .35792 Mdot
.66 .35792 Mdot
.66 .35792 Mdot
.66 .35793 Mdot
.66 .35793 Mdot
.66 .35793 Mdot
.66 .35793 Mdot
.66 .35794 Mdot
.66 .35794 Mdot
.66 .35794 Mdot
.66 .35795 Mdot
.66 .35795 Mdot
.66 .35795 Mdot
.66 .35795 Mdot
.66 .35795 Mdot
.66 .35796 Mdot
.66 .35796 Mdot
.66 .35797 Mdot
.66 .35798 Mdot
.66 .35799 Mdot
.66 .35799 Mdot
.66 .35801 Mdot
.66 .35803 Mdot
.66 .35805 Mdot
.66 .35807 Mdot
.66 .35809 Mdot
.66 .35809 Mdot
.66 .35812 Mdot
.66 .35813 Mdot
.66 .35814 Mdot
.66 .35815 Mdot
.66 .35817 Mdot
.66 .35818 Mdot
.66 .35818 Mdot
.66 .3582 Mdot
.66 .35822 Mdot
.66 .35822 Mdot
.66 .35825 Mdot
.66 .35825 Mdot
.66 .35827 Mdot
.66 .35827 Mdot
.66 .35829 Mdot
.66 .35831 Mdot
.66 .35832 Mdot
.66 .35835 Mdot
.66 .35835 Mdot
.66 .35836 Mdot
.66 .35837 Mdot
.66 .35837 Mdot
.66 .35837 Mdot
.66 .35839 Mdot
.66 .3584 Mdot
.66 .35841 Mdot
.66 .35842 Mdot
.66 .35845 Mdot
.66 .35845 Mdot
.66 .35846 Mdot
.66 .3585 Mdot
.66 .35853 Mdot
.66 .35855 Mdot
.66 .35861 Mdot
.66 .35861 Mdot
.66 .35862 Mdot
.66 .35862 Mdot
.66 .35865 Mdot
.66 .35869 Mdot
.66 .3587 Mdot
.66 .3587 Mdot
.66 .3587 Mdot
.66 .35871 Mdot
.66 .35872 Mdot
.66 .35875 Mdot
.66 .35877 Mdot
.66 .35879 Mdot
.66 .35879 Mdot
.66 .35879 Mdot
.66 .3588 Mdot
.66 .35891 Mdot
.66 .35892 Mdot
.66 .35897 Mdot
.66 .35898 Mdot
.66 .35898 Mdot
.66 .35909 Mdot
.66 .35913 Mdot
.66 .35914 Mdot
.66 .35918 Mdot
.66 .35923 Mdot
.66 .35926 Mdot
.66 .35927 Mdot
.66 .35929 Mdot
.66 .35932 Mdot
.66 .35932 Mdot
.66 .35933 Mdot
.66 .35935 Mdot
.66 .35935 Mdot
.66 .35937 Mdot
.66 .35939 Mdot
.66 .35942 Mdot
.66 .35943 Mdot
.66 .35946 Mdot
.66 .35947 Mdot
.66 .35948 Mdot
.66 .35948 Mdot
.66 .35948 Mdot
.66 .35949 Mdot
.66 .35952 Mdot
.66 .35953 Mdot
.66 .35953 Mdot
.66 .35953 Mdot
.66 .35954 Mdot
.66 .35954 Mdot
.66 .35955 Mdot
.66 .35956 Mdot
.66 .35956 Mdot
.66 .35957 Mdot
.66 .35957 Mdot
.66 .35957 Mdot
.66 .35959 Mdot
.66 .35963 Mdot
.66 .35966 Mdot
.66 .35989 Mdot
.66 .3599 Mdot
.66 .36007 Mdot
.66 .36016 Mdot
.66 .36035 Mdot
.66 .36063 Mdot
.66 .36066 Mdot
.66 .36067 Mdot
.66 .36086 Mdot
.66 .36096 Mdot
.66 .36135 Mdot
.66 .36163 Mdot
.66 .36169 Mdot
.66 .36186 Mdot
.66 .36187 Mdot
.66 .36211 Mdot
.66 .36211 Mdot
.66 .36214 Mdot
.66 .36221 Mdot
.66 .3623 Mdot
.66 .36236 Mdot
.66 .36251 Mdot
.66 .36259 Mdot
.66 .36268 Mdot
.66 .36299 Mdot
.66 .36304 Mdot
.66 .36323 Mdot
.66 .3633 Mdot
.66 .36334 Mdot
.66 .36338 Mdot
.66 .36341 Mdot
.66 .36345 Mdot
.66 .36347 Mdot
.66 .36348 Mdot
.66 .3635 Mdot
.66 .36355 Mdot
.66 .36386 Mdot
.66 .36391 Mdot
.66 .36391 Mdot
.66 .36396 Mdot
.66 .36401 Mdot
.66 .36404 Mdot
.66 .36409 Mdot
.66 .3642 Mdot
.66 .36426 Mdot
.66 .36427 Mdot
.66 .36431 Mdot
.66 .36432 Mdot
.66 .36433 Mdot
.66 .36452 Mdot
.66 .36472 Mdot
.66 .36489 Mdot
.66 .365 Mdot
.66 .36519 Mdot
.66 .36563 Mdot
.66 .36605 Mdot
.66 .36636 Mdot
.66 .36656 Mdot
.66 .36693 Mdot
.66 .36698 Mdot
.66 .36742 Mdot
.66 .36753 Mdot
.66 .36815 Mdot
.66 .36826 Mdot
.66 .36832 Mdot
.66 .36853 Mdot
.66 .36864 Mdot
.66 .36865 Mdot
.66 .36865 Mdot
.66 .36868 Mdot
.66 .36868 Mdot
.66 .36871 Mdot
.66 .36878 Mdot
.66 .36881 Mdot
.66 .36883 Mdot
.66 .36886 Mdot
.66 .36889 Mdot
.66 .36889 Mdot
.66 .36892 Mdot
.66 .3691 Mdot
.66 .36914 Mdot
.66 .36915 Mdot
.66 .36917 Mdot
.66 .36919 Mdot
.66 .36926 Mdot
.66 .3693 Mdot
.66 .36942 Mdot
.66 .36945 Mdot
.66 .36965 Mdot
.66 .36976 Mdot
.66 .36986 Mdot
.66 .3699 Mdot
.66 .37001 Mdot
.66 .37003 Mdot
.66 .37003 Mdot
.66 .37019 Mdot
.66 .3702 Mdot
.66 .37032 Mdot
.66 .37037 Mdot
.66 .37057 Mdot
.66 .37087 Mdot
.66 .3711 Mdot
.66 .37111 Mdot
.66 .37113 Mdot
.66 .37137 Mdot
.66 .37154 Mdot
.66 .37179 Mdot
.66 .37201 Mdot
.66 .37204 Mdot
.66 .37208 Mdot
.66 .3721 Mdot
.66 .37215 Mdot
.66 .37237 Mdot
.66 .37242 Mdot
.66 .37258 Mdot
.66 .37301 Mdot
.66 .37302 Mdot
.66 .37305 Mdot
.66 .37308 Mdot
.66 .37314 Mdot
.66 .37315 Mdot
.66 .37315 Mdot
.66 .37315 Mdot
.66 .37316 Mdot
.66 .37327 Mdot
.66 .37328 Mdot
.66 .37341 Mdot
.66 .37354 Mdot
.66 .37355 Mdot
.66 .37363 Mdot
.66 .37365 Mdot
.66 .37369 Mdot
.66 .37369 Mdot
.66 .3737 Mdot
.66 .37372 Mdot
.66 .37374 Mdot
.66 .37382 Mdot
.66 .37394 Mdot
.66 .37394 Mdot
.66 .37401 Mdot
.66 .37405 Mdot
.66 .37419 Mdot
.66 .37422 Mdot
.66 .37424 Mdot
.66 .37427 Mdot
.66 .37462 Mdot
.66 .37474 Mdot
.66 .37485 Mdot
.66 .37488 Mdot
.66 .37491 Mdot
.66 .37492 Mdot
.66 .37496 Mdot
.66 .37504 Mdot
.66 .37511 Mdot
.66 .37519 Mdot
.66 .3752 Mdot
.66 .37523 Mdot
.66 .37524 Mdot
.66 .3753 Mdot
.66 .37539 Mdot
.66 .37545 Mdot
.66 .37549 Mdot
.66 .37556 Mdot
.66 .3756 Mdot
.66 .3757 Mdot
.66 .37571 Mdot
.66 .37572 Mdot
.66 .37578 Mdot
.66 .37583 Mdot
.66 .37587 Mdot
.66 .37588 Mdot
.66 .37599 Mdot
.66 .37604 Mdot
.66 .37611 Mdot
.66 .37623 Mdot
.66 .37633 Mdot
.66 .37637 Mdot
.66 .37645 Mdot
.66 .37645 Mdot
.66 .37666 Mdot
.66 .37668 Mdot
.66 .37669 Mdot
.66 .37677 Mdot
.66 .37688 Mdot
.66 .37689 Mdot
.66 .37692 Mdot
.66 .37699 Mdot
.66 .37705 Mdot
.66 .37712 Mdot
.66 .37717 Mdot
.66 .37722 Mdot
.66 .3773 Mdot
.66 .37738 Mdot
.66 .37746 Mdot
.66 .37747 Mdot
.66 .37753 Mdot
.66 .37763 Mdot
.66 .37772 Mdot
.66 .37772 Mdot
.66 .37787 Mdot
.66 .37788 Mdot
.66 .37794 Mdot
.66 .37795 Mdot
.66 .37796 Mdot
.66 .37808 Mdot
.66 .37813 Mdot
.66 .37818 Mdot
.66 .37823 Mdot
.66 .37827 Mdot
.66 .3783 Mdot
.66 .37833 Mdot
.66 .37834 Mdot
.66 .37836 Mdot
.66 .37836 Mdot
.66 .37838 Mdot
.66 .3784 Mdot
.66 .37844 Mdot
.66 .37844 Mdot
.66 .37847 Mdot
.66 .37848 Mdot
.66 .37849 Mdot
.66 .37849 Mdot
.66 .37849 Mdot
.66 .3785 Mdot
.66 .37853 Mdot
.66 .37853 Mdot
.66 .37854 Mdot
.66 .37855 Mdot
.66 .37855 Mdot
.66 .37855 Mdot
.66 .37857 Mdot
.66 .37857 Mdot
.66 .37858 Mdot
.66 .37858 Mdot
.66 .37887 Mdot
.66 .37902 Mdot
.66 .37962 Mdot
.66 .38049 Mdot
.66 .38071 Mdot
.66 .38112 Mdot
.66 .38114 Mdot
.66 .3812 Mdot
.66 .3818 Mdot
.66 .38222 Mdot
.66 .38241 Mdot
.66 .38278 Mdot
.66 .3828 Mdot
.66 .38327 Mdot
.66 .38334 Mdot
.66 .38342 Mdot
.66 .38346 Mdot
.66 .38346 Mdot
.66 .38346 Mdot
.66 .38347 Mdot
.66 .38349 Mdot
.66 .38351 Mdot
.66 .38352 Mdot
.66 .38353 Mdot
.66 .38354 Mdot
.66 .38355 Mdot
.66 .38355 Mdot
.66 .38357 Mdot
.66 .38364 Mdot
.66 .38365 Mdot
.66 .38365 Mdot
.66 .38366 Mdot
.66 .38367 Mdot
.66 .38369 Mdot
.66 .38375 Mdot
.66 .38377 Mdot
.66 .38384 Mdot
.66 .38388 Mdot
.66 .38392 Mdot
.66 .38393 Mdot
.66 .38397 Mdot
.66 .38398 Mdot
.66 .38398 Mdot
.66 .38404 Mdot
.66 .38408 Mdot
.66 .3841 Mdot
.66 .38417 Mdot
.66 .38428 Mdot
.66 .38436 Mdot
.66 .38437 Mdot
.66 .38446 Mdot
.66 .38468 Mdot
.66 .38469 Mdot
.66 .38471 Mdot
.66 .38471 Mdot
.66 .3848 Mdot
.66 .38482 Mdot
.66 .38505 Mdot
.66 .38507 Mdot
.66 .38507 Mdot
.66 .38507 Mdot
.66 .38511 Mdot
.66 .38516 Mdot
.66 .3852 Mdot
.66 .38523 Mdot
.66 .38525 Mdot
.66 .38525 Mdot
.66 .38525 Mdot
.66 .38527 Mdot
.66 .38535 Mdot
.66 .38541 Mdot
.66 .38542 Mdot
.66 .38543 Mdot
.66 .38544 Mdot
.66 .38555 Mdot
.66 .38565 Mdot
.66 .38574 Mdot
.66 .38575 Mdot
.66 .38575 Mdot
.66 .3858 Mdot
.66 .38583 Mdot
.66 .38586 Mdot
.66 .38587 Mdot
.66 .3859 Mdot
.66 .3859 Mdot
.66 .38591 Mdot
.66 .38593 Mdot
.66 .38594 Mdot
.66 .38595 Mdot
.66 .38601 Mdot
.66 .38603 Mdot
.66 .38607 Mdot
.66 .3861 Mdot
.66 .38611 Mdot
.66 .38614 Mdot
.66 .38614 Mdot
.66 .3862 Mdot
.66 .38622 Mdot
.66 .38624 Mdot
.66 .38628 Mdot
.66 .38629 Mdot
.66 .38631 Mdot
.66 .38635 Mdot
.66 .38637 Mdot
.66 .38638 Mdot
.66 .38641 Mdot
.66 .38646 Mdot
.66 .38646 Mdot
.66 .38651 Mdot
.66 .38653 Mdot
.66 .38659 Mdot
.66 .38661 Mdot
.66 .38665 Mdot
.66 .38666 Mdot
.66 .38668 Mdot
.66 .38669 Mdot
.66 .38671 Mdot
.66 .38671 Mdot
.66 .38672 Mdot
.66 .38673 Mdot
.66 .38673 Mdot
.66 .38673 Mdot
.66 .38674 Mdot
.66 .38675 Mdot
.66 .38676 Mdot
.66 .38676 Mdot
.66 .38677 Mdot
.66 .38677 Mdot
.66 .38677 Mdot
.66 .38677 Mdot
.66 .38679 Mdot
.66 .38679 Mdot
.66 .38679 Mdot
.66 .38679 Mdot
.66 .38679 Mdot
.66 .38679 Mdot
.66 .3868 Mdot
.66 .3868 Mdot
.66 .3868 Mdot
.66 .3868 Mdot
.66 .39225 Mdot
.66 .39225 Mdot
.66 .39225 Mdot
.66 .39225 Mdot
.66 .39226 Mdot
.66 .39226 Mdot
.66 .39226 Mdot
.66 .39226 Mdot
.66 .39226 Mdot
.66 .39226 Mdot
.66 .39227 Mdot
.66 .39227 Mdot
.66 .39227 Mdot
.66 .39227 Mdot
.66 .39227 Mdot
.66 .39227 Mdot
.66 .39228 Mdot
.66 .39228 Mdot
.66 .39229 Mdot
.66 .39229 Mdot
.66 .39229 Mdot
.66 .39229 Mdot
.66 .3923 Mdot
.66 .3923 Mdot
.66 .39231 Mdot
.66 .39231 Mdot
.66 .39232 Mdot
.66 .39233 Mdot
.66 .39235 Mdot
.66 .39236 Mdot
.66 .39238 Mdot
.66 .3924 Mdot
.66 .39242 Mdot
.66 .39242 Mdot
.66 .39245 Mdot
.66 .39246 Mdot
.66 .39247 Mdot
.66 .39248 Mdot
.66 .3925 Mdot
.66 .39251 Mdot
.66 .39251 Mdot
.66 .39253 Mdot
.66 .39254 Mdot
.66 .39255 Mdot
.66 .39258 Mdot
.66 .39258 Mdot
.66 .39259 Mdot
.66 .3926 Mdot
.66 .39261 Mdot
.66 .39263 Mdot
.66 .39264 Mdot
.66 .39267 Mdot
.66 .39267 Mdot
.66 .39268 Mdot
.66 .39269 Mdot
.66 .39269 Mdot
.66 .39269 Mdot
.66 .39271 Mdot
.66 .39271 Mdot
.66 .39273 Mdot
.66 .39274 Mdot
.66 .39277 Mdot
.66 .39277 Mdot
.66 .39277 Mdot
.66 .39282 Mdot
.66 .39286 Mdot
.66 .39292 Mdot
.66 .39292 Mdot
.66 .39292 Mdot
.66 .39293 Mdot
.66 .39296 Mdot
.66 .393 Mdot
.66 .39301 Mdot
.66 .39301 Mdot
.66 .39301 Mdot
.66 .39302 Mdot
.66 .39303 Mdot
.66 .39305 Mdot
.66 .39307 Mdot
.66 .39309 Mdot
.66 .39309 Mdot
.66 .39309 Mdot
.66 .3931 Mdot
.66 .39321 Mdot
.66 .39322 Mdot
.66 .39326 Mdot
.66 .39327 Mdot
.66 .39328 Mdot
.66 .39338 Mdot
.66 .39342 Mdot
.66 .39342 Mdot
.66 .39346 Mdot
.66 .39351 Mdot
.66 .39355 Mdot
.66 .39355 Mdot
.66 .39357 Mdot
.66 .3936 Mdot
.66 .3936 Mdot
.66 .39361 Mdot
.66 .39362 Mdot
.66 .39363 Mdot
.66 .39365 Mdot
.66 .39367 Mdot
.66 .3937 Mdot
.66 .39371 Mdot
.66 .39373 Mdot
.66 .39375 Mdot
.66 .39375 Mdot
.66 .39375 Mdot
.66 .39375 Mdot
.66 .39376 Mdot
.66 .39379 Mdot
.66 .3938 Mdot
.66 .3938 Mdot
.66 .3938 Mdot
.66 .39381 Mdot
.66 .39381 Mdot
.66 .39382 Mdot
.66 .39383 Mdot
.66 .39383 Mdot
.66 .39384 Mdot
.66 .39384 Mdot
.66 .39384 Mdot
.66 .39386 Mdot
.66 .3939 Mdot
.66 .39393 Mdot
.66 .39414 Mdot
.66 .39415 Mdot
.66 .39431 Mdot
.66 .3944 Mdot
.66 .39458 Mdot
.66 .39484 Mdot
.66 .39487 Mdot
.66 .39488 Mdot
.66 .39505 Mdot
.66 .39515 Mdot
.66 .39551 Mdot
.66 .39577 Mdot
.66 .39583 Mdot
.66 .39595 Mdot
.66 .39595 Mdot
.66 .39595 Mdot
.66 .39595 Mdot
.66 .39596 Mdot
.66 .39596 Mdot
.66 .39596 Mdot
.66 .39596 Mdot
.66 .39596 Mdot
.66 .39597 Mdot
.66 .39598 Mdot
.66 .39598 Mdot
.66 .39598 Mdot
.66 .39598 Mdot
.66 .39599 Mdot
.66 .39599 Mdot
.66 .396 Mdot
.66 .39601 Mdot
.66 .39602 Mdot
.66 .39603 Mdot
.66 .39604 Mdot
.66 .39604 Mdot
.66 .39605 Mdot
.66 .39605 Mdot
.66 .39606 Mdot
.66 .39607 Mdot
.66 .39609 Mdot
.66 .39611 Mdot
.66 .39613 Mdot
.66 .39615 Mdot
.66 .3962 Mdot
.66 .3962 Mdot
.66 .39621 Mdot
.66 .39623 Mdot
.66 .39624 Mdot
.66 .3963 Mdot
.66 .3963 Mdot
.66 .39633 Mdot
.66 .39638 Mdot
.66 .3964 Mdot
.66 .3964 Mdot
.66 .39643 Mdot
.66 .39646 Mdot
.66 .3965 Mdot
.66 .39652 Mdot
.66 .39654 Mdot
.66 .39657 Mdot
.66 .39659 Mdot
.66 .39662 Mdot
.66 .39663 Mdot
.66 .39663 Mdot
.66 .39668 Mdot
.66 .39671 Mdot
.66 .39671 Mdot
.66 .39672 Mdot
.66 .3968 Mdot
.66 .3968 Mdot
.66 .39684 Mdot
.66 .39685 Mdot
.66 .39689 Mdot
.66 .39694 Mdot
.66 .39697 Mdot
.66 .39699 Mdot
.66 .39703 Mdot
.66 .39703 Mdot
.66 .39705 Mdot
.66 .39707 Mdot
.66 .39709 Mdot
.66 .3971 Mdot
.66 .3971 Mdot
.66 .39714 Mdot
.66 .39715 Mdot
.66 .39718 Mdot
.66 .3972 Mdot
.66 .39722 Mdot
.66 .39726 Mdot
.66 .39728 Mdot
.66 .39728 Mdot
.66 .39729 Mdot
.66 .3973 Mdot
.66 .39733 Mdot
.66 .39736 Mdot
.66 .39739 Mdot
.66 .3974 Mdot
.66 .39741 Mdot
.66 .39742 Mdot
.66 .39743 Mdot
.66 .39747 Mdot
.66 .39752 Mdot
.66 .39765 Mdot
.66 .39767 Mdot
.66 .39767 Mdot
.66 .39768 Mdot
.66 .39774 Mdot
.66 .39775 Mdot
.66 .39778 Mdot
.66 .39778 Mdot
.66 .39782 Mdot
.66 .39785 Mdot
.66 .39786 Mdot
.66 .39787 Mdot
.66 .39787 Mdot
.66 .39787 Mdot
.66 .39789 Mdot
.66 .3979 Mdot
.66 .39792 Mdot
.66 .39793 Mdot
.66 .39798 Mdot
.66 .39803 Mdot
.66 .39803 Mdot
.66 .39807 Mdot
.66 .39808 Mdot
.66 .39808 Mdot
.66 .39808 Mdot
.66 .39808 Mdot
.66 .3981 Mdot
.66 .39811 Mdot
.66 .39812 Mdot
.66 .39813 Mdot
.66 .39829 Mdot
.66 .39835 Mdot
.66 .39837 Mdot
.66 .39845 Mdot
.66 .39847 Mdot
.66 .39848 Mdot
.66 .39849 Mdot
.66 .3985 Mdot
.66 .39858 Mdot
.66 .39868 Mdot
.66 .39874 Mdot
.66 .39883 Mdot
.66 .39883 Mdot
.66 .39884 Mdot
.66 .39892 Mdot
.66 .39903 Mdot
.66 .3991 Mdot
.66 .39912 Mdot
.66 .39916 Mdot
.66 .39917 Mdot
.66 .39923 Mdot
.66 .39923 Mdot
.66 .39923 Mdot
.66 .39927 Mdot
.66 .39929 Mdot
.66 .39932 Mdot
.66 .39936 Mdot
.66 .39943 Mdot
.66 .39944 Mdot
.66 .39949 Mdot
.66 .3995 Mdot
.66 .39953 Mdot
.66 .39954 Mdot
.66 .39954 Mdot
.66 .39954 Mdot
.66 .39956 Mdot
.66 .39962 Mdot
.66 .39963 Mdot
.66 .39963 Mdot
.66 .39965 Mdot
.66 .39966 Mdot
.66 .39966 Mdot
.66 .39967 Mdot
.66 .3997 Mdot
.66 .39971 Mdot
.66 .39971 Mdot
.66 .39972 Mdot
.66 .39972 Mdot
.66 .39972 Mdot
.66 .39976 Mdot
.66 .39983 Mdot
.66 .39986 Mdot
.66 .39989 Mdot
.66 .40011 Mdot
.66 .40015 Mdot
.66 .40031 Mdot
.66 .40032 Mdot
.66 .40045 Mdot
.66 .40052 Mdot
.66 .40063 Mdot
.66 .40077 Mdot
.66 .40092 Mdot
.66 .40099 Mdot
.66 .40103 Mdot
.66 .40108 Mdot
.66 .40115 Mdot
.66 .40122 Mdot
.66 .40122 Mdot
.66 .40122 Mdot
.66 .40124 Mdot
.66 .40124 Mdot
.66 .40126 Mdot
.66 .4013 Mdot
.66 .40131 Mdot
.66 .40132 Mdot
.66 .40134 Mdot
.66 .40136 Mdot
.66 .40136 Mdot
.66 .40137 Mdot
.66 .40148 Mdot
.66 .4015 Mdot
.66 .4015 Mdot
.66 .4015 Mdot
.66 .40151 Mdot
.66 .40152 Mdot
.66 .40153 Mdot
.66 .40155 Mdot
.66 .40156 Mdot
.66 .40159 Mdot
.66 .40165 Mdot
.66 .40167 Mdot
.66 .40177 Mdot
.66 .4018 Mdot
.66 .40182 Mdot
.66 .40187 Mdot
.66 .4019 Mdot
.66 .40192 Mdot
.66 .40195 Mdot
.66 .40196 Mdot
.66 .40196 Mdot
.66 .40204 Mdot
.66 .40204 Mdot
.66 .4021 Mdot
.66 .40212 Mdot
.66 .40221 Mdot
.66 .40234 Mdot
.66 .40237 Mdot
.66 .40243 Mdot
.66 .40244 Mdot
.66 .40244 Mdot
.66 .40254 Mdot
.66 .4026 Mdot
.66 .40263 Mdot
.66 .40268 Mdot
.66 .40269 Mdot
.66 .40276 Mdot
.66 .40277 Mdot
.66 .40278 Mdot
.66 .40279 Mdot
.66 .40279 Mdot
.66 .40279 Mdot
.66 .40279 Mdot
.66 .40279 Mdot
.66 .4028 Mdot
.66 .4028 Mdot
.66 .4028 Mdot
.66 .4028 Mdot
.66 .4028 Mdot
.66 .4028 Mdot
.66 .40281 Mdot
.66 .40282 Mdot
.66 .40282 Mdot
.66 .40282 Mdot
.66 .40282 Mdot
.66 .40282 Mdot
.66 .40283 Mdot
.66 .40283 Mdot
.66 .40284 Mdot
.66 .40285 Mdot
.66 .40285 Mdot
.66 .40286 Mdot
.66 .40286 Mdot
.66 .40287 Mdot
.66 .40287 Mdot
.66 .40287 Mdot
.66 .40288 Mdot
.66 .40289 Mdot
.66 .40289 Mdot
.66 .4029 Mdot
.66 .40292 Mdot
.66 .40293 Mdot
.66 .40293 Mdot
.66 .40294 Mdot
.66 .40298 Mdot
.66 .40298 Mdot
.66 .40299 Mdot
.66 .403 Mdot
.66 .403 Mdot
.66 .40304 Mdot
.66 .40304 Mdot
.66 .40304 Mdot
.66 .40304 Mdot
.66 .40305 Mdot
.66 .40306 Mdot
.66 .40306 Mdot
.66 .40307 Mdot
.66 .40307 Mdot
.66 .40307 Mdot
.66 .40307 Mdot
.66 .40307 Mdot
.66 .40309 Mdot
.66 .4031 Mdot
.66 .4031 Mdot
.66 .4031 Mdot
.66 .4031 Mdot
.66 .40312 Mdot
.66 .40312 Mdot
.66 .40313 Mdot
.66 .40315 Mdot
.66 .40315 Mdot
.66 .40315 Mdot
.66 .40316 Mdot
.66 .40316 Mdot
.66 .40317 Mdot
.66 .40317 Mdot
.66 .40318 Mdot
.66 .40318 Mdot
.66 .40318 Mdot
.66 .40318 Mdot
.66 .40318 Mdot
.66 .40318 Mdot
.66 .40319 Mdot
.66 .4032 Mdot
.66 .4032 Mdot
.66 .40321 Mdot
.66 .40321 Mdot
.66 .40321 Mdot
.66 .40321 Mdot
.66 .40322 Mdot
.66 .40323 Mdot
.66 .40323 Mdot
.66 .40324 Mdot
.66 .40324 Mdot
.66 .40324 Mdot
.66 .40325 Mdot
.66 .40325 Mdot
.66 .40325 Mdot
.66 .40326 Mdot
.66 .40327 Mdot
.66 .40327 Mdot
.66 .40327 Mdot
.66 .40328 Mdot
.66 .40329 Mdot
.66 .40329 Mdot
.66 .4033 Mdot
.66 .4033 Mdot
.66 .4033 Mdot
.66 .4033 Mdot
.66 .40331 Mdot
.66 .40331 Mdot
.66 .40331 Mdot
.66 .40331 Mdot
.66 .40331 Mdot
.66 .40331 Mdot
.66 .40331 Mdot
.66 .40331 Mdot
.66 .40331 Mdot
.66 .40332 Mdot
.66 .40332 Mdot
.66 .40332 Mdot
.66 .40332 Mdot
.66 .40332 Mdot
.66 .40332 Mdot
.66 .40332 Mdot
.66 .40332 Mdot
.66 .40332 Mdot
.66 .40332 Mdot
.66 .40332 Mdot
.66 .40332 Mdot
.66 .40332 Mdot
.66 .40332 Mdot
.66 .40332 Mdot
.662 .35521 Mdot
.662 .35521 Mdot
.662 .35521 Mdot
.662 .35521 Mdot
.662 .35522 Mdot
.662 .35523 Mdot
.662 .35525 Mdot
.662 .35525 Mdot
.662 .35527 Mdot
.662 .35528 Mdot
.662 .3553 Mdot
.662 .35542 Mdot
.662 .35543 Mdot
.662 .35543 Mdot
.662 .35545 Mdot
.662 .35545 Mdot
.662 .35549 Mdot
.662 .3555 Mdot
.662 .35553 Mdot
.662 .35554 Mdot
.662 .35558 Mdot
.662 .35559 Mdot
.662 .35559 Mdot
.662 .35576 Mdot
.662 .35576 Mdot
.662 .35576 Mdot
.662 .35578 Mdot
.662 .35578 Mdot
.662 .35578 Mdot
.662 .3558 Mdot
.662 .3558 Mdot
.662 .35582 Mdot
.662 .35588 Mdot
.662 .35591 Mdot
.662 .35593 Mdot
.662 .35604 Mdot
.662 .35606 Mdot
.662 .35606 Mdot
.662 .35607 Mdot
.662 .35609 Mdot
.662 .3561 Mdot
.662 .35612 Mdot
.662 .35624 Mdot
.662 .3563 Mdot
.662 .35631 Mdot
.662 .35635 Mdot
.662 .35636 Mdot
.662 .35641 Mdot
.662 .35642 Mdot
.662 .35642 Mdot
.662 .35645 Mdot
.662 .35646 Mdot
.662 .35649 Mdot
.662 .35661 Mdot
.662 .35668 Mdot
.662 .35672 Mdot
.662 .35676 Mdot
.662 .35679 Mdot
.662 .35679 Mdot
.662 .35685 Mdot
.662 .35701 Mdot
.662 .35705 Mdot
.662 .35707 Mdot
.662 .35712 Mdot
.662 .35714 Mdot
.662 .35716 Mdot
.662 .35718 Mdot
.662 .3572 Mdot
.662 .35728 Mdot
.662 .35728 Mdot
.662 .35747 Mdot
.662 .35755 Mdot
.662 .35757 Mdot
.662 .35768 Mdot
.662 .35769 Mdot
.662 .35769 Mdot
.662 .35791 Mdot
.662 .35792 Mdot
.662 .35797 Mdot
.662 .35809 Mdot
.662 .35813 Mdot
.662 .35828 Mdot
.662 .35835 Mdot
.662 .3584 Mdot
.662 .35857 Mdot
.662 .35864 Mdot
.662 .35864 Mdot
.662 .35864 Mdot
.662 .35864 Mdot
.662 .35865 Mdot
.662 .35881 Mdot
.662 .35887 Mdot
.662 .35901 Mdot
.662 .3591 Mdot
.662 .3591 Mdot
.662 .3592 Mdot
.662 .3593 Mdot
.662 .35932 Mdot
.662 .35932 Mdot
.662 .35933 Mdot
.662 .35944 Mdot
.662 .35961 Mdot
.662 .35974 Mdot
.662 .35987 Mdot
.662 .35989 Mdot
.662 .36003 Mdot
.662 .3601 Mdot
.662 .36017 Mdot
.662 .36017 Mdot
.662 .3605 Mdot
.662 .3605 Mdot
.662 .3605 Mdot
.662 .36071 Mdot
.662 .36101 Mdot
.662 .36111 Mdot
.662 .36116 Mdot
.662 .36119 Mdot
.662 .36131 Mdot
.662 .36156 Mdot
.662 .36163 Mdot
.662 .36182 Mdot
.662 .36191 Mdot
.662 .36192 Mdot
.662 .36193 Mdot
.662 .36211 Mdot
.662 .3622 Mdot
.662 .36245 Mdot
.662 .36246 Mdot
.662 .36252 Mdot
.662 .36268 Mdot
.662 .36307 Mdot
.662 .3632 Mdot
.662 .3632 Mdot
.662 .36321 Mdot
.662 .36322 Mdot
.662 .36323 Mdot
.662 .36324 Mdot
.662 .36332 Mdot
.662 .36339 Mdot
.662 .3634 Mdot
.662 .36359 Mdot
.662 .36359 Mdot
.662 .36391 Mdot
.662 .36392 Mdot
.662 .36393 Mdot
.662 .36397 Mdot
.662 .36397 Mdot
.662 .36408 Mdot
.662 .36412 Mdot
.662 .36427 Mdot
.662 .36435 Mdot
.662 .36458 Mdot
.662 .36461 Mdot
.662 .36465 Mdot
.662 .36487 Mdot
.662 .36498 Mdot
.662 .36511 Mdot
.662 .36515 Mdot
.662 .36519 Mdot
.662 .36526 Mdot
.662 .36534 Mdot
.662 .36535 Mdot
.662 .36549 Mdot
.662 .36566 Mdot
.662 .3657 Mdot
.662 .36574 Mdot
.662 .36582 Mdot
.662 .36592 Mdot
.662 .36606 Mdot
.662 .36651 Mdot
.662 .3667 Mdot
.662 .36685 Mdot
.662 .36685 Mdot
.662 .36703 Mdot
.662 .36734 Mdot
.662 .36737 Mdot
.662 .36756 Mdot
.662 .36772 Mdot
.662 .36782 Mdot
.662 .36782 Mdot
.662 .3679 Mdot
.662 .36791 Mdot
.662 .36791 Mdot
.662 .36791 Mdot
.662 .36792 Mdot
.662 .36792 Mdot
.662 .36799 Mdot
.662 .36828 Mdot
.662 .36832 Mdot
.662 .3686 Mdot
.662 .36861 Mdot
.662 .36881 Mdot
.662 .36895 Mdot
.662 .36904 Mdot
.662 .36912 Mdot
.662 .36943 Mdot
.662 .36943 Mdot
.662 .36967 Mdot
.662 .36972 Mdot
.662 .37018 Mdot
.662 .37018 Mdot
.662 .37026 Mdot
.662 .37033 Mdot
.662 .37034 Mdot
.662 .3705 Mdot
.662 .37054 Mdot
.662 .37065 Mdot
.662 .37071 Mdot
.662 .37084 Mdot
.662 .37087 Mdot
.662 .37093 Mdot
.662 .37105 Mdot
.662 .37107 Mdot
.662 .37117 Mdot
.662 .3714 Mdot
.662 .3714 Mdot
.662 .37141 Mdot
.662 .3715 Mdot
.662 .37152 Mdot
.662 .37159 Mdot
.662 .37176 Mdot
.662 .37176 Mdot
.662 .37183 Mdot
.662 .37185 Mdot
.662 .37187 Mdot
.662 .37189 Mdot
.662 .37196 Mdot
.662 .37201 Mdot
.662 .37223 Mdot
.662 .37227 Mdot
.662 .37257 Mdot
.662 .3726 Mdot
.662 .37264 Mdot
.662 .37264 Mdot
.662 .37309 Mdot
.662 .3731 Mdot
.662 .37328 Mdot
.662 .37346 Mdot
.662 .37349 Mdot
.662 .37349 Mdot
.662 .37353 Mdot
.662 .37355 Mdot
.662 .37356 Mdot
.662 .37386 Mdot
.662 .37407 Mdot
.662 .37409 Mdot
.662 .37419 Mdot
.662 .37424 Mdot
.662 .37477 Mdot
.662 .37478 Mdot
.662 .3749 Mdot
.662 .37505 Mdot
.662 .37516 Mdot
.662 .37529 Mdot
.662 .37533 Mdot
.662 .3755 Mdot
.662 .37559 Mdot
.662 .37591 Mdot
.662 .37613 Mdot
.662 .37654 Mdot
.662 .37655 Mdot
.662 .3766 Mdot
.662 .37679 Mdot
.662 .37681 Mdot
.662 .3769 Mdot
.662 .37692 Mdot
.662 .37722 Mdot
.662 .37724 Mdot
.662 .37724 Mdot
.662 .3774 Mdot
.662 .37744 Mdot
.662 .37762 Mdot
.662 .37766 Mdot
.662 .37769 Mdot
.662 .3777 Mdot
.662 .37773 Mdot
.662 .37787 Mdot
.662 .37794 Mdot
.662 .37795 Mdot
.662 .378 Mdot
.662 .37801 Mdot
.662 .37807 Mdot
.662 .37812 Mdot
.662 .37828 Mdot
.662 .37835 Mdot
.662 .37839 Mdot
.662 .37845 Mdot
.662 .37851 Mdot
.662 .37869 Mdot
.662 .37876 Mdot
.662 .37938 Mdot
.662 .37938 Mdot
.662 .37987 Mdot
.662 .37987 Mdot
.662 .37987 Mdot
.662 .37988 Mdot
.662 .38011 Mdot
.662 .38028 Mdot
.662 .38029 Mdot
.662 .38037 Mdot
.662 .38046 Mdot
.662 .38054 Mdot
.662 .38061 Mdot
.662 .38062 Mdot
.662 .38077 Mdot
.662 .38078 Mdot
.662 .38095 Mdot
.662 .38106 Mdot
.662 .38126 Mdot
.662 .3813 Mdot
.662 .38151 Mdot
.662 .3816 Mdot
.662 .38165 Mdot
.662 .38173 Mdot
.662 .38177 Mdot
.662 .38189 Mdot
.662 .38199 Mdot
.662 .38226 Mdot
.662 .38238 Mdot
.662 .38252 Mdot
.662 .38252 Mdot
.662 .38254 Mdot
.662 .38254 Mdot
.662 .38258 Mdot
.662 .3826 Mdot
.662 .38278 Mdot
.662 .3828 Mdot
.662 .38281 Mdot
.662 .3829 Mdot
.662 .38299 Mdot
.662 .38301 Mdot
.662 .38302 Mdot
.662 .38305 Mdot
.662 .38314 Mdot
.662 .38322 Mdot
.662 .38323 Mdot
.662 .38326 Mdot
.662 .3833 Mdot
.662 .38352 Mdot
.662 .38359 Mdot
.662 .38364 Mdot
.662 .38364 Mdot
.662 .38383 Mdot
.662 .38399 Mdot
.662 .38402 Mdot
.662 .38402 Mdot
.662 .38402 Mdot
.662 .38402 Mdot
.662 .38402 Mdot
.662 .38404 Mdot
.662 .38416 Mdot
.662 .38453 Mdot
.662 .38463 Mdot
.662 .38478 Mdot
.662 .38483 Mdot
.662 .38488 Mdot
.662 .3849 Mdot
.662 .38493 Mdot
.662 .38495 Mdot
.662 .385 Mdot
.662 .38502 Mdot
.662 .3851 Mdot
.662 .38517 Mdot
.662 .38518 Mdot
.662 .38521 Mdot
.662 .38523 Mdot
.662 .38531 Mdot
.662 .38535 Mdot
.662 .38537 Mdot
.662 .38544 Mdot
.662 .38545 Mdot
.662 .38554 Mdot
.662 .38555 Mdot
.662 .386 Mdot
.662 .386 Mdot
.662 .38603 Mdot
.662 .38605 Mdot
.662 .38621 Mdot
.662 .38625 Mdot
.662 .38629 Mdot
.662 .38641 Mdot
.662 .38642 Mdot
.662 .38645 Mdot
.662 .38681 Mdot
.662 .38683 Mdot
.662 .38684 Mdot
.662 .38693 Mdot
.662 .38693 Mdot
.662 .38699 Mdot
.662 .38704 Mdot
.662 .38705 Mdot
.662 .38706 Mdot
.662 .38706 Mdot
.662 .38707 Mdot
.662 .38711 Mdot
.662 .38713 Mdot
.662 .38714 Mdot
.662 .38715 Mdot
.662 .38717 Mdot
.662 .38719 Mdot
.662 .38726 Mdot
.662 .3873 Mdot
.662 .38737 Mdot
.662 .38754 Mdot
.662 .38768 Mdot
.662 .38775 Mdot
.662 .3878 Mdot
.662 .3878 Mdot
.662 .38782 Mdot
.662 .38785 Mdot
.662 .38787 Mdot
.662 .38794 Mdot
.662 .38802 Mdot
.662 .38814 Mdot
.662 .38818 Mdot
.662 .38821 Mdot
.662 .38822 Mdot
.662 .38828 Mdot
.662 .38839 Mdot
.662 .38843 Mdot
.662 .38845 Mdot
.662 .3885 Mdot
.662 .38851 Mdot
.662 .38853 Mdot
.662 .38856 Mdot
.662 .38857 Mdot
.662 .3886 Mdot
.662 .38863 Mdot
.662 .38863 Mdot
.662 .38864 Mdot
.662 .38873 Mdot
.662 .38874 Mdot
.662 .38879 Mdot
.662 .38885 Mdot
.662 .38885 Mdot
.662 .38907 Mdot
.662 .38909 Mdot
.662 .38909 Mdot
.662 .3891 Mdot
.662 .38911 Mdot
.662 .38912 Mdot
.662 .38913 Mdot
.662 .38917 Mdot
.662 .38918 Mdot
.662 .38919 Mdot
.662 .38921 Mdot
.662 .38922 Mdot
.662 .38922 Mdot
.662 .38925 Mdot
.662 .38942 Mdot
.662 .38946 Mdot
.662 .38952 Mdot
.662 .38952 Mdot
.662 .38963 Mdot
.662 .38966 Mdot
.662 .38967 Mdot
.662 .3897 Mdot
.662 .3897 Mdot
.662 .3897 Mdot
.662 .38972 Mdot
.662 .38972 Mdot
.662 .38973 Mdot
.662 .38974 Mdot
.662 .38984 Mdot
.662 .3899 Mdot
.662 .38992 Mdot
.662 .38993 Mdot
.662 .39002 Mdot
.662 .39003 Mdot
.662 .39003 Mdot
.662 .39005 Mdot
.662 .39013 Mdot
.662 .39013 Mdot
.662 .39014 Mdot
.662 .39015 Mdot
.662 .3902 Mdot
.662 .39021 Mdot
.662 .39028 Mdot
.662 .39028 Mdot
.662 .39029 Mdot
.662 .39029 Mdot
.662 .39032 Mdot
.662 .39032 Mdot
.662 .39033 Mdot
.662 .39041 Mdot
.662 .39047 Mdot
.662 .3905 Mdot
.662 .39052 Mdot
.662 .39052 Mdot
.662 .39053 Mdot
.662 .39055 Mdot
.662 .39059 Mdot
.662 .39059 Mdot
.662 .39063 Mdot
.662 .39063 Mdot
.662 .39067 Mdot
.662 .39069 Mdot
.662 .39069 Mdot
.662 .3907 Mdot
.662 .3907 Mdot
.662 .3907 Mdot
.662 .39082 Mdot
.662 .39082 Mdot
.662 .39082 Mdot
.662 .39082 Mdot
.662 .39082 Mdot
.662 .39083 Mdot
.662 .39085 Mdot
.662 .39085 Mdot
.662 .39088 Mdot
.662 .39088 Mdot
.662 .3909 Mdot
.662 .39091 Mdot
.662 .39091 Mdot
.662 .39092 Mdot
.662 .39092 Mdot
.662 .39094 Mdot
.662 .39097 Mdot
.662 .39102 Mdot
.662 .39102 Mdot
.662 .39102 Mdot
.662 .39104 Mdot
.662 .39104 Mdot
.662 .39104 Mdot
.662 .39104 Mdot
.662 .39108 Mdot
.662 .39109 Mdot
.662 .39111 Mdot
.662 .39112 Mdot
.662 .39112 Mdot
.662 .39112 Mdot
.662 .39117 Mdot
.662 .39117 Mdot
.662 .39118 Mdot
.662 .39118 Mdot
.662 .39123 Mdot
.662 .39123 Mdot
.662 .39125 Mdot
.662 .39128 Mdot
.662 .39133 Mdot
.662 .39133 Mdot
.662 .39134 Mdot
.662 .39134 Mdot
.662 .39135 Mdot
.662 .39135 Mdot
.662 .39135 Mdot
.662 .39137 Mdot
.662 .39137 Mdot
.662 .39139 Mdot
.662 .39144 Mdot
.662 .39144 Mdot
.662 .39147 Mdot
.662 .3915 Mdot
.662 .39159 Mdot
.662 .3916 Mdot
.662 .3916 Mdot
.662 .39161 Mdot
.662 .39162 Mdot
.662 .39162 Mdot
.662 .39162 Mdot
.662 .39165 Mdot
.662 .39165 Mdot
.662 .39166 Mdot
.662 .39166 Mdot
.662 .39166 Mdot
.662 .39167 Mdot
.662 .39167 Mdot
.662 .39179 Mdot
.662 .39179 Mdot
.662 .39182 Mdot
.662 .39184 Mdot
.662 .39185 Mdot
.662 .39189 Mdot
.662 .3919 Mdot
.662 .3919 Mdot
.662 .39192 Mdot
.662 .39193 Mdot
.662 .39194 Mdot
.662 .39195 Mdot
.662 .39196 Mdot
.662 .39196 Mdot
.662 .39199 Mdot
.662 .392 Mdot
.662 .39202 Mdot
.662 .39208 Mdot
.662 .39211 Mdot
.662 .39211 Mdot
.662 .39213 Mdot
.662 .39215 Mdot
.662 .39221 Mdot
.662 .39225 Mdot
.662 .39228 Mdot
.662 .39229 Mdot
.662 .39231 Mdot
.662 .39232 Mdot
.662 .39232 Mdot
.662 .39234 Mdot
.662 .39237 Mdot
.662 .39244 Mdot
.662 .39253 Mdot
.662 .39256 Mdot
.662 .39258 Mdot
.662 .39262 Mdot
.662 .39262 Mdot
.662 .39263 Mdot
.662 .39264 Mdot
.662 .39264 Mdot
.662 .39265 Mdot
.662 .39267 Mdot
.662 .39268 Mdot
.662 .39268 Mdot
.662 .39268 Mdot
.662 .39269 Mdot
.662 .39271 Mdot
.662 .39274 Mdot
.662 .39274 Mdot
.662 .39278 Mdot
.662 .39279 Mdot
.662 .3928 Mdot
.662 .39297 Mdot
.662 .39298 Mdot
.662 .39299 Mdot
.662 .39305 Mdot
.662 .39307 Mdot
.662 .39308 Mdot
.662 .39316 Mdot
.662 .39317 Mdot
.662 .39318 Mdot
.662 .39318 Mdot
.662 .39339 Mdot
.662 .3934 Mdot
.662 .39344 Mdot
.662 .39345 Mdot
.662 .39348 Mdot
.662 .39349 Mdot
.662 .3935 Mdot
.662 .39354 Mdot
.662 .39355 Mdot
.662 .39357 Mdot
.662 .39357 Mdot
.662 .3936 Mdot
.662 .39364 Mdot
.662 .39365 Mdot
.662 .39367 Mdot
.662 .39368 Mdot
.662 .39369 Mdot
.662 .3937 Mdot
.662 .39372 Mdot
.662 .39375 Mdot
.662 .39382 Mdot
.662 .39386 Mdot
.662 .39403 Mdot
.662 .39408 Mdot
.662 .39409 Mdot
.662 .39409 Mdot
.662 .39409 Mdot
.662 .39409 Mdot
.662 .39409 Mdot
.662 .39411 Mdot
.662 .39418 Mdot
.662 .39426 Mdot
.662 .39426 Mdot
.662 .39428 Mdot
.662 .39431 Mdot
.662 .39441 Mdot
.662 .39443 Mdot
.662 .39444 Mdot
.662 .39445 Mdot
.662 .39448 Mdot
.662 .39452 Mdot
.662 .39453 Mdot
.662 .39454 Mdot
.662 .39455 Mdot
.662 .39459 Mdot
.662 .39463 Mdot
.662 .39463 Mdot
.662 .39464 Mdot
.662 .39472 Mdot
.662 .39473 Mdot
.662 .39474 Mdot
.662 .39474 Mdot
.662 .39475 Mdot
.662 .39475 Mdot
.662 .39481 Mdot
.662 .39486 Mdot
.662 .39498 Mdot
.662 .39502 Mdot
.662 .39507 Mdot
.662 .39509 Mdot
.662 .39513 Mdot
.662 .39515 Mdot
.662 .39518 Mdot
.662 .39528 Mdot
.662 .39529 Mdot
.662 .39538 Mdot
.662 .39542 Mdot
.662 .39549 Mdot
.662 .39549 Mdot
.662 .39556 Mdot
.662 .39556 Mdot
.662 .39559 Mdot
.662 .39562 Mdot
.662 .39566 Mdot
.662 .39569 Mdot
.662 .3957 Mdot
.662 .39577 Mdot
.662 .39587 Mdot
.662 .39587 Mdot
.662 .39587 Mdot
.662 .39587 Mdot
.662 .39607 Mdot
.662 .39607 Mdot
.662 .39632 Mdot
.662 .39635 Mdot
.662 .39642 Mdot
.662 .39644 Mdot
.662 .39647 Mdot
.662 .39649 Mdot
.662 .39651 Mdot
.662 .39658 Mdot
.662 .3966 Mdot
.662 .39662 Mdot
.662 .39662 Mdot
.662 .39664 Mdot
.662 .39665 Mdot
.662 .39668 Mdot
.662 .39673 Mdot
.662 .39674 Mdot
.662 .39675 Mdot
.662 .39676 Mdot
.662 .39677 Mdot
.662 .39685 Mdot
.662 .39686 Mdot
.662 .39692 Mdot
.662 .39692 Mdot
.662 .39693 Mdot
.662 .39705 Mdot
.662 .39706 Mdot
.662 .39709 Mdot
.662 .3971 Mdot
.662 .39718 Mdot
.662 .39719 Mdot
.662 .3972 Mdot
.662 .39736 Mdot
.662 .39744 Mdot
.662 .39757 Mdot
.662 .3976 Mdot
.662 .39766 Mdot
.662 .39768 Mdot
.662 .39773 Mdot
.662 .39777 Mdot
.662 .39783 Mdot
.662 .39787 Mdot
.662 .39788 Mdot
.662 .39808 Mdot
.662 .3981 Mdot
.662 .39813 Mdot
.662 .39814 Mdot
.662 .39822 Mdot
.662 .39833 Mdot
.662 .39833 Mdot
.662 .39834 Mdot
.662 .39835 Mdot
.662 .39835 Mdot
.662 .39837 Mdot
.662 .39843 Mdot
.662 .3985 Mdot
.662 .3985 Mdot
.662 .39867 Mdot
.662 .39867 Mdot
.662 .39868 Mdot
.662 .3987 Mdot
.662 .3988 Mdot
.662 .39882 Mdot
.662 .3989 Mdot
.662 .39892 Mdot
.662 .39894 Mdot
.662 .39895 Mdot
.662 .39896 Mdot
.662 .39896 Mdot
.662 .39899 Mdot
.662 .39899 Mdot
.662 .39905 Mdot
.662 .39908 Mdot
.662 .39908 Mdot
.662 .39912 Mdot
.662 .39912 Mdot
.662 .39912 Mdot
.662 .3992 Mdot
.662 .39925 Mdot
.662 .39929 Mdot
.662 .39931 Mdot
.662 .39932 Mdot
.662 .39937 Mdot
.662 .39939 Mdot
.662 .39943 Mdot
.662 .39944 Mdot
.662 .3995 Mdot
.662 .3995 Mdot
.662 .39953 Mdot
.662 .39956 Mdot
.662 .39956 Mdot
.662 .39972 Mdot
.662 .39974 Mdot
.662 .39982 Mdot
.662 .39982 Mdot
.662 .39993 Mdot
.662 .39996 Mdot
.662 .39999 Mdot
.662 .40004 Mdot
.662 .40011 Mdot
.662 .40011 Mdot
.662 .40021 Mdot
.662 .40023 Mdot
.662 .40033 Mdot
.662 .40035 Mdot
.662 .40035 Mdot
.662 .40035 Mdot
.662 .40035 Mdot
.662 .40035 Mdot
.662 .40036 Mdot
.662 .40038 Mdot
.662 .40038 Mdot
.662 .40042 Mdot
.662 .40048 Mdot
.662 .40054 Mdot
.662 .40055 Mdot
.662 .40066 Mdot
.662 .40072 Mdot
.662 .40072 Mdot
.662 .40077 Mdot
.662 .40083 Mdot
.662 .40099 Mdot
.662 .40104 Mdot
.662 .40107 Mdot
.662 .4011 Mdot
.662 .40111 Mdot
.662 .40112 Mdot
.662 .40118 Mdot
.662 .40123 Mdot
.662 .40123 Mdot
.662 .40126 Mdot
.662 .40128 Mdot
.662 .40129 Mdot
.662 .40131 Mdot
.662 .40135 Mdot
.662 .40139 Mdot
.662 .40146 Mdot
.662 .40148 Mdot
.662 .40149 Mdot
.662 .40156 Mdot
.662 .40159 Mdot
.662 .40164 Mdot
.662 .40165 Mdot
.662 .40169 Mdot
.662 .40169 Mdot
.662 .4017 Mdot
.662 .40171 Mdot
.662 .40171 Mdot
.662 .40182 Mdot
.662 .40182 Mdot
.662 .40188 Mdot
.662 .40188 Mdot
.662 .40191 Mdot
.662 .40193 Mdot
.662 .40194 Mdot
.662 .40194 Mdot
.662 .40194 Mdot
.662 .40194 Mdot
.662 .40195 Mdot
.662 .40199 Mdot
.662 .40212 Mdot
.662 .40217 Mdot
.662 .40219 Mdot
.662 .40219 Mdot
.662 .40228 Mdot
.662 .40231 Mdot
.662 .40236 Mdot
.662 .40236 Mdot
.662 .40237 Mdot
.662 .4024 Mdot
.662 .40246 Mdot
.662 .40248 Mdot
.662 .40257 Mdot
.662 .4026 Mdot
.662 .40261 Mdot
.662 .40263 Mdot
.662 .40266 Mdot
.662 .40276 Mdot
.662 .40283 Mdot
.662 .40283 Mdot
.662 .40283 Mdot
.662 .40293 Mdot
.662 .40293 Mdot
.662 .40296 Mdot
.662 .40298 Mdot
.662 .40302 Mdot
.662 .40303 Mdot
.662 .40307 Mdot
.662 .40311 Mdot
.662 .40317 Mdot
.662 .4032 Mdot
.662 .4032 Mdot
.662 .40321 Mdot
.662 .40321 Mdot
.662 .40324 Mdot
.662 .40328 Mdot
.662 .40328 Mdot
.662 .40331 Mdot
.662 .40335 Mdot
.662 .40337 Mdot
.662 .40342 Mdot
.662 .40342 Mdot
.662 .40342 Mdot
.662 .40342 Mdot
.662 .40342 Mdot
.662 .40344 Mdot
.662 .4035 Mdot
.662 .40351 Mdot
.662 .40354 Mdot
.662 .40359 Mdot
.662 .4036 Mdot
.662 .40364 Mdot
.662 .40365 Mdot
.662 .40365 Mdot
.662 .40372 Mdot
.662 .40372 Mdot
.662 .40373 Mdot
.662 .40376 Mdot
.662 .40377 Mdot
.662 .40379 Mdot
.662 .40385 Mdot
.662 .40385 Mdot
.662 .40388 Mdot
.662 .40388 Mdot
.662 .40389 Mdot
.662 .4039 Mdot
.662 .4039 Mdot
.662 .40392 Mdot
.662 .40393 Mdot
.662 .40394 Mdot
.662 .40399 Mdot
.662 .40401 Mdot
.662 .40401 Mdot
.662 .40402 Mdot
.662 .40403 Mdot
.662 .40404 Mdot
.662 .40406 Mdot
.662 .4041 Mdot
.662 .40411 Mdot
.662 .40411 Mdot
.662 .40412 Mdot
.662 .40412 Mdot
.662 .40413 Mdot
.662 .40414 Mdot
.662 .40414 Mdot
.662 .40416 Mdot
.662 .40416 Mdot
.662 .40418 Mdot
.662 .40422 Mdot
.662 .40422 Mdot
.662 .40423 Mdot
.662 .40423 Mdot
.662 .40423 Mdot
.662 .40424 Mdot
.662 .40424 Mdot
.662 .40427 Mdot
.662 .40428 Mdot
.662 .40429 Mdot
.662 .40431 Mdot
.662 .40432 Mdot
.662 .40432 Mdot
.662 .40432 Mdot
.662 .40432 Mdot
.662 .40432 Mdot
.662 .40433 Mdot
.662 .40433 Mdot
.662 .40433 Mdot
.662 .40438 Mdot
.662 .40438 Mdot
.662 .40438 Mdot
.662 .4044 Mdot
.662 .4044 Mdot
.662 .40441 Mdot
.662 .40441 Mdot
.662 .40442 Mdot
.662 .40443 Mdot
.662 .40443 Mdot
.662 .40443 Mdot
.662 .40443 Mdot
.662 .40447 Mdot
.662 .40448 Mdot
.662 .40448 Mdot
.662 .40449 Mdot
.662 .40449 Mdot
.662 .40449 Mdot
.662 .4045 Mdot
.662 .4045 Mdot
.662 .4045 Mdot
.662 .4045 Mdot
.662 .4045 Mdot
.664 .35238 Mdot
.664 .35238 Mdot
.664 .35239 Mdot
.664 .35239 Mdot
.664 .35239 Mdot
.664 .35239 Mdot
.664 .3524 Mdot
.664 .3524 Mdot
.664 .3524 Mdot
.664 .35241 Mdot
.664 .35242 Mdot
.664 .35242 Mdot
.664 .35243 Mdot
.664 .35243 Mdot
.664 .35244 Mdot
.664 .35245 Mdot
.664 .35245 Mdot
.664 .35247 Mdot
.664 .35247 Mdot
.664 .35247 Mdot
.664 .35247 Mdot
.664 .35248 Mdot
.664 .35249 Mdot
.664 .35251 Mdot
.664 .35253 Mdot
.664 .35254 Mdot
.664 .35257 Mdot
.664 .35257 Mdot
.664 .35258 Mdot
.664 .35259 Mdot
.664 .35266 Mdot
.664 .35269 Mdot
.664 .3527 Mdot
.664 .35271 Mdot
.664 .35273 Mdot
.664 .35278 Mdot
.664 .35285 Mdot
.664 .35287 Mdot
.664 .35292 Mdot
.664 .35292 Mdot
.664 .35293 Mdot
.664 .35293 Mdot
.664 .35296 Mdot
.664 .35299 Mdot
.664 .35304 Mdot
.664 .35308 Mdot
.664 .35311 Mdot
.664 .35314 Mdot
.664 .35317 Mdot
.664 .35324 Mdot
.664 .35325 Mdot
.664 .35327 Mdot
.664 .35336 Mdot
.664 .3536 Mdot
.664 .3536 Mdot
.664 .3536 Mdot
.664 .35361 Mdot
.664 .35376 Mdot
.664 .35379 Mdot
.664 .35384 Mdot
.664 .35397 Mdot
.664 .35415 Mdot
.664 .35419 Mdot
.664 .35449 Mdot
.664 .35463 Mdot
.664 .35473 Mdot
.664 .35486 Mdot
.664 .3549 Mdot
.664 .35503 Mdot
.664 .35504 Mdot
.664 .35508 Mdot
.664 .35512 Mdot
.664 .35514 Mdot
.664 .35515 Mdot
.664 .35533 Mdot
.664 .35559 Mdot
.664 .35565 Mdot
.664 .35573 Mdot
.664 .35582 Mdot
.664 .35585 Mdot
.664 .35586 Mdot
.664 .35588 Mdot
.664 .35593 Mdot
.664 .35613 Mdot
.664 .35641 Mdot
.664 .35645 Mdot
.664 .35666 Mdot
.664 .35668 Mdot
.664 .35678 Mdot
.664 .35684 Mdot
.664 .3569 Mdot
.664 .35715 Mdot
.664 .35721 Mdot
.664 .35731 Mdot
.664 .35734 Mdot
.664 .35757 Mdot
.664 .35761 Mdot
.664 .35765 Mdot
.664 .35766 Mdot
.664 .35779 Mdot
.664 .35787 Mdot
.664 .35793 Mdot
.664 .35805 Mdot
.664 .35806 Mdot
.664 .35815 Mdot
.664 .35824 Mdot
.664 .35828 Mdot
.664 .35853 Mdot
.664 .35857 Mdot
.664 .35857 Mdot
.664 .35888 Mdot
.664 .35897 Mdot
.664 .35898 Mdot
.664 .35915 Mdot
.664 .35916 Mdot
.664 .35921 Mdot
.664 .3593 Mdot
.664 .35934 Mdot
.664 .35942 Mdot
.664 .35952 Mdot
.664 .35954 Mdot
.664 .35963 Mdot
.664 .3597 Mdot
.664 .35978 Mdot
.664 .35985 Mdot
.664 .35997 Mdot
.664 .35998 Mdot
.664 .36 Mdot
.664 .36001 Mdot
.664 .36005 Mdot
.664 .3601 Mdot
.664 .36052 Mdot
.664 .36052 Mdot
.664 .36063 Mdot
.664 .36067 Mdot
.664 .36088 Mdot
.664 .36088 Mdot
.664 .36103 Mdot
.664 .36105 Mdot
.664 .36115 Mdot
.664 .36116 Mdot
.664 .36118 Mdot
.664 .36129 Mdot
.664 .3613 Mdot
.664 .3613 Mdot
.664 .36136 Mdot
.664 .36144 Mdot
.664 .36146 Mdot
.664 .3615 Mdot
.664 .36162 Mdot
.664 .36164 Mdot
.664 .3617 Mdot
.664 .36172 Mdot
.664 .36173 Mdot
.664 .36179 Mdot
.664 .36181 Mdot
.664 .36184 Mdot
.664 .36195 Mdot
.664 .36197 Mdot
.664 .36199 Mdot
.664 .36233 Mdot
.664 .36281 Mdot
.664 .36319 Mdot
.664 .3635 Mdot
.664 .3635 Mdot
.664 .36373 Mdot
.664 .36395 Mdot
.664 .36428 Mdot
.664 .36429 Mdot
.664 .36445 Mdot
.664 .36491 Mdot
.664 .36492 Mdot
.664 .36522 Mdot
.664 .36531 Mdot
.664 .36555 Mdot
.664 .36576 Mdot
.664 .3658 Mdot
.664 .36614 Mdot
.664 .36636 Mdot
.664 .36656 Mdot
.664 .3667 Mdot
.664 .36726 Mdot
.664 .36728 Mdot
.664 .36733 Mdot
.664 .36735 Mdot
.664 .36736 Mdot
.664 .36739 Mdot
.664 .36743 Mdot
.664 .36744 Mdot
.664 .3675 Mdot
.664 .36752 Mdot
.664 .36753 Mdot
.664 .36757 Mdot
.664 .36759 Mdot
.664 .3676 Mdot
.664 .36766 Mdot
.664 .36766 Mdot
.664 .36772 Mdot
.664 .36773 Mdot
.664 .3678 Mdot
.664 .3678 Mdot
.664 .36791 Mdot
.664 .36793 Mdot
.664 .36798 Mdot
.664 .36798 Mdot
.664 .3682 Mdot
.664 .36822 Mdot
.664 .36824 Mdot
.664 .36825 Mdot
.664 .36826 Mdot
.664 .36833 Mdot
.664 .3684 Mdot
.664 .36849 Mdot
.664 .36859 Mdot
.664 .3687 Mdot
.664 .36879 Mdot
.664 .3688 Mdot
.664 .36884 Mdot
.664 .36902 Mdot
.664 .36925 Mdot
.664 .36931 Mdot
.664 .36938 Mdot
.664 .36955 Mdot
.664 .36959 Mdot
.664 .36981 Mdot
.664 .37005 Mdot
.664 .37015 Mdot
.664 .3703 Mdot
.664 .37065 Mdot
.664 .37069 Mdot
.664 .3707 Mdot
.664 .37071 Mdot
.664 .3708 Mdot
.664 .37086 Mdot
.664 .37109 Mdot
.664 .37124 Mdot
.664 .37147 Mdot
.664 .37166 Mdot
.664 .3721 Mdot
.664 .37227 Mdot
.664 .37241 Mdot
.664 .37247 Mdot
.664 .37266 Mdot
.664 .37268 Mdot
.664 .37311 Mdot
.664 .37313 Mdot
.664 .37323 Mdot
.664 .3733 Mdot
.664 .37334 Mdot
.664 .37341 Mdot
.664 .37354 Mdot
.664 .37358 Mdot
.664 .37359 Mdot
.664 .37373 Mdot
.664 .37396 Mdot
.664 .37412 Mdot
.664 .37443 Mdot
.664 .37448 Mdot
.664 .37452 Mdot
.664 .37468 Mdot
.664 .37469 Mdot
.664 .37479 Mdot
.664 .37479 Mdot
.664 .37488 Mdot
.664 .37493 Mdot
.664 .37493 Mdot
.664 .37507 Mdot
.664 .37509 Mdot
.664 .37515 Mdot
.664 .37522 Mdot
.664 .37529 Mdot
.664 .37534 Mdot
.664 .37555 Mdot
.664 .37565 Mdot
.664 .37575 Mdot
.664 .37578 Mdot
.664 .37593 Mdot
.664 .37599 Mdot
.664 .37613 Mdot
.664 .37613 Mdot
.664 .37616 Mdot
.664 .37621 Mdot
.664 .37644 Mdot
.664 .37645 Mdot
.664 .37647 Mdot
.664 .37651 Mdot
.664 .37675 Mdot
.664 .37675 Mdot
.664 .37679 Mdot
.664 .37708 Mdot
.664 .37716 Mdot
.664 .37717 Mdot
.664 .37728 Mdot
.664 .3775 Mdot
.664 .37766 Mdot
.664 .37777 Mdot
.664 .37804 Mdot
.664 .37805 Mdot
.664 .37821 Mdot
.664 .37861 Mdot
.664 .37887 Mdot
.664 .37906 Mdot
.664 .37918 Mdot
.664 .37928 Mdot
.664 .37928 Mdot
.664 .37932 Mdot
.664 .37934 Mdot
.664 .37936 Mdot
.664 .37966 Mdot
.664 .37981 Mdot
.664 .38 Mdot
.664 .38017 Mdot
.664 .38031 Mdot
.664 .38038 Mdot
.664 .38045 Mdot
.664 .38059 Mdot
.664 .38067 Mdot
.664 .38069 Mdot
.664 .38083 Mdot
.664 .38085 Mdot
.664 .38092 Mdot
.664 .38096 Mdot
.664 .38105 Mdot
.664 .38114 Mdot
.664 .38116 Mdot
.664 .38128 Mdot
.664 .3813 Mdot
.664 .38157 Mdot
.664 .3816 Mdot
.664 .38164 Mdot
.664 .38169 Mdot
.664 .38173 Mdot
.664 .38178 Mdot
.664 .38185 Mdot
.664 .38193 Mdot
.664 .38242 Mdot
.664 .38248 Mdot
.664 .38264 Mdot
.664 .38265 Mdot
.664 .38274 Mdot
.664 .38288 Mdot
.664 .38306 Mdot
.664 .38331 Mdot
.664 .38339 Mdot
.664 .38359 Mdot
.664 .38359 Mdot
.664 .38381 Mdot
.664 .38381 Mdot
.664 .38402 Mdot
.664 .38409 Mdot
.664 .38421 Mdot
.664 .3844 Mdot
.664 .3846 Mdot
.664 .3846 Mdot
.664 .38461 Mdot
.664 .38462 Mdot
.664 .38463 Mdot
.664 .38463 Mdot
.664 .38465 Mdot
.664 .38466 Mdot
.664 .38466 Mdot
.664 .38467 Mdot
.664 .38468 Mdot
.664 .38468 Mdot
.664 .3847 Mdot
.664 .3847 Mdot
.664 .38472 Mdot
.664 .38472 Mdot
.664 .38475 Mdot
.664 .38475 Mdot
.664 .38478 Mdot
.664 .38479 Mdot
.664 .3848 Mdot
.664 .3848 Mdot
.664 .38487 Mdot
.664 .38488 Mdot
.664 .38489 Mdot
.664 .38489 Mdot
.664 .38489 Mdot
.664 .38491 Mdot
.664 .38496 Mdot
.664 .38499 Mdot
.664 .38502 Mdot
.664 .38507 Mdot
.664 .38512 Mdot
.664 .38519 Mdot
.664 .38521 Mdot
.664 .38523 Mdot
.664 .38528 Mdot
.664 .38536 Mdot
.664 .38543 Mdot
.664 .38551 Mdot
.664 .38561 Mdot
.664 .38562 Mdot
.664 .38565 Mdot
.664 .38567 Mdot
.664 .38574 Mdot
.664 .38578 Mdot
.664 .3859 Mdot
.664 .38603 Mdot
.664 .38608 Mdot
.664 .38614 Mdot
.664 .38619 Mdot
.664 .3862 Mdot
.664 .38632 Mdot
.664 .38632 Mdot
.664 .38635 Mdot
.664 .38637 Mdot
.664 .38638 Mdot
.664 .3864 Mdot
.664 .38644 Mdot
.664 .38645 Mdot
.664 .38649 Mdot
.664 .38656 Mdot
.664 .3866 Mdot
.664 .38676 Mdot
.664 .38676 Mdot
.664 .38679 Mdot
.664 .38681 Mdot
.664 .38682 Mdot
.664 .3869 Mdot
.664 .38699 Mdot
.664 .3871 Mdot
.664 .38718 Mdot
.664 .38724 Mdot
.664 .38732 Mdot
.664 .38741 Mdot
.664 .38746 Mdot
.664 .38752 Mdot
.664 .38771 Mdot
.664 .38782 Mdot
.664 .38789 Mdot
.664 .38801 Mdot
.664 .38827 Mdot
.664 .38834 Mdot
.664 .38837 Mdot
.664 .38841 Mdot
.664 .38843 Mdot
.664 .38847 Mdot
.664 .38849 Mdot
.664 .3886 Mdot
.664 .38861 Mdot
.664 .38862 Mdot
.664 .38866 Mdot
.664 .38868 Mdot
.664 .38883 Mdot
.664 .38884 Mdot
.664 .38895 Mdot
.664 .38899 Mdot
.664 .38913 Mdot
.664 .38925 Mdot
.664 .3894 Mdot
.664 .3894 Mdot
.664 .3894 Mdot
.664 .38941 Mdot
.664 .38941 Mdot
.664 .38941 Mdot
.664 .38941 Mdot
.664 .38942 Mdot
.664 .38942 Mdot
.664 .38942 Mdot
.664 .38942 Mdot
.664 .38943 Mdot
.664 .38943 Mdot
.664 .38943 Mdot
.664 .38944 Mdot
.664 .38944 Mdot
.664 .38945 Mdot
.664 .38945 Mdot
.664 .38945 Mdot
.664 .38947 Mdot
.664 .38948 Mdot
.664 .38948 Mdot
.664 .38948 Mdot
.664 .38948 Mdot
.664 .3895 Mdot
.664 .3895 Mdot
.664 .38951 Mdot
.664 .38952 Mdot
.664 .38954 Mdot
.664 .38956 Mdot
.664 .38956 Mdot
.664 .38957 Mdot
.664 .38958 Mdot
.664 .38964 Mdot
.664 .38967 Mdot
.664 .38967 Mdot
.664 .38968 Mdot
.664 .3897 Mdot
.664 .38975 Mdot
.664 .38978 Mdot
.664 .38979 Mdot
.664 .38981 Mdot
.664 .38982 Mdot
.664 .38982 Mdot
.664 .38986 Mdot
.664 .38986 Mdot
.664 .38987 Mdot
.664 .38987 Mdot
.664 .38988 Mdot
.664 .38989 Mdot
.664 .3899 Mdot
.664 .38993 Mdot
.664 .38997 Mdot
.664 .38998 Mdot
.664 .38999 Mdot
.664 .39001 Mdot
.664 .39004 Mdot
.664 .39006 Mdot
.664 .39008 Mdot
.664 .39015 Mdot
.664 .39016 Mdot
.664 .39018 Mdot
.664 .39023 Mdot
.664 .39026 Mdot
.664 .39031 Mdot
.664 .3904 Mdot
.664 .39043 Mdot
.664 .39047 Mdot
.664 .39047 Mdot
.664 .39047 Mdot
.664 .39048 Mdot
.664 .39053 Mdot
.664 .39057 Mdot
.664 .39061 Mdot
.664 .39064 Mdot
.664 .39069 Mdot
.664 .39071 Mdot
.664 .39081 Mdot
.664 .39096 Mdot
.664 .39097 Mdot
.664 .39101 Mdot
.664 .39128 Mdot
.664 .39141 Mdot
.664 .39148 Mdot
.664 .39151 Mdot
.664 .39156 Mdot
.664 .39158 Mdot
.664 .39162 Mdot
.664 .39166 Mdot
.664 .39178 Mdot
.664 .39179 Mdot
.664 .39183 Mdot
.664 .39185 Mdot
.664 .39187 Mdot
.664 .39188 Mdot
.664 .39189 Mdot
.664 .39203 Mdot
.664 .39207 Mdot
.664 .39207 Mdot
.664 .39216 Mdot
.664 .39221 Mdot
.664 .39228 Mdot
.664 .39231 Mdot
.664 .39236 Mdot
.664 .39237 Mdot
.664 .39244 Mdot
.664 .39245 Mdot
.664 .39247 Mdot
.664 .39247 Mdot
.664 .39247 Mdot
.664 .39253 Mdot
.664 .39254 Mdot
.664 .39256 Mdot
.664 .39257 Mdot
.664 .39259 Mdot
.664 .3926 Mdot
.664 .39264 Mdot
.664 .39276 Mdot
.664 .39282 Mdot
.664 .39285 Mdot
.664 .3929 Mdot
.664 .39299 Mdot
.664 .39302 Mdot
.664 .39305 Mdot
.664 .39309 Mdot
.664 .39313 Mdot
.664 .39316 Mdot
.664 .39319 Mdot
.664 .39324 Mdot
.664 .39328 Mdot
.664 .39332 Mdot
.664 .39333 Mdot
.664 .39334 Mdot
.664 .39335 Mdot
.664 .39335 Mdot
.664 .39343 Mdot
.664 .39345 Mdot
.664 .39348 Mdot
.664 .39349 Mdot
.664 .3935 Mdot
.664 .39352 Mdot
.664 .39353 Mdot
.664 .39353 Mdot
.664 .39354 Mdot
.664 .39355 Mdot
.664 .39356 Mdot
.664 .39361 Mdot
.664 .39361 Mdot
.664 .39364 Mdot
.664 .39366 Mdot
.664 .39369 Mdot
.664 .39374 Mdot
.664 .3938 Mdot
.664 .39382 Mdot
.664 .39385 Mdot
.664 .39386 Mdot
.664 .39387 Mdot
.664 .39388 Mdot
.664 .39392 Mdot
.664 .39396 Mdot
.664 .39399 Mdot
.664 .39403 Mdot
.664 .39405 Mdot
.664 .39406 Mdot
.664 .39407 Mdot
.664 .3941 Mdot
.664 .39412 Mdot
.664 .39414 Mdot
.664 .39415 Mdot
.664 .39417 Mdot
.664 .39419 Mdot
.664 .3942 Mdot
.664 .3942 Mdot
.664 .3942 Mdot
.664 .39421 Mdot
.664 .39421 Mdot
.664 .39424 Mdot
.664 .39424 Mdot
.664 .39425 Mdot
.664 .39425 Mdot
.664 .39426 Mdot
.664 .39426 Mdot
.664 .39427 Mdot
.664 .39427 Mdot
.664 .39428 Mdot
.664 .39428 Mdot
.664 .39429 Mdot
.664 .39429 Mdot
.664 .3943 Mdot
.664 .3943 Mdot
.664 .3943 Mdot
.664 .39431 Mdot
.664 .39431 Mdot
.664 .39432 Mdot
.664 .39432 Mdot
.664 .39432 Mdot
.664 .39433 Mdot
.664 .39433 Mdot
.664 .39442 Mdot
.664 .3945 Mdot
.664 .39455 Mdot
.664 .39458 Mdot
.664 .39468 Mdot
.664 .39468 Mdot
.664 .39477 Mdot
.664 .39477 Mdot
.664 .39485 Mdot
.664 .39489 Mdot
.664 .395 Mdot
.664 .39507 Mdot
.664 .39513 Mdot
.664 .39517 Mdot
.664 .39518 Mdot
.664 .39524 Mdot
.664 .39527 Mdot
.664 .39547 Mdot
.664 .39551 Mdot
.664 .39553 Mdot
.664 .39556 Mdot
.664 .39557 Mdot
.664 .3956 Mdot
.664 .39561 Mdot
.664 .39562 Mdot
.664 .39573 Mdot
.664 .39574 Mdot
.664 .39579 Mdot
.664 .3958 Mdot
.664 .39584 Mdot
.664 .39587 Mdot
.664 .39589 Mdot
.664 .39592 Mdot
.664 .39593 Mdot
.664 .39599 Mdot
.664 .39599 Mdot
.664 .39603 Mdot
.664 .39608 Mdot
.664 .39611 Mdot
.664 .39614 Mdot
.664 .3962 Mdot
.664 .39626 Mdot
.664 .39634 Mdot
.664 .3964 Mdot
.664 .39652 Mdot
.664 .39653 Mdot
.664 .39654 Mdot
.664 .39655 Mdot
.664 .39655 Mdot
.664 .39659 Mdot
.664 .39664 Mdot
.664 .39672 Mdot
.664 .39682 Mdot
.664 .39698 Mdot
.664 .39704 Mdot
.664 .39704 Mdot
.664 .39714 Mdot
.664 .39719 Mdot
.664 .39725 Mdot
.664 .39733 Mdot
.664 .39738 Mdot
.664 .39738 Mdot
.664 .39741 Mdot
.664 .39752 Mdot
.664 .39754 Mdot
.664 .39754 Mdot
.664 .39763 Mdot
.664 .39764 Mdot
.664 .39765 Mdot
.664 .39766 Mdot
.664 .39774 Mdot
.664 .39776 Mdot
.664 .39778 Mdot
.664 .39778 Mdot
.664 .39783 Mdot
.664 .39785 Mdot
.664 .39791 Mdot
.664 .39792 Mdot
.664 .39795 Mdot
.664 .39799 Mdot
.664 .39807 Mdot
.664 .39809 Mdot
.664 .39812 Mdot
.664 .39814 Mdot
.664 .39816 Mdot
.664 .39817 Mdot
.664 .39822 Mdot
.664 .39822 Mdot
.664 .39824 Mdot
.664 .39827 Mdot
.664 .39827 Mdot
.664 .39831 Mdot
.664 .39832 Mdot
.664 .39837 Mdot
.664 .39839 Mdot
.664 .39841 Mdot
.664 .39852 Mdot
.664 .39858 Mdot
.664 .39867 Mdot
.664 .39872 Mdot
.664 .39872 Mdot
.664 .39874 Mdot
.664 .39878 Mdot
.664 .39881 Mdot
.664 .39882 Mdot
.664 .39885 Mdot
.664 .39889 Mdot
.664 .39889 Mdot
.664 .39905 Mdot
.664 .39905 Mdot
.664 .39912 Mdot
.664 .39914 Mdot
.664 .39919 Mdot
.664 .39925 Mdot
.664 .39941 Mdot
.664 .39948 Mdot
.664 .39956 Mdot
.664 .39961 Mdot
.664 .3997 Mdot
.664 .39972 Mdot
.664 .39975 Mdot
.664 .39975 Mdot
.664 .39976 Mdot
.664 .39977 Mdot
.664 .39989 Mdot
.664 .39995 Mdot
.664 .39998 Mdot
.664 .40006 Mdot
.664 .40014 Mdot
.664 .40016 Mdot
.664 .40021 Mdot
.664 .40024 Mdot
.664 .40026 Mdot
.664 .40034 Mdot
.664 .4004 Mdot
.664 .40042 Mdot
.664 .40042 Mdot
.664 .40045 Mdot
.664 .40049 Mdot
.664 .40052 Mdot
.664 .40055 Mdot
.664 .40058 Mdot
.664 .4006 Mdot
.664 .4006 Mdot
.664 .40061 Mdot
.664 .40061 Mdot
.664 .40062 Mdot
.664 .40069 Mdot
.664 .40069 Mdot
.664 .40071 Mdot
.664 .40072 Mdot
.664 .40076 Mdot
.664 .40076 Mdot
.664 .40078 Mdot
.664 .40078 Mdot
.664 .4008 Mdot
.664 .40081 Mdot
.664 .40083 Mdot
.664 .40083 Mdot
.664 .40084 Mdot
.664 .40085 Mdot
.664 .40085 Mdot
.664 .40086 Mdot
.664 .40088 Mdot
.664 .40088 Mdot
.664 .4009 Mdot
.664 .40091 Mdot
.664 .40091 Mdot
.664 .40092 Mdot
.664 .40093 Mdot
.664 .40094 Mdot
.664 .40113 Mdot
.664 .40118 Mdot
.664 .40125 Mdot
.664 .40132 Mdot
.664 .40143 Mdot
.664 .40145 Mdot
.664 .40152 Mdot
.664 .4016 Mdot
.664 .40163 Mdot
.664 .40172 Mdot
.664 .40173 Mdot
.664 .40188 Mdot
.664 .40193 Mdot
.664 .40194 Mdot
.664 .40204 Mdot
.664 .40212 Mdot
.664 .40219 Mdot
.664 .40219 Mdot
.664 .40229 Mdot
.664 .40242 Mdot
.664 .40257 Mdot
.664 .40268 Mdot
.664 .40269 Mdot
.664 .4027 Mdot
.664 .40273 Mdot
.664 .40274 Mdot
.664 .40275 Mdot
.664 .40277 Mdot
.664 .40277 Mdot
.664 .40278 Mdot
.664 .4028 Mdot
.664 .4028 Mdot
.664 .40284 Mdot
.664 .40285 Mdot
.664 .40286 Mdot
.664 .40289 Mdot
.664 .4029 Mdot
.664 .4029 Mdot
.664 .40291 Mdot
.664 .40295 Mdot
.664 .40295 Mdot
.664 .40295 Mdot
.664 .40299 Mdot
.664 .40299 Mdot
.664 .40304 Mdot
.664 .40304 Mdot
.664 .40311 Mdot
.664 .40312 Mdot
.664 .40316 Mdot
.664 .40316 Mdot
.664 .40329 Mdot
.664 .40331 Mdot
.664 .40332 Mdot
.664 .40332 Mdot
.664 .40333 Mdot
.664 .40333 Mdot
.664 .40337 Mdot
.664 .40339 Mdot
.664 .40341 Mdot
.664 .40344 Mdot
.664 .40347 Mdot
.664 .40347 Mdot
.664 .4035 Mdot
.664 .40353 Mdot
.664 .40354 Mdot
.664 .40357 Mdot
.664 .40359 Mdot
.664 .40359 Mdot
.664 .40364 Mdot
.664 .40365 Mdot
.664 .40368 Mdot
.664 .40377 Mdot
.664 .40377 Mdot
.664 .40379 Mdot
.664 .40386 Mdot
.664 .40388 Mdot
.664 .4039 Mdot
.664 .40393 Mdot
.664 .40393 Mdot
.664 .40397 Mdot
.664 .40399 Mdot
.664 .40402 Mdot
.664 .40406 Mdot
.664 .40406 Mdot
.664 .40407 Mdot
.664 .40409 Mdot
.664 .40416 Mdot
.664 .40417 Mdot
.664 .4042 Mdot
.664 .40422 Mdot
.664 .4043 Mdot
.664 .40431 Mdot
.664 .40433 Mdot
.664 .40436 Mdot
.664 .40437 Mdot
.664 .40443 Mdot
.664 .40445 Mdot
.664 .40453 Mdot
.664 .40459 Mdot
.664 .40461 Mdot
.664 .40462 Mdot
.664 .40462 Mdot
.664 .40463 Mdot
.664 .40466 Mdot
.664 .40468 Mdot
.664 .4047 Mdot
.664 .40478 Mdot
.664 .40484 Mdot
.664 .40484 Mdot
.664 .40484 Mdot
.664 .40485 Mdot
.664 .40487 Mdot
.664 .40487 Mdot
.664 .40491 Mdot
.664 .40492 Mdot
.664 .40496 Mdot
.664 .40499 Mdot
.664 .40504 Mdot
.664 .40513 Mdot
.664 .40514 Mdot
.664 .40519 Mdot
.664 .40523 Mdot
.664 .40525 Mdot
.664 .40526 Mdot
.664 .4053 Mdot
.664 .40531 Mdot
.664 .40531 Mdot
.664 .40531 Mdot
.664 .40538 Mdot
.664 .40541 Mdot
.664 .40541 Mdot
.664 .40542 Mdot
.664 .40544 Mdot
.664 .40545 Mdot
.664 .40546 Mdot
.664 .40546 Mdot
.664 .40548 Mdot
.664 .40549 Mdot
.664 .4055 Mdot
.664 .40551 Mdot
.664 .40551 Mdot
.664 .40551 Mdot
.664 .40552 Mdot
.664 .40553 Mdot
.664 .40554 Mdot
.664 .40556 Mdot
.664 .40557 Mdot
.664 .40558 Mdot
.664 .40558 Mdot
.664 .40558 Mdot
.664 .40559 Mdot
.664 .40561 Mdot
.664 .40562 Mdot
.664 .40562 Mdot
.664 .40562 Mdot
.664 .40563 Mdot
.664 .40563 Mdot
.664 .40564 Mdot
.664 .40564 Mdot
.664 .40565 Mdot
.664 .40565 Mdot
.664 .40565 Mdot
.664 .40565 Mdot
.664 .40565 Mdot
.664 .40566 Mdot
.664 .40566 Mdot
.664 .40566 Mdot
.664 .40566 Mdot
.664 .40566 Mdot
.664 .40567 Mdot
.664 .40567 Mdot
.664 .40567 Mdot
.664 .40567 Mdot
.664 .40567 Mdot
.664 .40567 Mdot
.664 .40567 Mdot
.664 .40567 Mdot
.664 .40568 Mdot
.664 .40568 Mdot
.664 .40568 Mdot
.664 .40568 Mdot
.666 .34945 Mdot
.666 .34945 Mdot
.666 .34945 Mdot
.666 .34946 Mdot
.666 .34946 Mdot
.666 .34947 Mdot
.666 .34948 Mdot
.666 .34949 Mdot
.666 .34952 Mdot
.666 .34953 Mdot
.666 .34954 Mdot
.666 .34956 Mdot
.666 .34956 Mdot
.666 .34956 Mdot
.666 .34959 Mdot
.666 .34966 Mdot
.666 .3497 Mdot
.666 .34974 Mdot
.666 .34974 Mdot
.666 .34978 Mdot
.666 .3498 Mdot
.666 .34992 Mdot
.666 .34993 Mdot
.666 .35002 Mdot
.666 .35002 Mdot
.666 .35016 Mdot
.666 .35037 Mdot
.666 .35038 Mdot
.666 .35049 Mdot
.666 .35057 Mdot
.666 .35059 Mdot
.666 .35061 Mdot
.666 .35061 Mdot
.666 .35068 Mdot
.666 .3508 Mdot
.666 .35082 Mdot
.666 .35083 Mdot
.666 .35085 Mdot
.666 .35085 Mdot
.666 .35086 Mdot
.666 .35087 Mdot
.666 .35087 Mdot
.666 .35088 Mdot
.666 .35088 Mdot
.666 .35089 Mdot
.666 .35091 Mdot
.666 .35093 Mdot
.666 .35095 Mdot
.666 .35098 Mdot
.666 .35104 Mdot
.666 .35108 Mdot
.666 .35113 Mdot
.666 .35113 Mdot
.666 .3512 Mdot
.666 .35121 Mdot
.666 .35122 Mdot
.666 .35131 Mdot
.666 .35139 Mdot
.666 .35141 Mdot
.666 .35142 Mdot
.666 .35144 Mdot
.666 .35157 Mdot
.666 .3516 Mdot
.666 .3517 Mdot
.666 .3517 Mdot
.666 .35171 Mdot
.666 .35179 Mdot
.666 .35185 Mdot
.666 .35186 Mdot
.666 .35187 Mdot
.666 .35204 Mdot
.666 .35205 Mdot
.666 .35207 Mdot
.666 .3521 Mdot
.666 .35213 Mdot
.666 .35216 Mdot
.666 .35217 Mdot
.666 .35228 Mdot
.666 .35242 Mdot
.666 .35242 Mdot
.666 .3525 Mdot
.666 .35257 Mdot
.666 .35261 Mdot
.666 .35262 Mdot
.666 .35269 Mdot
.666 .3531 Mdot
.666 .35311 Mdot
.666 .35312 Mdot
.666 .35325 Mdot
.666 .35336 Mdot
.666 .35357 Mdot
.666 .35365 Mdot
.666 .35369 Mdot
.666 .35369 Mdot
.666 .35386 Mdot
.666 .35389 Mdot
.666 .3539 Mdot
.666 .354 Mdot
.666 .35412 Mdot
.666 .35422 Mdot
.666 .35429 Mdot
.666 .35473 Mdot
.666 .35493 Mdot
.666 .355 Mdot
.666 .35509 Mdot
.666 .35517 Mdot
.666 .35517 Mdot
.666 .35564 Mdot
.666 .35568 Mdot
.666 .35571 Mdot
.666 .35579 Mdot
.666 .35585 Mdot
.666 .35586 Mdot
.666 .35588 Mdot
.666 .35603 Mdot
.666 .35611 Mdot
.666 .35612 Mdot
.666 .35618 Mdot
.666 .35633 Mdot
.666 .35646 Mdot
.666 .3566 Mdot
.666 .3567 Mdot
.666 .35673 Mdot
.666 .35676 Mdot
.666 .35714 Mdot
.666 .35724 Mdot
.666 .3573 Mdot
.666 .35737 Mdot
.666 .35756 Mdot
.666 .35767 Mdot
.666 .35777 Mdot
.666 .35798 Mdot
.666 .35808 Mdot
.666 .35819 Mdot
.666 .35833 Mdot
.666 .35838 Mdot
.666 .35842 Mdot
.666 .35846 Mdot
.666 .35859 Mdot
.666 .35865 Mdot
.666 .35874 Mdot
.666 .35875 Mdot
.666 .35877 Mdot
.666 .35887 Mdot
.666 .35888 Mdot
.666 .35895 Mdot
.666 .35898 Mdot
.666 .35914 Mdot
.666 .35926 Mdot
.666 .35937 Mdot
.666 .3594 Mdot
.666 .35949 Mdot
.666 .35968 Mdot
.666 .35969 Mdot
.666 .3597 Mdot
.666 .35976 Mdot
.666 .35979 Mdot
.666 .35984 Mdot
.666 .3599 Mdot
.666 .36009 Mdot
.666 .36029 Mdot
.666 .36029 Mdot
.666 .36032 Mdot
.666 .36051 Mdot
.666 .3606 Mdot
.666 .36085 Mdot
.666 .36096 Mdot
.666 .36104 Mdot
.666 .36107 Mdot
.666 .36111 Mdot
.666 .3618 Mdot
.666 .36192 Mdot
.666 .36194 Mdot
.666 .36233 Mdot
.666 .36237 Mdot
.666 .36283 Mdot
.666 .36286 Mdot
.666 .36313 Mdot
.666 .36327 Mdot
.666 .36371 Mdot
.666 .36388 Mdot
.666 .36401 Mdot
.666 .36404 Mdot
.666 .36416 Mdot
.666 .36423 Mdot
.666 .36519 Mdot
.666 .36562 Mdot
.666 .36594 Mdot
.666 .36654 Mdot
.666 .36674 Mdot
.666 .36684 Mdot
.666 .36701 Mdot
.666 .36704 Mdot
.666 .36706 Mdot
.666 .36708 Mdot
.666 .36711 Mdot
.666 .36724 Mdot
.666 .36726 Mdot
.666 .36744 Mdot
.666 .36786 Mdot
.666 .36806 Mdot
.666 .36812 Mdot
.666 .36821 Mdot
.666 .36828 Mdot
.666 .36882 Mdot
.666 .36885 Mdot
.666 .36899 Mdot
.666 .36903 Mdot
.666 .36907 Mdot
.666 .36911 Mdot
.666 .36937 Mdot
.666 .37007 Mdot
.666 .37013 Mdot
.666 .37013 Mdot
.666 .37113 Mdot
.666 .37124 Mdot
.666 .37133 Mdot
.666 .37138 Mdot
.666 .37141 Mdot
.666 .37142 Mdot
.666 .37157 Mdot
.666 .3718 Mdot
.666 .37194 Mdot
.666 .37197 Mdot
.666 .37231 Mdot
.666 .37243 Mdot
.666 .37249 Mdot
.666 .37254 Mdot
.666 .37278 Mdot
.666 .3728 Mdot
.666 .37282 Mdot
.666 .37305 Mdot
.666 .37374 Mdot
.666 .37396 Mdot
.666 .374 Mdot
.666 .37428 Mdot
.666 .37449 Mdot
.666 .37459 Mdot
.666 .37468 Mdot
.666 .37476 Mdot
.666 .37497 Mdot
.666 .37517 Mdot
.666 .37525 Mdot
.666 .37535 Mdot
.666 .37565 Mdot
.666 .37568 Mdot
.666 .37575 Mdot
.666 .37589 Mdot
.666 .37612 Mdot
.666 .37621 Mdot
.666 .37622 Mdot
.666 .37661 Mdot
.666 .37669 Mdot
.666 .3767 Mdot
.666 .37706 Mdot
.666 .3772 Mdot
.666 .3772 Mdot
.666 .37741 Mdot
.666 .37768 Mdot
.666 .37782 Mdot
.666 .37795 Mdot
.666 .37803 Mdot
.666 .37815 Mdot
.666 .37817 Mdot
.666 .3782 Mdot
.666 .3782 Mdot
.666 .37821 Mdot
.666 .37822 Mdot
.666 .37823 Mdot
.666 .37823 Mdot
.666 .37824 Mdot
.666 .37826 Mdot
.666 .3783 Mdot
.666 .37832 Mdot
.666 .37841 Mdot
.666 .37846 Mdot
.666 .37846 Mdot
.666 .37853 Mdot
.666 .37854 Mdot
.666 .37854 Mdot
.666 .37862 Mdot
.666 .37869 Mdot
.666 .37871 Mdot
.666 .37883 Mdot
.666 .37893 Mdot
.666 .37893 Mdot
.666 .37894 Mdot
.666 .37901 Mdot
.666 .37905 Mdot
.666 .37906 Mdot
.666 .37919 Mdot
.666 .37925 Mdot
.666 .37928 Mdot
.666 .37945 Mdot
.666 .3795 Mdot
.666 .37955 Mdot
.666 .37957 Mdot
.666 .37959 Mdot
.666 .37963 Mdot
.666 .37989 Mdot
.666 .37989 Mdot
.666 .3799 Mdot
.666 .37998 Mdot
.666 .38004 Mdot
.666 .38016 Mdot
.666 .38021 Mdot
.666 .38023 Mdot
.666 .38032 Mdot
.666 .38047 Mdot
.666 .38052 Mdot
.666 .38055 Mdot
.666 .38078 Mdot
.666 .38088 Mdot
.666 .38091 Mdot
.666 .38096 Mdot
.666 .38099 Mdot
.666 .38124 Mdot
.666 .38132 Mdot
.666 .38133 Mdot
.666 .3814 Mdot
.666 .38143 Mdot
.666 .38153 Mdot
.666 .38159 Mdot
.666 .38165 Mdot
.666 .38169 Mdot
.666 .38171 Mdot
.666 .38172 Mdot
.666 .38182 Mdot
.666 .38188 Mdot
.666 .38195 Mdot
.666 .38214 Mdot
.666 .38222 Mdot
.666 .38231 Mdot
.666 .38236 Mdot
.666 .38238 Mdot
.666 .3824 Mdot
.666 .38241 Mdot
.666 .38246 Mdot
.666 .38248 Mdot
.666 .38252 Mdot
.666 .38252 Mdot
.666 .38253 Mdot
.666 .38257 Mdot
.666 .38257 Mdot
.666 .3826 Mdot
.666 .38267 Mdot
.666 .38272 Mdot
.666 .3828 Mdot
.666 .38287 Mdot
.666 .38288 Mdot
.666 .38302 Mdot
.666 .38309 Mdot
.666 .3831 Mdot
.666 .3832 Mdot
.666 .38329 Mdot
.666 .38335 Mdot
.666 .38336 Mdot
.666 .38338 Mdot
.666 .38361 Mdot
.666 .38365 Mdot
.666 .38366 Mdot
.666 .38379 Mdot
.666 .38395 Mdot
.666 .38396 Mdot
.666 .38409 Mdot
.666 .38423 Mdot
.666 .38429 Mdot
.666 .38433 Mdot
.666 .38433 Mdot
.666 .3844 Mdot
.666 .38469 Mdot
.666 .38482 Mdot
.666 .38491 Mdot
.666 .38518 Mdot
.666 .38523 Mdot
.666 .38524 Mdot
.666 .38525 Mdot
.666 .38529 Mdot
.666 .3853 Mdot
.666 .38553 Mdot
.666 .38554 Mdot
.666 .38557 Mdot
.666 .38559 Mdot
.666 .38574 Mdot
.666 .38575 Mdot
.666 .3858 Mdot
.666 .38581 Mdot
.666 .38582 Mdot
.666 .3861 Mdot
.666 .38637 Mdot
.666 .3864 Mdot
.666 .38644 Mdot
.666 .38645 Mdot
.666 .38649 Mdot
.666 .38655 Mdot
.666 .38659 Mdot
.666 .3866 Mdot
.666 .38669 Mdot
.666 .38675 Mdot
.666 .38681 Mdot
.666 .38682 Mdot
.666 .38688 Mdot
.666 .38706 Mdot
.666 .38712 Mdot
.666 .38713 Mdot
.666 .3872 Mdot
.666 .38726 Mdot
.666 .38743 Mdot
.666 .38748 Mdot
.666 .38755 Mdot
.666 .38756 Mdot
.666 .38758 Mdot
.666 .3877 Mdot
.666 .3877 Mdot
.666 .38791 Mdot
.666 .38795 Mdot
.666 .388 Mdot
.666 .38818 Mdot
.666 .3882 Mdot
.666 .3882 Mdot
.666 .38821 Mdot
.666 .38821 Mdot
.666 .38821 Mdot
.666 .38821 Mdot
.666 .38822 Mdot
.666 .38823 Mdot
.666 .38825 Mdot
.666 .38826 Mdot
.666 .38826 Mdot
.666 .38828 Mdot
.666 .38828 Mdot
.666 .38828 Mdot
.666 .3883 Mdot
.666 .38832 Mdot
.666 .38836 Mdot
.666 .38838 Mdot
.666 .38838 Mdot
.666 .38841 Mdot
.666 .38841 Mdot
.666 .38845 Mdot
.666 .38846 Mdot
.666 .38851 Mdot
.666 .38852 Mdot
.666 .38853 Mdot
.666 .38854 Mdot
.666 .38856 Mdot
.666 .38862 Mdot
.666 .38862 Mdot
.666 .38862 Mdot
.666 .38869 Mdot
.666 .38873 Mdot
.666 .38887 Mdot
.666 .38888 Mdot
.666 .38889 Mdot
.666 .38898 Mdot
.666 .38899 Mdot
.666 .38904 Mdot
.666 .38906 Mdot
.666 .38907 Mdot
.666 .38907 Mdot
.666 .38907 Mdot
.666 .3891 Mdot
.666 .38913 Mdot
.666 .3892 Mdot
.666 .38922 Mdot
.666 .38924 Mdot
.666 .38924 Mdot
.666 .38924 Mdot
.666 .38926 Mdot
.666 .38926 Mdot
.666 .38927 Mdot
.666 .38927 Mdot
.666 .38928 Mdot
.666 .38928 Mdot
.666 .38929 Mdot
.666 .38929 Mdot
.666 .38931 Mdot
.666 .38932 Mdot
.666 .38934 Mdot
.666 .38936 Mdot
.666 .3894 Mdot
.666 .38941 Mdot
.666 .38944 Mdot
.666 .38946 Mdot
.666 .38948 Mdot
.666 .38948 Mdot
.666 .38954 Mdot
.666 .38955 Mdot
.666 .38955 Mdot
.666 .38963 Mdot
.666 .3897 Mdot
.666 .38971 Mdot
.666 .38972 Mdot
.666 .38974 Mdot
.666 .38981 Mdot
.666 .38984 Mdot
.666 .38987 Mdot
.666 .38995 Mdot
.666 .38995 Mdot
.666 .38996 Mdot
.666 .39002 Mdot
.666 .39003 Mdot
.666 .39003 Mdot
.666 .39007 Mdot
.666 .39007 Mdot
.666 .39009 Mdot
.666 .39009 Mdot
.666 .39023 Mdot
.666 .39024 Mdot
.666 .39025 Mdot
.666 .39026 Mdot
.666 .39029 Mdot
.666 .39031 Mdot
.666 .39034 Mdot
.666 .39034 Mdot
.666 .39036 Mdot
.666 .39044 Mdot
.666 .39053 Mdot
.666 .39053 Mdot
.666 .39056 Mdot
.666 .39056 Mdot
.666 .39062 Mdot
.666 .39063 Mdot
.666 .39064 Mdot
.666 .39069 Mdot
.666 .39072 Mdot
.666 .39074 Mdot
.666 .39077 Mdot
.666 .3908 Mdot
.666 .39091 Mdot
.666 .39092 Mdot
.666 .39095 Mdot
.666 .39096 Mdot
.666 .39101 Mdot
.666 .3911 Mdot
.666 .39116 Mdot
.666 .39116 Mdot
.666 .39117 Mdot
.666 .39129 Mdot
.666 .39131 Mdot
.666 .39132 Mdot
.666 .39139 Mdot
.666 .39139 Mdot
.666 .39144 Mdot
.666 .39153 Mdot
.666 .39158 Mdot
.666 .39162 Mdot
.666 .39165 Mdot
.666 .39168 Mdot
.666 .39169 Mdot
.666 .39179 Mdot
.666 .39184 Mdot
.666 .39187 Mdot
.666 .39187 Mdot
.666 .39189 Mdot
.666 .39189 Mdot
.666 .39196 Mdot
.666 .39203 Mdot
.666 .39204 Mdot
.666 .39208 Mdot
.666 .39208 Mdot
.666 .39217 Mdot
.666 .39223 Mdot
.666 .39231 Mdot
.666 .39233 Mdot
.666 .39233 Mdot
.666 .39244 Mdot
.666 .3926 Mdot
.666 .39264 Mdot
.666 .39271 Mdot
.666 .39273 Mdot
.666 .39278 Mdot
.666 .39279 Mdot
.666 .39283 Mdot
.666 .39289 Mdot
.666 .39297 Mdot
.666 .39301 Mdot
.666 .39305 Mdot
.666 .39305 Mdot
.666 .39306 Mdot
.666 .39312 Mdot
.666 .39315 Mdot
.666 .39321 Mdot
.666 .3933 Mdot
.666 .39332 Mdot
.666 .39334 Mdot
.666 .39344 Mdot
.666 .39344 Mdot
.666 .39349 Mdot
.666 .3935 Mdot
.666 .3935 Mdot
.666 .39354 Mdot
.666 .39356 Mdot
.666 .39364 Mdot
.666 .39366 Mdot
.666 .3937 Mdot
.666 .3937 Mdot
.666 .39373 Mdot
.666 .39381 Mdot
.666 .39384 Mdot
.666 .39384 Mdot
.666 .39387 Mdot
.666 .3939 Mdot
.666 .39394 Mdot
.666 .39394 Mdot
.666 .39396 Mdot
.666 .39398 Mdot
.666 .394 Mdot
.666 .39401 Mdot
.666 .39402 Mdot
.666 .39404 Mdot
.666 .39416 Mdot
.666 .39428 Mdot
.666 .39429 Mdot
.666 .39429 Mdot
.666 .39431 Mdot
.666 .39432 Mdot
.666 .39438 Mdot
.666 .39439 Mdot
.666 .3944 Mdot
.666 .39441 Mdot
.666 .39451 Mdot
.666 .39451 Mdot
.666 .39453 Mdot
.666 .39453 Mdot
.666 .39454 Mdot
.666 .39456 Mdot
.666 .39468 Mdot
.666 .39472 Mdot
.666 .39477 Mdot
.666 .3949 Mdot
.666 .39493 Mdot
.666 .39493 Mdot
.666 .39495 Mdot
.666 .39497 Mdot
.666 .39503 Mdot
.666 .39509 Mdot
.666 .39509 Mdot
.666 .39516 Mdot
.666 .39521 Mdot
.666 .39522 Mdot
.666 .39523 Mdot
.666 .39533 Mdot
.666 .39534 Mdot
.666 .39534 Mdot
.666 .39537 Mdot
.666 .39541 Mdot
.666 .39545 Mdot
.666 .39545 Mdot
.666 .39548 Mdot
.666 .39554 Mdot
.666 .39554 Mdot
.666 .39557 Mdot
.666 .39561 Mdot
.666 .39563 Mdot
.666 .39565 Mdot
.666 .39567 Mdot
.666 .39567 Mdot
.666 .39568 Mdot
.666 .39569 Mdot
.666 .39569 Mdot
.666 .3957 Mdot
.666 .39571 Mdot
.666 .39573 Mdot
.666 .39574 Mdot
.666 .39575 Mdot
.666 .39575 Mdot
.666 .39578 Mdot
.666 .39581 Mdot
.666 .39584 Mdot
.666 .39592 Mdot
.666 .39595 Mdot
.666 .39597 Mdot
.666 .39602 Mdot
.666 .39602 Mdot
.666 .39602 Mdot
.666 .39604 Mdot
.666 .39607 Mdot
.666 .39609 Mdot
.666 .39613 Mdot
.666 .39614 Mdot
.666 .39617 Mdot
.666 .39618 Mdot
.666 .39621 Mdot
.666 .39631 Mdot
.666 .39632 Mdot
.666 .39634 Mdot
.666 .39635 Mdot
.666 .39639 Mdot
.666 .39648 Mdot
.666 .3965 Mdot
.666 .39652 Mdot
.666 .39657 Mdot
.666 .39661 Mdot
.666 .39662 Mdot
.666 .39664 Mdot
.666 .39669 Mdot
.666 .39671 Mdot
.666 .39674 Mdot
.666 .39675 Mdot
.666 .39675 Mdot
.666 .39685 Mdot
.666 .39686 Mdot
.666 .39687 Mdot
.666 .39688 Mdot
.666 .3969 Mdot
.666 .39692 Mdot
.666 .39699 Mdot
.666 .397 Mdot
.666 .39702 Mdot
.666 .39707 Mdot
.666 .39707 Mdot
.666 .39709 Mdot
.666 .39711 Mdot
.666 .39712 Mdot
.666 .39712 Mdot
.666 .39716 Mdot
.666 .3972 Mdot
.666 .39721 Mdot
.666 .39724 Mdot
.666 .39727 Mdot
.666 .39727 Mdot
.666 .39728 Mdot
.666 .3973 Mdot
.666 .3973 Mdot
.666 .39732 Mdot
.666 .39735 Mdot
.666 .39736 Mdot
.666 .39738 Mdot
.666 .39739 Mdot
.666 .39739 Mdot
.666 .39739 Mdot
.666 .39739 Mdot
.666 .3974 Mdot
.666 .3974 Mdot
.666 .3974 Mdot
.666 .39741 Mdot
.666 .39742 Mdot
.666 .39746 Mdot
.666 .39749 Mdot
.666 .39755 Mdot
.666 .3976 Mdot
.666 .3977 Mdot
.666 .39778 Mdot
.666 .39778 Mdot
.666 .39783 Mdot
.666 .39797 Mdot
.666 .39797 Mdot
.666 .398 Mdot
.666 .39815 Mdot
.666 .39815 Mdot
.666 .39818 Mdot
.666 .39827 Mdot
.666 .39832 Mdot
.666 .39835 Mdot
.666 .39836 Mdot
.666 .39847 Mdot
.666 .39851 Mdot
.666 .39853 Mdot
.666 .39861 Mdot
.666 .39869 Mdot
.666 .39871 Mdot
.666 .39875 Mdot
.666 .39878 Mdot
.666 .39886 Mdot
.666 .39896 Mdot
.666 .39898 Mdot
.666 .39905 Mdot
.666 .3993 Mdot
.666 .39938 Mdot
.666 .39939 Mdot
.666 .3994 Mdot
.666 .39948 Mdot
.666 .3995 Mdot
.666 .39952 Mdot
.666 .39956 Mdot
.666 .39968 Mdot
.666 .3997 Mdot
.666 .39974 Mdot
.666 .39982 Mdot
.666 .39988 Mdot
.666 .39988 Mdot
.666 .39989 Mdot
.666 .39991 Mdot
.666 .39994 Mdot
.666 .39998 Mdot
.666 .40032 Mdot
.666 .40032 Mdot
.666 .40035 Mdot
.666 .40058 Mdot
.666 .40067 Mdot
.666 .40069 Mdot
.666 .4007 Mdot
.666 .40071 Mdot
.666 .40076 Mdot
.666 .40077 Mdot
.666 .40096 Mdot
.666 .40098 Mdot
.666 .40101 Mdot
.666 .40103 Mdot
.666 .4011 Mdot
.666 .40124 Mdot
.666 .4013 Mdot
.666 .4013 Mdot
.666 .40135 Mdot
.666 .40136 Mdot
.666 .40136 Mdot
.666 .40137 Mdot
.666 .40138 Mdot
.666 .40144 Mdot
.666 .40147 Mdot
.666 .40154 Mdot
.666 .40174 Mdot
.666 .40184 Mdot
.666 .40198 Mdot
.666 .4023 Mdot
.666 .40232 Mdot
.666 .40236 Mdot
.666 .40237 Mdot
.666 .40241 Mdot
.666 .40246 Mdot
.666 .40261 Mdot
.666 .40265 Mdot
.666 .40274 Mdot
.666 .40275 Mdot
.666 .4029 Mdot
.666 .40291 Mdot
.666 .40303 Mdot
.666 .40304 Mdot
.666 .40308 Mdot
.666 .4033 Mdot
.666 .40331 Mdot
.666 .40332 Mdot
.666 .40335 Mdot
.666 .40338 Mdot
.666 .40346 Mdot
.666 .40349 Mdot
.666 .40355 Mdot
.666 .40356 Mdot
.666 .40356 Mdot
.666 .40362 Mdot
.666 .40368 Mdot
.666 .4037 Mdot
.666 .40372 Mdot
.666 .40373 Mdot
.666 .40374 Mdot
.666 .40375 Mdot
.666 .40375 Mdot
.666 .40381 Mdot
.666 .40384 Mdot
.666 .40385 Mdot
.666 .40388 Mdot
.666 .40392 Mdot
.666 .40397 Mdot
.666 .40398 Mdot
.666 .404 Mdot
.666 .404 Mdot
.666 .40403 Mdot
.666 .40404 Mdot
.666 .40404 Mdot
.666 .40407 Mdot
.666 .40409 Mdot
.666 .40413 Mdot
.666 .40414 Mdot
.666 .40416 Mdot
.666 .40417 Mdot
.666 .40421 Mdot
.666 .40425 Mdot
.666 .40428 Mdot
.666 .40434 Mdot
.666 .40438 Mdot
.666 .40441 Mdot
.666 .40447 Mdot
.666 .40449 Mdot
.666 .40451 Mdot
.666 .40454 Mdot
.666 .40458 Mdot
.666 .40466 Mdot
.666 .40466 Mdot
.666 .40467 Mdot
.666 .40471 Mdot
.666 .40475 Mdot
.666 .40479 Mdot
.666 .40483 Mdot
.666 .40485 Mdot
.666 .40486 Mdot
.666 .40488 Mdot
.666 .40492 Mdot
.666 .40493 Mdot
.666 .40493 Mdot
.666 .40495 Mdot
.666 .40498 Mdot
.666 .40498 Mdot
.666 .405 Mdot
.666 .40514 Mdot
.666 .40514 Mdot
.666 .40517 Mdot
.666 .40519 Mdot
.666 .40521 Mdot
.666 .40528 Mdot
.666 .40541 Mdot
.666 .40543 Mdot
.666 .40546 Mdot
.666 .4055 Mdot
.666 .40553 Mdot
.666 .40553 Mdot
.666 .40554 Mdot
.666 .40559 Mdot
.666 .40559 Mdot
.666 .4056 Mdot
.666 .40563 Mdot
.666 .40569 Mdot
.666 .40572 Mdot
.666 .40576 Mdot
.666 .40577 Mdot
.666 .40577 Mdot
.666 .40589 Mdot
.666 .40591 Mdot
.666 .40592 Mdot
.666 .40593 Mdot
.666 .40595 Mdot
.666 .40597 Mdot
.666 .40597 Mdot
.666 .40601 Mdot
.666 .40605 Mdot
.666 .40605 Mdot
.666 .40606 Mdot
.666 .40607 Mdot
.666 .40608 Mdot
.666 .40608 Mdot
.666 .40608 Mdot
.666 .40614 Mdot
.666 .40614 Mdot
.666 .40614 Mdot
.666 .40616 Mdot
.666 .40618 Mdot
.666 .40619 Mdot
.666 .40619 Mdot
.666 .40622 Mdot
.666 .40623 Mdot
.666 .40626 Mdot
.666 .40627 Mdot
.666 .40627 Mdot
.666 .40628 Mdot
.666 .4063 Mdot
.666 .40633 Mdot
.666 .40633 Mdot
.666 .40633 Mdot
.666 .40636 Mdot
.666 .40636 Mdot
.666 .40637 Mdot
.666 .40638 Mdot
.666 .4064 Mdot
.666 .40641 Mdot
.666 .40642 Mdot
.666 .40642 Mdot
.666 .40643 Mdot
.666 .40643 Mdot
.666 .40643 Mdot
.666 .40643 Mdot
.666 .40643 Mdot
.666 .40644 Mdot
.666 .40644 Mdot
.666 .40644 Mdot
.666 .40645 Mdot
.666 .40645 Mdot
.666 .40646 Mdot
.666 .40649 Mdot
.666 .40651 Mdot
.666 .40651 Mdot
.666 .40652 Mdot
.666 .40652 Mdot
.666 .40655 Mdot
.666 .40658 Mdot
.666 .40658 Mdot
.666 .40664 Mdot
.666 .40668 Mdot
.666 .40669 Mdot
.666 .40671 Mdot
.666 .40672 Mdot
.666 .40675 Mdot
.666 .40675 Mdot
.666 .40677 Mdot
.666 .40677 Mdot
.666 .40678 Mdot
.666 .40679 Mdot
.666 .40681 Mdot
.666 .40682 Mdot
.666 .40682 Mdot
.666 .40682 Mdot
.666 .40683 Mdot
.666 .40683 Mdot
.666 .40683 Mdot
.666 .40684 Mdot
.666 .40684 Mdot
.666 .40685 Mdot
.666 .40685 Mdot
.666 .40685 Mdot
.666 .40685 Mdot
.666 .40685 Mdot
.666 .40685 Mdot
.668 .34641 Mdot
.668 .3474 Mdot
.668 .37301 Mdot
.668 .37528 Mdot
.668 .38743 Mdot
.668 .38797 Mdot
.668 .39889 Mdot
.668 .39969 Mdot
.668 .40775 Mdot
.668 .40803 Mdot
.67 .34327 Mdot
.67 .34327 Mdot
.67 .34327 Mdot
.67 .34327 Mdot
.67 .34327 Mdot
.67 .34327 Mdot
.67 .34328 Mdot
.67 .34328 Mdot
.67 .34328 Mdot
.67 .34328 Mdot
.67 .34328 Mdot
.67 .34328 Mdot
.67 .34329 Mdot
.67 .3433 Mdot
.67 .3433 Mdot
.67 .3433 Mdot
.67 .34333 Mdot
.67 .34333 Mdot
.67 .34335 Mdot
.67 .34335 Mdot
.67 .34337 Mdot
.67 .34341 Mdot
.67 .34344 Mdot
.67 .34347 Mdot
.67 .34347 Mdot
.67 .34347 Mdot
.67 .3435 Mdot
.67 .34351 Mdot
.67 .34352 Mdot
.67 .34354 Mdot
.67 .34354 Mdot
.67 .3436 Mdot
.67 .3436 Mdot
.67 .3436 Mdot
.67 .3436 Mdot
.67 .3436 Mdot
.67 .3436 Mdot
.67 .34361 Mdot
.67 .34361 Mdot
.67 .34361 Mdot
.67 .34362 Mdot
.67 .34363 Mdot
.67 .34363 Mdot
.67 .34363 Mdot
.67 .34365 Mdot
.67 .34367 Mdot
.67 .34372 Mdot
.67 .34377 Mdot
.67 .34377 Mdot
.67 .34378 Mdot
.67 .34379 Mdot
.67 .3438 Mdot
.67 .3438 Mdot
.67 .34385 Mdot
.67 .34389 Mdot
.67 .3439 Mdot
.67 .34391 Mdot
.67 .34394 Mdot
.67 .34394 Mdot
.67 .34396 Mdot
.67 .34397 Mdot
.67 .34399 Mdot
.67 .34399 Mdot
.67 .34399 Mdot
.67 .344 Mdot
.67 .344 Mdot
.67 .34401 Mdot
.67 .34401 Mdot
.67 .34402 Mdot
.67 .34403 Mdot
.67 .34404 Mdot
.67 .34404 Mdot
.67 .34412 Mdot
.67 .34418 Mdot
.67 .3442 Mdot
.67 .34423 Mdot
.67 .34426 Mdot
.67 .34427 Mdot
.67 .34432 Mdot
.67 .34436 Mdot
.67 .34436 Mdot
.67 .34444 Mdot
.67 .34444 Mdot
.67 .34451 Mdot
.67 .34455 Mdot
.67 .34455 Mdot
.67 .34458 Mdot
.67 .3447 Mdot
.67 .34472 Mdot
.67 .34489 Mdot
.67 .34502 Mdot
.67 .34506 Mdot
.67 .34512 Mdot
.67 .34522 Mdot
.67 .34524 Mdot
.67 .34528 Mdot
.67 .34533 Mdot
.67 .34533 Mdot
.67 .34534 Mdot
.67 .34536 Mdot
.67 .3454 Mdot
.67 .34552 Mdot
.67 .34552 Mdot
.67 .34553 Mdot
.67 .34554 Mdot
.67 .34555 Mdot
.67 .34559 Mdot
.67 .34563 Mdot
.67 .34567 Mdot
.67 .34567 Mdot
.67 .34567 Mdot
.67 .34568 Mdot
.67 .34569 Mdot
.67 .34569 Mdot
.67 .3457 Mdot
.67 .3457 Mdot
.67 .3457 Mdot
.67 .3457 Mdot
.67 .3457 Mdot
.67 .3457 Mdot
.67 .34571 Mdot
.67 .34576 Mdot
.67 .34586 Mdot
.67 .34589 Mdot
.67 .34594 Mdot
.67 .346 Mdot
.67 .34604 Mdot
.67 .34615 Mdot
.67 .3463 Mdot
.67 .34631 Mdot
.67 .34632 Mdot
.67 .34635 Mdot
.67 .34636 Mdot
.67 .34636 Mdot
.67 .34638 Mdot
.67 .34639 Mdot
.67 .3464 Mdot
.67 .3464 Mdot
.67 .3464 Mdot
.67 .34643 Mdot
.67 .34646 Mdot
.67 .34649 Mdot
.67 .3465 Mdot
.67 .34656 Mdot
.67 .34657 Mdot
.67 .3466 Mdot
.67 .34677 Mdot
.67 .34677 Mdot
.67 .34679 Mdot
.67 .34681 Mdot
.67 .34682 Mdot
.67 .34683 Mdot
.67 .34692 Mdot
.67 .34701 Mdot
.67 .34706 Mdot
.67 .34708 Mdot
.67 .34709 Mdot
.67 .34709 Mdot
.67 .34711 Mdot
.67 .34712 Mdot
.67 .34713 Mdot
.67 .34713 Mdot
.67 .34714 Mdot
.67 .34714 Mdot
.67 .34714 Mdot
.67 .34715 Mdot
.67 .34715 Mdot
.67 .34715 Mdot
.67 .34725 Mdot
.67 .34726 Mdot
.67 .34727 Mdot
.67 .34729 Mdot
.67 .34731 Mdot
.67 .34734 Mdot
.67 .34738 Mdot
.67 .34738 Mdot
.67 .3474 Mdot
.67 .34744 Mdot
.67 .34751 Mdot
.67 .34758 Mdot
.67 .34761 Mdot
.67 .34761 Mdot
.67 .34764 Mdot
.67 .34765 Mdot
.67 .34769 Mdot
.67 .34769 Mdot
.67 .3477 Mdot
.67 .34771 Mdot
.67 .34772 Mdot
.67 .34773 Mdot
.67 .34774 Mdot
.67 .34774 Mdot
.67 .34774 Mdot
.67 .34774 Mdot
.67 .34774 Mdot
.67 .34774 Mdot
.67 .34774 Mdot
.67 .34774 Mdot
.67 .34774 Mdot
.67 .34774 Mdot
.67 .37025 Mdot
.67 .37025 Mdot
.67 .37025 Mdot
.67 .37025 Mdot
.67 .37025 Mdot
.67 .37025 Mdot
.67 .37025 Mdot
.67 .37025 Mdot
.67 .37026 Mdot
.67 .37026 Mdot
.67 .37026 Mdot
.67 .37026 Mdot
.67 .37027 Mdot
.67 .37028 Mdot
.67 .37028 Mdot
.67 .37028 Mdot
.67 .37031 Mdot
.67 .37031 Mdot
.67 .37033 Mdot
.67 .37033 Mdot
.67 .37035 Mdot
.67 .3704 Mdot
.67 .37044 Mdot
.67 .37047 Mdot
.67 .37047 Mdot
.67 .37047 Mdot
.67 .3705 Mdot
.67 .37052 Mdot
.67 .37053 Mdot
.67 .37055 Mdot
.67 .37055 Mdot
.67 .37056 Mdot
.67 .37062 Mdot
.67 .37063 Mdot
.67 .37063 Mdot
.67 .37063 Mdot
.67 .37063 Mdot
.67 .37063 Mdot
.67 .37063 Mdot
.67 .37064 Mdot
.67 .37064 Mdot
.67 .37065 Mdot
.67 .37066 Mdot
.67 .37066 Mdot
.67 .37067 Mdot
.67 .37068 Mdot
.67 .37071 Mdot
.67 .37077 Mdot
.67 .37083 Mdot
.67 .37084 Mdot
.67 .37085 Mdot
.67 .37086 Mdot
.67 .37088 Mdot
.67 .37088 Mdot
.67 .37095 Mdot
.67 .37099 Mdot
.67 .37101 Mdot
.67 .37102 Mdot
.67 .37106 Mdot
.67 .37107 Mdot
.67 .37109 Mdot
.67 .37111 Mdot
.67 .37113 Mdot
.67 .37113 Mdot
.67 .37113 Mdot
.67 .37114 Mdot
.67 .37115 Mdot
.67 .37116 Mdot
.67 .37116 Mdot
.67 .37117 Mdot
.67 .37119 Mdot
.67 .3712 Mdot
.67 .3712 Mdot
.67 .37131 Mdot
.67 .3714 Mdot
.67 .37142 Mdot
.67 .37147 Mdot
.67 .37151 Mdot
.67 .37154 Mdot
.67 .37161 Mdot
.67 .37166 Mdot
.67 .37166 Mdot
.67 .37178 Mdot
.67 .37179 Mdot
.67 .3719 Mdot
.67 .37196 Mdot
.67 .37196 Mdot
.67 .37201 Mdot
.67 .3722 Mdot
.67 .37224 Mdot
.67 .37253 Mdot
.67 .37275 Mdot
.67 .37283 Mdot
.67 .37293 Mdot
.67 .37313 Mdot
.67 .37315 Mdot
.67 .37322 Mdot
.67 .37333 Mdot
.67 .37333 Mdot
.67 .37334 Mdot
.67 .37339 Mdot
.67 .37347 Mdot
.67 .37369 Mdot
.67 .37369 Mdot
.67 .37371 Mdot
.67 .37373 Mdot
.67 .37375 Mdot
.67 .37383 Mdot
.67 .37392 Mdot
.67 .37399 Mdot
.67 .374 Mdot
.67 .374 Mdot
.67 .37402 Mdot
.67 .37403 Mdot
.67 .37404 Mdot
.67 .37405 Mdot
.67 .37405 Mdot
.67 .37405 Mdot
.67 .37406 Mdot
.67 .37406 Mdot
.67 .37406 Mdot
.67 .37407 Mdot
.67 .37418 Mdot
.67 .37438 Mdot
.67 .37444 Mdot
.67 .37455 Mdot
.67 .37469 Mdot
.67 .37477 Mdot
.67 .37502 Mdot
.67 .37535 Mdot
.67 .37536 Mdot
.67 .37539 Mdot
.67 .37545 Mdot
.67 .37549 Mdot
.67 .37549 Mdot
.67 .37552 Mdot
.67 .37554 Mdot
.67 .37557 Mdot
.67 .37557 Mdot
.67 .37558 Mdot
.67 .37565 Mdot
.67 .37571 Mdot
.67 .37579 Mdot
.67 .3758 Mdot
.67 .37594 Mdot
.67 .37597 Mdot
.67 .37604 Mdot
.67 .37644 Mdot
.67 .37644 Mdot
.67 .3765 Mdot
.67 .37654 Mdot
.67 .37656 Mdot
.67 .3766 Mdot
.67 .37682 Mdot
.67 .37704 Mdot
.67 .37717 Mdot
.67 .37722 Mdot
.67 .37724 Mdot
.67 .37725 Mdot
.67 .3773 Mdot
.67 .37732 Mdot
.67 .37734 Mdot
.67 .37736 Mdot
.67 .37736 Mdot
.67 .37737 Mdot
.67 .37738 Mdot
.67 .37739 Mdot
.67 .37739 Mdot
.67 .3774 Mdot
.67 .37766 Mdot
.67 .3777 Mdot
.67 .37771 Mdot
.67 .37777 Mdot
.67 .37781 Mdot
.67 .37789 Mdot
.67 .37801 Mdot
.67 .37801 Mdot
.67 .37804 Mdot
.67 .37816 Mdot
.67 .37834 Mdot
.67 .37853 Mdot
.67 .37862 Mdot
.67 .37863 Mdot
.67 .3787 Mdot
.67 .37873 Mdot
.67 .37885 Mdot
.67 .37885 Mdot
.67 .37886 Mdot
.67 .3789 Mdot
.67 .37893 Mdot
.67 .37896 Mdot
.67 .37896 Mdot
.67 .37896 Mdot
.67 .37897 Mdot
.67 .37897 Mdot
.67 .37898 Mdot
.67 .37898 Mdot
.67 .37898 Mdot
.67 .37898 Mdot
.67 .37898 Mdot
.67 .37899 Mdot
.67 .38732 Mdot
.67 .38732 Mdot
.67 .38732 Mdot
.67 .38732 Mdot
.67 .38732 Mdot
.67 .38732 Mdot
.67 .38732 Mdot
.67 .38732 Mdot
.67 .38732 Mdot
.67 .38732 Mdot
.67 .38732 Mdot
.67 .38732 Mdot
.67 .38732 Mdot
.67 .38732 Mdot
.67 .38732 Mdot
.67 .38732 Mdot
.67 .38733 Mdot
.67 .38733 Mdot
.67 .38733 Mdot
.67 .38733 Mdot
.67 .38734 Mdot
.67 .38735 Mdot
.67 .38736 Mdot
.67 .38737 Mdot
.67 .38737 Mdot
.67 .38737 Mdot
.67 .38737 Mdot
.67 .38738 Mdot
.67 .38738 Mdot
.67 .38739 Mdot
.67 .38739 Mdot
.67 .3874 Mdot
.67 .3874 Mdot
.67 .3874 Mdot
.67 .3874 Mdot
.67 .3874 Mdot
.67 .3874 Mdot
.67 .3874 Mdot
.67 .38741 Mdot
.67 .38741 Mdot
.67 .38741 Mdot
.67 .38741 Mdot
.67 .38741 Mdot
.67 .38741 Mdot
.67 .38742 Mdot
.67 .38742 Mdot
.67 .38744 Mdot
.67 .38745 Mdot
.67 .38745 Mdot
.67 .38746 Mdot
.67 .38746 Mdot
.67 .38746 Mdot
.67 .38746 Mdot
.67 .38748 Mdot
.67 .38749 Mdot
.67 .38749 Mdot
.67 .3875 Mdot
.67 .38751 Mdot
.67 .38751 Mdot
.67 .38751 Mdot
.67 .38752 Mdot
.67 .38752 Mdot
.67 .38752 Mdot
.67 .38752 Mdot
.67 .38752 Mdot
.67 .38752 Mdot
.67 .38753 Mdot
.67 .38753 Mdot
.67 .38753 Mdot
.67 .38753 Mdot
.67 .38754 Mdot
.67 .38754 Mdot
.67 .38756 Mdot
.67 .38758 Mdot
.67 .38759 Mdot
.67 .3876 Mdot
.67 .38761 Mdot
.67 .38762 Mdot
.67 .38763 Mdot
.67 .38764 Mdot
.67 .38765 Mdot
.67 .38767 Mdot
.67 .38767 Mdot
.67 .3877 Mdot
.67 .38771 Mdot
.67 .38771 Mdot
.67 .38773 Mdot
.67 .38777 Mdot
.67 .38778 Mdot
.67 .38785 Mdot
.67 .3879 Mdot
.67 .38792 Mdot
.67 .38794 Mdot
.67 .38798 Mdot
.67 .38799 Mdot
.67 .388 Mdot
.67 .38803 Mdot
.67 .38803 Mdot
.67 .38803 Mdot
.67 .38804 Mdot
.67 .38806 Mdot
.67 .38811 Mdot
.67 .38811 Mdot
.67 .38812 Mdot
.67 .38812 Mdot
.67 .38812 Mdot
.67 .38814 Mdot
.67 .38816 Mdot
.67 .38818 Mdot
.67 .38818 Mdot
.67 .38818 Mdot
.67 .38819 Mdot
.67 .38819 Mdot
.67 .38819 Mdot
.67 .38819 Mdot
.67 .38819 Mdot
.67 .38819 Mdot
.67 .38819 Mdot
.67 .3882 Mdot
.67 .3882 Mdot
.67 .3882 Mdot
.67 .38822 Mdot
.67 .38827 Mdot
.67 .38828 Mdot
.67 .38831 Mdot
.67 .38834 Mdot
.67 .38836 Mdot
.67 .38841 Mdot
.67 .38849 Mdot
.67 .38849 Mdot
.67 .3885 Mdot
.67 .38851 Mdot
.67 .38852 Mdot
.67 .38852 Mdot
.67 .38853 Mdot
.67 .38853 Mdot
.67 .38854 Mdot
.67 .38854 Mdot
.67 .38854 Mdot
.67 .38856 Mdot
.67 .38857 Mdot
.67 .38859 Mdot
.67 .38859 Mdot
.67 .38862 Mdot
.67 .38863 Mdot
.67 .38864 Mdot
.67 .38873 Mdot
.67 .38873 Mdot
.67 .38875 Mdot
.67 .38876 Mdot
.67 .38876 Mdot
.67 .38877 Mdot
.67 .38882 Mdot
.67 .38887 Mdot
.67 .3889 Mdot
.67 .38891 Mdot
.67 .38891 Mdot
.67 .38891 Mdot
.67 .38892 Mdot
.67 .38893 Mdot
.67 .38893 Mdot
.67 .38894 Mdot
.67 .38894 Mdot
.67 .38894 Mdot
.67 .38894 Mdot
.67 .38895 Mdot
.67 .38895 Mdot
.67 .38895 Mdot
.67 .38901 Mdot
.67 .38901 Mdot
.67 .38902 Mdot
.67 .38903 Mdot
.67 .38904 Mdot
.67 .38906 Mdot
.67 .38908 Mdot
.67 .38908 Mdot
.67 .38909 Mdot
.67 .38912 Mdot
.67 .38916 Mdot
.67 .3892 Mdot
.67 .38922 Mdot
.67 .38922 Mdot
.67 .38924 Mdot
.67 .38924 Mdot
.67 .38927 Mdot
.67 .38927 Mdot
.67 .38927 Mdot
.67 .38928 Mdot
.67 .38929 Mdot
.67 .38929 Mdot
.67 .3893 Mdot
.67 .3893 Mdot
.67 .3893 Mdot
.67 .3893 Mdot
.67 .3893 Mdot
.67 .3893 Mdot
.67 .3893 Mdot
.67 .3893 Mdot
.67 .3893 Mdot
.67 .3893 Mdot
.67 .39793 Mdot
.67 .39793 Mdot
.67 .39793 Mdot
.67 .39793 Mdot
.67 .39793 Mdot
.67 .39793 Mdot
.67 .39793 Mdot
.67 .39793 Mdot
.67 .39794 Mdot
.67 .39794 Mdot
.67 .39794 Mdot
.67 .39795 Mdot
.67 .39796 Mdot
.67 .39797 Mdot
.67 .39798 Mdot
.67 .39798 Mdot
.67 .39802 Mdot
.67 .39803 Mdot
.67 .39806 Mdot
.67 .39806 Mdot
.67 .3981 Mdot
.67 .39817 Mdot
.67 .39823 Mdot
.67 .39828 Mdot
.67 .39829 Mdot
.67 .39829 Mdot
.67 .39833 Mdot
.67 .39836 Mdot
.67 .39838 Mdot
.67 .3984 Mdot
.67 .3984 Mdot
.67 .39841 Mdot
.67 .39851 Mdot
.67 .39851 Mdot
.67 .39851 Mdot
.67 .39852 Mdot
.67 .39852 Mdot
.67 .39852 Mdot
.67 .39853 Mdot
.67 .39853 Mdot
.67 .39854 Mdot
.67 .39855 Mdot
.67 .39857 Mdot
.67 .39857 Mdot
.67 .39858 Mdot
.67 .3986 Mdot
.67 .39864 Mdot
.67 .39872 Mdot
.67 .3988 Mdot
.67 .39881 Mdot
.67 .39882 Mdot
.67 .39884 Mdot
.67 .39886 Mdot
.67 .39886 Mdot
.67 .399 Mdot
.67 .39903 Mdot
.67 .39904 Mdot
.67 .39909 Mdot
.67 .39909 Mdot
.67 .39912 Mdot
.67 .39914 Mdot
.67 .39917 Mdot
.67 .39917 Mdot
.67 .39917 Mdot
.67 .39918 Mdot
.67 .39919 Mdot
.67 .3992 Mdot
.67 .3992 Mdot
.67 .39921 Mdot
.67 .39923 Mdot
.67 .39924 Mdot
.67 .39925 Mdot
.67 .39937 Mdot
.67 .39946 Mdot
.67 .39948 Mdot
.67 .39953 Mdot
.67 .39957 Mdot
.67 .39959 Mdot
.67 .39966 Mdot
.67 .3997 Mdot
.67 .3997 Mdot
.67 .3997 Mdot
.67 .3997 Mdot
.67 .39971 Mdot
.67 .39971 Mdot
.67 .39971 Mdot
.67 .39971 Mdot
.67 .39971 Mdot
.67 .39972 Mdot
.67 .39972 Mdot
.67 .39972 Mdot
.67 .39973 Mdot
.67 .39975 Mdot
.67 .39978 Mdot
.67 .39981 Mdot
.67 .39982 Mdot
.67 .39982 Mdot
.67 .39983 Mdot
.67 .39983 Mdot
.67 .39991 Mdot
.67 .39994 Mdot
.67 .39995 Mdot
.67 .39996 Mdot
.67 .39996 Mdot
.67 .39999 Mdot
.67 .40002 Mdot
.67 .40003 Mdot
.67 .4001 Mdot
.67 .40013 Mdot
.67 .40016 Mdot
.67 .40023 Mdot
.67 .40033 Mdot
.67 .40035 Mdot
.67 .40041 Mdot
.67 .40043 Mdot
.67 .40043 Mdot
.67 .40045 Mdot
.67 .40049 Mdot
.67 .40049 Mdot
.67 .40053 Mdot
.67 .40053 Mdot
.67 .40055 Mdot
.67 .40057 Mdot
.67 .40058 Mdot
.67 .40059 Mdot
.67 .40061 Mdot
.67 .40062 Mdot
.67 .40065 Mdot
.67 .40069 Mdot
.67 .40069 Mdot
.67 .40069 Mdot
.67 .4007 Mdot
.67 .4007 Mdot
.67 .4007 Mdot
.67 .4007 Mdot
.67 .40071 Mdot
.67 .40071 Mdot
.67 .40071 Mdot
.67 .40071 Mdot
.67 .40072 Mdot
.67 .40072 Mdot
.67 .40073 Mdot
.67 .40073 Mdot
.67 .40075 Mdot
.67 .40075 Mdot
.67 .40076 Mdot
.67 .40077 Mdot
.67 .4008 Mdot
.67 .4008 Mdot
.67 .4008 Mdot
.67 .40081 Mdot
.67 .40081 Mdot
.67 .40081 Mdot
.67 .40083 Mdot
.67 .40085 Mdot
.67 .40086 Mdot
.67 .40087 Mdot
.67 .40087 Mdot
.67 .40087 Mdot
.67 .40087 Mdot
.67 .40087 Mdot
.67 .40088 Mdot
.67 .40088 Mdot
.67 .40088 Mdot
.67 .40088 Mdot
.67 .40088 Mdot
.67 .40088 Mdot
.67 .40088 Mdot
.67 .40088 Mdot
.67 .4009 Mdot
.67 .40091 Mdot
.67 .40091 Mdot
.67 .40091 Mdot
.67 .40092 Mdot
.67 .40093 Mdot
.67 .40093 Mdot
.67 .40093 Mdot
.67 .40094 Mdot
.67 .40096 Mdot
.67 .40097 Mdot
.67 .40098 Mdot
.67 .40098 Mdot
.67 .40099 Mdot
.67 .40099 Mdot
.67 .401 Mdot
.67 .401 Mdot
.67 .401 Mdot
.67 .401 Mdot
.67 .401 Mdot
.67 .401 Mdot
.67 .401 Mdot
.67 .401 Mdot
.67 .401 Mdot
.67 .40101 Mdot
.67 .40101 Mdot
.67 .40101 Mdot
.67 .40101 Mdot
.67 .40101 Mdot
.67 .40101 Mdot
.67 .40101 Mdot
.67 .40793 Mdot
.67 .40793 Mdot
.67 .40793 Mdot
.67 .40793 Mdot
.67 .40793 Mdot
.67 .40793 Mdot
.67 .40793 Mdot
.67 .40793 Mdot
.67 .40794 Mdot
.67 .40794 Mdot
.67 .40794 Mdot
.67 .40794 Mdot
.67 .40794 Mdot
.67 .40795 Mdot
.67 .40795 Mdot
.67 .40795 Mdot
.67 .40796 Mdot
.67 .40796 Mdot
.67 .40797 Mdot
.67 .40797 Mdot
.67 .40798 Mdot
.67 .408 Mdot
.67 .40802 Mdot
.67 .40803 Mdot
.67 .40804 Mdot
.67 .40804 Mdot
.67 .40805 Mdot
.67 .40806 Mdot
.67 .40806 Mdot
.67 .40807 Mdot
.67 .40807 Mdot
.67 .40807 Mdot
.67 .4081 Mdot
.67 .40811 Mdot
.67 .40811 Mdot
.67 .40811 Mdot
.67 .40811 Mdot
.67 .40811 Mdot
.67 .40811 Mdot
.67 .40811 Mdot
.67 .40811 Mdot
.67 .40812 Mdot
.67 .40812 Mdot
.67 .40812 Mdot
.67 .40812 Mdot
.67 .40813 Mdot
.67 .40814 Mdot
.67 .40817 Mdot
.67 .4082 Mdot
.67 .4082 Mdot
.67 .4082 Mdot
.67 .40821 Mdot
.67 .40821 Mdot
.67 .40821 Mdot
.67 .40826 Mdot
.67 .40827 Mdot
.67 .40827 Mdot
.67 .40829 Mdot
.67 .40829 Mdot
.67 .4083 Mdot
.67 .40831 Mdot
.67 .40832 Mdot
.67 .40832 Mdot
.67 .40832 Mdot
.67 .40832 Mdot
.67 .40833 Mdot
.67 .40833 Mdot
.67 .40833 Mdot
.67 .40833 Mdot
.67 .40834 Mdot
.67 .40835 Mdot
.67 .40835 Mdot
.67 .40839 Mdot
.67 .40842 Mdot
.67 .40843 Mdot
.67 .40845 Mdot
.67 .40847 Mdot
.67 .40847 Mdot
.67 .4085 Mdot
.67 .40852 Mdot
.67 .40852 Mdot
.67 .40852 Mdot
.67 .40852 Mdot
.67 .40852 Mdot
.67 .40852 Mdot
.67 .40852 Mdot
.67 .40852 Mdot
.67 .40852 Mdot
.67 .40852 Mdot
.67 .40853 Mdot
.67 .40853 Mdot
.67 .40853 Mdot
.67 .40854 Mdot
.67 .40855 Mdot
.67 .40856 Mdot
.67 .40857 Mdot
.67 .40857 Mdot
.67 .40857 Mdot
.67 .40857 Mdot
.67 .4086 Mdot
.67 .40862 Mdot
.67 .40862 Mdot
.67 .40862 Mdot
.67 .40862 Mdot
.67 .40864 Mdot
.67 .40865 Mdot
.67 .40866 Mdot
.67 .40869 Mdot
.67 .4087 Mdot
.67 .40871 Mdot
.67 .40875 Mdot
.67 .4088 Mdot
.67 .40881 Mdot
.67 .40884 Mdot
.67 .40885 Mdot
.67 .40885 Mdot
.67 .40886 Mdot
.67 .40888 Mdot
.67 .40888 Mdot
.67 .4089 Mdot
.67 .4089 Mdot
.67 .40891 Mdot
.67 .40893 Mdot
.67 .40893 Mdot
.67 .40894 Mdot
.67 .40895 Mdot
.67 .40895 Mdot
.67 .40897 Mdot
.67 .40899 Mdot
.67 .40899 Mdot
.67 .409 Mdot
.67 .409 Mdot
.67 .409 Mdot
.67 .409 Mdot
.67 .409 Mdot
.67 .409 Mdot
.67 .40901 Mdot
.67 .40901 Mdot
.67 .40901 Mdot
.67 .40901 Mdot
.67 .40902 Mdot
.67 .40902 Mdot
.67 .40902 Mdot
.67 .40903 Mdot
.67 .40903 Mdot
.67 .40904 Mdot
.67 .40905 Mdot
.67 .40906 Mdot
.67 .40906 Mdot
.67 .40906 Mdot
.67 .40907 Mdot
.67 .40907 Mdot
.67 .40907 Mdot
.67 .40908 Mdot
.67 .4091 Mdot
.67 .4091 Mdot
.67 .40911 Mdot
.67 .40911 Mdot
.67 .40911 Mdot
.67 .40911 Mdot
.67 .40911 Mdot
.67 .40911 Mdot
.67 .40912 Mdot
.67 .40912 Mdot
.67 .40912 Mdot
.67 .40912 Mdot
.67 .40912 Mdot
.67 .40912 Mdot
.67 .40912 Mdot
.67 .40913 Mdot
.67 .40914 Mdot
.67 .40914 Mdot
.67 .40914 Mdot
.67 .40915 Mdot
.67 .40915 Mdot
.67 .40915 Mdot
.67 .40916 Mdot
.67 .40916 Mdot
.67 .40917 Mdot
.67 .40918 Mdot
.67 .40919 Mdot
.67 .40919 Mdot
.67 .40919 Mdot
.67 .4092 Mdot
.67 .4092 Mdot
.67 .4092 Mdot
.67 .4092 Mdot
.67 .40921 Mdot
.67 .40921 Mdot
.67 .40921 Mdot
.67 .40921 Mdot
.67 .40921 Mdot
.67 .40921 Mdot
.67 .40921 Mdot
.67 .40921 Mdot
.67 .40921 Mdot
.67 .40921 Mdot
.67 .40921 Mdot
.67 .40921 Mdot
.67 .40921 Mdot
.672 .34227 Mdot
.672 .37187 Mdot
.672 .38822 Mdot
.672 .40082 Mdot
.672 .40977 Mdot
.674 .33678 Mdot
.674 .33843 Mdot
.674 .37554 Mdot
.674 .37832 Mdot
.674 .38947 Mdot
.674 .39003 Mdot
.674 .39896 Mdot
.674 .39993 Mdot
.674 .41111 Mdot
.674 .41156 Mdot
.676 .33343 Mdot
.676 .33344 Mdot
.676 .33344 Mdot
.676 .33344 Mdot
.676 .33353 Mdot
.676 .33367 Mdot
.676 .33372 Mdot
.676 .33392 Mdot
.676 .33396 Mdot
.676 .334 Mdot
.676 .33403 Mdot
.676 .33405 Mdot
.676 .33405 Mdot
.676 .33407 Mdot
.676 .33408 Mdot
.676 .33415 Mdot
.676 .33418 Mdot
.676 .33438 Mdot
.676 .33438 Mdot
.676 .33438 Mdot
.676 .33439 Mdot
.676 .3344 Mdot
.676 .3344 Mdot
.676 .3344 Mdot
.676 .3344 Mdot
.676 .33444 Mdot
.676 .33444 Mdot
.676 .33446 Mdot
.676 .33451 Mdot
.676 .33459 Mdot
.676 .3346 Mdot
.676 .33462 Mdot
.676 .33469 Mdot
.676 .3347 Mdot
.676 .33471 Mdot
.676 .33474 Mdot
.676 .33475 Mdot
.676 .33475 Mdot
.676 .33488 Mdot
.676 .33489 Mdot
.676 .33489 Mdot
.676 .33507 Mdot
.676 .33529 Mdot
.676 .33531 Mdot
.676 .33544 Mdot
.676 .33566 Mdot
.676 .33567 Mdot
.676 .33586 Mdot
.676 .33586 Mdot
.676 .33593 Mdot
.676 .33595 Mdot
.676 .33621 Mdot
.676 .33621 Mdot
.676 .33626 Mdot
.676 .3363 Mdot
.676 .33635 Mdot
.676 .33647 Mdot
.676 .33651 Mdot
.676 .33651 Mdot
.676 .33653 Mdot
.676 .33654 Mdot
.676 .33659 Mdot
.676 .3366 Mdot
.676 .33671 Mdot
.676 .33679 Mdot
.676 .33683 Mdot
.676 .33683 Mdot
.676 .33684 Mdot
.676 .33686 Mdot
.676 .33695 Mdot
.676 .33701 Mdot
.676 .33701 Mdot
.676 .33707 Mdot
.676 .33709 Mdot
.676 .33709 Mdot
.676 .33757 Mdot
.676 .33758 Mdot
.676 .33779 Mdot
.676 .3378 Mdot
.676 .33796 Mdot
.676 .33799 Mdot
.676 .33808 Mdot
.676 .33816 Mdot
.676 .3382 Mdot
.676 .33829 Mdot
.676 .33834 Mdot
.676 .33847 Mdot
.676 .33849 Mdot
.676 .33852 Mdot
.676 .33865 Mdot
.676 .3389 Mdot
.676 .33911 Mdot
.676 .33931 Mdot
.676 .33975 Mdot
.676 .33976 Mdot
.676 .33994 Mdot
.676 .34035 Mdot
.676 .3404 Mdot
.676 .3404 Mdot
.676 .34053 Mdot
.676 .34069 Mdot
.676 .34083 Mdot
.676 .34084 Mdot
.676 .341 Mdot
.676 .34115 Mdot
.676 .34165 Mdot
.676 .34179 Mdot
.676 .3418 Mdot
.676 .34186 Mdot
.676 .34187 Mdot
.676 .34206 Mdot
.676 .34247 Mdot
.676 .34259 Mdot
.676 .34308 Mdot
.676 .34332 Mdot
.676 .34338 Mdot
.676 .34373 Mdot
.676 .34373 Mdot
.676 .34379 Mdot
.676 .34382 Mdot
.676 .34385 Mdot
.676 .34394 Mdot
.676 .34394 Mdot
.676 .34412 Mdot
.676 .34427 Mdot
.676 .34428 Mdot
.676 .34471 Mdot
.676 .34482 Mdot
.676 .34504 Mdot
.676 .3452 Mdot
.676 .34526 Mdot
.676 .34526 Mdot
.676 .34528 Mdot
.676 .34537 Mdot
.676 .34553 Mdot
.676 .34557 Mdot
.676 .34592 Mdot
.676 .34609 Mdot
.676 .34631 Mdot
.676 .34636 Mdot
.676 .34693 Mdot
.676 .3473 Mdot
.676 .34762 Mdot
.676 .34768 Mdot
.676 .34822 Mdot
.676 .34837 Mdot
.676 .34882 Mdot
.676 .349 Mdot
.676 .34907 Mdot
.676 .34969 Mdot
.676 .34973 Mdot
.676 .35003 Mdot
.676 .3503 Mdot
.676 .35072 Mdot
.676 .35079 Mdot
.676 .35093 Mdot
.676 .35102 Mdot
.676 .35108 Mdot
.676 .35171 Mdot
.676 .3519 Mdot
.676 .35243 Mdot
.676 .35335 Mdot
.676 .35461 Mdot
.676 .35478 Mdot
.676 .35488 Mdot
.676 .355 Mdot
.676 .35541 Mdot
.676 .35628 Mdot
.676 .35658 Mdot
.676 .35744 Mdot
.676 .35773 Mdot
.676 .35817 Mdot
.676 .35824 Mdot
.676 .35833 Mdot
.676 .35836 Mdot
.676 .35964 Mdot
.676 .35985 Mdot
.676 .36002 Mdot
.676 .3624 Mdot
.676 .36243 Mdot
.676 .36245 Mdot
.676 .3626 Mdot
.676 .36481 Mdot
.676 .36483 Mdot
.676 .36494 Mdot
.676 .36518 Mdot
.676 .36552 Mdot
.676 .36561 Mdot
.676 .36578 Mdot
.676 .36583 Mdot
.676 .36631 Mdot
.676 .36685 Mdot
.676 .36695 Mdot
.676 .36704 Mdot
.676 .36717 Mdot
.676 .36741 Mdot
.676 .36753 Mdot
.676 .36757 Mdot
.676 .36785 Mdot
.676 .36892 Mdot
.676 .36983 Mdot
.676 .37021 Mdot
.676 .37033 Mdot
.676 .37088 Mdot
.676 .3709 Mdot
.676 .37094 Mdot
.676 .37097 Mdot
.676 .37105 Mdot
.676 .37106 Mdot
.676 .37125 Mdot
.676 .37126 Mdot
.676 .37127 Mdot
.676 .3713 Mdot
.676 .37138 Mdot
.676 .37145 Mdot
.676 .37273 Mdot
.676 .37279 Mdot
.676 .37355 Mdot
.676 .37361 Mdot
.676 .37366 Mdot
.676 .37415 Mdot
.676 .37511 Mdot
.676 .37513 Mdot
.676 .37544 Mdot
.676 .37569 Mdot
.676 .37615 Mdot
.676 .37652 Mdot
.676 .37699 Mdot
.676 .37706 Mdot
.676 .3772 Mdot
.676 .3772 Mdot
.676 .37723 Mdot
.676 .37733 Mdot
.676 .37737 Mdot
.676 .37761 Mdot
.676 .37761 Mdot
.676 .37761 Mdot
.676 .37761 Mdot
.676 .37763 Mdot
.676 .37763 Mdot
.676 .37763 Mdot
.676 .37764 Mdot
.676 .37767 Mdot
.676 .37768 Mdot
.676 .3777 Mdot
.676 .37775 Mdot
.676 .37784 Mdot
.676 .37784 Mdot
.676 .37786 Mdot
.676 .37795 Mdot
.676 .37795 Mdot
.676 .37799 Mdot
.676 .37799 Mdot
.676 .37812 Mdot
.676 .37813 Mdot
.676 .37813 Mdot
.676 .37829 Mdot
.676 .37847 Mdot
.676 .37849 Mdot
.676 .37859 Mdot
.676 .37875 Mdot
.676 .37877 Mdot
.676 .3789 Mdot
.676 .3789 Mdot
.676 .37895 Mdot
.676 .37896 Mdot
.676 .37914 Mdot
.676 .37914 Mdot
.676 .3792 Mdot
.676 .37933 Mdot
.676 .37938 Mdot
.676 .37939 Mdot
.676 .37945 Mdot
.676 .3795 Mdot
.676 .37953 Mdot
.676 .37955 Mdot
.676 .37963 Mdot
.676 .37968 Mdot
.676 .37994 Mdot
.676 .37995 Mdot
.676 .38006 Mdot
.676 .38007 Mdot
.676 .38015 Mdot
.676 .38021 Mdot
.676 .38025 Mdot
.676 .38032 Mdot
.676 .38034 Mdot
.676 .3804 Mdot
.676 .38041 Mdot
.676 .38043 Mdot
.676 .38049 Mdot
.676 .3807 Mdot
.676 .3808 Mdot
.676 .38099 Mdot
.676 .38099 Mdot
.676 .38107 Mdot
.676 .38124 Mdot
.676 .38126 Mdot
.676 .38126 Mdot
.676 .38132 Mdot
.676 .38144 Mdot
.676 .38144 Mdot
.676 .3815 Mdot
.676 .38157 Mdot
.676 .38175 Mdot
.676 .38181 Mdot
.676 .38181 Mdot
.676 .38183 Mdot
.676 .38184 Mdot
.676 .38191 Mdot
.676 .38206 Mdot
.676 .3821 Mdot
.676 .38236 Mdot
.676 .38238 Mdot
.676 .3825 Mdot
.676 .38252 Mdot
.676 .38254 Mdot
.676 .38257 Mdot
.676 .38257 Mdot
.676 .38268 Mdot
.676 .38268 Mdot
.676 .38286 Mdot
.676 .38298 Mdot
.676 .383 Mdot
.676 .383 Mdot
.676 .38303 Mdot
.676 .38309 Mdot
.676 .3832 Mdot
.676 .38326 Mdot
.676 .38332 Mdot
.676 .38334 Mdot
.676 .38362 Mdot
.676 .38371 Mdot
.676 .38373 Mdot
.676 .38403 Mdot
.676 .3841 Mdot
.676 .38429 Mdot
.676 .3843 Mdot
.676 .38445 Mdot
.676 .38458 Mdot
.676 .38462 Mdot
.676 .38482 Mdot
.676 .38487 Mdot
.676 .385 Mdot
.676 .38523 Mdot
.676 .38554 Mdot
.676 .38558 Mdot
.676 .38561 Mdot
.676 .38563 Mdot
.676 .38573 Mdot
.676 .38593 Mdot
.676 .386 Mdot
.676 .38641 Mdot
.676 .38669 Mdot
.676 .38674 Mdot
.676 .38678 Mdot
.676 .38729 Mdot
.676 .3873 Mdot
.676 .3873 Mdot
.676 .38733 Mdot
.676 .38779 Mdot
.676 .3878 Mdot
.676 .38782 Mdot
.676 .38787 Mdot
.676 .38794 Mdot
.676 .38796 Mdot
.676 .388 Mdot
.676 .38821 Mdot
.676 .38825 Mdot
.676 .38827 Mdot
.676 .38832 Mdot
.676 .38835 Mdot
.676 .38835 Mdot
.676 .38841 Mdot
.676 .38862 Mdot
.676 .3888 Mdot
.676 .38888 Mdot
.676 .3889 Mdot
.676 .38901 Mdot
.676 .38902 Mdot
.676 .38904 Mdot
.676 .38904 Mdot
.676 .38908 Mdot
.676 .38909 Mdot
.676 .38909 Mdot
.676 .38911 Mdot
.676 .38937 Mdot
.676 .38953 Mdot
.676 .38954 Mdot
.676 .38965 Mdot
.676 .38983 Mdot
.676 .38983 Mdot
.676 .38989 Mdot
.676 .38994 Mdot
.676 .3901 Mdot
.676 .39021 Mdot
.676 .39023 Mdot
.676 .39023 Mdot
.676 .39024 Mdot
.676 .39026 Mdot
.676 .39026 Mdot
.676 .39031 Mdot
.676 .39031 Mdot
.676 .39031 Mdot
.676 .39031 Mdot
.676 .39031 Mdot
.676 .39031 Mdot
.676 .39032 Mdot
.676 .39032 Mdot
.676 .39032 Mdot
.676 .39032 Mdot
.676 .39033 Mdot
.676 .39034 Mdot
.676 .39035 Mdot
.676 .39035 Mdot
.676 .39036 Mdot
.676 .39037 Mdot
.676 .39038 Mdot
.676 .39038 Mdot
.676 .39038 Mdot
.676 .39041 Mdot
.676 .39041 Mdot
.676 .39041 Mdot
.676 .39044 Mdot
.676 .39047 Mdot
.676 .39048 Mdot
.676 .3905 Mdot
.676 .39053 Mdot
.676 .39053 Mdot
.676 .39056 Mdot
.676 .39056 Mdot
.676 .39057 Mdot
.676 .39057 Mdot
.676 .3906 Mdot
.676 .3906 Mdot
.676 .39061 Mdot
.676 .39064 Mdot
.676 .39065 Mdot
.676 .39066 Mdot
.676 .39067 Mdot
.676 .39068 Mdot
.676 .39068 Mdot
.676 .3907 Mdot
.676 .39071 Mdot
.676 .39076 Mdot
.676 .39076 Mdot
.676 .39078 Mdot
.676 .39078 Mdot
.676 .3908 Mdot
.676 .39081 Mdot
.676 .39081 Mdot
.676 .39083 Mdot
.676 .39083 Mdot
.676 .39084 Mdot
.676 .39085 Mdot
.676 .39085 Mdot
.676 .3909 Mdot
.676 .39096 Mdot
.676 .39096 Mdot
.676 .391 Mdot
.676 .39101 Mdot
.676 .39101 Mdot
.676 .39102 Mdot
.676 .39104 Mdot
.676 .39104 Mdot
.676 .39107 Mdot
.676 .3911 Mdot
.676 .39111 Mdot
.676 .39111 Mdot
.676 .39112 Mdot
.676 .39112 Mdot
.676 .39113 Mdot
.676 .39116 Mdot
.676 .39117 Mdot
.676 .39122 Mdot
.676 .39122 Mdot
.676 .39124 Mdot
.676 .39125 Mdot
.676 .39125 Mdot
.676 .39126 Mdot
.676 .39126 Mdot
.676 .39128 Mdot
.676 .39128 Mdot
.676 .39131 Mdot
.676 .39134 Mdot
.676 .39134 Mdot
.676 .39134 Mdot
.676 .39135 Mdot
.676 .39136 Mdot
.676 .39138 Mdot
.676 .39139 Mdot
.676 .3914 Mdot
.676 .39141 Mdot
.676 .39146 Mdot
.676 .39148 Mdot
.676 .39148 Mdot
.676 .39154 Mdot
.676 .39155 Mdot
.676 .39159 Mdot
.676 .39159 Mdot
.676 .39162 Mdot
.676 .39164 Mdot
.676 .39169 Mdot
.676 .3917 Mdot
.676 .39173 Mdot
.676 .39177 Mdot
.676 .39183 Mdot
.676 .39184 Mdot
.676 .39184 Mdot
.676 .39185 Mdot
.676 .39187 Mdot
.676 .39191 Mdot
.676 .39192 Mdot
.676 .392 Mdot
.676 .39205 Mdot
.676 .39207 Mdot
.676 .39217 Mdot
.676 .39217 Mdot
.676 .39217 Mdot
.676 .39218 Mdot
.676 .39227 Mdot
.676 .39227 Mdot
.676 .39227 Mdot
.676 .3923 Mdot
.676 .3923 Mdot
.676 .39231 Mdot
.676 .39235 Mdot
.676 .39236 Mdot
.676 .39237 Mdot
.676 .39238 Mdot
.676 .39238 Mdot
.676 .39239 Mdot
.676 .39243 Mdot
.676 .39247 Mdot
.676 .39248 Mdot
.676 .39249 Mdot
.676 .39251 Mdot
.676 .39251 Mdot
.676 .39251 Mdot
.676 .39251 Mdot
.676 .39252 Mdot
.676 .39252 Mdot
.676 .39252 Mdot
.676 .39253 Mdot
.676 .39258 Mdot
.676 .39261 Mdot
.676 .39267 Mdot
.676 .39268 Mdot
.676 .39269 Mdot
.676 .39275 Mdot
.676 .39275 Mdot
.676 .39275 Mdot
.676 .39276 Mdot
.676 .39276 Mdot
.676 .39277 Mdot
.676 .39277 Mdot
.676 .39279 Mdot
.676 .39281 Mdot
.676 .39282 Mdot
.676 .39284 Mdot
.676 .39287 Mdot
.676 .39296 Mdot
.676 .39303 Mdot
.676 .39306 Mdot
.676 .39307 Mdot
.676 .39308 Mdot
.676 .39318 Mdot
.676 .39318 Mdot
.676 .39325 Mdot
.676 .39326 Mdot
.676 .39326 Mdot
.676 .39326 Mdot
.676 .39327 Mdot
.676 .39336 Mdot
.676 .39346 Mdot
.676 .39349 Mdot
.676 .39354 Mdot
.676 .39365 Mdot
.676 .39368 Mdot
.676 .39368 Mdot
.676 .39369 Mdot
.676 .39371 Mdot
.676 .39385 Mdot
.676 .39386 Mdot
.676 .39399 Mdot
.676 .39402 Mdot
.676 .39408 Mdot
.676 .39409 Mdot
.676 .39412 Mdot
.676 .39418 Mdot
.676 .39424 Mdot
.676 .39433 Mdot
.676 .39445 Mdot
.676 .39452 Mdot
.676 .39459 Mdot
.676 .39464 Mdot
.676 .39465 Mdot
.676 .3947 Mdot
.676 .39474 Mdot
.676 .39474 Mdot
.676 .39477 Mdot
.676 .39477 Mdot
.676 .39478 Mdot
.676 .39478 Mdot
.676 .39478 Mdot
.676 .39479 Mdot
.676 .39484 Mdot
.676 .3949 Mdot
.676 .39492 Mdot
.676 .39495 Mdot
.676 .39495 Mdot
.676 .39503 Mdot
.676 .39507 Mdot
.676 .39507 Mdot
.676 .39514 Mdot
.676 .39525 Mdot
.676 .39526 Mdot
.676 .39526 Mdot
.676 .39526 Mdot
.676 .39528 Mdot
.676 .39528 Mdot
.676 .39529 Mdot
.676 .39529 Mdot
.676 .39534 Mdot
.676 .39534 Mdot
.676 .39538 Mdot
.676 .39545 Mdot
.676 .39554 Mdot
.676 .39556 Mdot
.676 .39556 Mdot
.676 .39557 Mdot
.676 .39559 Mdot
.676 .3956 Mdot
.676 .39562 Mdot
.676 .3957 Mdot
.676 .39572 Mdot
.676 .39573 Mdot
.676 .39576 Mdot
.676 .39578 Mdot
.676 .39579 Mdot
.676 .39579 Mdot
.676 .39597 Mdot
.676 .39599 Mdot
.676 .39599 Mdot
.676 .39599 Mdot
.676 .3962 Mdot
.676 .39621 Mdot
.676 .39623 Mdot
.676 .39634 Mdot
.676 .3965 Mdot
.676 .39653 Mdot
.676 .39661 Mdot
.676 .39664 Mdot
.676 .39665 Mdot
.676 .39666 Mdot
.676 .39668 Mdot
.676 .3968 Mdot
.676 .39689 Mdot
.676 .39694 Mdot
.676 .39696 Mdot
.676 .39704 Mdot
.676 .39705 Mdot
.676 .3971 Mdot
.676 .39716 Mdot
.676 .39716 Mdot
.676 .39723 Mdot
.676 .39726 Mdot
.676 .39737 Mdot
.676 .39738 Mdot
.676 .39742 Mdot
.676 .39752 Mdot
.676 .39753 Mdot
.676 .39755 Mdot
.676 .39757 Mdot
.676 .39761 Mdot
.676 .39763 Mdot
.676 .39765 Mdot
.676 .39765 Mdot
.676 .39766 Mdot
.676 .3977 Mdot
.676 .39777 Mdot
.676 .39777 Mdot
.676 .39781 Mdot
.676 .39781 Mdot
.676 .39782 Mdot
.676 .39783 Mdot
.676 .39783 Mdot
.676 .39788 Mdot
.676 .39789 Mdot
.676 .39798 Mdot
.676 .398 Mdot
.676 .39805 Mdot
.676 .39808 Mdot
.676 .39808 Mdot
.676 .39809 Mdot
.676 .39809 Mdot
.676 .39811 Mdot
.676 .39818 Mdot
.676 .3982 Mdot
.676 .39822 Mdot
.676 .39822 Mdot
.676 .39827 Mdot
.676 .39829 Mdot
.676 .39829 Mdot
.676 .39829 Mdot
.676 .39836 Mdot
.676 .39839 Mdot
.676 .39839 Mdot
.676 .39846 Mdot
.676 .39849 Mdot
.676 .39857 Mdot
.676 .39859 Mdot
.676 .3986 Mdot
.676 .3986 Mdot
.676 .39862 Mdot
.676 .39863 Mdot
.676 .39865 Mdot
.676 .39867 Mdot
.676 .39869 Mdot
.676 .39872 Mdot
.676 .39872 Mdot
.676 .39876 Mdot
.676 .39876 Mdot
.676 .39886 Mdot
.676 .39888 Mdot
.676 .39891 Mdot
.676 .39891 Mdot
.676 .39892 Mdot
.676 .39894 Mdot
.676 .39896 Mdot
.676 .39896 Mdot
.676 .39898 Mdot
.676 .39903 Mdot
.676 .39905 Mdot
.676 .39905 Mdot
.676 .39911 Mdot
.676 .39912 Mdot
.676 .39914 Mdot
.676 .39914 Mdot
.676 .39918 Mdot
.676 .39919 Mdot
.676 .39925 Mdot
.676 .39928 Mdot
.676 .39929 Mdot
.676 .39935 Mdot
.676 .39941 Mdot
.676 .39941 Mdot
.676 .39941 Mdot
.676 .39945 Mdot
.676 .39946 Mdot
.676 .39947 Mdot
.676 .39947 Mdot
.676 .3995 Mdot
.676 .39951 Mdot
.676 .39951 Mdot
.676 .39954 Mdot
.676 .39956 Mdot
.676 .39956 Mdot
.676 .39957 Mdot
.676 .39958 Mdot
.676 .39958 Mdot
.676 .39958 Mdot
.676 .39958 Mdot
.676 .39959 Mdot
.676 .39959 Mdot
.676 .39959 Mdot
.676 .39959 Mdot
.676 .39967 Mdot
.676 .39968 Mdot
.676 .39972 Mdot
.676 .39973 Mdot
.676 .39973 Mdot
.676 .39978 Mdot
.676 .3998 Mdot
.676 .39997 Mdot
.676 .40009 Mdot
.676 .40025 Mdot
.676 .40033 Mdot
.676 .40044 Mdot
.676 .40045 Mdot
.676 .40077 Mdot
.676 .40093 Mdot
.676 .40095 Mdot
.676 .40097 Mdot
.676 .40122 Mdot
.676 .40124 Mdot
.676 .40166 Mdot
.676 .40168 Mdot
.676 .40171 Mdot
.676 .40172 Mdot
.676 .40172 Mdot
.676 .40173 Mdot
.676 .40179 Mdot
.676 .40179 Mdot
.676 .40181 Mdot
.676 .40183 Mdot
.676 .40184 Mdot
.676 .40184 Mdot
.676 .40202 Mdot
.676 .40206 Mdot
.676 .40219 Mdot
.676 .40248 Mdot
.676 .40282 Mdot
.676 .4029 Mdot
.676 .40291 Mdot
.676 .40295 Mdot
.676 .40303 Mdot
.676 .40307 Mdot
.676 .4031 Mdot
.676 .40313 Mdot
.676 .4033 Mdot
.676 .40345 Mdot
.676 .40347 Mdot
.676 .40352 Mdot
.676 .40354 Mdot
.676 .40365 Mdot
.676 .40372 Mdot
.676 .40376 Mdot
.676 .40376 Mdot
.676 .40444 Mdot
.676 .40449 Mdot
.676 .40449 Mdot
.676 .4045 Mdot
.676 .40522 Mdot
.676 .40527 Mdot
.676 .40533 Mdot
.676 .40571 Mdot
.676 .40572 Mdot
.676 .40575 Mdot
.676 .40577 Mdot
.676 .4059 Mdot
.676 .40624 Mdot
.676 .40633 Mdot
.676 .40658 Mdot
.676 .4067 Mdot
.676 .40674 Mdot
.676 .40677 Mdot
.676 .40681 Mdot
.676 .40718 Mdot
.676 .40745 Mdot
.676 .4076 Mdot
.676 .40765 Mdot
.676 .40783 Mdot
.676 .40785 Mdot
.676 .40787 Mdot
.676 .40792 Mdot
.676 .40793 Mdot
.676 .40805 Mdot
.676 .40813 Mdot
.676 .40822 Mdot
.676 .40823 Mdot
.676 .4084 Mdot
.676 .40842 Mdot
.676 .40848 Mdot
.676 .40849 Mdot
.676 .4086 Mdot
.676 .40864 Mdot
.676 .4088 Mdot
.676 .40881 Mdot
.676 .4089 Mdot
.676 .40901 Mdot
.676 .40917 Mdot
.676 .40918 Mdot
.676 .40925 Mdot
.676 .40929 Mdot
.676 .40939 Mdot
.676 .4094 Mdot
.676 .40945 Mdot
.676 .40947 Mdot
.676 .40948 Mdot
.676 .40948 Mdot
.676 .4095 Mdot
.676 .40954 Mdot
.676 .4096 Mdot
.676 .40963 Mdot
.676 .40975 Mdot
.676 .40975 Mdot
.676 .4098 Mdot
.676 .40985 Mdot
.676 .40985 Mdot
.676 .40987 Mdot
.676 .40988 Mdot
.676 .40989 Mdot
.676 .40991 Mdot
.676 .40991 Mdot
.676 .41 Mdot
.676 .41002 Mdot
.676 .41009 Mdot
.676 .41022 Mdot
.676 .41026 Mdot
.676 .41037 Mdot
.676 .41042 Mdot
.676 .41043 Mdot
.676 .41044 Mdot
.676 .41044 Mdot
.676 .41048 Mdot
.676 .41062 Mdot
.676 .41066 Mdot
.676 .41071 Mdot
.676 .41071 Mdot
.676 .41075 Mdot
.676 .41079 Mdot
.676 .41083 Mdot
.676 .41083 Mdot
.676 .41084 Mdot
.676 .41096 Mdot
.676 .41101 Mdot
.676 .41101 Mdot
.676 .41113 Mdot
.676 .41119 Mdot
.676 .41124 Mdot
.676 .41131 Mdot
.676 .41135 Mdot
.676 .41136 Mdot
.676 .41136 Mdot
.676 .4114 Mdot
.676 .41141 Mdot
.676 .41144 Mdot
.676 .41145 Mdot
.676 .41147 Mdot
.676 .41149 Mdot
.676 .4115 Mdot
.676 .41155 Mdot
.676 .41155 Mdot
.676 .41161 Mdot
.676 .41161 Mdot
.676 .41174 Mdot
.676 .41174 Mdot
.676 .41175 Mdot
.676 .41176 Mdot
.676 .41176 Mdot
.676 .41178 Mdot
.676 .4118 Mdot
.676 .41181 Mdot
.676 .41181 Mdot
.676 .41181 Mdot
.676 .41182 Mdot
.676 .41184 Mdot
.676 .41187 Mdot
.676 .41188 Mdot
.676 .41189 Mdot
.676 .4119 Mdot
.676 .4119 Mdot
.676 .4119 Mdot
.676 .41191 Mdot
.676 .41194 Mdot
.676 .41196 Mdot
.676 .41197 Mdot
.676 .41198 Mdot
.676 .41198 Mdot
.676 .41205 Mdot
.676 .41206 Mdot
.676 .41208 Mdot
.676 .41208 Mdot
.676 .41213 Mdot
.676 .41213 Mdot
.676 .41219 Mdot
.676 .41223 Mdot
.676 .41223 Mdot
.676 .41229 Mdot
.676 .41234 Mdot
.676 .41234 Mdot
.676 .41235 Mdot
.676 .41238 Mdot
.676 .41238 Mdot
.676 .41238 Mdot
.676 .41239 Mdot
.676 .41239 Mdot
.676 .4124 Mdot
.676 .41242 Mdot
.676 .41242 Mdot
.676 .41243 Mdot
.676 .41245 Mdot
.676 .41246 Mdot
.676 .41247 Mdot
.676 .41247 Mdot
.676 .41248 Mdot
.676 .41248 Mdot
.676 .41248 Mdot
.676 .41248 Mdot
.676 .41248 Mdot
.676 .41248 Mdot
.676 .41248 Mdot
.676 .41248 Mdot
.676 .41254 Mdot
.676 .41254 Mdot
.676 .41256 Mdot
.676 .41257 Mdot
.676 .41257 Mdot
.676 .41257 Mdot
.676 .41258 Mdot
.676 .41259 Mdot
.676 .4126 Mdot
.676 .41261 Mdot
.676 .41266 Mdot
.676 .41268 Mdot
.676 .41271 Mdot
.676 .41274 Mdot
.676 .41274 Mdot
.676 .41274 Mdot
.676 .41274 Mdot
.678 .33003 Mdot
.678 .33003 Mdot
.678 .33004 Mdot
.678 .33008 Mdot
.678 .33015 Mdot
.678 .33017 Mdot
.678 .33018 Mdot
.678 .3302 Mdot
.678 .33023 Mdot
.678 .33024 Mdot
.678 .33054 Mdot
.678 .3306 Mdot
.678 .33066 Mdot
.678 .33076 Mdot
.678 .33099 Mdot
.678 .33103 Mdot
.678 .33106 Mdot
.678 .33107 Mdot
.678 .33151 Mdot
.678 .33181 Mdot
.678 .33188 Mdot
.678 .33189 Mdot
.678 .33197 Mdot
.678 .33206 Mdot
.678 .33212 Mdot
.678 .33228 Mdot
.678 .33245 Mdot
.678 .33265 Mdot
.678 .33271 Mdot
.678 .33285 Mdot
.678 .3332 Mdot
.678 .33328 Mdot
.678 .33353 Mdot
.678 .33383 Mdot
.678 .33387 Mdot
.678 .33457 Mdot
.678 .33507 Mdot
.678 .33583 Mdot
.678 .33612 Mdot
.678 .33664 Mdot
.678 .33675 Mdot
.678 .33695 Mdot
.678 .33721 Mdot
.678 .33748 Mdot
.678 .33748 Mdot
.678 .33749 Mdot
.678 .33749 Mdot
.678 .33753 Mdot
.678 .33755 Mdot
.678 .33756 Mdot
.678 .3376 Mdot
.678 .33765 Mdot
.678 .33766 Mdot
.678 .3378 Mdot
.678 .33782 Mdot
.678 .33783 Mdot
.678 .33787 Mdot
.678 .3379 Mdot
.678 .33802 Mdot
.678 .33804 Mdot
.678 .33805 Mdot
.678 .33814 Mdot
.678 .3382 Mdot
.678 .33845 Mdot
.678 .3385 Mdot
.678 .33856 Mdot
.678 .33868 Mdot
.678 .33871 Mdot
.678 .33879 Mdot
.678 .33884 Mdot
.678 .33892 Mdot
.678 .33896 Mdot
.678 .33906 Mdot
.678 .33913 Mdot
.678 .33925 Mdot
.678 .33929 Mdot
.678 .33934 Mdot
.678 .3394 Mdot
.678 .33948 Mdot
.678 .33954 Mdot
.678 .33969 Mdot
.678 .3398 Mdot
.678 .33981 Mdot
.678 .33982 Mdot
.678 .33992 Mdot
.678 .33998 Mdot
.678 .33999 Mdot
.678 .34017 Mdot
.678 .34027 Mdot
.678 .34034 Mdot
.678 .3404 Mdot
.678 .34054 Mdot
.678 .34061 Mdot
.678 .34074 Mdot
.678 .34081 Mdot
.678 .34099 Mdot
.678 .34116 Mdot
.678 .34133 Mdot
.678 .3414 Mdot
.678 .34162 Mdot
.678 .34185 Mdot
.678 .342 Mdot
.678 .34206 Mdot
.678 .34227 Mdot
.678 .3423 Mdot
.678 .34237 Mdot
.678 .34248 Mdot
.678 .34248 Mdot
.678 .34257 Mdot
.678 .34266 Mdot
.678 .34274 Mdot
.678 .34288 Mdot
.678 .34305 Mdot
.678 .34311 Mdot
.678 .34314 Mdot
.678 .34318 Mdot
.678 .34325 Mdot
.678 .34331 Mdot
.678 .34355 Mdot
.678 .34359 Mdot
.678 .34369 Mdot
.678 .34369 Mdot
.678 .34389 Mdot
.678 .34414 Mdot
.678 .34428 Mdot
.678 .34434 Mdot
.678 .34438 Mdot
.678 .34448 Mdot
.678 .34453 Mdot
.678 .34459 Mdot
.678 .34462 Mdot
.678 .34478 Mdot
.678 .34483 Mdot
.678 .34485 Mdot
.678 .34489 Mdot
.678 .34494 Mdot
.678 .34498 Mdot
.678 .34519 Mdot
.678 .34519 Mdot
.678 .34583 Mdot
.678 .34592 Mdot
.678 .34612 Mdot
.678 .34628 Mdot
.678 .34633 Mdot
.678 .34638 Mdot
.678 .34654 Mdot
.678 .34656 Mdot
.678 .34661 Mdot
.678 .34675 Mdot
.678 .34676 Mdot
.678 .34677 Mdot
.678 .347 Mdot
.678 .34703 Mdot
.678 .34704 Mdot
.678 .34711 Mdot
.678 .34711 Mdot
.678 .34813 Mdot
.678 .34868 Mdot
.678 .34915 Mdot
.678 .34927 Mdot
.678 .34952 Mdot
.678 .34965 Mdot
.678 .3499 Mdot
.678 .35032 Mdot
.678 .35075 Mdot
.678 .35118 Mdot
.678 .3516 Mdot
.678 .35163 Mdot
.678 .35172 Mdot
.678 .35196 Mdot
.678 .35343 Mdot
.678 .35351 Mdot
.678 .35359 Mdot
.678 .35361 Mdot
.678 .35389 Mdot
.678 .35407 Mdot
.678 .35449 Mdot
.678 .35463 Mdot
.678 .35481 Mdot
.678 .35491 Mdot
.678 .35524 Mdot
.678 .35536 Mdot
.678 .35568 Mdot
.678 .35574 Mdot
.678 .35585 Mdot
.678 .3568 Mdot
.678 .3571 Mdot
.678 .35735 Mdot
.678 .3575 Mdot
.678 .35757 Mdot
.678 .35811 Mdot
.678 .35836 Mdot
.678 .35895 Mdot
.678 .35927 Mdot
.678 .36119 Mdot
.678 .36129 Mdot
.678 .36147 Mdot
.678 .36179 Mdot
.678 .3653 Mdot
.678 .36538 Mdot
.678 .36545 Mdot
.678 .36591 Mdot
.678 .36598 Mdot
.678 .36647 Mdot
.678 .36649 Mdot
.678 .36694 Mdot
.678 .36703 Mdot
.678 .36807 Mdot
.678 .36833 Mdot
.678 .36913 Mdot
.678 .36922 Mdot
.678 .36928 Mdot
.678 .37009 Mdot
.678 .37038 Mdot
.678 .3708 Mdot
.678 .37102 Mdot
.678 .37148 Mdot
.678 .37158 Mdot
.678 .37217 Mdot
.678 .37224 Mdot
.678 .37224 Mdot
.678 .37306 Mdot
.678 .37315 Mdot
.678 .37358 Mdot
.678 .37446 Mdot
.678 .37461 Mdot
.678 .37536 Mdot
.678 .37543 Mdot
.678 .37569 Mdot
.678 .37594 Mdot
.678 .37626 Mdot
.678 .37629 Mdot
.678 .37643 Mdot
.678 .37644 Mdot
.678 .37701 Mdot
.678 .37711 Mdot
.678 .37733 Mdot
.678 .37765 Mdot
.678 .37769 Mdot
.678 .37813 Mdot
.678 .37839 Mdot
.678 .37858 Mdot
.678 .37863 Mdot
.678 .37875 Mdot
.678 .37887 Mdot
.678 .37901 Mdot
.678 .37937 Mdot
.678 .37941 Mdot
.678 .37973 Mdot
.678 .38073 Mdot
.678 .38086 Mdot
.678 .38131 Mdot
.678 .38142 Mdot
.678 .38142 Mdot
.678 .38142 Mdot
.678 .38142 Mdot
.678 .38144 Mdot
.678 .38145 Mdot
.678 .38145 Mdot
.678 .38147 Mdot
.678 .38149 Mdot
.678 .38149 Mdot
.678 .38154 Mdot
.678 .38155 Mdot
.678 .38156 Mdot
.678 .38157 Mdot
.678 .38158 Mdot
.678 .38163 Mdot
.678 .38164 Mdot
.678 .38164 Mdot
.678 .38167 Mdot
.678 .3817 Mdot
.678 .38179 Mdot
.678 .38181 Mdot
.678 .38183 Mdot
.678 .38183 Mdot
.678 .38189 Mdot
.678 .38192 Mdot
.678 .38193 Mdot
.678 .38196 Mdot
.678 .38198 Mdot
.678 .38201 Mdot
.678 .38204 Mdot
.678 .38208 Mdot
.678 .38211 Mdot
.678 .38213 Mdot
.678 .38216 Mdot
.678 .38218 Mdot
.678 .38223 Mdot
.678 .38227 Mdot
.678 .38228 Mdot
.678 .38231 Mdot
.678 .38233 Mdot
.678 .38234 Mdot
.678 .3824 Mdot
.678 .38243 Mdot
.678 .38246 Mdot
.678 .38248 Mdot
.678 .38252 Mdot
.678 .38254 Mdot
.678 .38259 Mdot
.678 .38261 Mdot
.678 .38267 Mdot
.678 .38272 Mdot
.678 .38278 Mdot
.678 .3828 Mdot
.678 .38287 Mdot
.678 .38299 Mdot
.678 .38307 Mdot
.678 .38308 Mdot
.678 .38311 Mdot
.678 .38314 Mdot
.678 .38314 Mdot
.678 .38317 Mdot
.678 .38319 Mdot
.678 .38322 Mdot
.678 .38326 Mdot
.678 .38331 Mdot
.678 .38333 Mdot
.678 .38333 Mdot
.678 .38335 Mdot
.678 .38346 Mdot
.678 .38347 Mdot
.678 .3835 Mdot
.678 .3835 Mdot
.678 .38355 Mdot
.678 .38363 Mdot
.678 .38367 Mdot
.678 .38369 Mdot
.678 .38369 Mdot
.678 .38372 Mdot
.678 .38374 Mdot
.678 .38376 Mdot
.678 .38381 Mdot
.678 .38383 Mdot
.678 .38384 Mdot
.678 .38385 Mdot
.678 .38386 Mdot
.678 .38392 Mdot
.678 .38392 Mdot
.678 .3841 Mdot
.678 .38412 Mdot
.678 .38422 Mdot
.678 .38425 Mdot
.678 .38429 Mdot
.678 .38431 Mdot
.678 .38434 Mdot
.678 .38434 Mdot
.678 .38435 Mdot
.678 .38441 Mdot
.678 .38442 Mdot
.678 .38442 Mdot
.678 .38444 Mdot
.678 .38444 Mdot
.678 .3847 Mdot
.678 .38484 Mdot
.678 .38496 Mdot
.678 .38499 Mdot
.678 .38505 Mdot
.678 .38508 Mdot
.678 .38514 Mdot
.678 .38524 Mdot
.678 .38535 Mdot
.678 .38545 Mdot
.678 .38555 Mdot
.678 .38555 Mdot
.678 .38558 Mdot
.678 .38563 Mdot
.678 .38597 Mdot
.678 .38599 Mdot
.678 .386 Mdot
.678 .38601 Mdot
.678 .38607 Mdot
.678 .38611 Mdot
.678 .38621 Mdot
.678 .38624 Mdot
.678 .38628 Mdot
.678 .3863 Mdot
.678 .38637 Mdot
.678 .3864 Mdot
.678 .38647 Mdot
.678 .38648 Mdot
.678 .3865 Mdot
.678 .38671 Mdot
.678 .38677 Mdot
.678 .38686 Mdot
.678 .38687 Mdot
.678 .38699 Mdot
.678 .38762 Mdot
.678 .38764 Mdot
.678 .38768 Mdot
.678 .38774 Mdot
.678 .38843 Mdot
.678 .38844 Mdot
.678 .38855 Mdot
.678 .38856 Mdot
.678 .38865 Mdot
.678 .38874 Mdot
.678 .38876 Mdot
.678 .38896 Mdot
.678 .38918 Mdot
.678 .38919 Mdot
.678 .38934 Mdot
.678 .38939 Mdot
.678 .38962 Mdot
.678 .38973 Mdot
.678 .38974 Mdot
.678 .38989 Mdot
.678 .38999 Mdot
.678 .39015 Mdot
.678 .39018 Mdot
.678 .39031 Mdot
.678 .39033 Mdot
.678 .39038 Mdot
.678 .39049 Mdot
.678 .39051 Mdot
.678 .39062 Mdot
.678 .39063 Mdot
.678 .39073 Mdot
.678 .39082 Mdot
.678 .39087 Mdot
.678 .39091 Mdot
.678 .39093 Mdot
.678 .39098 Mdot
.678 .39105 Mdot
.678 .39129 Mdot
.678 .39142 Mdot
.678 .39142 Mdot
.678 .39142 Mdot
.678 .39142 Mdot
.678 .39142 Mdot
.678 .39143 Mdot
.678 .39143 Mdot
.678 .39143 Mdot
.678 .39143 Mdot
.678 .39143 Mdot
.678 .39144 Mdot
.678 .39145 Mdot
.678 .39145 Mdot
.678 .39145 Mdot
.678 .39145 Mdot
.678 .39146 Mdot
.678 .39146 Mdot
.678 .39146 Mdot
.678 .39147 Mdot
.678 .39147 Mdot
.678 .39149 Mdot
.678 .39149 Mdot
.678 .3915 Mdot
.678 .3915 Mdot
.678 .39151 Mdot
.678 .39151 Mdot
.678 .39152 Mdot
.678 .39152 Mdot
.678 .39152 Mdot
.678 .39153 Mdot
.678 .39155 Mdot
.678 .39155 Mdot
.678 .39156 Mdot
.678 .39156 Mdot
.678 .39157 Mdot
.678 .39158 Mdot
.678 .39158 Mdot
.678 .39159 Mdot
.678 .39159 Mdot
.678 .3916 Mdot
.678 .39161 Mdot
.678 .39161 Mdot
.678 .39162 Mdot
.678 .39163 Mdot
.678 .39163 Mdot
.678 .39164 Mdot
.678 .39165 Mdot
.678 .39166 Mdot
.678 .39167 Mdot
.678 .39167 Mdot
.678 .39169 Mdot
.678 .39171 Mdot
.678 .39172 Mdot
.678 .39173 Mdot
.678 .39173 Mdot
.678 .39174 Mdot
.678 .39175 Mdot
.678 .39176 Mdot
.678 .39177 Mdot
.678 .39177 Mdot
.678 .39177 Mdot
.678 .39179 Mdot
.678 .3918 Mdot
.678 .3918 Mdot
.678 .3918 Mdot
.678 .39184 Mdot
.678 .39184 Mdot
.678 .39185 Mdot
.678 .39185 Mdot
.678 .39186 Mdot
.678 .39186 Mdot
.678 .39187 Mdot
.678 .39188 Mdot
.678 .39188 Mdot
.678 .39191 Mdot
.678 .39192 Mdot
.678 .39193 Mdot
.678 .39194 Mdot
.678 .39195 Mdot
.678 .39195 Mdot
.678 .39196 Mdot
.678 .39196 Mdot
.678 .39196 Mdot
.678 .39197 Mdot
.678 .39197 Mdot
.678 .39197 Mdot
.678 .39197 Mdot
.678 .39197 Mdot
.678 .39202 Mdot
.678 .39207 Mdot
.678 .39208 Mdot
.678 .39209 Mdot
.678 .3921 Mdot
.678 .39214 Mdot
.678 .39216 Mdot
.678 .39218 Mdot
.678 .39218 Mdot
.678 .39219 Mdot
.678 .39226 Mdot
.678 .39226 Mdot
.678 .39226 Mdot
.678 .39228 Mdot
.678 .39228 Mdot
.678 .3923 Mdot
.678 .39231 Mdot
.678 .39232 Mdot
.678 .39234 Mdot
.678 .39242 Mdot
.678 .39243 Mdot
.678 .39245 Mdot
.678 .39256 Mdot
.678 .39257 Mdot
.678 .39272 Mdot
.678 .39272 Mdot
.678 .39276 Mdot
.678 .39286 Mdot
.678 .39294 Mdot
.678 .39296 Mdot
.678 .39299 Mdot
.678 .39301 Mdot
.678 .39307 Mdot
.678 .39308 Mdot
.678 .39309 Mdot
.678 .39311 Mdot
.678 .39311 Mdot
.678 .39317 Mdot
.678 .39319 Mdot
.678 .39319 Mdot
.678 .3932 Mdot
.678 .39333 Mdot
.678 .39335 Mdot
.678 .39335 Mdot
.678 .39339 Mdot
.678 .39339 Mdot
.678 .39351 Mdot
.678 .39402 Mdot
.678 .39403 Mdot
.678 .39406 Mdot
.678 .39426 Mdot
.678 .39431 Mdot
.678 .39439 Mdot
.678 .39451 Mdot
.678 .39452 Mdot
.678 .39452 Mdot
.678 .39459 Mdot
.678 .3946 Mdot
.678 .39462 Mdot
.678 .39465 Mdot
.678 .39472 Mdot
.678 .3948 Mdot
.678 .3949 Mdot
.678 .39493 Mdot
.678 .39495 Mdot
.678 .39496 Mdot
.678 .39498 Mdot
.678 .395 Mdot
.678 .39504 Mdot
.678 .39508 Mdot
.678 .39508 Mdot
.678 .39513 Mdot
.678 .39514 Mdot
.678 .39518 Mdot
.678 .3952 Mdot
.678 .39521 Mdot
.678 .39527 Mdot
.678 .39528 Mdot
.678 .39534 Mdot
.678 .39538 Mdot
.678 .39545 Mdot
.678 .39545 Mdot
.678 .3955 Mdot
.678 .39559 Mdot
.678 .39561 Mdot
.678 .39567 Mdot
.678 .39568 Mdot
.678 .39576 Mdot
.678 .39584 Mdot
.678 .39585 Mdot
.678 .39589 Mdot
.678 .39592 Mdot
.678 .39593 Mdot
.678 .39597 Mdot
.678 .39598 Mdot
.678 .39625 Mdot
.678 .39627 Mdot
.678 .39629 Mdot
.678 .3963 Mdot
.678 .39655 Mdot
.678 .39659 Mdot
.678 .3966 Mdot
.678 .39663 Mdot
.678 .39665 Mdot
.678 .39673 Mdot
.678 .39674 Mdot
.678 .39675 Mdot
.678 .39677 Mdot
.678 .39678 Mdot
.678 .39681 Mdot
.678 .39682 Mdot
.678 .39684 Mdot
.678 .39685 Mdot
.678 .39688 Mdot
.678 .3969 Mdot
.678 .39692 Mdot
.678 .39692 Mdot
.678 .39693 Mdot
.678 .39694 Mdot
.678 .39707 Mdot
.678 .39709 Mdot
.678 .3971 Mdot
.678 .3971 Mdot
.678 .39714 Mdot
.678 .39718 Mdot
.678 .39721 Mdot
.678 .39725 Mdot
.678 .39728 Mdot
.678 .39729 Mdot
.678 .39731 Mdot
.678 .39732 Mdot
.678 .39737 Mdot
.678 .39742 Mdot
.678 .39752 Mdot
.678 .39752 Mdot
.678 .39752 Mdot
.678 .39753 Mdot
.678 .39753 Mdot
.678 .39755 Mdot
.678 .39755 Mdot
.678 .39755 Mdot
.678 .39757 Mdot
.678 .39757 Mdot
.678 .39759 Mdot
.678 .3976 Mdot
.678 .39764 Mdot
.678 .39764 Mdot
.678 .39771 Mdot
.678 .39771 Mdot
.678 .39773 Mdot
.678 .39774 Mdot
.678 .39774 Mdot
.678 .39774 Mdot
.678 .39775 Mdot
.678 .39777 Mdot
.678 .39778 Mdot
.678 .39778 Mdot
.678 .39779 Mdot
.678 .3978 Mdot
.678 .3978 Mdot
.678 .39782 Mdot
.678 .39785 Mdot
.678 .39787 Mdot
.678 .39787 Mdot
.678 .39788 Mdot
.678 .39788 Mdot
.678 .39792 Mdot
.678 .39793 Mdot
.678 .39793 Mdot
.678 .39794 Mdot
.678 .39795 Mdot
.678 .39797 Mdot
.678 .39798 Mdot
.678 .39799 Mdot
.678 .398 Mdot
.678 .398 Mdot
.678 .39801 Mdot
.678 .39802 Mdot
.678 .39802 Mdot
.678 .39805 Mdot
.678 .3981 Mdot
.678 .39812 Mdot
.678 .39813 Mdot
.678 .39815 Mdot
.678 .39817 Mdot
.678 .39819 Mdot
.678 .3982 Mdot
.678 .39822 Mdot
.678 .39822 Mdot
.678 .39824 Mdot
.678 .39825 Mdot
.678 .39826 Mdot
.678 .39827 Mdot
.678 .39829 Mdot
.678 .39829 Mdot
.678 .3983 Mdot
.678 .39831 Mdot
.678 .39831 Mdot
.678 .39833 Mdot
.678 .39835 Mdot
.678 .39836 Mdot
.678 .39837 Mdot
.678 .39837 Mdot
.678 .39839 Mdot
.678 .3984 Mdot
.678 .39841 Mdot
.678 .39842 Mdot
.678 .39843 Mdot
.678 .39844 Mdot
.678 .39844 Mdot
.678 .39845 Mdot
.678 .39847 Mdot
.678 .39848 Mdot
.678 .39848 Mdot
.678 .39849 Mdot
.678 .39852 Mdot
.678 .39853 Mdot
.678 .39854 Mdot
.678 .39855 Mdot
.678 .39855 Mdot
.678 .39856 Mdot
.678 .39857 Mdot
.678 .39857 Mdot
.678 .39858 Mdot
.678 .39858 Mdot
.678 .3986 Mdot
.678 .3986 Mdot
.678 .39861 Mdot
.678 .39861 Mdot
.678 .39861 Mdot
.678 .39862 Mdot
.678 .39862 Mdot
.678 .39862 Mdot
.678 .39862 Mdot
.678 .39862 Mdot
.678 .39866 Mdot
.678 .39882 Mdot
.678 .39887 Mdot
.678 .39922 Mdot
.678 .39933 Mdot
.678 .39935 Mdot
.678 .39947 Mdot
.678 .39952 Mdot
.678 .39957 Mdot
.678 .39961 Mdot
.678 .39962 Mdot
.678 .39969 Mdot
.678 .39978 Mdot
.678 .39993 Mdot
.678 .39994 Mdot
.678 .40005 Mdot
.678 .40013 Mdot
.678 .40016 Mdot
.678 .40036 Mdot
.678 .40036 Mdot
.678 .4004 Mdot
.678 .40042 Mdot
.678 .40052 Mdot
.678 .40061 Mdot
.678 .40069 Mdot
.678 .40072 Mdot
.678 .40097 Mdot
.678 .40102 Mdot
.678 .40131 Mdot
.678 .40145 Mdot
.678 .40148 Mdot
.678 .40174 Mdot
.678 .40175 Mdot
.678 .40177 Mdot
.678 .40196 Mdot
.678 .40199 Mdot
.678 .40214 Mdot
.678 .40221 Mdot
.678 .40234 Mdot
.678 .40244 Mdot
.678 .40269 Mdot
.678 .40271 Mdot
.678 .40274 Mdot
.678 .40299 Mdot
.678 .40307 Mdot
.678 .4034 Mdot
.678 .40343 Mdot
.678 .40357 Mdot
.678 .40357 Mdot
.678 .40372 Mdot
.678 .40375 Mdot
.678 .40389 Mdot
.678 .40391 Mdot
.678 .40393 Mdot
.678 .405 Mdot
.678 .40509 Mdot
.678 .40515 Mdot
.678 .40518 Mdot
.678 .40575 Mdot
.678 .40584 Mdot
.678 .40601 Mdot
.678 .40609 Mdot
.678 .40625 Mdot
.678 .40627 Mdot
.678 .40631 Mdot
.678 .40638 Mdot
.678 .40647 Mdot
.678 .40675 Mdot
.678 .40678 Mdot
.678 .4068 Mdot
.678 .40689 Mdot
.678 .40692 Mdot
.678 .40702 Mdot
.678 .40705 Mdot
.678 .4071 Mdot
.678 .40714 Mdot
.678 .40726 Mdot
.678 .40731 Mdot
.678 .40739 Mdot
.678 .4074 Mdot
.678 .40742 Mdot
.678 .40744 Mdot
.678 .40787 Mdot
.678 .40793 Mdot
.678 .40796 Mdot
.678 .40797 Mdot
.678 .40809 Mdot
.678 .40821 Mdot
.678 .40833 Mdot
.678 .40845 Mdot
.678 .40852 Mdot
.678 .40856 Mdot
.678 .40863 Mdot
.678 .40866 Mdot
.678 .40879 Mdot
.678 .40895 Mdot
.678 .40923 Mdot
.678 .40924 Mdot
.678 .40925 Mdot
.678 .40926 Mdot
.678 .40926 Mdot
.678 .40933 Mdot
.678 .40933 Mdot
.678 .40934 Mdot
.678 .40937 Mdot
.678 .40939 Mdot
.678 .40939 Mdot
.678 .40944 Mdot
.678 .40945 Mdot
.678 .40946 Mdot
.678 .40951 Mdot
.678 .40957 Mdot
.678 .40959 Mdot
.678 .40977 Mdot
.678 .40977 Mdot
.678 .40983 Mdot
.678 .40984 Mdot
.678 .40985 Mdot
.678 .40986 Mdot
.678 .40987 Mdot
.678 .40988 Mdot
.678 .40993 Mdot
.678 .40994 Mdot
.678 .40995 Mdot
.678 .40997 Mdot
.678 .41 Mdot
.678 .41001 Mdot
.678 .41002 Mdot
.678 .41006 Mdot
.678 .41013 Mdot
.678 .41019 Mdot
.678 .41019 Mdot
.678 .41022 Mdot
.678 .41023 Mdot
.678 .41029 Mdot
.678 .41031 Mdot
.678 .41033 Mdot
.678 .41034 Mdot
.678 .41035 Mdot
.678 .41036 Mdot
.678 .41041 Mdot
.678 .41045 Mdot
.678 .41047 Mdot
.678 .4105 Mdot
.678 .41052 Mdot
.678 .41052 Mdot
.678 .41055 Mdot
.678 .41057 Mdot
.678 .41058 Mdot
.678 .41064 Mdot
.678 .41065 Mdot
.678 .4107 Mdot
.678 .41076 Mdot
.678 .41082 Mdot
.678 .41084 Mdot
.678 .41089 Mdot
.678 .41093 Mdot
.678 .41098 Mdot
.678 .411 Mdot
.678 .41104 Mdot
.678 .41106 Mdot
.678 .41109 Mdot
.678 .41111 Mdot
.678 .41113 Mdot
.678 .41116 Mdot
.678 .41121 Mdot
.678 .41121 Mdot
.678 .41123 Mdot
.678 .41125 Mdot
.678 .41126 Mdot
.678 .41129 Mdot
.678 .41133 Mdot
.678 .41135 Mdot
.678 .41137 Mdot
.678 .41139 Mdot
.678 .4114 Mdot
.678 .41141 Mdot
.678 .41144 Mdot
.678 .41146 Mdot
.678 .41149 Mdot
.678 .4115 Mdot
.678 .41152 Mdot
.678 .41154 Mdot
.678 .41156 Mdot
.678 .41157 Mdot
.678 .4116 Mdot
.678 .4116 Mdot
.678 .41162 Mdot
.678 .41163 Mdot
.678 .4117 Mdot
.678 .41171 Mdot
.678 .41174 Mdot
.678 .41174 Mdot
.678 .41175 Mdot
.678 .41178 Mdot
.678 .41179 Mdot
.678 .4118 Mdot
.678 .4118 Mdot
.678 .41181 Mdot
.678 .41184 Mdot
.678 .41185 Mdot
.678 .41186 Mdot
.678 .41187 Mdot
.678 .41188 Mdot
.678 .41188 Mdot
.678 .41189 Mdot
.678 .41189 Mdot
.678 .41189 Mdot
.678 .41189 Mdot
.678 .41197 Mdot
.678 .41204 Mdot
.678 .41209 Mdot
.678 .41212 Mdot
.678 .41227 Mdot
.678 .41235 Mdot
.678 .41255 Mdot
.678 .41269 Mdot
.678 .41288 Mdot
.678 .41289 Mdot
.678 .41297 Mdot
.678 .41304 Mdot
.678 .41306 Mdot
.678 .41316 Mdot
.678 .41319 Mdot
.678 .41321 Mdot
.678 .41326 Mdot
.678 .41331 Mdot
.678 .41335 Mdot
.678 .41337 Mdot
.678 .4134 Mdot
.678 .41342 Mdot
.678 .41342 Mdot
.678 .41344 Mdot
.678 .41352 Mdot
.678 .41364 Mdot
.678 .41364 Mdot
.678 .41365 Mdot
.678 .41366 Mdot
.678 .41372 Mdot
.678 .41375 Mdot
.678 .41377 Mdot
.678 .41378 Mdot
.678 .41386 Mdot
.678 .41386 Mdot
.678 .41387 Mdot
.678 .41388 Mdot
.678 .41388 Mdot
.678 .41389 Mdot
.678 .41391 Mdot
.678 .41392 Mdot
.678 .41392 Mdot
.678 .41392 Mdot
.68 .32659 Mdot
.68 .32661 Mdot
.68 .32666 Mdot
.68 .3267 Mdot
.68 .32672 Mdot
.68 .32696 Mdot
.68 .32701 Mdot
.68 .32721 Mdot
.68 .32726 Mdot
.68 .32734 Mdot
.68 .32735 Mdot
.68 .32735 Mdot
.68 .32736 Mdot
.68 .32748 Mdot
.68 .32751 Mdot
.68 .3276 Mdot
.68 .32768 Mdot
.68 .32773 Mdot
.68 .32778 Mdot
.68 .32782 Mdot
.68 .32782 Mdot
.68 .32827 Mdot
.68 .3285 Mdot
.68 .32859 Mdot
.68 .32864 Mdot
.68 .32887 Mdot
.68 .32888 Mdot
.68 .32898 Mdot
.68 .32901 Mdot
.68 .32904 Mdot
.68 .32914 Mdot
.68 .32916 Mdot
.68 .32922 Mdot
.68 .32956 Mdot
.68 .32968 Mdot
.68 .32981 Mdot
.68 .32982 Mdot
.68 .33007 Mdot
.68 .33015 Mdot
.68 .33049 Mdot
.68 .3305 Mdot
.68 .33058 Mdot
.68 .33061 Mdot
.68 .33069 Mdot
.68 .33076 Mdot
.68 .33089 Mdot
.68 .33102 Mdot
.68 .33108 Mdot
.68 .33142 Mdot
.68 .33143 Mdot
.68 .33145 Mdot
.68 .33148 Mdot
.68 .33151 Mdot
.68 .33173 Mdot
.68 .33184 Mdot
.68 .33187 Mdot
.68 .33194 Mdot
.68 .33254 Mdot
.68 .33276 Mdot
.68 .33283 Mdot
.68 .33291 Mdot
.68 .33292 Mdot
.68 .33297 Mdot
.68 .33299 Mdot
.68 .33307 Mdot
.68 .33364 Mdot
.68 .33376 Mdot
.68 .33386 Mdot
.68 .33405 Mdot
.68 .33432 Mdot
.68 .33435 Mdot
.68 .33451 Mdot
.68 .33494 Mdot
.68 .33549 Mdot
.68 .33552 Mdot
.68 .33568 Mdot
.68 .33587 Mdot
.68 .33634 Mdot
.68 .33694 Mdot
.68 .33774 Mdot
.68 .33783 Mdot
.68 .33862 Mdot
.68 .3387 Mdot
.68 .3388 Mdot
.68 .33907 Mdot
.68 .33921 Mdot
.68 .3396 Mdot
.68 .34002 Mdot
.68 .34007 Mdot
.68 .34016 Mdot
.68 .34029 Mdot
.68 .34077 Mdot
.68 .34169 Mdot
.68 .34198 Mdot
.68 .34204 Mdot
.68 .34225 Mdot
.68 .34231 Mdot
.68 .34253 Mdot
.68 .34261 Mdot
.68 .34296 Mdot
.68 .34318 Mdot
.68 .34377 Mdot
.68 .34392 Mdot
.68 .34397 Mdot
.68 .34406 Mdot
.68 .34408 Mdot
.68 .3441 Mdot
.68 .34414 Mdot
.68 .34417 Mdot
.68 .34462 Mdot
.68 .34465 Mdot
.68 .34472 Mdot
.68 .34515 Mdot
.68 .3453 Mdot
.68 .34549 Mdot
.68 .34567 Mdot
.68 .34585 Mdot
.68 .34586 Mdot
.68 .34613 Mdot
.68 .34632 Mdot
.68 .34674 Mdot
.68 .34689 Mdot
.68 .34764 Mdot
.68 .34801 Mdot
.68 .34805 Mdot
.68 .34841 Mdot
.68 .34857 Mdot
.68 .34871 Mdot
.68 .34889 Mdot
.68 .34891 Mdot
.68 .34899 Mdot
.68 .34904 Mdot
.68 .34906 Mdot
.68 .34918 Mdot
.68 .34926 Mdot
.68 .3493 Mdot
.68 .34953 Mdot
.68 .34962 Mdot
.68 .34969 Mdot
.68 .34975 Mdot
.68 .34999 Mdot
.68 .35005 Mdot
.68 .35006 Mdot
.68 .35007 Mdot
.68 .35012 Mdot
.68 .35015 Mdot
.68 .35017 Mdot
.68 .35022 Mdot
.68 .35095 Mdot
.68 .35114 Mdot
.68 .3512 Mdot
.68 .35126 Mdot
.68 .35153 Mdot
.68 .35158 Mdot
.68 .35194 Mdot
.68 .35197 Mdot
.68 .35204 Mdot
.68 .35221 Mdot
.68 .35224 Mdot
.68 .35304 Mdot
.68 .35325 Mdot
.68 .35348 Mdot
.68 .35356 Mdot
.68 .35367 Mdot
.68 .35397 Mdot
.68 .354 Mdot
.68 .35412 Mdot
.68 .35414 Mdot
.68 .35448 Mdot
.68 .35454 Mdot
.68 .35455 Mdot
.68 .35459 Mdot
.68 .35495 Mdot
.68 .3552 Mdot
.68 .35533 Mdot
.68 .3557 Mdot
.68 .35573 Mdot
.68 .35583 Mdot
.68 .35605 Mdot
.68 .35607 Mdot
.68 .35623 Mdot
.68 .35639 Mdot
.68 .35662 Mdot
.68 .35701 Mdot
.68 .35701 Mdot
.68 .35719 Mdot
.68 .35813 Mdot
.68 .35839 Mdot
.68 .35846 Mdot
.68 .35852 Mdot
.68 .35872 Mdot
.68 .3591 Mdot
.68 .35926 Mdot
.68 .35951 Mdot
.68 .35956 Mdot
.68 .35979 Mdot
.68 .35989 Mdot
.68 .35998 Mdot
.68 .36006 Mdot
.68 .36009 Mdot
.68 .36015 Mdot
.68 .36023 Mdot
.68 .36036 Mdot
.68 .36055 Mdot
.68 .36057 Mdot
.68 .36065 Mdot
.68 .36099 Mdot
.68 .3611 Mdot
.68 .36117 Mdot
.68 .36122 Mdot
.68 .36137 Mdot
.68 .36175 Mdot
.68 .36186 Mdot
.68 .3619 Mdot
.68 .36191 Mdot
.68 .36274 Mdot
.68 .36323 Mdot
.68 .36325 Mdot
.68 .36375 Mdot
.68 .36387 Mdot
.68 .36437 Mdot
.68 .36452 Mdot
.68 .36464 Mdot
.68 .36483 Mdot
.68 .36501 Mdot
.68 .36508 Mdot
.68 .36515 Mdot
.68 .36535 Mdot
.68 .36543 Mdot
.68 .36558 Mdot
.68 .36575 Mdot
.68 .36576 Mdot
.68 .36642 Mdot
.68 .36662 Mdot
.68 .36677 Mdot
.68 .36766 Mdot
.68 .36825 Mdot
.68 .3687 Mdot
.68 .36878 Mdot
.68 .36904 Mdot
.68 .36942 Mdot
.68 .36942 Mdot
.68 .36945 Mdot
.68 .36964 Mdot
.68 .36999 Mdot
.68 .37001 Mdot
.68 .37022 Mdot
.68 .37043 Mdot
.68 .37066 Mdot
.68 .37073 Mdot
.68 .37105 Mdot
.68 .37122 Mdot
.68 .37139 Mdot
.68 .37163 Mdot
.68 .3719 Mdot
.68 .37191 Mdot
.68 .37209 Mdot
.68 .37241 Mdot
.68 .37286 Mdot
.68 .37286 Mdot
.68 .3729 Mdot
.68 .37295 Mdot
.68 .37311 Mdot
.68 .37361 Mdot
.68 .37383 Mdot
.68 .37393 Mdot
.68 .37402 Mdot
.68 .37482 Mdot
.68 .37509 Mdot
.68 .37547 Mdot
.68 .37615 Mdot
.68 .37619 Mdot
.68 .37724 Mdot
.68 .37734 Mdot
.68 .37735 Mdot
.68 .37735 Mdot
.68 .37736 Mdot
.68 .37751 Mdot
.68 .37754 Mdot
.68 .37773 Mdot
.68 .37848 Mdot
.68 .37854 Mdot
.68 .37884 Mdot
.68 .37886 Mdot
.68 .37888 Mdot
.68 .37894 Mdot
.68 .37896 Mdot
.68 .3793 Mdot
.68 .37937 Mdot
.68 .37958 Mdot
.68 .37977 Mdot
.68 .37977 Mdot
.68 .37983 Mdot
.68 .37991 Mdot
.68 .37998 Mdot
.68 .38005 Mdot
.68 .38025 Mdot
.68 .38025 Mdot
.68 .38028 Mdot
.68 .38029 Mdot
.68 .3804 Mdot
.68 .3805 Mdot
.68 .38086 Mdot
.68 .38089 Mdot
.68 .38093 Mdot
.68 .38099 Mdot
.68 .38123 Mdot
.68 .38132 Mdot
.68 .38139 Mdot
.68 .38151 Mdot
.68 .38173 Mdot
.68 .38193 Mdot
.68 .382 Mdot
.68 .38207 Mdot
.68 .38223 Mdot
.68 .38269 Mdot
.68 .38272 Mdot
.68 .38297 Mdot
.68 .38299 Mdot
.68 .38302 Mdot
.68 .3831 Mdot
.68 .38338 Mdot
.68 .3834 Mdot
.68 .38346 Mdot
.68 .3836 Mdot
.68 .38385 Mdot
.68 .38401 Mdot
.68 .38402 Mdot
.68 .3841 Mdot
.68 .38444 Mdot
.68 .38448 Mdot
.68 .38449 Mdot
.68 .38449 Mdot
.68 .3845 Mdot
.68 .38462 Mdot
.68 .38463 Mdot
.68 .38475 Mdot
.68 .38484 Mdot
.68 .38493 Mdot
.68 .38493 Mdot
.68 .38504 Mdot
.68 .38514 Mdot
.68 .38518 Mdot
.68 .38544 Mdot
.68 .38553 Mdot
.68 .38557 Mdot
.68 .3856 Mdot
.68 .38564 Mdot
.68 .38565 Mdot
.68 .38566 Mdot
.68 .38568 Mdot
.68 .38568 Mdot
.68 .38571 Mdot
.68 .38572 Mdot
.68 .38573 Mdot
.68 .38579 Mdot
.68 .38584 Mdot
.68 .38589 Mdot
.68 .3859 Mdot
.68 .3859 Mdot
.68 .38591 Mdot
.68 .38592 Mdot
.68 .38592 Mdot
.68 .38593 Mdot
.68 .38594 Mdot
.68 .3861 Mdot
.68 .38614 Mdot
.68 .38616 Mdot
.68 .38623 Mdot
.68 .38624 Mdot
.68 .38632 Mdot
.68 .38632 Mdot
.68 .38634 Mdot
.68 .38637 Mdot
.68 .38638 Mdot
.68 .38655 Mdot
.68 .38659 Mdot
.68 .38664 Mdot
.68 .38666 Mdot
.68 .38668 Mdot
.68 .38678 Mdot
.68 .38686 Mdot
.68 .38686 Mdot
.68 .38687 Mdot
.68 .38695 Mdot
.68 .387 Mdot
.68 .38703 Mdot
.68 .3871 Mdot
.68 .38713 Mdot
.68 .38717 Mdot
.68 .38717 Mdot
.68 .3874 Mdot
.68 .38766 Mdot
.68 .3877 Mdot
.68 .3878 Mdot
.68 .38786 Mdot
.68 .38793 Mdot
.68 .38796 Mdot
.68 .38798 Mdot
.68 .38799 Mdot
.68 .38805 Mdot
.68 .38806 Mdot
.68 .38816 Mdot
.68 .38817 Mdot
.68 .38818 Mdot
.68 .38821 Mdot
.68 .3883 Mdot
.68 .38831 Mdot
.68 .38856 Mdot
.68 .38866 Mdot
.68 .38868 Mdot
.68 .38877 Mdot
.68 .38882 Mdot
.68 .38886 Mdot
.68 .38889 Mdot
.68 .3889 Mdot
.68 .38897 Mdot
.68 .38902 Mdot
.68 .38903 Mdot
.68 .38918 Mdot
.68 .38921 Mdot
.68 .38937 Mdot
.68 .38948 Mdot
.68 .38956 Mdot
.68 .38957 Mdot
.68 .38962 Mdot
.68 .38969 Mdot
.68 .38969 Mdot
.68 .38973 Mdot
.68 .38983 Mdot
.68 .38987 Mdot
.68 .38991 Mdot
.68 .38992 Mdot
.68 .38998 Mdot
.68 .39004 Mdot
.68 .39008 Mdot
.68 .39013 Mdot
.68 .39016 Mdot
.68 .3903 Mdot
.68 .3903 Mdot
.68 .39034 Mdot
.68 .39047 Mdot
.68 .39064 Mdot
.68 .39088 Mdot
.68 .39108 Mdot
.68 .39109 Mdot
.68 .39111 Mdot
.68 .39115 Mdot
.68 .39135 Mdot
.68 .39135 Mdot
.68 .39136 Mdot
.68 .39144 Mdot
.68 .39154 Mdot
.68 .39172 Mdot
.68 .39178 Mdot
.68 .3919 Mdot
.68 .39191 Mdot
.68 .39207 Mdot
.68 .39233 Mdot
.68 .39234 Mdot
.68 .3924 Mdot
.68 .39245 Mdot
.68 .39253 Mdot
.68 .39253 Mdot
.68 .39254 Mdot
.68 .39255 Mdot
.68 .39255 Mdot
.68 .39255 Mdot
.68 .39259 Mdot
.68 .39259 Mdot
.68 .39262 Mdot
.68 .39263 Mdot
.68 .39264 Mdot
.68 .39265 Mdot
.68 .39266 Mdot
.68 .39267 Mdot
.68 .39267 Mdot
.68 .39271 Mdot
.68 .39272 Mdot
.68 .39272 Mdot
.68 .39272 Mdot
.68 .39274 Mdot
.68 .39276 Mdot
.68 .39279 Mdot
.68 .3928 Mdot
.68 .39281 Mdot
.68 .39281 Mdot
.68 .39285 Mdot
.68 .39297 Mdot
.68 .393 Mdot
.68 .39302 Mdot
.68 .39306 Mdot
.68 .39308 Mdot
.68 .39311 Mdot
.68 .39312 Mdot
.68 .39312 Mdot
.68 .39313 Mdot
.68 .39315 Mdot
.68 .39323 Mdot
.68 .3933 Mdot
.68 .39331 Mdot
.68 .39332 Mdot
.68 .39335 Mdot
.68 .39338 Mdot
.68 .39341 Mdot
.68 .39352 Mdot
.68 .39352 Mdot
.68 .39357 Mdot
.68 .39357 Mdot
.68 .39359 Mdot
.68 .39367 Mdot
.68 .3937 Mdot
.68 .39375 Mdot
.68 .39379 Mdot
.68 .39381 Mdot
.68 .39384 Mdot
.68 .39384 Mdot
.68 .39384 Mdot
.68 .39392 Mdot
.68 .39398 Mdot
.68 .39401 Mdot
.68 .39403 Mdot
.68 .39404 Mdot
.68 .39407 Mdot
.68 .3941 Mdot
.68 .39419 Mdot
.68 .39421 Mdot
.68 .39425 Mdot
.68 .3943 Mdot
.68 .39433 Mdot
.68 .39437 Mdot
.68 .39439 Mdot
.68 .39445 Mdot
.68 .39463 Mdot
.68 .39463 Mdot
.68 .39464 Mdot
.68 .39467 Mdot
.68 .3947 Mdot
.68 .39475 Mdot
.68 .39478 Mdot
.68 .3948 Mdot
.68 .39483 Mdot
.68 .39483 Mdot
.68 .39494 Mdot
.68 .39501 Mdot
.68 .39501 Mdot
.68 .39506 Mdot
.68 .39509 Mdot
.68 .39516 Mdot
.68 .3952 Mdot
.68 .39523 Mdot
.68 .39524 Mdot
.68 .39524 Mdot
.68 .39532 Mdot
.68 .39534 Mdot
.68 .39535 Mdot
.68 .39535 Mdot
.68 .39543 Mdot
.68 .39553 Mdot
.68 .3956 Mdot
.68 .39565 Mdot
.68 .39567 Mdot
.68 .39567 Mdot
.68 .39572 Mdot
.68 .39574 Mdot
.68 .39576 Mdot
.68 .39577 Mdot
.68 .3958 Mdot
.68 .39582 Mdot
.68 .39582 Mdot
.68 .39584 Mdot
.68 .39586 Mdot
.68 .3959 Mdot
.68 .39591 Mdot
.68 .39591 Mdot
.68 .39594 Mdot
.68 .39596 Mdot
.68 .39596 Mdot
.68 .396 Mdot
.68 .39604 Mdot
.68 .3961 Mdot
.68 .39611 Mdot
.68 .39618 Mdot
.68 .39618 Mdot
.68 .3962 Mdot
.68 .39622 Mdot
.68 .39623 Mdot
.68 .39624 Mdot
.68 .39626 Mdot
.68 .39628 Mdot
.68 .39631 Mdot
.68 .39632 Mdot
.68 .39636 Mdot
.68 .39646 Mdot
.68 .39646 Mdot
.68 .3965 Mdot
.68 .39651 Mdot
.68 .39651 Mdot
.68 .39652 Mdot
.68 .39656 Mdot
.68 .39656 Mdot
.68 .39658 Mdot
.68 .39659 Mdot
.68 .39659 Mdot
.68 .39661 Mdot
.68 .39663 Mdot
.68 .39665 Mdot
.68 .39669 Mdot
.68 .39671 Mdot
.68 .39681 Mdot
.68 .3969 Mdot
.68 .3969 Mdot
.68 .39691 Mdot
.68 .39692 Mdot
.68 .39695 Mdot
.68 .39696 Mdot
.68 .39698 Mdot
.68 .39701 Mdot
.68 .39701 Mdot
.68 .39701 Mdot
.68 .39705 Mdot
.68 .39708 Mdot
.68 .39709 Mdot
.68 .3971 Mdot
.68 .39712 Mdot
.68 .39713 Mdot
.68 .3972 Mdot
.68 .3972 Mdot
.68 .39721 Mdot
.68 .39722 Mdot
.68 .39722 Mdot
.68 .39725 Mdot
.68 .39726 Mdot
.68 .39728 Mdot
.68 .39729 Mdot
.68 .3973 Mdot
.68 .39736 Mdot
.68 .39737 Mdot
.68 .39737 Mdot
.68 .39737 Mdot
.68 .39738 Mdot
.68 .39738 Mdot
.68 .39738 Mdot
.68 .39738 Mdot
.68 .3974 Mdot
.68 .39742 Mdot
.68 .39744 Mdot
.68 .39744 Mdot
.68 .39745 Mdot
.68 .39746 Mdot
.68 .39746 Mdot
.68 .39747 Mdot
.68 .39747 Mdot
.68 .39748 Mdot
.68 .39749 Mdot
.68 .3975 Mdot
.68 .39752 Mdot
.68 .39755 Mdot
.68 .39765 Mdot
.68 .39766 Mdot
.68 .3977 Mdot
.68 .39774 Mdot
.68 .39774 Mdot
.68 .39777 Mdot
.68 .3978 Mdot
.68 .39785 Mdot
.68 .39785 Mdot
.68 .3979 Mdot
.68 .3979 Mdot
.68 .3979 Mdot
.68 .39791 Mdot
.68 .39792 Mdot
.68 .39804 Mdot
.68 .39807 Mdot
.68 .39808 Mdot
.68 .39813 Mdot
.68 .39823 Mdot
.68 .39828 Mdot
.68 .3983 Mdot
.68 .39831 Mdot
.68 .39841 Mdot
.68 .39844 Mdot
.68 .39845 Mdot
.68 .39846 Mdot
.68 .39854 Mdot
.68 .39855 Mdot
.68 .39872 Mdot
.68 .39878 Mdot
.68 .3988 Mdot
.68 .39883 Mdot
.68 .3989 Mdot
.68 .39897 Mdot
.68 .39902 Mdot
.68 .39904 Mdot
.68 .39907 Mdot
.68 .39916 Mdot
.68 .39918 Mdot
.68 .39919 Mdot
.68 .3992 Mdot
.68 .39933 Mdot
.68 .39937 Mdot
.68 .3994 Mdot
.68 .39941 Mdot
.68 .39942 Mdot
.68 .39942 Mdot
.68 .39949 Mdot
.68 .39951 Mdot
.68 .39953 Mdot
.68 .39956 Mdot
.68 .39958 Mdot
.68 .39958 Mdot
.68 .39965 Mdot
.68 .39972 Mdot
.68 .39975 Mdot
.68 .39986 Mdot
.68 .39987 Mdot
.68 .39989 Mdot
.68 .3999 Mdot
.68 .3999 Mdot
.68 .4 Mdot
.68 .40003 Mdot
.68 .40028 Mdot
.68 .40034 Mdot
.68 .40035 Mdot
.68 .4004 Mdot
.68 .40041 Mdot
.68 .40041 Mdot
.68 .40041 Mdot
.68 .40045 Mdot
.68 .40079 Mdot
.68 .40081 Mdot
.68 .40104 Mdot
.68 .40116 Mdot
.68 .40125 Mdot
.68 .40151 Mdot
.68 .40154 Mdot
.68 .40157 Mdot
.68 .40164 Mdot
.68 .40181 Mdot
.68 .40186 Mdot
.68 .40187 Mdot
.68 .40189 Mdot
.68 .40189 Mdot
.68 .40203 Mdot
.68 .40213 Mdot
.68 .40219 Mdot
.68 .40219 Mdot
.68 .40228 Mdot
.68 .40236 Mdot
.68 .40241 Mdot
.68 .40246 Mdot
.68 .40257 Mdot
.68 .40259 Mdot
.68 .40266 Mdot
.68 .40273 Mdot
.68 .40279 Mdot
.68 .4028 Mdot
.68 .40291 Mdot
.68 .40297 Mdot
.68 .40298 Mdot
.68 .40298 Mdot
.68 .4031 Mdot
.68 .40318 Mdot
.68 .4032 Mdot
.68 .40334 Mdot
.68 .40353 Mdot
.68 .4038 Mdot
.68 .40384 Mdot
.68 .40391 Mdot
.68 .40411 Mdot
.68 .40411 Mdot
.68 .40416 Mdot
.68 .40421 Mdot
.68 .40423 Mdot
.68 .40429 Mdot
.68 .40431 Mdot
.68 .40433 Mdot
.68 .40439 Mdot
.68 .40445 Mdot
.68 .40449 Mdot
.68 .40453 Mdot
.68 .40468 Mdot
.68 .40472 Mdot
.68 .40487 Mdot
.68 .40487 Mdot
.68 .40502 Mdot
.68 .40527 Mdot
.68 .40527 Mdot
.68 .40528 Mdot
.68 .40531 Mdot
.68 .40542 Mdot
.68 .40547 Mdot
.68 .40548 Mdot
.68 .4055 Mdot
.68 .40554 Mdot
.68 .40564 Mdot
.68 .40566 Mdot
.68 .40567 Mdot
.68 .40573 Mdot
.68 .40576 Mdot
.68 .40579 Mdot
.68 .4058 Mdot
.68 .40581 Mdot
.68 .40584 Mdot
.68 .40586 Mdot
.68 .40589 Mdot
.68 .40596 Mdot
.68 .40597 Mdot
.68 .40605 Mdot
.68 .40609 Mdot
.68 .40621 Mdot
.68 .40626 Mdot
.68 .40628 Mdot
.68 .4063 Mdot
.68 .40638 Mdot
.68 .40665 Mdot
.68 .4067 Mdot
.68 .40682 Mdot
.68 .40688 Mdot
.68 .40693 Mdot
.68 .40697 Mdot
.68 .40698 Mdot
.68 .40704 Mdot
.68 .40707 Mdot
.68 .40708 Mdot
.68 .40719 Mdot
.68 .40722 Mdot
.68 .40729 Mdot
.68 .4074 Mdot
.68 .40741 Mdot
.68 .40741 Mdot
.68 .40743 Mdot
.68 .40753 Mdot
.68 .40753 Mdot
.68 .40757 Mdot
.68 .40758 Mdot
.68 .40766 Mdot
.68 .40769 Mdot
.68 .40771 Mdot
.68 .40778 Mdot
.68 .40784 Mdot
.68 .40807 Mdot
.68 .40808 Mdot
.68 .40812 Mdot
.68 .40814 Mdot
.68 .40815 Mdot
.68 .40825 Mdot
.68 .40827 Mdot
.68 .40835 Mdot
.68 .40836 Mdot
.68 .40838 Mdot
.68 .40843 Mdot
.68 .40864 Mdot
.68 .40865 Mdot
.68 .40866 Mdot
.68 .40867 Mdot
.68 .40868 Mdot
.68 .40868 Mdot
.68 .40868 Mdot
.68 .4087 Mdot
.68 .40877 Mdot
.68 .40879 Mdot
.68 .40881 Mdot
.68 .40883 Mdot
.68 .4089 Mdot
.68 .40891 Mdot
.68 .40893 Mdot
.68 .40896 Mdot
.68 .40897 Mdot
.68 .40898 Mdot
.68 .409 Mdot
.68 .40901 Mdot
.68 .40906 Mdot
.68 .4091 Mdot
.68 .40915 Mdot
.68 .40925 Mdot
.68 .40926 Mdot
.68 .40936 Mdot
.68 .40957 Mdot
.68 .40961 Mdot
.68 .40973 Mdot
.68 .40978 Mdot
.68 .40986 Mdot
.68 .40986 Mdot
.68 .40991 Mdot
.68 .40996 Mdot
.68 .41001 Mdot
.68 .41005 Mdot
.68 .41017 Mdot
.68 .41019 Mdot
.68 .4102 Mdot
.68 .41032 Mdot
.68 .41033 Mdot
.68 .41034 Mdot
.68 .41035 Mdot
.68 .41035 Mdot
.68 .41038 Mdot
.68 .41039 Mdot
.68 .41043 Mdot
.68 .41059 Mdot
.68 .41066 Mdot
.68 .41075 Mdot
.68 .41077 Mdot
.68 .41083 Mdot
.68 .41085 Mdot
.68 .41091 Mdot
.68 .41092 Mdot
.68 .411 Mdot
.68 .41126 Mdot
.68 .41139 Mdot
.68 .41142 Mdot
.68 .41145 Mdot
.68 .41146 Mdot
.68 .41157 Mdot
.68 .41168 Mdot
.68 .41172 Mdot
.68 .41179 Mdot
.68 .41182 Mdot
.68 .41184 Mdot
.68 .41206 Mdot
.68 .41208 Mdot
.68 .4123 Mdot
.68 .41246 Mdot
.68 .41259 Mdot
.68 .41264 Mdot
.68 .41269 Mdot
.68 .41269 Mdot
.68 .41284 Mdot
.68 .41296 Mdot
.68 .413 Mdot
.68 .41301 Mdot
.68 .41308 Mdot
.68 .41314 Mdot
.68 .41316 Mdot
.68 .4132 Mdot
.68 .41335 Mdot
.68 .41337 Mdot
.68 .41338 Mdot
.68 .41339 Mdot
.68 .41339 Mdot
.68 .41341 Mdot
.68 .41343 Mdot
.68 .41349 Mdot
.68 .41366 Mdot
.68 .41367 Mdot
.68 .41368 Mdot
.68 .41371 Mdot
.68 .41377 Mdot
.68 .41378 Mdot
.68 .41379 Mdot
.68 .41379 Mdot
.68 .4138 Mdot
.68 .41389 Mdot
.68 .4139 Mdot
.68 .41394 Mdot
.68 .41397 Mdot
.68 .41399 Mdot
.68 .41401 Mdot
.68 .41402 Mdot
.68 .41405 Mdot
.68 .41405 Mdot
.68 .41414 Mdot
.68 .41416 Mdot
.68 .41423 Mdot
.68 .41423 Mdot
.68 .41427 Mdot
.68 .4143 Mdot
.68 .41439 Mdot
.68 .41441 Mdot
.68 .41441 Mdot
.68 .41444 Mdot
.68 .41445 Mdot
.68 .41445 Mdot
.68 .41448 Mdot
.68 .41449 Mdot
.68 .41455 Mdot
.68 .41456 Mdot
.68 .41458 Mdot
.68 .41465 Mdot
.68 .41477 Mdot
.68 .41477 Mdot
.68 .41478 Mdot
.68 .41479 Mdot
.68 .41481 Mdot
.68 .41483 Mdot
.68 .41485 Mdot
.68 .41486 Mdot
.68 .41489 Mdot
.68 .41489 Mdot
.68 .4149 Mdot
.68 .4149 Mdot
.68 .41492 Mdot
.68 .41493 Mdot
.68 .41497 Mdot
.68 .41499 Mdot
.68 .415 Mdot
.68 .41507 Mdot
.68 .41507 Mdot
.68 .41508 Mdot
.68 .41509 Mdot
.68 .4151 Mdot
.682 .32313 Mdot
.682 .32313 Mdot
.682 .32314 Mdot
.682 .32315 Mdot
.682 .32316 Mdot
.682 .32317 Mdot
.682 .32317 Mdot
.682 .32319 Mdot
.682 .32322 Mdot
.682 .32333 Mdot
.682 .3234 Mdot
.682 .32345 Mdot
.682 .32345 Mdot
.682 .32352 Mdot
.682 .32354 Mdot
.682 .32355 Mdot
.682 .32357 Mdot
.682 .32368 Mdot
.682 .32388 Mdot
.682 .32395 Mdot
.682 .324 Mdot
.682 .32402 Mdot
.682 .32408 Mdot
.682 .32411 Mdot
.682 .32416 Mdot
.682 .32418 Mdot
.682 .32428 Mdot
.682 .32432 Mdot
.682 .32435 Mdot
.682 .32436 Mdot
.682 .32444 Mdot
.682 .32474 Mdot
.682 .32483 Mdot
.682 .32483 Mdot
.682 .325 Mdot
.682 .3251 Mdot
.682 .32514 Mdot
.682 .32523 Mdot
.682 .32526 Mdot
.682 .32538 Mdot
.682 .32541 Mdot
.682 .32544 Mdot
.682 .3255 Mdot
.682 .32572 Mdot
.682 .32585 Mdot
.682 .32593 Mdot
.682 .32609 Mdot
.682 .32636 Mdot
.682 .32647 Mdot
.682 .32652 Mdot
.682 .32676 Mdot
.682 .32687 Mdot
.682 .32687 Mdot
.682 .32696 Mdot
.682 .3271 Mdot
.682 .32722 Mdot
.682 .32724 Mdot
.682 .32726 Mdot
.682 .3275 Mdot
.682 .32761 Mdot
.682 .32768 Mdot
.682 .32784 Mdot
.682 .32795 Mdot
.682 .32799 Mdot
.682 .32801 Mdot
.682 .32831 Mdot
.682 .32855 Mdot
.682 .32856 Mdot
.682 .32858 Mdot
.682 .32886 Mdot
.682 .32888 Mdot
.682 .32897 Mdot
.682 .32897 Mdot
.682 .32899 Mdot
.682 .32909 Mdot
.682 .32913 Mdot
.682 .32917 Mdot
.682 .32919 Mdot
.682 .32976 Mdot
.682 .33002 Mdot
.682 .33024 Mdot
.682 .33034 Mdot
.682 .33092 Mdot
.682 .33161 Mdot
.682 .33172 Mdot
.682 .33193 Mdot
.682 .33227 Mdot
.682 .33239 Mdot
.682 .33242 Mdot
.682 .33294 Mdot
.682 .33309 Mdot
.682 .33321 Mdot
.682 .33332 Mdot
.682 .33413 Mdot
.682 .33433 Mdot
.682 .3345 Mdot
.682 .33467 Mdot
.682 .33485 Mdot
.682 .33488 Mdot
.682 .33489 Mdot
.682 .33505 Mdot
.682 .33507 Mdot
.682 .33538 Mdot
.682 .33552 Mdot
.682 .3357 Mdot
.682 .33616 Mdot
.682 .33637 Mdot
.682 .33694 Mdot
.682 .33704 Mdot
.682 .3373 Mdot
.682 .33754 Mdot
.682 .33792 Mdot
.682 .33806 Mdot
.682 .33836 Mdot
.682 .33965 Mdot
.682 .33978 Mdot
.682 .33985 Mdot
.682 .33991 Mdot
.682 .34005 Mdot
.682 .34008 Mdot
.682 .34078 Mdot
.682 .34098 Mdot
.682 .34108 Mdot
.682 .3415 Mdot
.682 .34177 Mdot
.682 .34187 Mdot
.682 .34203 Mdot
.682 .34214 Mdot
.682 .34226 Mdot
.682 .34265 Mdot
.682 .34328 Mdot
.682 .34367 Mdot
.682 .34428 Mdot
.682 .3444 Mdot
.682 .34463 Mdot
.682 .34488 Mdot
.682 .34566 Mdot
.682 .34589 Mdot
.682 .3461 Mdot
.682 .3468 Mdot
.682 .34746 Mdot
.682 .3475 Mdot
.682 .34751 Mdot
.682 .34771 Mdot
.682 .3479 Mdot
.682 .34791 Mdot
.682 .34796 Mdot
.682 .34815 Mdot
.682 .34823 Mdot
.682 .34834 Mdot
.682 .3486 Mdot
.682 .34868 Mdot
.682 .34873 Mdot
.682 .34902 Mdot
.682 .34925 Mdot
.682 .34931 Mdot
.682 .34936 Mdot
.682 .34952 Mdot
.682 .34954 Mdot
.682 .34976 Mdot
.682 .35012 Mdot
.682 .3507 Mdot
.682 .3509 Mdot
.682 .3516 Mdot
.682 .35167 Mdot
.682 .3517 Mdot
.682 .35194 Mdot
.682 .35298 Mdot
.682 .3536 Mdot
.682 .35396 Mdot
.682 .35416 Mdot
.682 .35422 Mdot
.682 .35582 Mdot
.682 .3562 Mdot
.682 .3563 Mdot
.682 .35647 Mdot
.682 .35685 Mdot
.682 .35732 Mdot
.682 .35781 Mdot
.682 .35786 Mdot
.682 .35808 Mdot
.682 .35835 Mdot
.682 .35889 Mdot
.682 .35928 Mdot
.682 .35978 Mdot
.682 .35985 Mdot
.682 .35986 Mdot
.682 .3611 Mdot
.682 .36128 Mdot
.682 .36169 Mdot
.682 .36213 Mdot
.682 .36239 Mdot
.682 .3627 Mdot
.682 .36286 Mdot
.682 .36292 Mdot
.682 .36314 Mdot
.682 .36344 Mdot
.682 .36381 Mdot
.682 .36456 Mdot
.682 .36469 Mdot
.682 .36472 Mdot
.682 .36498 Mdot
.682 .36602 Mdot
.682 .36616 Mdot
.682 .36634 Mdot
.682 .36658 Mdot
.682 .36695 Mdot
.682 .36715 Mdot
.682 .36729 Mdot
.682 .3678 Mdot
.682 .36785 Mdot
.682 .36791 Mdot
.682 .36905 Mdot
.682 .36909 Mdot
.682 .3692 Mdot
.682 .36932 Mdot
.682 .36961 Mdot
.682 .36964 Mdot
.682 .3697 Mdot
.682 .36971 Mdot
.682 .36976 Mdot
.682 .36977 Mdot
.682 .36993 Mdot
.682 .37006 Mdot
.682 .37023 Mdot
.682 .37024 Mdot
.682 .37026 Mdot
.682 .37032 Mdot
.682 .37045 Mdot
.682 .37084 Mdot
.682 .37089 Mdot
.682 .37096 Mdot
.682 .37112 Mdot
.682 .37115 Mdot
.682 .37152 Mdot
.682 .37214 Mdot
.682 .37225 Mdot
.682 .37277 Mdot
.682 .37285 Mdot
.682 .37314 Mdot
.682 .37343 Mdot
.682 .37393 Mdot
.682 .37399 Mdot
.682 .37411 Mdot
.682 .37423 Mdot
.682 .37439 Mdot
.682 .37494 Mdot
.682 .37507 Mdot
.682 .37514 Mdot
.682 .37535 Mdot
.682 .37543 Mdot
.682 .37581 Mdot
.682 .37587 Mdot
.682 .37594 Mdot
.682 .37609 Mdot
.682 .37666 Mdot
.682 .37683 Mdot
.682 .37688 Mdot
.682 .37706 Mdot
.682 .37742 Mdot
.682 .37748 Mdot
.682 .37751 Mdot
.682 .37758 Mdot
.682 .37767 Mdot
.682 .37769 Mdot
.682 .37779 Mdot
.682 .37783 Mdot
.682 .37786 Mdot
.682 .37822 Mdot
.682 .3783 Mdot
.682 .3783 Mdot
.682 .37852 Mdot
.682 .37862 Mdot
.682 .37864 Mdot
.682 .37873 Mdot
.682 .37875 Mdot
.682 .37877 Mdot
.682 .37881 Mdot
.682 .37897 Mdot
.682 .37905 Mdot
.682 .37921 Mdot
.682 .37937 Mdot
.682 .37966 Mdot
.682 .37979 Mdot
.682 .37986 Mdot
.682 .37987 Mdot
.682 .37988 Mdot
.682 .38 Mdot
.682 .38009 Mdot
.682 .38052 Mdot
.682 .38053 Mdot
.682 .3807 Mdot
.682 .38076 Mdot
.682 .3808 Mdot
.682 .3815 Mdot
.682 .38176 Mdot
.682 .3818 Mdot
.682 .38187 Mdot
.682 .38199 Mdot
.682 .38203 Mdot
.682 .38204 Mdot
.682 .38235 Mdot
.682 .38261 Mdot
.682 .38268 Mdot
.682 .38278 Mdot
.682 .38285 Mdot
.682 .38285 Mdot
.682 .3829 Mdot
.682 .38291 Mdot
.682 .38304 Mdot
.682 .3831 Mdot
.682 .38323 Mdot
.682 .38346 Mdot
.682 .38356 Mdot
.682 .38377 Mdot
.682 .38385 Mdot
.682 .38419 Mdot
.682 .38423 Mdot
.682 .38424 Mdot
.682 .38426 Mdot
.682 .3843 Mdot
.682 .3843 Mdot
.682 .38448 Mdot
.682 .38456 Mdot
.682 .38466 Mdot
.682 .38479 Mdot
.682 .38482 Mdot
.682 .38494 Mdot
.682 .38509 Mdot
.682 .38518 Mdot
.682 .38532 Mdot
.682 .38535 Mdot
.682 .38546 Mdot
.682 .38563 Mdot
.682 .38569 Mdot
.682 .38573 Mdot
.682 .38603 Mdot
.682 .38604 Mdot
.682 .38612 Mdot
.682 .38613 Mdot
.682 .38614 Mdot
.682 .38618 Mdot
.682 .38622 Mdot
.682 .38627 Mdot
.682 .38629 Mdot
.682 .3863 Mdot
.682 .38636 Mdot
.682 .38642 Mdot
.682 .38643 Mdot
.682 .38647 Mdot
.682 .38647 Mdot
.682 .38652 Mdot
.682 .38671 Mdot
.682 .38675 Mdot
.682 .38691 Mdot
.682 .38691 Mdot
.682 .38696 Mdot
.682 .38736 Mdot
.682 .3874 Mdot
.682 .38741 Mdot
.682 .38772 Mdot
.682 .38779 Mdot
.682 .38781 Mdot
.682 .38784 Mdot
.682 .38791 Mdot
.682 .388 Mdot
.682 .38819 Mdot
.682 .38829 Mdot
.682 .38836 Mdot
.682 .38847 Mdot
.682 .38847 Mdot
.682 .38873 Mdot
.682 .3888 Mdot
.682 .38888 Mdot
.682 .38892 Mdot
.682 .38898 Mdot
.682 .38901 Mdot
.682 .38906 Mdot
.682 .38911 Mdot
.682 .38933 Mdot
.682 .38938 Mdot
.682 .38956 Mdot
.682 .38959 Mdot
.682 .38966 Mdot
.682 .38972 Mdot
.682 .38976 Mdot
.682 .38978 Mdot
.682 .38987 Mdot
.682 .38989 Mdot
.682 .39008 Mdot
.682 .39011 Mdot
.682 .39013 Mdot
.682 .39018 Mdot
.682 .3902 Mdot
.682 .3902 Mdot
.682 .3902 Mdot
.682 .39021 Mdot
.682 .39026 Mdot
.682 .39028 Mdot
.682 .39029 Mdot
.682 .39029 Mdot
.682 .3903 Mdot
.682 .39032 Mdot
.682 .39039 Mdot
.682 .3904 Mdot
.682 .39041 Mdot
.682 .39044 Mdot
.682 .3905 Mdot
.682 .39061 Mdot
.682 .39063 Mdot
.682 .39072 Mdot
.682 .39073 Mdot
.682 .39078 Mdot
.682 .39083 Mdot
.682 .39091 Mdot
.682 .39092 Mdot
.682 .39094 Mdot
.682 .39099 Mdot
.682 .39108 Mdot
.682 .3911 Mdot
.682 .39111 Mdot
.682 .39115 Mdot
.682 .39116 Mdot
.682 .39123 Mdot
.682 .39124 Mdot
.682 .3914 Mdot
.682 .39141 Mdot
.682 .39144 Mdot
.682 .39151 Mdot
.682 .39152 Mdot
.682 .39157 Mdot
.682 .39168 Mdot
.682 .3917 Mdot
.682 .39171 Mdot
.682 .39172 Mdot
.682 .39175 Mdot
.682 .39177 Mdot
.682 .39179 Mdot
.682 .3919 Mdot
.682 .39194 Mdot
.682 .39201 Mdot
.682 .39202 Mdot
.682 .39205 Mdot
.682 .39206 Mdot
.682 .39218 Mdot
.682 .39222 Mdot
.682 .39239 Mdot
.682 .39241 Mdot
.682 .39242 Mdot
.682 .39244 Mdot
.682 .39247 Mdot
.682 .39253 Mdot
.682 .39256 Mdot
.682 .39257 Mdot
.682 .39264 Mdot
.682 .39265 Mdot
.682 .39273 Mdot
.682 .39274 Mdot
.682 .39285 Mdot
.682 .39289 Mdot
.682 .39289 Mdot
.682 .39294 Mdot
.682 .39295 Mdot
.682 .39296 Mdot
.682 .39296 Mdot
.682 .39298 Mdot
.682 .39299 Mdot
.682 .39299 Mdot
.682 .393 Mdot
.682 .39302 Mdot
.682 .39302 Mdot
.682 .39307 Mdot
.682 .39309 Mdot
.682 .3931 Mdot
.682 .39336 Mdot
.682 .39358 Mdot
.682 .39359 Mdot
.682 .39364 Mdot
.682 .39365 Mdot
.682 .39365 Mdot
.682 .39366 Mdot
.682 .39366 Mdot
.682 .39367 Mdot
.682 .39368 Mdot
.682 .39368 Mdot
.682 .39369 Mdot
.682 .3937 Mdot
.682 .39371 Mdot
.682 .39372 Mdot
.682 .39374 Mdot
.682 .39376 Mdot
.682 .39376 Mdot
.682 .39377 Mdot
.682 .39383 Mdot
.682 .39384 Mdot
.682 .39389 Mdot
.682 .39393 Mdot
.682 .39398 Mdot
.682 .39399 Mdot
.682 .39401 Mdot
.682 .39405 Mdot
.682 .3941 Mdot
.682 .39414 Mdot
.682 .39415 Mdot
.682 .39417 Mdot
.682 .39418 Mdot
.682 .39427 Mdot
.682 .3943 Mdot
.682 .39432 Mdot
.682 .39434 Mdot
.682 .39437 Mdot
.682 .39437 Mdot
.682 .3944 Mdot
.682 .39441 Mdot
.682 .39443 Mdot
.682 .39444 Mdot
.682 .39446 Mdot
.682 .39452 Mdot
.682 .39453 Mdot
.682 .39454 Mdot
.682 .3946 Mdot
.682 .39464 Mdot
.682 .39467 Mdot
.682 .3947 Mdot
.682 .39477 Mdot
.682 .39477 Mdot
.682 .39486 Mdot
.682 .39497 Mdot
.682 .39498 Mdot
.682 .39499 Mdot
.682 .39501 Mdot
.682 .39501 Mdot
.682 .39502 Mdot
.682 .39502 Mdot
.682 .39502 Mdot
.682 .39503 Mdot
.682 .39503 Mdot
.682 .39503 Mdot
.682 .39504 Mdot
.682 .39504 Mdot
.682 .39506 Mdot
.682 .39506 Mdot
.682 .39508 Mdot
.682 .39512 Mdot
.682 .39513 Mdot
.682 .39516 Mdot
.682 .39516 Mdot
.682 .39519 Mdot
.682 .3952 Mdot
.682 .39521 Mdot
.682 .39523 Mdot
.682 .39525 Mdot
.682 .39526 Mdot
.682 .39526 Mdot
.682 .39527 Mdot
.682 .39534 Mdot
.682 .39535 Mdot
.682 .3954 Mdot
.682 .39541 Mdot
.682 .39542 Mdot
.682 .39542 Mdot
.682 .39545 Mdot
.682 .39547 Mdot
.682 .39551 Mdot
.682 .39552 Mdot
.682 .39553 Mdot
.682 .39554 Mdot
.682 .39554 Mdot
.682 .39555 Mdot
.682 .39556 Mdot
.682 .3956 Mdot
.682 .39562 Mdot
.682 .39563 Mdot
.682 .39566 Mdot
.682 .39567 Mdot
.682 .39567 Mdot
.682 .39574 Mdot
.682 .39574 Mdot
.682 .39577 Mdot
.682 .39577 Mdot
.682 .39578 Mdot
.682 .39579 Mdot
.682 .3958 Mdot
.682 .39584 Mdot
.682 .39585 Mdot
.682 .39586 Mdot
.682 .39587 Mdot
.682 .3959 Mdot
.682 .39592 Mdot
.682 .39594 Mdot
.682 .39594 Mdot
.682 .39598 Mdot
.682 .39599 Mdot
.682 .39603 Mdot
.682 .39605 Mdot
.682 .39606 Mdot
.682 .39607 Mdot
.682 .39607 Mdot
.682 .3961 Mdot
.682 .39611 Mdot
.682 .39611 Mdot
.682 .39611 Mdot
.682 .39611 Mdot
.682 .39613 Mdot
.682 .39614 Mdot
.682 .39615 Mdot
.682 .39615 Mdot
.682 .39615 Mdot
.682 .39615 Mdot
.682 .39617 Mdot
.682 .39618 Mdot
.682 .39619 Mdot
.682 .39627 Mdot
.682 .39628 Mdot
.682 .39631 Mdot
.682 .39632 Mdot
.682 .39633 Mdot
.682 .39636 Mdot
.682 .39639 Mdot
.682 .3964 Mdot
.682 .39647 Mdot
.682 .39649 Mdot
.682 .39657 Mdot
.682 .39659 Mdot
.682 .39661 Mdot
.682 .39662 Mdot
.682 .39664 Mdot
.682 .39666 Mdot
.682 .39669 Mdot
.682 .39672 Mdot
.682 .39682 Mdot
.682 .39682 Mdot
.682 .39686 Mdot
.682 .39689 Mdot
.682 .39693 Mdot
.682 .397 Mdot
.682 .39703 Mdot
.682 .39706 Mdot
.682 .39707 Mdot
.682 .39708 Mdot
.682 .39711 Mdot
.682 .39722 Mdot
.682 .39723 Mdot
.682 .39724 Mdot
.682 .39739 Mdot
.682 .39741 Mdot
.682 .39741 Mdot
.682 .39747 Mdot
.682 .39748 Mdot
.682 .39756 Mdot
.682 .39757 Mdot
.682 .39757 Mdot
.682 .39759 Mdot
.682 .39759 Mdot
.682 .39761 Mdot
.682 .39764 Mdot
.682 .39764 Mdot
.682 .39765 Mdot
.682 .39767 Mdot
.682 .39768 Mdot
.682 .3977 Mdot
.682 .3977 Mdot
.682 .3977 Mdot
.682 .39773 Mdot
.682 .39774 Mdot
.682 .39784 Mdot
.682 .39786 Mdot
.682 .39788 Mdot
.682 .39795 Mdot
.682 .39799 Mdot
.682 .398 Mdot
.682 .39805 Mdot
.682 .39808 Mdot
.682 .39813 Mdot
.682 .39818 Mdot
.682 .39819 Mdot
.682 .39824 Mdot
.682 .39827 Mdot
.682 .3983 Mdot
.682 .39836 Mdot
.682 .39837 Mdot
.682 .39838 Mdot
.682 .39839 Mdot
.682 .39839 Mdot
.682 .3984 Mdot
.682 .39853 Mdot
.682 .39856 Mdot
.682 .39863 Mdot
.682 .39867 Mdot
.682 .39875 Mdot
.682 .3988 Mdot
.682 .39881 Mdot
.682 .39886 Mdot
.682 .39887 Mdot
.682 .39888 Mdot
.682 .39888 Mdot
.682 .39891 Mdot
.682 .39894 Mdot
.682 .39897 Mdot
.682 .39906 Mdot
.682 .39917 Mdot
.682 .39917 Mdot
.682 .39918 Mdot
.682 .39923 Mdot
.682 .39925 Mdot
.682 .39927 Mdot
.682 .39936 Mdot
.682 .3996 Mdot
.682 .39961 Mdot
.682 .39963 Mdot
.682 .39969 Mdot
.682 .3997 Mdot
.682 .39984 Mdot
.682 .39987 Mdot
.682 .39991 Mdot
.682 .39992 Mdot
.682 .39992 Mdot
.682 .39994 Mdot
.682 .39999 Mdot
.682 .40009 Mdot
.682 .40014 Mdot
.682 .4002 Mdot
.682 .40022 Mdot
.682 .40028 Mdot
.682 .40029 Mdot
.682 .4003 Mdot
.682 .4003 Mdot
.682 .40033 Mdot
.682 .40034 Mdot
.682 .40037 Mdot
.682 .40045 Mdot
.682 .40045 Mdot
.682 .40047 Mdot
.682 .40059 Mdot
.682 .4006 Mdot
.682 .40062 Mdot
.682 .40065 Mdot
.682 .40066 Mdot
.682 .40069 Mdot
.682 .40071 Mdot
.682 .40072 Mdot
.682 .40074 Mdot
.682 .40086 Mdot
.682 .40092 Mdot
.682 .40093 Mdot
.682 .40099 Mdot
.682 .40118 Mdot
.682 .40123 Mdot
.682 .40125 Mdot
.682 .40127 Mdot
.682 .4014 Mdot
.682 .40142 Mdot
.682 .40149 Mdot
.682 .40151 Mdot
.682 .40156 Mdot
.682 .40173 Mdot
.682 .40182 Mdot
.682 .40186 Mdot
.682 .40188 Mdot
.682 .40204 Mdot
.682 .40213 Mdot
.682 .40222 Mdot
.682 .40225 Mdot
.682 .40242 Mdot
.682 .40245 Mdot
.682 .40265 Mdot
.682 .40276 Mdot
.682 .40277 Mdot
.682 .40282 Mdot
.682 .40284 Mdot
.682 .40286 Mdot
.682 .40298 Mdot
.682 .40302 Mdot
.682 .40304 Mdot
.682 .40305 Mdot
.682 .40305 Mdot
.682 .4031 Mdot
.682 .40314 Mdot
.682 .40319 Mdot
.682 .4032 Mdot
.682 .40321 Mdot
.682 .40321 Mdot
.682 .40324 Mdot
.682 .40324 Mdot
.682 .40333 Mdot
.682 .40337 Mdot
.682 .4034 Mdot
.682 .40342 Mdot
.682 .40377 Mdot
.682 .40379 Mdot
.682 .4038 Mdot
.682 .40396 Mdot
.682 .404 Mdot
.682 .40406 Mdot
.682 .40417 Mdot
.682 .40425 Mdot
.682 .4043 Mdot
.682 .40434 Mdot
.682 .40465 Mdot
.682 .40473 Mdot
.682 .40474 Mdot
.682 .40478 Mdot
.682 .405 Mdot
.682 .40512 Mdot
.682 .4052 Mdot
.682 .40527 Mdot
.682 .40529 Mdot
.682 .40533 Mdot
.682 .40543 Mdot
.682 .4055 Mdot
.682 .40563 Mdot
.682 .40575 Mdot
.682 .40581 Mdot
.682 .40617 Mdot
.682 .40617 Mdot
.682 .40619 Mdot
.682 .40634 Mdot
.682 .40645 Mdot
.682 .40661 Mdot
.682 .40668 Mdot
.682 .40675 Mdot
.682 .40676 Mdot
.682 .4069 Mdot
.682 .40704 Mdot
.682 .40715 Mdot
.682 .40719 Mdot
.682 .40722 Mdot
.682 .40733 Mdot
.682 .40779 Mdot
.682 .4078 Mdot
.682 .40786 Mdot
.682 .40796 Mdot
.682 .40814 Mdot
.682 .40843 Mdot
.682 .4085 Mdot
.682 .40851 Mdot
.682 .40853 Mdot
.682 .40872 Mdot
.682 .40878 Mdot
.682 .40894 Mdot
.682 .40904 Mdot
.682 .4091 Mdot
.682 .40911 Mdot
.682 .40915 Mdot
.682 .40917 Mdot
.682 .40918 Mdot
.682 .40925 Mdot
.682 .40933 Mdot
.682 .40934 Mdot
.682 .40936 Mdot
.682 .40944 Mdot
.682 .40947 Mdot
.682 .40949 Mdot
.682 .40954 Mdot
.682 .40956 Mdot
.682 .40956 Mdot
.682 .40961 Mdot
.682 .40967 Mdot
.682 .40967 Mdot
.682 .40968 Mdot
.682 .40986 Mdot
.682 .41006 Mdot
.682 .41011 Mdot
.682 .41013 Mdot
.682 .41018 Mdot
.682 .41039 Mdot
.682 .41046 Mdot
.682 .41053 Mdot
.682 .41056 Mdot
.682 .41073 Mdot
.682 .41083 Mdot
.682 .411 Mdot
.682 .41111 Mdot
.682 .41114 Mdot
.682 .41117 Mdot
.682 .41122 Mdot
.682 .41124 Mdot
.682 .41132 Mdot
.682 .41143 Mdot
.682 .41146 Mdot
.682 .41152 Mdot
.682 .4117 Mdot
.682 .41171 Mdot
.682 .41175 Mdot
.682 .41177 Mdot
.682 .41179 Mdot
.682 .41182 Mdot
.682 .41217 Mdot
.682 .41225 Mdot
.682 .41229 Mdot
.682 .41239 Mdot
.682 .41246 Mdot
.682 .41253 Mdot
.682 .41256 Mdot
.682 .41271 Mdot
.682 .41277 Mdot
.682 .41289 Mdot
.682 .41294 Mdot
.682 .41298 Mdot
.682 .41306 Mdot
.682 .41307 Mdot
.682 .41311 Mdot
.682 .41311 Mdot
.682 .41312 Mdot
.682 .41317 Mdot
.682 .41322 Mdot
.682 .41326 Mdot
.682 .41332 Mdot
.682 .41353 Mdot
.682 .41356 Mdot
.682 .4136 Mdot
.682 .41364 Mdot
.682 .41378 Mdot
.682 .41379 Mdot
.682 .41382 Mdot
.682 .41391 Mdot
.682 .41397 Mdot
.682 .414 Mdot
.682 .41418 Mdot
.682 .41434 Mdot
.682 .41436 Mdot
.682 .41442 Mdot
.682 .41449 Mdot
.682 .41465 Mdot
.682 .41465 Mdot
.682 .41466 Mdot
.682 .41467 Mdot
.682 .4147 Mdot
.682 .41471 Mdot
.682 .41471 Mdot
.682 .41473 Mdot
.682 .41474 Mdot
.682 .41481 Mdot
.682 .41482 Mdot
.682 .41482 Mdot
.682 .41488 Mdot
.682 .41496 Mdot
.682 .41497 Mdot
.682 .41498 Mdot
.682 .41501 Mdot
.682 .41505 Mdot
.682 .41507 Mdot
.682 .4151 Mdot
.682 .41517 Mdot
.682 .41517 Mdot
.682 .41518 Mdot
.682 .41521 Mdot
.682 .41525 Mdot
.682 .41527 Mdot
.682 .41527 Mdot
.682 .4153 Mdot
.682 .41536 Mdot
.682 .41538 Mdot
.682 .41541 Mdot
.682 .41548 Mdot
.682 .41552 Mdot
.682 .41555 Mdot
.682 .41558 Mdot
.682 .41564 Mdot
.682 .41565 Mdot
.682 .41566 Mdot
.682 .41567 Mdot
.682 .4157 Mdot
.682 .41571 Mdot
.682 .41574 Mdot
.682 .41575 Mdot
.682 .41577 Mdot
.682 .41582 Mdot
.682 .41582 Mdot
.682 .41584 Mdot
.682 .41592 Mdot
.682 .41594 Mdot
.682 .41595 Mdot
.682 .41596 Mdot
.682 .41597 Mdot
.682 .41599 Mdot
.682 .416 Mdot
.682 .41601 Mdot
.682 .41602 Mdot
.682 .41604 Mdot
.682 .41604 Mdot
.682 .41606 Mdot
.682 .41607 Mdot
.682 .41613 Mdot
.682 .41616 Mdot
.682 .41616 Mdot
.682 .41617 Mdot
.682 .41617 Mdot
.682 .41619 Mdot
.682 .41619 Mdot
.682 .4162 Mdot
.682 .41622 Mdot
.682 .41625 Mdot
.682 .41626 Mdot
.682 .41626 Mdot
.682 .41626 Mdot
.682 .41627 Mdot
.682 .41627 Mdot
.682 .41627 Mdot
.682 .41628 Mdot
.682 .41628 Mdot
.684 .31965 Mdot
.684 .31966 Mdot
.684 .31966 Mdot
.684 .31966 Mdot
.684 .31966 Mdot
.684 .31968 Mdot
.684 .31968 Mdot
.684 .31969 Mdot
.684 .3197 Mdot
.684 .31971 Mdot
.684 .31972 Mdot
.684 .31977 Mdot
.684 .31992 Mdot
.684 .32007 Mdot
.684 .32007 Mdot
.684 .32021 Mdot
.684 .32029 Mdot
.684 .32032 Mdot
.684 .32041 Mdot
.684 .32047 Mdot
.684 .32051 Mdot
.684 .32064 Mdot
.684 .32068 Mdot
.684 .32073 Mdot
.684 .32086 Mdot
.684 .32091 Mdot
.684 .32098 Mdot
.684 .32108 Mdot
.684 .32117 Mdot
.684 .32132 Mdot
.684 .32142 Mdot
.684 .32159 Mdot
.684 .32178 Mdot
.684 .32196 Mdot
.684 .32206 Mdot
.684 .32214 Mdot
.684 .32222 Mdot
.684 .32245 Mdot
.684 .32258 Mdot
.684 .32259 Mdot
.684 .3226 Mdot
.684 .3229 Mdot
.684 .32297 Mdot
.684 .32313 Mdot
.684 .32316 Mdot
.684 .32347 Mdot
.684 .32367 Mdot
.684 .32371 Mdot
.684 .324 Mdot
.684 .32404 Mdot
.684 .32437 Mdot
.684 .32445 Mdot
.684 .3245 Mdot
.684 .32456 Mdot
.684 .32458 Mdot
.684 .32465 Mdot
.684 .32466 Mdot
.684 .32485 Mdot
.684 .3249 Mdot
.684 .32529 Mdot
.684 .32587 Mdot
.684 .32587 Mdot
.684 .32637 Mdot
.684 .32639 Mdot
.684 .32643 Mdot
.684 .32678 Mdot
.684 .32678 Mdot
.684 .32695 Mdot
.684 .32706 Mdot
.684 .32734 Mdot
.684 .32737 Mdot
.684 .32739 Mdot
.684 .3275 Mdot
.684 .32776 Mdot
.684 .32777 Mdot
.684 .32782 Mdot
.684 .32789 Mdot
.684 .32794 Mdot
.684 .32805 Mdot
.684 .32831 Mdot
.684 .32895 Mdot
.684 .32906 Mdot
.684 .32913 Mdot
.684 .32963 Mdot
.684 .32976 Mdot
.684 .33032 Mdot
.684 .33067 Mdot
.684 .33083 Mdot
.684 .33102 Mdot
.684 .33106 Mdot
.684 .33147 Mdot
.684 .33204 Mdot
.684 .33279 Mdot
.684 .33286 Mdot
.684 .33321 Mdot
.684 .33349 Mdot
.684 .33351 Mdot
.684 .33359 Mdot
.684 .33384 Mdot
.684 .33386 Mdot
.684 .33387 Mdot
.684 .33445 Mdot
.684 .33523 Mdot
.684 .33526 Mdot
.684 .33546 Mdot
.684 .33558 Mdot
.684 .33606 Mdot
.684 .33643 Mdot
.684 .33664 Mdot
.684 .33666 Mdot
.684 .33678 Mdot
.684 .337 Mdot
.684 .33709 Mdot
.684 .33716 Mdot
.684 .33723 Mdot
.684 .33738 Mdot
.684 .3374 Mdot
.684 .33745 Mdot
.684 .33763 Mdot
.684 .33804 Mdot
.684 .33828 Mdot
.684 .33861 Mdot
.684 .33866 Mdot
.684 .33873 Mdot
.684 .33874 Mdot
.684 .33899 Mdot
.684 .33911 Mdot
.684 .34067 Mdot
.684 .3409 Mdot
.684 .34182 Mdot
.684 .34189 Mdot
.684 .34241 Mdot
.684 .34262 Mdot
.684 .34407 Mdot
.684 .34412 Mdot
.684 .34452 Mdot
.684 .34462 Mdot
.684 .34525 Mdot
.684 .34575 Mdot
.684 .34611 Mdot
.684 .34645 Mdot
.684 .34679 Mdot
.684 .34745 Mdot
.684 .34748 Mdot
.684 .34775 Mdot
.684 .34833 Mdot
.684 .34888 Mdot
.684 .34999 Mdot
.684 .35001 Mdot
.684 .35009 Mdot
.684 .35032 Mdot
.684 .35078 Mdot
.684 .35102 Mdot
.684 .35128 Mdot
.684 .35138 Mdot
.684 .35143 Mdot
.684 .35176 Mdot
.684 .35275 Mdot
.684 .35284 Mdot
.684 .35371 Mdot
.684 .35419 Mdot
.684 .35443 Mdot
.684 .35448 Mdot
.684 .35459 Mdot
.684 .35488 Mdot
.684 .35489 Mdot
.684 .35526 Mdot
.684 .35557 Mdot
.684 .35573 Mdot
.684 .35601 Mdot
.684 .35623 Mdot
.684 .3565 Mdot
.684 .35687 Mdot
.684 .35734 Mdot
.684 .35778 Mdot
.684 .35841 Mdot
.684 .35841 Mdot
.684 .35854 Mdot
.684 .35861 Mdot
.684 .35876 Mdot
.684 .35913 Mdot
.684 .35926 Mdot
.684 .35937 Mdot
.684 .35951 Mdot
.684 .35959 Mdot
.684 .35983 Mdot
.684 .35983 Mdot
.684 .36017 Mdot
.684 .36073 Mdot
.684 .36082 Mdot
.684 .36101 Mdot
.684 .36123 Mdot
.684 .36124 Mdot
.684 .36172 Mdot
.684 .36189 Mdot
.684 .36198 Mdot
.684 .36348 Mdot
.684 .36402 Mdot
.684 .36505 Mdot
.684 .36526 Mdot
.684 .36531 Mdot
.684 .36567 Mdot
.684 .36627 Mdot
.684 .36639 Mdot
.684 .36714 Mdot
.684 .3673 Mdot
.684 .36781 Mdot
.684 .36786 Mdot
.684 .36865 Mdot
.684 .36877 Mdot
.684 .3691 Mdot
.684 .36928 Mdot
.684 .36929 Mdot
.684 .36954 Mdot
.684 .36983 Mdot
.684 .37017 Mdot
.684 .37022 Mdot
.684 .37028 Mdot
.684 .37105 Mdot
.684 .37142 Mdot
.684 .37144 Mdot
.684 .37144 Mdot
.684 .37153 Mdot
.684 .37176 Mdot
.684 .37234 Mdot
.684 .37266 Mdot
.684 .37283 Mdot
.684 .37288 Mdot
.684 .37302 Mdot
.684 .37329 Mdot
.684 .37353 Mdot
.684 .37393 Mdot
.684 .37394 Mdot
.684 .37423 Mdot
.684 .37484 Mdot
.684 .37489 Mdot
.684 .37495 Mdot
.684 .37526 Mdot
.684 .3754 Mdot
.684 .37556 Mdot
.684 .37558 Mdot
.684 .37559 Mdot
.684 .37579 Mdot
.684 .37581 Mdot
.684 .37599 Mdot
.684 .37617 Mdot
.684 .37708 Mdot
.684 .37719 Mdot
.684 .37735 Mdot
.684 .37742 Mdot
.684 .37761 Mdot
.684 .37767 Mdot
.684 .37797 Mdot
.684 .37814 Mdot
.684 .37827 Mdot
.684 .37849 Mdot
.684 .37863 Mdot
.684 .37876 Mdot
.684 .37883 Mdot
.684 .37895 Mdot
.684 .37938 Mdot
.684 .37942 Mdot
.684 .37951 Mdot
.684 .3797 Mdot
.684 .37981 Mdot
.684 .37983 Mdot
.684 .37999 Mdot
.684 .38 Mdot
.684 .38017 Mdot
.684 .38024 Mdot
.684 .38027 Mdot
.684 .38031 Mdot
.684 .3804 Mdot
.684 .38043 Mdot
.684 .38086 Mdot
.684 .38109 Mdot
.684 .38123 Mdot
.684 .3813 Mdot
.684 .38134 Mdot
.684 .38145 Mdot
.684 .38146 Mdot
.684 .38147 Mdot
.684 .38161 Mdot
.684 .38163 Mdot
.684 .38165 Mdot
.684 .38167 Mdot
.684 .38171 Mdot
.684 .38181 Mdot
.684 .38203 Mdot
.684 .38207 Mdot
.684 .3821 Mdot
.684 .38249 Mdot
.684 .3826 Mdot
.684 .38265 Mdot
.684 .38271 Mdot
.684 .38302 Mdot
.684 .38324 Mdot
.684 .38326 Mdot
.684 .38336 Mdot
.684 .38344 Mdot
.684 .38347 Mdot
.684 .38354 Mdot
.684 .38355 Mdot
.684 .38371 Mdot
.684 .38392 Mdot
.684 .38392 Mdot
.684 .38398 Mdot
.684 .38413 Mdot
.684 .38423 Mdot
.684 .38429 Mdot
.684 .38437 Mdot
.684 .3844 Mdot
.684 .38441 Mdot
.684 .38443 Mdot
.684 .38447 Mdot
.684 .38447 Mdot
.684 .38453 Mdot
.684 .38463 Mdot
.684 .38469 Mdot
.684 .38477 Mdot
.684 .38478 Mdot
.684 .3848 Mdot
.684 .3848 Mdot
.684 .38486 Mdot
.684 .38489 Mdot
.684 .3853 Mdot
.684 .38551 Mdot
.684 .38553 Mdot
.684 .38569 Mdot
.684 .386 Mdot
.684 .38601 Mdot
.684 .38609 Mdot
.684 .38611 Mdot
.684 .38625 Mdot
.684 .38635 Mdot
.684 .38642 Mdot
.684 .38649 Mdot
.684 .38656 Mdot
.684 .3867 Mdot
.684 .38698 Mdot
.684 .38721 Mdot
.684 .38726 Mdot
.684 .38739 Mdot
.684 .38744 Mdot
.684 .38746 Mdot
.684 .38772 Mdot
.684 .38773 Mdot
.684 .38798 Mdot
.684 .38803 Mdot
.684 .38804 Mdot
.684 .38806 Mdot
.684 .38818 Mdot
.684 .38823 Mdot
.684 .38835 Mdot
.684 .38863 Mdot
.684 .38874 Mdot
.684 .38874 Mdot
.684 .38876 Mdot
.684 .3888 Mdot
.684 .38889 Mdot
.684 .38893 Mdot
.684 .38894 Mdot
.684 .38904 Mdot
.684 .38914 Mdot
.684 .38916 Mdot
.684 .38919 Mdot
.684 .38923 Mdot
.684 .38923 Mdot
.684 .38931 Mdot
.684 .38934 Mdot
.684 .3897 Mdot
.684 .38991 Mdot
.684 .38991 Mdot
.684 .38997 Mdot
.684 .39009 Mdot
.684 .39024 Mdot
.684 .39033 Mdot
.684 .39046 Mdot
.684 .39054 Mdot
.684 .39057 Mdot
.684 .39061 Mdot
.684 .39066 Mdot
.684 .39071 Mdot
.684 .39072 Mdot
.684 .39086 Mdot
.684 .39092 Mdot
.684 .39093 Mdot
.684 .39097 Mdot
.684 .39115 Mdot
.684 .39118 Mdot
.684 .39122 Mdot
.684 .39132 Mdot
.684 .39132 Mdot
.684 .39137 Mdot
.684 .39147 Mdot
.684 .39159 Mdot
.684 .39159 Mdot
.684 .39162 Mdot
.684 .39162 Mdot
.684 .39168 Mdot
.684 .39183 Mdot
.684 .39185 Mdot
.684 .39187 Mdot
.684 .39197 Mdot
.684 .392 Mdot
.684 .39202 Mdot
.684 .39208 Mdot
.684 .3921 Mdot
.684 .39211 Mdot
.684 .3922 Mdot
.684 .39225 Mdot
.684 .39227 Mdot
.684 .3923 Mdot
.684 .39244 Mdot
.684 .39251 Mdot
.684 .39253 Mdot
.684 .39253 Mdot
.684 .39256 Mdot
.684 .39256 Mdot
.684 .39263 Mdot
.684 .3927 Mdot
.684 .39272 Mdot
.684 .39282 Mdot
.684 .39283 Mdot
.684 .39284 Mdot
.684 .39286 Mdot
.684 .39293 Mdot
.684 .39293 Mdot
.684 .39293 Mdot
.684 .39294 Mdot
.684 .39297 Mdot
.684 .39299 Mdot
.684 .39301 Mdot
.684 .39301 Mdot
.684 .39302 Mdot
.684 .39302 Mdot
.684 .39307 Mdot
.684 .39307 Mdot
.684 .39307 Mdot
.684 .39308 Mdot
.684 .39308 Mdot
.684 .39309 Mdot
.684 .39316 Mdot
.684 .39319 Mdot
.684 .39329 Mdot
.684 .39329 Mdot
.684 .39331 Mdot
.684 .39333 Mdot
.684 .39334 Mdot
.684 .39335 Mdot
.684 .39343 Mdot
.684 .39351 Mdot
.684 .39355 Mdot
.684 .39361 Mdot
.684 .39363 Mdot
.684 .3937 Mdot
.684 .39373 Mdot
.684 .39376 Mdot
.684 .39379 Mdot
.684 .39382 Mdot
.684 .39388 Mdot
.684 .39392 Mdot
.684 .39395 Mdot
.684 .39399 Mdot
.684 .39403 Mdot
.684 .39406 Mdot
.684 .39409 Mdot
.684 .39409 Mdot
.684 .39414 Mdot
.684 .39416 Mdot
.684 .39418 Mdot
.684 .3942 Mdot
.684 .39421 Mdot
.684 .39425 Mdot
.684 .39425 Mdot
.684 .39427 Mdot
.684 .39427 Mdot
.684 .39428 Mdot
.684 .39432 Mdot
.684 .39435 Mdot
.684 .39436 Mdot
.684 .39437 Mdot
.684 .39441 Mdot
.684 .39442 Mdot
.684 .39443 Mdot
.684 .39443 Mdot
.684 .39444 Mdot
.684 .39444 Mdot
.684 .39445 Mdot
.684 .39445 Mdot
.684 .39446 Mdot
.684 .39446 Mdot
.684 .39446 Mdot
.684 .39446 Mdot
.684 .39446 Mdot
.684 .39455 Mdot
.684 .39457 Mdot
.684 .39463 Mdot
.684 .39467 Mdot
.684 .39473 Mdot
.684 .39474 Mdot
.684 .39475 Mdot
.684 .39476 Mdot
.684 .39478 Mdot
.684 .3948 Mdot
.684 .39482 Mdot
.684 .39483 Mdot
.684 .39487 Mdot
.684 .39487 Mdot
.684 .39487 Mdot
.684 .39487 Mdot
.684 .39487 Mdot
.684 .39487 Mdot
.684 .39488 Mdot
.684 .39488 Mdot
.684 .39488 Mdot
.684 .39488 Mdot
.684 .39488 Mdot
.684 .39489 Mdot
.684 .39489 Mdot
.684 .39491 Mdot
.684 .39491 Mdot
.684 .39492 Mdot
.684 .39493 Mdot
.684 .39495 Mdot
.684 .39495 Mdot
.684 .39495 Mdot
.684 .39496 Mdot
.684 .39496 Mdot
.684 .39497 Mdot
.684 .39498 Mdot
.684 .39499 Mdot
.684 .395 Mdot
.684 .395 Mdot
.684 .39502 Mdot
.684 .39502 Mdot
.684 .39504 Mdot
.684 .39505 Mdot
.684 .39507 Mdot
.684 .39508 Mdot
.684 .39509 Mdot
.684 .39511 Mdot
.684 .39513 Mdot
.684 .39515 Mdot
.684 .39516 Mdot
.684 .39517 Mdot
.684 .39518 Mdot
.684 .39521 Mdot
.684 .39522 Mdot
.684 .39524 Mdot
.684 .39526 Mdot
.684 .39529 Mdot
.684 .39533 Mdot
.684 .39533 Mdot
.684 .39534 Mdot
.684 .39534 Mdot
.684 .39535 Mdot
.684 .39535 Mdot
.684 .39539 Mdot
.684 .39541 Mdot
.684 .39543 Mdot
.684 .39544 Mdot
.684 .39544 Mdot
.684 .39544 Mdot
.684 .39544 Mdot
.684 .39544 Mdot
.684 .39546 Mdot
.684 .39546 Mdot
.684 .39546 Mdot
.684 .39547 Mdot
.684 .39547 Mdot
.684 .39548 Mdot
.684 .39549 Mdot
.684 .3955 Mdot
.684 .3955 Mdot
.684 .3955 Mdot
.684 .39553 Mdot
.684 .39553 Mdot
.684 .39554 Mdot
.684 .39554 Mdot
.684 .39558 Mdot
.684 .39559 Mdot
.684 .39562 Mdot
.684 .39565 Mdot
.684 .39565 Mdot
.684 .39566 Mdot
.684 .39566 Mdot
.684 .39567 Mdot
.684 .3957 Mdot
.684 .39575 Mdot
.684 .39576 Mdot
.684 .39577 Mdot
.684 .39579 Mdot
.684 .39583 Mdot
.684 .39583 Mdot
.684 .39584 Mdot
.684 .39586 Mdot
.684 .39587 Mdot
.684 .39588 Mdot
.684 .39592 Mdot
.684 .39593 Mdot
.684 .39594 Mdot
.684 .396 Mdot
.684 .39602 Mdot
.684 .39602 Mdot
.684 .39603 Mdot
.684 .39603 Mdot
.684 .39608 Mdot
.684 .39612 Mdot
.684 .39614 Mdot
.684 .39614 Mdot
.684 .39618 Mdot
.684 .3962 Mdot
.684 .39621 Mdot
.684 .39628 Mdot
.684 .39629 Mdot
.684 .3963 Mdot
.684 .39632 Mdot
.684 .39637 Mdot
.684 .39638 Mdot
.684 .3964 Mdot
.684 .39642 Mdot
.684 .39643 Mdot
.684 .39645 Mdot
.684 .39647 Mdot
.684 .39653 Mdot
.684 .39656 Mdot
.684 .39662 Mdot
.684 .39666 Mdot
.684 .39669 Mdot
.684 .39669 Mdot
.684 .39677 Mdot
.684 .39691 Mdot
.684 .39692 Mdot
.684 .39695 Mdot
.684 .39695 Mdot
.684 .39696 Mdot
.684 .39698 Mdot
.684 .39698 Mdot
.684 .39702 Mdot
.684 .39706 Mdot
.684 .39706 Mdot
.684 .39708 Mdot
.684 .39711 Mdot
.684 .39712 Mdot
.684 .39713 Mdot
.684 .39713 Mdot
.684 .39718 Mdot
.684 .39728 Mdot
.684 .39732 Mdot
.684 .39734 Mdot
.684 .39739 Mdot
.684 .3974 Mdot
.684 .3974 Mdot
.684 .39742 Mdot
.684 .39751 Mdot
.684 .39751 Mdot
.684 .39761 Mdot
.684 .39762 Mdot
.684 .39763 Mdot
.684 .39768 Mdot
.684 .3977 Mdot
.684 .39779 Mdot
.684 .39789 Mdot
.684 .39794 Mdot
.684 .39796 Mdot
.684 .39799 Mdot
.684 .39802 Mdot
.684 .39805 Mdot
.684 .3981 Mdot
.684 .39811 Mdot
.684 .39814 Mdot
.684 .39814 Mdot
.684 .39826 Mdot
.684 .39831 Mdot
.684 .39832 Mdot
.684 .39839 Mdot
.684 .39854 Mdot
.684 .39855 Mdot
.684 .39858 Mdot
.684 .39858 Mdot
.684 .39858 Mdot
.684 .39859 Mdot
.684 .39861 Mdot
.684 .39864 Mdot
.684 .39867 Mdot
.684 .39869 Mdot
.684 .39869 Mdot
.684 .39871 Mdot
.684 .39871 Mdot
.684 .39872 Mdot
.684 .39873 Mdot
.684 .39876 Mdot
.684 .39878 Mdot
.684 .39881 Mdot
.684 .39887 Mdot
.684 .39888 Mdot
.684 .39889 Mdot
.684 .39896 Mdot
.684 .39902 Mdot
.684 .39902 Mdot
.684 .39904 Mdot
.684 .39905 Mdot
.684 .39908 Mdot
.684 .39912 Mdot
.684 .39912 Mdot
.684 .3992 Mdot
.684 .39931 Mdot
.684 .39933 Mdot
.684 .39935 Mdot
.684 .39939 Mdot
.684 .39952 Mdot
.684 .39954 Mdot
.684 .39962 Mdot
.684 .39965 Mdot
.684 .39967 Mdot
.684 .39967 Mdot
.684 .39968 Mdot
.684 .39969 Mdot
.684 .39974 Mdot
.684 .39974 Mdot
.684 .39974 Mdot
.684 .39978 Mdot
.684 .3998 Mdot
.684 .39982 Mdot
.684 .39987 Mdot
.684 .39995 Mdot
.684 .40009 Mdot
.684 .4001 Mdot
.684 .40013 Mdot
.684 .40014 Mdot
.684 .40016 Mdot
.684 .40018 Mdot
.684 .40023 Mdot
.684 .40024 Mdot
.684 .40029 Mdot
.684 .4003 Mdot
.684 .40034 Mdot
.684 .4004 Mdot
.684 .40043 Mdot
.684 .40044 Mdot
.684 .40059 Mdot
.684 .40063 Mdot
.684 .40065 Mdot
.684 .40069 Mdot
.684 .40074 Mdot
.684 .40081 Mdot
.684 .40085 Mdot
.684 .40091 Mdot
.684 .40101 Mdot
.684 .40103 Mdot
.684 .40109 Mdot
.684 .40112 Mdot
.684 .40117 Mdot
.684 .4012 Mdot
.684 .4015 Mdot
.684 .40156 Mdot
.684 .40161 Mdot
.684 .40162 Mdot
.684 .40169 Mdot
.684 .40169 Mdot
.684 .4017 Mdot
.684 .40175 Mdot
.684 .40179 Mdot
.684 .40189 Mdot
.684 .40191 Mdot
.684 .40193 Mdot
.684 .40212 Mdot
.684 .40221 Mdot
.684 .40222 Mdot
.684 .40234 Mdot
.684 .40242 Mdot
.684 .4025 Mdot
.684 .40255 Mdot
.684 .40256 Mdot
.684 .40262 Mdot
.684 .40272 Mdot
.684 .4029 Mdot
.684 .40297 Mdot
.684 .403 Mdot
.684 .403 Mdot
.684 .403 Mdot
.684 .40312 Mdot
.684 .40336 Mdot
.684 .40338 Mdot
.684 .40339 Mdot
.684 .4035 Mdot
.684 .40359 Mdot
.684 .40366 Mdot
.684 .40366 Mdot
.684 .40372 Mdot
.684 .40382 Mdot
.684 .40386 Mdot
.684 .4041 Mdot
.684 .40411 Mdot
.684 .40427 Mdot
.684 .40431 Mdot
.684 .40454 Mdot
.684 .40457 Mdot
.684 .40476 Mdot
.684 .40486 Mdot
.684 .40488 Mdot
.684 .40494 Mdot
.684 .40525 Mdot
.684 .4054 Mdot
.684 .40585 Mdot
.684 .40587 Mdot
.684 .40592 Mdot
.684 .40606 Mdot
.684 .40606 Mdot
.684 .40613 Mdot
.684 .40618 Mdot
.684 .40621 Mdot
.684 .40637 Mdot
.684 .40647 Mdot
.684 .40647 Mdot
.684 .40654 Mdot
.684 .40656 Mdot
.684 .4066 Mdot
.684 .40663 Mdot
.684 .40667 Mdot
.684 .40678 Mdot
.684 .40682 Mdot
.684 .40684 Mdot
.684 .40688 Mdot
.684 .40688 Mdot
.684 .40706 Mdot
.684 .40719 Mdot
.684 .40732 Mdot
.684 .40742 Mdot
.684 .4075 Mdot
.684 .40756 Mdot
.684 .40764 Mdot
.684 .40769 Mdot
.684 .40778 Mdot
.684 .40788 Mdot
.684 .40788 Mdot
.684 .40797 Mdot
.684 .40799 Mdot
.684 .40801 Mdot
.684 .40808 Mdot
.684 .40821 Mdot
.684 .40846 Mdot
.684 .40848 Mdot
.684 .40876 Mdot
.684 .40885 Mdot
.684 .40887 Mdot
.684 .40889 Mdot
.684 .40897 Mdot
.684 .40903 Mdot
.684 .40916 Mdot
.684 .40922 Mdot
.684 .40925 Mdot
.684 .40925 Mdot
.684 .40956 Mdot
.684 .40971 Mdot
.684 .40987 Mdot
.684 .40995 Mdot
.684 .40995 Mdot
.684 .41014 Mdot
.684 .41023 Mdot
.684 .41032 Mdot
.684 .41042 Mdot
.684 .41056 Mdot
.684 .41073 Mdot
.684 .41076 Mdot
.684 .41087 Mdot
.684 .41088 Mdot
.684 .41128 Mdot
.684 .41133 Mdot
.684 .41147 Mdot
.684 .41149 Mdot
.684 .41174 Mdot
.684 .4118 Mdot
.684 .41223 Mdot
.684 .41226 Mdot
.684 .41233 Mdot
.684 .41233 Mdot
.684 .41235 Mdot
.684 .41236 Mdot
.684 .41245 Mdot
.684 .41252 Mdot
.684 .41263 Mdot
.684 .41268 Mdot
.684 .41269 Mdot
.684 .41269 Mdot
.684 .41273 Mdot
.684 .41275 Mdot
.684 .41277 Mdot
.684 .4128 Mdot
.684 .41285 Mdot
.684 .41289 Mdot
.684 .41289 Mdot
.684 .41295 Mdot
.684 .41305 Mdot
.684 .41318 Mdot
.684 .41321 Mdot
.684 .41326 Mdot
.684 .41327 Mdot
.684 .41348 Mdot
.684 .41364 Mdot
.684 .41364 Mdot
.684 .41365 Mdot
.684 .41371 Mdot
.684 .41374 Mdot
.684 .41374 Mdot
.684 .41381 Mdot
.684 .41391 Mdot
.684 .41393 Mdot
.684 .41413 Mdot
.684 .41428 Mdot
.684 .41439 Mdot
.684 .4144 Mdot
.684 .41445 Mdot
.684 .4145 Mdot
.684 .41459 Mdot
.684 .41474 Mdot
.684 .41477 Mdot
.684 .41491 Mdot
.684 .41493 Mdot
.684 .41496 Mdot
.684 .41513 Mdot
.684 .4152 Mdot
.684 .41523 Mdot
.684 .41524 Mdot
.684 .41526 Mdot
.684 .41527 Mdot
.684 .41528 Mdot
.684 .41535 Mdot
.684 .41538 Mdot
.684 .41538 Mdot
.684 .41539 Mdot
.684 .41547 Mdot
.684 .41549 Mdot
.684 .41554 Mdot
.684 .41554 Mdot
.684 .41563 Mdot
.684 .41564 Mdot
.684 .41565 Mdot
.684 .41578 Mdot
.684 .41578 Mdot
.684 .41594 Mdot
.684 .41604 Mdot
.684 .41606 Mdot
.684 .41611 Mdot
.684 .41611 Mdot
.684 .41613 Mdot
.684 .41614 Mdot
.684 .41615 Mdot
.684 .41616 Mdot
.684 .41619 Mdot
.684 .41628 Mdot
.684 .41628 Mdot
.684 .41636 Mdot
.684 .41637 Mdot
.684 .41643 Mdot
.684 .41651 Mdot
.684 .41652 Mdot
.684 .41656 Mdot
.684 .41658 Mdot
.684 .41666 Mdot
.684 .41666 Mdot
.684 .41667 Mdot
.684 .4167 Mdot
.684 .41676 Mdot
.684 .41678 Mdot
.684 .41681 Mdot
.684 .41683 Mdot
.684 .41688 Mdot
.684 .41693 Mdot
.684 .41698 Mdot
.684 .417 Mdot
.684 .41704 Mdot
.684 .41707 Mdot
.684 .4171 Mdot
.684 .41711 Mdot
.684 .41713 Mdot
.684 .41716 Mdot
.684 .41718 Mdot
.684 .41719 Mdot
.684 .41722 Mdot
.684 .41723 Mdot
.684 .41725 Mdot
.684 .41727 Mdot
.684 .41728 Mdot
.684 .4173 Mdot
.684 .41734 Mdot
.684 .41734 Mdot
.684 .41738 Mdot
.684 .41742 Mdot
.684 .41744 Mdot
.684 .41744 Mdot
.684 .41744 Mdot
.684 .41744 Mdot
.684 .41744 Mdot
.684 .41745 Mdot
.684 .41745 Mdot
.684 .41745 Mdot
.684 .41745 Mdot
.684 .41745 Mdot
.684 .41745 Mdot
.686 .31617 Mdot
.686 .31617 Mdot
.686 .31618 Mdot
.686 .31623 Mdot
.686 .31625 Mdot
.686 .3163 Mdot
.686 .31631 Mdot
.686 .31632 Mdot
.686 .31632 Mdot
.686 .31634 Mdot
.686 .31642 Mdot
.686 .31646 Mdot
.686 .31655 Mdot
.686 .31663 Mdot
.686 .31665 Mdot
.686 .31668 Mdot
.686 .31674 Mdot
.686 .31675 Mdot
.686 .31678 Mdot
.686 .31684 Mdot
.686 .31688 Mdot
.686 .31692 Mdot
.686 .31697 Mdot
.686 .31703 Mdot
.686 .31706 Mdot
.686 .31709 Mdot
.686 .31714 Mdot
.686 .31714 Mdot
.686 .31715 Mdot
.686 .31733 Mdot
.686 .31737 Mdot
.686 .3175 Mdot
.686 .31753 Mdot
.686 .31762 Mdot
.686 .31782 Mdot
.686 .31783 Mdot
.686 .31786 Mdot
.686 .31787 Mdot
.686 .31789 Mdot
.686 .31814 Mdot
.686 .31825 Mdot
.686 .31841 Mdot
.686 .31849 Mdot
.686 .31915 Mdot
.686 .31931 Mdot
.686 .31955 Mdot
.686 .31957 Mdot
.686 .31961 Mdot
.686 .31962 Mdot
.686 .31964 Mdot
.686 .31969 Mdot
.686 .31979 Mdot
.686 .31999 Mdot
.686 .32013 Mdot
.686 .32041 Mdot
.686 .32047 Mdot
.686 .32052 Mdot
.686 .32054 Mdot
.686 .32063 Mdot
.686 .32063 Mdot
.686 .32077 Mdot
.686 .32112 Mdot
.686 .32128 Mdot
.686 .32138 Mdot
.686 .32142 Mdot
.686 .32151 Mdot
.686 .32192 Mdot
.686 .32194 Mdot
.686 .32197 Mdot
.686 .32223 Mdot
.686 .32227 Mdot
.686 .32241 Mdot
.686 .32257 Mdot
.686 .32262 Mdot
.686 .32268 Mdot
.686 .32273 Mdot
.686 .32278 Mdot
.686 .32294 Mdot
.686 .32303 Mdot
.686 .32305 Mdot
.686 .32308 Mdot
.686 .32309 Mdot
.686 .3232 Mdot
.686 .32333 Mdot
.686 .32336 Mdot
.686 .32337 Mdot
.686 .32339 Mdot
.686 .32346 Mdot
.686 .32349 Mdot
.686 .32371 Mdot
.686 .32392 Mdot
.686 .32394 Mdot
.686 .3242 Mdot
.686 .32445 Mdot
.686 .3248 Mdot
.686 .32481 Mdot
.686 .32489 Mdot
.686 .32493 Mdot
.686 .3251 Mdot
.686 .32524 Mdot
.686 .3253 Mdot
.686 .32535 Mdot
.686 .32536 Mdot
.686 .32544 Mdot
.686 .3256 Mdot
.686 .32572 Mdot
.686 .32597 Mdot
.686 .3261 Mdot
.686 .32629 Mdot
.686 .32636 Mdot
.686 .32645 Mdot
.686 .32674 Mdot
.686 .32688 Mdot
.686 .32696 Mdot
.686 .32707 Mdot
.686 .32717 Mdot
.686 .32736 Mdot
.686 .32741 Mdot
.686 .32775 Mdot
.686 .3279 Mdot
.686 .32792 Mdot
.686 .32796 Mdot
.686 .32799 Mdot
.686 .328 Mdot
.686 .32802 Mdot
.686 .32812 Mdot
.686 .32825 Mdot
.686 .32826 Mdot
.686 .32826 Mdot
.686 .32921 Mdot
.686 .32954 Mdot
.686 .32997 Mdot
.686 .33014 Mdot
.686 .33082 Mdot
.686 .33092 Mdot
.686 .33149 Mdot
.686 .33295 Mdot
.686 .33337 Mdot
.686 .33362 Mdot
.686 .33374 Mdot
.686 .33464 Mdot
.686 .33493 Mdot
.686 .33572 Mdot
.686 .33578 Mdot
.686 .33629 Mdot
.686 .33664 Mdot
.686 .33707 Mdot
.686 .33719 Mdot
.686 .33776 Mdot
.686 .33791 Mdot
.686 .33809 Mdot
.686 .33839 Mdot
.686 .33839 Mdot
.686 .33931 Mdot
.686 .33953 Mdot
.686 .33968 Mdot
.686 .33993 Mdot
.686 .34012 Mdot
.686 .34173 Mdot
.686 .34207 Mdot
.686 .34219 Mdot
.686 .34294 Mdot
.686 .34301 Mdot
.686 .34314 Mdot
.686 .34417 Mdot
.686 .34588 Mdot
.686 .34651 Mdot
.686 .34661 Mdot
.686 .34694 Mdot
.686 .34714 Mdot
.686 .34761 Mdot
.686 .34826 Mdot
.686 .34849 Mdot
.686 .34877 Mdot
.686 .3491 Mdot
.686 .34935 Mdot
.686 .34958 Mdot
.686 .35014 Mdot
.686 .35043 Mdot
.686 .35192 Mdot
.686 .35225 Mdot
.686 .35239 Mdot
.686 .35248 Mdot
.686 .35267 Mdot
.686 .35404 Mdot
.686 .35462 Mdot
.686 .35474 Mdot
.686 .35562 Mdot
.686 .35651 Mdot
.686 .35675 Mdot
.686 .35682 Mdot
.686 .35712 Mdot
.686 .35713 Mdot
.686 .35773 Mdot
.686 .35793 Mdot
.686 .35795 Mdot
.686 .35805 Mdot
.686 .35809 Mdot
.686 .35832 Mdot
.686 .35843 Mdot
.686 .3585 Mdot
.686 .35919 Mdot
.686 .35958 Mdot
.686 .36021 Mdot
.686 .36058 Mdot
.686 .36067 Mdot
.686 .36075 Mdot
.686 .36082 Mdot
.686 .361 Mdot
.686 .36113 Mdot
.686 .36128 Mdot
.686 .36131 Mdot
.686 .36198 Mdot
.686 .36234 Mdot
.686 .36259 Mdot
.686 .36334 Mdot
.686 .36341 Mdot
.686 .36383 Mdot
.686 .36423 Mdot
.686 .36476 Mdot
.686 .36515 Mdot
.686 .36519 Mdot
.686 .36637 Mdot
.686 .36643 Mdot
.686 .36758 Mdot
.686 .36789 Mdot
.686 .36794 Mdot
.686 .36923 Mdot
.686 .3696 Mdot
.686 .36977 Mdot
.686 .36999 Mdot
.686 .37012 Mdot
.686 .37109 Mdot
.686 .3714 Mdot
.686 .37188 Mdot
.686 .37195 Mdot
.686 .3724 Mdot
.686 .37273 Mdot
.686 .37289 Mdot
.686 .37342 Mdot
.686 .37366 Mdot
.686 .37378 Mdot
.686 .37428 Mdot
.686 .37448 Mdot
.686 .37516 Mdot
.686 .37528 Mdot
.686 .37543 Mdot
.686 .37598 Mdot
.686 .37607 Mdot
.686 .37623 Mdot
.686 .37626 Mdot
.686 .37628 Mdot
.686 .37629 Mdot
.686 .37661 Mdot
.686 .37679 Mdot
.686 .37692 Mdot
.686 .37696 Mdot
.686 .37709 Mdot
.686 .37715 Mdot
.686 .37723 Mdot
.686 .37729 Mdot
.686 .3774 Mdot
.686 .37748 Mdot
.686 .3775 Mdot
.686 .37754 Mdot
.686 .3776 Mdot
.686 .3776 Mdot
.686 .37761 Mdot
.686 .37781 Mdot
.686 .37797 Mdot
.686 .37808 Mdot
.686 .37826 Mdot
.686 .37827 Mdot
.686 .37828 Mdot
.686 .37832 Mdot
.686 .37852 Mdot
.686 .3786 Mdot
.686 .37931 Mdot
.686 .37946 Mdot
.686 .37946 Mdot
.686 .37949 Mdot
.686 .3795 Mdot
.686 .37953 Mdot
.686 .37959 Mdot
.686 .3797 Mdot
.686 .37978 Mdot
.686 .37993 Mdot
.686 .37996 Mdot
.686 .37998 Mdot
.686 .37999 Mdot
.686 .38004 Mdot
.686 .38004 Mdot
.686 .38011 Mdot
.686 .38028 Mdot
.686 .3804 Mdot
.686 .38042 Mdot
.686 .38066 Mdot
.686 .38067 Mdot
.686 .38078 Mdot
.686 .38086 Mdot
.686 .38093 Mdot
.686 .38095 Mdot
.686 .38098 Mdot
.686 .38099 Mdot
.686 .38102 Mdot
.686 .38108 Mdot
.686 .38113 Mdot
.686 .38114 Mdot
.686 .38114 Mdot
.686 .38119 Mdot
.686 .38124 Mdot
.686 .38125 Mdot
.686 .38126 Mdot
.686 .38126 Mdot
.686 .38129 Mdot
.686 .3813 Mdot
.686 .38139 Mdot
.686 .38147 Mdot
.686 .38147 Mdot
.686 .38157 Mdot
.686 .38166 Mdot
.686 .38179 Mdot
.686 .38179 Mdot
.686 .38182 Mdot
.686 .38184 Mdot
.686 .3819 Mdot
.686 .38195 Mdot
.686 .38197 Mdot
.686 .38198 Mdot
.686 .38199 Mdot
.686 .38201 Mdot
.686 .38207 Mdot
.686 .38211 Mdot
.686 .3823 Mdot
.686 .38232 Mdot
.686 .38235 Mdot
.686 .38245 Mdot
.686 .38252 Mdot
.686 .38255 Mdot
.686 .38258 Mdot
.686 .38265 Mdot
.686 .38266 Mdot
.686 .38277 Mdot
.686 .38281 Mdot
.686 .38282 Mdot
.686 .38283 Mdot
.686 .38284 Mdot
.686 .38284 Mdot
.686 .38285 Mdot
.686 .38288 Mdot
.686 .38292 Mdot
.686 .38292 Mdot
.686 .3832 Mdot
.686 .3833 Mdot
.686 .38365 Mdot
.686 .38368 Mdot
.686 .38383 Mdot
.686 .38421 Mdot
.686 .38432 Mdot
.686 .38463 Mdot
.686 .38488 Mdot
.686 .3849 Mdot
.686 .38502 Mdot
.686 .3852 Mdot
.686 .38522 Mdot
.686 .38535 Mdot
.686 .38542 Mdot
.686 .38549 Mdot
.686 .38549 Mdot
.686 .38577 Mdot
.686 .38582 Mdot
.686 .38586 Mdot
.686 .3862 Mdot
.686 .38629 Mdot
.686 .38646 Mdot
.686 .38649 Mdot
.686 .38703 Mdot
.686 .38723 Mdot
.686 .38768 Mdot
.686 .38772 Mdot
.686 .38782 Mdot
.686 .38814 Mdot
.686 .3882 Mdot
.686 .38822 Mdot
.686 .38824 Mdot
.686 .38861 Mdot
.686 .38863 Mdot
.686 .38878 Mdot
.686 .38898 Mdot
.686 .38903 Mdot
.686 .38914 Mdot
.686 .38917 Mdot
.686 .38919 Mdot
.686 .38924 Mdot
.686 .38944 Mdot
.686 .38955 Mdot
.686 .38961 Mdot
.686 .38962 Mdot
.686 .38964 Mdot
.686 .38965 Mdot
.686 .38968 Mdot
.686 .3897 Mdot
.686 .38984 Mdot
.686 .39006 Mdot
.686 .39014 Mdot
.686 .3902 Mdot
.686 .39029 Mdot
.686 .39035 Mdot
.686 .39035 Mdot
.686 .39055 Mdot
.686 .39073 Mdot
.686 .39078 Mdot
.686 .39079 Mdot
.686 .39108 Mdot
.686 .39111 Mdot
.686 .39113 Mdot
.686 .39128 Mdot
.686 .39141 Mdot
.686 .39154 Mdot
.686 .39156 Mdot
.686 .39164 Mdot
.686 .39168 Mdot
.686 .39178 Mdot
.686 .39191 Mdot
.686 .39193 Mdot
.686 .39205 Mdot
.686 .39219 Mdot
.686 .39219 Mdot
.686 .39229 Mdot
.686 .39229 Mdot
.686 .39232 Mdot
.686 .39235 Mdot
.686 .39236 Mdot
.686 .39239 Mdot
.686 .39239 Mdot
.686 .3924 Mdot
.686 .3924 Mdot
.686 .39243 Mdot
.686 .39245 Mdot
.686 .39258 Mdot
.686 .39259 Mdot
.686 .39259 Mdot
.686 .3926 Mdot
.686 .39262 Mdot
.686 .39263 Mdot
.686 .39265 Mdot
.686 .39266 Mdot
.686 .39266 Mdot
.686 .39266 Mdot
.686 .39267 Mdot
.686 .39267 Mdot
.686 .39271 Mdot
.686 .39272 Mdot
.686 .39276 Mdot
.686 .39277 Mdot
.686 .3928 Mdot
.686 .39281 Mdot
.686 .39281 Mdot
.686 .39281 Mdot
.686 .39282 Mdot
.686 .39283 Mdot
.686 .39284 Mdot
.686 .39284 Mdot
.686 .39284 Mdot
.686 .39285 Mdot
.686 .39285 Mdot
.686 .39286 Mdot
.686 .39286 Mdot
.686 .39286 Mdot
.686 .39286 Mdot
.686 .39288 Mdot
.686 .39289 Mdot
.686 .39291 Mdot
.686 .39292 Mdot
.686 .39294 Mdot
.686 .39294 Mdot
.686 .39295 Mdot
.686 .39295 Mdot
.686 .39296 Mdot
.686 .39297 Mdot
.686 .39297 Mdot
.686 .39297 Mdot
.686 .39298 Mdot
.686 .39298 Mdot
.686 .39299 Mdot
.686 .39302 Mdot
.686 .39303 Mdot
.686 .39304 Mdot
.686 .39305 Mdot
.686 .39306 Mdot
.686 .39307 Mdot
.686 .39308 Mdot
.686 .3931 Mdot
.686 .3931 Mdot
.686 .3931 Mdot
.686 .3931 Mdot
.686 .3931 Mdot
.686 .39311 Mdot
.686 .39311 Mdot
.686 .39312 Mdot
.686 .39312 Mdot
.686 .39587 Mdot
.686 .39587 Mdot
.686 .39587 Mdot
.686 .39587 Mdot
.686 .39587 Mdot
.686 .39587 Mdot
.686 .39587 Mdot
.686 .39587 Mdot
.686 .39587 Mdot
.686 .39588 Mdot
.686 .39588 Mdot
.686 .39589 Mdot
.686 .39589 Mdot
.686 .3959 Mdot
.686 .3959 Mdot
.686 .3959 Mdot
.686 .39592 Mdot
.686 .39592 Mdot
.686 .39592 Mdot
.686 .39592 Mdot
.686 .39592 Mdot
.686 .39592 Mdot
.686 .39593 Mdot
.686 .39593 Mdot
.686 .39593 Mdot
.686 .39594 Mdot
.686 .39594 Mdot
.686 .39594 Mdot
.686 .39595 Mdot
.686 .39596 Mdot
.686 .39596 Mdot
.686 .39597 Mdot
.686 .39597 Mdot
.686 .39597 Mdot
.686 .39597 Mdot
.686 .39597 Mdot
.686 .39597 Mdot
.686 .39598 Mdot
.686 .39598 Mdot
.686 .39598 Mdot
.686 .39598 Mdot
.686 .39598 Mdot
.686 .39599 Mdot
.686 .39599 Mdot
.686 .39599 Mdot
.686 .39599 Mdot
.686 .396 Mdot
.686 .39601 Mdot
.686 .39602 Mdot
.686 .39603 Mdot
.686 .39604 Mdot
.686 .39604 Mdot
.686 .39605 Mdot
.686 .39605 Mdot
.686 .39605 Mdot
.686 .39605 Mdot
.686 .39606 Mdot
.686 .39606 Mdot
.686 .39607 Mdot
.686 .39607 Mdot
.686 .39608 Mdot
.686 .39608 Mdot
.686 .39613 Mdot
.686 .39614 Mdot
.686 .39615 Mdot
.686 .39615 Mdot
.686 .39615 Mdot
.686 .39615 Mdot
.686 .39616 Mdot
.686 .39617 Mdot
.686 .39618 Mdot
.686 .39619 Mdot
.686 .39619 Mdot
.686 .39623 Mdot
.686 .39623 Mdot
.686 .39628 Mdot
.686 .39633 Mdot
.686 .39634 Mdot
.686 .39639 Mdot
.686 .39643 Mdot
.686 .39644 Mdot
.686 .39647 Mdot
.686 .39648 Mdot
.686 .39653 Mdot
.686 .39658 Mdot
.686 .39664 Mdot
.686 .39665 Mdot
.686 .39666 Mdot
.686 .39677 Mdot
.686 .39677 Mdot
.686 .39679 Mdot
.686 .39686 Mdot
.686 .39694 Mdot
.686 .39694 Mdot
.686 .39696 Mdot
.686 .39699 Mdot
.686 .39702 Mdot
.686 .39705 Mdot
.686 .39713 Mdot
.686 .39718 Mdot
.686 .39719 Mdot
.686 .3972 Mdot
.686 .39721 Mdot
.686 .39721 Mdot
.686 .39722 Mdot
.686 .39724 Mdot
.686 .39728 Mdot
.686 .39736 Mdot
.686 .39737 Mdot
.686 .39738 Mdot
.686 .39739 Mdot
.686 .39743 Mdot
.686 .39745 Mdot
.686 .39752 Mdot
.686 .39758 Mdot
.686 .39759 Mdot
.686 .39773 Mdot
.686 .39773 Mdot
.686 .39774 Mdot
.686 .39776 Mdot
.686 .39788 Mdot
.686 .39792 Mdot
.686 .39793 Mdot
.686 .39809 Mdot
.686 .39817 Mdot
.686 .39836 Mdot
.686 .39837 Mdot
.686 .39843 Mdot
.686 .39846 Mdot
.686 .39858 Mdot
.686 .3986 Mdot
.686 .39861 Mdot
.686 .39871 Mdot
.686 .39871 Mdot
.686 .39874 Mdot
.686 .39876 Mdot
.686 .39881 Mdot
.686 .39882 Mdot
.686 .39888 Mdot
.686 .39892 Mdot
.686 .39893 Mdot
.686 .39902 Mdot
.686 .39913 Mdot
.686 .39916 Mdot
.686 .39929 Mdot
.686 .39935 Mdot
.686 .39936 Mdot
.686 .39948 Mdot
.686 .39951 Mdot
.686 .39961 Mdot
.686 .39961 Mdot
.686 .39962 Mdot
.686 .39963 Mdot
.686 .39963 Mdot
.686 .39964 Mdot
.686 .39964 Mdot
.686 .39964 Mdot
.686 .39965 Mdot
.686 .39966 Mdot
.686 .3997 Mdot
.686 .3997 Mdot
.686 .39972 Mdot
.686 .39973 Mdot
.686 .39974 Mdot
.686 .39977 Mdot
.686 .3998 Mdot
.686 .39981 Mdot
.686 .39982 Mdot
.686 .39988 Mdot
.686 .3999 Mdot
.686 .39992 Mdot
.686 .39992 Mdot
.686 .39993 Mdot
.686 .39993 Mdot
.686 .39994 Mdot
.686 .39996 Mdot
.686 .39998 Mdot
.686 .39998 Mdot
.686 .39999 Mdot
.686 .39999 Mdot
.686 .40004 Mdot
.686 .40007 Mdot
.686 .4001 Mdot
.686 .4001 Mdot
.686 .40013 Mdot
.686 .40016 Mdot
.686 .40016 Mdot
.686 .40017 Mdot
.686 .40017 Mdot
.686 .40017 Mdot
.686 .40018 Mdot
.686 .4002 Mdot
.686 .40021 Mdot
.686 .40021 Mdot
.686 .40022 Mdot
.686 .40023 Mdot
.686 .40025 Mdot
.686 .40026 Mdot
.686 .40027 Mdot
.686 .40028 Mdot
.686 .40028 Mdot
.686 .4003 Mdot
.686 .40033 Mdot
.686 .40037 Mdot
.686 .40037 Mdot
.686 .40045 Mdot
.686 .40046 Mdot
.686 .4005 Mdot
.686 .40055 Mdot
.686 .40058 Mdot
.686 .40058 Mdot
.686 .40059 Mdot
.686 .4006 Mdot
.686 .4006 Mdot
.686 .40062 Mdot
.686 .40067 Mdot
.686 .40069 Mdot
.686 .40073 Mdot
.686 .40075 Mdot
.686 .40076 Mdot
.686 .40076 Mdot
.686 .40077 Mdot
.686 .40077 Mdot
.686 .40082 Mdot
.686 .40105 Mdot
.686 .40108 Mdot
.686 .40114 Mdot
.686 .40116 Mdot
.686 .40116 Mdot
.686 .40116 Mdot
.686 .40122 Mdot
.686 .40126 Mdot
.686 .40131 Mdot
.686 .40137 Mdot
.686 .40138 Mdot
.686 .40138 Mdot
.686 .4014 Mdot
.686 .40141 Mdot
.686 .40142 Mdot
.686 .40144 Mdot
.686 .40148 Mdot
.686 .4015 Mdot
.686 .40152 Mdot
.686 .40154 Mdot
.686 .40159 Mdot
.686 .4016 Mdot
.686 .40164 Mdot
.686 .4017 Mdot
.686 .4018 Mdot
.686 .4018 Mdot
.686 .40181 Mdot
.686 .40182 Mdot
.686 .40187 Mdot
.686 .4019 Mdot
.686 .40207 Mdot
.686 .40212 Mdot
.686 .40216 Mdot
.686 .40238 Mdot
.686 .40244 Mdot
.686 .40259 Mdot
.686 .40263 Mdot
.686 .40271 Mdot
.686 .40287 Mdot
.686 .40292 Mdot
.686 .40302 Mdot
.686 .40316 Mdot
.686 .40318 Mdot
.686 .40333 Mdot
.686 .40343 Mdot
.686 .40373 Mdot
.686 .40376 Mdot
.686 .40383 Mdot
.686 .40388 Mdot
.686 .404 Mdot
.686 .40438 Mdot
.686 .4044 Mdot
.686 .40449 Mdot
.686 .40484 Mdot
.686 .40485 Mdot
.686 .4052 Mdot
.686 .40521 Mdot
.686 .40533 Mdot
.686 .40549 Mdot
.686 .4056 Mdot
.686 .40572 Mdot
.686 .40574 Mdot
.686 .40596 Mdot
.686 .40604 Mdot
.686 .40614 Mdot
.686 .40633 Mdot
.686 .40634 Mdot
.686 .40638 Mdot
.686 .40642 Mdot
.686 .40648 Mdot
.686 .40649 Mdot
.686 .40652 Mdot
.686 .40654 Mdot
.686 .40665 Mdot
.686 .40683 Mdot
.686 .40694 Mdot
.686 .40714 Mdot
.686 .40716 Mdot
.686 .40719 Mdot
.686 .40726 Mdot
.686 .40727 Mdot
.686 .4073 Mdot
.686 .4073 Mdot
.686 .40736 Mdot
.686 .40753 Mdot
.686 .40753 Mdot
.686 .40762 Mdot
.686 .40764 Mdot
.686 .4077 Mdot
.686 .40795 Mdot
.686 .4082 Mdot
.686 .40824 Mdot
.686 .4084 Mdot
.686 .40878 Mdot
.686 .40883 Mdot
.686 .40886 Mdot
.686 .4089 Mdot
.686 .40899 Mdot
.686 .4094 Mdot
.686 .40948 Mdot
.686 .40964 Mdot
.686 .4097 Mdot
.686 .40977 Mdot
.686 .40986 Mdot
.686 .40993 Mdot
.686 .41 Mdot
.686 .41017 Mdot
.686 .41031 Mdot
.686 .41036 Mdot
.686 .41045 Mdot
.686 .41048 Mdot
.686 .41065 Mdot
.686 .41111 Mdot
.686 .41139 Mdot
.686 .41143 Mdot
.686 .41145 Mdot
.686 .41165 Mdot
.686 .41168 Mdot
.686 .41178 Mdot
.686 .41221 Mdot
.686 .41226 Mdot
.686 .41233 Mdot
.686 .41237 Mdot
.686 .41243 Mdot
.686 .41268 Mdot
.686 .41268 Mdot
.686 .41276 Mdot
.686 .4128 Mdot
.686 .41284 Mdot
.686 .413 Mdot
.686 .41303 Mdot
.686 .41315 Mdot
.686 .41324 Mdot
.686 .41338 Mdot
.686 .41339 Mdot
.686 .4136 Mdot
.686 .41368 Mdot
.686 .41392 Mdot
.686 .41396 Mdot
.686 .41402 Mdot
.686 .41413 Mdot
.686 .41453 Mdot
.686 .41468 Mdot
.686 .4147 Mdot
.686 .41488 Mdot
.686 .41493 Mdot
.686 .41504 Mdot
.686 .41513 Mdot
.686 .41539 Mdot
.686 .41539 Mdot
.686 .41543 Mdot
.686 .41545 Mdot
.686 .41546 Mdot
.686 .41546 Mdot
.686 .41547 Mdot
.686 .41548 Mdot
.686 .41549 Mdot
.686 .41552 Mdot
.686 .41561 Mdot
.686 .41563 Mdot
.686 .41568 Mdot
.686 .41571 Mdot
.686 .41574 Mdot
.686 .41576 Mdot
.686 .41579 Mdot
.686 .41587 Mdot
.686 .4159 Mdot
.686 .41591 Mdot
.686 .41596 Mdot
.686 .416 Mdot
.686 .41607 Mdot
.686 .4161 Mdot
.686 .41614 Mdot
.686 .41616 Mdot
.686 .41617 Mdot
.686 .41618 Mdot
.686 .4162 Mdot
.686 .41623 Mdot
.686 .41628 Mdot
.686 .41629 Mdot
.686 .41631 Mdot
.686 .41631 Mdot
.686 .41641 Mdot
.686 .41647 Mdot
.686 .41654 Mdot
.686 .41655 Mdot
.686 .4166 Mdot
.686 .41666 Mdot
.686 .41667 Mdot
.686 .41669 Mdot
.686 .41669 Mdot
.686 .4167 Mdot
.686 .41671 Mdot
.686 .41674 Mdot
.686 .41677 Mdot
.686 .41677 Mdot
.686 .41678 Mdot
.686 .41679 Mdot
.686 .41681 Mdot
.686 .41685 Mdot
.686 .41687 Mdot
.686 .41688 Mdot
.686 .4169 Mdot
.686 .41691 Mdot
.686 .41695 Mdot
.686 .41699 Mdot
.686 .417 Mdot
.686 .41707 Mdot
.686 .41708 Mdot
.686 .41708 Mdot
.686 .41719 Mdot
.686 .41722 Mdot
.686 .41723 Mdot
.686 .41726 Mdot
.686 .4173 Mdot
.686 .41739 Mdot
.686 .41743 Mdot
.686 .41743 Mdot
.686 .41745 Mdot
.686 .41746 Mdot
.686 .41747 Mdot
.686 .41749 Mdot
.686 .41757 Mdot
.686 .4176 Mdot
.686 .41766 Mdot
.686 .41768 Mdot
.686 .4177 Mdot
.686 .4177 Mdot
.686 .4177 Mdot
.686 .41772 Mdot
.686 .41772 Mdot
.686 .41778 Mdot
.686 .41783 Mdot
.686 .418 Mdot
.686 .41803 Mdot
.686 .41807 Mdot
.686 .4181 Mdot
.686 .41817 Mdot
.686 .41817 Mdot
.686 .41818 Mdot
.686 .41818 Mdot
.686 .41818 Mdot
.686 .41824 Mdot
.686 .41826 Mdot
.686 .41827 Mdot
.686 .41831 Mdot
.686 .41832 Mdot
.686 .41837 Mdot
.686 .41837 Mdot
.686 .41837 Mdot
.686 .41838 Mdot
.686 .41839 Mdot
.686 .4184 Mdot
.686 .41842 Mdot
.686 .41843 Mdot
.686 .41844 Mdot
.686 .41845 Mdot
.686 .41847 Mdot
.686 .41847 Mdot
.686 .41848 Mdot
.686 .41849 Mdot
.686 .4185 Mdot
.686 .41851 Mdot
.686 .41853 Mdot
.686 .41855 Mdot
.686 .41856 Mdot
.686 .41859 Mdot
.686 .41859 Mdot
.686 .41859 Mdot
.686 .41859 Mdot
.686 .41859 Mdot
.686 .41861 Mdot
.686 .41861 Mdot
.686 .41863 Mdot
.686 .41863 Mdot
.686 .41863 Mdot
.688 .31269 Mdot
.688 .31271 Mdot
.688 .31272 Mdot
.688 .31274 Mdot
.688 .31275 Mdot
.688 .31282 Mdot
.688 .31286 Mdot
.688 .31292 Mdot
.688 .31299 Mdot
.688 .31299 Mdot
.688 .31315 Mdot
.688 .31316 Mdot
.688 .31316 Mdot
.688 .31318 Mdot
.688 .31319 Mdot
.688 .31338 Mdot
.688 .31341 Mdot
.688 .31347 Mdot
.688 .31348 Mdot
.688 .31348 Mdot
.688 .31354 Mdot
.688 .3137 Mdot
.688 .31375 Mdot
.688 .31381 Mdot
.688 .31395 Mdot
.688 .3141 Mdot
.688 .31418 Mdot
.688 .31431 Mdot
.688 .31433 Mdot
.688 .31442 Mdot
.688 .31447 Mdot
.688 .31457 Mdot
.688 .31524 Mdot
.688 .31544 Mdot
.688 .31586 Mdot
.688 .31588 Mdot
.688 .3161 Mdot
.688 .31616 Mdot
.688 .3162 Mdot
.688 .31624 Mdot
.688 .3168 Mdot
.688 .31695 Mdot
.688 .31707 Mdot
.688 .31711 Mdot
.688 .31721 Mdot
.688 .3173 Mdot
.688 .31739 Mdot
.688 .31747 Mdot
.688 .3178 Mdot
.688 .31858 Mdot
.688 .31907 Mdot
.688 .31914 Mdot
.688 .31957 Mdot
.688 .31966 Mdot
.688 .31968 Mdot
.688 .3199 Mdot
.688 .32015 Mdot
.688 .32029 Mdot
.688 .32059 Mdot
.688 .32069 Mdot
.688 .32086 Mdot
.688 .32088 Mdot
.688 .32089 Mdot
.688 .32099 Mdot
.688 .3213 Mdot
.688 .32166 Mdot
.688 .32191 Mdot
.688 .32194 Mdot
.688 .32212 Mdot
.688 .32229 Mdot
.688 .3223 Mdot
.688 .32233 Mdot
.688 .32259 Mdot
.688 .32262 Mdot
.688 .32266 Mdot
.688 .32313 Mdot
.688 .32333 Mdot
.688 .32333 Mdot
.688 .32372 Mdot
.688 .32402 Mdot
.688 .32482 Mdot
.688 .32494 Mdot
.688 .32507 Mdot
.688 .32521 Mdot
.688 .3254 Mdot
.688 .32553 Mdot
.688 .32573 Mdot
.688 .32592 Mdot
.688 .32606 Mdot
.688 .32606 Mdot
.688 .3265 Mdot
.688 .32667 Mdot
.688 .32705 Mdot
.688 .32707 Mdot
.688 .32725 Mdot
.688 .32727 Mdot
.688 .32761 Mdot
.688 .32773 Mdot
.688 .32783 Mdot
.688 .32815 Mdot
.688 .32879 Mdot
.688 .32891 Mdot
.688 .32982 Mdot
.688 .32995 Mdot
.688 .33023 Mdot
.688 .33028 Mdot
.688 .33054 Mdot
.688 .33062 Mdot
.688 .33075 Mdot
.688 .33117 Mdot
.688 .33128 Mdot
.688 .33137 Mdot
.688 .33159 Mdot
.688 .33168 Mdot
.688 .33223 Mdot
.688 .33247 Mdot
.688 .33272 Mdot
.688 .33288 Mdot
.688 .3331 Mdot
.688 .33352 Mdot
.688 .33406 Mdot
.688 .33435 Mdot
.688 .33564 Mdot
.688 .33571 Mdot
.688 .33635 Mdot
.688 .3366 Mdot
.688 .33745 Mdot
.688 .33751 Mdot
.688 .33773 Mdot
.688 .33817 Mdot
.688 .3382 Mdot
.688 .33893 Mdot
.688 .3403 Mdot
.688 .34078 Mdot
.688 .34126 Mdot
.688 .34157 Mdot
.688 .34179 Mdot
.688 .34229 Mdot
.688 .34252 Mdot
.688 .34274 Mdot
.688 .34278 Mdot
.688 .34358 Mdot
.688 .34361 Mdot
.688 .34383 Mdot
.688 .34383 Mdot
.688 .34384 Mdot
.688 .34403 Mdot
.688 .3441 Mdot
.688 .34415 Mdot
.688 .3442 Mdot
.688 .34422 Mdot
.688 .34422 Mdot
.688 .3444 Mdot
.688 .34486 Mdot
.688 .34498 Mdot
.688 .34499 Mdot
.688 .34528 Mdot
.688 .34546 Mdot
.688 .3456 Mdot
.688 .34576 Mdot
.688 .34632 Mdot
.688 .34633 Mdot
.688 .34636 Mdot
.688 .34713 Mdot
.688 .34721 Mdot
.688 .34754 Mdot
.688 .34759 Mdot
.688 .34762 Mdot
.688 .34774 Mdot
.688 .34784 Mdot
.688 .34826 Mdot
.688 .34831 Mdot
.688 .34834 Mdot
.688 .34848 Mdot
.688 .34855 Mdot
.688 .34925 Mdot
.688 .34939 Mdot
.688 .34943 Mdot
.688 .34968 Mdot
.688 .34991 Mdot
.688 .34993 Mdot
.688 .34995 Mdot
.688 .34998 Mdot
.688 .35001 Mdot
.688 .35026 Mdot
.688 .35042 Mdot
.688 .35065 Mdot
.688 .35089 Mdot
.688 .35107 Mdot
.688 .35158 Mdot
.688 .35188 Mdot
.688 .35233 Mdot
.688 .35233 Mdot
.688 .35233 Mdot
.688 .35235 Mdot
.688 .3525 Mdot
.688 .35259 Mdot
.688 .35268 Mdot
.688 .3528 Mdot
.688 .35284 Mdot
.688 .35328 Mdot
.688 .35359 Mdot
.688 .3538 Mdot
.688 .35387 Mdot
.688 .35429 Mdot
.688 .3547 Mdot
.688 .35481 Mdot
.688 .35482 Mdot
.688 .35523 Mdot
.688 .35544 Mdot
.688 .35563 Mdot
.688 .35579 Mdot
.688 .35591 Mdot
.688 .35619 Mdot
.688 .35631 Mdot
.688 .35634 Mdot
.688 .35641 Mdot
.688 .35658 Mdot
.688 .35669 Mdot
.688 .35717 Mdot
.688 .35729 Mdot
.688 .35766 Mdot
.688 .35769 Mdot
.688 .35772 Mdot
.688 .3578 Mdot
.688 .35811 Mdot
.688 .35814 Mdot
.688 .35839 Mdot
.688 .35879 Mdot
.688 .35879 Mdot
.688 .35914 Mdot
.688 .35945 Mdot
.688 .35983 Mdot
.688 .35985 Mdot
.688 .3599 Mdot
.688 .35991 Mdot
.688 .3602 Mdot
.688 .36045 Mdot
.688 .36082 Mdot
.688 .36103 Mdot
.688 .36104 Mdot
.688 .36107 Mdot
.688 .36114 Mdot
.688 .3612 Mdot
.688 .36121 Mdot
.688 .36158 Mdot
.688 .36172 Mdot
.688 .36178 Mdot
.688 .36187 Mdot
.688 .362 Mdot
.688 .36253 Mdot
.688 .36274 Mdot
.688 .36275 Mdot
.688 .36288 Mdot
.688 .36294 Mdot
.688 .36321 Mdot
.688 .36349 Mdot
.688 .36388 Mdot
.688 .36397 Mdot
.688 .36413 Mdot
.688 .36454 Mdot
.688 .36471 Mdot
.688 .36481 Mdot
.688 .36483 Mdot
.688 .36487 Mdot
.688 .36505 Mdot
.688 .36507 Mdot
.688 .36515 Mdot
.688 .3653 Mdot
.688 .36565 Mdot
.688 .36586 Mdot
.688 .36597 Mdot
.688 .36617 Mdot
.688 .36623 Mdot
.688 .36637 Mdot
.688 .36659 Mdot
.688 .36664 Mdot
.688 .36671 Mdot
.688 .36695 Mdot
.688 .367 Mdot
.688 .36734 Mdot
.688 .36761 Mdot
.688 .36761 Mdot
.688 .36769 Mdot
.688 .36788 Mdot
.688 .36789 Mdot
.688 .36791 Mdot
.688 .36801 Mdot
.688 .36802 Mdot
.688 .36803 Mdot
.688 .36817 Mdot
.688 .36829 Mdot
.688 .36844 Mdot
.688 .36862 Mdot
.688 .36862 Mdot
.688 .36863 Mdot
.688 .36875 Mdot
.688 .36922 Mdot
.688 .36946 Mdot
.688 .37011 Mdot
.688 .3705 Mdot
.688 .37103 Mdot
.688 .37105 Mdot
.688 .37107 Mdot
.688 .37156 Mdot
.688 .37224 Mdot
.688 .37238 Mdot
.688 .37246 Mdot
.688 .37248 Mdot
.688 .37283 Mdot
.688 .3731 Mdot
.688 .37338 Mdot
.688 .37351 Mdot
.688 .3738 Mdot
.688 .37382 Mdot
.688 .37385 Mdot
.688 .37385 Mdot
.688 .37386 Mdot
.688 .37416 Mdot
.688 .37433 Mdot
.688 .37513 Mdot
.688 .37539 Mdot
.688 .37576 Mdot
.688 .3759 Mdot
.688 .37595 Mdot
.688 .37619 Mdot
.688 .37631 Mdot
.688 .37663 Mdot
.688 .37729 Mdot
.688 .37737 Mdot
.688 .37739 Mdot
.688 .37746 Mdot
.688 .37769 Mdot
.688 .37776 Mdot
.688 .37804 Mdot
.688 .37812 Mdot
.688 .37837 Mdot
.688 .37894 Mdot
.688 .37933 Mdot
.688 .37934 Mdot
.688 .37947 Mdot
.688 .37986 Mdot
.688 .37994 Mdot
.688 .38 Mdot
.688 .38007 Mdot
.688 .38011 Mdot
.688 .38016 Mdot
.688 .3802 Mdot
.688 .38071 Mdot
.688 .38095 Mdot
.688 .38116 Mdot
.688 .38117 Mdot
.688 .38126 Mdot
.688 .38136 Mdot
.688 .38141 Mdot
.688 .38156 Mdot
.688 .38167 Mdot
.688 .382 Mdot
.688 .38207 Mdot
.688 .38259 Mdot
.688 .38293 Mdot
.688 .3831 Mdot
.688 .38314 Mdot
.688 .38329 Mdot
.688 .38341 Mdot
.688 .38357 Mdot
.688 .38362 Mdot
.688 .38372 Mdot
.688 .38375 Mdot
.688 .38406 Mdot
.688 .38432 Mdot
.688 .38439 Mdot
.688 .38452 Mdot
.688 .38472 Mdot
.688 .38492 Mdot
.688 .38498 Mdot
.688 .38502 Mdot
.688 .38507 Mdot
.688 .38564 Mdot
.688 .38578 Mdot
.688 .38601 Mdot
.688 .38658 Mdot
.688 .38701 Mdot
.688 .38705 Mdot
.688 .38706 Mdot
.688 .38726 Mdot
.688 .38726 Mdot
.688 .3873 Mdot
.688 .38732 Mdot
.688 .38733 Mdot
.688 .38736 Mdot
.688 .38738 Mdot
.688 .38745 Mdot
.688 .38747 Mdot
.688 .38753 Mdot
.688 .38756 Mdot
.688 .38758 Mdot
.688 .38761 Mdot
.688 .38771 Mdot
.688 .38772 Mdot
.688 .38786 Mdot
.688 .38793 Mdot
.688 .38794 Mdot
.688 .38794 Mdot
.688 .38796 Mdot
.688 .38798 Mdot
.688 .38807 Mdot
.688 .38823 Mdot
.688 .38825 Mdot
.688 .38826 Mdot
.688 .3883 Mdot
.688 .38834 Mdot
.688 .38835 Mdot
.688 .38835 Mdot
.688 .38836 Mdot
.688 .3884 Mdot
.688 .38843 Mdot
.688 .38847 Mdot
.688 .38851 Mdot
.688 .38863 Mdot
.688 .38868 Mdot
.688 .38875 Mdot
.688 .38875 Mdot
.688 .38878 Mdot
.688 .3888 Mdot
.688 .38881 Mdot
.688 .38883 Mdot
.688 .38884 Mdot
.688 .38891 Mdot
.688 .38896 Mdot
.688 .38901 Mdot
.688 .38908 Mdot
.688 .38917 Mdot
.688 .38923 Mdot
.688 .38927 Mdot
.688 .3893 Mdot
.688 .38932 Mdot
.688 .38941 Mdot
.688 .38945 Mdot
.688 .38947 Mdot
.688 .38955 Mdot
.688 .38956 Mdot
.688 .38962 Mdot
.688 .38963 Mdot
.688 .38965 Mdot
.688 .38969 Mdot
.688 .38974 Mdot
.688 .3898 Mdot
.688 .3898 Mdot
.688 .38986 Mdot
.688 .38991 Mdot
.688 .38997 Mdot
.688 .38998 Mdot
.688 .38998 Mdot
.688 .39006 Mdot
.688 .39016 Mdot
.688 .39016 Mdot
.688 .39018 Mdot
.688 .39018 Mdot
.688 .39026 Mdot
.688 .39027 Mdot
.688 .39029 Mdot
.688 .39031 Mdot
.688 .39042 Mdot
.688 .39042 Mdot
.688 .39044 Mdot
.688 .39049 Mdot
.688 .3906 Mdot
.688 .39061 Mdot
.688 .3907 Mdot
.688 .39072 Mdot
.688 .39074 Mdot
.688 .39075 Mdot
.688 .39078 Mdot
.688 .39078 Mdot
.688 .39079 Mdot
.688 .39082 Mdot
.688 .39087 Mdot
.688 .3909 Mdot
.688 .39092 Mdot
.688 .39098 Mdot
.688 .39102 Mdot
.688 .39103 Mdot
.688 .39107 Mdot
.688 .39107 Mdot
.688 .39113 Mdot
.688 .39117 Mdot
.688 .39117 Mdot
.688 .39118 Mdot
.688 .39121 Mdot
.688 .39121 Mdot
.688 .39123 Mdot
.688 .39123 Mdot
.688 .39123 Mdot
.688 .39125 Mdot
.688 .39127 Mdot
.688 .39129 Mdot
.688 .39132 Mdot
.688 .39132 Mdot
.688 .39132 Mdot
.688 .39134 Mdot
.688 .39698 Mdot
.688 .39698 Mdot
.688 .39699 Mdot
.688 .39699 Mdot
.688 .397 Mdot
.688 .397 Mdot
.688 .39701 Mdot
.688 .39702 Mdot
.688 .39702 Mdot
.688 .39702 Mdot
.688 .39703 Mdot
.688 .39703 Mdot
.688 .39704 Mdot
.688 .39704 Mdot
.688 .39704 Mdot
.688 .39706 Mdot
.688 .39708 Mdot
.688 .39708 Mdot
.688 .39709 Mdot
.688 .3971 Mdot
.688 .39711 Mdot
.688 .39714 Mdot
.688 .39714 Mdot
.688 .39715 Mdot
.688 .39717 Mdot
.688 .39718 Mdot
.688 .39719 Mdot
.688 .39719 Mdot
.688 .3972 Mdot
.688 .3972 Mdot
.688 .39721 Mdot
.688 .39722 Mdot
.688 .39725 Mdot
.688 .39726 Mdot
.688 .39729 Mdot
.688 .39731 Mdot
.688 .39732 Mdot
.688 .39732 Mdot
.688 .39736 Mdot
.688 .39737 Mdot
.688 .39738 Mdot
.688 .39738 Mdot
.688 .39741 Mdot
.688 .39741 Mdot
.688 .39742 Mdot
.688 .39742 Mdot
.688 .39745 Mdot
.688 .39748 Mdot
.688 .39749 Mdot
.688 .39749 Mdot
.688 .39751 Mdot
.688 .39753 Mdot
.688 .39755 Mdot
.688 .39755 Mdot
.688 .39757 Mdot
.688 .39759 Mdot
.688 .39761 Mdot
.688 .39761 Mdot
.688 .39762 Mdot
.688 .39764 Mdot
.688 .39764 Mdot
.688 .39767 Mdot
.688 .39768 Mdot
.688 .39769 Mdot
.688 .39773 Mdot
.688 .39774 Mdot
.688 .39775 Mdot
.688 .39776 Mdot
.688 .39778 Mdot
.688 .39782 Mdot
.688 .39784 Mdot
.688 .39786 Mdot
.688 .39788 Mdot
.688 .3979 Mdot
.688 .39791 Mdot
.688 .39791 Mdot
.688 .39792 Mdot
.688 .39792 Mdot
.688 .39793 Mdot
.688 .39793 Mdot
.688 .39796 Mdot
.688 .39798 Mdot
.688 .39802 Mdot
.688 .39804 Mdot
.688 .39805 Mdot
.688 .39806 Mdot
.688 .39808 Mdot
.688 .39808 Mdot
.688 .39808 Mdot
.688 .39808 Mdot
.688 .3981 Mdot
.688 .39811 Mdot
.688 .39811 Mdot
.688 .39812 Mdot
.688 .39818 Mdot
.688 .39821 Mdot
.688 .39822 Mdot
.688 .39823 Mdot
.688 .39823 Mdot
.688 .39823 Mdot
.688 .39826 Mdot
.688 .39831 Mdot
.688 .39831 Mdot
.688 .39834 Mdot
.688 .39835 Mdot
.688 .39836 Mdot
.688 .39838 Mdot
.688 .39839 Mdot
.688 .3984 Mdot
.688 .39843 Mdot
.688 .39843 Mdot
.688 .39844 Mdot
.688 .39845 Mdot
.688 .39846 Mdot
.688 .39847 Mdot
.688 .39847 Mdot
.688 .39854 Mdot
.688 .39854 Mdot
.688 .39856 Mdot
.688 .39871 Mdot
.688 .39891 Mdot
.688 .39899 Mdot
.688 .39904 Mdot
.688 .39924 Mdot
.688 .39926 Mdot
.688 .39927 Mdot
.688 .39929 Mdot
.688 .39936 Mdot
.688 .39943 Mdot
.688 .39947 Mdot
.688 .3995 Mdot
.688 .39959 Mdot
.688 .39969 Mdot
.688 .3997 Mdot
.688 .39973 Mdot
.688 .39975 Mdot
.688 .3998 Mdot
.688 .39985 Mdot
.688 .3999 Mdot
.688 .39991 Mdot
.688 .39997 Mdot
.688 .40008 Mdot
.688 .40026 Mdot
.688 .40028 Mdot
.688 .40039 Mdot
.688 .40043 Mdot
.688 .40048 Mdot
.688 .4005 Mdot
.688 .40053 Mdot
.688 .40056 Mdot
.688 .40056 Mdot
.688 .40063 Mdot
.688 .40071 Mdot
.688 .40088 Mdot
.688 .40089 Mdot
.688 .4009 Mdot
.688 .40092 Mdot
.688 .40094 Mdot
.688 .40096 Mdot
.688 .40099 Mdot
.688 .40111 Mdot
.688 .40116 Mdot
.688 .40116 Mdot
.688 .40129 Mdot
.688 .40147 Mdot
.688 .40155 Mdot
.688 .40158 Mdot
.688 .40167 Mdot
.688 .40169 Mdot
.688 .40176 Mdot
.688 .40178 Mdot
.688 .40179 Mdot
.688 .40182 Mdot
.688 .40203 Mdot
.688 .40213 Mdot
.688 .40217 Mdot
.688 .40224 Mdot
.688 .40226 Mdot
.688 .4023 Mdot
.688 .40242 Mdot
.688 .4025 Mdot
.688 .40275 Mdot
.688 .4028 Mdot
.688 .40289 Mdot
.688 .4029 Mdot
.688 .4029 Mdot
.688 .40291 Mdot
.688 .40291 Mdot
.688 .403 Mdot
.688 .40304 Mdot
.688 .40313 Mdot
.688 .40321 Mdot
.688 .40332 Mdot
.688 .40333 Mdot
.688 .40335 Mdot
.688 .40339 Mdot
.688 .4036 Mdot
.688 .40375 Mdot
.688 .40376 Mdot
.688 .40376 Mdot
.688 .40392 Mdot
.688 .40404 Mdot
.688 .40424 Mdot
.688 .40431 Mdot
.688 .40445 Mdot
.688 .40449 Mdot
.688 .40449 Mdot
.688 .40449 Mdot
.688 .40454 Mdot
.688 .40459 Mdot
.688 .40462 Mdot
.688 .40467 Mdot
.688 .40467 Mdot
.688 .40467 Mdot
.688 .4047 Mdot
.688 .40471 Mdot
.688 .40471 Mdot
.688 .40477 Mdot
.688 .40479 Mdot
.688 .40479 Mdot
.688 .40487 Mdot
.688 .40497 Mdot
.688 .40498 Mdot
.688 .40506 Mdot
.688 .40508 Mdot
.688 .40509 Mdot
.688 .40515 Mdot
.688 .4052 Mdot
.688 .40521 Mdot
.688 .40527 Mdot
.688 .4053 Mdot
.688 .40537 Mdot
.688 .40547 Mdot
.688 .40551 Mdot
.688 .40554 Mdot
.688 .40554 Mdot
.688 .40559 Mdot
.688 .40561 Mdot
.688 .40561 Mdot
.688 .40564 Mdot
.688 .40569 Mdot
.688 .40581 Mdot
.688 .40586 Mdot
.688 .40588 Mdot
.688 .40599 Mdot
.688 .40608 Mdot
.688 .40615 Mdot
.688 .40617 Mdot
.688 .40621 Mdot
.688 .40621 Mdot
.688 .40627 Mdot
.688 .40643 Mdot
.688 .40646 Mdot
.688 .40649 Mdot
.688 .40651 Mdot
.688 .40655 Mdot
.688 .40665 Mdot
.688 .40665 Mdot
.688 .40667 Mdot
.688 .40669 Mdot
.688 .4067 Mdot
.688 .4067 Mdot
.688 .40676 Mdot
.688 .40687 Mdot
.688 .40694 Mdot
.688 .40702 Mdot
.688 .40703 Mdot
.688 .40704 Mdot
.688 .40705 Mdot
.688 .40715 Mdot
.688 .40724 Mdot
.688 .40734 Mdot
.688 .40734 Mdot
.688 .40746 Mdot
.688 .40753 Mdot
.688 .40753 Mdot
.688 .40762 Mdot
.688 .40764 Mdot
.688 .40765 Mdot
.688 .40766 Mdot
.688 .40776 Mdot
.688 .4078 Mdot
.688 .40793 Mdot
.688 .40796 Mdot
.688 .40801 Mdot
.688 .40803 Mdot
.688 .40804 Mdot
.688 .40807 Mdot
.688 .40815 Mdot
.688 .40819 Mdot
.688 .40823 Mdot
.688 .40828 Mdot
.688 .40834 Mdot
.688 .40845 Mdot
.688 .40846 Mdot
.688 .40849 Mdot
.688 .4086 Mdot
.688 .40872 Mdot
.688 .40874 Mdot
.688 .4088 Mdot
.688 .40888 Mdot
.688 .40901 Mdot
.688 .40902 Mdot
.688 .40905 Mdot
.688 .40907 Mdot
.688 .4091 Mdot
.688 .40914 Mdot
.688 .40915 Mdot
.688 .40915 Mdot
.688 .40915 Mdot
.688 .40927 Mdot
.688 .40935 Mdot
.688 .40949 Mdot
.688 .40954 Mdot
.688 .40961 Mdot
.688 .40967 Mdot
.688 .40972 Mdot
.688 .40979 Mdot
.688 .40979 Mdot
.688 .4098 Mdot
.688 .40981 Mdot
.688 .40981 Mdot
.688 .40988 Mdot
.688 .40994 Mdot
.688 .40995 Mdot
.688 .40999 Mdot
.688 .41018 Mdot
.688 .4102 Mdot
.688 .41024 Mdot
.688 .41025 Mdot
.688 .41026 Mdot
.688 .41038 Mdot
.688 .41041 Mdot
.688 .41044 Mdot
.688 .41045 Mdot
.688 .41046 Mdot
.688 .41055 Mdot
.688 .41057 Mdot
.688 .41078 Mdot
.688 .41079 Mdot
.688 .41079 Mdot
.688 .41094 Mdot
.688 .41099 Mdot
.688 .41103 Mdot
.688 .41107 Mdot
.688 .41115 Mdot
.688 .41116 Mdot
.688 .41119 Mdot
.688 .41131 Mdot
.688 .41136 Mdot
.688 .41136 Mdot
.688 .41137 Mdot
.688 .41138 Mdot
.688 .41139 Mdot
.688 .41141 Mdot
.688 .41146 Mdot
.688 .41147 Mdot
.688 .41147 Mdot
.688 .41153 Mdot
.688 .41153 Mdot
.688 .41175 Mdot
.688 .41176 Mdot
.688 .41182 Mdot
.688 .41188 Mdot
.688 .41202 Mdot
.688 .41208 Mdot
.688 .41216 Mdot
.688 .41229 Mdot
.688 .41242 Mdot
.688 .41278 Mdot
.688 .41298 Mdot
.688 .41299 Mdot
.688 .41311 Mdot
.688 .41316 Mdot
.688 .41318 Mdot
.688 .41341 Mdot
.688 .41347 Mdot
.688 .41365 Mdot
.688 .41366 Mdot
.688 .41401 Mdot
.688 .41408 Mdot
.688 .41423 Mdot
.688 .41434 Mdot
.688 .4144 Mdot
.688 .41444 Mdot
.688 .41451 Mdot
.688 .41457 Mdot
.688 .41472 Mdot
.688 .41474 Mdot
.688 .4148 Mdot
.688 .41483 Mdot
.688 .41486 Mdot
.688 .41497 Mdot
.688 .415 Mdot
.688 .41502 Mdot
.688 .41509 Mdot
.688 .41511 Mdot
.688 .41518 Mdot
.688 .41522 Mdot
.688 .41546 Mdot
.688 .41549 Mdot
.688 .41566 Mdot
.688 .41575 Mdot
.688 .41577 Mdot
.688 .41581 Mdot
.688 .4159 Mdot
.688 .4159 Mdot
.688 .41595 Mdot
.688 .41595 Mdot
.688 .41605 Mdot
.688 .4161 Mdot
.688 .41622 Mdot
.688 .41622 Mdot
.688 .41626 Mdot
.688 .41631 Mdot
.688 .41636 Mdot
.688 .41639 Mdot
.688 .41648 Mdot
.688 .41652 Mdot
.688 .41655 Mdot
.688 .41676 Mdot
.688 .41684 Mdot
.688 .41695 Mdot
.688 .41695 Mdot
.688 .417 Mdot
.688 .41713 Mdot
.688 .41714 Mdot
.688 .41715 Mdot
.688 .41722 Mdot
.688 .41722 Mdot
.688 .41722 Mdot
.688 .41727 Mdot
.688 .41732 Mdot
.688 .41733 Mdot
.688 .41739 Mdot
.688 .41749 Mdot
.688 .41757 Mdot
.688 .4176 Mdot
.688 .4176 Mdot
.688 .41761 Mdot
.688 .41765 Mdot
.688 .41768 Mdot
.688 .41776 Mdot
.688 .4178 Mdot
.688 .41787 Mdot
.688 .41792 Mdot
.688 .41793 Mdot
.688 .41795 Mdot
.688 .41807 Mdot
.688 .41809 Mdot
.688 .41822 Mdot
.688 .41843 Mdot
.688 .41852 Mdot
.688 .41854 Mdot
.688 .41856 Mdot
.688 .41859 Mdot
.688 .41861 Mdot
.688 .41863 Mdot
.688 .41866 Mdot
.688 .4187 Mdot
.688 .41885 Mdot
.688 .41886 Mdot
.688 .41887 Mdot
.688 .41889 Mdot
.688 .41894 Mdot
.688 .41895 Mdot
.688 .41906 Mdot
.688 .41912 Mdot
.688 .4193 Mdot
.688 .41933 Mdot
.688 .41934 Mdot
.688 .41936 Mdot
.688 .41937 Mdot
.688 .41941 Mdot
.688 .41943 Mdot
.688 .41947 Mdot
.688 .41951 Mdot
.688 .41952 Mdot
.688 .41953 Mdot
.688 .41958 Mdot
.688 .41959 Mdot
.688 .41959 Mdot
.688 .4196 Mdot
.688 .41962 Mdot
.688 .41962 Mdot
.688 .41967 Mdot
.688 .41968 Mdot
.688 .41968 Mdot
.688 .41968 Mdot
.688 .41968 Mdot
.688 .41973 Mdot
.688 .41973 Mdot
.688 .41975 Mdot
.688 .41976 Mdot
.688 .41978 Mdot
.688 .41979 Mdot
.688 .4198 Mdot
.688 .4198 Mdot
.688 .4198 Mdot
.688 .41981 Mdot
.69 .30924 Mdot
.69 .30925 Mdot
.69 .30936 Mdot
.69 .30937 Mdot
.69 .30949 Mdot
.69 .30949 Mdot
.69 .30967 Mdot
.69 .30979 Mdot
.69 .3098 Mdot
.69 .30981 Mdot
.69 .30982 Mdot
.69 .31005 Mdot
.69 .31033 Mdot
.69 .31033 Mdot
.69 .31069 Mdot
.69 .31096 Mdot
.69 .31098 Mdot
.69 .31098 Mdot
.69 .31098 Mdot
.69 .31101 Mdot
.69 .31103 Mdot
.69 .3111 Mdot
.69 .31113 Mdot
.69 .3112 Mdot
.69 .31137 Mdot
.69 .31147 Mdot
.69 .31152 Mdot
.69 .31153 Mdot
.69 .31157 Mdot
.69 .31177 Mdot
.69 .31186 Mdot
.69 .31192 Mdot
.69 .31192 Mdot
.69 .31199 Mdot
.69 .312 Mdot
.69 .31228 Mdot
.69 .31232 Mdot
.69 .31239 Mdot
.69 .31258 Mdot
.69 .31281 Mdot
.69 .31287 Mdot
.69 .31297 Mdot
.69 .31303 Mdot
.69 .31309 Mdot
.69 .31311 Mdot
.69 .31318 Mdot
.69 .3132 Mdot
.69 .31345 Mdot
.69 .31346 Mdot
.69 .31365 Mdot
.69 .31368 Mdot
.69 .31378 Mdot
.69 .31385 Mdot
.69 .31398 Mdot
.69 .31399 Mdot
.69 .31417 Mdot
.69 .31418 Mdot
.69 .31428 Mdot
.69 .31429 Mdot
.69 .31431 Mdot
.69 .31437 Mdot
.69 .31439 Mdot
.69 .31453 Mdot
.69 .31488 Mdot
.69 .31492 Mdot
.69 .31493 Mdot
.69 .31501 Mdot
.69 .31524 Mdot
.69 .3155 Mdot
.69 .31551 Mdot
.69 .31561 Mdot
.69 .31576 Mdot
.69 .31582 Mdot
.69 .31606 Mdot
.69 .31657 Mdot
.69 .31673 Mdot
.69 .31681 Mdot
.69 .31691 Mdot
.69 .31701 Mdot
.69 .31706 Mdot
.69 .3172 Mdot
.69 .31726 Mdot
.69 .31736 Mdot
.69 .31738 Mdot
.69 .3174 Mdot
.69 .31744 Mdot
.69 .31745 Mdot
.69 .31752 Mdot
.69 .31765 Mdot
.69 .31799 Mdot
.69 .31803 Mdot
.69 .31834 Mdot
.69 .31837 Mdot
.69 .31851 Mdot
.69 .31893 Mdot
.69 .319 Mdot
.69 .31903 Mdot
.69 .31903 Mdot
.69 .31923 Mdot
.69 .31927 Mdot
.69 .31935 Mdot
.69 .31974 Mdot
.69 .31995 Mdot
.69 .32033 Mdot
.69 .32035 Mdot
.69 .32053 Mdot
.69 .32057 Mdot
.69 .32137 Mdot
.69 .32203 Mdot
.69 .32231 Mdot
.69 .32237 Mdot
.69 .32252 Mdot
.69 .32252 Mdot
.69 .32267 Mdot
.69 .32344 Mdot
.69 .32393 Mdot
.69 .32455 Mdot
.69 .32491 Mdot
.69 .32491 Mdot
.69 .32528 Mdot
.69 .32534 Mdot
.69 .32539 Mdot
.69 .32539 Mdot
.69 .32546 Mdot
.69 .3257 Mdot
.69 .32677 Mdot
.69 .32734 Mdot
.69 .32758 Mdot
.69 .32759 Mdot
.69 .32806 Mdot
.69 .32869 Mdot
.69 .3291 Mdot
.69 .32935 Mdot
.69 .33091 Mdot
.69 .33127 Mdot
.69 .33198 Mdot
.69 .33236 Mdot
.69 .3329 Mdot
.69 .3329 Mdot
.69 .33336 Mdot
.69 .33348 Mdot
.69 .33373 Mdot
.69 .334 Mdot
.69 .33431 Mdot
.69 .33494 Mdot
.69 .33512 Mdot
.69 .33523 Mdot
.69 .33537 Mdot
.69 .33606 Mdot
.69 .3361 Mdot
.69 .33644 Mdot
.69 .33667 Mdot
.69 .33681 Mdot
.69 .33719 Mdot
.69 .33731 Mdot
.69 .3376 Mdot
.69 .33771 Mdot
.69 .33817 Mdot
.69 .33835 Mdot
.69 .33843 Mdot
.69 .33854 Mdot
.69 .33863 Mdot
.69 .33941 Mdot
.69 .33954 Mdot
.69 .33962 Mdot
.69 .33968 Mdot
.69 .33976 Mdot
.69 .34037 Mdot
.69 .34044 Mdot
.69 .34055 Mdot
.69 .34092 Mdot
.69 .34102 Mdot
.69 .34104 Mdot
.69 .34184 Mdot
.69 .34185 Mdot
.69 .34189 Mdot
.69 .34265 Mdot
.69 .34359 Mdot
.69 .34366 Mdot
.69 .34376 Mdot
.69 .3438 Mdot
.69 .34397 Mdot
.69 .34401 Mdot
.69 .34433 Mdot
.69 .34446 Mdot
.69 .3447 Mdot
.69 .34491 Mdot
.69 .34494 Mdot
.69 .34537 Mdot
.69 .34562 Mdot
.69 .34575 Mdot
.69 .34682 Mdot
.69 .34687 Mdot
.69 .34731 Mdot
.69 .34731 Mdot
.69 .34784 Mdot
.69 .34797 Mdot
.69 .348 Mdot
.69 .34812 Mdot
.69 .34823 Mdot
.69 .34846 Mdot
.69 .34876 Mdot
.69 .34885 Mdot
.69 .34889 Mdot
.69 .34912 Mdot
.69 .34925 Mdot
.69 .34966 Mdot
.69 .35025 Mdot
.69 .35082 Mdot
.69 .35092 Mdot
.69 .35125 Mdot
.69 .35147 Mdot
.69 .35171 Mdot
.69 .35171 Mdot
.69 .35184 Mdot
.69 .35193 Mdot
.69 .35193 Mdot
.69 .35193 Mdot
.69 .35195 Mdot
.69 .352 Mdot
.69 .35205 Mdot
.69 .35209 Mdot
.69 .35215 Mdot
.69 .35218 Mdot
.69 .35228 Mdot
.69 .35231 Mdot
.69 .35241 Mdot
.69 .35243 Mdot
.69 .35253 Mdot
.69 .35253 Mdot
.69 .35257 Mdot
.69 .35257 Mdot
.69 .35261 Mdot
.69 .35263 Mdot
.69 .35269 Mdot
.69 .35269 Mdot
.69 .35271 Mdot
.69 .35279 Mdot
.69 .35293 Mdot
.69 .35308 Mdot
.69 .35309 Mdot
.69 .35311 Mdot
.69 .35312 Mdot
.69 .35315 Mdot
.69 .35316 Mdot
.69 .35317 Mdot
.69 .35318 Mdot
.69 .35318 Mdot
.69 .35319 Mdot
.69 .3532 Mdot
.69 .36629 Mdot
.69 .36742 Mdot
.69 .36857 Mdot
.69 .3686 Mdot
.69 .36861 Mdot
.69 .36863 Mdot
.69 .36864 Mdot
.69 .36869 Mdot
.69 .36871 Mdot
.69 .3688 Mdot
.69 .36884 Mdot
.69 .36889 Mdot
.69 .36892 Mdot
.69 .36924 Mdot
.69 .36938 Mdot
.69 .36982 Mdot
.69 .37008 Mdot
.69 .37012 Mdot
.69 .37013 Mdot
.69 .3702 Mdot
.69 .3703 Mdot
.69 .37038 Mdot
.69 .37047 Mdot
.69 .37049 Mdot
.69 .3706 Mdot
.69 .37061 Mdot
.69 .37089 Mdot
.69 .37096 Mdot
.69 .37127 Mdot
.69 .37134 Mdot
.69 .37164 Mdot
.69 .37171 Mdot
.69 .37186 Mdot
.69 .3719 Mdot
.69 .37203 Mdot
.69 .37216 Mdot
.69 .37231 Mdot
.69 .37233 Mdot
.69 .37236 Mdot
.69 .37236 Mdot
.69 .37237 Mdot
.69 .37263 Mdot
.69 .373 Mdot
.69 .373 Mdot
.69 .37366 Mdot
.69 .37368 Mdot
.69 .37369 Mdot
.69 .37371 Mdot
.69 .37426 Mdot
.69 .37457 Mdot
.69 .37516 Mdot
.69 .37543 Mdot
.69 .37619 Mdot
.69 .37654 Mdot
.69 .37689 Mdot
.69 .37743 Mdot
.69 .37834 Mdot
.69 .37844 Mdot
.69 .37847 Mdot
.69 .37872 Mdot
.69 .37876 Mdot
.69 .37903 Mdot
.69 .37903 Mdot
.69 .37908 Mdot
.69 .37909 Mdot
.69 .37929 Mdot
.69 .37945 Mdot
.69 .37958 Mdot
.69 .3797 Mdot
.69 .37973 Mdot
.69 .37974 Mdot
.69 .37978 Mdot
.69 .37979 Mdot
.69 .3801 Mdot
.69 .3802 Mdot
.69 .38029 Mdot
.69 .38034 Mdot
.69 .38038 Mdot
.69 .38046 Mdot
.69 .38063 Mdot
.69 .38063 Mdot
.69 .38067 Mdot
.69 .38077 Mdot
.69 .38088 Mdot
.69 .38089 Mdot
.69 .38093 Mdot
.69 .38102 Mdot
.69 .38132 Mdot
.69 .38151 Mdot
.69 .38163 Mdot
.69 .38172 Mdot
.69 .38184 Mdot
.69 .38186 Mdot
.69 .38197 Mdot
.69 .38198 Mdot
.69 .38203 Mdot
.69 .38217 Mdot
.69 .38219 Mdot
.69 .3822 Mdot
.69 .3822 Mdot
.69 .38227 Mdot
.69 .38228 Mdot
.69 .38231 Mdot
.69 .38243 Mdot
.69 .3825 Mdot
.69 .38263 Mdot
.69 .38268 Mdot
.69 .38269 Mdot
.69 .38294 Mdot
.69 .38313 Mdot
.69 .38321 Mdot
.69 .38323 Mdot
.69 .38327 Mdot
.69 .38327 Mdot
.69 .38332 Mdot
.69 .38366 Mdot
.69 .38383 Mdot
.69 .38392 Mdot
.69 .38392 Mdot
.69 .38402 Mdot
.69 .38403 Mdot
.69 .38404 Mdot
.69 .38404 Mdot
.69 .38406 Mdot
.69 .38412 Mdot
.69 .38439 Mdot
.69 .38453 Mdot
.69 .38459 Mdot
.69 .38459 Mdot
.69 .3847 Mdot
.69 .38485 Mdot
.69 .38494 Mdot
.69 .385 Mdot
.69 .38535 Mdot
.69 .38543 Mdot
.69 .38558 Mdot
.69 .38566 Mdot
.69 .38575 Mdot
.69 .38578 Mdot
.69 .38578 Mdot
.69 .38587 Mdot
.69 .3859 Mdot
.69 .38595 Mdot
.69 .386 Mdot
.69 .38607 Mdot
.69 .3862 Mdot
.69 .38623 Mdot
.69 .38625 Mdot
.69 .38628 Mdot
.69 .38642 Mdot
.69 .38643 Mdot
.69 .38649 Mdot
.69 .38654 Mdot
.69 .38656 Mdot
.69 .38664 Mdot
.69 .38666 Mdot
.69 .38672 Mdot
.69 .38674 Mdot
.69 .38683 Mdot
.69 .38686 Mdot
.69 .38688 Mdot
.69 .3869 Mdot
.69 .38691 Mdot
.69 .38706 Mdot
.69 .38708 Mdot
.69 .3871 Mdot
.69 .38711 Mdot
.69 .38713 Mdot
.69 .38724 Mdot
.69 .38725 Mdot
.69 .38727 Mdot
.69 .38734 Mdot
.69 .38736 Mdot
.69 .38736 Mdot
.69 .3875 Mdot
.69 .38751 Mdot
.69 .38751 Mdot
.69 .38765 Mdot
.69 .38781 Mdot
.69 .38783 Mdot
.69 .38784 Mdot
.69 .38785 Mdot
.69 .38788 Mdot
.69 .38789 Mdot
.69 .38794 Mdot
.69 .38797 Mdot
.69 .38801 Mdot
.69 .38804 Mdot
.69 .38805 Mdot
.69 .38812 Mdot
.69 .38817 Mdot
.69 .38819 Mdot
.69 .38837 Mdot
.69 .38838 Mdot
.69 .38845 Mdot
.69 .38845 Mdot
.69 .38854 Mdot
.69 .38856 Mdot
.69 .38857 Mdot
.69 .38859 Mdot
.69 .3886 Mdot
.69 .38864 Mdot
.69 .38869 Mdot
.69 .38871 Mdot
.69 .38871 Mdot
.69 .38875 Mdot
.69 .38877 Mdot
.69 .38884 Mdot
.69 .38894 Mdot
.69 .38903 Mdot
.69 .38905 Mdot
.69 .3891 Mdot
.69 .38913 Mdot
.69 .38917 Mdot
.69 .38917 Mdot
.69 .38919 Mdot
.69 .38921 Mdot
.69 .38921 Mdot
.69 .38921 Mdot
.69 .38921 Mdot
.69 .38922 Mdot
.69 .38923 Mdot
.69 .38923 Mdot
.69 .38924 Mdot
.69 .38925 Mdot
.69 .38926 Mdot
.69 .38927 Mdot
.69 .38928 Mdot
.69 .38929 Mdot
.69 .3893 Mdot
.69 .3893 Mdot
.69 .38931 Mdot
.69 .38931 Mdot
.69 .38932 Mdot
.69 .38932 Mdot
.69 .38933 Mdot
.69 .38933 Mdot
.69 .38933 Mdot
.69 .38934 Mdot
.69 .38937 Mdot
.69 .38939 Mdot
.69 .38939 Mdot
.69 .3894 Mdot
.69 .3894 Mdot
.69 .3894 Mdot
.69 .3894 Mdot
.69 .38941 Mdot
.69 .38941 Mdot
.69 .38941 Mdot
.69 .38941 Mdot
.69 .38941 Mdot
.69 .39809 Mdot
.69 .39809 Mdot
.69 .39809 Mdot
.69 .39809 Mdot
.69 .39809 Mdot
.69 .39809 Mdot
.69 .39809 Mdot
.69 .39809 Mdot
.69 .39809 Mdot
.69 .39809 Mdot
.69 .3981 Mdot
.69 .3981 Mdot
.69 .39811 Mdot
.69 .39812 Mdot
.69 .39812 Mdot
.69 .39812 Mdot
.69 .39812 Mdot
.69 .39812 Mdot
.69 .39812 Mdot
.69 .39812 Mdot
.69 .39813 Mdot
.69 .39813 Mdot
.69 .39813 Mdot
.69 .39813 Mdot
.69 .39814 Mdot
.69 .39814 Mdot
.69 .39815 Mdot
.69 .39815 Mdot
.69 .39815 Mdot
.69 .39815 Mdot
.69 .39816 Mdot
.69 .39816 Mdot
.69 .39816 Mdot
.69 .39816 Mdot
.69 .39816 Mdot
.69 .39817 Mdot
.69 .39817 Mdot
.69 .39817 Mdot
.69 .39819 Mdot
.69 .3982 Mdot
.69 .39822 Mdot
.69 .39823 Mdot
.69 .39826 Mdot
.69 .39829 Mdot
.69 .39832 Mdot
.69 .39832 Mdot
.69 .39834 Mdot
.69 .39834 Mdot
.69 .39835 Mdot
.69 .39836 Mdot
.69 .39838 Mdot
.69 .39838 Mdot
.69 .39839 Mdot
.69 .39839 Mdot
.69 .3984 Mdot
.69 .39843 Mdot
.69 .39843 Mdot
.69 .39846 Mdot
.69 .39846 Mdot
.69 .39852 Mdot
.69 .39853 Mdot
.69 .39855 Mdot
.69 .39857 Mdot
.69 .39858 Mdot
.69 .39859 Mdot
.69 .3986 Mdot
.69 .39861 Mdot
.69 .39863 Mdot
.69 .39863 Mdot
.69 .39864 Mdot
.69 .39865 Mdot
.69 .39865 Mdot
.69 .39866 Mdot
.69 .39871 Mdot
.69 .39876 Mdot
.69 .39876 Mdot
.69 .39877 Mdot
.69 .39882 Mdot
.69 .39882 Mdot
.69 .39882 Mdot
.69 .39885 Mdot
.69 .39885 Mdot
.69 .39886 Mdot
.69 .3989 Mdot
.69 .3989 Mdot
.69 .39891 Mdot
.69 .39891 Mdot
.69 .39892 Mdot
.69 .39897 Mdot
.69 .39898 Mdot
.69 .39898 Mdot
.69 .39899 Mdot
.69 .399 Mdot
.69 .39903 Mdot
.69 .39904 Mdot
.69 .39906 Mdot
.69 .39907 Mdot
.69 .39909 Mdot
.69 .3991 Mdot
.69 .39912 Mdot
.69 .39914 Mdot
.69 .39914 Mdot
.69 .39919 Mdot
.69 .3992 Mdot
.69 .39921 Mdot
.69 .39922 Mdot
.69 .39927 Mdot
.69 .39929 Mdot
.69 .39931 Mdot
.69 .39932 Mdot
.69 .39933 Mdot
.69 .39936 Mdot
.69 .39936 Mdot
.69 .39937 Mdot
.69 .3994 Mdot
.69 .39943 Mdot
.69 .39948 Mdot
.69 .39951 Mdot
.69 .39963 Mdot
.69 .39965 Mdot
.69 .39968 Mdot
.69 .39973 Mdot
.69 .39977 Mdot
.69 .39977 Mdot
.69 .39979 Mdot
.69 .39984 Mdot
.69 .39993 Mdot
.69 .39995 Mdot
.69 .39995 Mdot
.69 .39995 Mdot
.69 .39996 Mdot
.69 .39996 Mdot
.69 .4 Mdot
.69 .4 Mdot
.69 .40003 Mdot
.69 .40008 Mdot
.69 .4002 Mdot
.69 .40021 Mdot
.69 .40021 Mdot
.69 .40023 Mdot
.69 .40023 Mdot
.69 .40026 Mdot
.69 .40032 Mdot
.69 .4004 Mdot
.69 .40041 Mdot
.69 .40043 Mdot
.69 .40047 Mdot
.69 .40049 Mdot
.69 .40053 Mdot
.69 .40054 Mdot
.69 .40055 Mdot
.69 .40057 Mdot
.69 .40057 Mdot
.69 .40057 Mdot
.69 .40058 Mdot
.69 .40063 Mdot
.69 .40064 Mdot
.69 .40064 Mdot
.69 .40068 Mdot
.69 .40069 Mdot
.69 .40073 Mdot
.69 .40076 Mdot
.69 .4008 Mdot
.69 .40086 Mdot
.69 .40096 Mdot
.69 .40099 Mdot
.69 .401 Mdot
.69 .401 Mdot
.69 .40104 Mdot
.69 .40107 Mdot
.69 .40108 Mdot
.69 .40108 Mdot
.69 .40114 Mdot
.69 .40116 Mdot
.69 .40118 Mdot
.69 .40119 Mdot
.69 .40122 Mdot
.69 .40126 Mdot
.69 .40135 Mdot
.69 .40136 Mdot
.69 .40137 Mdot
.69 .40137 Mdot
.69 .40138 Mdot
.69 .40142 Mdot
.69 .40147 Mdot
.69 .40152 Mdot
.69 .40158 Mdot
.69 .40158 Mdot
.69 .4016 Mdot
.69 .4016 Mdot
.69 .40169 Mdot
.69 .4017 Mdot
.69 .40178 Mdot
.69 .40179 Mdot
.69 .40182 Mdot
.69 .40211 Mdot
.69 .40228 Mdot
.69 .40239 Mdot
.69 .4025 Mdot
.69 .40273 Mdot
.69 .40282 Mdot
.69 .403 Mdot
.69 .40309 Mdot
.69 .40326 Mdot
.69 .40327 Mdot
.69 .40327 Mdot
.69 .40328 Mdot
.69 .40348 Mdot
.69 .40348 Mdot
.69 .40359 Mdot
.69 .40367 Mdot
.69 .40367 Mdot
.69 .40368 Mdot
.69 .40368 Mdot
.69 .40369 Mdot
.69 .40373 Mdot
.69 .40378 Mdot
.69 .40381 Mdot
.69 .40382 Mdot
.69 .40387 Mdot
.69 .40389 Mdot
.69 .40398 Mdot
.69 .404 Mdot
.69 .4041 Mdot
.69 .40412 Mdot
.69 .4042 Mdot
.69 .4042 Mdot
.69 .40424 Mdot
.69 .40424 Mdot
.69 .40427 Mdot
.69 .40429 Mdot
.69 .40434 Mdot
.69 .40435 Mdot
.69 .40436 Mdot
.69 .40444 Mdot
.69 .40457 Mdot
.69 .40461 Mdot
.69 .4047 Mdot
.69 .40471 Mdot
.69 .40473 Mdot
.69 .40474 Mdot
.69 .40477 Mdot
.69 .40477 Mdot
.69 .40479 Mdot
.69 .40479 Mdot
.69 .4048 Mdot
.69 .4048 Mdot
.69 .40481 Mdot
.69 .40515 Mdot
.69 .40548 Mdot
.69 .40918 Mdot
.69 .40918 Mdot
.69 .40918 Mdot
.69 .40918 Mdot
.69 .40918 Mdot
.69 .40919 Mdot
.69 .40919 Mdot
.69 .4092 Mdot
.69 .4092 Mdot
.69 .40921 Mdot
.69 .40921 Mdot
.69 .40925 Mdot
.69 .40929 Mdot
.69 .40931 Mdot
.69 .40932 Mdot
.69 .40932 Mdot
.69 .40933 Mdot
.69 .40934 Mdot
.69 .40935 Mdot
.69 .40935 Mdot
.69 .40936 Mdot
.69 .40936 Mdot
.69 .40939 Mdot
.69 .40939 Mdot
.69 .40942 Mdot
.69 .40943 Mdot
.69 .40946 Mdot
.69 .40946 Mdot
.69 .40948 Mdot
.69 .40949 Mdot
.69 .40951 Mdot
.69 .40952 Mdot
.69 .40953 Mdot
.69 .40953 Mdot
.69 .40953 Mdot
.69 .40955 Mdot
.69 .40959 Mdot
.69 .40959 Mdot
.69 .40965 Mdot
.69 .40971 Mdot
.69 .4098 Mdot
.69 .40983 Mdot
.69 .40998 Mdot
.69 .41015 Mdot
.69 .41026 Mdot
.69 .41029 Mdot
.69 .41036 Mdot
.69 .41037 Mdot
.69 .41039 Mdot
.69 .41047 Mdot
.69 .41054 Mdot
.69 .41057 Mdot
.69 .4106 Mdot
.69 .41061 Mdot
.69 .41064 Mdot
.69 .41079 Mdot
.69 .41079 Mdot
.69 .4109 Mdot
.69 .41092 Mdot
.69 .41121 Mdot
.69 .41124 Mdot
.69 .41131 Mdot
.69 .41143 Mdot
.69 .41143 Mdot
.69 .41149 Mdot
.69 .41155 Mdot
.69 .41159 Mdot
.69 .41168 Mdot
.69 .41169 Mdot
.69 .41173 Mdot
.69 .41174 Mdot
.69 .41177 Mdot
.69 .41179 Mdot
.69 .41204 Mdot
.69 .41224 Mdot
.69 .41226 Mdot
.69 .41226 Mdot
.69 .41247 Mdot
.69 .41248 Mdot
.69 .4125 Mdot
.69 .4126 Mdot
.69 .41263 Mdot
.69 .41265 Mdot
.69 .41281 Mdot
.69 .41284 Mdot
.69 .41285 Mdot
.69 .41287 Mdot
.69 .41291 Mdot
.69 .41312 Mdot
.69 .41314 Mdot
.69 .41317 Mdot
.69 .41319 Mdot
.69 .41324 Mdot
.69 .41336 Mdot
.69 .41339 Mdot
.69 .41347 Mdot
.69 .4135 Mdot
.69 .4136 Mdot
.69 .41364 Mdot
.69 .4137 Mdot
.69 .41379 Mdot
.69 .4138 Mdot
.69 .41399 Mdot
.69 .41402 Mdot
.69 .41405 Mdot
.69 .4141 Mdot
.69 .41427 Mdot
.69 .41435 Mdot
.69 .41442 Mdot
.69 .41449 Mdot
.69 .41452 Mdot
.69 .41464 Mdot
.69 .41464 Mdot
.69 .41479 Mdot
.69 .41489 Mdot
.69 .41507 Mdot
.69 .41517 Mdot
.69 .41558 Mdot
.69 .41565 Mdot
.69 .41576 Mdot
.69 .41593 Mdot
.69 .41605 Mdot
.69 .41605 Mdot
.69 .41612 Mdot
.69 .41627 Mdot
.69 .41655 Mdot
.69 .41662 Mdot
.69 .41664 Mdot
.69 .41664 Mdot
.69 .41665 Mdot
.69 .41667 Mdot
.69 .41676 Mdot
.69 .41677 Mdot
.69 .41686 Mdot
.69 .41703 Mdot
.69 .41716 Mdot
.69 .41736 Mdot
.69 .4174 Mdot
.69 .4174 Mdot
.69 .41744 Mdot
.69 .41746 Mdot
.69 .41753 Mdot
.69 .41771 Mdot
.69 .41792 Mdot
.69 .41793 Mdot
.69 .41798 Mdot
.69 .41799 Mdot
.69 .41809 Mdot
.69 .41814 Mdot
.69 .41825 Mdot
.69 .41827 Mdot
.69 .41828 Mdot
.69 .41833 Mdot
.69 .41833 Mdot
.69 .41834 Mdot
.69 .41836 Mdot
.69 .41847 Mdot
.69 .41851 Mdot
.69 .41852 Mdot
.69 .4186 Mdot
.69 .41861 Mdot
.69 .41871 Mdot
.69 .41874 Mdot
.69 .41876 Mdot
.69 .41876 Mdot
.69 .41877 Mdot
.69 .41878 Mdot
.69 .41878 Mdot
.69 .41881 Mdot
.69 .41883 Mdot
.69 .41886 Mdot
.69 .41888 Mdot
.69 .4189 Mdot
.69 .41893 Mdot
.69 .41895 Mdot
.69 .419 Mdot
.69 .41913 Mdot
.69 .4192 Mdot
.69 .41921 Mdot
.69 .41926 Mdot
.69 .41928 Mdot
.69 .41928 Mdot
.69 .41935 Mdot
.69 .41942 Mdot
.69 .41944 Mdot
.69 .41944 Mdot
.69 .41945 Mdot
.69 .41955 Mdot
.69 .41958 Mdot
.69 .41959 Mdot
.69 .41961 Mdot
.69 .41961 Mdot
.69 .41961 Mdot
.69 .41964 Mdot
.69 .41964 Mdot
.69 .41969 Mdot
.69 .41969 Mdot
.69 .41973 Mdot
.69 .41975 Mdot
.69 .41978 Mdot
.69 .41978 Mdot
.69 .41984 Mdot
.69 .41984 Mdot
.69 .41991 Mdot
.69 .41991 Mdot
.69 .41993 Mdot
.69 .41994 Mdot
.69 .41995 Mdot
.69 .41997 Mdot
.69 .42 Mdot
.69 .42001 Mdot
.69 .42007 Mdot
.69 .42013 Mdot
.69 .42015 Mdot
.69 .42015 Mdot
.69 .42023 Mdot
.69 .42023 Mdot
.69 .42025 Mdot
.69 .42025 Mdot
.69 .42027 Mdot
.69 .42029 Mdot
.69 .42035 Mdot
.69 .42036 Mdot
.69 .42036 Mdot
.69 .42038 Mdot
.69 .4204 Mdot
.69 .42045 Mdot
.69 .42047 Mdot
.69 .42048 Mdot
.69 .4205 Mdot
.69 .4205 Mdot
.69 .42051 Mdot
.69 .42051 Mdot
.69 .42051 Mdot
.69 .42051 Mdot
.69 .42059 Mdot
.69 .42069 Mdot
.69 .42069 Mdot
.69 .42076 Mdot
.69 .42083 Mdot
.69 .42083 Mdot
.69 .42083 Mdot
.69 .42084 Mdot
.69 .42087 Mdot
.69 .42092 Mdot
.69 .42092 Mdot
.69 .42095 Mdot
.69 .42095 Mdot
.69 .42098 Mdot
.69 .42099 Mdot
.692 .30583 Mdot
.692 .30584 Mdot
.692 .30584 Mdot
.692 .30586 Mdot
.692 .30587 Mdot
.692 .30588 Mdot
.692 .3059 Mdot
.692 .3059 Mdot
.692 .3059 Mdot
.692 .30591 Mdot
.692 .30592 Mdot
.692 .30593 Mdot
.692 .30593 Mdot
.692 .30595 Mdot
.692 .30597 Mdot
.692 .30601 Mdot
.692 .30605 Mdot
.692 .30614 Mdot
.692 .30618 Mdot
.692 .30627 Mdot
.692 .30627 Mdot
.692 .30629 Mdot
.692 .30634 Mdot
.692 .30636 Mdot
.692 .30638 Mdot
.692 .30642 Mdot
.692 .30654 Mdot
.692 .30662 Mdot
.692 .30665 Mdot
.692 .30666 Mdot
.692 .30687 Mdot
.692 .30688 Mdot
.692 .30693 Mdot
.692 .30705 Mdot
.692 .30732 Mdot
.692 .30734 Mdot
.692 .30738 Mdot
.692 .30741 Mdot
.692 .3076 Mdot
.692 .30766 Mdot
.692 .30768 Mdot
.692 .30812 Mdot
.692 .30822 Mdot
.692 .30823 Mdot
.692 .30828 Mdot
.692 .30834 Mdot
.692 .30837 Mdot
.692 .30838 Mdot
.692 .30853 Mdot
.692 .3086 Mdot
.692 .30917 Mdot
.692 .30924 Mdot
.692 .30925 Mdot
.692 .30931 Mdot
.692 .30932 Mdot
.692 .30934 Mdot
.692 .30945 Mdot
.692 .3096 Mdot
.692 .30966 Mdot
.692 .30967 Mdot
.692 .30971 Mdot
.692 .31021 Mdot
.692 .31023 Mdot
.692 .31033 Mdot
.692 .31056 Mdot
.692 .31057 Mdot
.692 .31086 Mdot
.692 .31095 Mdot
.692 .31109 Mdot
.692 .31177 Mdot
.692 .31202 Mdot
.692 .31206 Mdot
.692 .31209 Mdot
.692 .31215 Mdot
.692 .31233 Mdot
.692 .31238 Mdot
.692 .31266 Mdot
.692 .31274 Mdot
.692 .31281 Mdot
.692 .31314 Mdot
.692 .31318 Mdot
.692 .31331 Mdot
.692 .31349 Mdot
.692 .31351 Mdot
.692 .31353 Mdot
.692 .31368 Mdot
.692 .31373 Mdot
.692 .31374 Mdot
.692 .31427 Mdot
.692 .31429 Mdot
.692 .31435 Mdot
.692 .31453 Mdot
.692 .31468 Mdot
.692 .31484 Mdot
.692 .31497 Mdot
.692 .31514 Mdot
.692 .31525 Mdot
.692 .31548 Mdot
.692 .31563 Mdot
.692 .31576 Mdot
.692 .31588 Mdot
.692 .31611 Mdot
.692 .31618 Mdot
.692 .31629 Mdot
.692 .31631 Mdot
.692 .3166 Mdot
.692 .31696 Mdot
.692 .31702 Mdot
.692 .31734 Mdot
.692 .31742 Mdot
.692 .31744 Mdot
.692 .31756 Mdot
.692 .31796 Mdot
.692 .31799 Mdot
.692 .31809 Mdot
.692 .31838 Mdot
.692 .31844 Mdot
.692 .31872 Mdot
.692 .31877 Mdot
.692 .31877 Mdot
.692 .31893 Mdot
.692 .31913 Mdot
.692 .31916 Mdot
.692 .31925 Mdot
.692 .31932 Mdot
.692 .31937 Mdot
.692 .31941 Mdot
.692 .31944 Mdot
.692 .31951 Mdot
.692 .31957 Mdot
.692 .31957 Mdot
.692 .31962 Mdot
.692 .31971 Mdot
.692 .31976 Mdot
.692 .31993 Mdot
.692 .31996 Mdot
.692 .31999 Mdot
.692 .32001 Mdot
.692 .32003 Mdot
.692 .32013 Mdot
.692 .32033 Mdot
.692 .32036 Mdot
.692 .32038 Mdot
.692 .32082 Mdot
.692 .32104 Mdot
.692 .32131 Mdot
.692 .32142 Mdot
.692 .32168 Mdot
.692 .32174 Mdot
.692 .32189 Mdot
.692 .32192 Mdot
.692 .32201 Mdot
.692 .3221 Mdot
.692 .32214 Mdot
.692 .32225 Mdot
.692 .32225 Mdot
.692 .32267 Mdot
.692 .32281 Mdot
.692 .32289 Mdot
.692 .32294 Mdot
.692 .32302 Mdot
.692 .32328 Mdot
.692 .32336 Mdot
.692 .32373 Mdot
.692 .32416 Mdot
.692 .32419 Mdot
.692 .32453 Mdot
.692 .32459 Mdot
.692 .32464 Mdot
.692 .32479 Mdot
.692 .32488 Mdot
.692 .32504 Mdot
.692 .32556 Mdot
.692 .32582 Mdot
.692 .32606 Mdot
.692 .32608 Mdot
.692 .32621 Mdot
.692 .32623 Mdot
.692 .32651 Mdot
.692 .32653 Mdot
.692 .32657 Mdot
.692 .32705 Mdot
.692 .32735 Mdot
.692 .32737 Mdot
.692 .32741 Mdot
.692 .32755 Mdot
.692 .32758 Mdot
.692 .32782 Mdot
.692 .3281 Mdot
.692 .32815 Mdot
.692 .32872 Mdot
.692 .32882 Mdot
.692 .32887 Mdot
.692 .32888 Mdot
.692 .32893 Mdot
.692 .32894 Mdot
.692 .32906 Mdot
.692 .32929 Mdot
.692 .32947 Mdot
.692 .32981 Mdot
.692 .33024 Mdot
.692 .33059 Mdot
.692 .33072 Mdot
.692 .3316 Mdot
.692 .33168 Mdot
.692 .33225 Mdot
.692 .33274 Mdot
.692 .3332 Mdot
.692 .33336 Mdot
.692 .33345 Mdot
.692 .33354 Mdot
.692 .33397 Mdot
.692 .33419 Mdot
.692 .33426 Mdot
.692 .33455 Mdot
.692 .33456 Mdot
.692 .33461 Mdot
.692 .33462 Mdot
.692 .33468 Mdot
.692 .33479 Mdot
.692 .33487 Mdot
.692 .33535 Mdot
.692 .33541 Mdot
.692 .33549 Mdot
.692 .33571 Mdot
.692 .33584 Mdot
.692 .33585 Mdot
.692 .33598 Mdot
.692 .33615 Mdot
.692 .3362 Mdot
.692 .33623 Mdot
.692 .33629 Mdot
.692 .33635 Mdot
.692 .33639 Mdot
.692 .33653 Mdot
.692 .33668 Mdot
.692 .33673 Mdot
.692 .3369 Mdot
.692 .337 Mdot
.692 .33702 Mdot
.692 .33703 Mdot
.692 .33718 Mdot
.692 .33721 Mdot
.692 .33721 Mdot
.692 .33726 Mdot
.692 .33745 Mdot
.692 .33746 Mdot
.692 .33747 Mdot
.692 .33748 Mdot
.692 .3375 Mdot
.692 .36319 Mdot
.692 .36367 Mdot
.692 .36474 Mdot
.692 .36478 Mdot
.692 .36529 Mdot
.692 .36533 Mdot
.692 .36555 Mdot
.692 .36563 Mdot
.692 .36582 Mdot
.692 .36627 Mdot
.692 .36627 Mdot
.692 .36629 Mdot
.692 .36629 Mdot
.692 .36635 Mdot
.692 .36637 Mdot
.692 .36642 Mdot
.692 .36647 Mdot
.692 .36648 Mdot
.692 .36649 Mdot
.692 .36651 Mdot
.692 .36654 Mdot
.692 .36657 Mdot
.692 .36658 Mdot
.692 .36665 Mdot
.692 .36671 Mdot
.692 .36672 Mdot
.692 .36683 Mdot
.692 .36696 Mdot
.692 .36724 Mdot
.692 .36736 Mdot
.692 .36763 Mdot
.692 .36764 Mdot
.692 .36769 Mdot
.692 .36785 Mdot
.692 .36791 Mdot
.692 .36797 Mdot
.692 .36811 Mdot
.692 .36823 Mdot
.692 .36847 Mdot
.692 .36871 Mdot
.692 .36873 Mdot
.692 .3688 Mdot
.692 .36881 Mdot
.692 .36882 Mdot
.692 .36896 Mdot
.692 .36945 Mdot
.692 .36948 Mdot
.692 .36964 Mdot
.692 .36999 Mdot
.692 .37007 Mdot
.692 .37077 Mdot
.692 .37085 Mdot
.692 .37094 Mdot
.692 .37102 Mdot
.692 .37103 Mdot
.692 .37112 Mdot
.692 .37156 Mdot
.692 .37167 Mdot
.692 .37175 Mdot
.692 .37179 Mdot
.692 .37179 Mdot
.692 .37187 Mdot
.692 .37224 Mdot
.692 .37251 Mdot
.692 .37296 Mdot
.692 .37302 Mdot
.692 .37329 Mdot
.692 .3733 Mdot
.692 .37344 Mdot
.692 .37361 Mdot
.692 .37368 Mdot
.692 .37371 Mdot
.692 .37409 Mdot
.692 .37429 Mdot
.692 .37449 Mdot
.692 .37463 Mdot
.692 .37475 Mdot
.692 .37481 Mdot
.692 .37572 Mdot
.692 .37574 Mdot
.692 .37577 Mdot
.692 .3759 Mdot
.692 .37593 Mdot
.692 .37607 Mdot
.692 .37609 Mdot
.692 .37611 Mdot
.692 .37614 Mdot
.692 .37618 Mdot
.692 .37625 Mdot
.692 .37641 Mdot
.692 .37677 Mdot
.692 .37693 Mdot
.692 .37693 Mdot
.692 .37696 Mdot
.692 .37704 Mdot
.692 .37743 Mdot
.692 .37771 Mdot
.692 .3779 Mdot
.692 .37815 Mdot
.692 .37817 Mdot
.692 .37823 Mdot
.692 .37839 Mdot
.692 .37844 Mdot
.692 .37894 Mdot
.692 .37896 Mdot
.692 .37912 Mdot
.692 .37951 Mdot
.692 .37951 Mdot
.692 .37956 Mdot
.692 .37975 Mdot
.692 .37975 Mdot
.692 .38004 Mdot
.692 .38005 Mdot
.692 .3801 Mdot
.692 .38021 Mdot
.692 .38022 Mdot
.692 .38036 Mdot
.692 .38088 Mdot
.692 .3809 Mdot
.692 .38101 Mdot
.692 .38103 Mdot
.692 .38114 Mdot
.692 .38117 Mdot
.692 .3812 Mdot
.692 .38133 Mdot
.692 .3814 Mdot
.692 .38156 Mdot
.692 .38177 Mdot
.692 .38179 Mdot
.692 .38185 Mdot
.692 .3819 Mdot
.692 .382 Mdot
.692 .3821 Mdot
.692 .38231 Mdot
.692 .38238 Mdot
.692 .38254 Mdot
.692 .38265 Mdot
.692 .3828 Mdot
.692 .3828 Mdot
.692 .38284 Mdot
.692 .38296 Mdot
.692 .38297 Mdot
.692 .38308 Mdot
.692 .3832 Mdot
.692 .38341 Mdot
.692 .38342 Mdot
.692 .38344 Mdot
.692 .38355 Mdot
.692 .38357 Mdot
.692 .38363 Mdot
.692 .38364 Mdot
.692 .38364 Mdot
.692 .38376 Mdot
.692 .38382 Mdot
.692 .38392 Mdot
.692 .38399 Mdot
.692 .384 Mdot
.692 .38405 Mdot
.692 .38407 Mdot
.692 .38409 Mdot
.692 .38413 Mdot
.692 .38413 Mdot
.692 .38423 Mdot
.692 .38429 Mdot
.692 .38432 Mdot
.692 .38439 Mdot
.692 .38441 Mdot
.692 .3845 Mdot
.692 .3846 Mdot
.692 .38461 Mdot
.692 .3847 Mdot
.692 .38475 Mdot
.692 .38477 Mdot
.692 .38481 Mdot
.692 .38493 Mdot
.692 .38499 Mdot
.692 .38504 Mdot
.692 .38504 Mdot
.692 .38508 Mdot
.692 .38508 Mdot
.692 .38512 Mdot
.692 .38514 Mdot
.692 .38515 Mdot
.692 .38515 Mdot
.692 .38526 Mdot
.692 .38533 Mdot
.692 .38533 Mdot
.692 .38534 Mdot
.692 .38537 Mdot
.692 .38538 Mdot
.692 .38543 Mdot
.692 .38549 Mdot
.692 .38562 Mdot
.692 .38564 Mdot
.692 .38565 Mdot
.692 .38566 Mdot
.692 .38567 Mdot
.692 .38567 Mdot
.692 .38569 Mdot
.692 .38574 Mdot
.692 .38578 Mdot
.692 .38594 Mdot
.692 .38601 Mdot
.692 .38604 Mdot
.692 .38622 Mdot
.692 .38623 Mdot
.692 .38634 Mdot
.692 .38644 Mdot
.692 .38653 Mdot
.692 .38656 Mdot
.692 .38658 Mdot
.692 .3866 Mdot
.692 .38668 Mdot
.692 .38672 Mdot
.692 .38673 Mdot
.692 .38679 Mdot
.692 .38679 Mdot
.692 .3868 Mdot
.692 .3868 Mdot
.692 .38681 Mdot
.692 .38683 Mdot
.692 .38685 Mdot
.692 .38694 Mdot
.692 .38695 Mdot
.692 .38696 Mdot
.692 .38701 Mdot
.692 .38703 Mdot
.692 .38703 Mdot
.692 .38705 Mdot
.692 .38709 Mdot
.692 .3871 Mdot
.692 .3871 Mdot
.692 .38711 Mdot
.692 .38712 Mdot
.692 .38713 Mdot
.692 .38716 Mdot
.692 .38718 Mdot
.692 .38719 Mdot
.692 .38722 Mdot
.692 .38724 Mdot
.692 .38725 Mdot
.692 .38725 Mdot
.692 .38727 Mdot
.692 .38728 Mdot
.692 .38728 Mdot
.692 .38729 Mdot
.692 .38732 Mdot
.692 .38733 Mdot
.692 .38733 Mdot
.692 .38733 Mdot
.692 .38733 Mdot
.692 .3992 Mdot
.692 .3992 Mdot
.692 .3992 Mdot
.692 .3992 Mdot
.692 .3992 Mdot
.692 .39921 Mdot
.692 .39922 Mdot
.692 .39922 Mdot
.692 .39922 Mdot
.692 .39923 Mdot
.692 .39923 Mdot
.692 .39923 Mdot
.692 .39924 Mdot
.692 .39925 Mdot
.692 .39925 Mdot
.692 .39926 Mdot
.692 .39927 Mdot
.692 .39927 Mdot
.692 .39928 Mdot
.692 .39928 Mdot
.692 .39928 Mdot
.692 .39928 Mdot
.692 .3993 Mdot
.692 .3993 Mdot
.692 .3993 Mdot
.692 .39931 Mdot
.692 .39933 Mdot
.692 .39933 Mdot
.692 .39934 Mdot
.692 .39937 Mdot
.692 .39937 Mdot
.692 .39938 Mdot
.692 .39938 Mdot
.692 .39938 Mdot
.692 .39939 Mdot
.692 .39939 Mdot
.692 .39941 Mdot
.692 .39941 Mdot
.692 .39942 Mdot
.692 .39945 Mdot
.692 .39946 Mdot
.692 .39946 Mdot
.692 .39948 Mdot
.692 .39951 Mdot
.692 .39954 Mdot
.692 .39958 Mdot
.692 .39958 Mdot
.692 .39964 Mdot
.692 .39965 Mdot
.692 .39968 Mdot
.692 .39973 Mdot
.692 .39974 Mdot
.692 .39976 Mdot
.692 .39977 Mdot
.692 .39977 Mdot
.692 .39977 Mdot
.692 .39977 Mdot
.692 .39978 Mdot
.692 .39978 Mdot
.692 .39983 Mdot
.692 .39985 Mdot
.692 .39987 Mdot
.692 .39987 Mdot
.692 .39988 Mdot
.692 .39988 Mdot
.692 .39988 Mdot
.692 .3999 Mdot
.692 .39994 Mdot
.692 .39994 Mdot
.692 .39994 Mdot
.692 .39995 Mdot
.692 .39997 Mdot
.692 .39997 Mdot
.692 .39998 Mdot
.692 .39998 Mdot
.692 .4 Mdot
.692 .40002 Mdot
.692 .40006 Mdot
.692 .40007 Mdot
.692 .40008 Mdot
.692 .40009 Mdot
.692 .40012 Mdot
.692 .40013 Mdot
.692 .40016 Mdot
.692 .40019 Mdot
.692 .4002 Mdot
.692 .40022 Mdot
.692 .40023 Mdot
.692 .40025 Mdot
.692 .40028 Mdot
.692 .40028 Mdot
.692 .40029 Mdot
.692 .4003 Mdot
.692 .40031 Mdot
.692 .40033 Mdot
.692 .40033 Mdot
.692 .40035 Mdot
.692 .40039 Mdot
.692 .40041 Mdot
.692 .40044 Mdot
.692 .40045 Mdot
.692 .40045 Mdot
.692 .40047 Mdot
.692 .40047 Mdot
.692 .40051 Mdot
.692 .40052 Mdot
.692 .40052 Mdot
.692 .40059 Mdot
.692 .40063 Mdot
.692 .40067 Mdot
.692 .40067 Mdot
.692 .40071 Mdot
.692 .40072 Mdot
.692 .40072 Mdot
.692 .40077 Mdot
.692 .40081 Mdot
.692 .40086 Mdot
.692 .40088 Mdot
.692 .40095 Mdot
.692 .40098 Mdot
.692 .40101 Mdot
.692 .40103 Mdot
.692 .40105 Mdot
.692 .40112 Mdot
.692 .40118 Mdot
.692 .4012 Mdot
.692 .40124 Mdot
.692 .40125 Mdot
.692 .40126 Mdot
.692 .4013 Mdot
.692 .4013 Mdot
.692 .40134 Mdot
.692 .40134 Mdot
.692 .40151 Mdot
.692 .40156 Mdot
.692 .40156 Mdot
.692 .40159 Mdot
.692 .40161 Mdot
.692 .40161 Mdot
.692 .40171 Mdot
.692 .40171 Mdot
.692 .40176 Mdot
.692 .40178 Mdot
.692 .40178 Mdot
.692 .40191 Mdot
.692 .40196 Mdot
.692 .40196 Mdot
.692 .40212 Mdot
.692 .40214 Mdot
.692 .40219 Mdot
.692 .4022 Mdot
.692 .40221 Mdot
.692 .40229 Mdot
.692 .40235 Mdot
.692 .40244 Mdot
.692 .40256 Mdot
.692 .40258 Mdot
.692 .40259 Mdot
.692 .40259 Mdot
.692 .40264 Mdot
.692 .40275 Mdot
.692 .4028 Mdot
.692 .40282 Mdot
.692 .40284 Mdot
.692 .40285 Mdot
.692 .40285 Mdot
.692 .40286 Mdot
.692 .4029 Mdot
.692 .40291 Mdot
.692 .40295 Mdot
.692 .40296 Mdot
.692 .40296 Mdot
.692 .40324 Mdot
.692 .40326 Mdot
.692 .4033 Mdot
.692 .40334 Mdot
.692 .4034 Mdot
.692 .40346 Mdot
.692 .40358 Mdot
.692 .40359 Mdot
.692 .40361 Mdot
.692 .40366 Mdot
.692 .4037 Mdot
.692 .40371 Mdot
.692 .40379 Mdot
.692 .4038 Mdot
.692 .40394 Mdot
.692 .40402 Mdot
.692 .40413 Mdot
.692 .40416 Mdot
.692 .40416 Mdot
.692 .40417 Mdot
.692 .40419 Mdot
.692 .40422 Mdot
.692 .40436 Mdot
.692 .40438 Mdot
.692 .40439 Mdot
.692 .40441 Mdot
.692 .40444 Mdot
.692 .40446 Mdot
.692 .40467 Mdot
.692 .40469 Mdot
.692 .4048 Mdot
.692 .40484 Mdot
.692 .40485 Mdot
.692 .405 Mdot
.692 .40504 Mdot
.692 .40504 Mdot
.692 .40504 Mdot
.692 .40506 Mdot
.692 .40507 Mdot
.692 .40514 Mdot
.692 .40521 Mdot
.692 .40525 Mdot
.692 .40529 Mdot
.692 .4053 Mdot
.692 .40532 Mdot
.692 .40537 Mdot
.692 .40538 Mdot
.692 .40538 Mdot
.692 .40546 Mdot
.692 .4055 Mdot
.692 .40558 Mdot
.692 .40562 Mdot
.692 .40565 Mdot
.692 .40565 Mdot
.692 .40567 Mdot
.692 .40569 Mdot
.692 .40569 Mdot
.692 .4057 Mdot
.692 .40571 Mdot
.692 .40571 Mdot
.692 .40572 Mdot
.692 .40572 Mdot
.692 .40574 Mdot
.692 .40575 Mdot
.692 .40575 Mdot
.692 .40577 Mdot
.692 .40577 Mdot
.692 .40578 Mdot
.692 .40578 Mdot
.692 .40591 Mdot
.692 .40596 Mdot
.692 .40599 Mdot
.692 .40605 Mdot
.692 .40606 Mdot
.692 .40621 Mdot
.692 .40622 Mdot
.692 .40652 Mdot
.692 .40666 Mdot
.692 .41367 Mdot
.692 .41367 Mdot
.692 .41367 Mdot
.692 .41367 Mdot
.692 .41368 Mdot
.692 .41373 Mdot
.692 .41374 Mdot
.692 .41374 Mdot
.692 .41375 Mdot
.692 .41379 Mdot
.692 .41379 Mdot
.692 .4138 Mdot
.692 .41383 Mdot
.692 .41387 Mdot
.692 .41388 Mdot
.692 .41392 Mdot
.692 .41396 Mdot
.692 .41397 Mdot
.692 .41399 Mdot
.692 .414 Mdot
.692 .41401 Mdot
.692 .41402 Mdot
.692 .41407 Mdot
.692 .4141 Mdot
.692 .41411 Mdot
.692 .41414 Mdot
.692 .4142 Mdot
.692 .41422 Mdot
.692 .41423 Mdot
.692 .41436 Mdot
.692 .41439 Mdot
.692 .41441 Mdot
.692 .41443 Mdot
.692 .41443 Mdot
.692 .41445 Mdot
.692 .41445 Mdot
.692 .41452 Mdot
.692 .41454 Mdot
.692 .4146 Mdot
.692 .41472 Mdot
.692 .41474 Mdot
.692 .41476 Mdot
.692 .41481 Mdot
.692 .41493 Mdot
.692 .41506 Mdot
.692 .41521 Mdot
.692 .41523 Mdot
.692 .41546 Mdot
.692 .4155 Mdot
.692 .41559 Mdot
.692 .41571 Mdot
.692 .41579 Mdot
.692 .41584 Mdot
.692 .4159 Mdot
.692 .41593 Mdot
.692 .41594 Mdot
.692 .41595 Mdot
.692 .41595 Mdot
.692 .41597 Mdot
.692 .41599 Mdot
.692 .41614 Mdot
.692 .41616 Mdot
.692 .41623 Mdot
.692 .4163 Mdot
.692 .4163 Mdot
.692 .41634 Mdot
.692 .41635 Mdot
.692 .41635 Mdot
.692 .41643 Mdot
.692 .41656 Mdot
.692 .41657 Mdot
.692 .41658 Mdot
.692 .41665 Mdot
.692 .41666 Mdot
.692 .41669 Mdot
.692 .4167 Mdot
.692 .41676 Mdot
.692 .41683 Mdot
.692 .41697 Mdot
.692 .41701 Mdot
.692 .41704 Mdot
.692 .41707 Mdot
.692 .41709 Mdot
.692 .4171 Mdot
.692 .4172 Mdot
.692 .4172 Mdot
.692 .41732 Mdot
.692 .41741 Mdot
.692 .41744 Mdot
.692 .41751 Mdot
.692 .41753 Mdot
.692 .41754 Mdot
.692 .41756 Mdot
.692 .4176 Mdot
.692 .41771 Mdot
.692 .41771 Mdot
.692 .41774 Mdot
.692 .41775 Mdot
.692 .41778 Mdot
.692 .4178 Mdot
.692 .41781 Mdot
.692 .41785 Mdot
.692 .41786 Mdot
.692 .41793 Mdot
.692 .41796 Mdot
.692 .41803 Mdot
.692 .41809 Mdot
.692 .41821 Mdot
.692 .41822 Mdot
.692 .41822 Mdot
.692 .41828 Mdot
.692 .4183 Mdot
.692 .41831 Mdot
.692 .41831 Mdot
.692 .41832 Mdot
.692 .41833 Mdot
.692 .41837 Mdot
.692 .41839 Mdot
.692 .41841 Mdot
.692 .41843 Mdot
.692 .41843 Mdot
.692 .41844 Mdot
.692 .41846 Mdot
.692 .41847 Mdot
.692 .41848 Mdot
.692 .41849 Mdot
.692 .41851 Mdot
.692 .41854 Mdot
.692 .41854 Mdot
.692 .4186 Mdot
.692 .41864 Mdot
.692 .41864 Mdot
.692 .41865 Mdot
.692 .41873 Mdot
.692 .41874 Mdot
.692 .41882 Mdot
.692 .41885 Mdot
.692 .41886 Mdot
.692 .41896 Mdot
.692 .419 Mdot
.692 .419 Mdot
.692 .41902 Mdot
.692 .41911 Mdot
.692 .41913 Mdot
.692 .41922 Mdot
.692 .4193 Mdot
.692 .41931 Mdot
.692 .41934 Mdot
.692 .41935 Mdot
.692 .41942 Mdot
.692 .41945 Mdot
.692 .41948 Mdot
.692 .41952 Mdot
.692 .41959 Mdot
.692 .41962 Mdot
.692 .41966 Mdot
.692 .4197 Mdot
.692 .41974 Mdot
.692 .41978 Mdot
.692 .41983 Mdot
.692 .41984 Mdot
.692 .41985 Mdot
.692 .41999 Mdot
.692 .42 Mdot
.692 .42001 Mdot
.692 .42005 Mdot
.692 .42006 Mdot
.692 .42006 Mdot
.692 .42011 Mdot
.692 .42015 Mdot
.692 .42016 Mdot
.692 .42025 Mdot
.692 .42027 Mdot
.692 .42029 Mdot
.692 .42036 Mdot
.692 .42038 Mdot
.692 .42043 Mdot
.692 .42044 Mdot
.692 .42045 Mdot
.692 .42046 Mdot
.692 .42053 Mdot
.692 .42071 Mdot
.692 .42075 Mdot
.692 .42078 Mdot
.692 .42086 Mdot
.692 .42086 Mdot
.692 .42092 Mdot
.692 .42095 Mdot
.692 .42095 Mdot
.692 .42109 Mdot
.692 .4211 Mdot
.692 .4211 Mdot
.692 .42112 Mdot
.692 .42116 Mdot
.692 .42119 Mdot
.692 .4212 Mdot
.692 .4212 Mdot
.692 .42122 Mdot
.692 .42122 Mdot
.692 .42124 Mdot
.692 .42139 Mdot
.692 .42142 Mdot
.692 .42146 Mdot
.692 .42146 Mdot
.692 .42147 Mdot
.692 .42148 Mdot
.692 .4215 Mdot
.692 .4215 Mdot
.692 .42153 Mdot
.692 .42165 Mdot
.692 .42165 Mdot
.692 .42167 Mdot
.692 .42172 Mdot
.692 .42173 Mdot
.692 .42174 Mdot
.692 .42175 Mdot
.692 .42182 Mdot
.692 .42185 Mdot
.692 .42187 Mdot
.692 .42187 Mdot
.692 .42193 Mdot
.692 .42193 Mdot
.692 .42194 Mdot
.692 .42196 Mdot
.692 .42199 Mdot
.692 .42201 Mdot
.692 .42201 Mdot
.692 .42202 Mdot
.692 .42203 Mdot
.692 .42204 Mdot
.692 .42204 Mdot
.692 .42206 Mdot
.692 .42207 Mdot
.692 .4221 Mdot
.692 .42211 Mdot
.692 .42212 Mdot
.692 .42212 Mdot
.692 .42213 Mdot
.692 .42213 Mdot
.692 .42213 Mdot
.692 .42214 Mdot
.692 .42214 Mdot
.692 .42214 Mdot
.692 .42214 Mdot
.692 .42214 Mdot
.692 .42215 Mdot
.692 .42215 Mdot
.692 .42216 Mdot
.692 .42216 Mdot
.692 .42216 Mdot
.694 .30244 Mdot
.694 .30244 Mdot
.694 .30244 Mdot
.694 .30245 Mdot
.694 .30247 Mdot
.694 .3025 Mdot
.694 .30251 Mdot
.694 .30254 Mdot
.694 .30255 Mdot
.694 .30257 Mdot
.694 .30258 Mdot
.694 .30261 Mdot
.694 .30261 Mdot
.694 .30262 Mdot
.694 .30264 Mdot
.694 .30266 Mdot
.694 .30271 Mdot
.694 .30271 Mdot
.694 .30274 Mdot
.694 .30277 Mdot
.694 .30285 Mdot
.694 .30292 Mdot
.694 .30313 Mdot
.694 .30346 Mdot
.694 .30347 Mdot
.694 .30351 Mdot
.694 .30377 Mdot
.694 .30378 Mdot
.694 .3038 Mdot
.694 .30386 Mdot
.694 .30399 Mdot
.694 .30422 Mdot
.694 .30424 Mdot
.694 .30442 Mdot
.694 .30447 Mdot
.694 .30451 Mdot
.694 .30457 Mdot
.694 .30464 Mdot
.694 .30512 Mdot
.694 .30514 Mdot
.694 .3054 Mdot
.694 .30563 Mdot
.694 .30598 Mdot
.694 .30611 Mdot
.694 .30623 Mdot
.694 .30647 Mdot
.694 .30667 Mdot
.694 .3069 Mdot
.694 .30727 Mdot
.694 .30728 Mdot
.694 .30737 Mdot
.694 .30751 Mdot
.694 .30754 Mdot
.694 .30768 Mdot
.694 .30785 Mdot
.694 .30835 Mdot
.694 .30846 Mdot
.694 .30859 Mdot
.694 .3086 Mdot
.694 .30878 Mdot
.694 .309 Mdot
.694 .30916 Mdot
.694 .30945 Mdot
.694 .3095 Mdot
.694 .3096 Mdot
.694 .30962 Mdot
.694 .30969 Mdot
.694 .30972 Mdot
.694 .30981 Mdot
.694 .30985 Mdot
.694 .30987 Mdot
.694 .30995 Mdot
.694 .31004 Mdot
.694 .31004 Mdot
.694 .31007 Mdot
.694 .31025 Mdot
.694 .31048 Mdot
.694 .31049 Mdot
.694 .31052 Mdot
.694 .31061 Mdot
.694 .31066 Mdot
.694 .31072 Mdot
.694 .31098 Mdot
.694 .31118 Mdot
.694 .3112 Mdot
.694 .31133 Mdot
.694 .31134 Mdot
.694 .31143 Mdot
.694 .31153 Mdot
.694 .31154 Mdot
.694 .31165 Mdot
.694 .31167 Mdot
.694 .3117 Mdot
.694 .31198 Mdot
.694 .31217 Mdot
.694 .31225 Mdot
.694 .31232 Mdot
.694 .31239 Mdot
.694 .31245 Mdot
.694 .31257 Mdot
.694 .31259 Mdot
.694 .31263 Mdot
.694 .31268 Mdot
.694 .31273 Mdot
.694 .3129 Mdot
.694 .31294 Mdot
.694 .31299 Mdot
.694 .31309 Mdot
.694 .31332 Mdot
.694 .31333 Mdot
.694 .31343 Mdot
.694 .31344 Mdot
.694 .31368 Mdot
.694 .31387 Mdot
.694 .31394 Mdot
.694 .31397 Mdot
.694 .31398 Mdot
.694 .31401 Mdot
.694 .31407 Mdot
.694 .31419 Mdot
.694 .31426 Mdot
.694 .31433 Mdot
.694 .31439 Mdot
.694 .31441 Mdot
.694 .31443 Mdot
.694 .31445 Mdot
.694 .31479 Mdot
.694 .31484 Mdot
.694 .31514 Mdot
.694 .3152 Mdot
.694 .31525 Mdot
.694 .31537 Mdot
.694 .3154 Mdot
.694 .3157 Mdot
.694 .31589 Mdot
.694 .3159 Mdot
.694 .31614 Mdot
.694 .31615 Mdot
.694 .3162 Mdot
.694 .31626 Mdot
.694 .31639 Mdot
.694 .31643 Mdot
.694 .31697 Mdot
.694 .31697 Mdot
.694 .31713 Mdot
.694 .31716 Mdot
.694 .31734 Mdot
.694 .31735 Mdot
.694 .31775 Mdot
.694 .31782 Mdot
.694 .31785 Mdot
.694 .31789 Mdot
.694 .31796 Mdot
.694 .31819 Mdot
.694 .31854 Mdot
.694 .31869 Mdot
.694 .31879 Mdot
.694 .3188 Mdot
.694 .31893 Mdot
.694 .31926 Mdot
.694 .31929 Mdot
.694 .31937 Mdot
.694 .31938 Mdot
.694 .31949 Mdot
.694 .31955 Mdot
.694 .31967 Mdot
.694 .31969 Mdot
.694 .31996 Mdot
.694 .31999 Mdot
.694 .32004 Mdot
.694 .32008 Mdot
.694 .32021 Mdot
.694 .32031 Mdot
.694 .32035 Mdot
.694 .32044 Mdot
.694 .32055 Mdot
.694 .32059 Mdot
.694 .32063 Mdot
.694 .32067 Mdot
.694 .32077 Mdot
.694 .32111 Mdot
.694 .32126 Mdot
.694 .3213 Mdot
.694 .32155 Mdot
.694 .32158 Mdot
.694 .32166 Mdot
.694 .32185 Mdot
.694 .32185 Mdot
.694 .32186 Mdot
.694 .32188 Mdot
.694 .32198 Mdot
.694 .32201 Mdot
.694 .32206 Mdot
.694 .32211 Mdot
.694 .32216 Mdot
.694 .32238 Mdot
.694 .32239 Mdot
.694 .32242 Mdot
.694 .3225 Mdot
.694 .32262 Mdot
.694 .32263 Mdot
.694 .32271 Mdot
.694 .32276 Mdot
.694 .32278 Mdot
.694 .3228 Mdot
.694 .3228 Mdot
.694 .32281 Mdot
.694 .32283 Mdot
.694 .32284 Mdot
.694 .32286 Mdot
.694 .32288 Mdot
.694 .3229 Mdot
.694 .32342 Mdot
.694 .32423 Mdot
.694 .32511 Mdot
.694 .32766 Mdot
.694 .32802 Mdot
.694 .32816 Mdot
.694 .33092 Mdot
.694 .33439 Mdot
.694 .3371 Mdot
.694 .34054 Mdot
.694 .34149 Mdot
.694 .34227 Mdot
.694 .34274 Mdot
.694 .34342 Mdot
.694 .34581 Mdot
.694 .34599 Mdot
.694 .34914 Mdot
.694 .35081 Mdot
.694 .35139 Mdot
.694 .35142 Mdot
.694 .35144 Mdot
.694 .35144 Mdot
.694 .35146 Mdot
.694 .35153 Mdot
.694 .35162 Mdot
.694 .35166 Mdot
.694 .35171 Mdot
.694 .3518 Mdot
.694 .35185 Mdot
.694 .35185 Mdot
.694 .3519 Mdot
.694 .35196 Mdot
.694 .35202 Mdot
.694 .35205 Mdot
.694 .35206 Mdot
.694 .35208 Mdot
.694 .35216 Mdot
.694 .35224 Mdot
.694 .35241 Mdot
.694 .35243 Mdot
.694 .35253 Mdot
.694 .35266 Mdot
.694 .3528 Mdot
.694 .35295 Mdot
.694 .35318 Mdot
.694 .35321 Mdot
.694 .35395 Mdot
.694 .35504 Mdot
.694 .35515 Mdot
.694 .35518 Mdot
.694 .35532 Mdot
.694 .35534 Mdot
.694 .35535 Mdot
.694 .35543 Mdot
.694 .35594 Mdot
.694 .35605 Mdot
.694 .35626 Mdot
.694 .3563 Mdot
.694 .35637 Mdot
.694 .35643 Mdot
.694 .35658 Mdot
.694 .35703 Mdot
.694 .35787 Mdot
.694 .35792 Mdot
.694 .35855 Mdot
.694 .35873 Mdot
.694 .35885 Mdot
.694 .35906 Mdot
.694 .35931 Mdot
.694 .36022 Mdot
.694 .36095 Mdot
.694 .36189 Mdot
.694 .36266 Mdot
.694 .3627 Mdot
.694 .36281 Mdot
.694 .36354 Mdot
.694 .3638 Mdot
.694 .36405 Mdot
.694 .36422 Mdot
.694 .36449 Mdot
.694 .36461 Mdot
.694 .36492 Mdot
.694 .36521 Mdot
.694 .36527 Mdot
.694 .36535 Mdot
.694 .3658 Mdot
.694 .36583 Mdot
.694 .36599 Mdot
.694 .36606 Mdot
.694 .3663 Mdot
.694 .36638 Mdot
.694 .3664 Mdot
.694 .36641 Mdot
.694 .36649 Mdot
.694 .36667 Mdot
.694 .36668 Mdot
.694 .36674 Mdot
.694 .36687 Mdot
.694 .36702 Mdot
.694 .36703 Mdot
.694 .36716 Mdot
.694 .36744 Mdot
.694 .36758 Mdot
.694 .36772 Mdot
.694 .36782 Mdot
.694 .36784 Mdot
.694 .36787 Mdot
.694 .36798 Mdot
.694 .36811 Mdot
.694 .36817 Mdot
.694 .36825 Mdot
.694 .36825 Mdot
.694 .36831 Mdot
.694 .3684 Mdot
.694 .36852 Mdot
.694 .3686 Mdot
.694 .36902 Mdot
.694 .36951 Mdot
.694 .37005 Mdot
.694 .37089 Mdot
.694 .3712 Mdot
.694 .37154 Mdot
.694 .37156 Mdot
.694 .37207 Mdot
.694 .37262 Mdot
.694 .37305 Mdot
.694 .37379 Mdot
.694 .37391 Mdot
.694 .37414 Mdot
.694 .37419 Mdot
.694 .37437 Mdot
.694 .37444 Mdot
.694 .37444 Mdot
.694 .37466 Mdot
.694 .37475 Mdot
.694 .3748 Mdot
.694 .37499 Mdot
.694 .3752 Mdot
.694 .3752 Mdot
.694 .37528 Mdot
.694 .3757 Mdot
.694 .3762 Mdot
.694 .37624 Mdot
.694 .37629 Mdot
.694 .37638 Mdot
.694 .37649 Mdot
.694 .37659 Mdot
.694 .37673 Mdot
.694 .37729 Mdot
.694 .3777 Mdot
.694 .37775 Mdot
.694 .37801 Mdot
.694 .37802 Mdot
.694 .37804 Mdot
.694 .37821 Mdot
.694 .37841 Mdot
.694 .37842 Mdot
.694 .37857 Mdot
.694 .37863 Mdot
.694 .37868 Mdot
.694 .37873 Mdot
.694 .37925 Mdot
.694 .3796 Mdot
.694 .37974 Mdot
.694 .37987 Mdot
.694 .37998 Mdot
.694 .38009 Mdot
.694 .38028 Mdot
.694 .38029 Mdot
.694 .38033 Mdot
.694 .3804 Mdot
.694 .38048 Mdot
.694 .38056 Mdot
.694 .38078 Mdot
.694 .38083 Mdot
.694 .38088 Mdot
.694 .38096 Mdot
.694 .38105 Mdot
.694 .38112 Mdot
.694 .38124 Mdot
.694 .38126 Mdot
.694 .3813 Mdot
.694 .38133 Mdot
.694 .38134 Mdot
.694 .38138 Mdot
.694 .38139 Mdot
.694 .3814 Mdot
.694 .38143 Mdot
.694 .38147 Mdot
.694 .38147 Mdot
.694 .38148 Mdot
.694 .38155 Mdot
.694 .38163 Mdot
.694 .38164 Mdot
.694 .38168 Mdot
.694 .3817 Mdot
.694 .38189 Mdot
.694 .38198 Mdot
.694 .38201 Mdot
.694 .38205 Mdot
.694 .38207 Mdot
.694 .38223 Mdot
.694 .38232 Mdot
.694 .38236 Mdot
.694 .38237 Mdot
.694 .3824 Mdot
.694 .38241 Mdot
.694 .38247 Mdot
.694 .38248 Mdot
.694 .38253 Mdot
.694 .3826 Mdot
.694 .38264 Mdot
.694 .38264 Mdot
.694 .38271 Mdot
.694 .38277 Mdot
.694 .38279 Mdot
.694 .3828 Mdot
.694 .38281 Mdot
.694 .38282 Mdot
.694 .38287 Mdot
.694 .38289 Mdot
.694 .38291 Mdot
.694 .38293 Mdot
.694 .38294 Mdot
.694 .38305 Mdot
.694 .38315 Mdot
.694 .38318 Mdot
.694 .38331 Mdot
.694 .38337 Mdot
.694 .38347 Mdot
.694 .3835 Mdot
.694 .38366 Mdot
.694 .38366 Mdot
.694 .38371 Mdot
.694 .38376 Mdot
.694 .38387 Mdot
.694 .38389 Mdot
.694 .38392 Mdot
.694 .38398 Mdot
.694 .38407 Mdot
.694 .38411 Mdot
.694 .38414 Mdot
.694 .38414 Mdot
.694 .38417 Mdot
.694 .38426 Mdot
.694 .38428 Mdot
.694 .38428 Mdot
.694 .38433 Mdot
.694 .38436 Mdot
.694 .38443 Mdot
.694 .38443 Mdot
.694 .38444 Mdot
.694 .38446 Mdot
.694 .38449 Mdot
.694 .38451 Mdot
.694 .38452 Mdot
.694 .38454 Mdot
.694 .38457 Mdot
.694 .38459 Mdot
.694 .3846 Mdot
.694 .38462 Mdot
.694 .3847 Mdot
.694 .38474 Mdot
.694 .38475 Mdot
.694 .3848 Mdot
.694 .38483 Mdot
.694 .38487 Mdot
.694 .38487 Mdot
.694 .38488 Mdot
.694 .38488 Mdot
.694 .38491 Mdot
.694 .38492 Mdot
.694 .38493 Mdot
.694 .38494 Mdot
.694 .385 Mdot
.694 .385 Mdot
.694 .385 Mdot
.694 .38502 Mdot
.694 .38505 Mdot
.694 .38505 Mdot
.694 .38507 Mdot
.694 .38508 Mdot
.694 .38509 Mdot
.694 .38509 Mdot
.694 .38509 Mdot
.694 .3851 Mdot
.694 .3851 Mdot
.694 .38511 Mdot
.694 .38511 Mdot
.694 .40031 Mdot
.694 .40031 Mdot
.694 .40031 Mdot
.694 .40032 Mdot
.694 .40032 Mdot
.694 .40032 Mdot
.694 .40032 Mdot
.694 .40032 Mdot
.694 .40032 Mdot
.694 .40033 Mdot
.694 .40033 Mdot
.694 .40034 Mdot
.694 .40035 Mdot
.694 .40035 Mdot
.694 .40035 Mdot
.694 .40037 Mdot
.694 .40037 Mdot
.694 .40037 Mdot
.694 .40038 Mdot
.694 .40039 Mdot
.694 .40039 Mdot
.694 .40039 Mdot
.694 .40039 Mdot
.694 .4004 Mdot
.694 .40041 Mdot
.694 .40043 Mdot
.694 .40043 Mdot
.694 .40045 Mdot
.694 .40047 Mdot
.694 .40048 Mdot
.694 .40048 Mdot
.694 .40049 Mdot
.694 .4005 Mdot
.694 .40051 Mdot
.694 .40051 Mdot
.694 .40052 Mdot
.694 .40053 Mdot
.694 .40053 Mdot
.694 .40053 Mdot
.694 .40054 Mdot
.694 .40056 Mdot
.694 .40057 Mdot
.694 .40058 Mdot
.694 .40058 Mdot
.694 .40059 Mdot
.694 .40062 Mdot
.694 .40063 Mdot
.694 .40063 Mdot
.694 .40064 Mdot
.694 .40065 Mdot
.694 .40068 Mdot
.694 .4007 Mdot
.694 .40071 Mdot
.694 .40072 Mdot
.694 .40075 Mdot
.694 .40077 Mdot
.694 .40079 Mdot
.694 .40079 Mdot
.694 .40084 Mdot
.694 .40085 Mdot
.694 .40088 Mdot
.694 .4009 Mdot
.694 .40094 Mdot
.694 .40095 Mdot
.694 .40099 Mdot
.694 .40102 Mdot
.694 .40102 Mdot
.694 .40103 Mdot
.694 .40104 Mdot
.694 .40104 Mdot
.694 .40106 Mdot
.694 .40106 Mdot
.694 .40107 Mdot
.694 .40107 Mdot
.694 .40108 Mdot
.694 .40109 Mdot
.694 .40112 Mdot
.694 .40112 Mdot
.694 .40113 Mdot
.694 .40115 Mdot
.694 .40117 Mdot
.694 .40117 Mdot
.694 .40119 Mdot
.694 .4012 Mdot
.694 .40121 Mdot
.694 .40121 Mdot
.694 .40122 Mdot
.694 .40125 Mdot
.694 .4013 Mdot
.694 .40131 Mdot
.694 .40132 Mdot
.694 .40133 Mdot
.694 .40136 Mdot
.694 .40142 Mdot
.694 .40143 Mdot
.694 .40144 Mdot
.694 .40144 Mdot
.694 .40147 Mdot
.694 .40149 Mdot
.694 .40149 Mdot
.694 .40149 Mdot
.694 .40151 Mdot
.694 .40152 Mdot
.694 .40152 Mdot
.694 .40152 Mdot
.694 .40153 Mdot
.694 .40154 Mdot
.694 .40155 Mdot
.694 .40156 Mdot
.694 .40157 Mdot
.694 .4016 Mdot
.694 .40163 Mdot
.694 .40165 Mdot
.694 .40168 Mdot
.694 .4017 Mdot
.694 .40171 Mdot
.694 .40178 Mdot
.694 .40181 Mdot
.694 .40183 Mdot
.694 .40186 Mdot
.694 .40187 Mdot
.694 .40187 Mdot
.694 .40193 Mdot
.694 .40197 Mdot
.694 .402 Mdot
.694 .40204 Mdot
.694 .40209 Mdot
.694 .40219 Mdot
.694 .40236 Mdot
.694 .40237 Mdot
.694 .40239 Mdot
.694 .40241 Mdot
.694 .40245 Mdot
.694 .40246 Mdot
.694 .40252 Mdot
.694 .40257 Mdot
.694 .40258 Mdot
.694 .40258 Mdot
.694 .40266 Mdot
.694 .40268 Mdot
.694 .4028 Mdot
.694 .40297 Mdot
.694 .40302 Mdot
.694 .40305 Mdot
.694 .40308 Mdot
.694 .40311 Mdot
.694 .40313 Mdot
.694 .40314 Mdot
.694 .40329 Mdot
.694 .40342 Mdot
.694 .40344 Mdot
.694 .40344 Mdot
.694 .4035 Mdot
.694 .40356 Mdot
.694 .40358 Mdot
.694 .40361 Mdot
.694 .40367 Mdot
.694 .40367 Mdot
.694 .40369 Mdot
.694 .40375 Mdot
.694 .40376 Mdot
.694 .40383 Mdot
.694 .40387 Mdot
.694 .40409 Mdot
.694 .40422 Mdot
.694 .40438 Mdot
.694 .40453 Mdot
.694 .40454 Mdot
.694 .40464 Mdot
.694 .40473 Mdot
.694 .40498 Mdot
.694 .40513 Mdot
.694 .40528 Mdot
.694 .4054 Mdot
.694 .40542 Mdot
.694 .40546 Mdot
.694 .40548 Mdot
.694 .4055 Mdot
.694 .4055 Mdot
.694 .40552 Mdot
.694 .40554 Mdot
.694 .40558 Mdot
.694 .40561 Mdot
.694 .40562 Mdot
.694 .40563 Mdot
.694 .40565 Mdot
.694 .4057 Mdot
.694 .40573 Mdot
.694 .40581 Mdot
.694 .40585 Mdot
.694 .40586 Mdot
.694 .4059 Mdot
.694 .40594 Mdot
.694 .40595 Mdot
.694 .40596 Mdot
.694 .40601 Mdot
.694 .40603 Mdot
.694 .40603 Mdot
.694 .40604 Mdot
.694 .40606 Mdot
.694 .40613 Mdot
.694 .40615 Mdot
.694 .4062 Mdot
.694 .40621 Mdot
.694 .40633 Mdot
.694 .40636 Mdot
.694 .40637 Mdot
.694 .40646 Mdot
.694 .40654 Mdot
.694 .40658 Mdot
.694 .40666 Mdot
.694 .40671 Mdot
.694 .40677 Mdot
.694 .40685 Mdot
.694 .40706 Mdot
.694 .40708 Mdot
.694 .4071 Mdot
.694 .40731 Mdot
.694 .40758 Mdot
.694 .40778 Mdot
.694 .40803 Mdot
.694 .4081 Mdot
.694 .40816 Mdot
.694 .4082 Mdot
.694 .40824 Mdot
.694 .40842 Mdot
.694 .40843 Mdot
.694 .40866 Mdot
.694 .40879 Mdot
.694 .40883 Mdot
.694 .40885 Mdot
.694 .40886 Mdot
.694 .40888 Mdot
.694 .40894 Mdot
.694 .40896 Mdot
.694 .4091 Mdot
.694 .40913 Mdot
.694 .40913 Mdot
.694 .40913 Mdot
.694 .40917 Mdot
.694 .40918 Mdot
.694 .40921 Mdot
.694 .40951 Mdot
.694 .40971 Mdot
.694 .40972 Mdot
.694 .40978 Mdot
.694 .40982 Mdot
.694 .40986 Mdot
.694 .4099 Mdot
.694 .40992 Mdot
.694 .40993 Mdot
.694 .40997 Mdot
.694 .40999 Mdot
.694 .41002 Mdot
.694 .41002 Mdot
.694 .41002 Mdot
.694 .41003 Mdot
.694 .41005 Mdot
.694 .41007 Mdot
.694 .41008 Mdot
.694 .41008 Mdot
.694 .41009 Mdot
.694 .41012 Mdot
.694 .41013 Mdot
.694 .41014 Mdot
.694 .41017 Mdot
.694 .41018 Mdot
.694 .41019 Mdot
.694 .41019 Mdot
.694 .4102 Mdot
.694 .41021 Mdot
.694 .41036 Mdot
.694 .41081 Mdot
.694 .41166 Mdot
.694 .4117 Mdot
.694 .41234 Mdot
.694 .41252 Mdot
.694 .41265 Mdot
.694 .41286 Mdot
.694 .41311 Mdot
.694 .41402 Mdot
.694 .41473 Mdot
.694 .41565 Mdot
.694 .41638 Mdot
.694 .41642 Mdot
.694 .41651 Mdot
.694 .41719 Mdot
.694 .41742 Mdot
.694 .41764 Mdot
.694 .41778 Mdot
.694 .41778 Mdot
.694 .41779 Mdot
.694 .41779 Mdot
.694 .41779 Mdot
.694 .4178 Mdot
.694 .4178 Mdot
.694 .4178 Mdot
.694 .41781 Mdot
.694 .41782 Mdot
.694 .41785 Mdot
.694 .41785 Mdot
.694 .41788 Mdot
.694 .4179 Mdot
.694 .41791 Mdot
.694 .41791 Mdot
.694 .41797 Mdot
.694 .41799 Mdot
.694 .418 Mdot
.694 .41801 Mdot
.694 .41802 Mdot
.694 .41805 Mdot
.694 .41805 Mdot
.694 .41805 Mdot
.694 .41805 Mdot
.694 .4181 Mdot
.694 .41813 Mdot
.694 .41813 Mdot
.694 .4182 Mdot
.694 .41821 Mdot
.694 .41825 Mdot
.694 .41834 Mdot
.694 .41837 Mdot
.694 .41838 Mdot
.694 .41839 Mdot
.694 .4184 Mdot
.694 .41843 Mdot
.694 .41845 Mdot
.694 .41846 Mdot
.694 .41849 Mdot
.694 .41852 Mdot
.694 .41854 Mdot
.694 .41855 Mdot
.694 .41856 Mdot
.694 .41863 Mdot
.694 .41863 Mdot
.694 .41867 Mdot
.694 .41868 Mdot
.694 .41871 Mdot
.694 .41871 Mdot
.694 .41874 Mdot
.694 .41874 Mdot
.694 .41883 Mdot
.694 .41887 Mdot
.694 .41887 Mdot
.694 .4189 Mdot
.694 .41894 Mdot
.694 .41903 Mdot
.694 .41909 Mdot
.694 .41911 Mdot
.694 .41912 Mdot
.694 .41913 Mdot
.694 .41915 Mdot
.694 .41926 Mdot
.694 .41926 Mdot
.694 .41931 Mdot
.694 .41931 Mdot
.694 .41936 Mdot
.694 .41936 Mdot
.694 .4195 Mdot
.694 .41951 Mdot
.694 .41955 Mdot
.694 .41956 Mdot
.694 .41958 Mdot
.694 .41958 Mdot
.694 .41965 Mdot
.694 .41965 Mdot
.694 .4197 Mdot
.694 .41978 Mdot
.694 .41979 Mdot
.694 .41982 Mdot
.694 .41983 Mdot
.694 .41985 Mdot
.694 .41993 Mdot
.694 .41994 Mdot
.694 .42004 Mdot
.694 .42004 Mdot
.694 .42005 Mdot
.694 .42005 Mdot
.694 .42007 Mdot
.694 .42009 Mdot
.694 .4201 Mdot
.694 .42014 Mdot
.694 .42015 Mdot
.694 .42016 Mdot
.694 .42016 Mdot
.694 .42017 Mdot
.694 .42019 Mdot
.694 .42024 Mdot
.694 .42031 Mdot
.694 .42031 Mdot
.694 .42034 Mdot
.694 .42034 Mdot
.694 .4204 Mdot
.694 .42043 Mdot
.694 .42045 Mdot
.694 .42045 Mdot
.694 .4205 Mdot
.694 .42051 Mdot
.694 .42053 Mdot
.694 .42054 Mdot
.694 .42054 Mdot
.694 .42058 Mdot
.694 .42059 Mdot
.694 .42061 Mdot
.694 .42063 Mdot
.694 .42065 Mdot
.694 .42071 Mdot
.694 .42078 Mdot
.694 .42079 Mdot
.694 .42079 Mdot
.694 .42082 Mdot
.694 .42083 Mdot
.694 .42085 Mdot
.694 .42088 Mdot
.694 .42088 Mdot
.694 .42092 Mdot
.694 .42092 Mdot
.694 .42098 Mdot
.694 .42105 Mdot
.694 .42106 Mdot
.694 .42108 Mdot
.694 .4211 Mdot
.694 .42111 Mdot
.694 .42111 Mdot
.694 .42117 Mdot
.694 .42122 Mdot
.694 .42123 Mdot
.694 .42123 Mdot
.694 .42126 Mdot
.694 .42128 Mdot
.694 .42129 Mdot
.694 .4213 Mdot
.694 .42132 Mdot
.694 .42133 Mdot
.694 .42135 Mdot
.694 .42135 Mdot
.694 .42138 Mdot
.694 .42139 Mdot
.694 .42147 Mdot
.694 .42152 Mdot
.694 .42158 Mdot
.694 .42163 Mdot
.694 .42163 Mdot
.694 .42167 Mdot
.694 .4217 Mdot
.694 .42183 Mdot
.694 .42188 Mdot
.694 .42192 Mdot
.694 .42193 Mdot
.694 .42197 Mdot
.694 .42199 Mdot
.694 .42199 Mdot
.694 .4221 Mdot
.694 .42216 Mdot
.694 .42222 Mdot
.694 .42228 Mdot
.694 .42231 Mdot
.694 .42235 Mdot
.694 .42245 Mdot
.694 .42251 Mdot
.694 .42258 Mdot
.694 .42259 Mdot
.694 .42272 Mdot
.694 .42274 Mdot
.694 .42276 Mdot
.694 .42277 Mdot
.694 .42279 Mdot
.694 .42284 Mdot
.694 .42284 Mdot
.694 .42291 Mdot
.694 .42294 Mdot
.694 .42296 Mdot
.694 .42296 Mdot
.694 .42297 Mdot
.694 .42304 Mdot
.694 .42305 Mdot
.694 .42305 Mdot
.694 .42315 Mdot
.694 .4232 Mdot
.694 .42322 Mdot
.694 .42325 Mdot
.694 .42326 Mdot
.694 .42326 Mdot
.694 .42326 Mdot
.694 .42328 Mdot
.694 .42328 Mdot
.694 .42329 Mdot
.694 .42329 Mdot
.694 .42329 Mdot
.694 .4233 Mdot
.694 .4233 Mdot
.694 .42331 Mdot
.694 .42331 Mdot
.694 .42332 Mdot
.694 .42332 Mdot
.694 .42333 Mdot
.694 .42334 Mdot
.694 .42334 Mdot
.694 .42334 Mdot
.694 .42334 Mdot
.696 .29911 Mdot
.696 .29911 Mdot
.696 .29911 Mdot
.696 .29911 Mdot
.696 .29912 Mdot
.696 .29916 Mdot
.696 .29918 Mdot
.696 .29919 Mdot
.696 .2992 Mdot
.696 .29921 Mdot
.696 .29939 Mdot
.696 .29945 Mdot
.696 .29949 Mdot
.696 .29956 Mdot
.696 .29958 Mdot
.696 .29962 Mdot
.696 .29971 Mdot
.696 .29979 Mdot
.696 .29997 Mdot
.696 .3 Mdot
.696 .30003 Mdot
.696 .30003 Mdot
.696 .30005 Mdot
.696 .30005 Mdot
.696 .30011 Mdot
.696 .30018 Mdot
.696 .30018 Mdot
.696 .30018 Mdot
.696 .30022 Mdot
.696 .30023 Mdot
.696 .30025 Mdot
.696 .30029 Mdot
.696 .30031 Mdot
.696 .30033 Mdot
.696 .3004 Mdot
.696 .3004 Mdot
.696 .30041 Mdot
.696 .30041 Mdot
.696 .30052 Mdot
.696 .30062 Mdot
.696 .30071 Mdot
.696 .30074 Mdot
.696 .30084 Mdot
.696 .30087 Mdot
.696 .30089 Mdot
.696 .30097 Mdot
.696 .30101 Mdot
.696 .30105 Mdot
.696 .30116 Mdot
.696 .30117 Mdot
.696 .30131 Mdot
.696 .3015 Mdot
.696 .30162 Mdot
.696 .30167 Mdot
.696 .30169 Mdot
.696 .3017 Mdot
.696 .30173 Mdot
.696 .30173 Mdot
.696 .30174 Mdot
.696 .30174 Mdot
.696 .30191 Mdot
.696 .30201 Mdot
.696 .30206 Mdot
.696 .30218 Mdot
.696 .30219 Mdot
.696 .30224 Mdot
.696 .30228 Mdot
.696 .30242 Mdot
.696 .30245 Mdot
.696 .30267 Mdot
.696 .30271 Mdot
.696 .30276 Mdot
.696 .3029 Mdot
.696 .30303 Mdot
.696 .30306 Mdot
.696 .30312 Mdot
.696 .30317 Mdot
.696 .30326 Mdot
.696 .30332 Mdot
.696 .30363 Mdot
.696 .30363 Mdot
.696 .30364 Mdot
.696 .30373 Mdot
.696 .30383 Mdot
.696 .30383 Mdot
.696 .30384 Mdot
.696 .3041 Mdot
.696 .30425 Mdot
.696 .30448 Mdot
.696 .30452 Mdot
.696 .30462 Mdot
.696 .30462 Mdot
.696 .3047 Mdot
.696 .30475 Mdot
.696 .30475 Mdot
.696 .30477 Mdot
.696 .30478 Mdot
.696 .305 Mdot
.696 .30504 Mdot
.696 .30512 Mdot
.696 .30553 Mdot
.696 .30553 Mdot
.696 .30567 Mdot
.696 .30567 Mdot
.696 .30603 Mdot
.696 .30613 Mdot
.696 .30651 Mdot
.696 .30677 Mdot
.696 .30682 Mdot
.696 .30696 Mdot
.696 .30705 Mdot
.696 .30733 Mdot
.696 .30752 Mdot
.696 .30754 Mdot
.696 .30784 Mdot
.696 .30786 Mdot
.696 .30795 Mdot
.696 .3081 Mdot
.696 .30819 Mdot
.696 .30821 Mdot
.696 .30843 Mdot
.696 .30848 Mdot
.696 .3086 Mdot
.696 .30879 Mdot
.696 .30881 Mdot
.696 .30895 Mdot
.696 .30896 Mdot
.696 .30897 Mdot
.696 .30915 Mdot
.696 .30917 Mdot
.696 .30919 Mdot
.696 .30919 Mdot
.696 .30927 Mdot
.696 .3093 Mdot
.696 .30931 Mdot
.696 .30932 Mdot
.696 .30947 Mdot
.696 .30948 Mdot
.696 .30954 Mdot
.696 .30967 Mdot
.696 .30967 Mdot
.696 .30968 Mdot
.696 .30974 Mdot
.696 .3098 Mdot
.696 .30986 Mdot
.696 .30989 Mdot
.696 .30992 Mdot
.696 .30996 Mdot
.696 .3101 Mdot
.696 .31014 Mdot
.696 .31015 Mdot
.696 .31018 Mdot
.696 .31019 Mdot
.696 .31031 Mdot
.696 .31031 Mdot
.696 .31032 Mdot
.696 .31033 Mdot
.696 .31034 Mdot
.696 .31035 Mdot
.696 .31101 Mdot
.696 .31134 Mdot
.696 .31202 Mdot
.696 .31217 Mdot
.696 .31288 Mdot
.696 .31393 Mdot
.696 .31473 Mdot
.696 .31493 Mdot
.696 .31579 Mdot
.696 .31666 Mdot
.696 .31694 Mdot
.696 .31827 Mdot
.696 .31946 Mdot
.696 .31979 Mdot
.696 .32037 Mdot
.696 .32183 Mdot
.696 .32235 Mdot
.696 .32335 Mdot
.696 .32533 Mdot
.696 .32766 Mdot
.696 .32776 Mdot
.696 .32811 Mdot
.696 .32982 Mdot
.696 .33099 Mdot
.696 .33222 Mdot
.696 .33545 Mdot
.696 .33545 Mdot
.696 .33545 Mdot
.696 .33547 Mdot
.696 .33547 Mdot
.696 .33548 Mdot
.696 .33557 Mdot
.696 .33567 Mdot
.696 .33572 Mdot
.696 .33577 Mdot
.696 .33579 Mdot
.696 .33585 Mdot
.696 .33652 Mdot
.696 .33674 Mdot
.696 .33685 Mdot
.696 .33693 Mdot
.696 .33708 Mdot
.696 .33716 Mdot
.696 .33721 Mdot
.696 .33726 Mdot
.696 .33726 Mdot
.696 .33735 Mdot
.696 .33739 Mdot
.696 .33777 Mdot
.696 .33804 Mdot
.696 .33877 Mdot
.696 .33886 Mdot
.696 .33896 Mdot
.696 .33897 Mdot
.696 .33905 Mdot
.696 .33906 Mdot
.696 .3392 Mdot
.696 .33928 Mdot
.696 .33954 Mdot
.696 .33955 Mdot
.696 .33956 Mdot
.696 .33971 Mdot
.696 .33975 Mdot
.696 .33982 Mdot
.696 .33998 Mdot
.696 .34005 Mdot
.696 .34011 Mdot
.696 .34039 Mdot
.696 .34039 Mdot
.696 .34042 Mdot
.696 .34043 Mdot
.696 .34084 Mdot
.696 .34124 Mdot
.696 .34158 Mdot
.696 .34169 Mdot
.696 .3421 Mdot
.696 .34217 Mdot
.696 .34218 Mdot
.696 .34259 Mdot
.696 .34273 Mdot
.696 .34275 Mdot
.696 .34287 Mdot
.696 .34329 Mdot
.696 .34333 Mdot
.696 .34372 Mdot
.696 .34387 Mdot
.696 .34433 Mdot
.696 .3446 Mdot
.696 .34504 Mdot
.696 .34526 Mdot
.696 .34533 Mdot
.696 .34535 Mdot
.696 .34548 Mdot
.696 .34549 Mdot
.696 .34551 Mdot
.696 .34553 Mdot
.696 .34615 Mdot
.696 .34655 Mdot
.696 .3466 Mdot
.696 .34674 Mdot
.696 .34715 Mdot
.696 .34718 Mdot
.696 .34721 Mdot
.696 .34724 Mdot
.696 .3474 Mdot
.696 .34753 Mdot
.696 .34754 Mdot
.696 .3476 Mdot
.696 .34809 Mdot
.696 .34819 Mdot
.696 .34825 Mdot
.696 .349 Mdot
.696 .34918 Mdot
.696 .34924 Mdot
.696 .34931 Mdot
.696 .34934 Mdot
.696 .3495 Mdot
.696 .34987 Mdot
.696 .35035 Mdot
.696 .35047 Mdot
.696 .35064 Mdot
.696 .3507 Mdot
.696 .35087 Mdot
.696 .3511 Mdot
.696 .35122 Mdot
.696 .35143 Mdot
.696 .35255 Mdot
.696 .35256 Mdot
.696 .35259 Mdot
.696 .35293 Mdot
.696 .35329 Mdot
.696 .35331 Mdot
.696 .35332 Mdot
.696 .35403 Mdot
.696 .35425 Mdot
.696 .35482 Mdot
.696 .35563 Mdot
.696 .35575 Mdot
.696 .35606 Mdot
.696 .35611 Mdot
.696 .35613 Mdot
.696 .35639 Mdot
.696 .35656 Mdot
.696 .35658 Mdot
.696 .35666 Mdot
.696 .35669 Mdot
.696 .35683 Mdot
.696 .35743 Mdot
.696 .35759 Mdot
.696 .35785 Mdot
.696 .35877 Mdot
.696 .35925 Mdot
.696 .35928 Mdot
.696 .35929 Mdot
.696 .35932 Mdot
.696 .35938 Mdot
.696 .35972 Mdot
.696 .35974 Mdot
.696 .3606 Mdot
.696 .36093 Mdot
.696 .36125 Mdot
.696 .36171 Mdot
.696 .36181 Mdot
.696 .36184 Mdot
.696 .36248 Mdot
.696 .36304 Mdot
.696 .36333 Mdot
.696 .36348 Mdot
.696 .36392 Mdot
.696 .36409 Mdot
.696 .36419 Mdot
.696 .36456 Mdot
.696 .36498 Mdot
.696 .36507 Mdot
.696 .36535 Mdot
.696 .36563 Mdot
.696 .3657 Mdot
.696 .36597 Mdot
.696 .36633 Mdot
.696 .36659 Mdot
.696 .36664 Mdot
.696 .36689 Mdot
.696 .36701 Mdot
.696 .36734 Mdot
.696 .3675 Mdot
.696 .36761 Mdot
.696 .36767 Mdot
.696 .36769 Mdot
.696 .36817 Mdot
.696 .36827 Mdot
.696 .36842 Mdot
.696 .3685 Mdot
.696 .36875 Mdot
.696 .36887 Mdot
.696 .36927 Mdot
.696 .36933 Mdot
.696 .36971 Mdot
.696 .36972 Mdot
.696 .36976 Mdot
.696 .3698 Mdot
.696 .37023 Mdot
.696 .37029 Mdot
.696 .37034 Mdot
.696 .37035 Mdot
.696 .37056 Mdot
.696 .37062 Mdot
.696 .37065 Mdot
.696 .37069 Mdot
.696 .37079 Mdot
.696 .37108 Mdot
.696 .37109 Mdot
.696 .37119 Mdot
.696 .37125 Mdot
.696 .37126 Mdot
.696 .37145 Mdot
.696 .37157 Mdot
.696 .37158 Mdot
.696 .37158 Mdot
.696 .37161 Mdot
.696 .37176 Mdot
.696 .37191 Mdot
.696 .37203 Mdot
.696 .37204 Mdot
.696 .37213 Mdot
.696 .37219 Mdot
.696 .37229 Mdot
.696 .37262 Mdot
.696 .37273 Mdot
.696 .37274 Mdot
.696 .37282 Mdot
.696 .37284 Mdot
.696 .37306 Mdot
.696 .37313 Mdot
.696 .37313 Mdot
.696 .37316 Mdot
.696 .37317 Mdot
.696 .3732 Mdot
.696 .37323 Mdot
.696 .3738 Mdot
.696 .37396 Mdot
.696 .37417 Mdot
.696 .37471 Mdot
.696 .37523 Mdot
.696 .37536 Mdot
.696 .37538 Mdot
.696 .3754 Mdot
.696 .37564 Mdot
.696 .37596 Mdot
.696 .37603 Mdot
.696 .37608 Mdot
.696 .37615 Mdot
.696 .37674 Mdot
.696 .37694 Mdot
.696 .37704 Mdot
.696 .37719 Mdot
.696 .37729 Mdot
.696 .37776 Mdot
.696 .37776 Mdot
.696 .37776 Mdot
.696 .3778 Mdot
.696 .37781 Mdot
.696 .37783 Mdot
.696 .37788 Mdot
.696 .37798 Mdot
.696 .37799 Mdot
.696 .37819 Mdot
.696 .37827 Mdot
.696 .3783 Mdot
.696 .37839 Mdot
.696 .37842 Mdot
.696 .37853 Mdot
.696 .37897 Mdot
.696 .37901 Mdot
.696 .37903 Mdot
.696 .37906 Mdot
.696 .37924 Mdot
.696 .37927 Mdot
.696 .37938 Mdot
.696 .37963 Mdot
.696 .37966 Mdot
.696 .37968 Mdot
.696 .37984 Mdot
.696 .37999 Mdot
.696 .38015 Mdot
.696 .38025 Mdot
.696 .38026 Mdot
.696 .38038 Mdot
.696 .38046 Mdot
.696 .38057 Mdot
.696 .38058 Mdot
.696 .38063 Mdot
.696 .38069 Mdot
.696 .38069 Mdot
.696 .3808 Mdot
.696 .38082 Mdot
.696 .38085 Mdot
.696 .38103 Mdot
.696 .38108 Mdot
.696 .38123 Mdot
.696 .38127 Mdot
.696 .38154 Mdot
.696 .3816 Mdot
.696 .38163 Mdot
.696 .38181 Mdot
.696 .38192 Mdot
.696 .38196 Mdot
.696 .38204 Mdot
.696 .38205 Mdot
.696 .38212 Mdot
.696 .38214 Mdot
.696 .38218 Mdot
.696 .38225 Mdot
.696 .38225 Mdot
.696 .3823 Mdot
.696 .3823 Mdot
.696 .38231 Mdot
.696 .38237 Mdot
.696 .38237 Mdot
.696 .38238 Mdot
.696 .38238 Mdot
.696 .38241 Mdot
.696 .38242 Mdot
.696 .38247 Mdot
.696 .38249 Mdot
.696 .38253 Mdot
.696 .38254 Mdot
.696 .38254 Mdot
.696 .38258 Mdot
.696 .38259 Mdot
.696 .38261 Mdot
.696 .38261 Mdot
.696 .38263 Mdot
.696 .38267 Mdot
.696 .38269 Mdot
.696 .3827 Mdot
.696 .3827 Mdot
.696 .38274 Mdot
.696 .38274 Mdot
.696 .38274 Mdot
.696 .38274 Mdot
.696 .38275 Mdot
.696 .38275 Mdot
.696 .40142 Mdot
.696 .40142 Mdot
.696 .40143 Mdot
.696 .40143 Mdot
.696 .40143 Mdot
.696 .40143 Mdot
.696 .40144 Mdot
.696 .40144 Mdot
.696 .40144 Mdot
.696 .40145 Mdot
.696 .40146 Mdot
.696 .40147 Mdot
.696 .40147 Mdot
.696 .40147 Mdot
.696 .40148 Mdot
.696 .40149 Mdot
.696 .40149 Mdot
.696 .40149 Mdot
.696 .4015 Mdot
.696 .40151 Mdot
.696 .40153 Mdot
.696 .40153 Mdot
.696 .40154 Mdot
.696 .40154 Mdot
.696 .40154 Mdot
.696 .40155 Mdot
.696 .40156 Mdot
.696 .40157 Mdot
.696 .40157 Mdot
.696 .40158 Mdot
.696 .40158 Mdot
.696 .4016 Mdot
.696 .40162 Mdot
.696 .40162 Mdot
.696 .40165 Mdot
.696 .40165 Mdot
.696 .40168 Mdot
.696 .40169 Mdot
.696 .40172 Mdot
.696 .40178 Mdot
.696 .40179 Mdot
.696 .40181 Mdot
.696 .40189 Mdot
.696 .4019 Mdot
.696 .40195 Mdot
.696 .40197 Mdot
.696 .40202 Mdot
.696 .40203 Mdot
.696 .40204 Mdot
.696 .40207 Mdot
.696 .40207 Mdot
.696 .40209 Mdot
.696 .40211 Mdot
.696 .40211 Mdot
.696 .40215 Mdot
.696 .40217 Mdot
.696 .40221 Mdot
.696 .40221 Mdot
.696 .40224 Mdot
.696 .40229 Mdot
.696 .40234 Mdot
.696 .40239 Mdot
.696 .40239 Mdot
.696 .4024 Mdot
.696 .40248 Mdot
.696 .40252 Mdot
.696 .40253 Mdot
.696 .40258 Mdot
.696 .40259 Mdot
.696 .4026 Mdot
.696 .40261 Mdot
.696 .40274 Mdot
.696 .40278 Mdot
.696 .40279 Mdot
.696 .40282 Mdot
.696 .40282 Mdot
.696 .40285 Mdot
.696 .40291 Mdot
.696 .40291 Mdot
.696 .40294 Mdot
.696 .40296 Mdot
.696 .40296 Mdot
.696 .40297 Mdot
.696 .40298 Mdot
.696 .40298 Mdot
.696 .40298 Mdot
.696 .40312 Mdot
.696 .40315 Mdot
.696 .4032 Mdot
.696 .40323 Mdot
.696 .40329 Mdot
.696 .40347 Mdot
.696 .40349 Mdot
.696 .40351 Mdot
.696 .40353 Mdot
.696 .40362 Mdot
.696 .4037 Mdot
.696 .4037 Mdot
.696 .40371 Mdot
.696 .40375 Mdot
.696 .4039 Mdot
.696 .40406 Mdot
.696 .40413 Mdot
.696 .40417 Mdot
.696 .40434 Mdot
.696 .40435 Mdot
.696 .40436 Mdot
.696 .40436 Mdot
.696 .40437 Mdot
.696 .40437 Mdot
.696 .40439 Mdot
.696 .40446 Mdot
.696 .40446 Mdot
.696 .40449 Mdot
.696 .40449 Mdot
.696 .40452 Mdot
.696 .40462 Mdot
.696 .40465 Mdot
.696 .40467 Mdot
.696 .40469 Mdot
.696 .4047 Mdot
.696 .40473 Mdot
.696 .40478 Mdot
.696 .40482 Mdot
.696 .40483 Mdot
.696 .40483 Mdot
.696 .40483 Mdot
.696 .40487 Mdot
.696 .40492 Mdot
.696 .40492 Mdot
.696 .40494 Mdot
.696 .40497 Mdot
.696 .40498 Mdot
.696 .40506 Mdot
.696 .40509 Mdot
.696 .4051 Mdot
.696 .40511 Mdot
.696 .40513 Mdot
.696 .40519 Mdot
.696 .40519 Mdot
.696 .4052 Mdot
.696 .40522 Mdot
.696 .40535 Mdot
.696 .40536 Mdot
.696 .40537 Mdot
.696 .40537 Mdot
.696 .40548 Mdot
.696 .4055 Mdot
.696 .40562 Mdot
.696 .40565 Mdot
.696 .40572 Mdot
.696 .40575 Mdot
.696 .40579 Mdot
.696 .40582 Mdot
.696 .40596 Mdot
.696 .40596 Mdot
.696 .40598 Mdot
.696 .40601 Mdot
.696 .40605 Mdot
.696 .40615 Mdot
.696 .40618 Mdot
.696 .40625 Mdot
.696 .40627 Mdot
.696 .40634 Mdot
.696 .40645 Mdot
.696 .40652 Mdot
.696 .40654 Mdot
.696 .40662 Mdot
.696 .4067 Mdot
.696 .40673 Mdot
.696 .40685 Mdot
.696 .40695 Mdot
.696 .40698 Mdot
.696 .40703 Mdot
.696 .40715 Mdot
.696 .40719 Mdot
.696 .40727 Mdot
.696 .40743 Mdot
.696 .40761 Mdot
.696 .40762 Mdot
.696 .40764 Mdot
.696 .40777 Mdot
.696 .40786 Mdot
.696 .40795 Mdot
.696 .40819 Mdot
.696 .4082 Mdot
.696 .40829 Mdot
.696 .40831 Mdot
.696 .40831 Mdot
.696 .40832 Mdot
.696 .40832 Mdot
.696 .40846 Mdot
.696 .40871 Mdot
.696 .40878 Mdot
.696 .40883 Mdot
.696 .40899 Mdot
.696 .40903 Mdot
.696 .40904 Mdot
.696 .40906 Mdot
.696 .40906 Mdot
.696 .40911 Mdot
.696 .40918 Mdot
.696 .40919 Mdot
.696 .4092 Mdot
.696 .40928 Mdot
.696 .40932 Mdot
.696 .40954 Mdot
.696 .40969 Mdot
.696 .40975 Mdot
.696 .40994 Mdot
.696 .40995 Mdot
.696 .40995 Mdot
.696 .41005 Mdot
.696 .41014 Mdot
.696 .41015 Mdot
.696 .41015 Mdot
.696 .41045 Mdot
.696 .41051 Mdot
.696 .41054 Mdot
.696 .41061 Mdot
.696 .41065 Mdot
.696 .41067 Mdot
.696 .41071 Mdot
.696 .41075 Mdot
.696 .41087 Mdot
.696 .41097 Mdot
.696 .41102 Mdot
.696 .41102 Mdot
.696 .41104 Mdot
.696 .41106 Mdot
.696 .41111 Mdot
.696 .41131 Mdot
.696 .41132 Mdot
.696 .41135 Mdot
.696 .41148 Mdot
.696 .4115 Mdot
.696 .4115 Mdot
.696 .41153 Mdot
.696 .41158 Mdot
.696 .41159 Mdot
.696 .41159 Mdot
.696 .4116 Mdot
.696 .41171 Mdot
.696 .41175 Mdot
.696 .41176 Mdot
.696 .41187 Mdot
.696 .41203 Mdot
.696 .41204 Mdot
.696 .41204 Mdot
.696 .41205 Mdot
.696 .41208 Mdot
.696 .41209 Mdot
.696 .41211 Mdot
.696 .41216 Mdot
.696 .41228 Mdot
.696 .41235 Mdot
.696 .41247 Mdot
.696 .41251 Mdot
.696 .41262 Mdot
.696 .41263 Mdot
.696 .41274 Mdot
.696 .41277 Mdot
.696 .41277 Mdot
.696 .41281 Mdot
.696 .41292 Mdot
.696 .41294 Mdot
.696 .41305 Mdot
.696 .41308 Mdot
.696 .41317 Mdot
.696 .41328 Mdot
.696 .41338 Mdot
.696 .41339 Mdot
.696 .4134 Mdot
.696 .4134 Mdot
.696 .41347 Mdot
.696 .41348 Mdot
.696 .4135 Mdot
.696 .41355 Mdot
.696 .41356 Mdot
.696 .41357 Mdot
.696 .41361 Mdot
.696 .41362 Mdot
.696 .41362 Mdot
.696 .41369 Mdot
.696 .41371 Mdot
.696 .41375 Mdot
.696 .41375 Mdot
.696 .41377 Mdot
.696 .41377 Mdot
.696 .4138 Mdot
.696 .41382 Mdot
.696 .41401 Mdot
.696 .41409 Mdot
.696 .41419 Mdot
.696 .4142 Mdot
.696 .41422 Mdot
.696 .41422 Mdot
.696 .41423 Mdot
.696 .41425 Mdot
.696 .41427 Mdot
.696 .41431 Mdot
.696 .41433 Mdot
.696 .41436 Mdot
.696 .41442 Mdot
.696 .41459 Mdot
.696 .41461 Mdot
.696 .41461 Mdot
.696 .41463 Mdot
.696 .41464 Mdot
.696 .41467 Mdot
.696 .41469 Mdot
.696 .41469 Mdot
.696 .41469 Mdot
.696 .4147 Mdot
.696 .4147 Mdot
.696 .4147 Mdot
.696 .41555 Mdot
.696 .41587 Mdot
.696 .41618 Mdot
.696 .41663 Mdot
.696 .41673 Mdot
.696 .41675 Mdot
.696 .41737 Mdot
.696 .41789 Mdot
.696 .41816 Mdot
.696 .41829 Mdot
.696 .41868 Mdot
.696 .41884 Mdot
.696 .41893 Mdot
.696 .41924 Mdot
.696 .4196 Mdot
.696 .41967 Mdot
.696 .41991 Mdot
.696 .42014 Mdot
.696 .42019 Mdot
.696 .42041 Mdot
.696 .42069 Mdot
.696 .42088 Mdot
.696 .42093 Mdot
.696 .42111 Mdot
.696 .4212 Mdot
.696 .42138 Mdot
.696 .42138 Mdot
.696 .42139 Mdot
.696 .42139 Mdot
.696 .42139 Mdot
.696 .42139 Mdot
.696 .42143 Mdot
.696 .42143 Mdot
.696 .42144 Mdot
.696 .42144 Mdot
.696 .42145 Mdot
.696 .42149 Mdot
.696 .4215 Mdot
.696 .42151 Mdot
.696 .42152 Mdot
.696 .42153 Mdot
.696 .42155 Mdot
.696 .42156 Mdot
.696 .42157 Mdot
.696 .42157 Mdot
.696 .4216 Mdot
.696 .42162 Mdot
.696 .42162 Mdot
.696 .42166 Mdot
.696 .42167 Mdot
.696 .42167 Mdot
.696 .42168 Mdot
.696 .4217 Mdot
.696 .4217 Mdot
.696 .4217 Mdot
.696 .42171 Mdot
.696 .42176 Mdot
.696 .42176 Mdot
.696 .42176 Mdot
.696 .4218 Mdot
.696 .42181 Mdot
.696 .42186 Mdot
.696 .42189 Mdot
.696 .42191 Mdot
.696 .42197 Mdot
.696 .42197 Mdot
.696 .422 Mdot
.696 .42204 Mdot
.696 .42206 Mdot
.696 .42207 Mdot
.696 .42215 Mdot
.696 .42216 Mdot
.696 .42221 Mdot
.696 .42229 Mdot
.696 .42231 Mdot
.696 .42235 Mdot
.696 .42236 Mdot
.696 .42244 Mdot
.696 .42254 Mdot
.696 .42257 Mdot
.696 .42267 Mdot
.696 .42267 Mdot
.696 .42271 Mdot
.696 .42271 Mdot
.696 .42282 Mdot
.696 .42284 Mdot
.696 .42286 Mdot
.696 .42292 Mdot
.696 .42292 Mdot
.696 .42292 Mdot
.696 .42293 Mdot
.696 .42294 Mdot
.696 .42296 Mdot
.696 .42296 Mdot
.696 .42299 Mdot
.696 .423 Mdot
.696 .42306 Mdot
.696 .42311 Mdot
.696 .42318 Mdot
.696 .42318 Mdot
.696 .42318 Mdot
.696 .42321 Mdot
.696 .42324 Mdot
.696 .42324 Mdot
.696 .42324 Mdot
.696 .42332 Mdot
.696 .42334 Mdot
.696 .42337 Mdot
.696 .42338 Mdot
.696 .4234 Mdot
.696 .42341 Mdot
.696 .42344 Mdot
.696 .42348 Mdot
.696 .4235 Mdot
.696 .42351 Mdot
.696 .42357 Mdot
.696 .42358 Mdot
.696 .42362 Mdot
.696 .42363 Mdot
.696 .42364 Mdot
.696 .42365 Mdot
.696 .42368 Mdot
.696 .42369 Mdot
.696 .42372 Mdot
.696 .42377 Mdot
.696 .42377 Mdot
.696 .42377 Mdot
.696 .42377 Mdot
.696 .42378 Mdot
.696 .42378 Mdot
.696 .42379 Mdot
.696 .42381 Mdot
.696 .42384 Mdot
.696 .42389 Mdot
.696 .42393 Mdot
.696 .42393 Mdot
.696 .42397 Mdot
.696 .42398 Mdot
.696 .42399 Mdot
.696 .42401 Mdot
.696 .42402 Mdot
.696 .42402 Mdot
.696 .42405 Mdot
.696 .42406 Mdot
.696 .42409 Mdot
.696 .42412 Mdot
.696 .42415 Mdot
.696 .42415 Mdot
.696 .42415 Mdot
.696 .42415 Mdot
.696 .42417 Mdot
.696 .42418 Mdot
.696 .42418 Mdot
.696 .42419 Mdot
.696 .4242 Mdot
.696 .4242 Mdot
.696 .42421 Mdot
.696 .42421 Mdot
.696 .42421 Mdot
.696 .42423 Mdot
.696 .42425 Mdot
.696 .42425 Mdot
.696 .42426 Mdot
.696 .42426 Mdot
.696 .42426 Mdot
.696 .42427 Mdot
.696 .42432 Mdot
.696 .42434 Mdot
.696 .42437 Mdot
.696 .42438 Mdot
.696 .42439 Mdot
.696 .42441 Mdot
.696 .42442 Mdot
.696 .42444 Mdot
.696 .42449 Mdot
.696 .42449 Mdot
.696 .42449 Mdot
.696 .4245 Mdot
.696 .4245 Mdot
.696 .42452 Mdot
.696 .42452 Mdot
.696 .42452 Mdot
.696 .42452 Mdot
.696 .42452 Mdot
.698 .29585 Mdot
.698 .29585 Mdot
.698 .29586 Mdot
.698 .29586 Mdot
.698 .29586 Mdot
.698 .29587 Mdot
.698 .29589 Mdot
.698 .29589 Mdot
.698 .29591 Mdot
.698 .29594 Mdot
.698 .29594 Mdot
.698 .29598 Mdot
.698 .296 Mdot
.698 .29607 Mdot
.698 .29608 Mdot
.698 .29612 Mdot
.698 .29615 Mdot
.698 .29618 Mdot
.698 .29618 Mdot
.698 .29622 Mdot
.698 .29622 Mdot
.698 .29628 Mdot
.698 .29634 Mdot
.698 .29635 Mdot
.698 .29644 Mdot
.698 .29655 Mdot
.698 .29658 Mdot
.698 .29664 Mdot
.698 .29664 Mdot
.698 .2967 Mdot
.698 .29671 Mdot
.698 .29672 Mdot
.698 .29678 Mdot
.698 .29685 Mdot
.698 .29692 Mdot
.698 .29697 Mdot
.698 .29698 Mdot
.698 .29702 Mdot
.698 .29703 Mdot
.698 .29705 Mdot
.698 .29706 Mdot
.698 .29707 Mdot
.698 .2972 Mdot
.698 .2973 Mdot
.698 .29733 Mdot
.698 .29733 Mdot
.698 .29734 Mdot
.698 .29736 Mdot
.698 .29737 Mdot
.698 .29738 Mdot
.698 .29742 Mdot
.698 .29759 Mdot
.698 .29765 Mdot
.698 .29768 Mdot
.698 .29769 Mdot
.698 .29786 Mdot
.698 .29789 Mdot
.698 .29792 Mdot
.698 .29801 Mdot
.698 .29803 Mdot
.698 .2981 Mdot
.698 .29816 Mdot
.698 .29823 Mdot
.698 .2983 Mdot
.698 .29834 Mdot
.698 .29838 Mdot
.698 .29841 Mdot
.698 .29878 Mdot
.698 .29886 Mdot
.698 .29897 Mdot
.698 .29903 Mdot
.698 .29903 Mdot
.698 .29904 Mdot
.698 .29917 Mdot
.698 .29922 Mdot
.698 .29926 Mdot
.698 .29926 Mdot
.698 .29932 Mdot
.698 .29933 Mdot
.698 .29935 Mdot
.698 .29937 Mdot
.698 .29937 Mdot
.698 .29939 Mdot
.698 .29943 Mdot
.698 .29943 Mdot
.698 .29945 Mdot
.698 .29946 Mdot
.698 .29952 Mdot
.698 .29957 Mdot
.698 .29959 Mdot
.698 .29969 Mdot
.698 .29972 Mdot
.698 .29979 Mdot
.698 .29979 Mdot
.698 .29981 Mdot
.698 .29989 Mdot
.698 .30008 Mdot
.698 .30008 Mdot
.698 .30014 Mdot
.698 .30023 Mdot
.698 .30023 Mdot
.698 .30024 Mdot
.698 .30028 Mdot
.698 .3003 Mdot
.698 .30041 Mdot
.698 .30042 Mdot
.698 .30043 Mdot
.698 .30043 Mdot
.698 .30049 Mdot
.698 .30049 Mdot
.698 .3005 Mdot
.698 .30096 Mdot
.698 .30101 Mdot
.698 .30109 Mdot
.698 .30123 Mdot
.698 .3013 Mdot
.698 .30148 Mdot
.698 .30173 Mdot
.698 .30208 Mdot
.698 .30209 Mdot
.698 .30212 Mdot
.698 .30213 Mdot
.698 .30313 Mdot
.698 .30353 Mdot
.698 .30378 Mdot
.698 .30408 Mdot
.698 .30408 Mdot
.698 .30488 Mdot
.698 .30501 Mdot
.698 .30677 Mdot
.698 .30682 Mdot
.698 .30701 Mdot
.698 .30712 Mdot
.698 .30717 Mdot
.698 .30754 Mdot
.698 .30765 Mdot
.698 .30771 Mdot
.698 .30857 Mdot
.698 .30902 Mdot
.698 .30904 Mdot
.698 .30911 Mdot
.698 .31016 Mdot
.698 .3105 Mdot
.698 .31054 Mdot
.698 .31116 Mdot
.698 .31304 Mdot
.698 .316 Mdot
.698 .31648 Mdot
.698 .3166 Mdot
.698 .31737 Mdot
.698 .31742 Mdot
.698 .31748 Mdot
.698 .31811 Mdot
.698 .3193 Mdot
.698 .3199 Mdot
.698 .31996 Mdot
.698 .31998 Mdot
.698 .31998 Mdot
.698 .32002 Mdot
.698 .32003 Mdot
.698 .32004 Mdot
.698 .32005 Mdot
.698 .32007 Mdot
.698 .32013 Mdot
.698 .32013 Mdot
.698 .3202 Mdot
.698 .3203 Mdot
.698 .32031 Mdot
.698 .32045 Mdot
.698 .3205 Mdot
.698 .32078 Mdot
.698 .3208 Mdot
.698 .32096 Mdot
.698 .32106 Mdot
.698 .32112 Mdot
.698 .32114 Mdot
.698 .32117 Mdot
.698 .32129 Mdot
.698 .32129 Mdot
.698 .32151 Mdot
.698 .32152 Mdot
.698 .32152 Mdot
.698 .32173 Mdot
.698 .32174 Mdot
.698 .32202 Mdot
.698 .32208 Mdot
.698 .32248 Mdot
.698 .3226 Mdot
.698 .32278 Mdot
.698 .32281 Mdot
.698 .32301 Mdot
.698 .32306 Mdot
.698 .3231 Mdot
.698 .32329 Mdot
.698 .32354 Mdot
.698 .32379 Mdot
.698 .32398 Mdot
.698 .32402 Mdot
.698 .32417 Mdot
.698 .3242 Mdot
.698 .32428 Mdot
.698 .32431 Mdot
.698 .32437 Mdot
.698 .32485 Mdot
.698 .3252 Mdot
.698 .32529 Mdot
.698 .32529 Mdot
.698 .32532 Mdot
.698 .32533 Mdot
.698 .32543 Mdot
.698 .32545 Mdot
.698 .32548 Mdot
.698 .32549 Mdot
.698 .32562 Mdot
.698 .32591 Mdot
.698 .32624 Mdot
.698 .32625 Mdot
.698 .32649 Mdot
.698 .32649 Mdot
.698 .3266 Mdot
.698 .32663 Mdot
.698 .32721 Mdot
.698 .32726 Mdot
.698 .3274 Mdot
.698 .3275 Mdot
.698 .32754 Mdot
.698 .32777 Mdot
.698 .32783 Mdot
.698 .3279 Mdot
.698 .32818 Mdot
.698 .3284 Mdot
.698 .32866 Mdot
.698 .32894 Mdot
.698 .32908 Mdot
.698 .32923 Mdot
.698 .32934 Mdot
.698 .32942 Mdot
.698 .3301 Mdot
.698 .33076 Mdot
.698 .33095 Mdot
.698 .33104 Mdot
.698 .33147 Mdot
.698 .33171 Mdot
.698 .33172 Mdot
.698 .33176 Mdot
.698 .33222 Mdot
.698 .33237 Mdot
.698 .33242 Mdot
.698 .33257 Mdot
.698 .33257 Mdot
.698 .33282 Mdot
.698 .33284 Mdot
.698 .33294 Mdot
.698 .33298 Mdot
.698 .33302 Mdot
.698 .33308 Mdot
.698 .33323 Mdot
.698 .33324 Mdot
.698 .33329 Mdot
.698 .33334 Mdot
.698 .3336 Mdot
.698 .33376 Mdot
.698 .33385 Mdot
.698 .33422 Mdot
.698 .33434 Mdot
.698 .33461 Mdot
.698 .33462 Mdot
.698 .3347 Mdot
.698 .33499 Mdot
.698 .33573 Mdot
.698 .33575 Mdot
.698 .33598 Mdot
.698 .33619 Mdot
.698 .33633 Mdot
.698 .33633 Mdot
.698 .33637 Mdot
.698 .33651 Mdot
.698 .3366 Mdot
.698 .337 Mdot
.698 .33705 Mdot
.698 .33709 Mdot
.698 .33711 Mdot
.698 .33722 Mdot
.698 .33729 Mdot
.698 .33731 Mdot
.698 .33732 Mdot
.698 .33737 Mdot
.698 .33915 Mdot
.698 .33932 Mdot
.698 .33964 Mdot
.698 .34017 Mdot
.698 .34044 Mdot
.698 .34089 Mdot
.698 .34114 Mdot
.698 .34212 Mdot
.698 .3427 Mdot
.698 .34343 Mdot
.698 .34349 Mdot
.698 .34359 Mdot
.698 .34364 Mdot
.698 .34605 Mdot
.698 .3465 Mdot
.698 .34743 Mdot
.698 .34852 Mdot
.698 .34893 Mdot
.698 .34984 Mdot
.698 .3505 Mdot
.698 .35096 Mdot
.698 .35096 Mdot
.698 .35135 Mdot
.698 .35265 Mdot
.698 .35266 Mdot
.698 .35337 Mdot
.698 .35367 Mdot
.698 .35384 Mdot
.698 .35411 Mdot
.698 .35431 Mdot
.698 .35431 Mdot
.698 .35467 Mdot
.698 .3549 Mdot
.698 .35544 Mdot
.698 .35597 Mdot
.698 .35609 Mdot
.698 .35697 Mdot
.698 .35744 Mdot
.698 .35837 Mdot
.698 .35839 Mdot
.698 .35866 Mdot
.698 .35965 Mdot
.698 .36002 Mdot
.698 .36025 Mdot
.698 .36043 Mdot
.698 .36087 Mdot
.698 .36093 Mdot
.698 .36101 Mdot
.698 .36121 Mdot
.698 .36127 Mdot
.698 .36136 Mdot
.698 .36148 Mdot
.698 .36153 Mdot
.698 .36243 Mdot
.698 .36257 Mdot
.698 .36258 Mdot
.698 .36269 Mdot
.698 .36299 Mdot
.698 .36302 Mdot
.698 .36304 Mdot
.698 .36321 Mdot
.698 .36356 Mdot
.698 .36374 Mdot
.698 .36376 Mdot
.698 .36377 Mdot
.698 .36401 Mdot
.698 .36404 Mdot
.698 .36419 Mdot
.698 .36512 Mdot
.698 .36574 Mdot
.698 .36595 Mdot
.698 .36596 Mdot
.698 .36608 Mdot
.698 .36645 Mdot
.698 .36648 Mdot
.698 .36649 Mdot
.698 .36665 Mdot
.698 .36697 Mdot
.698 .36699 Mdot
.698 .36703 Mdot
.698 .36717 Mdot
.698 .3672 Mdot
.698 .36724 Mdot
.698 .36731 Mdot
.698 .36733 Mdot
.698 .36804 Mdot
.698 .3681 Mdot
.698 .36844 Mdot
.698 .36844 Mdot
.698 .36858 Mdot
.698 .36869 Mdot
.698 .36887 Mdot
.698 .36936 Mdot
.698 .36936 Mdot
.698 .36938 Mdot
.698 .36938 Mdot
.698 .36956 Mdot
.698 .36969 Mdot
.698 .36979 Mdot
.698 .36982 Mdot
.698 .3699 Mdot
.698 .36994 Mdot
.698 .36997 Mdot
.698 .37027 Mdot
.698 .37028 Mdot
.698 .37038 Mdot
.698 .37038 Mdot
.698 .37038 Mdot
.698 .37047 Mdot
.698 .37065 Mdot
.698 .37078 Mdot
.698 .37087 Mdot
.698 .37095 Mdot
.698 .37119 Mdot
.698 .37165 Mdot
.698 .37222 Mdot
.698 .37228 Mdot
.698 .37252 Mdot
.698 .37284 Mdot
.698 .37291 Mdot
.698 .37304 Mdot
.698 .37313 Mdot
.698 .3732 Mdot
.698 .37323 Mdot
.698 .37331 Mdot
.698 .37338 Mdot
.698 .37342 Mdot
.698 .37375 Mdot
.698 .37385 Mdot
.698 .3741 Mdot
.698 .37427 Mdot
.698 .37469 Mdot
.698 .37481 Mdot
.698 .37534 Mdot
.698 .37549 Mdot
.698 .37566 Mdot
.698 .37569 Mdot
.698 .37571 Mdot
.698 .37579 Mdot
.698 .37589 Mdot
.698 .37589 Mdot
.698 .37612 Mdot
.698 .37626 Mdot
.698 .37631 Mdot
.698 .37651 Mdot
.698 .37663 Mdot
.698 .37674 Mdot
.698 .37675 Mdot
.698 .37682 Mdot
.698 .37682 Mdot
.698 .37704 Mdot
.698 .37718 Mdot
.698 .37746 Mdot
.698 .37754 Mdot
.698 .37778 Mdot
.698 .37784 Mdot
.698 .3779 Mdot
.698 .37792 Mdot
.698 .37793 Mdot
.698 .37794 Mdot
.698 .37807 Mdot
.698 .37816 Mdot
.698 .37818 Mdot
.698 .37819 Mdot
.698 .37822 Mdot
.698 .37823 Mdot
.698 .37823 Mdot
.698 .37827 Mdot
.698 .37849 Mdot
.698 .3785 Mdot
.698 .37863 Mdot
.698 .37866 Mdot
.698 .37868 Mdot
.698 .37875 Mdot
.698 .37876 Mdot
.698 .37882 Mdot
.698 .37886 Mdot
.698 .37891 Mdot
.698 .37897 Mdot
.698 .37902 Mdot
.698 .37904 Mdot
.698 .37929 Mdot
.698 .37934 Mdot
.698 .37944 Mdot
.698 .37945 Mdot
.698 .37945 Mdot
.698 .37953 Mdot
.698 .37956 Mdot
.698 .37958 Mdot
.698 .37958 Mdot
.698 .37962 Mdot
.698 .37964 Mdot
.698 .37964 Mdot
.698 .37965 Mdot
.698 .37966 Mdot
.698 .37968 Mdot
.698 .37968 Mdot
.698 .3797 Mdot
.698 .37974 Mdot
.698 .37976 Mdot
.698 .37983 Mdot
.698 .37984 Mdot
.698 .3799 Mdot
.698 .37994 Mdot
.698 .38004 Mdot
.698 .38007 Mdot
.698 .38014 Mdot
.698 .38016 Mdot
.698 .38017 Mdot
.698 .38022 Mdot
.698 .38022 Mdot
.698 .38025 Mdot
.698 .38025 Mdot
.698 .38026 Mdot
.698 .40253 Mdot
.698 .40254 Mdot
.698 .40254 Mdot
.698 .40255 Mdot
.698 .40255 Mdot
.698 .40256 Mdot
.698 .40257 Mdot
.698 .40257 Mdot
.698 .40259 Mdot
.698 .4026 Mdot
.698 .40263 Mdot
.698 .40265 Mdot
.698 .40266 Mdot
.698 .40267 Mdot
.698 .40269 Mdot
.698 .40269 Mdot
.698 .40271 Mdot
.698 .40271 Mdot
.698 .40271 Mdot
.698 .40272 Mdot
.698 .40272 Mdot
.698 .40272 Mdot
.698 .40272 Mdot
.698 .40273 Mdot
.698 .40274 Mdot
.698 .40274 Mdot
.698 .40275 Mdot
.698 .40276 Mdot
.698 .40278 Mdot
.698 .40278 Mdot
.698 .40278 Mdot
.698 .40282 Mdot
.698 .40283 Mdot
.698 .40291 Mdot
.698 .40291 Mdot
.698 .40293 Mdot
.698 .40295 Mdot
.698 .40296 Mdot
.698 .40297 Mdot
.698 .40299 Mdot
.698 .403 Mdot
.698 .40302 Mdot
.698 .40302 Mdot
.698 .40303 Mdot
.698 .40307 Mdot
.698 .40307 Mdot
.698 .40314 Mdot
.698 .40315 Mdot
.698 .40316 Mdot
.698 .40316 Mdot
.698 .40316 Mdot
.698 .40317 Mdot
.698 .40317 Mdot
.698 .4032 Mdot
.698 .40324 Mdot
.698 .40325 Mdot
.698 .40325 Mdot
.698 .40326 Mdot
.698 .40327 Mdot
.698 .40329 Mdot
.698 .40336 Mdot
.698 .40339 Mdot
.698 .40347 Mdot
.698 .40351 Mdot
.698 .40358 Mdot
.698 .40358 Mdot
.698 .4036 Mdot
.698 .4036 Mdot
.698 .40364 Mdot
.698 .40367 Mdot
.698 .40373 Mdot
.698 .40375 Mdot
.698 .40379 Mdot
.698 .40386 Mdot
.698 .40386 Mdot
.698 .40389 Mdot
.698 .40391 Mdot
.698 .40392 Mdot
.698 .40393 Mdot
.698 .40398 Mdot
.698 .40402 Mdot
.698 .40418 Mdot
.698 .40421 Mdot
.698 .40434 Mdot
.698 .40439 Mdot
.698 .40446 Mdot
.698 .40449 Mdot
.698 .40459 Mdot
.698 .4046 Mdot
.698 .40462 Mdot
.698 .40465 Mdot
.698 .40466 Mdot
.698 .40467 Mdot
.698 .4047 Mdot
.698 .40474 Mdot
.698 .40476 Mdot
.698 .40485 Mdot
.698 .40492 Mdot
.698 .40494 Mdot
.698 .40511 Mdot
.698 .40524 Mdot
.698 .40531 Mdot
.698 .40533 Mdot
.698 .40536 Mdot
.698 .4054 Mdot
.698 .40545 Mdot
.698 .40547 Mdot
.698 .40547 Mdot
.698 .40547 Mdot
.698 .4055 Mdot
.698 .40551 Mdot
.698 .40559 Mdot
.698 .4056 Mdot
.698 .40561 Mdot
.698 .40563 Mdot
.698 .40564 Mdot
.698 .40567 Mdot
.698 .40571 Mdot
.698 .40576 Mdot
.698 .40576 Mdot
.698 .40577 Mdot
.698 .40577 Mdot
.698 .40591 Mdot
.698 .40596 Mdot
.698 .40599 Mdot
.698 .40603 Mdot
.698 .40603 Mdot
.698 .40613 Mdot
.698 .40614 Mdot
.698 .40635 Mdot
.698 .40635 Mdot
.698 .40637 Mdot
.698 .40638 Mdot
.698 .40639 Mdot
.698 .40643 Mdot
.698 .40644 Mdot
.698 .40645 Mdot
.698 .40654 Mdot
.698 .40658 Mdot
.698 .40659 Mdot
.698 .40659 Mdot
.698 .4067 Mdot
.698 .40673 Mdot
.698 .40674 Mdot
.698 .4068 Mdot
.698 .40697 Mdot
.698 .40723 Mdot
.698 .40727 Mdot
.698 .40728 Mdot
.698 .40735 Mdot
.698 .40735 Mdot
.698 .40735 Mdot
.698 .40741 Mdot
.698 .4075 Mdot
.698 .40755 Mdot
.698 .40756 Mdot
.698 .40756 Mdot
.698 .40765 Mdot
.698 .40768 Mdot
.698 .40768 Mdot
.698 .40772 Mdot
.698 .40797 Mdot
.698 .40798 Mdot
.698 .40802 Mdot
.698 .40804 Mdot
.698 .40806 Mdot
.698 .40811 Mdot
.698 .40814 Mdot
.698 .40815 Mdot
.698 .40827 Mdot
.698 .40832 Mdot
.698 .40838 Mdot
.698 .40849 Mdot
.698 .40876 Mdot
.698 .40883 Mdot
.698 .40884 Mdot
.698 .40909 Mdot
.698 .40922 Mdot
.698 .40946 Mdot
.698 .40949 Mdot
.698 .40964 Mdot
.698 .40978 Mdot
.698 .40984 Mdot
.698 .40994 Mdot
.698 .40994 Mdot
.698 .40999 Mdot
.698 .41007 Mdot
.698 .41011 Mdot
.698 .41019 Mdot
.698 .41038 Mdot
.698 .41039 Mdot
.698 .41074 Mdot
.698 .41084 Mdot
.698 .41084 Mdot
.698 .41096 Mdot
.698 .41114 Mdot
.698 .41138 Mdot
.698 .41149 Mdot
.698 .41178 Mdot
.698 .41203 Mdot
.698 .41215 Mdot
.698 .41278 Mdot
.698 .4128 Mdot
.698 .41282 Mdot
.698 .41284 Mdot
.698 .41303 Mdot
.698 .41318 Mdot
.698 .41344 Mdot
.698 .41351 Mdot
.698 .41363 Mdot
.698 .4137 Mdot
.698 .41384 Mdot
.698 .41392 Mdot
.698 .41397 Mdot
.698 .41443 Mdot
.698 .41445 Mdot
.698 .41445 Mdot
.698 .41446 Mdot
.698 .41447 Mdot
.698 .41451 Mdot
.698 .41451 Mdot
.698 .41452 Mdot
.698 .41453 Mdot
.698 .41464 Mdot
.698 .41466 Mdot
.698 .4147 Mdot
.698 .41471 Mdot
.698 .41471 Mdot
.698 .41474 Mdot
.698 .4148 Mdot
.698 .41486 Mdot
.698 .41487 Mdot
.698 .41506 Mdot
.698 .41514 Mdot
.698 .41516 Mdot
.698 .41516 Mdot
.698 .41523 Mdot
.698 .41526 Mdot
.698 .41536 Mdot
.698 .41538 Mdot
.698 .41543 Mdot
.698 .4155 Mdot
.698 .41551 Mdot
.698 .41552 Mdot
.698 .41552 Mdot
.698 .41556 Mdot
.698 .41558 Mdot
.698 .41559 Mdot
.698 .4156 Mdot
.698 .41563 Mdot
.698 .41563 Mdot
.698 .4157 Mdot
.698 .4157 Mdot
.698 .41574 Mdot
.698 .41575 Mdot
.698 .41579 Mdot
.698 .41591 Mdot
.698 .41592 Mdot
.698 .41592 Mdot
.698 .41599 Mdot
.698 .4161 Mdot
.698 .41612 Mdot
.698 .41617 Mdot
.698 .41635 Mdot
.698 .41652 Mdot
.698 .41655 Mdot
.698 .41657 Mdot
.698 .41662 Mdot
.698 .41665 Mdot
.698 .41672 Mdot
.698 .41679 Mdot
.698 .41685 Mdot
.698 .41693 Mdot
.698 .41694 Mdot
.698 .41696 Mdot
.698 .41702 Mdot
.698 .41703 Mdot
.698 .41706 Mdot
.698 .41709 Mdot
.698 .4171 Mdot
.698 .41726 Mdot
.698 .41727 Mdot
.698 .41729 Mdot
.698 .4173 Mdot
.698 .41736 Mdot
.698 .41736 Mdot
.698 .41745 Mdot
.698 .41752 Mdot
.698 .41756 Mdot
.698 .41756 Mdot
.698 .41757 Mdot
.698 .41758 Mdot
.698 .4176 Mdot
.698 .4176 Mdot
.698 .41761 Mdot
.698 .41761 Mdot
.698 .41764 Mdot
.698 .41773 Mdot
.698 .41786 Mdot
.698 .41787 Mdot
.698 .41788 Mdot
.698 .4179 Mdot
.698 .41791 Mdot
.698 .41795 Mdot
.698 .41796 Mdot
.698 .41801 Mdot
.698 .41807 Mdot
.698 .41814 Mdot
.698 .41819 Mdot
.698 .4182 Mdot
.698 .41822 Mdot
.698 .41827 Mdot
.698 .41828 Mdot
.698 .41832 Mdot
.698 .41835 Mdot
.698 .41846 Mdot
.698 .41848 Mdot
.698 .41855 Mdot
.698 .41855 Mdot
.698 .41861 Mdot
.698 .41861 Mdot
.698 .41861 Mdot
.698 .41867 Mdot
.698 .41867 Mdot
.698 .4187 Mdot
.698 .41871 Mdot
.698 .41872 Mdot
.698 .41873 Mdot
.698 .41876 Mdot
.698 .4188 Mdot
.698 .41881 Mdot
.698 .41888 Mdot
.698 .41889 Mdot
.698 .41893 Mdot
.698 .41893 Mdot
.698 .41896 Mdot
.698 .41898 Mdot
.698 .41898 Mdot
.698 .41899 Mdot
.698 .419 Mdot
.698 .419 Mdot
.698 .41901 Mdot
.698 .41901 Mdot
.698 .41902 Mdot
.698 .41902 Mdot
.698 .41903 Mdot
.698 .41904 Mdot
.698 .4192 Mdot
.698 .41952 Mdot
.698 .41969 Mdot
.698 .4197 Mdot
.698 .41972 Mdot
.698 .41992 Mdot
.698 .41995 Mdot
.698 .42008 Mdot
.698 .42088 Mdot
.698 .42139 Mdot
.698 .42156 Mdot
.698 .42157 Mdot
.698 .42167 Mdot
.698 .42195 Mdot
.698 .42197 Mdot
.698 .42198 Mdot
.698 .4221 Mdot
.698 .42234 Mdot
.698 .42235 Mdot
.698 .42238 Mdot
.698 .42249 Mdot
.698 .4225 Mdot
.698 .42253 Mdot
.698 .42258 Mdot
.698 .4226 Mdot
.698 .42308 Mdot
.698 .42312 Mdot
.698 .42334 Mdot
.698 .42334 Mdot
.698 .42343 Mdot
.698 .4235 Mdot
.698 .42361 Mdot
.698 .42389 Mdot
.698 .4239 Mdot
.698 .4239 Mdot
.698 .42391 Mdot
.698 .424 Mdot
.698 .42408 Mdot
.698 .42413 Mdot
.698 .42415 Mdot
.698 .42419 Mdot
.698 .42421 Mdot
.698 .42422 Mdot
.698 .42435 Mdot
.698 .42436 Mdot
.698 .42436 Mdot
.698 .42437 Mdot
.698 .42437 Mdot
.698 .42438 Mdot
.698 .42438 Mdot
.698 .42441 Mdot
.698 .42442 Mdot
.698 .42443 Mdot
.698 .42443 Mdot
.698 .42443 Mdot
.698 .42446 Mdot
.698 .42447 Mdot
.698 .42447 Mdot
.698 .42453 Mdot
.698 .42455 Mdot
.698 .42456 Mdot
.698 .42458 Mdot
.698 .42459 Mdot
.698 .42461 Mdot
.698 .42462 Mdot
.698 .42463 Mdot
.698 .42465 Mdot
.698 .42466 Mdot
.698 .42466 Mdot
.698 .42466 Mdot
.698 .42467 Mdot
.698 .42468 Mdot
.698 .42468 Mdot
.698 .42468 Mdot
.698 .42469 Mdot
.698 .42469 Mdot
.698 .42471 Mdot
.698 .42471 Mdot
.698 .42472 Mdot
.698 .42474 Mdot
.698 .42477 Mdot
.698 .42477 Mdot
.698 .42477 Mdot
.698 .42479 Mdot
.698 .42482 Mdot
.698 .42485 Mdot
.698 .42495 Mdot
.698 .42496 Mdot
.698 .42497 Mdot
.698 .42498 Mdot
.698 .425 Mdot
.698 .42502 Mdot
.698 .42504 Mdot
.698 .42506 Mdot
.698 .42507 Mdot
.698 .42509 Mdot
.698 .4251 Mdot
.698 .42511 Mdot
.698 .42516 Mdot
.698 .42516 Mdot
.698 .42517 Mdot
.698 .42519 Mdot
.698 .42524 Mdot
.698 .42525 Mdot
.698 .42525 Mdot
.698 .42525 Mdot
.698 .42526 Mdot
.698 .42526 Mdot
.698 .42527 Mdot
.698 .42527 Mdot
.698 .4253 Mdot
.698 .42534 Mdot
.698 .42534 Mdot
.698 .42535 Mdot
.698 .42535 Mdot
.698 .42535 Mdot
.698 .42537 Mdot
.698 .42537 Mdot
.698 .42538 Mdot
.698 .4254 Mdot
.698 .42542 Mdot
.698 .42544 Mdot
.698 .42544 Mdot
.698 .42545 Mdot
.698 .42546 Mdot
.698 .42547 Mdot
.698 .42548 Mdot
.698 .42549 Mdot
.698 .42552 Mdot
.698 .42555 Mdot
.698 .42555 Mdot
.698 .42557 Mdot
.698 .42559 Mdot
.698 .42559 Mdot
.698 .4256 Mdot
.698 .4256 Mdot
.698 .42561 Mdot
.698 .42561 Mdot
.698 .42563 Mdot
.698 .42563 Mdot
.698 .42565 Mdot
.698 .42566 Mdot
.698 .42567 Mdot
.698 .42567 Mdot
.698 .42568 Mdot
.698 .42568 Mdot
.698 .42568 Mdot
.698 .42569 Mdot
.698 .42569 Mdot
.698 .42569 Mdot
.698 .42569 Mdot
.698 .4257 Mdot
.698 .4257 Mdot
.7 .29266 Mdot
.7 .29266 Mdot
.7 .29266 Mdot
.7 .29267 Mdot
.7 .29267 Mdot
.7 .29268 Mdot
.7 .29271 Mdot
.7 .29272 Mdot
.7 .29272 Mdot
.7 .29272 Mdot
.7 .29273 Mdot
.7 .29274 Mdot
.7 .29276 Mdot
.7 .29279 Mdot
.7 .29279 Mdot
.7 .29279 Mdot
.7 .29284 Mdot
.7 .29288 Mdot
.7 .29288 Mdot
.7 .29289 Mdot
.7 .2929 Mdot
.7 .29291 Mdot
.7 .29292 Mdot
.7 .29293 Mdot
.7 .29294 Mdot
.7 .29295 Mdot
.7 .29298 Mdot
.7 .29299 Mdot
.7 .293 Mdot
.7 .29303 Mdot
.7 .29304 Mdot
.7 .29306 Mdot
.7 .29309 Mdot
.7 .29309 Mdot
.7 .2931 Mdot
.7 .29315 Mdot
.7 .29316 Mdot
.7 .29317 Mdot
.7 .29317 Mdot
.7 .29322 Mdot
.7 .29325 Mdot
.7 .29326 Mdot
.7 .2933 Mdot
.7 .29337 Mdot
.7 .29337 Mdot
.7 .2934 Mdot
.7 .29349 Mdot
.7 .2935 Mdot
.7 .2935 Mdot
.7 .29352 Mdot
.7 .29352 Mdot
.7 .29353 Mdot
.7 .29357 Mdot
.7 .29357 Mdot
.7 .29358 Mdot
.7 .29358 Mdot
.7 .29358 Mdot
.7 .29358 Mdot
.7 .29358 Mdot
.7 .29359 Mdot
.7 .29359 Mdot
.7 .29365 Mdot
.7 .29379 Mdot
.7 .29399 Mdot
.7 .29405 Mdot
.7 .29422 Mdot
.7 .29438 Mdot
.7 .29448 Mdot
.7 .29463 Mdot
.7 .29465 Mdot
.7 .29472 Mdot
.7 .2948 Mdot
.7 .29487 Mdot
.7 .29487 Mdot
.7 .2949 Mdot
.7 .29493 Mdot
.7 .29498 Mdot
.7 .29509 Mdot
.7 .29523 Mdot
.7 .29548 Mdot
.7 .29573 Mdot
.7 .29579 Mdot
.7 .29585 Mdot
.7 .29644 Mdot
.7 .29651 Mdot
.7 .29696 Mdot
.7 .29795 Mdot
.7 .29804 Mdot
.7 .29895 Mdot
.7 .2996 Mdot
.7 .29983 Mdot
.7 .30084 Mdot
.7 .30123 Mdot
.7 .30174 Mdot
.7 .30204 Mdot
.7 .30219 Mdot
.7 .30271 Mdot
.7 .30328 Mdot
.7 .30566 Mdot
.7 .30578 Mdot
.7 .30644 Mdot
.7 .30644 Mdot
.7 .30645 Mdot
.7 .30646 Mdot
.7 .30647 Mdot
.7 .3065 Mdot
.7 .30657 Mdot
.7 .3066 Mdot
.7 .3066 Mdot
.7 .3066 Mdot
.7 .30665 Mdot
.7 .30668 Mdot
.7 .30671 Mdot
.7 .30681 Mdot
.7 .30681 Mdot
.7 .30682 Mdot
.7 .30686 Mdot
.7 .30696 Mdot
.7 .30706 Mdot
.7 .30707 Mdot
.7 .30709 Mdot
.7 .30712 Mdot
.7 .30714 Mdot
.7 .30717 Mdot
.7 .30721 Mdot
.7 .30722 Mdot
.7 .30727 Mdot
.7 .30735 Mdot
.7 .30739 Mdot
.7 .3074 Mdot
.7 .30748 Mdot
.7 .30754 Mdot
.7 .30756 Mdot
.7 .30757 Mdot
.7 .3076 Mdot
.7 .30767 Mdot
.7 .30768 Mdot
.7 .3077 Mdot
.7 .30784 Mdot
.7 .30788 Mdot
.7 .30789 Mdot
.7 .30791 Mdot
.7 .30805 Mdot
.7 .30815 Mdot
.7 .30818 Mdot
.7 .30829 Mdot
.7 .30848 Mdot
.7 .30849 Mdot
.7 .3086 Mdot
.7 .30884 Mdot
.7 .30888 Mdot
.7 .30889 Mdot
.7 .30894 Mdot
.7 .30895 Mdot
.7 .30896 Mdot
.7 .30908 Mdot
.7 .30911 Mdot
.7 .30911 Mdot
.7 .30912 Mdot
.7 .30912 Mdot
.7 .30912 Mdot
.7 .30913 Mdot
.7 .30914 Mdot
.7 .30915 Mdot
.7 .30935 Mdot
.7 .30978 Mdot
.7 .3103 Mdot
.7 .3104 Mdot
.7 .31056 Mdot
.7 .31111 Mdot
.7 .31161 Mdot
.7 .31195 Mdot
.7 .31199 Mdot
.7 .31208 Mdot
.7 .31223 Mdot
.7 .31228 Mdot
.7 .3123 Mdot
.7 .31233 Mdot
.7 .31236 Mdot
.7 .31242 Mdot
.7 .31243 Mdot
.7 .3125 Mdot
.7 .31264 Mdot
.7 .31273 Mdot
.7 .31289 Mdot
.7 .31298 Mdot
.7 .31321 Mdot
.7 .31321 Mdot
.7 .3133 Mdot
.7 .3134 Mdot
.7 .31356 Mdot
.7 .31373 Mdot
.7 .31384 Mdot
.7 .31394 Mdot
.7 .31394 Mdot
.7 .31395 Mdot
.7 .3144 Mdot
.7 .31447 Mdot
.7 .31449 Mdot
.7 .3149 Mdot
.7 .31509 Mdot
.7 .31525 Mdot
.7 .31575 Mdot
.7 .31612 Mdot
.7 .31633 Mdot
.7 .31651 Mdot
.7 .31734 Mdot
.7 .31848 Mdot
.7 .31849 Mdot
.7 .3186 Mdot
.7 .31886 Mdot
.7 .31995 Mdot
.7 .32047 Mdot
.7 .32052 Mdot
.7 .32162 Mdot
.7 .32177 Mdot
.7 .32207 Mdot
.7 .32325 Mdot
.7 .32357 Mdot
.7 .32413 Mdot
.7 .32446 Mdot
.7 .32477 Mdot
.7 .32497 Mdot
.7 .32515 Mdot
.7 .32562 Mdot
.7 .32581 Mdot
.7 .32655 Mdot
.7 .32698 Mdot
.7 .32727 Mdot
.7 .32731 Mdot
.7 .32752 Mdot
.7 .32764 Mdot
.7 .32792 Mdot
.7 .32849 Mdot
.7 .32881 Mdot
.7 .32892 Mdot
.7 .32921 Mdot
.7 .32946 Mdot
.7 .32978 Mdot
.7 .32987 Mdot
.7 .32996 Mdot
.7 .33011 Mdot
.7 .33043 Mdot
.7 .33087 Mdot
.7 .331 Mdot
.7 .33133 Mdot
.7 .33149 Mdot
.7 .33174 Mdot
.7 .33245 Mdot
.7 .33304 Mdot
.7 .33325 Mdot
.7 .33369 Mdot
.7 .33405 Mdot
.7 .33438 Mdot
.7 .33475 Mdot
.7 .33493 Mdot
.7 .3351 Mdot
.7 .33522 Mdot
.7 .33543 Mdot
.7 .33635 Mdot
.7 .33649 Mdot
.7 .33676 Mdot
.7 .33769 Mdot
.7 .3377 Mdot
.7 .3382 Mdot
.7 .33823 Mdot
.7 .33825 Mdot
.7 .33874 Mdot
.7 .33954 Mdot
.7 .33989 Mdot
.7 .33989 Mdot
.7 .33998 Mdot
.7 .34035 Mdot
.7 .34048 Mdot
.7 .34055 Mdot
.7 .34094 Mdot
.7 .34098 Mdot
.7 .34102 Mdot
.7 .34133 Mdot
.7 .34225 Mdot
.7 .34246 Mdot
.7 .34267 Mdot
.7 .34279 Mdot
.7 .34291 Mdot
.7 .34295 Mdot
.7 .34306 Mdot
.7 .34466 Mdot
.7 .34537 Mdot
.7 .34559 Mdot
.7 .34653 Mdot
.7 .3482 Mdot
.7 .35004 Mdot
.7 .35051 Mdot
.7 .35113 Mdot
.7 .35134 Mdot
.7 .35139 Mdot
.7 .35153 Mdot
.7 .35217 Mdot
.7 .35222 Mdot
.7 .35262 Mdot
.7 .35282 Mdot
.7 .35297 Mdot
.7 .35308 Mdot
.7 .35334 Mdot
.7 .35351 Mdot
.7 .35375 Mdot
.7 .35376 Mdot
.7 .35382 Mdot
.7 .35412 Mdot
.7 .35462 Mdot
.7 .35508 Mdot
.7 .35533 Mdot
.7 .35538 Mdot
.7 .35599 Mdot
.7 .35602 Mdot
.7 .35603 Mdot
.7 .35606 Mdot
.7 .3561 Mdot
.7 .3562 Mdot
.7 .35644 Mdot
.7 .35653 Mdot
.7 .35654 Mdot
.7 .35655 Mdot
.7 .35665 Mdot
.7 .3567 Mdot
.7 .3568 Mdot
.7 .35682 Mdot
.7 .35691 Mdot
.7 .35724 Mdot
.7 .35725 Mdot
.7 .35725 Mdot
.7 .35738 Mdot
.7 .35739 Mdot
.7 .35769 Mdot
.7 .35773 Mdot
.7 .35797 Mdot
.7 .35805 Mdot
.7 .3581 Mdot
.7 .35814 Mdot
.7 .35824 Mdot
.7 .35832 Mdot
.7 .35842 Mdot
.7 .35853 Mdot
.7 .35858 Mdot
.7 .35873 Mdot
.7 .35892 Mdot
.7 .35898 Mdot
.7 .35911 Mdot
.7 .35914 Mdot
.7 .35934 Mdot
.7 .35938 Mdot
.7 .3594 Mdot
.7 .35942 Mdot
.7 .35951 Mdot
.7 .35957 Mdot
.7 .35965 Mdot
.7 .35967 Mdot
.7 .35976 Mdot
.7 .35998 Mdot
.7 .36001 Mdot
.7 .36007 Mdot
.7 .36008 Mdot
.7 .36015 Mdot
.7 .36027 Mdot
.7 .36046 Mdot
.7 .36051 Mdot
.7 .36063 Mdot
.7 .36068 Mdot
.7 .36074 Mdot
.7 .36106 Mdot
.7 .36114 Mdot
.7 .36146 Mdot
.7 .36154 Mdot
.7 .36158 Mdot
.7 .36188 Mdot
.7 .36204 Mdot
.7 .36245 Mdot
.7 .36245 Mdot
.7 .36277 Mdot
.7 .36323 Mdot
.7 .36343 Mdot
.7 .36348 Mdot
.7 .3636 Mdot
.7 .36361 Mdot
.7 .36377 Mdot
.7 .36377 Mdot
.7 .3638 Mdot
.7 .36383 Mdot
.7 .36416 Mdot
.7 .36422 Mdot
.7 .36425 Mdot
.7 .36426 Mdot
.7 .36426 Mdot
.7 .36427 Mdot
.7 .36429 Mdot
.7 .36433 Mdot
.7 .36436 Mdot
.7 .36489 Mdot
.7 .3658 Mdot
.7 .3658 Mdot
.7 .36605 Mdot
.7 .36643 Mdot
.7 .36648 Mdot
.7 .36738 Mdot
.7 .36761 Mdot
.7 .36782 Mdot
.7 .36789 Mdot
.7 .36801 Mdot
.7 .36823 Mdot
.7 .36841 Mdot
.7 .36887 Mdot
.7 .36898 Mdot
.7 .3693 Mdot
.7 .36977 Mdot
.7 .36982 Mdot
.7 .37039 Mdot
.7 .37066 Mdot
.7 .37071 Mdot
.7 .3711 Mdot
.7 .37114 Mdot
.7 .37118 Mdot
.7 .37136 Mdot
.7 .37155 Mdot
.7 .37166 Mdot
.7 .37175 Mdot
.7 .37179 Mdot
.7 .37182 Mdot
.7 .37184 Mdot
.7 .37184 Mdot
.7 .37189 Mdot
.7 .37196 Mdot
.7 .37202 Mdot
.7 .37204 Mdot
.7 .37217 Mdot
.7 .37227 Mdot
.7 .37242 Mdot
.7 .37259 Mdot
.7 .37265 Mdot
.7 .37286 Mdot
.7 .37303 Mdot
.7 .37341 Mdot
.7 .37341 Mdot
.7 .3735 Mdot
.7 .37356 Mdot
.7 .37372 Mdot
.7 .37385 Mdot
.7 .37397 Mdot
.7 .37404 Mdot
.7 .37423 Mdot
.7 .37429 Mdot
.7 .37439 Mdot
.7 .37454 Mdot
.7 .37454 Mdot
.7 .37455 Mdot
.7 .37472 Mdot
.7 .37476 Mdot
.7 .37489 Mdot
.7 .37516 Mdot
.7 .3752 Mdot
.7 .37525 Mdot
.7 .37528 Mdot
.7 .3754 Mdot
.7 .37576 Mdot
.7 .37596 Mdot
.7 .37597 Mdot
.7 .37597 Mdot
.7 .37614 Mdot
.7 .3765 Mdot
.7 .37652 Mdot
.7 .37655 Mdot
.7 .37659 Mdot
.7 .37662 Mdot
.7 .37663 Mdot
.7 .37667 Mdot
.7 .37673 Mdot
.7 .37676 Mdot
.7 .37685 Mdot
.7 .37689 Mdot
.7 .37694 Mdot
.7 .37695 Mdot
.7 .37703 Mdot
.7 .37706 Mdot
.7 .37707 Mdot
.7 .37714 Mdot
.7 .3772 Mdot
.7 .37741 Mdot
.7 .37751 Mdot
.7 .37753 Mdot
.7 .37753 Mdot
.7 .37755 Mdot
.7 .37756 Mdot
.7 .37756 Mdot
.7 .37761 Mdot
.7 .37762 Mdot
.7 .37762 Mdot
.7 .37762 Mdot
.7 .37763 Mdot
.7 .37763 Mdot
.7 .37763 Mdot
.7 .37763 Mdot
.7 .37764 Mdot
.7 .40365 Mdot
.7 .40365 Mdot
.7 .40365 Mdot
.7 .40365 Mdot
.7 .40365 Mdot
.7 .40365 Mdot
.7 .40365 Mdot
.7 .40365 Mdot
.7 .40365 Mdot
.7 .40367 Mdot
.7 .40367 Mdot
.7 .40367 Mdot
.7 .40368 Mdot
.7 .40368 Mdot
.7 .40368 Mdot
.7 .40371 Mdot
.7 .40378 Mdot
.7 .40379 Mdot
.7 .40381 Mdot
.7 .40382 Mdot
.7 .40383 Mdot
.7 .40385 Mdot
.7 .40385 Mdot
.7 .40387 Mdot
.7 .40388 Mdot
.7 .40391 Mdot
.7 .40392 Mdot
.7 .40393 Mdot
.7 .40394 Mdot
.7 .40395 Mdot
.7 .40396 Mdot
.7 .40397 Mdot
.7 .40398 Mdot
.7 .40398 Mdot
.7 .40409 Mdot
.7 .40414 Mdot
.7 .40414 Mdot
.7 .40414 Mdot
.7 .4042 Mdot
.7 .40431 Mdot
.7 .40435 Mdot
.7 .40435 Mdot
.7 .40437 Mdot
.7 .40438 Mdot
.7 .40446 Mdot
.7 .4045 Mdot
.7 .40451 Mdot
.7 .40456 Mdot
.7 .40456 Mdot
.7 .40456 Mdot
.7 .40461 Mdot
.7 .40464 Mdot
.7 .40465 Mdot
.7 .40471 Mdot
.7 .40473 Mdot
.7 .40476 Mdot
.7 .4048 Mdot
.7 .40485 Mdot
.7 .40487 Mdot
.7 .40489 Mdot
.7 .40489 Mdot
.7 .405 Mdot
.7 .40505 Mdot
.7 .40511 Mdot
.7 .40513 Mdot
.7 .40518 Mdot
.7 .40522 Mdot
.7 .40525 Mdot
.7 .40529 Mdot
.7 .40529 Mdot
.7 .40531 Mdot
.7 .40533 Mdot
.7 .40535 Mdot
.7 .40535 Mdot
.7 .40535 Mdot
.7 .40536 Mdot
.7 .40537 Mdot
.7 .4054 Mdot
.7 .40543 Mdot
.7 .40548 Mdot
.7 .40554 Mdot
.7 .40555 Mdot
.7 .40556 Mdot
.7 .40567 Mdot
.7 .40569 Mdot
.7 .40576 Mdot
.7 .40593 Mdot
.7 .40594 Mdot
.7 .40607 Mdot
.7 .40617 Mdot
.7 .4062 Mdot
.7 .40633 Mdot
.7 .40638 Mdot
.7 .40644 Mdot
.7 .40647 Mdot
.7 .40649 Mdot
.7 .40655 Mdot
.7 .40662 Mdot
.7 .40687 Mdot
.7 .40688 Mdot
.7 .40699 Mdot
.7 .40706 Mdot
.7 .40706 Mdot
.7 .40731 Mdot
.7 .40746 Mdot
.7 .40747 Mdot
.7 .40748 Mdot
.7 .40749 Mdot
.7 .40749 Mdot
.7 .40749 Mdot
.7 .40749 Mdot
.7 .4075 Mdot
.7 .40752 Mdot
.7 .40761 Mdot
.7 .40762 Mdot
.7 .40763 Mdot
.7 .40763 Mdot
.7 .40767 Mdot
.7 .40767 Mdot
.7 .4077 Mdot
.7 .40772 Mdot
.7 .40777 Mdot
.7 .4079 Mdot
.7 .40799 Mdot
.7 .40799 Mdot
.7 .4081 Mdot
.7 .40815 Mdot
.7 .40823 Mdot
.7 .40824 Mdot
.7 .40826 Mdot
.7 .40835 Mdot
.7 .40837 Mdot
.7 .40846 Mdot
.7 .40848 Mdot
.7 .40849 Mdot
.7 .40852 Mdot
.7 .40854 Mdot
.7 .40859 Mdot
.7 .40862 Mdot
.7 .40864 Mdot
.7 .40864 Mdot
.7 .40866 Mdot
.7 .40867 Mdot
.7 .40873 Mdot
.7 .40875 Mdot
.7 .40876 Mdot
.7 .40878 Mdot
.7 .4088 Mdot
.7 .40882 Mdot
.7 .40883 Mdot
.7 .40883 Mdot
.7 .40884 Mdot
.7 .4089 Mdot
.7 .40891 Mdot
.7 .40894 Mdot
.7 .40896 Mdot
.7 .40901 Mdot
.7 .40905 Mdot
.7 .40906 Mdot
.7 .40909 Mdot
.7 .40912 Mdot
.7 .40914 Mdot
.7 .40917 Mdot
.7 .40918 Mdot
.7 .40919 Mdot
.7 .40921 Mdot
.7 .40928 Mdot
.7 .40929 Mdot
.7 .40937 Mdot
.7 .40937 Mdot
.7 .40941 Mdot
.7 .40941 Mdot
.7 .40941 Mdot
.7 .4095 Mdot
.7 .40953 Mdot
.7 .40953 Mdot
.7 .40956 Mdot
.7 .40957 Mdot
.7 .4096 Mdot
.7 .4096 Mdot
.7 .40961 Mdot
.7 .40963 Mdot
.7 .40969 Mdot
.7 .40972 Mdot
.7 .40973 Mdot
.7 .40974 Mdot
.7 .40974 Mdot
.7 .40975 Mdot
.7 .40991 Mdot
.7 .40993 Mdot
.7 .41 Mdot
.7 .41012 Mdot
.7 .41025 Mdot
.7 .41033 Mdot
.7 .41035 Mdot
.7 .41035 Mdot
.7 .41042 Mdot
.7 .41046 Mdot
.7 .41053 Mdot
.7 .41056 Mdot
.7 .4106 Mdot
.7 .41065 Mdot
.7 .41076 Mdot
.7 .41077 Mdot
.7 .41095 Mdot
.7 .41098 Mdot
.7 .411 Mdot
.7 .41105 Mdot
.7 .41122 Mdot
.7 .41134 Mdot
.7 .41183 Mdot
.7 .41227 Mdot
.7 .41252 Mdot
.7 .41258 Mdot
.7 .41276 Mdot
.7 .41318 Mdot
.7 .41321 Mdot
.7 .41323 Mdot
.7 .41326 Mdot
.7 .41329 Mdot
.7 .41334 Mdot
.7 .4134 Mdot
.7 .41364 Mdot
.7 .41372 Mdot
.7 .41373 Mdot
.7 .41374 Mdot
.7 .41385 Mdot
.7 .41386 Mdot
.7 .4139 Mdot
.7 .41399 Mdot
.7 .41402 Mdot
.7 .41402 Mdot
.7 .41411 Mdot
.7 .41432 Mdot
.7 .41445 Mdot
.7 .41445 Mdot
.7 .41446 Mdot
.7 .41459 Mdot
.7 .41459 Mdot
.7 .41484 Mdot
.7 .41491 Mdot
.7 .41495 Mdot
.7 .41519 Mdot
.7 .41524 Mdot
.7 .41527 Mdot
.7 .41532 Mdot
.7 .41536 Mdot
.7 .41546 Mdot
.7 .41555 Mdot
.7 .41564 Mdot
.7 .41576 Mdot
.7 .41581 Mdot
.7 .41597 Mdot
.7 .41615 Mdot
.7 .41622 Mdot
.7 .41626 Mdot
.7 .41635 Mdot
.7 .41638 Mdot
.7 .41649 Mdot
.7 .41658 Mdot
.7 .41662 Mdot
.7 .41664 Mdot
.7 .41667 Mdot
.7 .41675 Mdot
.7 .41682 Mdot
.7 .41689 Mdot
.7 .41692 Mdot
.7 .41701 Mdot
.7 .41716 Mdot
.7 .41723 Mdot
.7 .41726 Mdot
.7 .41731 Mdot
.7 .41733 Mdot
.7 .4174 Mdot
.7 .41751 Mdot
.7 .41771 Mdot
.7 .41776 Mdot
.7 .41788 Mdot
.7 .41793 Mdot
.7 .41798 Mdot
.7 .41807 Mdot
.7 .41815 Mdot
.7 .4183 Mdot
.7 .41839 Mdot
.7 .4187 Mdot
.7 .41878 Mdot
.7 .41882 Mdot
.7 .41911 Mdot
.7 .41912 Mdot
.7 .41926 Mdot
.7 .41955 Mdot
.7 .41962 Mdot
.7 .41965 Mdot
.7 .41965 Mdot
.7 .41996 Mdot
.7 .42018 Mdot
.7 .42023 Mdot
.7 .42028 Mdot
.7 .42038 Mdot
.7 .42052 Mdot
.7 .42056 Mdot
.7 .42061 Mdot
.7 .42072 Mdot
.7 .42073 Mdot
.7 .42075 Mdot
.7 .42087 Mdot
.7 .42087 Mdot
.7 .42087 Mdot
.7 .4209 Mdot
.7 .42093 Mdot
.7 .42097 Mdot
.7 .42101 Mdot
.7 .42104 Mdot
.7 .42107 Mdot
.7 .42107 Mdot
.7 .42113 Mdot
.7 .4212 Mdot
.7 .42122 Mdot
.7 .42126 Mdot
.7 .42128 Mdot
.7 .42128 Mdot
.7 .4213 Mdot
.7 .42131 Mdot
.7 .42131 Mdot
.7 .42132 Mdot
.7 .42133 Mdot
.7 .42137 Mdot
.7 .4214 Mdot
.7 .42141 Mdot
.7 .4215 Mdot
.7 .42164 Mdot
.7 .42179 Mdot
.7 .42183 Mdot
.7 .42186 Mdot
.7 .422 Mdot
.7 .42212 Mdot
.7 .42217 Mdot
.7 .42217 Mdot
.7 .42218 Mdot
.7 .42218 Mdot
.7 .42218 Mdot
.7 .42218 Mdot
.7 .42218 Mdot
.7 .42218 Mdot
.7 .42219 Mdot
.7 .42222 Mdot
.7 .42223 Mdot
.7 .42223 Mdot
.7 .42224 Mdot
.7 .42224 Mdot
.7 .42226 Mdot
.7 .42232 Mdot
.7 .42235 Mdot
.7 .42235 Mdot
.7 .42241 Mdot
.7 .42244 Mdot
.7 .42245 Mdot
.7 .42248 Mdot
.7 .42251 Mdot
.7 .42252 Mdot
.7 .42252 Mdot
.7 .42253 Mdot
.7 .42257 Mdot
.7 .42258 Mdot
.7 .42258 Mdot
.7 .4226 Mdot
.7 .42261 Mdot
.7 .42261 Mdot
.7 .42262 Mdot
.7 .42263 Mdot
.7 .42265 Mdot
.7 .42266 Mdot
.7 .42267 Mdot
.7 .42269 Mdot
.7 .4227 Mdot
.7 .42271 Mdot
.7 .42272 Mdot
.7 .42272 Mdot
.7 .42273 Mdot
.7 .42274 Mdot
.7 .42274 Mdot
.7 .42275 Mdot
.7 .42277 Mdot
.7 .4228 Mdot
.7 .42281 Mdot
.7 .42282 Mdot
.7 .42282 Mdot
.7 .42284 Mdot
.7 .42285 Mdot
.7 .42286 Mdot
.7 .42287 Mdot
.7 .42287 Mdot
.7 .42288 Mdot
.7 .42288 Mdot
.7 .4229 Mdot
.7 .42291 Mdot
.7 .42291 Mdot
.7 .42292 Mdot
.7 .42292 Mdot
.7 .42292 Mdot
.7 .4231 Mdot
.7 .42313 Mdot
.7 .4238 Mdot
.7 .42396 Mdot
.7 .42411 Mdot
.7 .42415 Mdot
.7 .42423 Mdot
.7 .42438 Mdot
.7 .42449 Mdot
.7 .42478 Mdot
.7 .42484 Mdot
.7 .42503 Mdot
.7 .42529 Mdot
.7 .42532 Mdot
.7 .42561 Mdot
.7 .42574 Mdot
.7 .42576 Mdot
.7 .42593 Mdot
.7 .42595 Mdot
.7 .42596 Mdot
.7 .42604 Mdot
.7 .42611 Mdot
.7 .42615 Mdot
.7 .42619 Mdot
.7 .4262 Mdot
.7 .42621 Mdot
.7 .42622 Mdot
.7 .42622 Mdot
.7 .42624 Mdot
.7 .42626 Mdot
.7 .42628 Mdot
.7 .42629 Mdot
.7 .42633 Mdot
.7 .42636 Mdot
.7 .42641 Mdot
.7 .42646 Mdot
.7 .42648 Mdot
.7 .42654 Mdot
.7 .42658 Mdot
.7 .4266 Mdot
.7 .4266 Mdot
.7 .4266 Mdot
.7 .4266 Mdot
.7 .4266 Mdot
.7 .4266 Mdot
.7 .4266 Mdot
.7 .4266 Mdot
.7 .4266 Mdot
.7 .42662 Mdot
.7 .42662 Mdot
.7 .42662 Mdot
.7 .42662 Mdot
.7 .42662 Mdot
.7 .42663 Mdot
.7 .42665 Mdot
.7 .42666 Mdot
.7 .42666 Mdot
.7 .42668 Mdot
.7 .42669 Mdot
.7 .4267 Mdot
.7 .42671 Mdot
.7 .42672 Mdot
.7 .42672 Mdot
.7 .42672 Mdot
.7 .42673 Mdot
.7 .42674 Mdot
.7 .42674 Mdot
.7 .42675 Mdot
.7 .42675 Mdot
.7 .42676 Mdot
.7 .42676 Mdot
.7 .42677 Mdot
.7 .42677 Mdot
.7 .42678 Mdot
.7 .42679 Mdot
.7 .42679 Mdot
.7 .42679 Mdot
.7 .4268 Mdot
.7 .4268 Mdot
.7 .4268 Mdot
.7 .42681 Mdot
.7 .42681 Mdot
.7 .42681 Mdot
.7 .42682 Mdot
.7 .42683 Mdot
.7 .42683 Mdot
.7 .42683 Mdot
.7 .42684 Mdot
.7 .42685 Mdot
.7 .42685 Mdot
.7 .42686 Mdot
.7 .42686 Mdot
.7 .42686 Mdot
.7 .42686 Mdot
.7 .42687 Mdot
.7 .42687 Mdot
.7 .42687 Mdot
.7 .42687 Mdot
.7 .42687 Mdot
.7 .42687 Mdot
.702 .28961 Mdot
.702 .28961 Mdot
.702 .28961 Mdot
.702 .28961 Mdot
.702 .28961 Mdot
.702 .28961 Mdot
.702 .28961 Mdot
.702 .28961 Mdot
.702 .28962 Mdot
.702 .28962 Mdot
.702 .28963 Mdot
.702 .28963 Mdot
.702 .28964 Mdot
.702 .28965 Mdot
.702 .28965 Mdot
.702 .28966 Mdot
.702 .28967 Mdot
.702 .28969 Mdot
.702 .28969 Mdot
.702 .28969 Mdot
.702 .28969 Mdot
.702 .28972 Mdot
.702 .28973 Mdot
.702 .28974 Mdot
.702 .28974 Mdot
.702 .28976 Mdot
.702 .28979 Mdot
.702 .28981 Mdot
.702 .28986 Mdot
.702 .28987 Mdot
.702 .2899 Mdot
.702 .28991 Mdot
.702 .28995 Mdot
.702 .28996 Mdot
.702 .29001 Mdot
.702 .29003 Mdot
.702 .29007 Mdot
.702 .29011 Mdot
.702 .29011 Mdot
.702 .29014 Mdot
.702 .29022 Mdot
.702 .29025 Mdot
.702 .29035 Mdot
.702 .29036 Mdot
.702 .29041 Mdot
.702 .29049 Mdot
.702 .29052 Mdot
.702 .29053 Mdot
.702 .29055 Mdot
.702 .29058 Mdot
.702 .29066 Mdot
.702 .29074 Mdot
.702 .29075 Mdot
.702 .29094 Mdot
.702 .29105 Mdot
.702 .29119 Mdot
.702 .29138 Mdot
.702 .29147 Mdot
.702 .29173 Mdot
.702 .29178 Mdot
.702 .29197 Mdot
.702 .29213 Mdot
.702 .29214 Mdot
.702 .29224 Mdot
.702 .2923 Mdot
.702 .2924 Mdot
.702 .29254 Mdot
.702 .29269 Mdot
.702 .29271 Mdot
.702 .29275 Mdot
.702 .29278 Mdot
.702 .29291 Mdot
.702 .29313 Mdot
.702 .29317 Mdot
.702 .29336 Mdot
.702 .29336 Mdot
.702 .29338 Mdot
.702 .29344 Mdot
.702 .29361 Mdot
.702 .29379 Mdot
.702 .29384 Mdot
.702 .29387 Mdot
.702 .29401 Mdot
.702 .29407 Mdot
.702 .29407 Mdot
.702 .29411 Mdot
.702 .29413 Mdot
.702 .29416 Mdot
.702 .29416 Mdot
.702 .29416 Mdot
.702 .29421 Mdot
.702 .29423 Mdot
.702 .29427 Mdot
.702 .29463 Mdot
.702 .29476 Mdot
.702 .29481 Mdot
.702 .295 Mdot
.702 .29528 Mdot
.702 .2955 Mdot
.702 .29566 Mdot
.702 .29581 Mdot
.702 .29582 Mdot
.702 .29582 Mdot
.702 .29582 Mdot
.702 .29582 Mdot
.702 .29582 Mdot
.702 .29583 Mdot
.702 .29583 Mdot
.702 .29583 Mdot
.702 .29585 Mdot
.702 .29585 Mdot
.702 .29586 Mdot
.702 .29588 Mdot
.702 .29589 Mdot
.702 .2959 Mdot
.702 .29592 Mdot
.702 .29593 Mdot
.702 .29597 Mdot
.702 .29598 Mdot
.702 .29598 Mdot
.702 .29598 Mdot
.702 .29604 Mdot
.702 .29604 Mdot
.702 .29606 Mdot
.702 .29608 Mdot
.702 .29608 Mdot
.702 .29612 Mdot
.702 .29618 Mdot
.702 .29622 Mdot
.702 .29633 Mdot
.702 .29635 Mdot
.702 .2964 Mdot
.702 .29643 Mdot
.702 .2965 Mdot
.702 .29653 Mdot
.702 .29664 Mdot
.702 .29667 Mdot
.702 .29675 Mdot
.702 .29684 Mdot
.702 .29685 Mdot
.702 .2969 Mdot
.702 .29707 Mdot
.702 .29715 Mdot
.702 .29735 Mdot
.702 .29738 Mdot
.702 .29744 Mdot
.702 .29748 Mdot
.702 .29766 Mdot
.702 .29773 Mdot
.702 .29775 Mdot
.702 .29778 Mdot
.702 .29785 Mdot
.702 .29804 Mdot
.702 .29817 Mdot
.702 .29822 Mdot
.702 .29824 Mdot
.702 .2984 Mdot
.702 .29844 Mdot
.702 .29869 Mdot
.702 .29894 Mdot
.702 .29928 Mdot
.702 .29974 Mdot
.702 .29995 Mdot
.702 .30062 Mdot
.702 .30074 Mdot
.702 .30076 Mdot
.702 .30124 Mdot
.702 .30149 Mdot
.702 .30164 Mdot
.702 .30167 Mdot
.702 .30183 Mdot
.702 .30187 Mdot
.702 .30193 Mdot
.702 .3021 Mdot
.702 .30237 Mdot
.702 .30248 Mdot
.702 .30277 Mdot
.702 .30318 Mdot
.702 .30324 Mdot
.702 .30333 Mdot
.702 .30341 Mdot
.702 .30369 Mdot
.702 .30379 Mdot
.702 .30438 Mdot
.702 .30444 Mdot
.702 .30455 Mdot
.702 .30457 Mdot
.702 .30481 Mdot
.702 .30509 Mdot
.702 .30509 Mdot
.702 .3051 Mdot
.702 .30516 Mdot
.702 .30533 Mdot
.702 .30585 Mdot
.702 .30616 Mdot
.702 .30637 Mdot
.702 .30654 Mdot
.702 .30662 Mdot
.702 .30707 Mdot
.702 .30723 Mdot
.702 .30725 Mdot
.702 .30736 Mdot
.702 .30744 Mdot
.702 .30751 Mdot
.702 .30752 Mdot
.702 .30753 Mdot
.702 .30768 Mdot
.702 .30774 Mdot
.702 .30786 Mdot
.702 .30901 Mdot
.702 .3093 Mdot
.702 .30942 Mdot
.702 .30959 Mdot
.702 .31021 Mdot
.702 .31076 Mdot
.702 .31115 Mdot
.702 .31131 Mdot
.702 .31188 Mdot
.702 .31243 Mdot
.702 .31258 Mdot
.702 .31296 Mdot
.702 .31296 Mdot
.702 .31298 Mdot
.702 .31298 Mdot
.702 .31298 Mdot
.702 .31299 Mdot
.702 .31301 Mdot
.702 .31301 Mdot
.702 .31303 Mdot
.702 .31308 Mdot
.702 .31309 Mdot
.702 .31311 Mdot
.702 .31317 Mdot
.702 .31323 Mdot
.702 .31326 Mdot
.702 .31334 Mdot
.702 .31335 Mdot
.702 .3135 Mdot
.702 .31352 Mdot
.702 .31353 Mdot
.702 .31354 Mdot
.702 .31372 Mdot
.702 .31375 Mdot
.702 .3138 Mdot
.702 .31386 Mdot
.702 .31389 Mdot
.702 .31402 Mdot
.702 .31424 Mdot
.702 .31437 Mdot
.702 .31475 Mdot
.702 .31482 Mdot
.702 .31491 Mdot
.702 .315 Mdot
.702 .3151 Mdot
.702 .31536 Mdot
.702 .31547 Mdot
.702 .31585 Mdot
.702 .31597 Mdot
.702 .31623 Mdot
.702 .31652 Mdot
.702 .31657 Mdot
.702 .3166 Mdot
.702 .3168 Mdot
.702 .317 Mdot
.702 .31738 Mdot
.702 .31768 Mdot
.702 .31781 Mdot
.702 .31844 Mdot
.702 .31855 Mdot
.702 .31876 Mdot
.702 .31891 Mdot
.702 .31956 Mdot
.702 .31983 Mdot
.702 .31991 Mdot
.702 .32003 Mdot
.702 .32028 Mdot
.702 .32076 Mdot
.702 .32097 Mdot
.702 .32149 Mdot
.702 .32164 Mdot
.702 .32172 Mdot
.702 .32233 Mdot
.702 .32251 Mdot
.702 .32345 Mdot
.702 .32438 Mdot
.702 .32569 Mdot
.702 .32745 Mdot
.702 .32748 Mdot
.702 .32829 Mdot
.702 .33081 Mdot
.702 .33091 Mdot
.702 .3314 Mdot
.702 .33145 Mdot
.702 .33333 Mdot
.702 .33408 Mdot
.702 .33432 Mdot
.702 .33489 Mdot
.702 .33503 Mdot
.702 .3355 Mdot
.702 .33557 Mdot
.702 .33563 Mdot
.702 .33581 Mdot
.702 .33605 Mdot
.702 .33641 Mdot
.702 .3367 Mdot
.702 .33687 Mdot
.702 .33757 Mdot
.702 .33775 Mdot
.702 .33777 Mdot
.702 .33809 Mdot
.702 .33817 Mdot
.702 .33827 Mdot
.702 .33837 Mdot
.702 .33848 Mdot
.702 .33929 Mdot
.702 .33932 Mdot
.702 .34016 Mdot
.702 .3403 Mdot
.702 .34085 Mdot
.702 .34109 Mdot
.702 .34143 Mdot
.702 .3416 Mdot
.702 .34171 Mdot
.702 .34176 Mdot
.702 .34187 Mdot
.702 .34279 Mdot
.702 .34318 Mdot
.702 .34389 Mdot
.702 .34392 Mdot
.702 .34541 Mdot
.702 .3456 Mdot
.702 .34591 Mdot
.702 .34603 Mdot
.702 .34608 Mdot
.702 .34697 Mdot
.702 .3476 Mdot
.702 .34799 Mdot
.702 .34802 Mdot
.702 .34806 Mdot
.702 .34824 Mdot
.702 .34888 Mdot
.702 .34948 Mdot
.702 .35044 Mdot
.702 .35072 Mdot
.702 .35148 Mdot
.702 .3516 Mdot
.702 .35178 Mdot
.702 .35241 Mdot
.702 .35252 Mdot
.702 .35275 Mdot
.702 .35279 Mdot
.702 .35309 Mdot
.702 .35336 Mdot
.702 .35388 Mdot
.702 .35434 Mdot
.702 .35487 Mdot
.702 .35488 Mdot
.702 .35541 Mdot
.702 .35546 Mdot
.702 .35548 Mdot
.702 .35582 Mdot
.702 .35586 Mdot
.702 .35608 Mdot
.702 .35629 Mdot
.702 .35632 Mdot
.702 .35635 Mdot
.702 .3564 Mdot
.702 .35648 Mdot
.702 .35653 Mdot
.702 .35671 Mdot
.702 .35683 Mdot
.702 .35704 Mdot
.702 .35743 Mdot
.702 .35826 Mdot
.702 .35913 Mdot
.702 .36088 Mdot
.702 .36167 Mdot
.702 .3619 Mdot
.702 .36203 Mdot
.702 .36248 Mdot
.702 .36315 Mdot
.702 .36353 Mdot
.702 .36369 Mdot
.702 .36414 Mdot
.702 .36514 Mdot
.702 .36549 Mdot
.702 .36559 Mdot
.702 .36568 Mdot
.702 .36574 Mdot
.702 .36598 Mdot
.702 .36642 Mdot
.702 .36664 Mdot
.702 .36666 Mdot
.702 .36679 Mdot
.702 .36707 Mdot
.702 .36802 Mdot
.702 .36804 Mdot
.702 .36814 Mdot
.702 .36847 Mdot
.702 .36914 Mdot
.702 .36933 Mdot
.702 .36941 Mdot
.702 .36953 Mdot
.702 .36968 Mdot
.702 .36978 Mdot
.702 .36981 Mdot
.702 .36988 Mdot
.702 .37009 Mdot
.702 .37011 Mdot
.702 .37012 Mdot
.702 .37015 Mdot
.702 .37015 Mdot
.702 .37015 Mdot
.702 .37017 Mdot
.702 .37018 Mdot
.702 .3702 Mdot
.702 .37021 Mdot
.702 .37024 Mdot
.702 .37033 Mdot
.702 .37034 Mdot
.702 .37038 Mdot
.702 .37048 Mdot
.702 .37059 Mdot
.702 .37063 Mdot
.702 .37064 Mdot
.702 .37064 Mdot
.702 .37076 Mdot
.702 .37079 Mdot
.702 .37094 Mdot
.702 .37103 Mdot
.702 .37106 Mdot
.702 .37108 Mdot
.702 .37109 Mdot
.702 .3712 Mdot
.702 .3713 Mdot
.702 .37138 Mdot
.702 .37143 Mdot
.702 .3715 Mdot
.702 .37151 Mdot
.702 .37159 Mdot
.702 .37163 Mdot
.702 .37179 Mdot
.702 .37183 Mdot
.702 .37206 Mdot
.702 .37214 Mdot
.702 .37232 Mdot
.702 .37246 Mdot
.702 .37256 Mdot
.702 .37278 Mdot
.702 .37279 Mdot
.702 .37288 Mdot
.702 .37298 Mdot
.702 .37301 Mdot
.702 .37303 Mdot
.702 .37304 Mdot
.702 .37308 Mdot
.702 .37319 Mdot
.702 .37325 Mdot
.702 .37327 Mdot
.702 .3734 Mdot
.702 .37346 Mdot
.702 .37358 Mdot
.702 .37362 Mdot
.702 .37363 Mdot
.702 .3737 Mdot
.702 .37376 Mdot
.702 .37379 Mdot
.702 .37388 Mdot
.702 .37392 Mdot
.702 .37399 Mdot
.702 .37401 Mdot
.702 .37407 Mdot
.702 .37409 Mdot
.702 .37421 Mdot
.702 .37425 Mdot
.702 .37434 Mdot
.702 .37439 Mdot
.702 .3744 Mdot
.702 .37442 Mdot
.702 .37445 Mdot
.702 .37454 Mdot
.702 .37455 Mdot
.702 .37455 Mdot
.702 .37456 Mdot
.702 .37464 Mdot
.702 .37465 Mdot
.702 .37469 Mdot
.702 .37471 Mdot
.702 .37475 Mdot
.702 .37479 Mdot
.702 .3748 Mdot
.702 .37481 Mdot
.702 .37484 Mdot
.702 .37486 Mdot
.702 .37486 Mdot
.702 .37487 Mdot
.702 .37488 Mdot
.702 .37488 Mdot
.702 .37488 Mdot
.702 .37489 Mdot
.702 .3749 Mdot
.702 .40476 Mdot
.702 .40476 Mdot
.702 .40476 Mdot
.702 .40476 Mdot
.702 .40476 Mdot
.702 .40477 Mdot
.702 .40477 Mdot
.702 .40477 Mdot
.702 .40477 Mdot
.702 .40478 Mdot
.702 .40479 Mdot
.702 .40479 Mdot
.702 .4048 Mdot
.702 .40481 Mdot
.702 .40482 Mdot
.702 .40483 Mdot
.702 .40483 Mdot
.702 .40486 Mdot
.702 .40486 Mdot
.702 .40486 Mdot
.702 .40486 Mdot
.702 .40489 Mdot
.702 .4049 Mdot
.702 .4049 Mdot
.702 .40491 Mdot
.702 .40492 Mdot
.702 .40494 Mdot
.702 .40496 Mdot
.702 .40499 Mdot
.702 .405 Mdot
.702 .40501 Mdot
.702 .40502 Mdot
.702 .40504 Mdot
.702 .40505 Mdot
.702 .40508 Mdot
.702 .40509 Mdot
.702 .4051 Mdot
.702 .40513 Mdot
.702 .40513 Mdot
.702 .40514 Mdot
.702 .40517 Mdot
.702 .40519 Mdot
.702 .40523 Mdot
.702 .40524 Mdot
.702 .40525 Mdot
.702 .40528 Mdot
.702 .40529 Mdot
.702 .4053 Mdot
.702 .4053 Mdot
.702 .40531 Mdot
.702 .40534 Mdot
.702 .40537 Mdot
.702 .40537 Mdot
.702 .40543 Mdot
.702 .40546 Mdot
.702 .4055 Mdot
.702 .40555 Mdot
.702 .40558 Mdot
.702 .40564 Mdot
.702 .40565 Mdot
.702 .4057 Mdot
.702 .40571 Mdot
.702 .40573 Mdot
.702 .40574 Mdot
.702 .40576 Mdot
.702 .40577 Mdot
.702 .40579 Mdot
.702 .40582 Mdot
.702 .40585 Mdot
.702 .40586 Mdot
.702 .40586 Mdot
.702 .40587 Mdot
.702 .4059 Mdot
.702 .40594 Mdot
.702 .40595 Mdot
.702 .40598 Mdot
.702 .40598 Mdot
.702 .40598 Mdot
.702 .40599 Mdot
.702 .40603 Mdot
.702 .40606 Mdot
.702 .40607 Mdot
.702 .40607 Mdot
.702 .4061 Mdot
.702 .4061 Mdot
.702 .4061 Mdot
.702 .40611 Mdot
.702 .40612 Mdot
.702 .40612 Mdot
.702 .40612 Mdot
.702 .40612 Mdot
.702 .40613 Mdot
.702 .40613 Mdot
.702 .40614 Mdot
.702 .4062 Mdot
.702 .40622 Mdot
.702 .40622 Mdot
.702 .40625 Mdot
.702 .4063 Mdot
.702 .40633 Mdot
.702 .40635 Mdot
.702 .40641 Mdot
.702 .4066 Mdot
.702 .40669 Mdot
.702 .40671 Mdot
.702 .40672 Mdot
.702 .40699 Mdot
.702 .40706 Mdot
.702 .4071 Mdot
.702 .4071 Mdot
.702 .40717 Mdot
.702 .40729 Mdot
.702 .40736 Mdot
.702 .40737 Mdot
.702 .4074 Mdot
.702 .40742 Mdot
.702 .40752 Mdot
.702 .4078 Mdot
.702 .40792 Mdot
.702 .40797 Mdot
.702 .40807 Mdot
.702 .40825 Mdot
.702 .40838 Mdot
.702 .40841 Mdot
.702 .40847 Mdot
.702 .40869 Mdot
.702 .40917 Mdot
.702 .4094 Mdot
.702 .40963 Mdot
.702 .40973 Mdot
.702 .40979 Mdot
.702 .40982 Mdot
.702 .40987 Mdot
.702 .40988 Mdot
.702 .4099 Mdot
.702 .40991 Mdot
.702 .40992 Mdot
.702 .40993 Mdot
.702 .40999 Mdot
.702 .41005 Mdot
.702 .41006 Mdot
.702 .41015 Mdot
.702 .41015 Mdot
.702 .41017 Mdot
.702 .41031 Mdot
.702 .41031 Mdot
.702 .41045 Mdot
.702 .41058 Mdot
.702 .41072 Mdot
.702 .41079 Mdot
.702 .41087 Mdot
.702 .41088 Mdot
.702 .41094 Mdot
.702 .41097 Mdot
.702 .41113 Mdot
.702 .41118 Mdot
.702 .41121 Mdot
.702 .41141 Mdot
.702 .41149 Mdot
.702 .41174 Mdot
.702 .4119 Mdot
.702 .41207 Mdot
.702 .41212 Mdot
.702 .41213 Mdot
.702 .41213 Mdot
.702 .41224 Mdot
.702 .41241 Mdot
.702 .41264 Mdot
.702 .41265 Mdot
.702 .41268 Mdot
.702 .41276 Mdot
.702 .41281 Mdot
.702 .41321 Mdot
.702 .41321 Mdot
.702 .4134 Mdot
.702 .4135 Mdot
.702 .41374 Mdot
.702 .41377 Mdot
.702 .41378 Mdot
.702 .41381 Mdot
.702 .41386 Mdot
.702 .41395 Mdot
.702 .41401 Mdot
.702 .41415 Mdot
.702 .41419 Mdot
.702 .41441 Mdot
.702 .41442 Mdot
.702 .41463 Mdot
.702 .41466 Mdot
.702 .41468 Mdot
.702 .41471 Mdot
.702 .41473 Mdot
.702 .41482 Mdot
.702 .41482 Mdot
.702 .41487 Mdot
.702 .41505 Mdot
.702 .41509 Mdot
.702 .41517 Mdot
.702 .41526 Mdot
.702 .41533 Mdot
.702 .41537 Mdot
.702 .41539 Mdot
.702 .41553 Mdot
.702 .41557 Mdot
.702 .41572 Mdot
.702 .41578 Mdot
.702 .41597 Mdot
.702 .41646 Mdot
.702 .41648 Mdot
.702 .41661 Mdot
.702 .41663 Mdot
.702 .41729 Mdot
.702 .41751 Mdot
.702 .41751 Mdot
.702 .41797 Mdot
.702 .41832 Mdot
.702 .41856 Mdot
.702 .41881 Mdot
.702 .41886 Mdot
.702 .41902 Mdot
.702 .41904 Mdot
.702 .41908 Mdot
.702 .41922 Mdot
.702 .41928 Mdot
.702 .4194 Mdot
.702 .41947 Mdot
.702 .4195 Mdot
.702 .41952 Mdot
.702 .4196 Mdot
.702 .41977 Mdot
.702 .41981 Mdot
.702 .41986 Mdot
.702 .41989 Mdot
.702 .42006 Mdot
.702 .4201 Mdot
.702 .42017 Mdot
.702 .42028 Mdot
.702 .42033 Mdot
.702 .42038 Mdot
.702 .42039 Mdot
.702 .4204 Mdot
.702 .42048 Mdot
.702 .42055 Mdot
.702 .42059 Mdot
.702 .42069 Mdot
.702 .42072 Mdot
.702 .42079 Mdot
.702 .42081 Mdot
.702 .42084 Mdot
.702 .42086 Mdot
.702 .42088 Mdot
.702 .42098 Mdot
.702 .42102 Mdot
.702 .42108 Mdot
.702 .42111 Mdot
.702 .42112 Mdot
.702 .42114 Mdot
.702 .42115 Mdot
.702 .42116 Mdot
.702 .42121 Mdot
.702 .42121 Mdot
.702 .42121 Mdot
.702 .42122 Mdot
.702 .42126 Mdot
.702 .42126 Mdot
.702 .42128 Mdot
.702 .42129 Mdot
.702 .42131 Mdot
.702 .42132 Mdot
.702 .42133 Mdot
.702 .42133 Mdot
.702 .42135 Mdot
.702 .42135 Mdot
.702 .42135 Mdot
.702 .42136 Mdot
.702 .42136 Mdot
.702 .42136 Mdot
.702 .42136 Mdot
.702 .42136 Mdot
.702 .42137 Mdot
.702 .42147 Mdot
.702 .42151 Mdot
.702 .42166 Mdot
.702 .42181 Mdot
.702 .42186 Mdot
.702 .42196 Mdot
.702 .42211 Mdot
.702 .42228 Mdot
.702 .42233 Mdot
.702 .42236 Mdot
.702 .42244 Mdot
.702 .42276 Mdot
.702 .42279 Mdot
.702 .42281 Mdot
.702 .42285 Mdot
.702 .42285 Mdot
.702 .42285 Mdot
.702 .42287 Mdot
.702 .42289 Mdot
.702 .42293 Mdot
.702 .42293 Mdot
.702 .42297 Mdot
.702 .4231 Mdot
.702 .42312 Mdot
.702 .42317 Mdot
.702 .42323 Mdot
.702 .42331 Mdot
.702 .42346 Mdot
.702 .42351 Mdot
.702 .42352 Mdot
.702 .42352 Mdot
.702 .42353 Mdot
.702 .4236 Mdot
.702 .42367 Mdot
.702 .42368 Mdot
.702 .42371 Mdot
.702 .42372 Mdot
.702 .42389 Mdot
.702 .42392 Mdot
.702 .42399 Mdot
.702 .42402 Mdot
.702 .42404 Mdot
.702 .42406 Mdot
.702 .42418 Mdot
.702 .42426 Mdot
.702 .42429 Mdot
.702 .42436 Mdot
.702 .42441 Mdot
.702 .42443 Mdot
.702 .42444 Mdot
.702 .42449 Mdot
.702 .4245 Mdot
.702 .42454 Mdot
.702 .42461 Mdot
.702 .42475 Mdot
.702 .42475 Mdot
.702 .42479 Mdot
.702 .42498 Mdot
.702 .42504 Mdot
.702 .42517 Mdot
.702 .42527 Mdot
.702 .42534 Mdot
.702 .42541 Mdot
.702 .42542 Mdot
.702 .42547 Mdot
.702 .42548 Mdot
.702 .42549 Mdot
.702 .42553 Mdot
.702 .42558 Mdot
.702 .4256 Mdot
.702 .42561 Mdot
.702 .42562 Mdot
.702 .42564 Mdot
.702 .42569 Mdot
.702 .4257 Mdot
.702 .42572 Mdot
.702 .42573 Mdot
.702 .42579 Mdot
.702 .42581 Mdot
.702 .42586 Mdot
.702 .42587 Mdot
.702 .42588 Mdot
.702 .4259 Mdot
.702 .42592 Mdot
.702 .42593 Mdot
.702 .42596 Mdot
.702 .42597 Mdot
.702 .426 Mdot
.702 .426 Mdot
.702 .42602 Mdot
.702 .42602 Mdot
.702 .42606 Mdot
.702 .42607 Mdot
.702 .42609 Mdot
.702 .4261 Mdot
.702 .4261 Mdot
.702 .4261 Mdot
.702 .42611 Mdot
.702 .42611 Mdot
.702 .42613 Mdot
.702 .42613 Mdot
.702 .42613 Mdot
.702 .42613 Mdot
.702 .42614 Mdot
.702 .42614 Mdot
.702 .42615 Mdot
.702 .42615 Mdot
.702 .42616 Mdot
.702 .42616 Mdot
.702 .42616 Mdot
.702 .42617 Mdot
.702 .42617 Mdot
.702 .42617 Mdot
.702 .42617 Mdot
.702 .42617 Mdot
.702 .42617 Mdot
.702 .42617 Mdot
.702 .42617 Mdot
.702 .42618 Mdot
.702 .42618 Mdot
.702 .42622 Mdot
.702 .42627 Mdot
.702 .42633 Mdot
.702 .42642 Mdot
.702 .42647 Mdot
.702 .42649 Mdot
.702 .42652 Mdot
.702 .42663 Mdot
.702 .42664 Mdot
.702 .42665 Mdot
.702 .42666 Mdot
.702 .42666 Mdot
.702 .42667 Mdot
.702 .42667 Mdot
.702 .42668 Mdot
.702 .42669 Mdot
.702 .42669 Mdot
.702 .42671 Mdot
.702 .42675 Mdot
.702 .42676 Mdot
.702 .42677 Mdot
.702 .42683 Mdot
.702 .42688 Mdot
.702 .4269 Mdot
.702 .4269 Mdot
.702 .4269 Mdot
.702 .42696 Mdot
.702 .42697 Mdot
.702 .42704 Mdot
.702 .42708 Mdot
.702 .42709 Mdot
.702 .4271 Mdot
.702 .4271 Mdot
.702 .42715 Mdot
.702 .42719 Mdot
.702 .42722 Mdot
.702 .42724 Mdot
.702 .42727 Mdot
.702 .42727 Mdot
.702 .42732 Mdot
.702 .42738 Mdot
.702 .42739 Mdot
.702 .42747 Mdot
.702 .4275 Mdot
.702 .42755 Mdot
.702 .4276 Mdot
.702 .42763 Mdot
.702 .42769 Mdot
.702 .42769 Mdot
.702 .42772 Mdot
.702 .42774 Mdot
.702 .42775 Mdot
.702 .42775 Mdot
.702 .42776 Mdot
.702 .42777 Mdot
.702 .42779 Mdot
.702 .42781 Mdot
.702 .42781 Mdot
.702 .42784 Mdot
.702 .42785 Mdot
.702 .42787 Mdot
.702 .42788 Mdot
.702 .42788 Mdot
.702 .4279 Mdot
.702 .42791 Mdot
.702 .42791 Mdot
.702 .42793 Mdot
.702 .42793 Mdot
.702 .42794 Mdot
.702 .42795 Mdot
.702 .42796 Mdot
.702 .42796 Mdot
.702 .42797 Mdot
.702 .42798 Mdot
.702 .42799 Mdot
.702 .428 Mdot
.702 .428 Mdot
.702 .428 Mdot
.702 .428 Mdot
.702 .42801 Mdot
.702 .42801 Mdot
.702 .42801 Mdot
.702 .42801 Mdot
.702 .42802 Mdot
.702 .42802 Mdot
.702 .42802 Mdot
.702 .42803 Mdot
.702 .42803 Mdot
.702 .42803 Mdot
.702 .42803 Mdot
.702 .42803 Mdot
.702 .42803 Mdot
.702 .42804 Mdot
.702 .42804 Mdot
.702 .42804 Mdot
.702 .42804 Mdot
.702 .42804 Mdot
.702 .42804 Mdot
.702 .42804 Mdot
.702 .42804 Mdot
.704 .28842 Mdot
.704 .28843 Mdot
.704 .28843 Mdot
.704 .28843 Mdot
.704 .28843 Mdot
.704 .28845 Mdot
.704 .28847 Mdot
.704 .28847 Mdot
.704 .28848 Mdot
.704 .2885 Mdot
.704 .28852 Mdot
.704 .28862 Mdot
.704 .28862 Mdot
.704 .28867 Mdot
.704 .28875 Mdot
.704 .28878 Mdot
.704 .28884 Mdot
.704 .28887 Mdot
.704 .28889 Mdot
.704 .2889 Mdot
.704 .28892 Mdot
.704 .28892 Mdot
.704 .28896 Mdot
.704 .28897 Mdot
.704 .28899 Mdot
.704 .28917 Mdot
.704 .28929 Mdot
.704 .28936 Mdot
.704 .2894 Mdot
.704 .28944 Mdot
.704 .28945 Mdot
.704 .28961 Mdot
.704 .28971 Mdot
.704 .29033 Mdot
.704 .29038 Mdot
.704 .2905 Mdot
.704 .29058 Mdot
.704 .29059 Mdot
.704 .29059 Mdot
.704 .2906 Mdot
.704 .2906 Mdot
.704 .29063 Mdot
.704 .29066 Mdot
.704 .29067 Mdot
.704 .29067 Mdot
.704 .29068 Mdot
.704 .29069 Mdot
.704 .29071 Mdot
.704 .29074 Mdot
.704 .29091 Mdot
.704 .29091 Mdot
.704 .29099 Mdot
.704 .29099 Mdot
.704 .29111 Mdot
.704 .29117 Mdot
.704 .29122 Mdot
.704 .29127 Mdot
.704 .29132 Mdot
.704 .29136 Mdot
.704 .29137 Mdot
.704 .2914 Mdot
.704 .29141 Mdot
.704 .29149 Mdot
.704 .29149 Mdot
.704 .2915 Mdot
.704 .29153 Mdot
.704 .29186 Mdot
.704 .29204 Mdot
.704 .29207 Mdot
.704 .29212 Mdot
.704 .29216 Mdot
.704 .29219 Mdot
.704 .29227 Mdot
.704 .29234 Mdot
.704 .29234 Mdot
.704 .29235 Mdot
.704 .29237 Mdot
.704 .29248 Mdot
.704 .29255 Mdot
.704 .29262 Mdot
.704 .29267 Mdot
.704 .29276 Mdot
.704 .29287 Mdot
.704 .29306 Mdot
.704 .29358 Mdot
.704 .29367 Mdot
.704 .29407 Mdot
.704 .29413 Mdot
.704 .29423 Mdot
.704 .29429 Mdot
.704 .2943 Mdot
.704 .29449 Mdot
.704 .29468 Mdot
.704 .2947 Mdot
.704 .2947 Mdot
.704 .2947 Mdot
.704 .29472 Mdot
.704 .29479 Mdot
.704 .29485 Mdot
.704 .29486 Mdot
.704 .29487 Mdot
.704 .29488 Mdot
.704 .2949 Mdot
.704 .29496 Mdot
.704 .29503 Mdot
.704 .29541 Mdot
.704 .29541 Mdot
.704 .29558 Mdot
.704 .29559 Mdot
.704 .29565 Mdot
.704 .29587 Mdot
.704 .29601 Mdot
.704 .29611 Mdot
.704 .29614 Mdot
.704 .29621 Mdot
.704 .29626 Mdot
.704 .29635 Mdot
.704 .29643 Mdot
.704 .29646 Mdot
.704 .29648 Mdot
.704 .29656 Mdot
.704 .29657 Mdot
.704 .29675 Mdot
.704 .29676 Mdot
.704 .29676 Mdot
.704 .29681 Mdot
.704 .29686 Mdot
.704 .29712 Mdot
.704 .29722 Mdot
.704 .29769 Mdot
.704 .29779 Mdot
.704 .29781 Mdot
.704 .29811 Mdot
.704 .29815 Mdot
.704 .29824 Mdot
.704 .29835 Mdot
.704 .29848 Mdot
.704 .2985 Mdot
.704 .29856 Mdot
.704 .29864 Mdot
.704 .29874 Mdot
.704 .29893 Mdot
.704 .29894 Mdot
.704 .29896 Mdot
.704 .29898 Mdot
.704 .29902 Mdot
.704 .29933 Mdot
.704 .2995 Mdot
.704 .2997 Mdot
.704 .29982 Mdot
.704 .29991 Mdot
.704 .30008 Mdot
.704 .30013 Mdot
.704 .30038 Mdot
.704 .30093 Mdot
.704 .30139 Mdot
.704 .30161 Mdot
.704 .30215 Mdot
.704 .30216 Mdot
.704 .30242 Mdot
.704 .30244 Mdot
.704 .30268 Mdot
.704 .3028 Mdot
.704 .30343 Mdot
.704 .30389 Mdot
.704 .3039 Mdot
.704 .30398 Mdot
.704 .30408 Mdot
.704 .3044 Mdot
.704 .30445 Mdot
.704 .30452 Mdot
.704 .30458 Mdot
.704 .30459 Mdot
.704 .3046 Mdot
.704 .30521 Mdot
.704 .30559 Mdot
.704 .30579 Mdot
.704 .30579 Mdot
.704 .30585 Mdot
.704 .30585 Mdot
.704 .30587 Mdot
.704 .30593 Mdot
.704 .30599 Mdot
.704 .30606 Mdot
.704 .30614 Mdot
.704 .30614 Mdot
.704 .30635 Mdot
.704 .30639 Mdot
.704 .30641 Mdot
.704 .30645 Mdot
.704 .30647 Mdot
.704 .3065 Mdot
.704 .30651 Mdot
.704 .30669 Mdot
.704 .30691 Mdot
.704 .30802 Mdot
.704 .30817 Mdot
.704 .30819 Mdot
.704 .30864 Mdot
.704 .30876 Mdot
.704 .30877 Mdot
.704 .30888 Mdot
.704 .30891 Mdot
.704 .309 Mdot
.704 .30918 Mdot
.704 .30975 Mdot
.704 .30986 Mdot
.704 .31021 Mdot
.704 .31038 Mdot
.704 .31048 Mdot
.704 .31058 Mdot
.704 .31065 Mdot
.704 .31092 Mdot
.704 .31106 Mdot
.704 .31141 Mdot
.704 .31168 Mdot
.704 .31177 Mdot
.704 .31185 Mdot
.704 .31195 Mdot
.704 .31214 Mdot
.704 .31218 Mdot
.704 .31244 Mdot
.704 .31269 Mdot
.704 .31279 Mdot
.704 .31285 Mdot
.704 .31286 Mdot
.704 .31301 Mdot
.704 .31322 Mdot
.704 .31336 Mdot
.704 .31412 Mdot
.704 .31423 Mdot
.704 .31439 Mdot
.704 .31448 Mdot
.704 .31451 Mdot
.704 .31518 Mdot
.704 .31592 Mdot
.704 .31622 Mdot
.704 .3166 Mdot
.704 .31667 Mdot
.704 .31668 Mdot
.704 .31671 Mdot
.704 .31675 Mdot
.704 .3175 Mdot
.704 .31779 Mdot
.704 .31793 Mdot
.704 .31826 Mdot
.704 .31839 Mdot
.704 .3187 Mdot
.704 .31916 Mdot
.704 .31916 Mdot
.704 .31926 Mdot
.704 .31946 Mdot
.704 .31976 Mdot
.704 .32017 Mdot
.704 .32026 Mdot
.704 .32089 Mdot
.704 .32092 Mdot
.704 .32099 Mdot
.704 .32109 Mdot
.704 .32124 Mdot
.704 .32147 Mdot
.704 .32185 Mdot
.704 .3224 Mdot
.704 .32306 Mdot
.704 .32329 Mdot
.704 .32386 Mdot
.704 .32386 Mdot
.704 .3239 Mdot
.704 .32432 Mdot
.704 .32466 Mdot
.704 .32532 Mdot
.704 .32538 Mdot
.704 .32553 Mdot
.704 .32635 Mdot
.704 .32648 Mdot
.704 .32755 Mdot
.704 .32764 Mdot
.704 .32767 Mdot
.704 .32864 Mdot
.704 .32903 Mdot
.704 .32919 Mdot
.704 .32929 Mdot
.704 .32958 Mdot
.704 .32971 Mdot
.704 .33045 Mdot
.704 .33077 Mdot
.704 .3311 Mdot
.704 .33132 Mdot
.704 .33153 Mdot
.704 .33231 Mdot
.704 .33253 Mdot
.704 .33253 Mdot
.704 .3334 Mdot
.704 .33347 Mdot
.704 .33385 Mdot
.704 .33449 Mdot
.704 .33456 Mdot
.704 .33476 Mdot
.704 .33548 Mdot
.704 .33596 Mdot
.704 .33603 Mdot
.704 .33838 Mdot
.704 .33923 Mdot
.704 .33946 Mdot
.704 .34014 Mdot
.704 .34018 Mdot
.704 .34049 Mdot
.704 .34085 Mdot
.704 .34129 Mdot
.704 .34207 Mdot
.704 .34225 Mdot
.704 .34251 Mdot
.704 .34275 Mdot
.704 .34279 Mdot
.704 .34283 Mdot
.704 .34397 Mdot
.704 .34439 Mdot
.704 .34446 Mdot
.704 .34454 Mdot
.704 .34457 Mdot
.704 .34491 Mdot
.704 .34506 Mdot
.704 .34513 Mdot
.704 .34577 Mdot
.704 .34646 Mdot
.704 .34716 Mdot
.704 .34717 Mdot
.704 .34738 Mdot
.704 .34739 Mdot
.704 .34744 Mdot
.704 .34765 Mdot
.704 .34773 Mdot
.704 .34776 Mdot
.704 .34788 Mdot
.704 .34795 Mdot
.704 .34812 Mdot
.704 .34839 Mdot
.704 .3484 Mdot
.704 .34889 Mdot
.704 .34915 Mdot
.704 .34928 Mdot
.704 .34933 Mdot
.704 .34934 Mdot
.704 .34947 Mdot
.704 .34956 Mdot
.704 .34967 Mdot
.704 .34967 Mdot
.704 .3498 Mdot
.704 .35029 Mdot
.704 .3504 Mdot
.704 .35107 Mdot
.704 .35112 Mdot
.704 .35193 Mdot
.704 .35232 Mdot
.704 .35245 Mdot
.704 .35285 Mdot
.704 .3529 Mdot
.704 .35378 Mdot
.704 .35379 Mdot
.704 .35395 Mdot
.704 .35466 Mdot
.704 .35515 Mdot
.704 .35521 Mdot
.704 .35604 Mdot
.704 .35636 Mdot
.704 .3566 Mdot
.704 .35693 Mdot
.704 .35694 Mdot
.704 .35699 Mdot
.704 .35719 Mdot
.704 .3573 Mdot
.704 .35738 Mdot
.704 .35766 Mdot
.704 .35769 Mdot
.704 .35776 Mdot
.704 .35779 Mdot
.704 .35783 Mdot
.704 .35818 Mdot
.704 .35818 Mdot
.704 .35821 Mdot
.704 .35851 Mdot
.704 .35876 Mdot
.704 .35914 Mdot
.704 .35915 Mdot
.704 .3593 Mdot
.704 .35967 Mdot
.704 .35977 Mdot
.704 .36009 Mdot
.704 .36038 Mdot
.704 .36059 Mdot
.704 .36082 Mdot
.704 .36102 Mdot
.704 .36104 Mdot
.704 .36104 Mdot
.704 .36125 Mdot
.704 .36145 Mdot
.704 .36164 Mdot
.704 .36167 Mdot
.704 .36171 Mdot
.704 .36195 Mdot
.704 .36214 Mdot
.704 .36221 Mdot
.704 .36235 Mdot
.704 .36277 Mdot
.704 .3628 Mdot
.704 .36295 Mdot
.704 .36315 Mdot
.704 .36323 Mdot
.704 .36324 Mdot
.704 .36331 Mdot
.704 .3635 Mdot
.704 .36396 Mdot
.704 .36397 Mdot
.704 .36407 Mdot
.704 .3641 Mdot
.704 .36412 Mdot
.704 .36418 Mdot
.704 .36424 Mdot
.704 .36456 Mdot
.704 .36458 Mdot
.704 .36461 Mdot
.704 .36476 Mdot
.704 .36478 Mdot
.704 .36494 Mdot
.704 .36515 Mdot
.704 .36527 Mdot
.704 .36536 Mdot
.704 .36537 Mdot
.704 .36555 Mdot
.704 .36563 Mdot
.704 .36608 Mdot
.704 .36616 Mdot
.704 .3665 Mdot
.704 .36663 Mdot
.704 .36668 Mdot
.704 .36683 Mdot
.704 .36695 Mdot
.704 .36696 Mdot
.704 .36718 Mdot
.704 .36723 Mdot
.704 .36738 Mdot
.704 .36751 Mdot
.704 .3676 Mdot
.704 .36764 Mdot
.704 .36784 Mdot
.704 .36845 Mdot
.704 .36845 Mdot
.704 .36855 Mdot
.704 .36875 Mdot
.704 .36879 Mdot
.704 .36904 Mdot
.704 .3692 Mdot
.704 .36927 Mdot
.704 .36931 Mdot
.704 .36934 Mdot
.704 .36942 Mdot
.704 .36942 Mdot
.704 .36951 Mdot
.704 .36954 Mdot
.704 .36958 Mdot
.704 .36989 Mdot
.704 .37005 Mdot
.704 .37019 Mdot
.704 .37037 Mdot
.704 .37038 Mdot
.704 .37049 Mdot
.704 .37057 Mdot
.704 .3706 Mdot
.704 .37102 Mdot
.704 .37109 Mdot
.704 .37121 Mdot
.704 .37122 Mdot
.704 .37125 Mdot
.704 .37128 Mdot
.704 .37133 Mdot
.704 .37142 Mdot
.704 .37157 Mdot
.704 .37158 Mdot
.704 .37159 Mdot
.704 .37163 Mdot
.704 .37163 Mdot
.704 .37164 Mdot
.704 .37165 Mdot
.704 .37167 Mdot
.704 .37169 Mdot
.704 .37174 Mdot
.704 .37177 Mdot
.704 .37183 Mdot
.704 .37187 Mdot
.704 .37187 Mdot
.704 .37197 Mdot
.704 .37198 Mdot
.704 .372 Mdot
.704 .37201 Mdot
.704 .37201 Mdot
.704 .37203 Mdot
.704 .37204 Mdot
.704 .37205 Mdot
.704 .37205 Mdot
.704 .37205 Mdot
.704 .37206 Mdot
.704 .40587 Mdot
.704 .40587 Mdot
.704 .40587 Mdot
.704 .40587 Mdot
.704 .40587 Mdot
.704 .40588 Mdot
.704 .40588 Mdot
.704 .40588 Mdot
.704 .40588 Mdot
.704 .40589 Mdot
.704 .40589 Mdot
.704 .40592 Mdot
.704 .40592 Mdot
.704 .40593 Mdot
.704 .40595 Mdot
.704 .40596 Mdot
.704 .40597 Mdot
.704 .40598 Mdot
.704 .40598 Mdot
.704 .40598 Mdot
.704 .40599 Mdot
.704 .40599 Mdot
.704 .406 Mdot
.704 .406 Mdot
.704 .40601 Mdot
.704 .40605 Mdot
.704 .40607 Mdot
.704 .40609 Mdot
.704 .4061 Mdot
.704 .4061 Mdot
.704 .40611 Mdot
.704 .40614 Mdot
.704 .40616 Mdot
.704 .40628 Mdot
.704 .40629 Mdot
.704 .40631 Mdot
.704 .40634 Mdot
.704 .40634 Mdot
.704 .4064 Mdot
.704 .40643 Mdot
.704 .40648 Mdot
.704 .40656 Mdot
.704 .40658 Mdot
.704 .40658 Mdot
.704 .40661 Mdot
.704 .40661 Mdot
.704 .40663 Mdot
.704 .40664 Mdot
.704 .40665 Mdot
.704 .40667 Mdot
.704 .40672 Mdot
.704 .40679 Mdot
.704 .40685 Mdot
.704 .40688 Mdot
.704 .40688 Mdot
.704 .40705 Mdot
.704 .40711 Mdot
.704 .40712 Mdot
.704 .40714 Mdot
.704 .40718 Mdot
.704 .40722 Mdot
.704 .40723 Mdot
.704 .4073 Mdot
.704 .4073 Mdot
.704 .40733 Mdot
.704 .40737 Mdot
.704 .40739 Mdot
.704 .40742 Mdot
.704 .40752 Mdot
.704 .40754 Mdot
.704 .40766 Mdot
.704 .40768 Mdot
.704 .40773 Mdot
.704 .40774 Mdot
.704 .40776 Mdot
.704 .40779 Mdot
.704 .40785 Mdot
.704 .40789 Mdot
.704 .4079 Mdot
.704 .40794 Mdot
.704 .40795 Mdot
.704 .40796 Mdot
.704 .40804 Mdot
.704 .40806 Mdot
.704 .40808 Mdot
.704 .40808 Mdot
.704 .40809 Mdot
.704 .40812 Mdot
.704 .40812 Mdot
.704 .40825 Mdot
.704 .4083 Mdot
.704 .40832 Mdot
.704 .40832 Mdot
.704 .40834 Mdot
.704 .4084 Mdot
.704 .40844 Mdot
.704 .40845 Mdot
.704 .40856 Mdot
.704 .4086 Mdot
.704 .40862 Mdot
.704 .40867 Mdot
.704 .40873 Mdot
.704 .40875 Mdot
.704 .40875 Mdot
.704 .4088 Mdot
.704 .40886 Mdot
.704 .40891 Mdot
.704 .40892 Mdot
.704 .40892 Mdot
.704 .40897 Mdot
.704 .40904 Mdot
.704 .40909 Mdot
.704 .40917 Mdot
.704 .40926 Mdot
.704 .40928 Mdot
.704 .40938 Mdot
.704 .40942 Mdot
.704 .40943 Mdot
.704 .40953 Mdot
.704 .4096 Mdot
.704 .40968 Mdot
.704 .40968 Mdot
.704 .40969 Mdot
.704 .40978 Mdot
.704 .40979 Mdot
.704 .4098 Mdot
.704 .40982 Mdot
.704 .40983 Mdot
.704 .4099 Mdot
.704 .40992 Mdot
.704 .40995 Mdot
.704 .41 Mdot
.704 .41002 Mdot
.704 .41002 Mdot
.704 .41011 Mdot
.704 .41017 Mdot
.704 .41026 Mdot
.704 .41048 Mdot
.704 .4105 Mdot
.704 .41062 Mdot
.704 .41081 Mdot
.704 .41086 Mdot
.704 .41086 Mdot
.704 .41109 Mdot
.704 .41111 Mdot
.704 .41121 Mdot
.704 .41125 Mdot
.704 .41135 Mdot
.704 .41156 Mdot
.704 .41158 Mdot
.704 .41175 Mdot
.704 .41178 Mdot
.704 .41191 Mdot
.704 .41194 Mdot
.704 .41194 Mdot
.704 .41197 Mdot
.704 .412 Mdot
.704 .41203 Mdot
.704 .41203 Mdot
.704 .41205 Mdot
.704 .41208 Mdot
.704 .41215 Mdot
.704 .41228 Mdot
.704 .41228 Mdot
.704 .41235 Mdot
.704 .4124 Mdot
.704 .41242 Mdot
.704 .41245 Mdot
.704 .41245 Mdot
.704 .41248 Mdot
.704 .41253 Mdot
.704 .41254 Mdot
.704 .41255 Mdot
.704 .4126 Mdot
.704 .4126 Mdot
.704 .41279 Mdot
.704 .41297 Mdot
.704 .41313 Mdot
.704 .41315 Mdot
.704 .41319 Mdot
.704 .41328 Mdot
.704 .41329 Mdot
.704 .41331 Mdot
.704 .41333 Mdot
.704 .41344 Mdot
.704 .41374 Mdot
.704 .41375 Mdot
.704 .41376 Mdot
.704 .41382 Mdot
.704 .41389 Mdot
.704 .41393 Mdot
.704 .41414 Mdot
.704 .41425 Mdot
.704 .41435 Mdot
.704 .41443 Mdot
.704 .41444 Mdot
.704 .41461 Mdot
.704 .41468 Mdot
.704 .41489 Mdot
.704 .41551 Mdot
.704 .41553 Mdot
.704 .41565 Mdot
.704 .41584 Mdot
.704 .41589 Mdot
.704 .41591 Mdot
.704 .41608 Mdot
.704 .41617 Mdot
.704 .41619 Mdot
.704 .41642 Mdot
.704 .41642 Mdot
.704 .41648 Mdot
.704 .41668 Mdot
.704 .41673 Mdot
.704 .41679 Mdot
.704 .41688 Mdot
.704 .41696 Mdot
.704 .41716 Mdot
.704 .41719 Mdot
.704 .41726 Mdot
.704 .41729 Mdot
.704 .41733 Mdot
.704 .41743 Mdot
.704 .41769 Mdot
.704 .4177 Mdot
.704 .41772 Mdot
.704 .418 Mdot
.704 .41803 Mdot
.704 .41825 Mdot
.704 .41829 Mdot
.704 .4183 Mdot
.704 .41848 Mdot
.704 .41857 Mdot
.704 .41868 Mdot
.704 .41869 Mdot
.704 .41869 Mdot
.704 .41884 Mdot
.704 .4189 Mdot
.704 .41907 Mdot
.704 .41922 Mdot
.704 .41932 Mdot
.704 .41938 Mdot
.704 .41942 Mdot
.704 .41945 Mdot
.704 .41946 Mdot
.704 .41947 Mdot
.704 .41964 Mdot
.704 .41966 Mdot
.704 .41977 Mdot
.704 .41985 Mdot
.704 .41991 Mdot
.704 .41993 Mdot
.704 .41993 Mdot
.704 .42006 Mdot
.704 .42014 Mdot
.704 .42017 Mdot
.704 .42026 Mdot
.704 .4203 Mdot
.704 .42037 Mdot
.704 .42057 Mdot
.704 .42059 Mdot
.704 .42059 Mdot
.704 .42059 Mdot
.704 .42062 Mdot
.704 .42072 Mdot
.704 .4208 Mdot
.704 .421 Mdot
.704 .42117 Mdot
.704 .42118 Mdot
.704 .42121 Mdot
.704 .42125 Mdot
.704 .42128 Mdot
.704 .42149 Mdot
.704 .42152 Mdot
.704 .42158 Mdot
.704 .42162 Mdot
.704 .42162 Mdot
.704 .42164 Mdot
.704 .42167 Mdot
.704 .42173 Mdot
.704 .42181 Mdot
.704 .42182 Mdot
.704 .42187 Mdot
.704 .42189 Mdot
.704 .42192 Mdot
.704 .42194 Mdot
.704 .42201 Mdot
.704 .42211 Mdot
.704 .42215 Mdot
.704 .42222 Mdot
.704 .42224 Mdot
.704 .42227 Mdot
.704 .4223 Mdot
.704 .42234 Mdot
.704 .42244 Mdot
.704 .42247 Mdot
.704 .42262 Mdot
.704 .42267 Mdot
.704 .4227 Mdot
.704 .42271 Mdot
.704 .42273 Mdot
.704 .42274 Mdot
.704 .42277 Mdot
.704 .4229 Mdot
.704 .4229 Mdot
.704 .42294 Mdot
.704 .42325 Mdot
.704 .42331 Mdot
.704 .42336 Mdot
.704 .42336 Mdot
.704 .42337 Mdot
.704 .42338 Mdot
.704 .42339 Mdot
.704 .42339 Mdot
.704 .4234 Mdot
.704 .42346 Mdot
.704 .42346 Mdot
.704 .42349 Mdot
.704 .4235 Mdot
.704 .42352 Mdot
.704 .42354 Mdot
.704 .42354 Mdot
.704 .42354 Mdot
.704 .42356 Mdot
.704 .42356 Mdot
.704 .42362 Mdot
.704 .42372 Mdot
.704 .42389 Mdot
.704 .42389 Mdot
.704 .4239 Mdot
.704 .42392 Mdot
.704 .42394 Mdot
.704 .42395 Mdot
.704 .42404 Mdot
.704 .42407 Mdot
.704 .42409 Mdot
.704 .42409 Mdot
.704 .42422 Mdot
.704 .4244 Mdot
.704 .42443 Mdot
.704 .4245 Mdot
.704 .4245 Mdot
.704 .42458 Mdot
.704 .42458 Mdot
.704 .42473 Mdot
.704 .4248 Mdot
.704 .42493 Mdot
.704 .42509 Mdot
.704 .42516 Mdot
.704 .42517 Mdot
.704 .42522 Mdot
.704 .42525 Mdot
.704 .42528 Mdot
.704 .42534 Mdot
.704 .42539 Mdot
.704 .42548 Mdot
.704 .42549 Mdot
.704 .42549 Mdot
.704 .4255 Mdot
.704 .4255 Mdot
.704 .42556 Mdot
.704 .42559 Mdot
.704 .42561 Mdot
.704 .42563 Mdot
.704 .42563 Mdot
.704 .42567 Mdot
.704 .4257 Mdot
.704 .42573 Mdot
.704 .42574 Mdot
.704 .42583 Mdot
.704 .42583 Mdot
.704 .42586 Mdot
.704 .426 Mdot
.704 .42603 Mdot
.704 .4261 Mdot
.704 .42612 Mdot
.704 .42613 Mdot
.704 .42613 Mdot
.704 .42614 Mdot
.704 .42619 Mdot
.704 .42619 Mdot
.704 .42622 Mdot
.704 .42622 Mdot
.704 .42623 Mdot
.704 .42625 Mdot
.704 .42628 Mdot
.704 .42629 Mdot
.704 .42632 Mdot
.704 .42632 Mdot
.704 .42635 Mdot
.704 .42639 Mdot
.704 .42646 Mdot
.704 .42648 Mdot
.704 .42648 Mdot
.704 .42653 Mdot
.704 .42653 Mdot
.704 .42664 Mdot
.704 .42666 Mdot
.704 .42668 Mdot
.704 .42669 Mdot
.704 .42669 Mdot
.704 .42669 Mdot
.704 .42669 Mdot
.704 .42671 Mdot
.704 .42673 Mdot
.704 .42674 Mdot
.704 .42674 Mdot
.704 .42674 Mdot
.704 .42675 Mdot
.704 .4268 Mdot
.704 .42686 Mdot
.704 .42686 Mdot
.704 .42688 Mdot
.704 .42691 Mdot
.704 .42693 Mdot
.704 .42705 Mdot
.704 .42707 Mdot
.704 .42723 Mdot
.704 .42729 Mdot
.704 .42732 Mdot
.704 .42735 Mdot
.704 .42736 Mdot
.704 .42738 Mdot
.704 .4274 Mdot
.704 .42744 Mdot
.704 .42744 Mdot
.704 .42745 Mdot
.704 .42745 Mdot
.704 .42747 Mdot
.704 .42749 Mdot
.704 .4275 Mdot
.704 .42751 Mdot
.704 .42753 Mdot
.704 .42754 Mdot
.704 .42759 Mdot
.704 .42769 Mdot
.704 .4277 Mdot
.704 .4277 Mdot
.704 .4277 Mdot
.704 .42773 Mdot
.704 .42773 Mdot
.704 .42774 Mdot
.704 .42774 Mdot
.704 .42776 Mdot
.704 .42777 Mdot
.704 .42778 Mdot
.704 .4278 Mdot
.704 .42782 Mdot
.704 .42785 Mdot
.704 .42786 Mdot
.704 .42788 Mdot
.704 .42788 Mdot
.704 .42793 Mdot
.704 .42794 Mdot
.704 .42795 Mdot
.704 .42795 Mdot
.704 .42795 Mdot
.704 .42795 Mdot
.704 .42795 Mdot
.704 .42796 Mdot
.704 .42797 Mdot
.704 .42797 Mdot
.704 .42798 Mdot
.704 .42798 Mdot
.704 .42798 Mdot
.704 .428 Mdot
.704 .42804 Mdot
.704 .42806 Mdot
.704 .42825 Mdot
.704 .42828 Mdot
.704 .42833 Mdot
.704 .42833 Mdot
.704 .42834 Mdot
.704 .42835 Mdot
.704 .42838 Mdot
.704 .42841 Mdot
.704 .42847 Mdot
.704 .42847 Mdot
.704 .42848 Mdot
.704 .42849 Mdot
.704 .42849 Mdot
.704 .4285 Mdot
.704 .4285 Mdot
.704 .42851 Mdot
.704 .42851 Mdot
.704 .42853 Mdot
.704 .42854 Mdot
.704 .42857 Mdot
.704 .42858 Mdot
.704 .42858 Mdot
.704 .42861 Mdot
.704 .42862 Mdot
.704 .42863 Mdot
.704 .42863 Mdot
.704 .42863 Mdot
.704 .42864 Mdot
.704 .42864 Mdot
.704 .42864 Mdot
.704 .42864 Mdot
.704 .42864 Mdot
.704 .42865 Mdot
.706 .28368 Mdot
.706 .4304 Mdot
.708 .28151 Mdot
.708 .43137 Mdot
.71 .27834 Mdot
.71 .28266 Mdot
.71 .43124 Mdot
.71 .43273 Mdot
.712 .27572 Mdot
.712 .2767 Mdot
.712 .28341 Mdot
.712 .28605 Mdot
.712 .43038 Mdot
.712 .43124 Mdot
.712 .43358 Mdot
.712 .43394 Mdot
.714 .3172 Mdot
.714 .31793 Mdot
.714 .35623 Mdot
.714 .35642 Mdot
.714 .41143 Mdot
.714 .41148 Mdot
.714 .4214 Mdot
.714 .42159 Mdot
.716 .3229 Mdot
.716 .32308 Mdot
.716 .32324 Mdot
.716 .32326 Mdot
.716 .32358 Mdot
.716 .32389 Mdot
.716 .32414 Mdot
.716 .32416 Mdot
.716 .32455 Mdot
.716 .32462 Mdot
.716 .32489 Mdot
.716 .32495 Mdot
.716 .32521 Mdot
.716 .32541 Mdot
.716 .326 Mdot
.716 .3261 Mdot
.716 .32635 Mdot
.716 .32635 Mdot
.716 .32636 Mdot
.716 .32636 Mdot
.716 .32636 Mdot
.716 .32636 Mdot
.716 .32637 Mdot
.716 .32639 Mdot
.716 .3264 Mdot
.716 .3264 Mdot
.716 .32641 Mdot
.716 .32641 Mdot
.716 .32649 Mdot
.716 .32651 Mdot
.716 .32653 Mdot
.716 .32663 Mdot
.716 .32664 Mdot
.716 .32672 Mdot
.716 .32682 Mdot
.716 .32686 Mdot
.716 .32686 Mdot
.716 .32686 Mdot
.716 .32693 Mdot
.716 .32699 Mdot
.716 .327 Mdot
.716 .32701 Mdot
.716 .32705 Mdot
.716 .32705 Mdot
.716 .32707 Mdot
.716 .32708 Mdot
.716 .32709 Mdot
.716 .32713 Mdot
.716 .3272 Mdot
.716 .32725 Mdot
.716 .32731 Mdot
.716 .32743 Mdot
.716 .3276 Mdot
.716 .32761 Mdot
.716 .32785 Mdot
.716 .32792 Mdot
.716 .32793 Mdot
.716 .32796 Mdot
.716 .32815 Mdot
.716 .32819 Mdot
.716 .32828 Mdot
.716 .32833 Mdot
.716 .32838 Mdot
.716 .32853 Mdot
.716 .32856 Mdot
.716 .32861 Mdot
.716 .32865 Mdot
.716 .32868 Mdot
.716 .32872 Mdot
.716 .32882 Mdot
.716 .32884 Mdot
.716 .32895 Mdot
.716 .32912 Mdot
.716 .32919 Mdot
.716 .32924 Mdot
.716 .3293 Mdot
.716 .32936 Mdot
.716 .32939 Mdot
.716 .32943 Mdot
.716 .3295 Mdot
.716 .32967 Mdot
.716 .32975 Mdot
.716 .3298 Mdot
.716 .32981 Mdot
.716 .32986 Mdot
.716 .33022 Mdot
.716 .33022 Mdot
.716 .33027 Mdot
.716 .33039 Mdot
.716 .33039 Mdot
.716 .33046 Mdot
.716 .33048 Mdot
.716 .33052 Mdot
.716 .33054 Mdot
.716 .3306 Mdot
.716 .33086 Mdot
.716 .33092 Mdot
.716 .33099 Mdot
.716 .33107 Mdot
.716 .3312 Mdot
.716 .33124 Mdot
.716 .3313 Mdot
.716 .33156 Mdot
.716 .33169 Mdot
.716 .33177 Mdot
.716 .33184 Mdot
.716 .33187 Mdot
.716 .3319 Mdot
.716 .33201 Mdot
.716 .33203 Mdot
.716 .33208 Mdot
.716 .33209 Mdot
.716 .3322 Mdot
.716 .33225 Mdot
.716 .33227 Mdot
.716 .33284 Mdot
.716 .33298 Mdot
.716 .3331 Mdot
.716 .33315 Mdot
.716 .33324 Mdot
.716 .33338 Mdot
.716 .33345 Mdot
.716 .33361 Mdot
.716 .33364 Mdot
.716 .33389 Mdot
.716 .33401 Mdot
.716 .33402 Mdot
.716 .33408 Mdot
.716 .33415 Mdot
.716 .33419 Mdot
.716 .3342 Mdot
.716 .33434 Mdot
.716 .33438 Mdot
.716 .33441 Mdot
.716 .33444 Mdot
.716 .33444 Mdot
.716 .33446 Mdot
.716 .33452 Mdot
.716 .33452 Mdot
.716 .33452 Mdot
.716 .33454 Mdot
.716 .33465 Mdot
.716 .33466 Mdot
.716 .33467 Mdot
.716 .33467 Mdot
.716 .33471 Mdot
.716 .33476 Mdot
.716 .33478 Mdot
.716 .33479 Mdot
.716 .33482 Mdot
.716 .33483 Mdot
.716 .33485 Mdot
.716 .33485 Mdot
.716 .33489 Mdot
.716 .33494 Mdot
.716 .33503 Mdot
.716 .33504 Mdot
.716 .3351 Mdot
.716 .33526 Mdot
.716 .33534 Mdot
.716 .33534 Mdot
.716 .33535 Mdot
.716 .33538 Mdot
.716 .33547 Mdot
.716 .3355 Mdot
.716 .3355 Mdot
.716 .3355 Mdot
.716 .33561 Mdot
.716 .33564 Mdot
.716 .33569 Mdot
.716 .33573 Mdot
.716 .33583 Mdot
.716 .33589 Mdot
.716 .3359 Mdot
.716 .33593 Mdot
.716 .33593 Mdot
.716 .336 Mdot
.716 .33618 Mdot
.716 .33628 Mdot
.716 .33628 Mdot
.716 .33632 Mdot
.716 .3364 Mdot
.716 .33646 Mdot
.716 .33656 Mdot
.716 .33673 Mdot
.716 .33678 Mdot
.716 .33687 Mdot
.716 .33717 Mdot
.716 .3372 Mdot
.716 .33721 Mdot
.716 .33722 Mdot
.716 .33724 Mdot
.716 .33724 Mdot
.716 .33728 Mdot
.716 .33736 Mdot
.716 .33738 Mdot
.716 .3374 Mdot
.716 .33741 Mdot
.716 .33741 Mdot
.716 .33743 Mdot
.716 .33743 Mdot
.716 .33745 Mdot
.716 .33751 Mdot
.716 .33771 Mdot
.716 .33773 Mdot
.716 .33795 Mdot
.716 .33797 Mdot
.716 .33802 Mdot
.716 .3381 Mdot
.716 .33823 Mdot
.716 .33841 Mdot
.716 .33845 Mdot
.716 .3387 Mdot
.716 .33872 Mdot
.716 .33876 Mdot
.716 .3388 Mdot
.716 .33894 Mdot
.716 .33917 Mdot
.716 .33924 Mdot
.716 .33929 Mdot
.716 .3396 Mdot
.716 .33968 Mdot
.716 .3397 Mdot
.716 .33971 Mdot
.716 .33976 Mdot
.716 .33981 Mdot
.716 .33986 Mdot
.716 .34007 Mdot
.716 .34021 Mdot
.716 .34024 Mdot
.716 .34039 Mdot
.716 .3404 Mdot
.716 .34045 Mdot
.716 .34051 Mdot
.716 .34053 Mdot
.716 .34057 Mdot
.716 .34062 Mdot
.716 .3407 Mdot
.716 .34077 Mdot
.716 .34077 Mdot
.716 .34092 Mdot
.716 .34094 Mdot
.716 .34115 Mdot
.716 .34136 Mdot
.716 .34148 Mdot
.716 .34148 Mdot
.716 .34159 Mdot
.716 .34162 Mdot
.716 .34195 Mdot
.716 .34222 Mdot
.716 .34236 Mdot
.716 .34241 Mdot
.716 .34248 Mdot
.716 .34261 Mdot
.716 .34268 Mdot
.716 .34277 Mdot
.716 .3428 Mdot
.716 .34281 Mdot
.716 .34282 Mdot
.716 .34283 Mdot
.716 .34295 Mdot
.716 .34302 Mdot
.716 .34304 Mdot
.716 .34317 Mdot
.716 .34324 Mdot
.716 .34326 Mdot
.716 .34336 Mdot
.716 .34338 Mdot
.716 .34341 Mdot
.716 .34351 Mdot
.716 .34369 Mdot
.716 .34372 Mdot
.716 .34384 Mdot
.716 .34393 Mdot
.716 .34395 Mdot
.716 .34398 Mdot
.716 .34403 Mdot
.716 .34412 Mdot
.716 .34412 Mdot
.716 .34412 Mdot
.716 .34416 Mdot
.716 .34418 Mdot
.716 .34435 Mdot
.716 .34435 Mdot
.716 .34435 Mdot
.716 .34437 Mdot
.716 .34443 Mdot
.716 .34449 Mdot
.716 .34462 Mdot
.716 .34463 Mdot
.716 .34468 Mdot
.716 .34472 Mdot
.716 .34473 Mdot
.716 .34478 Mdot
.716 .34479 Mdot
.716 .3448 Mdot
.716 .34487 Mdot
.716 .34492 Mdot
.716 .34494 Mdot
.716 .34497 Mdot
.716 .34504 Mdot
.716 .3451 Mdot
.716 .34512 Mdot
.716 .34513 Mdot
.716 .34514 Mdot
.716 .34523 Mdot
.716 .34526 Mdot
.716 .34526 Mdot
.716 .34527 Mdot
.716 .34528 Mdot
.716 .34529 Mdot
.716 .3453 Mdot
.716 .3454 Mdot
.716 .34547 Mdot
.716 .34556 Mdot
.716 .34561 Mdot
.716 .3458 Mdot
.716 .34582 Mdot
.716 .34596 Mdot
.716 .34599 Mdot
.716 .34603 Mdot
.716 .3461 Mdot
.716 .34616 Mdot
.716 .34618 Mdot
.716 .34619 Mdot
.716 .34637 Mdot
.716 .3464 Mdot
.716 .34644 Mdot
.716 .3465 Mdot
.716 .34659 Mdot
.716 .34659 Mdot
.716 .3466 Mdot
.716 .34663 Mdot
.716 .34666 Mdot
.716 .34669 Mdot
.716 .3469 Mdot
.716 .34698 Mdot
.716 .34699 Mdot
.716 .34699 Mdot
.716 .34705 Mdot
.716 .34706 Mdot
.716 .34711 Mdot
.716 .34722 Mdot
.716 .34723 Mdot
.716 .34726 Mdot
.716 .34726 Mdot
.716 .34732 Mdot
.716 .34737 Mdot
.716 .34745 Mdot
.716 .34746 Mdot
.716 .34752 Mdot
.716 .34753 Mdot
.716 .34764 Mdot
.716 .34776 Mdot
.716 .34781 Mdot
.716 .34784 Mdot
.716 .3479 Mdot
.716 .34792 Mdot
.716 .34797 Mdot
.716 .34799 Mdot
.716 .34805 Mdot
.716 .34814 Mdot
.716 .3482 Mdot
.716 .3483 Mdot
.716 .34847 Mdot
.716 .34851 Mdot
.716 .34859 Mdot
.716 .34872 Mdot
.716 .34872 Mdot
.716 .34877 Mdot
.716 .34879 Mdot
.716 .34881 Mdot
.716 .34881 Mdot
.716 .34883 Mdot
.716 .34885 Mdot
.716 .34885 Mdot
.716 .34891 Mdot
.716 .34897 Mdot
.716 .34906 Mdot
.716 .34907 Mdot
.716 .34909 Mdot
.716 .3491 Mdot
.716 .34913 Mdot
.716 .34923 Mdot
.716 .34927 Mdot
.716 .34935 Mdot
.716 .34941 Mdot
.716 .34943 Mdot
.716 .34951 Mdot
.716 .34959 Mdot
.716 .34963 Mdot
.716 .34966 Mdot
.716 .34967 Mdot
.716 .34968 Mdot
.716 .34975 Mdot
.716 .34976 Mdot
.716 .34982 Mdot
.716 .34984 Mdot
.716 .3499 Mdot
.716 .34993 Mdot
.716 .35012 Mdot
.716 .35021 Mdot
.716 .3503 Mdot
.716 .35032 Mdot
.716 .35033 Mdot
.716 .35033 Mdot
.716 .35035 Mdot
.716 .3504 Mdot
.716 .35041 Mdot
.716 .35042 Mdot
.716 .35045 Mdot
.716 .35046 Mdot
.716 .35053 Mdot
.716 .35058 Mdot
.716 .3506 Mdot
.716 .35064 Mdot
.716 .35065 Mdot
.716 .35065 Mdot
.716 .35066 Mdot
.716 .35067 Mdot
.716 .35071 Mdot
.716 .35071 Mdot
.716 .35072 Mdot
.716 .35075 Mdot
.716 .35075 Mdot
.716 .35077 Mdot
.716 .35078 Mdot
.716 .35085 Mdot
.716 .35087 Mdot
.716 .35089 Mdot
.716 .35091 Mdot
.716 .35103 Mdot
.716 .35114 Mdot
.716 .35117 Mdot
.716 .35118 Mdot
.716 .35122 Mdot
.716 .35143 Mdot
.716 .35145 Mdot
.716 .35148 Mdot
.716 .35153 Mdot
.716 .35154 Mdot
.716 .35157 Mdot
.716 .35159 Mdot
.716 .35163 Mdot
.716 .35171 Mdot
.716 .35172 Mdot
.716 .35177 Mdot
.716 .35179 Mdot
.716 .35193 Mdot
.716 .35195 Mdot
.716 .35197 Mdot
.716 .352 Mdot
.716 .35201 Mdot
.716 .35212 Mdot
.716 .35213 Mdot
.716 .35213 Mdot
.716 .35215 Mdot
.716 .35217 Mdot
.716 .35224 Mdot
.716 .35225 Mdot
.716 .35226 Mdot
.716 .35229 Mdot
.716 .35231 Mdot
.716 .35233 Mdot
.716 .35241 Mdot
.716 .35244 Mdot
.716 .35246 Mdot
.716 .35249 Mdot
.716 .35259 Mdot
.716 .3526 Mdot
.716 .35265 Mdot
.716 .35268 Mdot
.716 .35275 Mdot
.716 .35285 Mdot
.716 .35288 Mdot
.716 .35289 Mdot
.716 .35289 Mdot
.716 .3529 Mdot
.716 .35291 Mdot
.716 .35292 Mdot
.716 .35293 Mdot
.716 .35295 Mdot
.716 .35295 Mdot
.716 .35295 Mdot
.716 .35299 Mdot
.716 .35302 Mdot
.716 .35305 Mdot
.716 .35305 Mdot
.716 .35305 Mdot
.716 .35308 Mdot
.716 .35308 Mdot
.716 .35308 Mdot
.716 .35308 Mdot
.716 .35308 Mdot
.716 .35309 Mdot
.716 .35309 Mdot
.716 .35309 Mdot
.716 .35309 Mdot
.716 .35309 Mdot
.716 .35309 Mdot
.716 .35309 Mdot
.716 .41253 Mdot
.716 .41253 Mdot
.716 .41253 Mdot
.716 .41253 Mdot
.716 .41253 Mdot
.716 .41254 Mdot
.716 .41254 Mdot
.716 .41254 Mdot
.716 .41254 Mdot
.716 .41254 Mdot
.716 .41254 Mdot
.716 .41254 Mdot
.716 .41254 Mdot
.716 .41255 Mdot
.716 .41255 Mdot
.716 .41255 Mdot
.716 .41256 Mdot
.716 .41257 Mdot
.716 .41257 Mdot
.716 .41257 Mdot
.716 .41258 Mdot
.716 .41258 Mdot
.716 .41258 Mdot
.716 .41258 Mdot
.716 .41259 Mdot
.716 .41259 Mdot
.716 .41259 Mdot
.716 .4126 Mdot
.716 .41262 Mdot
.716 .41264 Mdot
.716 .41265 Mdot
.716 .41266 Mdot
.716 .41267 Mdot
.716 .41269 Mdot
.716 .4127 Mdot
.716 .4127 Mdot
.716 .41271 Mdot
.716 .41273 Mdot
.716 .41274 Mdot
.716 .41274 Mdot
.716 .41275 Mdot
.716 .41275 Mdot
.716 .41275 Mdot
.716 .41277 Mdot
.716 .41278 Mdot
.716 .41278 Mdot
.716 .41278 Mdot
.716 .41279 Mdot
.716 .41281 Mdot
.716 .41282 Mdot
.716 .41282 Mdot
.716 .41283 Mdot
.716 .41283 Mdot
.716 .41287 Mdot
.716 .41287 Mdot
.716 .41289 Mdot
.716 .41289 Mdot
.716 .41291 Mdot
.716 .41292 Mdot
.716 .41293 Mdot
.716 .41293 Mdot
.716 .41294 Mdot
.716 .41295 Mdot
.716 .41296 Mdot
.716 .41296 Mdot
.716 .41302 Mdot
.716 .41303 Mdot
.716 .41303 Mdot
.716 .41304 Mdot
.716 .41307 Mdot
.716 .4131 Mdot
.716 .4131 Mdot
.716 .41311 Mdot
.716 .41311 Mdot
.716 .41313 Mdot
.716 .41313 Mdot
.716 .41314 Mdot
.716 .41314 Mdot
.716 .41315 Mdot
.716 .41315 Mdot
.716 .41315 Mdot
.716 .41316 Mdot
.716 .41316 Mdot
.716 .41316 Mdot
.716 .41316 Mdot
.716 .41317 Mdot
.716 .41318 Mdot
.716 .41318 Mdot
.716 .4132 Mdot
.716 .41321 Mdot
.716 .41321 Mdot
.716 .41322 Mdot
.716 .41322 Mdot
.716 .41323 Mdot
.716 .41324 Mdot
.716 .41325 Mdot
.716 .41325 Mdot
.716 .41325 Mdot
.716 .41325 Mdot
.716 .41328 Mdot
.716 .4133 Mdot
.716 .41335 Mdot
.716 .41335 Mdot
.716 .41337 Mdot
.716 .41338 Mdot
.716 .41339 Mdot
.716 .41339 Mdot
.716 .41341 Mdot
.716 .41342 Mdot
.716 .41342 Mdot
.716 .41343 Mdot
.716 .41344 Mdot
.716 .41346 Mdot
.716 .41348 Mdot
.716 .41348 Mdot
.716 .4135 Mdot
.716 .41352 Mdot
.716 .41353 Mdot
.716 .41355 Mdot
.716 .41356 Mdot
.716 .41356 Mdot
.716 .41357 Mdot
.716 .41357 Mdot
.716 .4136 Mdot
.716 .41361 Mdot
.716 .41362 Mdot
.716 .41363 Mdot
.716 .41363 Mdot
.716 .41364 Mdot
.716 .41364 Mdot
.716 .41364 Mdot
.716 .41365 Mdot
.716 .41366 Mdot
.716 .41366 Mdot
.716 .41369 Mdot
.716 .41371 Mdot
.716 .41372 Mdot
.716 .41377 Mdot
.716 .41379 Mdot
.716 .41381 Mdot
.716 .41383 Mdot
.716 .41385 Mdot
.716 .41385 Mdot
.716 .41386 Mdot
.716 .41387 Mdot
.716 .41389 Mdot
.716 .41389 Mdot
.716 .41391 Mdot
.716 .41394 Mdot
.716 .41396 Mdot
.716 .41397 Mdot
.716 .41398 Mdot
.716 .41399 Mdot
.716 .414 Mdot
.716 .41402 Mdot
.716 .41403 Mdot
.716 .41403 Mdot
.716 .41404 Mdot
.716 .41404 Mdot
.716 .41407 Mdot
.716 .41408 Mdot
.716 .41409 Mdot
.716 .4141 Mdot
.716 .4141 Mdot
.716 .4141 Mdot
.716 .41413 Mdot
.716 .41418 Mdot
.716 .41419 Mdot
.716 .4142 Mdot
.716 .4142 Mdot
.716 .41421 Mdot
.716 .41421 Mdot
.716 .41423 Mdot
.716 .41424 Mdot
.716 .41425 Mdot
.716 .41426 Mdot
.716 .41431 Mdot
.716 .41431 Mdot
.716 .41432 Mdot
.716 .41433 Mdot
.716 .41435 Mdot
.716 .41436 Mdot
.716 .41437 Mdot
.716 .4144 Mdot
.716 .41441 Mdot
.716 .41446 Mdot
.716 .41447 Mdot
.716 .41449 Mdot
.716 .41451 Mdot
.716 .41454 Mdot
.716 .41454 Mdot
.716 .41454 Mdot
.716 .41454 Mdot
.716 .41455 Mdot
.716 .41455 Mdot
.716 .41455 Mdot
.716 .41458 Mdot
.716 .41458 Mdot
.716 .41458 Mdot
.716 .41459 Mdot
.716 .4146 Mdot
.716 .41462 Mdot
.716 .41463 Mdot
.716 .41463 Mdot
.716 .41465 Mdot
.716 .41466 Mdot
.716 .41467 Mdot
.716 .41467 Mdot
.716 .41468 Mdot
.716 .41468 Mdot
.716 .41469 Mdot
.716 .41471 Mdot
.716 .41471 Mdot
.716 .41474 Mdot
.716 .41476 Mdot
.716 .41477 Mdot
.716 .41478 Mdot
.716 .41478 Mdot
.716 .41478 Mdot
.716 .41482 Mdot
.716 .41483 Mdot
.716 .41484 Mdot
.716 .41484 Mdot
.716 .41484 Mdot
.716 .41486 Mdot
.716 .41487 Mdot
.716 .41488 Mdot
.716 .41489 Mdot
.716 .41491 Mdot
.716 .41494 Mdot
.716 .41495 Mdot
.716 .41499 Mdot
.716 .41502 Mdot
.716 .41503 Mdot
.716 .41503 Mdot
.716 .41506 Mdot
.716 .41506 Mdot
.716 .41508 Mdot
.716 .41512 Mdot
.716 .41512 Mdot
.716 .41514 Mdot
.716 .41517 Mdot
.716 .41517 Mdot
.716 .41517 Mdot
.716 .41518 Mdot
.716 .41521 Mdot
.716 .41522 Mdot
.716 .41526 Mdot
.716 .41528 Mdot
.716 .41529 Mdot
.716 .41532 Mdot
.716 .41539 Mdot
.716 .41548 Mdot
.716 .41549 Mdot
.716 .41551 Mdot
.716 .41551 Mdot
.716 .41554 Mdot
.716 .4156 Mdot
.716 .41565 Mdot
.716 .41566 Mdot
.716 .41569 Mdot
.716 .4157 Mdot
.716 .41571 Mdot
.716 .41573 Mdot
.716 .41575 Mdot
.716 .41576 Mdot
.716 .41576 Mdot
.716 .41578 Mdot
.716 .41579 Mdot
.716 .41579 Mdot
.716 .41583 Mdot
.716 .41584 Mdot
.716 .41588 Mdot
.716 .41593 Mdot
.716 .41594 Mdot
.716 .41595 Mdot
.716 .41597 Mdot
.716 .41597 Mdot
.716 .41598 Mdot
.716 .41599 Mdot
.716 .41607 Mdot
.716 .41609 Mdot
.716 .41611 Mdot
.716 .41616 Mdot
.716 .4162 Mdot
.716 .41621 Mdot
.716 .41622 Mdot
.716 .41623 Mdot
.716 .41629 Mdot
.716 .4163 Mdot
.716 .41635 Mdot
.716 .41638 Mdot
.716 .4164 Mdot
.716 .41641 Mdot
.716 .41642 Mdot
.716 .41647 Mdot
.716 .41648 Mdot
.716 .41653 Mdot
.716 .41655 Mdot
.716 .41655 Mdot
.716 .41655 Mdot
.716 .41656 Mdot
.716 .41656 Mdot
.716 .41656 Mdot
.716 .41656 Mdot
.716 .41657 Mdot
.716 .41659 Mdot
.716 .4166 Mdot
.716 .4166 Mdot
.716 .41661 Mdot
.716 .41661 Mdot
.716 .41661 Mdot
.716 .41662 Mdot
.716 .4167 Mdot
.716 .41672 Mdot
.716 .41673 Mdot
.716 .41678 Mdot
.716 .4168 Mdot
.716 .41682 Mdot
.716 .41684 Mdot
.716 .41685 Mdot
.716 .41685 Mdot
.716 .41687 Mdot
.716 .41692 Mdot
.716 .41694 Mdot
.716 .41694 Mdot
.716 .41694 Mdot
.716 .41695 Mdot
.716 .41696 Mdot
.716 .41699 Mdot
.716 .417 Mdot
.716 .41701 Mdot
.716 .41702 Mdot
.716 .41705 Mdot
.716 .41705 Mdot
.716 .41705 Mdot
.716 .41706 Mdot
.716 .41708 Mdot
.716 .41708 Mdot
.716 .41709 Mdot
.716 .41709 Mdot
.716 .41711 Mdot
.716 .41715 Mdot
.716 .41716 Mdot
.716 .41717 Mdot
.716 .41719 Mdot
.716 .4172 Mdot
.716 .41721 Mdot
.716 .41721 Mdot
.716 .41722 Mdot
.716 .41722 Mdot
.716 .41723 Mdot
.716 .41723 Mdot
.716 .41724 Mdot
.716 .41725 Mdot
.716 .41726 Mdot
.716 .41726 Mdot
.716 .41726 Mdot
.716 .41727 Mdot
.716 .41729 Mdot
.716 .4173 Mdot
.716 .4173 Mdot
.716 .4173 Mdot
.716 .41731 Mdot
.716 .41732 Mdot
.716 .41732 Mdot
.716 .41733 Mdot
.716 .41734 Mdot
.716 .41734 Mdot
.716 .41738 Mdot
.716 .41738 Mdot
.716 .41739 Mdot
.716 .41741 Mdot
.716 .41743 Mdot
.716 .41743 Mdot
.716 .41746 Mdot
.716 .41752 Mdot
.716 .41753 Mdot
.716 .41757 Mdot
.716 .41759 Mdot
.716 .41763 Mdot
.716 .41765 Mdot
.716 .41766 Mdot
.716 .41769 Mdot
.716 .41773 Mdot
.716 .41788 Mdot
.716 .41788 Mdot
.716 .4179 Mdot
.716 .41792 Mdot
.716 .41793 Mdot
.716 .41794 Mdot
.716 .41795 Mdot
.716 .41797 Mdot
.716 .41798 Mdot
.716 .41799 Mdot
.716 .41801 Mdot
.716 .41803 Mdot
.716 .41806 Mdot
.716 .41813 Mdot
.716 .41814 Mdot
.716 .41815 Mdot
.716 .41819 Mdot
.716 .41821 Mdot
.716 .41823 Mdot
.716 .41824 Mdot
.716 .41831 Mdot
.716 .41832 Mdot
.716 .41833 Mdot
.716 .41834 Mdot
.716 .41834 Mdot
.716 .41836 Mdot
.716 .41836 Mdot
.716 .41839 Mdot
.716 .41841 Mdot
.716 .41841 Mdot
.716 .4185 Mdot
.716 .41851 Mdot
.716 .41851 Mdot
.716 .41853 Mdot
.716 .41855 Mdot
.716 .41859 Mdot
.716 .41861 Mdot
.716 .41862 Mdot
.716 .41863 Mdot
.716 .41864 Mdot
.716 .41866 Mdot
.716 .41867 Mdot
.716 .41869 Mdot
.716 .41873 Mdot
.716 .41876 Mdot
.716 .41877 Mdot
.716 .41879 Mdot
.716 .4188 Mdot
.716 .41881 Mdot
.716 .41882 Mdot
.716 .41884 Mdot
.716 .41884 Mdot
.716 .41888 Mdot
.716 .4189 Mdot
.716 .41891 Mdot
.716 .41893 Mdot
.716 .41894 Mdot
.716 .41899 Mdot
.716 .419 Mdot
.716 .419 Mdot
.716 .41902 Mdot
.716 .41908 Mdot
.716 .41909 Mdot
.716 .41913 Mdot
.716 .41916 Mdot
.716 .41917 Mdot
.716 .41919 Mdot
.716 .41921 Mdot
.716 .41922 Mdot
.716 .41922 Mdot
.716 .41922 Mdot
.716 .41923 Mdot
.716 .41923 Mdot
.716 .41924 Mdot
.716 .41924 Mdot
.716 .41924 Mdot
.716 .41926 Mdot
.716 .41928 Mdot
.716 .41928 Mdot
.716 .41928 Mdot
.716 .41929 Mdot
.716 .41931 Mdot
.716 .41934 Mdot
.716 .41934 Mdot
.716 .41936 Mdot
.716 .41937 Mdot
.716 .41937 Mdot
.716 .41939 Mdot
.716 .4194 Mdot
.716 .4194 Mdot
.716 .4194 Mdot
.716 .4194 Mdot
.716 .41941 Mdot
.716 .41941 Mdot
.716 .41941 Mdot
.716 .41941 Mdot
.716 .41941 Mdot
.716 .41941 Mdot
.716 .41941 Mdot
.716 .41948 Mdot
.716 .4195 Mdot
.716 .41965 Mdot
.716 .41971 Mdot
.716 .41978 Mdot
.716 .41979 Mdot
.716 .41986 Mdot
.716 .41988 Mdot
.716 .41998 Mdot
.716 .41999 Mdot
.716 .42005 Mdot
.716 .42013 Mdot
.716 .42022 Mdot
.716 .42022 Mdot
.716 .42026 Mdot
.716 .42031 Mdot
.718 .33439 Mdot
.718 .34053 Mdot
.718 .3497 Mdot
.718 .41365 Mdot
.718 .41599 Mdot
.718 .41756 Mdot
.72 .3401 Mdot
.72 .34621 Mdot
.72 .41477 Mdot
.72 .41633 Mdot
.722 .34227 Mdot
.722 .41601 Mdot
.724 .30944 Mdot
.724 .30983 Mdot
.724 .30989 Mdot
.724 .30995 Mdot
.724 .31017 Mdot
.724 .31074 Mdot
.724 .31135 Mdot
.724 .31172 Mdot
.724 .31205 Mdot
.724 .31206 Mdot
.724 .3123 Mdot
.724 .3124 Mdot
.724 .31281 Mdot
.724 .31291 Mdot
.724 .31292 Mdot
.724 .313 Mdot
.724 .31329 Mdot
.724 .31334 Mdot
.724 .31334 Mdot
.724 .31348 Mdot
.724 .31393 Mdot
.724 .31394 Mdot
.724 .314 Mdot
.724 .31407 Mdot
.724 .31438 Mdot
.724 .31479 Mdot
.724 .31486 Mdot
.724 .31496 Mdot
.724 .31501 Mdot
.724 .31507 Mdot
.724 .31531 Mdot
.724 .3154 Mdot
.724 .31546 Mdot
.724 .31548 Mdot
.724 .31566 Mdot
.724 .31627 Mdot
.724 .31632 Mdot
.724 .3167 Mdot
.724 .31675 Mdot
.724 .31685 Mdot
.724 .3171 Mdot
.724 .31717 Mdot
.724 .31718 Mdot
.724 .31719 Mdot
.724 .31757 Mdot
.724 .31767 Mdot
.724 .31819 Mdot
.724 .31824 Mdot
.724 .31834 Mdot
.724 .31866 Mdot
.724 .31902 Mdot
.724 .31956 Mdot
.724 .31992 Mdot
.724 .32 Mdot
.724 .32017 Mdot
.724 .3202 Mdot
.724 .32036 Mdot
.724 .32073 Mdot
.724 .32076 Mdot
.724 .32101 Mdot
.724 .32118 Mdot
.724 .32141 Mdot
.724 .32178 Mdot
.724 .3219 Mdot
.724 .32193 Mdot
.724 .32224 Mdot
.724 .32231 Mdot
.724 .32266 Mdot
.724 .32283 Mdot
.724 .32307 Mdot
.724 .32331 Mdot
.724 .32354 Mdot
.724 .32354 Mdot
.724 .32355 Mdot
.724 .32368 Mdot
.724 .3238 Mdot
.724 .32392 Mdot
.724 .32396 Mdot
.724 .324 Mdot
.724 .32415 Mdot
.724 .32418 Mdot
.724 .32422 Mdot
.724 .32426 Mdot
.724 .32453 Mdot
.724 .32485 Mdot
.724 .3249 Mdot
.724 .32497 Mdot
.724 .32506 Mdot
.724 .32506 Mdot
.724 .3252 Mdot
.724 .32558 Mdot
.724 .32575 Mdot
.724 .32581 Mdot
.724 .32598 Mdot
.724 .32618 Mdot
.724 .32628 Mdot
.724 .32631 Mdot
.724 .32635 Mdot
.724 .32635 Mdot
.724 .32641 Mdot
.724 .32666 Mdot
.724 .32667 Mdot
.724 .32679 Mdot
.724 .32693 Mdot
.724 .32697 Mdot
.724 .32716 Mdot
.724 .32717 Mdot
.724 .32751 Mdot
.724 .32762 Mdot
.724 .32773 Mdot
.724 .32784 Mdot
.724 .32791 Mdot
.724 .3282 Mdot
.724 .32821 Mdot
.724 .32822 Mdot
.724 .32824 Mdot
.724 .32831 Mdot
.724 .32843 Mdot
.724 .32851 Mdot
.724 .32852 Mdot
.724 .32852 Mdot
.724 .32873 Mdot
.724 .32873 Mdot
.724 .32885 Mdot
.724 .3289 Mdot
.724 .32904 Mdot
.724 .32927 Mdot
.724 .32931 Mdot
.724 .32932 Mdot
.724 .32934 Mdot
.724 .32945 Mdot
.724 .3297 Mdot
.724 .32989 Mdot
.724 .32996 Mdot
.724 .33002 Mdot
.724 .33011 Mdot
.724 .33014 Mdot
.724 .3302 Mdot
.724 .33021 Mdot
.724 .33021 Mdot
.724 .33024 Mdot
.724 .33036 Mdot
.724 .33051 Mdot
.724 .33053 Mdot
.724 .33056 Mdot
.724 .33057 Mdot
.724 .33069 Mdot
.724 .33082 Mdot
.724 .33083 Mdot
.724 .33091 Mdot
.724 .33093 Mdot
.724 .331 Mdot
.724 .33102 Mdot
.724 .33102 Mdot
.724 .3311 Mdot
.724 .33125 Mdot
.724 .33127 Mdot
.724 .33143 Mdot
.724 .33155 Mdot
.724 .33163 Mdot
.724 .33165 Mdot
.724 .33173 Mdot
.724 .33182 Mdot
.724 .33183 Mdot
.724 .33198 Mdot
.724 .3321 Mdot
.724 .33211 Mdot
.724 .33229 Mdot
.724 .33233 Mdot
.724 .33239 Mdot
.724 .33251 Mdot
.724 .3326 Mdot
.724 .33261 Mdot
.724 .33263 Mdot
.724 .33266 Mdot
.724 .33267 Mdot
.724 .33269 Mdot
.724 .33276 Mdot
.724 .33286 Mdot
.724 .3329 Mdot
.724 .3329 Mdot
.724 .33294 Mdot
.724 .33309 Mdot
.724 .33324 Mdot
.724 .33325 Mdot
.724 .33326 Mdot
.724 .33334 Mdot
.724 .33335 Mdot
.724 .33338 Mdot
.724 .33342 Mdot
.724 .33349 Mdot
.724 .33349 Mdot
.724 .33359 Mdot
.724 .33362 Mdot
.724 .33369 Mdot
.724 .33371 Mdot
.724 .3338 Mdot
.724 .33381 Mdot
.724 .33383 Mdot
.724 .33386 Mdot
.724 .33389 Mdot
.724 .33396 Mdot
.724 .33399 Mdot
.724 .33405 Mdot
.724 .33413 Mdot
.724 .33414 Mdot
.724 .33414 Mdot
.724 .33415 Mdot
.724 .33418 Mdot
.724 .33426 Mdot
.724 .33435 Mdot
.724 .33437 Mdot
.724 .33441 Mdot
.724 .33443 Mdot
.724 .33443 Mdot
.724 .33443 Mdot
.724 .33444 Mdot
.724 .33448 Mdot
.724 .33453 Mdot
.724 .33454 Mdot
.724 .33455 Mdot
.724 .33455 Mdot
.724 .33464 Mdot
.724 .33468 Mdot
.724 .3347 Mdot
.724 .33474 Mdot
.724 .33479 Mdot
.724 .3348 Mdot
.724 .33493 Mdot
.724 .33497 Mdot
.724 .3351 Mdot
.724 .3351 Mdot
.724 .33519 Mdot
.724 .33526 Mdot
.724 .3353 Mdot
.724 .33533 Mdot
.724 .33536 Mdot
.724 .3354 Mdot
.724 .33541 Mdot
.724 .33541 Mdot
.724 .33543 Mdot
.724 .33549 Mdot
.724 .33555 Mdot
.724 .33556 Mdot
.724 .33559 Mdot
.724 .33559 Mdot
.724 .33561 Mdot
.724 .33562 Mdot
.724 .33565 Mdot
.724 .33569 Mdot
.724 .33571 Mdot
.724 .33579 Mdot
.724 .3358 Mdot
.724 .33582 Mdot
.724 .33585 Mdot
.724 .33587 Mdot
.724 .3359 Mdot
.724 .33593 Mdot
.724 .33593 Mdot
.724 .33594 Mdot
.724 .33594 Mdot
.724 .33595 Mdot
.724 .33599 Mdot
.724 .33604 Mdot
.724 .33606 Mdot
.724 .33607 Mdot
.724 .33607 Mdot
.724 .33607 Mdot
.724 .33609 Mdot
.724 .33612 Mdot
.724 .33612 Mdot
.724 .33616 Mdot
.724 .33618 Mdot
.724 .33621 Mdot
.724 .33623 Mdot
.724 .3363 Mdot
.724 .33632 Mdot
.724 .33638 Mdot
.724 .33639 Mdot
.724 .33643 Mdot
.724 .33646 Mdot
.724 .33648 Mdot
.724 .3365 Mdot
.724 .33651 Mdot
.724 .33653 Mdot
.724 .33654 Mdot
.724 .33655 Mdot
.724 .33658 Mdot
.724 .33661 Mdot
.724 .33664 Mdot
.724 .33665 Mdot
.724 .33667 Mdot
.724 .33669 Mdot
.724 .33674 Mdot
.724 .33674 Mdot
.724 .33678 Mdot
.724 .33678 Mdot
.724 .3368 Mdot
.724 .33682 Mdot
.724 .33682 Mdot
.724 .33682 Mdot
.724 .33682 Mdot
.724 .33683 Mdot
.724 .33685 Mdot
.724 .33688 Mdot
.724 .33689 Mdot
.724 .33689 Mdot
.724 .33689 Mdot
.724 .33689 Mdot
.724 .33691 Mdot
.724 .33693 Mdot
.724 .33695 Mdot
.724 .33698 Mdot
.724 .33698 Mdot
.724 .33699 Mdot
.724 .33703 Mdot
.724 .33708 Mdot
.724 .3371 Mdot
.724 .33712 Mdot
.724 .33714 Mdot
.724 .33715 Mdot
.724 .33716 Mdot
.724 .33717 Mdot
.724 .33717 Mdot
.724 .33718 Mdot
.724 .3372 Mdot
.724 .33722 Mdot
.724 .33723 Mdot
.724 .33724 Mdot
.724 .33725 Mdot
.724 .33727 Mdot
.724 .3373 Mdot
.724 .3373 Mdot
.724 .33732 Mdot
.724 .33733 Mdot
.724 .33733 Mdot
.724 .33735 Mdot
.724 .33735 Mdot
.724 .33735 Mdot
.724 .33735 Mdot
.724 .33735 Mdot
.724 .33737 Mdot
.724 .33739 Mdot
.724 .33739 Mdot
.724 .3374 Mdot
.724 .3374 Mdot
.724 .3374 Mdot
.724 .3374 Mdot
.724 .33743 Mdot
.724 .33745 Mdot
.724 .33746 Mdot
.724 .33752 Mdot
.724 .33754 Mdot
.724 .33755 Mdot
.724 .33756 Mdot
.724 .33757 Mdot
.724 .33758 Mdot
.724 .33759 Mdot
.724 .33759 Mdot
.724 .3376 Mdot
.724 .33763 Mdot
.724 .33763 Mdot
.724 .33764 Mdot
.724 .33765 Mdot
.724 .33769 Mdot
.724 .33769 Mdot
.724 .3377 Mdot
.724 .33771 Mdot
.724 .33771 Mdot
.724 .33771 Mdot
.724 .33771 Mdot
.724 .33771 Mdot
.724 .33772 Mdot
.724 .33774 Mdot
.724 .33774 Mdot
.724 .33774 Mdot
.724 .33775 Mdot
.724 .33775 Mdot
.724 .33775 Mdot
.724 .33777 Mdot
.724 .33779 Mdot
.724 .33779 Mdot
.724 .33784 Mdot
.724 .33786 Mdot
.724 .33787 Mdot
.724 .33787 Mdot
.724 .33789 Mdot
.724 .33789 Mdot
.724 .33789 Mdot
.724 .33792 Mdot
.724 .33793 Mdot
.724 .33793 Mdot
.724 .33794 Mdot
.724 .33797 Mdot
.724 .33797 Mdot
.724 .33799 Mdot
.724 .33799 Mdot
.724 .33799 Mdot
.724 .33799 Mdot
.724 .33799 Mdot
.724 .338 Mdot
.724 .33801 Mdot
.724 .33801 Mdot
.724 .33801 Mdot
.724 .33802 Mdot
.724 .33802 Mdot
.724 .33802 Mdot
.724 .33805 Mdot
.724 .33811 Mdot
.724 .33812 Mdot
.724 .33813 Mdot
.724 .33813 Mdot
.724 .33814 Mdot
.724 .33816 Mdot
.724 .33817 Mdot
.724 .33817 Mdot
.724 .33818 Mdot
.724 .33821 Mdot
.724 .33821 Mdot
.724 .33822 Mdot
.724 .33822 Mdot
.724 .33822 Mdot
.724 .33822 Mdot
.724 .33823 Mdot
.724 .33824 Mdot
.724 .33824 Mdot
.724 .33825 Mdot
.724 .33825 Mdot
.724 .33825 Mdot
.724 .33825 Mdot
.724 .33828 Mdot
.724 .33833 Mdot
.724 .33834 Mdot
.724 .33835 Mdot
.724 .33836 Mdot
.724 .33836 Mdot
.724 .33838 Mdot
.724 .33839 Mdot
.724 .33839 Mdot
.724 .3384 Mdot
.724 .33842 Mdot
.724 .33843 Mdot
.724 .33844 Mdot
.724 .33844 Mdot
.724 .33844 Mdot
.724 .33844 Mdot
.724 .33845 Mdot
.724 .33846 Mdot
.724 .33846 Mdot
.724 .33846 Mdot
.724 .33846 Mdot
.724 .33846 Mdot
.724 .33847 Mdot
.724 .33855 Mdot
.724 .33856 Mdot
.724 .33857 Mdot
.724 .33857 Mdot
.724 .33858 Mdot
.724 .3386 Mdot
.724 .33861 Mdot
.724 .33861 Mdot
.724 .33862 Mdot
.724 .33865 Mdot
.724 .33865 Mdot
.724 .33866 Mdot
.724 .33866 Mdot
.724 .33867 Mdot
.724 .33867 Mdot
.724 .33869 Mdot
.724 .33869 Mdot
.724 .33869 Mdot
.724 .33869 Mdot
.724 .33869 Mdot
.724 .33879 Mdot
.724 .33881 Mdot
.724 .33882 Mdot
.724 .33882 Mdot
.724 .33886 Mdot
.724 .33887 Mdot
.724 .3389 Mdot
.724 .33891 Mdot
.724 .33892 Mdot
.724 .33892 Mdot
.724 .33893 Mdot
.724 .33896 Mdot
.724 .33896 Mdot
.724 .33896 Mdot
.724 .33896 Mdot
.724 .33896 Mdot
.724 .33909 Mdot
.724 .33913 Mdot
.724 .33913 Mdot
.724 .33913 Mdot
.724 .33919 Mdot
.724 .33927 Mdot
.724 .33929 Mdot
.724 .3393 Mdot
.724 .33934 Mdot
.724 .33935 Mdot
.724 .33935 Mdot
.724 .41698 Mdot
.724 .41698 Mdot
.724 .41698 Mdot
.724 .41699 Mdot
.724 .41699 Mdot
.724 .417 Mdot
.724 .41702 Mdot
.724 .41703 Mdot
.724 .41703 Mdot
.724 .41704 Mdot
.724 .41704 Mdot
.724 .41708 Mdot
.724 .41708 Mdot
.724 .41708 Mdot
.724 .41708 Mdot
.724 .41708 Mdot
.724 .41709 Mdot
.724 .41709 Mdot
.724 .41709 Mdot
.724 .41709 Mdot
.724 .41709 Mdot
.724 .4171 Mdot
.724 .4171 Mdot
.724 .41711 Mdot
.724 .41711 Mdot
.724 .41712 Mdot
.724 .41712 Mdot
.724 .41715 Mdot
.724 .41715 Mdot
.724 .41715 Mdot
.724 .41715 Mdot
.724 .41715 Mdot
.724 .41715 Mdot
.724 .41715 Mdot
.724 .41715 Mdot
.724 .41715 Mdot
.724 .41716 Mdot
.724 .41716 Mdot
.724 .41716 Mdot
.724 .41717 Mdot
.724 .41717 Mdot
.724 .41717 Mdot
.724 .41718 Mdot
.724 .41718 Mdot
.724 .41718 Mdot
.724 .41718 Mdot
.724 .41718 Mdot
.724 .4172 Mdot
.724 .4172 Mdot
.724 .4172 Mdot
.724 .4172 Mdot
.724 .4172 Mdot
.724 .41721 Mdot
.724 .41721 Mdot
.724 .41721 Mdot
.724 .41721 Mdot
.724 .41721 Mdot
.724 .41721 Mdot
.724 .41721 Mdot
.724 .41721 Mdot
.724 .41722 Mdot
.724 .41722 Mdot
.724 .41722 Mdot
.724 .41723 Mdot
.724 .41723 Mdot
.724 .41723 Mdot
.724 .41723 Mdot
.724 .41724 Mdot
.724 .41724 Mdot
.724 .41725 Mdot
.724 .41726 Mdot
.724 .41726 Mdot
.724 .41726 Mdot
.724 .41726 Mdot
.724 .41726 Mdot
.724 .41726 Mdot
.724 .41726 Mdot
.724 .41727 Mdot
.724 .41727 Mdot
.724 .41727 Mdot
.724 .41727 Mdot
.724 .41727 Mdot
.724 .41727 Mdot
.724 .41728 Mdot
.724 .41728 Mdot
.724 .41728 Mdot
.724 .41728 Mdot
.724 .41729 Mdot
.724 .41729 Mdot
.724 .41729 Mdot
.724 .41729 Mdot
.724 .41729 Mdot
.724 .41731 Mdot
.724 .41732 Mdot
.724 .41732 Mdot
.724 .41732 Mdot
.724 .41732 Mdot
.724 .41732 Mdot
.724 .41732 Mdot
.724 .41732 Mdot
.724 .41732 Mdot
.724 .41733 Mdot
.724 .41733 Mdot
.724 .41733 Mdot
.724 .41733 Mdot
.724 .41733 Mdot
.724 .41733 Mdot
.724 .41734 Mdot
.724 .41734 Mdot
.724 .41734 Mdot
.724 .41734 Mdot
.724 .41735 Mdot
.724 .41735 Mdot
.724 .41735 Mdot
.724 .41735 Mdot
.724 .41736 Mdot
.724 .41736 Mdot
.724 .41736 Mdot
.724 .41737 Mdot
.724 .41738 Mdot
.724 .41738 Mdot
.724 .41739 Mdot
.724 .41739 Mdot
.724 .41739 Mdot
.724 .41739 Mdot
.724 .41739 Mdot
.724 .41739 Mdot
.724 .41739 Mdot
.724 .41739 Mdot
.724 .4174 Mdot
.724 .4174 Mdot
.724 .4174 Mdot
.724 .4174 Mdot
.724 .4174 Mdot
.724 .4174 Mdot
.724 .4174 Mdot
.724 .41741 Mdot
.724 .41741 Mdot
.724 .41742 Mdot
.724 .41742 Mdot
.724 .41742 Mdot
.724 .41743 Mdot
.724 .41743 Mdot
.724 .41743 Mdot
.724 .41743 Mdot
.724 .41743 Mdot
.724 .41744 Mdot
.724 .41744 Mdot
.724 .41744 Mdot
.724 .41746 Mdot
.724 .41746 Mdot
.724 .41747 Mdot
.724 .41747 Mdot
.724 .41748 Mdot
.724 .41748 Mdot
.724 .41748 Mdot
.724 .41748 Mdot
.724 .41748 Mdot
.724 .41748 Mdot
.724 .41749 Mdot
.724 .41749 Mdot
.724 .41749 Mdot
.724 .41749 Mdot
.724 .41749 Mdot
.724 .41749 Mdot
.724 .41749 Mdot
.724 .4175 Mdot
.724 .4175 Mdot
.724 .4175 Mdot
.724 .41751 Mdot
.724 .41751 Mdot
.724 .41751 Mdot
.724 .41752 Mdot
.724 .41752 Mdot
.724 .41753 Mdot
.724 .41753 Mdot
.724 .41753 Mdot
.724 .41753 Mdot
.724 .41754 Mdot
.724 .41754 Mdot
.724 .41754 Mdot
.724 .41754 Mdot
.724 .41755 Mdot
.724 .41756 Mdot
.724 .41757 Mdot
.724 .41758 Mdot
.724 .41758 Mdot
.724 .41758 Mdot
.724 .41759 Mdot
.724 .4176 Mdot
.724 .4176 Mdot
.724 .4176 Mdot
.724 .4176 Mdot
.724 .4176 Mdot
.724 .4176 Mdot
.724 .41761 Mdot
.724 .41761 Mdot
.724 .41762 Mdot
.724 .41762 Mdot
.724 .41762 Mdot
.724 .41762 Mdot
.724 .41762 Mdot
.724 .41763 Mdot
.724 .41763 Mdot
.724 .41763 Mdot
.724 .41764 Mdot
.724 .41764 Mdot
.724 .41766 Mdot
.724 .41766 Mdot
.724 .41766 Mdot
.724 .41767 Mdot
.724 .41767 Mdot
.724 .41768 Mdot
.724 .41769 Mdot
.724 .41769 Mdot
.724 .4177 Mdot
.724 .4177 Mdot
.724 .4177 Mdot
.724 .41771 Mdot
.724 .41771 Mdot
.724 .41772 Mdot
.724 .41773 Mdot
.724 .41773 Mdot
.724 .41775 Mdot
.724 .41775 Mdot
.724 .41777 Mdot
.724 .41778 Mdot
.724 .41778 Mdot
.724 .41779 Mdot
.724 .41779 Mdot
.724 .4178 Mdot
.724 .4178 Mdot
.724 .41781 Mdot
.724 .41781 Mdot
.724 .41781 Mdot
.724 .41781 Mdot
.724 .41782 Mdot
.724 .41782 Mdot
.724 .41783 Mdot
.724 .41784 Mdot
.724 .41785 Mdot
.724 .41785 Mdot
.724 .41785 Mdot
.724 .41785 Mdot
.724 .41786 Mdot
.724 .41786 Mdot
.724 .41787 Mdot
.724 .41788 Mdot
.724 .41788 Mdot
.724 .41789 Mdot
.724 .41791 Mdot
.724 .41791 Mdot
.724 .41792 Mdot
.724 .41793 Mdot
.724 .41793 Mdot
.724 .41793 Mdot
.724 .41794 Mdot
.724 .41794 Mdot
.724 .41795 Mdot
.724 .41796 Mdot
.724 .41798 Mdot
.724 .41798 Mdot
.724 .41798 Mdot
.724 .41798 Mdot
.724 .41799 Mdot
.724 .418 Mdot
.724 .41801 Mdot
.724 .41802 Mdot
.724 .41804 Mdot
.724 .41806 Mdot
.724 .41806 Mdot
.724 .41809 Mdot
.724 .4181 Mdot
.724 .41814 Mdot
.724 .41814 Mdot
.724 .41815 Mdot
.724 .41816 Mdot
.724 .41817 Mdot
.724 .41818 Mdot
.724 .4182 Mdot
.724 .4182 Mdot
.724 .4182 Mdot
.724 .4182 Mdot
.724 .41822 Mdot
.724 .41823 Mdot
.724 .41823 Mdot
.724 .41823 Mdot
.724 .41823 Mdot
.724 .41824 Mdot
.724 .41825 Mdot
.724 .41825 Mdot
.724 .41827 Mdot
.724 .41829 Mdot
.724 .4183 Mdot
.724 .4183 Mdot
.724 .41831 Mdot
.724 .41831 Mdot
.724 .41833 Mdot
.724 .41834 Mdot
.724 .41835 Mdot
.724 .41837 Mdot
.724 .41838 Mdot
.724 .41839 Mdot
.724 .41839 Mdot
.724 .41839 Mdot
.724 .41842 Mdot
.724 .41842 Mdot
.724 .41844 Mdot
.724 .41845 Mdot
.724 .41847 Mdot
.724 .41847 Mdot
.724 .41849 Mdot
.724 .4185 Mdot
.724 .41851 Mdot
.724 .41851 Mdot
.724 .41853 Mdot
.724 .41853 Mdot
.724 .41854 Mdot
.724 .41857 Mdot
.724 .41861 Mdot
.724 .41862 Mdot
.724 .41862 Mdot
.724 .41863 Mdot
.724 .41866 Mdot
.724 .41868 Mdot
.724 .41868 Mdot
.724 .41868 Mdot
.724 .41869 Mdot
.724 .4187 Mdot
.724 .4187 Mdot
.724 .41872 Mdot
.724 .41875 Mdot
.724 .41877 Mdot
.724 .41878 Mdot
.724 .41883 Mdot
.724 .41883 Mdot
.724 .41886 Mdot
.724 .4189 Mdot
.724 .4189 Mdot
.724 .41892 Mdot
.724 .41894 Mdot
.724 .41895 Mdot
.724 .41897 Mdot
.724 .419 Mdot
.724 .41904 Mdot
.724 .41904 Mdot
.724 .41908 Mdot
.724 .4191 Mdot
.724 .41911 Mdot
.724 .41911 Mdot
.724 .41913 Mdot
.724 .41913 Mdot
.724 .41915 Mdot
.724 .41916 Mdot
.724 .41919 Mdot
.724 .41922 Mdot
.724 .41922 Mdot
.724 .41923 Mdot
.724 .41924 Mdot
.724 .41927 Mdot
.724 .4193 Mdot
.724 .41931 Mdot
.724 .41931 Mdot
.724 .41931 Mdot
.724 .41933 Mdot
.724 .41934 Mdot
.724 .41936 Mdot
.724 .41938 Mdot
.724 .4194 Mdot
.724 .41944 Mdot
.724 .41951 Mdot
.724 .41954 Mdot
.724 .41954 Mdot
.724 .41954 Mdot
.724 .41955 Mdot
.724 .41961 Mdot
.724 .41965 Mdot
.724 .41966 Mdot
.724 .41969 Mdot
.724 .41969 Mdot
.724 .41975 Mdot
.724 .41975 Mdot
.724 .41975 Mdot
.724 .41977 Mdot
.724 .4198 Mdot
.724 .41982 Mdot
.724 .41983 Mdot
.724 .41983 Mdot
.724 .41983 Mdot
.724 .41991 Mdot
.724 .41992 Mdot
.724 .41995 Mdot
.724 .41998 Mdot
.724 .42001 Mdot
.724 .4201 Mdot
.724 .4201 Mdot
.724 .42015 Mdot
.724 .42016 Mdot
.724 .4202 Mdot
.724 .42023 Mdot
.724 .42023 Mdot
.724 .42029 Mdot
.724 .42031 Mdot
.724 .42031 Mdot
.724 .42032 Mdot
.724 .42033 Mdot
.724 .42035 Mdot
.724 .42041 Mdot
.724 .42045 Mdot
.724 .42047 Mdot
.724 .42051 Mdot
.724 .42061 Mdot
.724 .42064 Mdot
.724 .42064 Mdot
.724 .42067 Mdot
.724 .42069 Mdot
.724 .4207 Mdot
.724 .42078 Mdot
.724 .42085 Mdot
.724 .42086 Mdot
.724 .42087 Mdot
.724 .42088 Mdot
.724 .42092 Mdot
.724 .42093 Mdot
.724 .42094 Mdot
.724 .42097 Mdot
.724 .421 Mdot
.724 .42104 Mdot
.724 .42104 Mdot
.724 .42104 Mdot
.724 .4211 Mdot
.724 .42116 Mdot
.724 .42123 Mdot
.724 .42127 Mdot
.724 .42136 Mdot
.724 .42138 Mdot
.724 .42146 Mdot
.724 .42147 Mdot
.724 .4215 Mdot
.724 .4216 Mdot
.724 .42166 Mdot
.724 .42171 Mdot
.724 .42177 Mdot
.724 .42178 Mdot
.724 .42188 Mdot
.724 .42192 Mdot
.724 .42193 Mdot
.724 .42197 Mdot
.724 .42199 Mdot
.724 .42209 Mdot
.724 .42223 Mdot
.724 .42233 Mdot
.724 .42241 Mdot
.724 .42244 Mdot
.724 .42245 Mdot
.724 .42259 Mdot
.724 .42262 Mdot
.724 .42272 Mdot
.724 .42272 Mdot
.724 .42272 Mdot
.724 .42274 Mdot
.724 .42281 Mdot
.724 .42284 Mdot
.724 .42285 Mdot
.724 .42295 Mdot
.724 .42297 Mdot
.724 .42313 Mdot
.724 .42318 Mdot
.724 .42318 Mdot
.724 .4232 Mdot
.724 .42322 Mdot
.724 .42329 Mdot
.724 .4233 Mdot
.724 .42332 Mdot
.724 .42334 Mdot
.724 .42336 Mdot
.724 .42347 Mdot
.724 .42356 Mdot
.724 .42358 Mdot
.724 .42359 Mdot
.724 .4236 Mdot
.724 .42372 Mdot
.724 .42375 Mdot
.724 .42376 Mdot
.724 .42377 Mdot
.724 .42385 Mdot
.724 .42387 Mdot
.724 .42387 Mdot
.724 .4239 Mdot
.724 .42401 Mdot
.724 .42404 Mdot
.724 .4241 Mdot
.724 .42411 Mdot
.724 .4242 Mdot
.724 .4243 Mdot
.724 .42447 Mdot
.724 .42462 Mdot
.724 .42468 Mdot
.724 .4247 Mdot
.724 .42472 Mdot
.724 .42482 Mdot
.726 .30615 Mdot
.726 .30643 Mdot
.726 .30671 Mdot
.726 .30685 Mdot
.726 .30691 Mdot
.726 .30692 Mdot
.726 .30695 Mdot
.726 .30697 Mdot
.726 .307 Mdot
.726 .3072 Mdot
.726 .30732 Mdot
.726 .30741 Mdot
.726 .30751 Mdot
.726 .30752 Mdot
.726 .3076 Mdot
.726 .30762 Mdot
.726 .30791 Mdot
.726 .308 Mdot
.726 .30817 Mdot
.726 .30824 Mdot
.726 .30826 Mdot
.726 .30838 Mdot
.726 .30866 Mdot
.726 .30875 Mdot
.726 .3089 Mdot
.726 .30894 Mdot
.726 .30915 Mdot
.726 .30919 Mdot
.726 .30921 Mdot
.726 .30961 Mdot
.726 .30962 Mdot
.726 .30964 Mdot
.726 .30975 Mdot
.726 .30997 Mdot
.726 .31008 Mdot
.726 .31025 Mdot
.726 .3103 Mdot
.726 .31035 Mdot
.726 .31072 Mdot
.726 .31074 Mdot
.726 .31075 Mdot
.726 .31088 Mdot
.726 .31094 Mdot
.726 .311 Mdot
.726 .31101 Mdot
.726 .31108 Mdot
.726 .3111 Mdot
.726 .3111 Mdot
.726 .31111 Mdot
.726 .31112 Mdot
.726 .31116 Mdot
.726 .31117 Mdot
.726 .3112 Mdot
.726 .31123 Mdot
.726 .31126 Mdot
.726 .31128 Mdot
.726 .31129 Mdot
.726 .31136 Mdot
.726 .31138 Mdot
.726 .31139 Mdot
.726 .31141 Mdot
.726 .31141 Mdot
.726 .31144 Mdot
.726 .31144 Mdot
.726 .31145 Mdot
.726 .31146 Mdot
.726 .31146 Mdot
.726 .31163 Mdot
.726 .31171 Mdot
.726 .31176 Mdot
.726 .31185 Mdot
.726 .31212 Mdot
.726 .31229 Mdot
.726 .31259 Mdot
.726 .31265 Mdot
.726 .31267 Mdot
.726 .31313 Mdot
.726 .31315 Mdot
.726 .31319 Mdot
.726 .31324 Mdot
.726 .31331 Mdot
.726 .31333 Mdot
.726 .31338 Mdot
.726 .31348 Mdot
.726 .31353 Mdot
.726 .31355 Mdot
.726 .31365 Mdot
.726 .3137 Mdot
.726 .31371 Mdot
.726 .31382 Mdot
.726 .31392 Mdot
.726 .31395 Mdot
.726 .31428 Mdot
.726 .3143 Mdot
.726 .31433 Mdot
.726 .31435 Mdot
.726 .3146 Mdot
.726 .31464 Mdot
.726 .31471 Mdot
.726 .31475 Mdot
.726 .31482 Mdot
.726 .3149 Mdot
.726 .31499 Mdot
.726 .31508 Mdot
.726 .31517 Mdot
.726 .31521 Mdot
.726 .31535 Mdot
.726 .31536 Mdot
.726 .31556 Mdot
.726 .31563 Mdot
.726 .3157 Mdot
.726 .31571 Mdot
.726 .31571 Mdot
.726 .31599 Mdot
.726 .31648 Mdot
.726 .31665 Mdot
.726 .31685 Mdot
.726 .31689 Mdot
.726 .31695 Mdot
.726 .31699 Mdot
.726 .31701 Mdot
.726 .31704 Mdot
.726 .31712 Mdot
.726 .31749 Mdot
.726 .31772 Mdot
.726 .31775 Mdot
.726 .31775 Mdot
.726 .3178 Mdot
.726 .3178 Mdot
.726 .31781 Mdot
.726 .31783 Mdot
.726 .31786 Mdot
.726 .31791 Mdot
.726 .31798 Mdot
.726 .31801 Mdot
.726 .31802 Mdot
.726 .31814 Mdot
.726 .31822 Mdot
.726 .31826 Mdot
.726 .31828 Mdot
.726 .31833 Mdot
.726 .31833 Mdot
.726 .31845 Mdot
.726 .31847 Mdot
.726 .3185 Mdot
.726 .31858 Mdot
.726 .31868 Mdot
.726 .31873 Mdot
.726 .31886 Mdot
.726 .31889 Mdot
.726 .31893 Mdot
.726 .31904 Mdot
.726 .31905 Mdot
.726 .31913 Mdot
.726 .31931 Mdot
.726 .31944 Mdot
.726 .3195 Mdot
.726 .31965 Mdot
.726 .31971 Mdot
.726 .31977 Mdot
.726 .31978 Mdot
.726 .3199 Mdot
.726 .32012 Mdot
.726 .32015 Mdot
.726 .32017 Mdot
.726 .32038 Mdot
.726 .32042 Mdot
.726 .32053 Mdot
.726 .32058 Mdot
.726 .32065 Mdot
.726 .32068 Mdot
.726 .32069 Mdot
.726 .32073 Mdot
.726 .32081 Mdot
.726 .32083 Mdot
.726 .32088 Mdot
.726 .32094 Mdot
.726 .32108 Mdot
.726 .32109 Mdot
.726 .32117 Mdot
.726 .32119 Mdot
.726 .32126 Mdot
.726 .32127 Mdot
.726 .32134 Mdot
.726 .32134 Mdot
.726 .32158 Mdot
.726 .32167 Mdot
.726 .32173 Mdot
.726 .32189 Mdot
.726 .32192 Mdot
.726 .32194 Mdot
.726 .322 Mdot
.726 .32206 Mdot
.726 .3221 Mdot
.726 .3222 Mdot
.726 .32226 Mdot
.726 .32231 Mdot
.726 .32232 Mdot
.726 .32263 Mdot
.726 .32266 Mdot
.726 .32282 Mdot
.726 .32282 Mdot
.726 .32288 Mdot
.726 .32295 Mdot
.726 .32319 Mdot
.726 .32327 Mdot
.726 .32337 Mdot
.726 .32344 Mdot
.726 .32351 Mdot
.726 .32366 Mdot
.726 .32368 Mdot
.726 .32372 Mdot
.726 .32373 Mdot
.726 .32383 Mdot
.726 .32387 Mdot
.726 .324 Mdot
.726 .32404 Mdot
.726 .32405 Mdot
.726 .32409 Mdot
.726 .32411 Mdot
.726 .32413 Mdot
.726 .32419 Mdot
.726 .32441 Mdot
.726 .32447 Mdot
.726 .32447 Mdot
.726 .32464 Mdot
.726 .32473 Mdot
.726 .32478 Mdot
.726 .32485 Mdot
.726 .32487 Mdot
.726 .32488 Mdot
.726 .32503 Mdot
.726 .32507 Mdot
.726 .32509 Mdot
.726 .32523 Mdot
.726 .32525 Mdot
.726 .32525 Mdot
.726 .32533 Mdot
.726 .32537 Mdot
.726 .32538 Mdot
.726 .32543 Mdot
.726 .32545 Mdot
.726 .32561 Mdot
.726 .32567 Mdot
.726 .32577 Mdot
.726 .3258 Mdot
.726 .32582 Mdot
.726 .32583 Mdot
.726 .32592 Mdot
.726 .32594 Mdot
.726 .32597 Mdot
.726 .32603 Mdot
.726 .32603 Mdot
.726 .32605 Mdot
.726 .32607 Mdot
.726 .32608 Mdot
.726 .3261 Mdot
.726 .32617 Mdot
.726 .3262 Mdot
.726 .32627 Mdot
.726 .32628 Mdot
.726 .32634 Mdot
.726 .32635 Mdot
.726 .32644 Mdot
.726 .32647 Mdot
.726 .32651 Mdot
.726 .3266 Mdot
.726 .32662 Mdot
.726 .32665 Mdot
.726 .32666 Mdot
.726 .32667 Mdot
.726 .32673 Mdot
.726 .32676 Mdot
.726 .32677 Mdot
.726 .3268 Mdot
.726 .3268 Mdot
.726 .32681 Mdot
.726 .32681 Mdot
.726 .32687 Mdot
.726 .32688 Mdot
.726 .32688 Mdot
.726 .3269 Mdot
.726 .32692 Mdot
.726 .32692 Mdot
.726 .32693 Mdot
.726 .32709 Mdot
.726 .32711 Mdot
.726 .32711 Mdot
.726 .32715 Mdot
.726 .32729 Mdot
.726 .32735 Mdot
.726 .32742 Mdot
.726 .32753 Mdot
.726 .3276 Mdot
.726 .32762 Mdot
.726 .32766 Mdot
.726 .32767 Mdot
.726 .32772 Mdot
.726 .32774 Mdot
.726 .32781 Mdot
.726 .32784 Mdot
.726 .32787 Mdot
.726 .3279 Mdot
.726 .32795 Mdot
.726 .32828 Mdot
.726 .32831 Mdot
.726 .32835 Mdot
.726 .32841 Mdot
.726 .32842 Mdot
.726 .3285 Mdot
.726 .32866 Mdot
.726 .3287 Mdot
.726 .32873 Mdot
.726 .32882 Mdot
.726 .32887 Mdot
.726 .32887 Mdot
.726 .32891 Mdot
.726 .32898 Mdot
.726 .32913 Mdot
.726 .32915 Mdot
.726 .32926 Mdot
.726 .32927 Mdot
.726 .32928 Mdot
.726 .32936 Mdot
.726 .32944 Mdot
.726 .32955 Mdot
.726 .32959 Mdot
.726 .3296 Mdot
.726 .3296 Mdot
.726 .32964 Mdot
.726 .32967 Mdot
.726 .32968 Mdot
.726 .3297 Mdot
.726 .32972 Mdot
.726 .32978 Mdot
.726 .3298 Mdot
.726 .32984 Mdot
.726 .32985 Mdot
.726 .32985 Mdot
.726 .32993 Mdot
.726 .33004 Mdot
.726 .33005 Mdot
.726 .33013 Mdot
.726 .33013 Mdot
.726 .33022 Mdot
.726 .33026 Mdot
.726 .33027 Mdot
.726 .33028 Mdot
.726 .33036 Mdot
.726 .33039 Mdot
.726 .3304 Mdot
.726 .33041 Mdot
.726 .33042 Mdot
.726 .33043 Mdot
.726 .33044 Mdot
.726 .33044 Mdot
.726 .33044 Mdot
.726 .33045 Mdot
.726 .33046 Mdot
.726 .33046 Mdot
.726 .33047 Mdot
.726 .33047 Mdot
.726 .33047 Mdot
.726 .33049 Mdot
.726 .33049 Mdot
.726 .3305 Mdot
.726 .3305 Mdot
.726 .3305 Mdot
.726 .33051 Mdot
.726 .33051 Mdot
.726 .33051 Mdot
.726 .33051 Mdot
.726 .33059 Mdot
.726 .33065 Mdot
.726 .33069 Mdot
.726 .33075 Mdot
.726 .33077 Mdot
.726 .33087 Mdot
.726 .33088 Mdot
.726 .33089 Mdot
.726 .33099 Mdot
.726 .33104 Mdot
.726 .33113 Mdot
.726 .33122 Mdot
.726 .3313 Mdot
.726 .33132 Mdot
.726 .33141 Mdot
.726 .33144 Mdot
.726 .33162 Mdot
.726 .33171 Mdot
.726 .33174 Mdot
.726 .33192 Mdot
.726 .33193 Mdot
.726 .33195 Mdot
.726 .33203 Mdot
.726 .3321 Mdot
.726 .33214 Mdot
.726 .33216 Mdot
.726 .33233 Mdot
.726 .3324 Mdot
.726 .33252 Mdot
.726 .33263 Mdot
.726 .33266 Mdot
.726 .33269 Mdot
.726 .33271 Mdot
.726 .33272 Mdot
.726 .33276 Mdot
.726 .33281 Mdot
.726 .33298 Mdot
.726 .33308 Mdot
.726 .33318 Mdot
.726 .33323 Mdot
.726 .33323 Mdot
.726 .33334 Mdot
.726 .33339 Mdot
.726 .33348 Mdot
.726 .33358 Mdot
.726 .33359 Mdot
.726 .3336 Mdot
.726 .33369 Mdot
.726 .33371 Mdot
.726 .33371 Mdot
.726 .3338 Mdot
.726 .33383 Mdot
.726 .33384 Mdot
.726 .33394 Mdot
.726 .33395 Mdot
.726 .33395 Mdot
.726 .33399 Mdot
.726 .33413 Mdot
.726 .33416 Mdot
.726 .33417 Mdot
.726 .33421 Mdot
.726 .33428 Mdot
.726 .3343 Mdot
.726 .3344 Mdot
.726 .3344 Mdot
.726 .33444 Mdot
.726 .33445 Mdot
.726 .33448 Mdot
.726 .33449 Mdot
.726 .33455 Mdot
.726 .33456 Mdot
.726 .33456 Mdot
.726 .33457 Mdot
.726 .33462 Mdot
.726 .33473 Mdot
.726 .33478 Mdot
.726 .33483 Mdot
.726 .33497 Mdot
.726 .335 Mdot
.726 .33502 Mdot
.726 .33521 Mdot
.726 .33524 Mdot
.726 .3353 Mdot
.726 .3353 Mdot
.726 .33535 Mdot
.726 .33536 Mdot
.726 .33539 Mdot
.726 .33548 Mdot
.726 .33548 Mdot
.726 .3355 Mdot
.726 .33552 Mdot
.726 .33553 Mdot
.726 .33556 Mdot
.726 .33557 Mdot
.726 .33558 Mdot
.726 .33559 Mdot
.726 .33562 Mdot
.726 .33567 Mdot
.726 .3357 Mdot
.726 .3357 Mdot
.726 .33574 Mdot
.726 .33576 Mdot
.726 .33576 Mdot
.726 .33577 Mdot
.726 .3358 Mdot
.726 .33581 Mdot
.726 .33582 Mdot
.726 .33582 Mdot
.726 .33583 Mdot
.726 .33583 Mdot
.726 .33583 Mdot
.726 .33583 Mdot
.726 .33584 Mdot
.726 .33584 Mdot
.726 .33584 Mdot
.726 .33585 Mdot
.726 .33585 Mdot
.726 .33585 Mdot
.726 .33585 Mdot
.726 .33586 Mdot
.726 .33586 Mdot
.726 .33586 Mdot
.726 .33586 Mdot
.726 .33586 Mdot
.726 .33586 Mdot
.726 .33587 Mdot
.726 .33587 Mdot
.726 .33587 Mdot
.726 .41809 Mdot
.726 .41809 Mdot
.726 .41809 Mdot
.726 .41809 Mdot
.726 .41809 Mdot
.726 .41809 Mdot
.726 .41809 Mdot
.726 .41809 Mdot
.726 .41809 Mdot
.726 .41809 Mdot
.726 .41809 Mdot
.726 .4181 Mdot
.726 .4181 Mdot
.726 .4181 Mdot
.726 .4181 Mdot
.726 .4181 Mdot
.726 .4181 Mdot
.726 .4181 Mdot
.726 .4181 Mdot
.726 .4181 Mdot
.726 .4181 Mdot
.726 .4181 Mdot
.726 .4181 Mdot
.726 .41811 Mdot
.726 .41812 Mdot
.726 .41812 Mdot
.726 .41812 Mdot
.726 .41812 Mdot
.726 .41813 Mdot
.726 .41813 Mdot
.726 .41814 Mdot
.726 .41815 Mdot
.726 .41816 Mdot
.726 .41816 Mdot
.726 .41817 Mdot
.726 .41817 Mdot
.726 .41818 Mdot
.726 .41818 Mdot
.726 .41818 Mdot
.726 .41819 Mdot
.726 .41819 Mdot
.726 .41821 Mdot
.726 .41822 Mdot
.726 .41822 Mdot
.726 .41823 Mdot
.726 .41824 Mdot
.726 .41825 Mdot
.726 .41826 Mdot
.726 .41831 Mdot
.726 .41831 Mdot
.726 .41832 Mdot
.726 .41835 Mdot
.726 .41837 Mdot
.726 .41838 Mdot
.726 .41841 Mdot
.726 .41842 Mdot
.726 .41842 Mdot
.726 .41842 Mdot
.726 .41843 Mdot
.726 .41844 Mdot
.726 .41844 Mdot
.726 .41845 Mdot
.726 .41845 Mdot
.726 .41846 Mdot
.726 .41846 Mdot
.726 .41849 Mdot
.726 .4185 Mdot
.726 .41851 Mdot
.726 .41852 Mdot
.726 .41852 Mdot
.726 .41853 Mdot
.726 .41857 Mdot
.726 .41858 Mdot
.726 .41858 Mdot
.726 .41858 Mdot
.726 .41861 Mdot
.726 .41861 Mdot
.726 .41862 Mdot
.726 .41864 Mdot
.726 .41864 Mdot
.726 .41864 Mdot
.726 .41867 Mdot
.726 .41867 Mdot
.726 .41867 Mdot
.726 .4187 Mdot
.726 .41872 Mdot
.726 .41874 Mdot
.726 .41876 Mdot
.726 .41876 Mdot
.726 .41878 Mdot
.726 .4188 Mdot
.726 .41883 Mdot
.726 .41887 Mdot
.726 .41888 Mdot
.726 .41889 Mdot
.726 .4189 Mdot
.726 .4189 Mdot
.726 .41891 Mdot
.726 .41892 Mdot
.726 .41894 Mdot
.726 .41897 Mdot
.726 .41899 Mdot
.726 .41904 Mdot
.726 .41904 Mdot
.726 .41905 Mdot
.726 .41907 Mdot
.726 .41909 Mdot
.726 .41909 Mdot
.726 .4191 Mdot
.726 .41914 Mdot
.726 .41915 Mdot
.726 .41917 Mdot
.726 .41922 Mdot
.726 .41923 Mdot
.726 .41925 Mdot
.726 .41926 Mdot
.726 .41928 Mdot
.726 .4193 Mdot
.726 .41932 Mdot
.726 .41933 Mdot
.726 .41936 Mdot
.726 .41936 Mdot
.726 .41937 Mdot
.726 .41939 Mdot
.726 .4194 Mdot
.726 .41941 Mdot
.726 .41942 Mdot
.726 .41944 Mdot
.726 .41946 Mdot
.726 .41946 Mdot
.726 .41946 Mdot
.726 .41946 Mdot
.726 .41946 Mdot
.726 .41946 Mdot
.726 .41946 Mdot
.726 .41946 Mdot
.726 .41946 Mdot
.726 .41947 Mdot
.726 .41947 Mdot
.726 .41947 Mdot
.726 .41947 Mdot
.726 .41947 Mdot
.726 .41948 Mdot
.726 .41948 Mdot
.726 .41948 Mdot
.726 .41948 Mdot
.726 .41948 Mdot
.726 .41948 Mdot
.726 .41948 Mdot
.726 .41949 Mdot
.726 .41949 Mdot
.726 .4195 Mdot
.726 .41952 Mdot
.726 .41952 Mdot
.726 .41952 Mdot
.726 .41953 Mdot
.726 .41956 Mdot
.726 .41956 Mdot
.726 .41958 Mdot
.726 .41958 Mdot
.726 .41961 Mdot
.726 .41963 Mdot
.726 .41963 Mdot
.726 .41963 Mdot
.726 .41964 Mdot
.726 .41965 Mdot
.726 .41966 Mdot
.726 .41967 Mdot
.726 .41967 Mdot
.726 .41968 Mdot
.726 .41968 Mdot
.726 .41969 Mdot
.726 .41969 Mdot
.726 .4197 Mdot
.726 .41971 Mdot
.726 .41974 Mdot
.726 .41975 Mdot
.726 .41977 Mdot
.726 .41978 Mdot
.726 .41978 Mdot
.726 .41981 Mdot
.726 .41981 Mdot
.726 .41985 Mdot
.726 .41987 Mdot
.726 .41988 Mdot
.726 .41988 Mdot
.726 .41989 Mdot
.726 .41992 Mdot
.726 .41992 Mdot
.726 .41994 Mdot
.726 .41998 Mdot
.726 .42 Mdot
.726 .42 Mdot
.726 .42001 Mdot
.726 .42003 Mdot
.726 .42003 Mdot
.726 .42012 Mdot
.726 .42013 Mdot
.726 .42014 Mdot
.726 .42015 Mdot
.726 .42015 Mdot
.726 .42017 Mdot
.726 .42018 Mdot
.726 .42019 Mdot
.726 .42019 Mdot
.726 .4202 Mdot
.726 .42021 Mdot
.726 .42023 Mdot
.726 .42026 Mdot
.726 .42027 Mdot
.726 .42029 Mdot
.726 .42032 Mdot
.726 .42033 Mdot
.726 .42034 Mdot
.726 .42034 Mdot
.726 .42038 Mdot
.726 .42038 Mdot
.726 .42039 Mdot
.726 .42039 Mdot
.726 .42039 Mdot
.726 .4204 Mdot
.726 .4204 Mdot
.726 .42041 Mdot
.726 .42041 Mdot
.726 .42042 Mdot
.726 .42042 Mdot
.726 .42042 Mdot
.726 .42043 Mdot
.726 .42043 Mdot
.726 .42045 Mdot
.726 .42045 Mdot
.726 .42046 Mdot
.726 .42046 Mdot
.726 .42047 Mdot
.726 .42049 Mdot
.726 .4205 Mdot
.726 .42051 Mdot
.726 .42053 Mdot
.726 .42053 Mdot
.726 .42055 Mdot
.726 .42055 Mdot
.726 .42057 Mdot
.726 .42058 Mdot
.726 .4206 Mdot
.726 .4206 Mdot
.726 .42061 Mdot
.726 .42061 Mdot
.726 .42062 Mdot
.726 .42062 Mdot
.726 .42063 Mdot
.726 .42064 Mdot
.726 .42064 Mdot
.726 .42067 Mdot
.726 .42067 Mdot
.726 .42068 Mdot
.726 .42068 Mdot
.726 .42071 Mdot
.726 .42073 Mdot
.726 .42077 Mdot
.726 .42077 Mdot
.726 .42078 Mdot
.726 .42079 Mdot
.726 .4208 Mdot
.726 .42082 Mdot
.726 .42082 Mdot
.726 .42082 Mdot
.726 .42086 Mdot
.726 .42087 Mdot
.726 .42088 Mdot
.726 .42091 Mdot
.726 .42092 Mdot
.726 .42092 Mdot
.726 .42094 Mdot
.726 .42095 Mdot
.726 .42098 Mdot
.726 .42102 Mdot
.726 .42102 Mdot
.726 .42104 Mdot
.726 .42109 Mdot
.726 .42111 Mdot
.726 .42112 Mdot
.726 .42112 Mdot
.726 .42113 Mdot
.726 .42113 Mdot
.726 .42114 Mdot
.726 .42118 Mdot
.726 .42119 Mdot
.726 .42122 Mdot
.726 .42122 Mdot
.726 .42123 Mdot
.726 .42123 Mdot
.726 .42127 Mdot
.726 .42129 Mdot
.726 .42131 Mdot
.726 .42133 Mdot
.726 .42135 Mdot
.726 .42142 Mdot
.726 .42144 Mdot
.726 .42145 Mdot
.726 .42145 Mdot
.726 .42149 Mdot
.726 .4215 Mdot
.726 .42158 Mdot
.726 .42159 Mdot
.726 .4216 Mdot
.726 .42162 Mdot
.726 .42164 Mdot
.726 .42165 Mdot
.726 .42167 Mdot
.726 .42168 Mdot
.726 .42169 Mdot
.726 .4217 Mdot
.726 .42174 Mdot
.726 .42175 Mdot
.726 .42178 Mdot
.726 .42184 Mdot
.726 .42184 Mdot
.726 .42186 Mdot
.726 .42186 Mdot
.726 .42188 Mdot
.726 .42189 Mdot
.726 .42191 Mdot
.726 .42191 Mdot
.726 .42195 Mdot
.726 .42196 Mdot
.726 .42198 Mdot
.726 .42198 Mdot
.726 .422 Mdot
.726 .42201 Mdot
.726 .42201 Mdot
.726 .42202 Mdot
.726 .42204 Mdot
.726 .42205 Mdot
.726 .42208 Mdot
.726 .42209 Mdot
.726 .42215 Mdot
.726 .42216 Mdot
.726 .42216 Mdot
.726 .42222 Mdot
.726 .42225 Mdot
.726 .42226 Mdot
.726 .42227 Mdot
.726 .42229 Mdot
.726 .42233 Mdot
.726 .42234 Mdot
.726 .42238 Mdot
.726 .42242 Mdot
.726 .42245 Mdot
.726 .42245 Mdot
.726 .42248 Mdot
.726 .42249 Mdot
.726 .4225 Mdot
.726 .42253 Mdot
.726 .42255 Mdot
.726 .42257 Mdot
.726 .42259 Mdot
.726 .4226 Mdot
.726 .42261 Mdot
.726 .42264 Mdot
.726 .42264 Mdot
.726 .42265 Mdot
.726 .42266 Mdot
.726 .42267 Mdot
.726 .42269 Mdot
.726 .42272 Mdot
.726 .42272 Mdot
.726 .42273 Mdot
.726 .42275 Mdot
.726 .42276 Mdot
.726 .42277 Mdot
.726 .42278 Mdot
.726 .42278 Mdot
.726 .42278 Mdot
.726 .42279 Mdot
.726 .42279 Mdot
.726 .4228 Mdot
.726 .42286 Mdot
.726 .42296 Mdot
.726 .42298 Mdot
.726 .42299 Mdot
.726 .42299 Mdot
.726 .42301 Mdot
.726 .42302 Mdot
.726 .42303 Mdot
.726 .42309 Mdot
.726 .42313 Mdot
.726 .42319 Mdot
.726 .42326 Mdot
.726 .42334 Mdot
.726 .42334 Mdot
.726 .42334 Mdot
.726 .42336 Mdot
.726 .42338 Mdot
.726 .42343 Mdot
.726 .42343 Mdot
.726 .42347 Mdot
.726 .42348 Mdot
.726 .42351 Mdot
.726 .42353 Mdot
.726 .42356 Mdot
.726 .42358 Mdot
.726 .4236 Mdot
.726 .42361 Mdot
.726 .42363 Mdot
.726 .42364 Mdot
.726 .4237 Mdot
.726 .42371 Mdot
.726 .42372 Mdot
.726 .42372 Mdot
.726 .42381 Mdot
.726 .42382 Mdot
.726 .42385 Mdot
.726 .42388 Mdot
.726 .42388 Mdot
.726 .4239 Mdot
.726 .42392 Mdot
.726 .42393 Mdot
.726 .42394 Mdot
.726 .42397 Mdot
.726 .42398 Mdot
.726 .42399 Mdot
.726 .42401 Mdot
.726 .42402 Mdot
.726 .42403 Mdot
.726 .42404 Mdot
.726 .42416 Mdot
.726 .42417 Mdot
.726 .42418 Mdot
.726 .42427 Mdot
.726 .42431 Mdot
.726 .42439 Mdot
.726 .42441 Mdot
.726 .42442 Mdot
.726 .42445 Mdot
.726 .42449 Mdot
.726 .42449 Mdot
.726 .4245 Mdot
.726 .4245 Mdot
.726 .4245 Mdot
.726 .42451 Mdot
.726 .42451 Mdot
.726 .42451 Mdot
.726 .42451 Mdot
.726 .42452 Mdot
.726 .42454 Mdot
.726 .42454 Mdot
.726 .42455 Mdot
.726 .42456 Mdot
.726 .42456 Mdot
.726 .42457 Mdot
.726 .42458 Mdot
.726 .42459 Mdot
.726 .42459 Mdot
.726 .42459 Mdot
.726 .42459 Mdot
.726 .4246 Mdot
.726 .42461 Mdot
.726 .42462 Mdot
.726 .42464 Mdot
.726 .42465 Mdot
.726 .42469 Mdot
.726 .42469 Mdot
.726 .4247 Mdot
.726 .4248 Mdot
.726 .42481 Mdot
.726 .42483 Mdot
.726 .42487 Mdot
.726 .4249 Mdot
.726 .42496 Mdot
.726 .42499 Mdot
.726 .425 Mdot
.726 .425 Mdot
.726 .42511 Mdot
.726 .42512 Mdot
.726 .42513 Mdot
.726 .42519 Mdot
.726 .4252 Mdot
.726 .42524 Mdot
.726 .42527 Mdot
.726 .42535 Mdot
.726 .42538 Mdot
.726 .42538 Mdot
.726 .4254 Mdot
.726 .42545 Mdot
.726 .42548 Mdot
.726 .42556 Mdot
.726 .42556 Mdot
.726 .42559 Mdot
.726 .42559 Mdot
.726 .42562 Mdot
.726 .42564 Mdot
.726 .42567 Mdot
.726 .42573 Mdot
.726 .42574 Mdot
.726 .42574 Mdot
.726 .42575 Mdot
.726 .42576 Mdot
.726 .42577 Mdot
.726 .42581 Mdot
.726 .42589 Mdot
.726 .42597 Mdot
.728 .26126 Mdot
.728 .26127 Mdot
.728 .26129 Mdot
.728 .2613 Mdot
.728 .26136 Mdot
.728 .26139 Mdot
.728 .26144 Mdot
.728 .26161 Mdot
.728 .26162 Mdot
.728 .26165 Mdot
.728 .26175 Mdot
.728 .26175 Mdot
.728 .26191 Mdot
.728 .26196 Mdot
.728 .26199 Mdot
.728 .26205 Mdot
.728 .26208 Mdot
.728 .26249 Mdot
.728 .26265 Mdot
.728 .26282 Mdot
.728 .26288 Mdot
.728 .26298 Mdot
.728 .26307 Mdot
.728 .26334 Mdot
.728 .26343 Mdot
.728 .26383 Mdot
.728 .2639 Mdot
.728 .26491 Mdot
.728 .26654 Mdot
.728 .26668 Mdot
.728 .26684 Mdot
.728 .26695 Mdot
.728 .26803 Mdot
.728 .26863 Mdot
.728 .26999 Mdot
.728 .27038 Mdot
.728 .27134 Mdot
.728 .27416 Mdot
.728 .27469 Mdot
.728 .27528 Mdot
.728 .27557 Mdot
.728 .27614 Mdot
.728 .27637 Mdot
.728 .27742 Mdot
.728 .27824 Mdot
.728 .27831 Mdot
.728 .27879 Mdot
.728 .27907 Mdot
.728 .27917 Mdot
.728 .28058 Mdot
.728 .28108 Mdot
.728 .28108 Mdot
.728 .28143 Mdot
.728 .28198 Mdot
.728 .2823 Mdot
.728 .28314 Mdot
.728 .28392 Mdot
.728 .28413 Mdot
.728 .2842 Mdot
.728 .28474 Mdot
.728 .28554 Mdot
.728 .28564 Mdot
.728 .28625 Mdot
.728 .28635 Mdot
.728 .28653 Mdot
.728 .2866 Mdot
.728 .28728 Mdot
.728 .28752 Mdot
.728 .28777 Mdot
.728 .28785 Mdot
.728 .28853 Mdot
.728 .29138 Mdot
.728 .29148 Mdot
.728 .2936 Mdot
.728 .29541 Mdot
.728 .29564 Mdot
.728 .29676 Mdot
.728 .29707 Mdot
.728 .29728 Mdot
.728 .29742 Mdot
.728 .29811 Mdot
.728 .29823 Mdot
.728 .29843 Mdot
.728 .29854 Mdot
.728 .29882 Mdot
.728 .29909 Mdot
.728 .29916 Mdot
.728 .29918 Mdot
.728 .29936 Mdot
.728 .29965 Mdot
.728 .29985 Mdot
.728 .29994 Mdot
.728 .30018 Mdot
.728 .30036 Mdot
.728 .30057 Mdot
.728 .30211 Mdot
.728 .30271 Mdot
.728 .30303 Mdot
.728 .30313 Mdot
.728 .30323 Mdot
.728 .30343 Mdot
.728 .30346 Mdot
.728 .30352 Mdot
.728 .30355 Mdot
.728 .30363 Mdot
.728 .30373 Mdot
.728 .30374 Mdot
.728 .30387 Mdot
.728 .30393 Mdot
.728 .30396 Mdot
.728 .30403 Mdot
.728 .30408 Mdot
.728 .30458 Mdot
.728 .30485 Mdot
.728 .30491 Mdot
.728 .30514 Mdot
.728 .30516 Mdot
.728 .30538 Mdot
.728 .3054 Mdot
.728 .30546 Mdot
.728 .30556 Mdot
.728 .30566 Mdot
.728 .30571 Mdot
.728 .3058 Mdot
.728 .30581 Mdot
.728 .30581 Mdot
.728 .30599 Mdot
.728 .306 Mdot
.728 .30606 Mdot
.728 .30629 Mdot
.728 .30632 Mdot
.728 .30632 Mdot
.728 .30642 Mdot
.728 .30652 Mdot
.728 .30677 Mdot
.728 .3068 Mdot
.728 .30685 Mdot
.728 .30686 Mdot
.728 .30694 Mdot
.728 .30697 Mdot
.728 .30704 Mdot
.728 .30714 Mdot
.728 .30717 Mdot
.728 .30724 Mdot
.728 .30766 Mdot
.728 .3078 Mdot
.728 .30792 Mdot
.728 .30795 Mdot
.728 .30796 Mdot
.728 .30805 Mdot
.728 .30806 Mdot
.728 .30807 Mdot
.728 .3081 Mdot
.728 .30817 Mdot
.728 .30825 Mdot
.728 .30829 Mdot
.728 .3083 Mdot
.728 .30838 Mdot
.728 .30839 Mdot
.728 .30875 Mdot
.728 .3088 Mdot
.728 .3089 Mdot
.728 .30908 Mdot
.728 .30915 Mdot
.728 .30917 Mdot
.728 .30924 Mdot
.728 .30925 Mdot
.728 .30927 Mdot
.728 .30931 Mdot
.728 .30947 Mdot
.728 .30958 Mdot
.728 .30969 Mdot
.728 .30975 Mdot
.728 .30976 Mdot
.728 .30982 Mdot
.728 .30986 Mdot
.728 .31014 Mdot
.728 .31024 Mdot
.728 .31034 Mdot
.728 .31045 Mdot
.728 .31045 Mdot
.728 .31052 Mdot
.728 .31055 Mdot
.728 .3106 Mdot
.728 .31066 Mdot
.728 .31081 Mdot
.728 .3109 Mdot
.728 .3109 Mdot
.728 .31097 Mdot
.728 .31101 Mdot
.728 .31103 Mdot
.728 .31112 Mdot
.728 .31117 Mdot
.728 .3112 Mdot
.728 .31121 Mdot
.728 .31128 Mdot
.728 .31154 Mdot
.728 .3117 Mdot
.728 .31176 Mdot
.728 .31186 Mdot
.728 .312 Mdot
.728 .31209 Mdot
.728 .31213 Mdot
.728 .31218 Mdot
.728 .31241 Mdot
.728 .31243 Mdot
.728 .3125 Mdot
.728 .31253 Mdot
.728 .31272 Mdot
.728 .3128 Mdot
.728 .31285 Mdot
.728 .31289 Mdot
.728 .31294 Mdot
.728 .31295 Mdot
.728 .31301 Mdot
.728 .31301 Mdot
.728 .31305 Mdot
.728 .31318 Mdot
.728 .3132 Mdot
.728 .31332 Mdot
.728 .31342 Mdot
.728 .31347 Mdot
.728 .3135 Mdot
.728 .31375 Mdot
.728 .31376 Mdot
.728 .31379 Mdot
.728 .3138 Mdot
.728 .31392 Mdot
.728 .31392 Mdot
.728 .31405 Mdot
.728 .31406 Mdot
.728 .31413 Mdot
.728 .31431 Mdot
.728 .31431 Mdot
.728 .31434 Mdot
.728 .31435 Mdot
.728 .31439 Mdot
.728 .3145 Mdot
.728 .31454 Mdot
.728 .31455 Mdot
.728 .31478 Mdot
.728 .31482 Mdot
.728 .31486 Mdot
.728 .31491 Mdot
.728 .31493 Mdot
.728 .31531 Mdot
.728 .31533 Mdot
.728 .31536 Mdot
.728 .31538 Mdot
.728 .31539 Mdot
.728 .31544 Mdot
.728 .31549 Mdot
.728 .31549 Mdot
.728 .31567 Mdot
.728 .31568 Mdot
.728 .31575 Mdot
.728 .31576 Mdot
.728 .3158 Mdot
.728 .3158 Mdot
.728 .31588 Mdot
.728 .31593 Mdot
.728 .31599 Mdot
.728 .31601 Mdot
.728 .31603 Mdot
.728 .3161 Mdot
.728 .31613 Mdot
.728 .31621 Mdot
.728 .31622 Mdot
.728 .31626 Mdot
.728 .31626 Mdot
.728 .31627 Mdot
.728 .3164 Mdot
.728 .31659 Mdot
.728 .31669 Mdot
.728 .31694 Mdot
.728 .31716 Mdot
.728 .31718 Mdot
.728 .3172 Mdot
.728 .31741 Mdot
.728 .31745 Mdot
.728 .31751 Mdot
.728 .31761 Mdot
.728 .31809 Mdot
.728 .3182 Mdot
.728 .3183 Mdot
.728 .31841 Mdot
.728 .31844 Mdot
.728 .31873 Mdot
.728 .31892 Mdot
.728 .31895 Mdot
.728 .31901 Mdot
.728 .31912 Mdot
.728 .31913 Mdot
.728 .31919 Mdot
.728 .31923 Mdot
.728 .31985 Mdot
.728 .32002 Mdot
.728 .32029 Mdot
.728 .32039 Mdot
.728 .32057 Mdot
.728 .32088 Mdot
.728 .32088 Mdot
.728 .32089 Mdot
.728 .32105 Mdot
.728 .32114 Mdot
.728 .32127 Mdot
.728 .32128 Mdot
.728 .32143 Mdot
.728 .32158 Mdot
.728 .32184 Mdot
.728 .32186 Mdot
.728 .32206 Mdot
.728 .32206 Mdot
.728 .32225 Mdot
.728 .32226 Mdot
.728 .32234 Mdot
.728 .32239 Mdot
.728 .32239 Mdot
.728 .32263 Mdot
.728 .3227 Mdot
.728 .32277 Mdot
.728 .32283 Mdot
.728 .32286 Mdot
.728 .32299 Mdot
.728 .32303 Mdot
.728 .32327 Mdot
.728 .32334 Mdot
.728 .32355 Mdot
.728 .32369 Mdot
.728 .32392 Mdot
.728 .32406 Mdot
.728 .32421 Mdot
.728 .32434 Mdot
.728 .32443 Mdot
.728 .32463 Mdot
.728 .32473 Mdot
.728 .32477 Mdot
.728 .32489 Mdot
.728 .32498 Mdot
.728 .32508 Mdot
.728 .32519 Mdot
.728 .32534 Mdot
.728 .3255 Mdot
.728 .32569 Mdot
.728 .32571 Mdot
.728 .32574 Mdot
.728 .32589 Mdot
.728 .32596 Mdot
.728 .32623 Mdot
.728 .32636 Mdot
.728 .32639 Mdot
.728 .32653 Mdot
.728 .32662 Mdot
.728 .32671 Mdot
.728 .32681 Mdot
.728 .32682 Mdot
.728 .32695 Mdot
.728 .32695 Mdot
.728 .32696 Mdot
.728 .32702 Mdot
.728 .32705 Mdot
.728 .32722 Mdot
.728 .32728 Mdot
.728 .32732 Mdot
.728 .32734 Mdot
.728 .32741 Mdot
.728 .32754 Mdot
.728 .32756 Mdot
.728 .32769 Mdot
.728 .32774 Mdot
.728 .32783 Mdot
.728 .32784 Mdot
.728 .32788 Mdot
.728 .32831 Mdot
.728 .32832 Mdot
.728 .32833 Mdot
.728 .32835 Mdot
.728 .32838 Mdot
.728 .3284 Mdot
.728 .32841 Mdot
.728 .32843 Mdot
.728 .32857 Mdot
.728 .32859 Mdot
.728 .32863 Mdot
.728 .32863 Mdot
.728 .32885 Mdot
.728 .32887 Mdot
.728 .32893 Mdot
.728 .32894 Mdot
.728 .32898 Mdot
.728 .32927 Mdot
.728 .32927 Mdot
.728 .32929 Mdot
.728 .32931 Mdot
.728 .32932 Mdot
.728 .32933 Mdot
.728 .32939 Mdot
.728 .32955 Mdot
.728 .32961 Mdot
.728 .32963 Mdot
.728 .32976 Mdot
.728 .32996 Mdot
.728 .32998 Mdot
.728 .33001 Mdot
.728 .33005 Mdot
.728 .33006 Mdot
.728 .33013 Mdot
.728 .33016 Mdot
.728 .33021 Mdot
.728 .33022 Mdot
.728 .3304 Mdot
.728 .33052 Mdot
.728 .33064 Mdot
.728 .33066 Mdot
.728 .3307 Mdot
.728 .33072 Mdot
.728 .33072 Mdot
.728 .33074 Mdot
.728 .33074 Mdot
.728 .33074 Mdot
.728 .33078 Mdot
.728 .33085 Mdot
.728 .33085 Mdot
.728 .33104 Mdot
.728 .33105 Mdot
.728 .3311 Mdot
.728 .33113 Mdot
.728 .33113 Mdot
.728 .33117 Mdot
.728 .33117 Mdot
.728 .33119 Mdot
.728 .33125 Mdot
.728 .33128 Mdot
.728 .3313 Mdot
.728 .33135 Mdot
.728 .33137 Mdot
.728 .33138 Mdot
.728 .3314 Mdot
.728 .33145 Mdot
.728 .33148 Mdot
.728 .33155 Mdot
.728 .33156 Mdot
.728 .33159 Mdot
.728 .33159 Mdot
.728 .3316 Mdot
.728 .33163 Mdot
.728 .3317 Mdot
.728 .33177 Mdot
.728 .33184 Mdot
.728 .3319 Mdot
.728 .33196 Mdot
.728 .33205 Mdot
.728 .33215 Mdot
.728 .33216 Mdot
.728 .33216 Mdot
.728 .33217 Mdot
.728 .33218 Mdot
.728 .33219 Mdot
.728 .33219 Mdot
.728 .33224 Mdot
.728 .33226 Mdot
.728 .33226 Mdot
.728 .33227 Mdot
.728 .33227 Mdot
.728 .33229 Mdot
.728 .33232 Mdot
.728 .33232 Mdot
.728 .33235 Mdot
.728 .33237 Mdot
.728 .33238 Mdot
.728 .33238 Mdot
.728 .33238 Mdot
.728 .33239 Mdot
.728 .33444 Mdot
.728 .33523 Mdot
.728 .33928 Mdot
.728 .34026 Mdot
.728 .34304 Mdot
.728 .34401 Mdot
.728 .34508 Mdot
.728 .34571 Mdot
.728 .3476 Mdot
.728 .34932 Mdot
.728 .35374 Mdot
.728 .3541 Mdot
.728 .35472 Mdot
.728 .35515 Mdot
.728 .35567 Mdot
.728 .35738 Mdot
.728 .35742 Mdot
.728 .35853 Mdot
.728 .3589 Mdot
.728 .35898 Mdot
.728 .36092 Mdot
.728 .36147 Mdot
.728 .36176 Mdot
.728 .36252 Mdot
.728 .36261 Mdot
.728 .36285 Mdot
.728 .36296 Mdot
.728 .41147 Mdot
.728 .4115 Mdot
.728 .41156 Mdot
.728 .41158 Mdot
.728 .41177 Mdot
.728 .41185 Mdot
.728 .41199 Mdot
.728 .41248 Mdot
.728 .4125 Mdot
.728 .41259 Mdot
.728 .41288 Mdot
.728 .41288 Mdot
.728 .41332 Mdot
.728 .41345 Mdot
.728 .41356 Mdot
.728 .41371 Mdot
.728 .41381 Mdot
.728 .41492 Mdot
.728 .41535 Mdot
.728 .41583 Mdot
.728 .41599 Mdot
.728 .41626 Mdot
.728 .4165 Mdot
.728 .4172 Mdot
.728 .41745 Mdot
.728 .41848 Mdot
.728 .41868 Mdot
.728 .4192 Mdot
.728 .4192 Mdot
.728 .4192 Mdot
.728 .4192 Mdot
.728 .41921 Mdot
.728 .41921 Mdot
.728 .41922 Mdot
.728 .41922 Mdot
.728 .41923 Mdot
.728 .41923 Mdot
.728 .41923 Mdot
.728 .41923 Mdot
.728 .41924 Mdot
.728 .41924 Mdot
.728 .41925 Mdot
.728 .41925 Mdot
.728 .41926 Mdot
.728 .41926 Mdot
.728 .41926 Mdot
.728 .41926 Mdot
.728 .41926 Mdot
.728 .41929 Mdot
.728 .41931 Mdot
.728 .41933 Mdot
.728 .41934 Mdot
.728 .41936 Mdot
.728 .41938 Mdot
.728 .4194 Mdot
.728 .4194 Mdot
.728 .41941 Mdot
.728 .41941 Mdot
.728 .41941 Mdot
.728 .41942 Mdot
.728 .41943 Mdot
.728 .41944 Mdot
.728 .41946 Mdot
.728 .41946 Mdot
.728 .41946 Mdot
.728 .41947 Mdot
.728 .41948 Mdot
.728 .41948 Mdot
.728 .41949 Mdot
.728 .41951 Mdot
.728 .41951 Mdot
.728 .41951 Mdot
.728 .41952 Mdot
.728 .41952 Mdot
.728 .41953 Mdot
.728 .41954 Mdot
.728 .41955 Mdot
.728 .41959 Mdot
.728 .4196 Mdot
.728 .41961 Mdot
.728 .41962 Mdot
.728 .41962 Mdot
.728 .41962 Mdot
.728 .41963 Mdot
.728 .41963 Mdot
.728 .41963 Mdot
.728 .41964 Mdot
.728 .41965 Mdot
.728 .41968 Mdot
.728 .41971 Mdot
.728 .41976 Mdot
.728 .41976 Mdot
.728 .41977 Mdot
.728 .41978 Mdot
.728 .4198 Mdot
.728 .4198 Mdot
.728 .41981 Mdot
.728 .41982 Mdot
.728 .41982 Mdot
.728 .41988 Mdot
.728 .41991 Mdot
.728 .41991 Mdot
.728 .41993 Mdot
.728 .41997 Mdot
.728 .41998 Mdot
.728 .41999 Mdot
.728 .41999 Mdot
.728 .42 Mdot
.728 .42 Mdot
.728 .42 Mdot
.728 .42007 Mdot
.728 .42009 Mdot
.728 .42009 Mdot
.728 .4201 Mdot
.728 .42011 Mdot
.728 .42016 Mdot
.728 .42017 Mdot
.728 .42018 Mdot
.728 .42018 Mdot
.728 .42022 Mdot
.728 .42022 Mdot
.728 .42022 Mdot
.728 .42023 Mdot
.728 .42024 Mdot
.728 .42024 Mdot
.728 .42024 Mdot
.728 .42025 Mdot
.728 .42036 Mdot
.728 .42037 Mdot
.728 .42037 Mdot
.728 .4204 Mdot
.728 .42041 Mdot
.728 .42044 Mdot
.728 .42045 Mdot
.728 .42048 Mdot
.728 .4205 Mdot
.728 .4205 Mdot
.728 .42051 Mdot
.728 .42053 Mdot
.728 .42057 Mdot
.728 .42058 Mdot
.728 .4206 Mdot
.728 .4206 Mdot
.728 .4206 Mdot
.728 .42063 Mdot
.728 .42064 Mdot
.728 .42066 Mdot
.728 .42068 Mdot
.728 .42071 Mdot
.728 .42074 Mdot
.728 .42075 Mdot
.728 .42078 Mdot
.728 .42086 Mdot
.728 .42087 Mdot
.728 .42091 Mdot
.728 .42092 Mdot
.728 .42093 Mdot
.728 .42098 Mdot
.728 .42102 Mdot
.728 .42106 Mdot
.728 .42109 Mdot
.728 .42111 Mdot
.728 .42113 Mdot
.728 .42117 Mdot
.728 .42118 Mdot
.728 .4212 Mdot
.728 .42125 Mdot
.728 .42128 Mdot
.728 .42131 Mdot
.728 .42135 Mdot
.728 .42139 Mdot
.728 .42145 Mdot
.728 .42148 Mdot
.728 .42154 Mdot
.728 .42156 Mdot
.728 .42162 Mdot
.728 .42163 Mdot
.728 .42166 Mdot
.728 .42167 Mdot
.728 .42169 Mdot
.728 .42171 Mdot
.728 .42172 Mdot
.728 .42179 Mdot
.728 .42179 Mdot
.728 .4218 Mdot
.728 .42182 Mdot
.728 .42182 Mdot
.728 .42187 Mdot
.728 .42187 Mdot
.728 .42193 Mdot
.728 .42193 Mdot
.728 .422 Mdot
.728 .42204 Mdot
.728 .42208 Mdot
.728 .42208 Mdot
.728 .42212 Mdot
.728 .42214 Mdot
.728 .42218 Mdot
.728 .42218 Mdot
.728 .42219 Mdot
.728 .42227 Mdot
.728 .42231 Mdot
.728 .42234 Mdot
.728 .42241 Mdot
.728 .42246 Mdot
.728 .42262 Mdot
.728 .42263 Mdot
.728 .42265 Mdot
.728 .42265 Mdot
.728 .42268 Mdot
.728 .4227 Mdot
.728 .4227 Mdot
.728 .42275 Mdot
.728 .42283 Mdot
.728 .42284 Mdot
.728 .42287 Mdot
.728 .4229 Mdot
.728 .42293 Mdot
.728 .42305 Mdot
.728 .42308 Mdot
.728 .4231 Mdot
.728 .4231 Mdot
.728 .42316 Mdot
.728 .42317 Mdot
.728 .42317 Mdot
.728 .42323 Mdot
.728 .4233 Mdot
.728 .42333 Mdot
.728 .42337 Mdot
.728 .42341 Mdot
.728 .42341 Mdot
.728 .42341 Mdot
.728 .42342 Mdot
.728 .42343 Mdot
.728 .42345 Mdot
.728 .42346 Mdot
.728 .42347 Mdot
.728 .42348 Mdot
.728 .42349 Mdot
.728 .4235 Mdot
.728 .42352 Mdot
.728 .42354 Mdot
.728 .42354 Mdot
.728 .42355 Mdot
.728 .42355 Mdot
.728 .42357 Mdot
.728 .42357 Mdot
.728 .42362 Mdot
.728 .42362 Mdot
.728 .42363 Mdot
.728 .42365 Mdot
.728 .42365 Mdot
.728 .42365 Mdot
.728 .42366 Mdot
.728 .42367 Mdot
.728 .42377 Mdot
.728 .42378 Mdot
.728 .42379 Mdot
.728 .4238 Mdot
.728 .42381 Mdot
.728 .42387 Mdot
.728 .42388 Mdot
.728 .42389 Mdot
.728 .42392 Mdot
.728 .42393 Mdot
.728 .42393 Mdot
.728 .42394 Mdot
.728 .42394 Mdot
.728 .42399 Mdot
.728 .42401 Mdot
.728 .42401 Mdot
.728 .42404 Mdot
.728 .42404 Mdot
.728 .42408 Mdot
.728 .42408 Mdot
.728 .42409 Mdot
.728 .42409 Mdot
.728 .42416 Mdot
.728 .42417 Mdot
.728 .42418 Mdot
.728 .42421 Mdot
.728 .42424 Mdot
.728 .42425 Mdot
.728 .42428 Mdot
.728 .42429 Mdot
.728 .42429 Mdot
.728 .42431 Mdot
.728 .42431 Mdot
.728 .42433 Mdot
.728 .42434 Mdot
.728 .42435 Mdot
.728 .42437 Mdot
.728 .42442 Mdot
.728 .42443 Mdot
.728 .42445 Mdot
.728 .42446 Mdot
.728 .42452 Mdot
.728 .42453 Mdot
.728 .42454 Mdot
.728 .42457 Mdot
.728 .42461 Mdot
.728 .42463 Mdot
.728 .42464 Mdot
.728 .42465 Mdot
.728 .42469 Mdot
.728 .42477 Mdot
.728 .42479 Mdot
.728 .42479 Mdot
.728 .4248 Mdot
.728 .42481 Mdot
.728 .42484 Mdot
.728 .42484 Mdot
.728 .42485 Mdot
.728 .42487 Mdot
.728 .42487 Mdot
.728 .42489 Mdot
.728 .42494 Mdot
.728 .42495 Mdot
.728 .42497 Mdot
.728 .42498 Mdot
.728 .42499 Mdot
.728 .42499 Mdot
.728 .42503 Mdot
.728 .42505 Mdot
.728 .42508 Mdot
.728 .42516 Mdot
.728 .42517 Mdot
.728 .42518 Mdot
.728 .42519 Mdot
.728 .42521 Mdot
.728 .42524 Mdot
.728 .42527 Mdot
.728 .42531 Mdot
.728 .42532 Mdot
.728 .42533 Mdot
.728 .42533 Mdot
.728 .42535 Mdot
.728 .42535 Mdot
.728 .42537 Mdot
.728 .42542 Mdot
.728 .42545 Mdot
.728 .42547 Mdot
.728 .42557 Mdot
.728 .42557 Mdot
.728 .42559 Mdot
.728 .4256 Mdot
.728 .42561 Mdot
.728 .42563 Mdot
.728 .42565 Mdot
.728 .42566 Mdot
.728 .42566 Mdot
.728 .42566 Mdot
.728 .42569 Mdot
.728 .42569 Mdot
.728 .4257 Mdot
.728 .42573 Mdot
.728 .42577 Mdot
.728 .42589 Mdot
.728 .42591 Mdot
.728 .42592 Mdot
.728 .42595 Mdot
.728 .42597 Mdot
.728 .42597 Mdot
.728 .426 Mdot
.728 .426 Mdot
.728 .42601 Mdot
.728 .42602 Mdot
.728 .42609 Mdot
.728 .42612 Mdot
.728 .42615 Mdot
.728 .42615 Mdot
.728 .42616 Mdot
.728 .42622 Mdot
.728 .42624 Mdot
.728 .42624 Mdot
.728 .42629 Mdot
.728 .42629 Mdot
.728 .4263 Mdot
.728 .42632 Mdot
.728 .42634 Mdot
.728 .42636 Mdot
.728 .42639 Mdot
.728 .42641 Mdot
.728 .42642 Mdot
.728 .42648 Mdot
.728 .42648 Mdot
.728 .42655 Mdot
.728 .42657 Mdot
.728 .42664 Mdot
.728 .42679 Mdot
.728 .4268 Mdot
.728 .42682 Mdot
.728 .42683 Mdot
.728 .42685 Mdot
.728 .42689 Mdot
.728 .42689 Mdot
.728 .42692 Mdot
.728 .42694 Mdot
.728 .42695 Mdot
.728 .42696 Mdot
.728 .42697 Mdot
.728 .42703 Mdot
.728 .42706 Mdot
.728 .42709 Mdot
.728 .42718 Mdot
.728 .42736 Mdot
.728 .42781 Mdot
.728 .42787 Mdot
.728 .42792 Mdot
.728 .42799 Mdot
.728 .42802 Mdot
.728 .42808 Mdot
.728 .42817 Mdot
.728 .42822 Mdot
.728 .42823 Mdot
.728 .42825 Mdot
.728 .42832 Mdot
.728 .42841 Mdot
.728 .42844 Mdot
.728 .4285 Mdot
.728 .42854 Mdot
.728 .42875 Mdot
.728 .42879 Mdot
.728 .42885 Mdot
.728 .42895 Mdot
.728 .42929 Mdot
.728 .42936 Mdot
.728 .42992 Mdot
.728 .43059 Mdot
.728 .43062 Mdot
.728 .43155 Mdot
.728 .43177 Mdot
.728 .4318 Mdot
.728 .43188 Mdot
.728 .43196 Mdot
.728 .43219 Mdot
.728 .43221 Mdot
.728 .43227 Mdot
.728 .43231 Mdot
.728 .43252 Mdot
.728 .43255 Mdot
.728 .43283 Mdot
.728 .43301 Mdot
.728 .43304 Mdot
.728 .43311 Mdot
.728 .43339 Mdot
.728 .43368 Mdot
.728 .4338 Mdot
.728 .434 Mdot
.728 .43412 Mdot
.728 .43413 Mdot
.728 .43431 Mdot
.728 .43483 Mdot
.728 .43487 Mdot
.728 .43498 Mdot
.728 .43516 Mdot
.728 .43519 Mdot
.728 .4355 Mdot
.728 .43592 Mdot
.728 .43601 Mdot
.728 .43624 Mdot
.728 .43635 Mdot
.728 .43659 Mdot
.728 .43681 Mdot
.728 .43803 Mdot
.728 .43846 Mdot
.728 .43863 Mdot
.728 .43927 Mdot
.728 .43956 Mdot
.728 .4401 Mdot
.728 .44016 Mdot
.728 .44024 Mdot
.728 .44031 Mdot
.728 .44117 Mdot
.728 .44174 Mdot
.728 .44178 Mdot
.728 .44201 Mdot
.728 .44207 Mdot
.728 .44222 Mdot
.728 .44228 Mdot
.728 .44234 Mdot
.728 .44237 Mdot
.728 .44248 Mdot
.728 .44258 Mdot
.728 .44283 Mdot
.728 .44285 Mdot
.728 .44288 Mdot
.728 .44291 Mdot
.728 .44294 Mdot
.728 .44303 Mdot
.728 .44304 Mdot
.728 .4431 Mdot
.728 .44312 Mdot
.728 .44312 Mdot
.728 .44324 Mdot
.728 .44327 Mdot
.728 .44329 Mdot
.728 .44333 Mdot
.728 .44333 Mdot
.728 .44335 Mdot
.728 .44335 Mdot
.73 .26022 Mdot
.73 .26024 Mdot
.73 .26025 Mdot
.73 .26025 Mdot
.73 .2603 Mdot
.73 .26033 Mdot
.73 .26035 Mdot
.73 .26035 Mdot
.73 .26038 Mdot
.73 .26044 Mdot
.73 .26046 Mdot
.73 .26048 Mdot
.73 .26049 Mdot
.73 .26059 Mdot
.73 .2607 Mdot
.73 .2607 Mdot
.73 .2607 Mdot
.73 .26077 Mdot
.73 .26078 Mdot
.73 .2609 Mdot
.73 .26102 Mdot
.73 .26111 Mdot
.73 .26135 Mdot
.73 .26137 Mdot
.73 .26149 Mdot
.73 .26156 Mdot
.73 .26158 Mdot
.73 .26176 Mdot
.73 .26194 Mdot
.73 .26223 Mdot
.73 .26224 Mdot
.73 .26235 Mdot
.73 .26243 Mdot
.73 .26244 Mdot
.73 .26257 Mdot
.73 .26263 Mdot
.73 .26269 Mdot
.73 .26304 Mdot
.73 .26304 Mdot
.73 .26323 Mdot
.73 .26336 Mdot
.73 .26348 Mdot
.73 .2635 Mdot
.73 .26354 Mdot
.73 .26354 Mdot
.73 .26364 Mdot
.73 .26365 Mdot
.73 .26367 Mdot
.73 .26368 Mdot
.73 .26391 Mdot
.73 .26395 Mdot
.73 .26397 Mdot
.73 .26406 Mdot
.73 .26425 Mdot
.73 .26449 Mdot
.73 .26477 Mdot
.73 .26485 Mdot
.73 .2649 Mdot
.73 .26511 Mdot
.73 .26534 Mdot
.73 .26538 Mdot
.73 .26539 Mdot
.73 .26539 Mdot
.73 .26561 Mdot
.73 .26596 Mdot
.73 .26596 Mdot
.73 .26647 Mdot
.73 .26656 Mdot
.73 .26663 Mdot
.73 .26683 Mdot
.73 .26688 Mdot
.73 .26701 Mdot
.73 .26714 Mdot
.73 .26728 Mdot
.73 .2673 Mdot
.73 .26736 Mdot
.73 .2675 Mdot
.73 .26756 Mdot
.73 .2676 Mdot
.73 .26765 Mdot
.73 .26822 Mdot
.73 .26832 Mdot
.73 .26844 Mdot
.73 .26855 Mdot
.73 .26867 Mdot
.73 .26877 Mdot
.73 .26883 Mdot
.73 .26886 Mdot
.73 .26886 Mdot
.73 .26899 Mdot
.73 .26899 Mdot
.73 .26906 Mdot
.73 .26974 Mdot
.73 .26978 Mdot
.73 .27004 Mdot
.73 .27025 Mdot
.73 .27042 Mdot
.73 .27065 Mdot
.73 .27155 Mdot
.73 .27159 Mdot
.73 .27168 Mdot
.73 .27248 Mdot
.73 .27262 Mdot
.73 .27309 Mdot
.73 .27381 Mdot
.73 .27395 Mdot
.73 .27444 Mdot
.73 .27446 Mdot
.73 .2747 Mdot
.73 .27534 Mdot
.73 .2755 Mdot
.73 .27582 Mdot
.73 .27673 Mdot
.73 .2769 Mdot
.73 .27733 Mdot
.73 .27734 Mdot
.73 .27743 Mdot
.73 .27769 Mdot
.73 .27785 Mdot
.73 .27852 Mdot
.73 .27921 Mdot
.73 .28017 Mdot
.73 .28056 Mdot
.73 .28101 Mdot
.73 .28102 Mdot
.73 .28159 Mdot
.73 .2817 Mdot
.73 .28179 Mdot
.73 .28215 Mdot
.73 .28278 Mdot
.73 .28292 Mdot
.73 .2836 Mdot
.73 .28409 Mdot
.73 .28446 Mdot
.73 .28466 Mdot
.73 .28477 Mdot
.73 .28489 Mdot
.73 .28531 Mdot
.73 .28565 Mdot
.73 .28596 Mdot
.73 .28614 Mdot
.73 .28618 Mdot
.73 .2867 Mdot
.73 .28734 Mdot
.73 .28859 Mdot
.73 .28898 Mdot
.73 .28905 Mdot
.73 .28949 Mdot
.73 .28993 Mdot
.73 .28995 Mdot
.73 .28999 Mdot
.73 .29012 Mdot
.73 .29037 Mdot
.73 .29039 Mdot
.73 .29105 Mdot
.73 .29112 Mdot
.73 .29116 Mdot
.73 .29132 Mdot
.73 .2915 Mdot
.73 .29152 Mdot
.73 .29154 Mdot
.73 .29169 Mdot
.73 .29195 Mdot
.73 .29229 Mdot
.73 .2924 Mdot
.73 .29253 Mdot
.73 .29265 Mdot
.73 .29273 Mdot
.73 .29295 Mdot
.73 .29299 Mdot
.73 .29301 Mdot
.73 .29304 Mdot
.73 .29344 Mdot
.73 .2935 Mdot
.73 .29357 Mdot
.73 .29374 Mdot
.73 .29374 Mdot
.73 .29381 Mdot
.73 .29385 Mdot
.73 .29422 Mdot
.73 .29424 Mdot
.73 .29448 Mdot
.73 .29468 Mdot
.73 .29514 Mdot
.73 .29562 Mdot
.73 .29583 Mdot
.73 .29615 Mdot
.73 .29643 Mdot
.73 .29679 Mdot
.73 .29686 Mdot
.73 .29699 Mdot
.73 .29735 Mdot
.73 .29742 Mdot
.73 .29762 Mdot
.73 .29803 Mdot
.73 .29829 Mdot
.73 .29864 Mdot
.73 .29877 Mdot
.73 .29893 Mdot
.73 .29894 Mdot
.73 .29914 Mdot
.73 .29921 Mdot
.73 .29933 Mdot
.73 .29959 Mdot
.73 .29999 Mdot
.73 .30011 Mdot
.73 .30021 Mdot
.73 .30039 Mdot
.73 .30066 Mdot
.73 .30083 Mdot
.73 .30104 Mdot
.73 .30143 Mdot
.73 .30155 Mdot
.73 .30157 Mdot
.73 .30171 Mdot
.73 .30185 Mdot
.73 .30191 Mdot
.73 .30219 Mdot
.73 .30233 Mdot
.73 .30234 Mdot
.73 .30234 Mdot
.73 .30246 Mdot
.73 .3026 Mdot
.73 .30264 Mdot
.73 .3027 Mdot
.73 .30277 Mdot
.73 .30278 Mdot
.73 .30279 Mdot
.73 .30291 Mdot
.73 .30293 Mdot
.73 .30301 Mdot
.73 .30303 Mdot
.73 .30304 Mdot
.73 .30315 Mdot
.73 .30316 Mdot
.73 .30329 Mdot
.73 .30357 Mdot
.73 .30363 Mdot
.73 .30372 Mdot
.73 .30381 Mdot
.73 .30392 Mdot
.73 .30394 Mdot
.73 .30397 Mdot
.73 .30408 Mdot
.73 .3041 Mdot
.73 .30416 Mdot
.73 .30428 Mdot
.73 .30436 Mdot
.73 .30446 Mdot
.73 .3045 Mdot
.73 .30455 Mdot
.73 .30461 Mdot
.73 .30463 Mdot
.73 .30498 Mdot
.73 .30506 Mdot
.73 .30511 Mdot
.73 .30533 Mdot
.73 .30538 Mdot
.73 .30542 Mdot
.73 .30543 Mdot
.73 .30552 Mdot
.73 .3056 Mdot
.73 .30569 Mdot
.73 .3057 Mdot
.73 .30581 Mdot
.73 .30614 Mdot
.73 .30617 Mdot
.73 .30646 Mdot
.73 .30649 Mdot
.73 .30649 Mdot
.73 .30654 Mdot
.73 .30657 Mdot
.73 .30657 Mdot
.73 .30681 Mdot
.73 .30684 Mdot
.73 .30684 Mdot
.73 .30703 Mdot
.73 .30709 Mdot
.73 .30721 Mdot
.73 .30722 Mdot
.73 .30738 Mdot
.73 .30766 Mdot
.73 .30779 Mdot
.73 .3078 Mdot
.73 .30781 Mdot
.73 .30792 Mdot
.73 .30831 Mdot
.73 .30834 Mdot
.73 .30841 Mdot
.73 .30842 Mdot
.73 .30923 Mdot
.73 .3093 Mdot
.73 .30958 Mdot
.73 .30964 Mdot
.73 .30968 Mdot
.73 .3097 Mdot
.73 .30993 Mdot
.73 .31007 Mdot
.73 .31017 Mdot
.73 .3104 Mdot
.73 .31052 Mdot
.73 .31073 Mdot
.73 .31127 Mdot
.73 .31128 Mdot
.73 .31129 Mdot
.73 .31135 Mdot
.73 .3115 Mdot
.73 .31158 Mdot
.73 .31162 Mdot
.73 .31176 Mdot
.73 .31192 Mdot
.73 .31194 Mdot
.73 .31219 Mdot
.73 .31259 Mdot
.73 .31404 Mdot
.73 .31414 Mdot
.73 .31416 Mdot
.73 .31426 Mdot
.73 .31483 Mdot
.73 .31498 Mdot
.73 .31508 Mdot
.73 .31518 Mdot
.73 .31525 Mdot
.73 .31535 Mdot
.73 .31542 Mdot
.73 .31567 Mdot
.73 .31604 Mdot
.73 .31605 Mdot
.73 .31622 Mdot
.73 .31632 Mdot
.73 .3164 Mdot
.73 .31644 Mdot
.73 .31672 Mdot
.73 .31684 Mdot
.73 .31686 Mdot
.73 .31687 Mdot
.73 .31693 Mdot
.73 .31698 Mdot
.73 .31702 Mdot
.73 .31706 Mdot
.73 .31722 Mdot
.73 .31729 Mdot
.73 .31736 Mdot
.73 .31737 Mdot
.73 .31753 Mdot
.73 .31759 Mdot
.73 .31767 Mdot
.73 .31809 Mdot
.73 .31823 Mdot
.73 .3183 Mdot
.73 .31901 Mdot
.73 .31942 Mdot
.73 .31961 Mdot
.73 .31964 Mdot
.73 .31967 Mdot
.73 .31978 Mdot
.73 .31982 Mdot
.73 .32011 Mdot
.73 .32018 Mdot
.73 .32019 Mdot
.73 .32036 Mdot
.73 .32046 Mdot
.73 .32052 Mdot
.73 .3206 Mdot
.73 .3208 Mdot
.73 .32118 Mdot
.73 .32122 Mdot
.73 .32134 Mdot
.73 .32167 Mdot
.73 .32178 Mdot
.73 .32184 Mdot
.73 .32217 Mdot
.73 .32232 Mdot
.73 .32247 Mdot
.73 .32259 Mdot
.73 .32265 Mdot
.73 .32435 Mdot
.73 .32446 Mdot
.73 .32472 Mdot
.73 .32495 Mdot
.73 .32501 Mdot
.73 .32517 Mdot
.73 .32519 Mdot
.73 .32528 Mdot
.73 .32538 Mdot
.73 .32555 Mdot
.73 .32557 Mdot
.73 .32573 Mdot
.73 .32587 Mdot
.73 .32597 Mdot
.73 .32615 Mdot
.73 .32615 Mdot
.73 .32656 Mdot
.73 .32666 Mdot
.73 .32677 Mdot
.73 .32684 Mdot
.73 .32689 Mdot
.73 .32689 Mdot
.73 .32703 Mdot
.73 .32708 Mdot
.73 .32711 Mdot
.73 .32716 Mdot
.73 .32722 Mdot
.73 .3273 Mdot
.73 .32737 Mdot
.73 .32758 Mdot
.73 .32758 Mdot
.73 .3276 Mdot
.73 .32769 Mdot
.73 .32775 Mdot
.73 .32785 Mdot
.73 .32794 Mdot
.73 .32795 Mdot
.73 .32802 Mdot
.73 .32803 Mdot
.73 .32809 Mdot
.73 .3281 Mdot
.73 .32817 Mdot
.73 .32823 Mdot
.73 .32827 Mdot
.73 .32832 Mdot
.73 .32835 Mdot
.73 .32843 Mdot
.73 .32844 Mdot
.73 .32846 Mdot
.73 .32846 Mdot
.73 .32853 Mdot
.73 .32854 Mdot
.73 .32855 Mdot
.73 .32858 Mdot
.73 .32858 Mdot
.73 .32861 Mdot
.73 .32862 Mdot
.73 .32864 Mdot
.73 .32872 Mdot
.73 .32875 Mdot
.73 .32877 Mdot
.73 .32877 Mdot
.73 .32878 Mdot
.73 .32879 Mdot
.73 .3288 Mdot
.73 .32882 Mdot
.73 .32884 Mdot
.73 .32886 Mdot
.73 .32892 Mdot
.73 .32892 Mdot
.73 .32892 Mdot
.73 .32938 Mdot
.73 .33029 Mdot
.73 .33052 Mdot
.73 .33096 Mdot
.73 .33323 Mdot
.73 .33333 Mdot
.73 .33351 Mdot
.73 .33362 Mdot
.73 .33465 Mdot
.73 .33468 Mdot
.73 .33507 Mdot
.73 .33532 Mdot
.73 .33651 Mdot
.73 .33789 Mdot
.73 .33991 Mdot
.73 .33992 Mdot
.73 .34363 Mdot
.73 .34432 Mdot
.73 .34493 Mdot
.73 .34635 Mdot
.73 .34649 Mdot
.73 .34735 Mdot
.73 .34857 Mdot
.73 .34865 Mdot
.73 .35194 Mdot
.73 .35393 Mdot
.73 .3559 Mdot
.73 .35618 Mdot
.73 .35699 Mdot
.73 .35836 Mdot
.73 .35861 Mdot
.73 .36127 Mdot
.73 .36233 Mdot
.73 .36367 Mdot
.73 .36504 Mdot
.73 .36522 Mdot
.73 .36599 Mdot
.73 .36603 Mdot
.73 .36604 Mdot
.73 .36733 Mdot
.73 .36839 Mdot
.73 .36853 Mdot
.73 .36877 Mdot
.73 .36904 Mdot
.73 .36974 Mdot
.73 .37003 Mdot
.73 .37004 Mdot
.73 .37028 Mdot
.73 .37067 Mdot
.73 .37117 Mdot
.73 .37121 Mdot
.73 .37132 Mdot
.73 .37156 Mdot
.73 .40951 Mdot
.73 .40957 Mdot
.73 .4096 Mdot
.73 .40961 Mdot
.73 .40974 Mdot
.73 .40984 Mdot
.73 .4099 Mdot
.73 .4099 Mdot
.73 .40998 Mdot
.73 .41016 Mdot
.73 .41023 Mdot
.73 .41029 Mdot
.73 .41032 Mdot
.73 .4106 Mdot
.73 .41093 Mdot
.73 .41093 Mdot
.73 .41094 Mdot
.73 .41113 Mdot
.73 .41118 Mdot
.73 .41153 Mdot
.73 .41187 Mdot
.73 .41214 Mdot
.73 .41281 Mdot
.73 .41288 Mdot
.73 .41322 Mdot
.73 .41343 Mdot
.73 .41349 Mdot
.73 .41399 Mdot
.73 .41449 Mdot
.73 .41532 Mdot
.73 .41534 Mdot
.73 .41564 Mdot
.73 .41586 Mdot
.73 .41589 Mdot
.73 .41625 Mdot
.73 .4164 Mdot
.73 .41658 Mdot
.73 .41751 Mdot
.73 .41752 Mdot
.73 .41803 Mdot
.73 .41838 Mdot
.73 .41868 Mdot
.73 .41874 Mdot
.73 .41884 Mdot
.73 .41885 Mdot
.73 .41911 Mdot
.73 .41914 Mdot
.73 .41918 Mdot
.73 .41921 Mdot
.73 .41979 Mdot
.73 .4199 Mdot
.73 .41996 Mdot
.73 .4202 Mdot
.73 .42031 Mdot
.73 .42031 Mdot
.73 .42031 Mdot
.73 .42033 Mdot
.73 .42033 Mdot
.73 .42034 Mdot
.73 .42034 Mdot
.73 .42035 Mdot
.73 .42035 Mdot
.73 .42035 Mdot
.73 .42035 Mdot
.73 .42036 Mdot
.73 .42037 Mdot
.73 .42038 Mdot
.73 .42039 Mdot
.73 .42039 Mdot
.73 .4204 Mdot
.73 .4204 Mdot
.73 .42041 Mdot
.73 .42041 Mdot
.73 .42041 Mdot
.73 .42043 Mdot
.73 .42043 Mdot
.73 .42044 Mdot
.73 .42044 Mdot
.73 .42046 Mdot
.73 .42047 Mdot
.73 .42048 Mdot
.73 .42049 Mdot
.73 .42051 Mdot
.73 .42053 Mdot
.73 .42053 Mdot
.73 .42054 Mdot
.73 .42055 Mdot
.73 .42056 Mdot
.73 .42057 Mdot
.73 .42059 Mdot
.73 .42061 Mdot
.73 .42063 Mdot
.73 .42065 Mdot
.73 .42066 Mdot
.73 .42066 Mdot
.73 .42071 Mdot
.73 .42073 Mdot
.73 .42075 Mdot
.73 .42077 Mdot
.73 .42078 Mdot
.73 .42079 Mdot
.73 .4208 Mdot
.73 .42084 Mdot
.73 .42084 Mdot
.73 .42085 Mdot
.73 .42087 Mdot
.73 .4209 Mdot
.73 .42092 Mdot
.73 .42103 Mdot
.73 .42103 Mdot
.73 .42108 Mdot
.73 .4211 Mdot
.73 .42114 Mdot
.73 .42118 Mdot
.73 .42118 Mdot
.73 .42123 Mdot
.73 .42125 Mdot
.73 .42128 Mdot
.73 .42128 Mdot
.73 .42132 Mdot
.73 .42134 Mdot
.73 .4214 Mdot
.73 .42147 Mdot
.73 .4215 Mdot
.73 .42194 Mdot
.73 .42196 Mdot
.73 .42199 Mdot
.73 .42203 Mdot
.73 .42207 Mdot
.73 .42215 Mdot
.73 .42217 Mdot
.73 .4222 Mdot
.73 .42229 Mdot
.73 .42232 Mdot
.73 .42233 Mdot
.73 .42243 Mdot
.73 .42248 Mdot
.73 .4225 Mdot
.73 .42252 Mdot
.73 .42254 Mdot
.73 .42259 Mdot
.73 .42259 Mdot
.73 .42261 Mdot
.73 .42269 Mdot
.73 .4227 Mdot
.73 .42273 Mdot
.73 .42273 Mdot
.73 .42274 Mdot
.73 .42279 Mdot
.73 .4229 Mdot
.73 .42309 Mdot
.73 .42311 Mdot
.73 .42315 Mdot
.73 .42326 Mdot
.73 .42328 Mdot
.73 .4233 Mdot
.73 .42334 Mdot
.73 .42334 Mdot
.73 .42336 Mdot
.73 .42338 Mdot
.73 .42342 Mdot
.73 .42343 Mdot
.73 .42344 Mdot
.73 .42346 Mdot
.73 .42347 Mdot
.73 .42347 Mdot
.73 .42348 Mdot
.73 .42351 Mdot
.73 .42359 Mdot
.73 .4236 Mdot
.73 .42362 Mdot
.73 .42365 Mdot
.73 .42369 Mdot
.73 .42369 Mdot
.73 .42379 Mdot
.73 .42386 Mdot
.73 .42388 Mdot
.73 .42391 Mdot
.73 .42393 Mdot
.73 .42395 Mdot
.73 .42398 Mdot
.73 .42402 Mdot
.73 .42418 Mdot
.73 .4242 Mdot
.73 .42421 Mdot
.73 .42423 Mdot
.73 .42463 Mdot
.73 .42474 Mdot
.73 .42481 Mdot
.73 .42481 Mdot
.73 .42486 Mdot
.73 .4249 Mdot
.73 .42491 Mdot
.73 .42493 Mdot
.73 .42497 Mdot
.73 .42499 Mdot
.73 .42499 Mdot
.73 .42499 Mdot
.73 .42514 Mdot
.73 .4252 Mdot
.73 .42523 Mdot
.73 .4253 Mdot
.73 .42533 Mdot
.73 .42536 Mdot
.73 .42543 Mdot
.73 .42543 Mdot
.73 .42544 Mdot
.73 .42546 Mdot
.73 .42554 Mdot
.73 .42556 Mdot
.73 .42578 Mdot
.73 .42579 Mdot
.73 .42581 Mdot
.73 .42581 Mdot
.73 .42592 Mdot
.73 .42596 Mdot
.73 .42596 Mdot
.73 .42596 Mdot
.73 .426 Mdot
.73 .42608 Mdot
.73 .42612 Mdot
.73 .42612 Mdot
.73 .42616 Mdot
.73 .42617 Mdot
.73 .42623 Mdot
.73 .42623 Mdot
.73 .42624 Mdot
.73 .4263 Mdot
.73 .42631 Mdot
.73 .42631 Mdot
.73 .42633 Mdot
.73 .42633 Mdot
.73 .42634 Mdot
.73 .42642 Mdot
.73 .42643 Mdot
.73 .42652 Mdot
.73 .42655 Mdot
.73 .42655 Mdot
.73 .42658 Mdot
.73 .4266 Mdot
.73 .42663 Mdot
.73 .42663 Mdot
.73 .42664 Mdot
.73 .42666 Mdot
.73 .42672 Mdot
.73 .42673 Mdot
.73 .42676 Mdot
.73 .42676 Mdot
.73 .42686 Mdot
.73 .42686 Mdot
.73 .42688 Mdot
.73 .42689 Mdot
.73 .42691 Mdot
.73 .42693 Mdot
.73 .42696 Mdot
.73 .42699 Mdot
.73 .42701 Mdot
.73 .42701 Mdot
.73 .42705 Mdot
.73 .42706 Mdot
.73 .42706 Mdot
.73 .42709 Mdot
.73 .42712 Mdot
.73 .42714 Mdot
.73 .42716 Mdot
.73 .42724 Mdot
.73 .42728 Mdot
.73 .42728 Mdot
.73 .42732 Mdot
.73 .42732 Mdot
.73 .42733 Mdot
.73 .42735 Mdot
.73 .42735 Mdot
.73 .42739 Mdot
.73 .42739 Mdot
.73 .42739 Mdot
.73 .42741 Mdot
.73 .42743 Mdot
.73 .42744 Mdot
.73 .42748 Mdot
.73 .42752 Mdot
.73 .42752 Mdot
.73 .42752 Mdot
.73 .42756 Mdot
.73 .42765 Mdot
.73 .42766 Mdot
.73 .4277 Mdot
.73 .42774 Mdot
.73 .42775 Mdot
.73 .42778 Mdot
.73 .4279 Mdot
.73 .42796 Mdot
.73 .42801 Mdot
.73 .42809 Mdot
.73 .42814 Mdot
.73 .42817 Mdot
.73 .42821 Mdot
.73 .42833 Mdot
.73 .42841 Mdot
.73 .42844 Mdot
.73 .42846 Mdot
.73 .42852 Mdot
.73 .42852 Mdot
.73 .42857 Mdot
.73 .42861 Mdot
.73 .42872 Mdot
.73 .42879 Mdot
.73 .42892 Mdot
.73 .42898 Mdot
.73 .429 Mdot
.73 .42911 Mdot
.73 .42915 Mdot
.73 .42917 Mdot
.73 .42928 Mdot
.73 .42937 Mdot
.73 .42946 Mdot
.73 .42953 Mdot
.73 .42968 Mdot
.73 .42982 Mdot
.73 .42988 Mdot
.73 .42996 Mdot
.73 .42996 Mdot
.73 .43008 Mdot
.73 .43009 Mdot
.73 .43011 Mdot
.73 .43011 Mdot
.73 .43017 Mdot
.73 .43019 Mdot
.73 .43021 Mdot
.73 .43033 Mdot
.73 .43034 Mdot
.73 .43035 Mdot
.73 .43036 Mdot
.73 .43043 Mdot
.73 .43046 Mdot
.73 .4305 Mdot
.73 .43054 Mdot
.73 .43057 Mdot
.73 .43068 Mdot
.73 .43076 Mdot
.73 .43081 Mdot
.73 .43082 Mdot
.73 .43082 Mdot
.73 .43088 Mdot
.73 .43093 Mdot
.73 .43095 Mdot
.73 .43097 Mdot
.73 .43118 Mdot
.73 .43119 Mdot
.73 .43127 Mdot
.73 .43131 Mdot
.73 .43132 Mdot
.73 .43133 Mdot
.73 .43148 Mdot
.73 .43162 Mdot
.73 .43164 Mdot
.73 .43177 Mdot
.73 .43219 Mdot
.73 .43241 Mdot
.73 .43259 Mdot
.73 .4326 Mdot
.73 .43266 Mdot
.73 .43277 Mdot
.73 .43288 Mdot
.73 .43303 Mdot
.73 .43307 Mdot
.73 .43311 Mdot
.73 .43318 Mdot
.73 .43331 Mdot
.73 .43348 Mdot
.73 .43373 Mdot
.73 .43378 Mdot
.73 .434 Mdot
.73 .43413 Mdot
.73 .43416 Mdot
.73 .43421 Mdot
.73 .43442 Mdot
.73 .43442 Mdot
.73 .43459 Mdot
.73 .43473 Mdot
.73 .43509 Mdot
.73 .43536 Mdot
.73 .43562 Mdot
.73 .43568 Mdot
.73 .43578 Mdot
.73 .43582 Mdot
.73 .43582 Mdot
.73 .43599 Mdot
.73 .43606 Mdot
.73 .43642 Mdot
.73 .43655 Mdot
.73 .43662 Mdot
.73 .43688 Mdot
.73 .43698 Mdot
.73 .43699 Mdot
.73 .4372 Mdot
.73 .43726 Mdot
.73 .43757 Mdot
.73 .43777 Mdot
.73 .43783 Mdot
.73 .43819 Mdot
.73 .43822 Mdot
.73 .43824 Mdot
.73 .43865 Mdot
.73 .43876 Mdot
.73 .43884 Mdot
.73 .43894 Mdot
.73 .43906 Mdot
.73 .43908 Mdot
.73 .4394 Mdot
.73 .43944 Mdot
.73 .43944 Mdot
.73 .4395 Mdot
.73 .4395 Mdot
.73 .43951 Mdot
.73 .43954 Mdot
.73 .43959 Mdot
.73 .43965 Mdot
.73 .43971 Mdot
.73 .43976 Mdot
.73 .43982 Mdot
.73 .4401 Mdot
.73 .44013 Mdot
.73 .44014 Mdot
.73 .44017 Mdot
.73 .44025 Mdot
.73 .44028 Mdot
.73 .44029 Mdot
.73 .44036 Mdot
.73 .44042 Mdot
.73 .4405 Mdot
.73 .44052 Mdot
.73 .44063 Mdot
.73 .44066 Mdot
.73 .44071 Mdot
.73 .44098 Mdot
.73 .44098 Mdot
.73 .44117 Mdot
.73 .44129 Mdot
.73 .44129 Mdot
.73 .4413 Mdot
.73 .44132 Mdot
.73 .44145 Mdot
.73 .44156 Mdot
.73 .44159 Mdot
.73 .44164 Mdot
.73 .44179 Mdot
.73 .44194 Mdot
.73 .44204 Mdot
.73 .4421 Mdot
.73 .44211 Mdot
.73 .44213 Mdot
.73 .44227 Mdot
.73 .44227 Mdot
.73 .44228 Mdot
.73 .44229 Mdot
.73 .44235 Mdot
.73 .44235 Mdot
.73 .44237 Mdot
.73 .44239 Mdot
.73 .44246 Mdot
.73 .44254 Mdot
.73 .44266 Mdot
.73 .44266 Mdot
.73 .44287 Mdot
.73 .44291 Mdot
.73 .44295 Mdot
.73 .44303 Mdot
.73 .44304 Mdot
.73 .44309 Mdot
.73 .44316 Mdot
.73 .44316 Mdot
.73 .44335 Mdot
.73 .44347 Mdot
.73 .44359 Mdot
.73 .4436 Mdot
.73 .44365 Mdot
.73 .44373 Mdot
.73 .44375 Mdot
.73 .44391 Mdot
.73 .44397 Mdot
.73 .44405 Mdot
.73 .44413 Mdot
.73 .44414 Mdot
.73 .44419 Mdot
.73 .44419 Mdot
.73 .44419 Mdot
.73 .44427 Mdot
.73 .44434 Mdot
.73 .44435 Mdot
.73 .44436 Mdot
.73 .44438 Mdot
.73 .44442 Mdot
.73 .44444 Mdot
.73 .44444 Mdot
.73 .44446 Mdot
.73 .44448 Mdot
.73 .44451 Mdot
.73 .44451 Mdot
.73 .44452 Mdot
.73 .44454 Mdot
.732 .31325 Mdot
.732 .31325 Mdot
.732 .31325 Mdot
.732 .31325 Mdot
.732 .31326 Mdot
.732 .31326 Mdot
.732 .31326 Mdot
.732 .31327 Mdot
.732 .31327 Mdot
.732 .31327 Mdot
.732 .31328 Mdot
.732 .31328 Mdot
.732 .31329 Mdot
.732 .3133 Mdot
.732 .3133 Mdot
.732 .31332 Mdot
.732 .31335 Mdot
.732 .31336 Mdot
.732 .31339 Mdot
.732 .31339 Mdot
.732 .3134 Mdot
.732 .31341 Mdot
.732 .31343 Mdot
.732 .31344 Mdot
.732 .31345 Mdot
.732 .3135 Mdot
.732 .31351 Mdot
.732 .31351 Mdot
.732 .31351 Mdot
.732 .31356 Mdot
.732 .31356 Mdot
.732 .31358 Mdot
.732 .31361 Mdot
.732 .31363 Mdot
.732 .31363 Mdot
.732 .31367 Mdot
.732 .31367 Mdot
.732 .3137 Mdot
.732 .31371 Mdot
.732 .31373 Mdot
.732 .31374 Mdot
.732 .31374 Mdot
.732 .31378 Mdot
.732 .31381 Mdot
.732 .31381 Mdot
.732 .31382 Mdot
.732 .31383 Mdot
.732 .31384 Mdot
.732 .31384 Mdot
.732 .31385 Mdot
.732 .31388 Mdot
.732 .31388 Mdot
.732 .31389 Mdot
.732 .3139 Mdot
.732 .31392 Mdot
.732 .31397 Mdot
.732 .31399 Mdot
.732 .314 Mdot
.732 .314 Mdot
.732 .314 Mdot
.732 .31403 Mdot
.732 .31404 Mdot
.732 .31405 Mdot
.732 .31412 Mdot
.732 .31419 Mdot
.732 .31429 Mdot
.732 .31431 Mdot
.732 .31439 Mdot
.732 .31445 Mdot
.732 .31463 Mdot
.732 .3148 Mdot
.732 .31483 Mdot
.732 .31507 Mdot
.732 .31516 Mdot
.732 .31516 Mdot
.732 .31518 Mdot
.732 .31523 Mdot
.732 .31527 Mdot
.732 .31529 Mdot
.732 .31529 Mdot
.732 .31533 Mdot
.732 .31551 Mdot
.732 .31554 Mdot
.732 .3156 Mdot
.732 .31564 Mdot
.732 .31565 Mdot
.732 .31568 Mdot
.732 .3157 Mdot
.732 .31574 Mdot
.732 .31595 Mdot
.732 .31628 Mdot
.732 .31631 Mdot
.732 .31646 Mdot
.732 .31646 Mdot
.732 .31649 Mdot
.732 .31652 Mdot
.732 .31656 Mdot
.732 .31678 Mdot
.732 .31688 Mdot
.732 .31696 Mdot
.732 .31703 Mdot
.732 .31712 Mdot
.732 .31714 Mdot
.732 .31716 Mdot
.732 .31716 Mdot
.732 .31716 Mdot
.732 .31718 Mdot
.732 .31722 Mdot
.732 .31723 Mdot
.732 .31725 Mdot
.732 .31725 Mdot
.732 .31728 Mdot
.732 .31729 Mdot
.732 .31729 Mdot
.732 .3173 Mdot
.732 .3173 Mdot
.732 .31733 Mdot
.732 .31736 Mdot
.732 .31737 Mdot
.732 .31739 Mdot
.732 .31742 Mdot
.732 .31742 Mdot
.732 .31745 Mdot
.732 .31746 Mdot
.732 .31748 Mdot
.732 .31753 Mdot
.732 .31758 Mdot
.732 .31771 Mdot
.732 .31775 Mdot
.732 .31779 Mdot
.732 .31781 Mdot
.732 .31792 Mdot
.732 .31796 Mdot
.732 .31798 Mdot
.732 .318 Mdot
.732 .31801 Mdot
.732 .31806 Mdot
.732 .31812 Mdot
.732 .31824 Mdot
.732 .31824 Mdot
.732 .31827 Mdot
.732 .31833 Mdot
.732 .31834 Mdot
.732 .31837 Mdot
.732 .31844 Mdot
.732 .31846 Mdot
.732 .31851 Mdot
.732 .31863 Mdot
.732 .31865 Mdot
.732 .31869 Mdot
.732 .3187 Mdot
.732 .31871 Mdot
.732 .31877 Mdot
.732 .31879 Mdot
.732 .31879 Mdot
.732 .31884 Mdot
.732 .31886 Mdot
.732 .31898 Mdot
.732 .31901 Mdot
.732 .31909 Mdot
.732 .31909 Mdot
.732 .31912 Mdot
.732 .3192 Mdot
.732 .31923 Mdot
.732 .31928 Mdot
.732 .31938 Mdot
.732 .31944 Mdot
.732 .31965 Mdot
.732 .31967 Mdot
.732 .31982 Mdot
.732 .31983 Mdot
.732 .31987 Mdot
.732 .31989 Mdot
.732 .31997 Mdot
.732 .31998 Mdot
.732 .32 Mdot
.732 .32002 Mdot
.732 .32004 Mdot
.732 .32006 Mdot
.732 .32014 Mdot
.732 .32027 Mdot
.732 .32027 Mdot
.732 .32033 Mdot
.732 .32033 Mdot
.732 .32034 Mdot
.732 .32044 Mdot
.732 .32047 Mdot
.732 .3205 Mdot
.732 .32052 Mdot
.732 .32056 Mdot
.732 .32057 Mdot
.732 .32057 Mdot
.732 .32057 Mdot
.732 .32057 Mdot
.732 .32059 Mdot
.732 .32059 Mdot
.732 .3206 Mdot
.732 .32061 Mdot
.732 .32061 Mdot
.732 .32061 Mdot
.732 .32061 Mdot
.732 .32062 Mdot
.732 .32063 Mdot
.732 .32064 Mdot
.732 .32065 Mdot
.732 .32066 Mdot
.732 .32067 Mdot
.732 .32067 Mdot
.732 .32071 Mdot
.732 .32076 Mdot
.732 .32078 Mdot
.732 .32081 Mdot
.732 .32083 Mdot
.732 .32083 Mdot
.732 .32084 Mdot
.732 .32084 Mdot
.732 .32086 Mdot
.732 .32088 Mdot
.732 .32091 Mdot
.732 .32091 Mdot
.732 .32092 Mdot
.732 .32094 Mdot
.732 .32095 Mdot
.732 .32103 Mdot
.732 .32103 Mdot
.732 .32105 Mdot
.732 .32105 Mdot
.732 .32106 Mdot
.732 .32108 Mdot
.732 .32108 Mdot
.732 .32114 Mdot
.732 .32115 Mdot
.732 .32117 Mdot
.732 .32117 Mdot
.732 .32121 Mdot
.732 .32121 Mdot
.732 .32123 Mdot
.732 .32126 Mdot
.732 .32128 Mdot
.732 .32134 Mdot
.732 .32134 Mdot
.732 .32139 Mdot
.732 .32139 Mdot
.732 .32141 Mdot
.732 .32144 Mdot
.732 .32144 Mdot
.732 .32145 Mdot
.732 .32145 Mdot
.732 .32146 Mdot
.732 .32148 Mdot
.732 .32152 Mdot
.732 .32152 Mdot
.732 .32154 Mdot
.732 .32154 Mdot
.732 .32154 Mdot
.732 .32157 Mdot
.732 .32158 Mdot
.732 .3216 Mdot
.732 .32161 Mdot
.732 .32162 Mdot
.732 .32163 Mdot
.732 .32164 Mdot
.732 .32168 Mdot
.732 .32169 Mdot
.732 .32169 Mdot
.732 .32171 Mdot
.732 .32173 Mdot
.732 .32176 Mdot
.732 .32176 Mdot
.732 .32179 Mdot
.732 .3218 Mdot
.732 .32186 Mdot
.732 .32187 Mdot
.732 .32188 Mdot
.732 .3219 Mdot
.732 .3219 Mdot
.732 .3219 Mdot
.732 .32195 Mdot
.732 .32197 Mdot
.732 .32198 Mdot
.732 .322 Mdot
.732 .3221 Mdot
.732 .32217 Mdot
.732 .32221 Mdot
.732 .32221 Mdot
.732 .32223 Mdot
.732 .32227 Mdot
.732 .32235 Mdot
.732 .32235 Mdot
.732 .32235 Mdot
.732 .32236 Mdot
.732 .32238 Mdot
.732 .32239 Mdot
.732 .3224 Mdot
.732 .32243 Mdot
.732 .32251 Mdot
.732 .32252 Mdot
.732 .32254 Mdot
.732 .32258 Mdot
.732 .32258 Mdot
.732 .32261 Mdot
.732 .32264 Mdot
.732 .32266 Mdot
.732 .3227 Mdot
.732 .3227 Mdot
.732 .32271 Mdot
.732 .32278 Mdot
.732 .32279 Mdot
.732 .3228 Mdot
.732 .32283 Mdot
.732 .32285 Mdot
.732 .32286 Mdot
.732 .32287 Mdot
.732 .32288 Mdot
.732 .32293 Mdot
.732 .32294 Mdot
.732 .32294 Mdot
.732 .32296 Mdot
.732 .32296 Mdot
.732 .32302 Mdot
.732 .32306 Mdot
.732 .32307 Mdot
.732 .32307 Mdot
.732 .32308 Mdot
.732 .32309 Mdot
.732 .3231 Mdot
.732 .32313 Mdot
.732 .32314 Mdot
.732 .32316 Mdot
.732 .32316 Mdot
.732 .32323 Mdot
.732 .32323 Mdot
.732 .32332 Mdot
.732 .32335 Mdot
.732 .32339 Mdot
.732 .32341 Mdot
.732 .32342 Mdot
.732 .32345 Mdot
.732 .32347 Mdot
.732 .32347 Mdot
.732 .3235 Mdot
.732 .32351 Mdot
.732 .32356 Mdot
.732 .32357 Mdot
.732 .32359 Mdot
.732 .32359 Mdot
.732 .3236 Mdot
.732 .32362 Mdot
.732 .32363 Mdot
.732 .32363 Mdot
.732 .32365 Mdot
.732 .32365 Mdot
.732 .32366 Mdot
.732 .3237 Mdot
.732 .32372 Mdot
.732 .32373 Mdot
.732 .32375 Mdot
.732 .32377 Mdot
.732 .32377 Mdot
.732 .32379 Mdot
.732 .32381 Mdot
.732 .32381 Mdot
.732 .32385 Mdot
.732 .32387 Mdot
.732 .32389 Mdot
.732 .32389 Mdot
.732 .3239 Mdot
.732 .32391 Mdot
.732 .32393 Mdot
.732 .32397 Mdot
.732 .32397 Mdot
.732 .32399 Mdot
.732 .32401 Mdot
.732 .32405 Mdot
.732 .32407 Mdot
.732 .32409 Mdot
.732 .3241 Mdot
.732 .3241 Mdot
.732 .32411 Mdot
.732 .32411 Mdot
.732 .32412 Mdot
.732 .32413 Mdot
.732 .32413 Mdot
.732 .32414 Mdot
.732 .32415 Mdot
.732 .32416 Mdot
.732 .32416 Mdot
.732 .32416 Mdot
.732 .32416 Mdot
.732 .32417 Mdot
.732 .32417 Mdot
.732 .32418 Mdot
.732 .32418 Mdot
.732 .3242 Mdot
.732 .3242 Mdot
.732 .32421 Mdot
.732 .32421 Mdot
.732 .32421 Mdot
.732 .32422 Mdot
.732 .32425 Mdot
.732 .32428 Mdot
.732 .32431 Mdot
.732 .32434 Mdot
.732 .32442 Mdot
.732 .32443 Mdot
.732 .32444 Mdot
.732 .32445 Mdot
.732 .32445 Mdot
.732 .3245 Mdot
.732 .32451 Mdot
.732 .32462 Mdot
.732 .32469 Mdot
.732 .32471 Mdot
.732 .32471 Mdot
.732 .32472 Mdot
.732 .32473 Mdot
.732 .32474 Mdot
.732 .32476 Mdot
.732 .32477 Mdot
.732 .32483 Mdot
.732 .32484 Mdot
.732 .32484 Mdot
.732 .32485 Mdot
.732 .32486 Mdot
.732 .32488 Mdot
.732 .32488 Mdot
.732 .32488 Mdot
.732 .32491 Mdot
.732 .32499 Mdot
.732 .325 Mdot
.732 .32505 Mdot
.732 .32511 Mdot
.732 .32513 Mdot
.732 .32515 Mdot
.732 .32516 Mdot
.732 .32519 Mdot
.732 .32521 Mdot
.732 .32523 Mdot
.732 .32523 Mdot
.732 .32524 Mdot
.732 .32525 Mdot
.732 .32525 Mdot
.732 .32525 Mdot
.732 .32525 Mdot
.732 .32525 Mdot
.732 .32527 Mdot
.732 .32528 Mdot
.732 .32528 Mdot
.732 .32529 Mdot
.732 .32529 Mdot
.732 .32529 Mdot
.732 .3253 Mdot
.732 .3253 Mdot
.732 .3253 Mdot
.732 .3253 Mdot
.732 .3253 Mdot
.732 .32531 Mdot
.732 .32532 Mdot
.732 .32533 Mdot
.732 .32533 Mdot
.732 .32533 Mdot
.732 .32534 Mdot
.732 .32534 Mdot
.732 .32535 Mdot
.732 .32535 Mdot
.732 .32536 Mdot
.732 .32536 Mdot
.732 .32537 Mdot
.732 .32538 Mdot
.732 .32538 Mdot
.732 .32538 Mdot
.732 .32539 Mdot
.732 .3254 Mdot
.732 .3254 Mdot
.732 .3254 Mdot
.732 .32541 Mdot
.732 .32542 Mdot
.732 .32542 Mdot
.732 .32542 Mdot
.732 .32543 Mdot
.732 .32543 Mdot
.732 .32543 Mdot
.732 .32544 Mdot
.732 .32544 Mdot
.732 .32545 Mdot
.732 .32546 Mdot
.732 .32546 Mdot
.732 .32546 Mdot
.732 .32546 Mdot
.732 .32547 Mdot
.732 .32547 Mdot
.732 .32547 Mdot
.732 .32547 Mdot
.732 .32547 Mdot
.732 .32547 Mdot
.732 .32547 Mdot
.732 .32547 Mdot
.732 .32547 Mdot
.732 .32547 Mdot
.732 .32547 Mdot
.732 .42142 Mdot
.732 .42142 Mdot
.732 .42142 Mdot
.732 .42142 Mdot
.732 .42143 Mdot
.732 .42143 Mdot
.732 .42143 Mdot
.732 .42143 Mdot
.732 .42143 Mdot
.732 .42143 Mdot
.732 .42143 Mdot
.732 .42143 Mdot
.732 .42143 Mdot
.732 .42143 Mdot
.732 .42143 Mdot
.732 .42143 Mdot
.732 .42143 Mdot
.732 .42143 Mdot
.732 .42143 Mdot
.732 .42144 Mdot
.732 .42144 Mdot
.732 .42144 Mdot
.732 .42144 Mdot
.732 .42144 Mdot
.732 .42144 Mdot
.732 .42144 Mdot
.732 .42144 Mdot
.732 .42144 Mdot
.732 .42144 Mdot
.732 .42145 Mdot
.732 .42145 Mdot
.732 .42145 Mdot
.732 .42145 Mdot
.732 .42145 Mdot
.732 .42145 Mdot
.732 .42146 Mdot
.732 .42146 Mdot
.732 .42146 Mdot
.732 .42146 Mdot
.732 .42146 Mdot
.732 .42146 Mdot
.732 .42146 Mdot
.732 .42147 Mdot
.732 .42147 Mdot
.732 .42147 Mdot
.732 .42147 Mdot
.732 .42147 Mdot
.732 .42147 Mdot
.732 .42147 Mdot
.732 .42147 Mdot
.732 .42147 Mdot
.732 .42147 Mdot
.732 .42147 Mdot
.732 .42148 Mdot
.732 .42148 Mdot
.732 .42148 Mdot
.732 .42148 Mdot
.732 .42148 Mdot
.732 .42148 Mdot
.732 .42148 Mdot
.732 .42149 Mdot
.732 .42149 Mdot
.732 .42149 Mdot
.732 .42149 Mdot
.732 .4215 Mdot
.732 .42151 Mdot
.732 .42151 Mdot
.732 .42151 Mdot
.732 .42152 Mdot
.732 .42153 Mdot
.732 .42155 Mdot
.732 .42155 Mdot
.732 .42157 Mdot
.732 .42158 Mdot
.732 .42158 Mdot
.732 .42158 Mdot
.732 .42158 Mdot
.732 .42159 Mdot
.732 .42159 Mdot
.732 .42159 Mdot
.732 .42159 Mdot
.732 .42161 Mdot
.732 .42161 Mdot
.732 .42162 Mdot
.732 .42162 Mdot
.732 .42162 Mdot
.732 .42162 Mdot
.732 .42162 Mdot
.732 .42163 Mdot
.732 .42165 Mdot
.732 .42168 Mdot
.732 .42168 Mdot
.732 .42169 Mdot
.732 .42169 Mdot
.732 .42169 Mdot
.732 .4217 Mdot
.732 .4217 Mdot
.732 .42172 Mdot
.732 .42173 Mdot
.732 .42174 Mdot
.732 .42174 Mdot
.732 .42175 Mdot
.732 .42175 Mdot
.732 .42175 Mdot
.732 .42175 Mdot
.732 .42176 Mdot
.732 .42176 Mdot
.732 .42176 Mdot
.732 .42176 Mdot
.732 .42176 Mdot
.732 .42176 Mdot
.732 .42177 Mdot
.732 .42177 Mdot
.732 .42177 Mdot
.732 .42177 Mdot
.732 .42177 Mdot
.732 .42177 Mdot
.732 .42177 Mdot
.732 .42177 Mdot
.732 .42178 Mdot
.732 .42178 Mdot
.732 .42178 Mdot
.732 .42178 Mdot
.732 .42178 Mdot
.732 .42178 Mdot
.732 .42179 Mdot
.732 .42179 Mdot
.732 .42181 Mdot
.732 .42181 Mdot
.732 .42181 Mdot
.732 .42182 Mdot
.732 .42183 Mdot
.732 .42183 Mdot
.732 .42183 Mdot
.732 .42184 Mdot
.732 .42184 Mdot
.732 .42184 Mdot
.732 .42185 Mdot
.732 .42186 Mdot
.732 .42186 Mdot
.732 .42186 Mdot
.732 .42187 Mdot
.732 .42187 Mdot
.732 .42187 Mdot
.732 .42188 Mdot
.732 .42188 Mdot
.732 .42189 Mdot
.732 .4219 Mdot
.732 .4219 Mdot
.732 .4219 Mdot
.732 .42191 Mdot
.732 .42191 Mdot
.732 .42191 Mdot
.732 .42191 Mdot
.732 .42191 Mdot
.732 .42192 Mdot
.732 .42192 Mdot
.732 .42192 Mdot
.732 .42194 Mdot
.732 .42194 Mdot
.732 .42195 Mdot
.732 .42195 Mdot
.732 .42195 Mdot
.732 .42196 Mdot
.732 .42196 Mdot
.732 .42197 Mdot
.732 .42198 Mdot
.732 .42198 Mdot
.732 .42201 Mdot
.732 .42201 Mdot
.732 .42203 Mdot
.732 .42203 Mdot
.732 .42203 Mdot
.732 .42204 Mdot
.732 .42204 Mdot
.732 .42205 Mdot
.732 .42205 Mdot
.732 .42205 Mdot
.732 .42205 Mdot
.732 .42205 Mdot
.732 .42206 Mdot
.732 .42208 Mdot
.732 .42208 Mdot
.732 .42209 Mdot
.732 .42209 Mdot
.732 .42209 Mdot
.732 .4221 Mdot
.732 .4221 Mdot
.732 .42211 Mdot
.732 .42211 Mdot
.732 .42211 Mdot
.732 .42212 Mdot
.732 .42212 Mdot
.732 .42213 Mdot
.732 .42215 Mdot
.732 .42215 Mdot
.732 .42215 Mdot
.732 .42216 Mdot
.732 .42216 Mdot
.732 .42217 Mdot
.732 .42218 Mdot
.732 .42218 Mdot
.732 .42219 Mdot
.732 .4222 Mdot
.732 .4222 Mdot
.732 .42222 Mdot
.732 .42223 Mdot
.732 .42223 Mdot
.732 .42223 Mdot
.732 .42224 Mdot
.732 .42224 Mdot
.732 .42224 Mdot
.732 .42224 Mdot
.732 .42226 Mdot
.732 .42227 Mdot
.732 .42228 Mdot
.732 .42228 Mdot
.732 .42229 Mdot
.732 .42231 Mdot
.732 .42233 Mdot
.732 .42234 Mdot
.732 .42234 Mdot
.732 .42235 Mdot
.732 .42236 Mdot
.732 .42236 Mdot
.732 .42236 Mdot
.732 .42236 Mdot
.732 .42237 Mdot
.732 .42237 Mdot
.732 .42238 Mdot
.732 .42239 Mdot
.732 .42239 Mdot
.732 .42239 Mdot
.732 .4224 Mdot
.732 .42241 Mdot
.732 .42241 Mdot
.732 .42241 Mdot
.732 .42242 Mdot
.732 .42243 Mdot
.732 .42243 Mdot
.732 .42243 Mdot
.732 .42243 Mdot
.732 .42244 Mdot
.732 .42244 Mdot
.732 .42244 Mdot
.732 .42245 Mdot
.732 .42245 Mdot
.732 .42245 Mdot
.732 .42246 Mdot
.732 .42246 Mdot
.732 .42247 Mdot
.732 .42247 Mdot
.732 .42248 Mdot
.732 .42248 Mdot
.732 .42248 Mdot
.732 .42248 Mdot
.732 .42249 Mdot
.732 .42249 Mdot
.732 .42249 Mdot
.732 .4225 Mdot
.732 .42251 Mdot
.732 .42252 Mdot
.732 .42253 Mdot
.732 .42253 Mdot
.732 .42254 Mdot
.732 .42254 Mdot
.732 .42255 Mdot
.732 .42255 Mdot
.732 .42256 Mdot
.732 .42256 Mdot
.732 .42257 Mdot
.732 .42258 Mdot
.732 .42258 Mdot
.732 .42258 Mdot
.732 .42258 Mdot
.732 .42259 Mdot
.732 .42259 Mdot
.732 .42261 Mdot
.732 .42261 Mdot
.732 .42262 Mdot
.732 .42262 Mdot
.732 .42262 Mdot
.732 .42263 Mdot
.732 .42263 Mdot
.732 .42264 Mdot
.732 .42264 Mdot
.732 .42264 Mdot
.732 .42264 Mdot
.732 .42264 Mdot
.732 .42265 Mdot
.732 .42266 Mdot
.732 .42267 Mdot
.732 .42268 Mdot
.732 .42268 Mdot
.732 .42268 Mdot
.732 .42269 Mdot
.732 .42269 Mdot
.732 .42269 Mdot
.732 .42269 Mdot
.732 .4227 Mdot
.732 .4227 Mdot
.732 .4227 Mdot
.732 .4227 Mdot
.732 .4227 Mdot
.732 .4227 Mdot
.732 .4227 Mdot
.732 .42271 Mdot
.732 .42271 Mdot
.732 .42271 Mdot
.732 .42271 Mdot
.732 .42271 Mdot
.732 .42272 Mdot
.732 .42273 Mdot
.732 .42273 Mdot
.732 .42274 Mdot
.732 .42277 Mdot
.732 .42277 Mdot
.732 .42277 Mdot
.732 .42279 Mdot
.732 .42279 Mdot
.732 .42282 Mdot
.732 .42284 Mdot
.732 .42285 Mdot
.732 .42285 Mdot
.732 .42286 Mdot
.732 .42286 Mdot
.732 .42287 Mdot
.732 .42289 Mdot
.732 .42289 Mdot
.732 .42291 Mdot
.732 .42291 Mdot
.732 .42295 Mdot
.732 .42295 Mdot
.732 .42301 Mdot
.732 .42302 Mdot
.732 .42305 Mdot
.732 .42306 Mdot
.732 .42307 Mdot
.732 .42309 Mdot
.732 .4231 Mdot
.732 .4231 Mdot
.732 .42312 Mdot
.732 .42313 Mdot
.732 .42316 Mdot
.732 .42317 Mdot
.732 .42318 Mdot
.732 .42318 Mdot
.732 .42318 Mdot
.732 .4232 Mdot
.732 .4232 Mdot
.732 .42321 Mdot
.732 .42322 Mdot
.732 .42322 Mdot
.732 .42323 Mdot
.732 .42326 Mdot
.732 .42327 Mdot
.732 .42327 Mdot
.732 .42329 Mdot
.732 .4233 Mdot
.732 .4233 Mdot
.732 .42332 Mdot
.732 .42333 Mdot
.732 .42333 Mdot
.732 .42336 Mdot
.732 .42338 Mdot
.732 .42339 Mdot
.732 .42339 Mdot
.732 .4234 Mdot
.732 .4234 Mdot
.732 .42341 Mdot
.732 .42344 Mdot
.732 .42345 Mdot
.732 .42346 Mdot
.732 .42347 Mdot
.732 .4235 Mdot
.732 .42352 Mdot
.732 .42353 Mdot
.732 .42354 Mdot
.732 .42354 Mdot
.732 .42355 Mdot
.732 .42355 Mdot
.732 .42355 Mdot
.732 .42356 Mdot
.732 .42356 Mdot
.732 .42357 Mdot
.732 .42358 Mdot
.732 .42358 Mdot
.732 .42358 Mdot
.732 .42358 Mdot
.732 .42358 Mdot
.732 .42359 Mdot
.732 .42359 Mdot
.732 .4236 Mdot
.732 .4236 Mdot
.732 .42361 Mdot
.732 .42361 Mdot
.732 .42362 Mdot
.732 .42362 Mdot
.732 .42362 Mdot
.732 .42363 Mdot
.732 .42365 Mdot
.732 .42367 Mdot
.732 .42369 Mdot
.732 .42372 Mdot
.732 .42378 Mdot
.732 .42379 Mdot
.732 .4238 Mdot
.732 .4238 Mdot
.732 .4238 Mdot
.732 .42384 Mdot
.732 .42385 Mdot
.732 .42394 Mdot
.732 .424 Mdot
.732 .42401 Mdot
.732 .42401 Mdot
.732 .42402 Mdot
.732 .42402 Mdot
.732 .42404 Mdot
.732 .42405 Mdot
.732 .42406 Mdot
.732 .42411 Mdot
.732 .42412 Mdot
.732 .42412 Mdot
.732 .42412 Mdot
.732 .42414 Mdot
.732 .42415 Mdot
.732 .42415 Mdot
.732 .42415 Mdot
.732 .42418 Mdot
.732 .42424 Mdot
.732 .42425 Mdot
.732 .4243 Mdot
.732 .42435 Mdot
.732 .42436 Mdot
.732 .42438 Mdot
.732 .42439 Mdot
.732 .42442 Mdot
.732 .42444 Mdot
.732 .42446 Mdot
.732 .42446 Mdot
.732 .42446 Mdot
.732 .42447 Mdot
.732 .42447 Mdot
.732 .42447 Mdot
.732 .42447 Mdot
.732 .42448 Mdot
.732 .42449 Mdot
.732 .4245 Mdot
.732 .4245 Mdot
.732 .4245 Mdot
.732 .4245 Mdot
.732 .42451 Mdot
.732 .42451 Mdot
.732 .42451 Mdot
.732 .42452 Mdot
.732 .42452 Mdot
.732 .42452 Mdot
.732 .42452 Mdot
.732 .42453 Mdot
.732 .42454 Mdot
.732 .42454 Mdot
.732 .42454 Mdot
.732 .42455 Mdot
.732 .42455 Mdot
.732 .42456 Mdot
.732 .42456 Mdot
.732 .42457 Mdot
.732 .42457 Mdot
.732 .42458 Mdot
.732 .42458 Mdot
.732 .42459 Mdot
.732 .42459 Mdot
.732 .4246 Mdot
.732 .4246 Mdot
.732 .4246 Mdot
.732 .42461 Mdot
.732 .42462 Mdot
.732 .42462 Mdot
.732 .42462 Mdot
.732 .42463 Mdot
.732 .42463 Mdot
.732 .42464 Mdot
.732 .42464 Mdot
.732 .42464 Mdot
.732 .42465 Mdot
.732 .42465 Mdot
.732 .42466 Mdot
.732 .42466 Mdot
.732 .42466 Mdot
.732 .42466 Mdot
.732 .42467 Mdot
.732 .42467 Mdot
.732 .42467 Mdot
.732 .42467 Mdot
.732 .42467 Mdot
.732 .42467 Mdot
.732 .42467 Mdot
.732 .42467 Mdot
.732 .42467 Mdot
.732 .42467 Mdot
.732 .42467 Mdot
.734 .31886 Mdot
.734 .32197 Mdot
.734 .42256 Mdot
.734 .42338 Mdot
.736 .31865 Mdot
.736 .42366 Mdot
.738 .25794 Mdot
.738 .25794 Mdot
.738 .25794 Mdot
.738 .25794 Mdot
.738 .25794 Mdot
.738 .25795 Mdot
.738 .25795 Mdot
.738 .25796 Mdot
.738 .25797 Mdot
.738 .25797 Mdot
.738 .25798 Mdot
.738 .258 Mdot
.738 .25801 Mdot
.738 .25802 Mdot
.738 .25805 Mdot
.738 .25805 Mdot
.738 .25806 Mdot
.738 .25806 Mdot
.738 .25807 Mdot
.738 .25807 Mdot
.738 .25807 Mdot
.738 .25807 Mdot
.738 .25807 Mdot
.738 .25808 Mdot
.738 .25814 Mdot
.738 .25815 Mdot
.738 .25818 Mdot
.738 .25818 Mdot
.738 .25818 Mdot
.738 .25819 Mdot
.738 .2582 Mdot
.738 .25824 Mdot
.738 .25827 Mdot
.738 .2583 Mdot
.738 .25831 Mdot
.738 .25834 Mdot
.738 .25834 Mdot
.738 .25836 Mdot
.738 .25837 Mdot
.738 .25838 Mdot
.738 .25838 Mdot
.738 .25842 Mdot
.738 .25845 Mdot
.738 .25848 Mdot
.738 .25851 Mdot
.738 .25851 Mdot
.738 .25851 Mdot
.738 .25855 Mdot
.738 .25859 Mdot
.738 .25859 Mdot
.738 .2586 Mdot
.738 .25869 Mdot
.738 .2587 Mdot
.738 .2587 Mdot
.738 .25873 Mdot
.738 .25876 Mdot
.738 .25883 Mdot
.738 .25885 Mdot
.738 .25888 Mdot
.738 .25889 Mdot
.738 .25894 Mdot
.738 .25897 Mdot
.738 .25903 Mdot
.738 .25909 Mdot
.738 .25909 Mdot
.738 .25931 Mdot
.738 .25938 Mdot
.738 .25942 Mdot
.738 .25945 Mdot
.738 .25946 Mdot
.738 .25955 Mdot
.738 .25965 Mdot
.738 .25966 Mdot
.738 .25967 Mdot
.738 .25978 Mdot
.738 .2598 Mdot
.738 .25984 Mdot
.738 .25994 Mdot
.738 .25994 Mdot
.738 .25995 Mdot
.738 .26001 Mdot
.738 .26002 Mdot
.738 .26006 Mdot
.738 .26006 Mdot
.738 .26023 Mdot
.738 .26033 Mdot
.738 .26036 Mdot
.738 .26042 Mdot
.738 .26044 Mdot
.738 .2605 Mdot
.738 .26056 Mdot
.738 .26065 Mdot
.738 .26074 Mdot
.738 .26075 Mdot
.738 .2608 Mdot
.738 .26083 Mdot
.738 .26122 Mdot
.738 .26139 Mdot
.738 .26175 Mdot
.738 .2618 Mdot
.738 .26182 Mdot
.738 .26188 Mdot
.738 .262 Mdot
.738 .26204 Mdot
.738 .26204 Mdot
.738 .26207 Mdot
.738 .26216 Mdot
.738 .26221 Mdot
.738 .26226 Mdot
.738 .26231 Mdot
.738 .26268 Mdot
.738 .26279 Mdot
.738 .26283 Mdot
.738 .26304 Mdot
.738 .26325 Mdot
.738 .26334 Mdot
.738 .26335 Mdot
.738 .26343 Mdot
.738 .26352 Mdot
.738 .26394 Mdot
.738 .26401 Mdot
.738 .26401 Mdot
.738 .26418 Mdot
.738 .26421 Mdot
.738 .26427 Mdot
.738 .26429 Mdot
.738 .2643 Mdot
.738 .26434 Mdot
.738 .26437 Mdot
.738 .26438 Mdot
.738 .26442 Mdot
.738 .26449 Mdot
.738 .26453 Mdot
.738 .2646 Mdot
.738 .26464 Mdot
.738 .2651 Mdot
.738 .26523 Mdot
.738 .26543 Mdot
.738 .26543 Mdot
.738 .26565 Mdot
.738 .26566 Mdot
.738 .26575 Mdot
.738 .26577 Mdot
.738 .26588 Mdot
.738 .26589 Mdot
.738 .26599 Mdot
.738 .26605 Mdot
.738 .26648 Mdot
.738 .26665 Mdot
.738 .26674 Mdot
.738 .26688 Mdot
.738 .26727 Mdot
.738 .26743 Mdot
.738 .26762 Mdot
.738 .26767 Mdot
.738 .26772 Mdot
.738 .26772 Mdot
.738 .26774 Mdot
.738 .26777 Mdot
.738 .26788 Mdot
.738 .2679 Mdot
.738 .26801 Mdot
.738 .26809 Mdot
.738 .26824 Mdot
.738 .26833 Mdot
.738 .26874 Mdot
.738 .26881 Mdot
.738 .26895 Mdot
.738 .26913 Mdot
.738 .26921 Mdot
.738 .26929 Mdot
.738 .26963 Mdot
.738 .27024 Mdot
.738 .27065 Mdot
.738 .27092 Mdot
.738 .27187 Mdot
.738 .27203 Mdot
.738 .27221 Mdot
.738 .27227 Mdot
.738 .27241 Mdot
.738 .27243 Mdot
.738 .27312 Mdot
.738 .27322 Mdot
.738 .27328 Mdot
.738 .27411 Mdot
.738 .27481 Mdot
.738 .2752 Mdot
.738 .27534 Mdot
.738 .27672 Mdot
.738 .2769 Mdot
.738 .27737 Mdot
.738 .27755 Mdot
.738 .27809 Mdot
.738 .27863 Mdot
.738 .27876 Mdot
.738 .27893 Mdot
.738 .27931 Mdot
.738 .27971 Mdot
.738 .27993 Mdot
.738 .27995 Mdot
.738 .28012 Mdot
.738 .28022 Mdot
.738 .28035 Mdot
.738 .2806 Mdot
.738 .28101 Mdot
.738 .28127 Mdot
.738 .28163 Mdot
.738 .28205 Mdot
.738 .28241 Mdot
.738 .28313 Mdot
.738 .28381 Mdot
.738 .28382 Mdot
.738 .28392 Mdot
.738 .28434 Mdot
.738 .28516 Mdot
.738 .2852 Mdot
.738 .28523 Mdot
.738 .28523 Mdot
.738 .28526 Mdot
.738 .28566 Mdot
.738 .28588 Mdot
.738 .28588 Mdot
.738 .28589 Mdot
.738 .28613 Mdot
.738 .28628 Mdot
.738 .28638 Mdot
.738 .28703 Mdot
.738 .28725 Mdot
.738 .28735 Mdot
.738 .28736 Mdot
.738 .28765 Mdot
.738 .28799 Mdot
.738 .28804 Mdot
.738 .28814 Mdot
.738 .28832 Mdot
.738 .28915 Mdot
.738 .28926 Mdot
.738 .28944 Mdot
.738 .29007 Mdot
.738 .29017 Mdot
.738 .29024 Mdot
.738 .29048 Mdot
.738 .29092 Mdot
.738 .29115 Mdot
.738 .29125 Mdot
.738 .29187 Mdot
.738 .2923 Mdot
.738 .29237 Mdot
.738 .29268 Mdot
.738 .29277 Mdot
.738 .29341 Mdot
.738 .29367 Mdot
.738 .29372 Mdot
.738 .29412 Mdot
.738 .29438 Mdot
.738 .29443 Mdot
.738 .29447 Mdot
.738 .29452 Mdot
.738 .29494 Mdot
.738 .29502 Mdot
.738 .29544 Mdot
.738 .29555 Mdot
.738 .29668 Mdot
.738 .29685 Mdot
.738 .29735 Mdot
.738 .29752 Mdot
.738 .29782 Mdot
.738 .29874 Mdot
.738 .29882 Mdot
.738 .29883 Mdot
.738 .29913 Mdot
.738 .2992 Mdot
.738 .29955 Mdot
.738 .3 Mdot
.738 .30006 Mdot
.738 .30061 Mdot
.738 .30093 Mdot
.738 .30113 Mdot
.738 .30134 Mdot
.738 .30139 Mdot
.738 .30182 Mdot
.738 .30183 Mdot
.738 .30189 Mdot
.738 .30197 Mdot
.738 .30258 Mdot
.738 .30271 Mdot
.738 .3032 Mdot
.738 .30368 Mdot
.738 .30369 Mdot
.738 .30369 Mdot
.738 .3037 Mdot
.738 .30391 Mdot
.738 .30391 Mdot
.738 .30391 Mdot
.738 .30464 Mdot
.738 .30468 Mdot
.738 .30505 Mdot
.738 .30512 Mdot
.738 .30533 Mdot
.738 .30538 Mdot
.738 .30561 Mdot
.738 .30569 Mdot
.738 .30607 Mdot
.738 .3061 Mdot
.738 .3062 Mdot
.738 .30645 Mdot
.738 .30669 Mdot
.738 .30679 Mdot
.738 .3068 Mdot
.738 .30699 Mdot
.738 .30714 Mdot
.738 .30762 Mdot
.738 .30779 Mdot
.738 .30785 Mdot
.738 .30831 Mdot
.738 .30831 Mdot
.738 .30842 Mdot
.738 .30856 Mdot
.738 .30894 Mdot
.738 .30921 Mdot
.738 .30923 Mdot
.738 .30939 Mdot
.738 .30968 Mdot
.738 .30972 Mdot
.738 .30991 Mdot
.738 .3101 Mdot
.738 .3101 Mdot
.738 .31019 Mdot
.738 .31019 Mdot
.738 .31019 Mdot
.738 .31048 Mdot
.738 .31049 Mdot
.738 .31064 Mdot
.738 .31067 Mdot
.738 .31087 Mdot
.738 .3109 Mdot
.738 .31106 Mdot
.738 .31107 Mdot
.738 .31112 Mdot
.738 .31133 Mdot
.738 .31138 Mdot
.738 .31146 Mdot
.738 .31152 Mdot
.738 .31174 Mdot
.738 .31181 Mdot
.738 .31184 Mdot
.738 .31205 Mdot
.738 .31217 Mdot
.738 .31236 Mdot
.738 .31249 Mdot
.738 .31258 Mdot
.738 .31272 Mdot
.738 .31275 Mdot
.738 .31284 Mdot
.738 .31294 Mdot
.738 .31294 Mdot
.738 .31299 Mdot
.738 .31299 Mdot
.738 .31299 Mdot
.738 .31323 Mdot
.738 .31338 Mdot
.738 .31347 Mdot
.738 .31348 Mdot
.738 .3135 Mdot
.738 .31362 Mdot
.738 .31365 Mdot
.738 .31374 Mdot
.738 .31392 Mdot
.738 .31442 Mdot
.738 .31452 Mdot
.738 .31468 Mdot
.738 .31472 Mdot
.738 .31472 Mdot
.738 .31502 Mdot
.738 .3151 Mdot
.738 .31512 Mdot
.738 .31533 Mdot
.738 .31638 Mdot
.738 .31638 Mdot
.738 .31702 Mdot
.738 .32116 Mdot
.738 .32209 Mdot
.738 .32283 Mdot
.738 .32291 Mdot
.738 .32386 Mdot
.738 .32601 Mdot
.738 .32822 Mdot
.738 .32866 Mdot
.738 .32987 Mdot
.738 .33393 Mdot
.738 .33442 Mdot
.738 .33504 Mdot
.738 .3355 Mdot
.738 .33659 Mdot
.738 .33684 Mdot
.738 .33694 Mdot
.738 .33732 Mdot
.738 .33867 Mdot
.738 .33937 Mdot
.738 .33957 Mdot
.738 .34016 Mdot
.738 .34432 Mdot
.738 .34636 Mdot
.738 .3509 Mdot
.738 .3513 Mdot
.738 .35189 Mdot
.738 .35204 Mdot
.738 .35314 Mdot
.738 .35412 Mdot
.738 .35486 Mdot
.738 .35562 Mdot
.738 .35589 Mdot
.738 .35664 Mdot
.738 .35693 Mdot
.738 .35818 Mdot
.738 .3602 Mdot
.738 .36028 Mdot
.738 .36071 Mdot
.738 .36084 Mdot
.738 .36159 Mdot
.738 .36168 Mdot
.738 .36175 Mdot
.738 .36295 Mdot
.738 .3635 Mdot
.738 .3637 Mdot
.738 .36506 Mdot
.738 .3652 Mdot
.738 .36527 Mdot
.738 .36654 Mdot
.738 .36765 Mdot
.738 .36783 Mdot
.738 .36812 Mdot
.738 .36861 Mdot
.738 .36894 Mdot
.738 .36957 Mdot
.738 .37219 Mdot
.738 .3723 Mdot
.738 .37302 Mdot
.738 .37373 Mdot
.738 .37413 Mdot
.738 .37471 Mdot
.738 .37481 Mdot
.738 .37527 Mdot
.738 .37549 Mdot
.738 .37635 Mdot
.738 .37674 Mdot
.738 .37706 Mdot
.738 .37713 Mdot
.738 .37717 Mdot
.738 .37837 Mdot
.738 .37846 Mdot
.738 .37851 Mdot
.738 .37893 Mdot
.738 .3794 Mdot
.738 .37941 Mdot
.738 .37947 Mdot
.738 .37981 Mdot
.738 .38021 Mdot
.738 .38059 Mdot
.738 .38111 Mdot
.738 .38112 Mdot
.738 .38113 Mdot
.738 .38128 Mdot
.738 .3815 Mdot
.738 .38159 Mdot
.738 .38198 Mdot
.738 .38207 Mdot
.738 .38238 Mdot
.738 .38282 Mdot
.738 .38327 Mdot
.738 .38346 Mdot
.738 .38349 Mdot
.738 .3835 Mdot
.738 .38358 Mdot
.738 .38394 Mdot
.738 .38402 Mdot
.738 .38475 Mdot
.738 .38485 Mdot
.738 .38486 Mdot
.738 .38489 Mdot
.738 .38491 Mdot
.738 .38493 Mdot
.738 .38496 Mdot
.738 .38503 Mdot
.738 .38507 Mdot
.738 .38509 Mdot
.738 .38548 Mdot
.738 .38559 Mdot
.738 .38569 Mdot
.738 .38595 Mdot
.738 .38606 Mdot
.738 .38612 Mdot
.738 .38627 Mdot
.738 .38634 Mdot
.738 .38641 Mdot
.738 .38645 Mdot
.738 .38646 Mdot
.738 .38647 Mdot
.738 .38651 Mdot
.738 .38652 Mdot
.738 .40662 Mdot
.738 .40662 Mdot
.738 .40663 Mdot
.738 .40664 Mdot
.738 .40664 Mdot
.738 .40665 Mdot
.738 .40667 Mdot
.738 .40668 Mdot
.738 .40673 Mdot
.738 .40674 Mdot
.738 .40677 Mdot
.738 .40684 Mdot
.738 .40687 Mdot
.738 .4069 Mdot
.738 .407 Mdot
.738 .407 Mdot
.738 .40701 Mdot
.738 .40703 Mdot
.738 .40704 Mdot
.738 .40705 Mdot
.738 .40705 Mdot
.738 .40706 Mdot
.738 .40706 Mdot
.738 .40709 Mdot
.738 .40728 Mdot
.738 .4073 Mdot
.738 .4074 Mdot
.738 .40742 Mdot
.738 .40742 Mdot
.738 .40743 Mdot
.738 .40748 Mdot
.738 .4076 Mdot
.738 .40771 Mdot
.738 .40779 Mdot
.738 .40782 Mdot
.738 .40792 Mdot
.738 .40794 Mdot
.738 .408 Mdot
.738 .40804 Mdot
.738 .40804 Mdot
.738 .40805 Mdot
.738 .40818 Mdot
.738 .40828 Mdot
.738 .40838 Mdot
.738 .40847 Mdot
.738 .40849 Mdot
.738 .40849 Mdot
.738 .40861 Mdot
.738 .40872 Mdot
.738 .40874 Mdot
.738 .40876 Mdot
.738 .40907 Mdot
.738 .40908 Mdot
.738 .4091 Mdot
.738 .40918 Mdot
.738 .40928 Mdot
.738 .4095 Mdot
.738 .40956 Mdot
.738 .40968 Mdot
.738 .4097 Mdot
.738 .40985 Mdot
.738 .40995 Mdot
.738 .41013 Mdot
.738 .41032 Mdot
.738 .41034 Mdot
.738 .41101 Mdot
.738 .41117 Mdot
.738 .41125 Mdot
.738 .41137 Mdot
.738 .41144 Mdot
.738 .41149 Mdot
.738 .41177 Mdot
.738 .41209 Mdot
.738 .41211 Mdot
.738 .41214 Mdot
.738 .41248 Mdot
.738 .41253 Mdot
.738 .41267 Mdot
.738 .41297 Mdot
.738 .41299 Mdot
.738 .41301 Mdot
.738 .4132 Mdot
.738 .41323 Mdot
.738 .41334 Mdot
.738 .41336 Mdot
.738 .41386 Mdot
.738 .41417 Mdot
.738 .41424 Mdot
.738 .41443 Mdot
.738 .4145 Mdot
.738 .41468 Mdot
.738 .41487 Mdot
.738 .41511 Mdot
.738 .41539 Mdot
.738 .41542 Mdot
.738 .41557 Mdot
.738 .41567 Mdot
.738 .4168 Mdot
.738 .41731 Mdot
.738 .41834 Mdot
.738 .41849 Mdot
.738 .41854 Mdot
.738 .41872 Mdot
.738 .41906 Mdot
.738 .41915 Mdot
.738 .41918 Mdot
.738 .41924 Mdot
.738 .41952 Mdot
.738 .41963 Mdot
.738 .41979 Mdot
.738 .41992 Mdot
.738 .42095 Mdot
.738 .42126 Mdot
.738 .42137 Mdot
.738 .42195 Mdot
.738 .4225 Mdot
.738 .42275 Mdot
.738 .42277 Mdot
.738 .42297 Mdot
.738 .42321 Mdot
.738 .42432 Mdot
.738 .42449 Mdot
.738 .42449 Mdot
.738 .42477 Mdot
.738 .42483 Mdot
.738 .42483 Mdot
.738 .42486 Mdot
.738 .42494 Mdot
.738 .42494 Mdot
.738 .42495 Mdot
.738 .42499 Mdot
.738 .42502 Mdot
.738 .42516 Mdot
.738 .42521 Mdot
.738 .42523 Mdot
.738 .42524 Mdot
.738 .42527 Mdot
.738 .42528 Mdot
.738 .42528 Mdot
.738 .4253 Mdot
.738 .42534 Mdot
.738 .42541 Mdot
.738 .42541 Mdot
.738 .42541 Mdot
.738 .42542 Mdot
.738 .42543 Mdot
.738 .42545 Mdot
.738 .42548 Mdot
.738 .42549 Mdot
.738 .42552 Mdot
.738 .42555 Mdot
.738 .42559 Mdot
.738 .42564 Mdot
.738 .42567 Mdot
.738 .42573 Mdot
.738 .42574 Mdot
.738 .42576 Mdot
.738 .42582 Mdot
.738 .42583 Mdot
.738 .42586 Mdot
.738 .42587 Mdot
.738 .42593 Mdot
.738 .42594 Mdot
.738 .42594 Mdot
.738 .42599 Mdot
.738 .426 Mdot
.738 .42605 Mdot
.738 .42606 Mdot
.738 .4261 Mdot
.738 .42611 Mdot
.738 .42619 Mdot
.738 .42619 Mdot
.738 .42619 Mdot
.738 .42621 Mdot
.738 .42621 Mdot
.738 .42626 Mdot
.738 .42632 Mdot
.738 .42633 Mdot
.738 .42637 Mdot
.738 .42641 Mdot
.738 .42646 Mdot
.738 .42646 Mdot
.738 .42654 Mdot
.738 .42664 Mdot
.738 .42668 Mdot
.738 .42672 Mdot
.738 .42672 Mdot
.738 .42684 Mdot
.738 .42686 Mdot
.738 .42691 Mdot
.738 .42705 Mdot
.738 .42709 Mdot
.738 .42714 Mdot
.738 .42715 Mdot
.738 .42718 Mdot
.738 .42724 Mdot
.738 .42731 Mdot
.738 .42734 Mdot
.738 .42735 Mdot
.738 .42746 Mdot
.738 .42748 Mdot
.738 .42755 Mdot
.738 .42757 Mdot
.738 .42763 Mdot
.738 .42765 Mdot
.738 .42775 Mdot
.738 .42776 Mdot
.738 .42798 Mdot
.738 .42798 Mdot
.738 .42798 Mdot
.738 .42804 Mdot
.738 .42804 Mdot
.738 .42804 Mdot
.738 .42804 Mdot
.738 .42818 Mdot
.738 .42833 Mdot
.738 .42837 Mdot
.738 .42855 Mdot
.738 .42857 Mdot
.738 .42859 Mdot
.738 .42859 Mdot
.738 .42872 Mdot
.738 .42873 Mdot
.738 .4288 Mdot
.738 .42886 Mdot
.738 .42895 Mdot
.738 .42912 Mdot
.738 .42913 Mdot
.738 .42927 Mdot
.738 .42938 Mdot
.738 .4294 Mdot
.738 .42949 Mdot
.738 .42949 Mdot
.738 .42952 Mdot
.738 .4298 Mdot
.738 .42989 Mdot
.738 .42994 Mdot
.738 .4301 Mdot
.738 .43015 Mdot
.738 .4305 Mdot
.738 .43054 Mdot
.738 .43067 Mdot
.738 .4307 Mdot
.738 .43083 Mdot
.738 .43085 Mdot
.738 .43086 Mdot
.738 .43087 Mdot
.738 .43096 Mdot
.738 .43108 Mdot
.738 .4311 Mdot
.738 .43118 Mdot
.738 .43139 Mdot
.738 .43142 Mdot
.738 .43152 Mdot
.738 .43154 Mdot
.738 .43168 Mdot
.738 .43189 Mdot
.738 .43192 Mdot
.738 .43199 Mdot
.738 .43214 Mdot
.738 .43222 Mdot
.738 .43224 Mdot
.738 .43228 Mdot
.738 .43249 Mdot
.738 .43255 Mdot
.738 .43259 Mdot
.738 .43287 Mdot
.738 .43293 Mdot
.738 .43297 Mdot
.738 .43298 Mdot
.738 .4331 Mdot
.738 .4332 Mdot
.738 .4332 Mdot
.738 .43324 Mdot
.738 .43331 Mdot
.738 .43354 Mdot
.738 .43358 Mdot
.738 .43363 Mdot
.738 .43371 Mdot
.738 .43372 Mdot
.738 .43372 Mdot
.738 .4338 Mdot
.738 .43394 Mdot
.738 .43395 Mdot
.738 .43395 Mdot
.738 .43396 Mdot
.738 .43398 Mdot
.738 .43427 Mdot
.738 .43442 Mdot
.738 .43446 Mdot
.738 .43446 Mdot
.738 .43471 Mdot
.738 .43498 Mdot
.738 .43512 Mdot
.738 .43527 Mdot
.738 .43541 Mdot
.738 .43551 Mdot
.738 .43567 Mdot
.738 .43576 Mdot
.738 .43582 Mdot
.738 .43585 Mdot
.738 .43592 Mdot
.738 .43593 Mdot
.738 .43602 Mdot
.738 .43617 Mdot
.738 .43632 Mdot
.738 .43639 Mdot
.738 .43644 Mdot
.738 .43666 Mdot
.738 .43688 Mdot
.738 .43696 Mdot
.738 .43715 Mdot
.738 .43723 Mdot
.738 .43782 Mdot
.738 .43788 Mdot
.738 .43805 Mdot
.738 .43836 Mdot
.738 .43874 Mdot
.738 .43876 Mdot
.738 .43881 Mdot
.738 .43913 Mdot
.738 .43914 Mdot
.738 .4392 Mdot
.738 .43923 Mdot
.738 .43932 Mdot
.738 .43939 Mdot
.738 .43985 Mdot
.738 .43998 Mdot
.738 .44019 Mdot
.738 .4405 Mdot
.738 .44068 Mdot
.738 .44072 Mdot
.738 .44076 Mdot
.738 .44086 Mdot
.738 .44093 Mdot
.738 .44096 Mdot
.738 .44118 Mdot
.738 .44124 Mdot
.738 .44131 Mdot
.738 .44136 Mdot
.738 .44142 Mdot
.738 .44143 Mdot
.738 .44149 Mdot
.738 .44151 Mdot
.738 .44152 Mdot
.738 .44152 Mdot
.738 .44155 Mdot
.738 .44158 Mdot
.738 .44168 Mdot
.738 .44177 Mdot
.738 .44199 Mdot
.738 .44207 Mdot
.738 .44213 Mdot
.738 .44222 Mdot
.738 .44248 Mdot
.738 .44251 Mdot
.738 .44258 Mdot
.738 .44258 Mdot
.738 .44265 Mdot
.738 .44266 Mdot
.738 .44272 Mdot
.738 .44272 Mdot
.738 .44286 Mdot
.738 .44286 Mdot
.738 .44298 Mdot
.738 .44306 Mdot
.738 .44336 Mdot
.738 .44338 Mdot
.738 .44343 Mdot
.738 .44345 Mdot
.738 .4435 Mdot
.738 .44353 Mdot
.738 .44354 Mdot
.738 .44355 Mdot
.738 .44358 Mdot
.738 .44358 Mdot
.738 .4436 Mdot
.738 .44364 Mdot
.738 .44366 Mdot
.738 .44378 Mdot
.738 .44378 Mdot
.738 .44382 Mdot
.738 .44411 Mdot
.738 .44417 Mdot
.738 .44422 Mdot
.738 .44423 Mdot
.738 .44429 Mdot
.738 .44444 Mdot
.738 .44459 Mdot
.738 .44462 Mdot
.738 .44471 Mdot
.738 .44498 Mdot
.738 .44502 Mdot
.738 .44506 Mdot
.738 .44509 Mdot
.738 .44517 Mdot
.738 .44518 Mdot
.738 .44519 Mdot
.738 .44522 Mdot
.738 .44531 Mdot
.738 .44536 Mdot
.738 .44537 Mdot
.738 .44542 Mdot
.738 .44571 Mdot
.738 .44585 Mdot
.738 .44618 Mdot
.738 .4462 Mdot
.738 .44625 Mdot
.738 .44626 Mdot
.738 .44634 Mdot
.738 .44641 Mdot
.738 .44647 Mdot
.738 .44652 Mdot
.738 .44654 Mdot
.738 .4466 Mdot
.738 .44662 Mdot
.738 .44672 Mdot
.738 .44687 Mdot
.738 .44688 Mdot
.738 .44691 Mdot
.738 .44692 Mdot
.738 .44698 Mdot
.738 .44699 Mdot
.738 .44699 Mdot
.738 .44709 Mdot
.738 .44713 Mdot
.738 .44715 Mdot
.738 .44725 Mdot
.738 .44726 Mdot
.738 .44727 Mdot
.738 .44737 Mdot
.738 .44746 Mdot
.738 .44748 Mdot
.738 .4475 Mdot
.738 .44754 Mdot
.738 .44763 Mdot
.738 .44785 Mdot
.738 .44786 Mdot
.738 .44792 Mdot
.738 .44799 Mdot
.738 .44802 Mdot
.738 .44807 Mdot
.738 .44808 Mdot
.738 .44812 Mdot
.738 .44814 Mdot
.738 .44822 Mdot
.738 .44826 Mdot
.738 .44829 Mdot
.738 .4483 Mdot
.738 .4483 Mdot
.738 .44841 Mdot
.738 .44842 Mdot
.738 .44843 Mdot
.738 .44847 Mdot
.738 .44851 Mdot
.738 .44851 Mdot
.738 .44852 Mdot
.738 .44855 Mdot
.738 .44859 Mdot
.738 .44863 Mdot
.738 .44868 Mdot
.738 .44868 Mdot
.738 .44868 Mdot
.738 .4487 Mdot
.738 .44872 Mdot
.738 .44873 Mdot
.738 .44877 Mdot
.738 .44878 Mdot
.738 .44881 Mdot
.738 .44885 Mdot
.738 .4489 Mdot
.738 .44892 Mdot
.738 .44892 Mdot
.738 .44892 Mdot
.738 .44893 Mdot
.738 .44897 Mdot
.738 .44898 Mdot
.738 .44906 Mdot
.738 .44907 Mdot
.738 .44907 Mdot
.738 .44907 Mdot
.738 .44907 Mdot
.738 .44907 Mdot
.738 .44908 Mdot
.738 .44909 Mdot
.738 .44909 Mdot
.738 .44909 Mdot
.738 .44913 Mdot
.738 .44915 Mdot
.738 .44916 Mdot
.738 .44919 Mdot
.738 .4492 Mdot
.738 .4492 Mdot
.738 .44922 Mdot
.738 .44923 Mdot
.738 .44924 Mdot
.738 .44924 Mdot
.738 .44924 Mdot
.738 .44924 Mdot
.738 .44925 Mdot
.738 .44925 Mdot
.74 .25782 Mdot
.74 .25782 Mdot
.74 .25782 Mdot
.74 .25783 Mdot
.74 .25783 Mdot
.74 .25783 Mdot
.74 .25784 Mdot
.74 .25784 Mdot
.74 .25785 Mdot
.74 .25785 Mdot
.74 .25786 Mdot
.74 .25787 Mdot
.74 .25787 Mdot
.74 .25788 Mdot
.74 .25789 Mdot
.74 .25791 Mdot
.74 .25791 Mdot
.74 .25791 Mdot
.74 .25793 Mdot
.74 .25796 Mdot
.74 .25796 Mdot
.74 .25798 Mdot
.74 .25798 Mdot
.74 .25798 Mdot
.74 .25799 Mdot
.74 .25801 Mdot
.74 .25801 Mdot
.74 .25803 Mdot
.74 .25803 Mdot
.74 .25804 Mdot
.74 .25806 Mdot
.74 .25806 Mdot
.74 .2581 Mdot
.74 .2581 Mdot
.74 .25812 Mdot
.74 .25813 Mdot
.74 .25814 Mdot
.74 .25817 Mdot
.74 .25819 Mdot
.74 .25824 Mdot
.74 .25825 Mdot
.74 .25825 Mdot
.74 .25831 Mdot
.74 .25831 Mdot
.74 .25834 Mdot
.74 .25841 Mdot
.74 .25845 Mdot
.74 .25847 Mdot
.74 .25849 Mdot
.74 .25851 Mdot
.74 .25854 Mdot
.74 .25856 Mdot
.74 .25858 Mdot
.74 .25862 Mdot
.74 .25864 Mdot
.74 .2587 Mdot
.74 .25873 Mdot
.74 .25874 Mdot
.74 .25877 Mdot
.74 .25881 Mdot
.74 .25882 Mdot
.74 .25892 Mdot
.74 .25892 Mdot
.74 .25894 Mdot
.74 .25896 Mdot
.74 .25897 Mdot
.74 .25898 Mdot
.74 .25902 Mdot
.74 .25903 Mdot
.74 .25903 Mdot
.74 .25903 Mdot
.74 .25912 Mdot
.74 .2592 Mdot
.74 .2592 Mdot
.74 .25921 Mdot
.74 .2593 Mdot
.74 .25932 Mdot
.74 .25936 Mdot
.74 .25937 Mdot
.74 .25938 Mdot
.74 .25946 Mdot
.74 .25949 Mdot
.74 .2596 Mdot
.74 .25974 Mdot
.74 .25983 Mdot
.74 .25983 Mdot
.74 .25984 Mdot
.74 .25985 Mdot
.74 .25997 Mdot
.74 .25998 Mdot
.74 .26001 Mdot
.74 .26013 Mdot
.74 .26014 Mdot
.74 .26014 Mdot
.74 .26023 Mdot
.74 .26026 Mdot
.74 .26032 Mdot
.74 .26037 Mdot
.74 .26039 Mdot
.74 .26063 Mdot
.74 .26065 Mdot
.74 .26066 Mdot
.74 .26068 Mdot
.74 .26072 Mdot
.74 .26073 Mdot
.74 .26076 Mdot
.74 .26077 Mdot
.74 .26077 Mdot
.74 .2608 Mdot
.74 .26089 Mdot
.74 .26094 Mdot
.74 .26096 Mdot
.74 .26099 Mdot
.74 .26099 Mdot
.74 .26105 Mdot
.74 .26107 Mdot
.74 .26117 Mdot
.74 .26123 Mdot
.74 .26127 Mdot
.74 .26134 Mdot
.74 .2615 Mdot
.74 .26166 Mdot
.74 .26171 Mdot
.74 .26171 Mdot
.74 .26172 Mdot
.74 .26172 Mdot
.74 .26173 Mdot
.74 .26198 Mdot
.74 .26201 Mdot
.74 .26217 Mdot
.74 .26218 Mdot
.74 .26226 Mdot
.74 .26227 Mdot
.74 .2624 Mdot
.74 .26245 Mdot
.74 .26266 Mdot
.74 .26281 Mdot
.74 .26281 Mdot
.74 .26286 Mdot
.74 .2629 Mdot
.74 .263 Mdot
.74 .26301 Mdot
.74 .26305 Mdot
.74 .26311 Mdot
.74 .26313 Mdot
.74 .26318 Mdot
.74 .26319 Mdot
.74 .26326 Mdot
.74 .26331 Mdot
.74 .26332 Mdot
.74 .26336 Mdot
.74 .26349 Mdot
.74 .26357 Mdot
.74 .26406 Mdot
.74 .26459 Mdot
.74 .26461 Mdot
.74 .26503 Mdot
.74 .26538 Mdot
.74 .26575 Mdot
.74 .26605 Mdot
.74 .26662 Mdot
.74 .26702 Mdot
.74 .26731 Mdot
.74 .26741 Mdot
.74 .26753 Mdot
.74 .26834 Mdot
.74 .26882 Mdot
.74 .26889 Mdot
.74 .269 Mdot
.74 .26908 Mdot
.74 .26914 Mdot
.74 .26929 Mdot
.74 .26933 Mdot
.74 .2695 Mdot
.74 .26953 Mdot
.74 .26953 Mdot
.74 .26982 Mdot
.74 .26995 Mdot
.74 .26996 Mdot
.74 .27017 Mdot
.74 .27046 Mdot
.74 .27076 Mdot
.74 .27112 Mdot
.74 .27126 Mdot
.74 .27127 Mdot
.74 .27139 Mdot
.74 .27144 Mdot
.74 .27147 Mdot
.74 .27166 Mdot
.74 .27196 Mdot
.74 .27201 Mdot
.74 .27216 Mdot
.74 .27324 Mdot
.74 .27406 Mdot
.74 .2741 Mdot
.74 .27461 Mdot
.74 .27502 Mdot
.74 .27503 Mdot
.74 .27558 Mdot
.74 .27566 Mdot
.74 .27581 Mdot
.74 .27584 Mdot
.74 .27585 Mdot
.74 .27588 Mdot
.74 .27596 Mdot
.74 .276 Mdot
.74 .27651 Mdot
.74 .2767 Mdot
.74 .2767 Mdot
.74 .27687 Mdot
.74 .27752 Mdot
.74 .27753 Mdot
.74 .27755 Mdot
.74 .27778 Mdot
.74 .2778 Mdot
.74 .27809 Mdot
.74 .27821 Mdot
.74 .27828 Mdot
.74 .27851 Mdot
.74 .27863 Mdot
.74 .27872 Mdot
.74 .27906 Mdot
.74 .2806 Mdot
.74 .2807 Mdot
.74 .28089 Mdot
.74 .28104 Mdot
.74 .28113 Mdot
.74 .2813 Mdot
.74 .28147 Mdot
.74 .28181 Mdot
.74 .28229 Mdot
.74 .28367 Mdot
.74 .28382 Mdot
.74 .28416 Mdot
.74 .28436 Mdot
.74 .28448 Mdot
.74 .28508 Mdot
.74 .28562 Mdot
.74 .28568 Mdot
.74 .28594 Mdot
.74 .28601 Mdot
.74 .28611 Mdot
.74 .28667 Mdot
.74 .28675 Mdot
.74 .28701 Mdot
.74 .28723 Mdot
.74 .28724 Mdot
.74 .28735 Mdot
.74 .28759 Mdot
.74 .28821 Mdot
.74 .28905 Mdot
.74 .28921 Mdot
.74 .28974 Mdot
.74 .2905 Mdot
.74 .29065 Mdot
.74 .29182 Mdot
.74 .29207 Mdot
.74 .29212 Mdot
.74 .29228 Mdot
.74 .29239 Mdot
.74 .29296 Mdot
.74 .29397 Mdot
.74 .29405 Mdot
.74 .29424 Mdot
.74 .29453 Mdot
.74 .29535 Mdot
.74 .29564 Mdot
.74 .29587 Mdot
.74 .29612 Mdot
.74 .29665 Mdot
.74 .29705 Mdot
.74 .29787 Mdot
.74 .29811 Mdot
.74 .29813 Mdot
.74 .29823 Mdot
.74 .29838 Mdot
.74 .29844 Mdot
.74 .29855 Mdot
.74 .29869 Mdot
.74 .29883 Mdot
.74 .29907 Mdot
.74 .29907 Mdot
.74 .29915 Mdot
.74 .29939 Mdot
.74 .30071 Mdot
.74 .30071 Mdot
.74 .30105 Mdot
.74 .30106 Mdot
.74 .3011 Mdot
.74 .30131 Mdot
.74 .30171 Mdot
.74 .30172 Mdot
.74 .30181 Mdot
.74 .30193 Mdot
.74 .302 Mdot
.74 .30209 Mdot
.74 .30213 Mdot
.74 .30287 Mdot
.74 .30303 Mdot
.74 .30313 Mdot
.74 .30331 Mdot
.74 .30348 Mdot
.74 .30398 Mdot
.74 .30403 Mdot
.74 .30422 Mdot
.74 .30427 Mdot
.74 .30467 Mdot
.74 .30469 Mdot
.74 .30478 Mdot
.74 .30504 Mdot
.74 .30516 Mdot
.74 .30524 Mdot
.74 .30536 Mdot
.74 .30637 Mdot
.74 .30642 Mdot
.74 .307 Mdot
.74 .30703 Mdot
.74 .30724 Mdot
.74 .30759 Mdot
.74 .30762 Mdot
.74 .30769 Mdot
.74 .30779 Mdot
.74 .30809 Mdot
.74 .30871 Mdot
.74 .3091 Mdot
.74 .30915 Mdot
.74 .3092 Mdot
.74 .30927 Mdot
.74 .30938 Mdot
.74 .30947 Mdot
.74 .30947 Mdot
.74 .3095 Mdot
.74 .31011 Mdot
.74 .31025 Mdot
.74 .31035 Mdot
.74 .31064 Mdot
.74 .31111 Mdot
.74 .31127 Mdot
.74 .31151 Mdot
.74 .3116 Mdot
.74 .31162 Mdot
.74 .31181 Mdot
.74 .31186 Mdot
.74 .31198 Mdot
.74 .31203 Mdot
.74 .31213 Mdot
.74 .31264 Mdot
.74 .31731 Mdot
.74 .31806 Mdot
.74 .31944 Mdot
.74 .31978 Mdot
.74 .3199 Mdot
.74 .32038 Mdot
.74 .32116 Mdot
.74 .32127 Mdot
.74 .3217 Mdot
.74 .32195 Mdot
.74 .32253 Mdot
.74 .32296 Mdot
.74 .32307 Mdot
.74 .32406 Mdot
.74 .32458 Mdot
.74 .32507 Mdot
.74 .32511 Mdot
.74 .3267 Mdot
.74 .32891 Mdot
.74 .32942 Mdot
.74 .33092 Mdot
.74 .33093 Mdot
.74 .33187 Mdot
.74 .33201 Mdot
.74 .33371 Mdot
.74 .33411 Mdot
.74 .33697 Mdot
.74 .33701 Mdot
.74 .33708 Mdot
.74 .33714 Mdot
.74 .33714 Mdot
.74 .33778 Mdot
.74 .33952 Mdot
.74 .34137 Mdot
.74 .34226 Mdot
.74 .34275 Mdot
.74 .34342 Mdot
.74 .34459 Mdot
.74 .34489 Mdot
.74 .3455 Mdot
.74 .34556 Mdot
.74 .34587 Mdot
.74 .34619 Mdot
.74 .34678 Mdot
.74 .34778 Mdot
.74 .34817 Mdot
.74 .34818 Mdot
.74 .34834 Mdot
.74 .34861 Mdot
.74 .34875 Mdot
.74 .34927 Mdot
.74 .34953 Mdot
.74 .34963 Mdot
.74 .34984 Mdot
.74 .35275 Mdot
.74 .35299 Mdot
.74 .35362 Mdot
.74 .35438 Mdot
.74 .3547 Mdot
.74 .35579 Mdot
.74 .35588 Mdot
.74 .35595 Mdot
.74 .35747 Mdot
.74 .35789 Mdot
.74 .35792 Mdot
.74 .35945 Mdot
.74 .3596 Mdot
.74 .35969 Mdot
.74 .35973 Mdot
.74 .36085 Mdot
.74 .36255 Mdot
.74 .3639 Mdot
.74 .36427 Mdot
.74 .36537 Mdot
.74 .36546 Mdot
.74 .3656 Mdot
.74 .36611 Mdot
.74 .36636 Mdot
.74 .3674 Mdot
.74 .36758 Mdot
.74 .36762 Mdot
.74 .36858 Mdot
.74 .36966 Mdot
.74 .36968 Mdot
.74 .36976 Mdot
.74 .3699 Mdot
.74 .37033 Mdot
.74 .37044 Mdot
.74 .3706 Mdot
.74 .37088 Mdot
.74 .37108 Mdot
.74 .37114 Mdot
.74 .37237 Mdot
.74 .37253 Mdot
.74 .37304 Mdot
.74 .37337 Mdot
.74 .37356 Mdot
.74 .37392 Mdot
.74 .37468 Mdot
.74 .37491 Mdot
.74 .37537 Mdot
.74 .37567 Mdot
.74 .37592 Mdot
.74 .37626 Mdot
.74 .3766 Mdot
.74 .37674 Mdot
.74 .37701 Mdot
.74 .3775 Mdot
.74 .37838 Mdot
.74 .37875 Mdot
.74 .37879 Mdot
.74 .37954 Mdot
.74 .37961 Mdot
.74 .37974 Mdot
.74 .38031 Mdot
.74 .38055 Mdot
.74 .38092 Mdot
.74 .38105 Mdot
.74 .38125 Mdot
.74 .38147 Mdot
.74 .38152 Mdot
.74 .38197 Mdot
.74 .382 Mdot
.74 .3822 Mdot
.74 .38235 Mdot
.74 .38236 Mdot
.74 .38256 Mdot
.74 .38262 Mdot
.74 .38288 Mdot
.74 .38291 Mdot
.74 .38298 Mdot
.74 .38302 Mdot
.74 .38322 Mdot
.74 .38323 Mdot
.74 .38354 Mdot
.74 .38379 Mdot
.74 .38384 Mdot
.74 .38384 Mdot
.74 .38403 Mdot
.74 .38418 Mdot
.74 .38434 Mdot
.74 .38437 Mdot
.74 .38451 Mdot
.74 .3846 Mdot
.74 .38464 Mdot
.74 .38473 Mdot
.74 .38473 Mdot
.74 .38483 Mdot
.74 .38484 Mdot
.74 .38489 Mdot
.74 .38492 Mdot
.74 .38492 Mdot
.74 .38494 Mdot
.74 .4073 Mdot
.74 .40731 Mdot
.74 .40731 Mdot
.74 .40732 Mdot
.74 .40733 Mdot
.74 .40733 Mdot
.74 .40736 Mdot
.74 .40736 Mdot
.74 .40738 Mdot
.74 .40739 Mdot
.74 .40742 Mdot
.74 .40745 Mdot
.74 .40746 Mdot
.74 .4075 Mdot
.74 .40754 Mdot
.74 .40759 Mdot
.74 .40759 Mdot
.74 .40761 Mdot
.74 .40767 Mdot
.74 .40775 Mdot
.74 .40775 Mdot
.74 .40781 Mdot
.74 .40782 Mdot
.74 .40784 Mdot
.74 .40784 Mdot
.74 .40791 Mdot
.74 .40793 Mdot
.74 .40798 Mdot
.74 .40798 Mdot
.74 .40802 Mdot
.74 .40807 Mdot
.74 .40808 Mdot
.74 .4082 Mdot
.74 .40821 Mdot
.74 .40827 Mdot
.74 .40832 Mdot
.74 .40835 Mdot
.74 .40845 Mdot
.74 .40851 Mdot
.74 .40866 Mdot
.74 .40869 Mdot
.74 .40871 Mdot
.74 .40891 Mdot
.74 .40891 Mdot
.74 .40901 Mdot
.74 .40924 Mdot
.74 .40936 Mdot
.74 .40943 Mdot
.74 .40947 Mdot
.74 .40955 Mdot
.74 .40964 Mdot
.74 .4097 Mdot
.74 .40978 Mdot
.74 .4099 Mdot
.74 .40996 Mdot
.74 .41015 Mdot
.74 .41024 Mdot
.74 .41029 Mdot
.74 .41037 Mdot
.74 .4105 Mdot
.74 .41054 Mdot
.74 .41085 Mdot
.74 .41087 Mdot
.74 .41092 Mdot
.74 .41099 Mdot
.74 .41103 Mdot
.74 .41106 Mdot
.74 .41117 Mdot
.74 .4112 Mdot
.74 .41122 Mdot
.74 .41123 Mdot
.74 .4115 Mdot
.74 .41174 Mdot
.74 .41175 Mdot
.74 .41179 Mdot
.74 .41205 Mdot
.74 .41212 Mdot
.74 .41224 Mdot
.74 .41228 Mdot
.74 .4123 Mdot
.74 .41258 Mdot
.74 .41267 Mdot
.74 .413 Mdot
.74 .41343 Mdot
.74 .4137 Mdot
.74 .41371 Mdot
.74 .41374 Mdot
.74 .41378 Mdot
.74 .41415 Mdot
.74 .41416 Mdot
.74 .41427 Mdot
.74 .41464 Mdot
.74 .41466 Mdot
.74 .41468 Mdot
.74 .41495 Mdot
.74 .41503 Mdot
.74 .41522 Mdot
.74 .41538 Mdot
.74 .41544 Mdot
.74 .41616 Mdot
.74 .41621 Mdot
.74 .41623 Mdot
.74 .4163 Mdot
.74 .41643 Mdot
.74 .41646 Mdot
.74 .41653 Mdot
.74 .41657 Mdot
.74 .41657 Mdot
.74 .41667 Mdot
.74 .41691 Mdot
.74 .41706 Mdot
.74 .41714 Mdot
.74 .41722 Mdot
.74 .41723 Mdot
.74 .41739 Mdot
.74 .41746 Mdot
.74 .41775 Mdot
.74 .41792 Mdot
.74 .41804 Mdot
.74 .41826 Mdot
.74 .41873 Mdot
.74 .41916 Mdot
.74 .41932 Mdot
.74 .41932 Mdot
.74 .41934 Mdot
.74 .41936 Mdot
.74 .41937 Mdot
.74 .42009 Mdot
.74 .42019 Mdot
.74 .42062 Mdot
.74 .42066 Mdot
.74 .4209 Mdot
.74 .4209 Mdot
.74 .42128 Mdot
.74 .42141 Mdot
.74 .42198 Mdot
.74 .4224 Mdot
.74 .42241 Mdot
.74 .42253 Mdot
.74 .42267 Mdot
.74 .42293 Mdot
.74 .42296 Mdot
.74 .42307 Mdot
.74 .42322 Mdot
.74 .42329 Mdot
.74 .4234 Mdot
.74 .42343 Mdot
.74 .42364 Mdot
.74 .42377 Mdot
.74 .4238 Mdot
.74 .42389 Mdot
.74 .42426 Mdot
.74 .42446 Mdot
.74 .42573 Mdot
.74 .42587 Mdot
.74 .4259 Mdot
.74 .42591 Mdot
.74 .42595 Mdot
.74 .42596 Mdot
.74 .42601 Mdot
.74 .42602 Mdot
.74 .42604 Mdot
.74 .42611 Mdot
.74 .42615 Mdot
.74 .42629 Mdot
.74 .42636 Mdot
.74 .42639 Mdot
.74 .42643 Mdot
.74 .4266 Mdot
.74 .42661 Mdot
.74 .42661 Mdot
.74 .42664 Mdot
.74 .42667 Mdot
.74 .42669 Mdot
.74 .4267 Mdot
.74 .42672 Mdot
.74 .42683 Mdot
.74 .427 Mdot
.74 .42709 Mdot
.74 .42712 Mdot
.74 .42713 Mdot
.74 .42714 Mdot
.74 .42725 Mdot
.74 .4273 Mdot
.74 .42731 Mdot
.74 .42748 Mdot
.74 .42749 Mdot
.74 .42778 Mdot
.74 .42782 Mdot
.74 .42784 Mdot
.74 .42788 Mdot
.74 .42795 Mdot
.74 .42798 Mdot
.74 .42798 Mdot
.74 .4281 Mdot
.74 .42811 Mdot
.74 .42817 Mdot
.74 .42819 Mdot
.74 .42833 Mdot
.74 .42838 Mdot
.74 .42844 Mdot
.74 .42846 Mdot
.74 .42851 Mdot
.74 .42873 Mdot
.74 .42874 Mdot
.74 .42877 Mdot
.74 .42879 Mdot
.74 .42883 Mdot
.74 .42885 Mdot
.74 .42886 Mdot
.74 .42897 Mdot
.74 .42904 Mdot
.74 .42905 Mdot
.74 .42905 Mdot
.74 .42915 Mdot
.74 .42916 Mdot
.74 .42955 Mdot
.74 .42963 Mdot
.74 .42965 Mdot
.74 .42965 Mdot
.74 .42972 Mdot
.74 .42977 Mdot
.74 .42981 Mdot
.74 .42984 Mdot
.74 .42986 Mdot
.74 .42991 Mdot
.74 .42994 Mdot
.74 .42995 Mdot
.74 .43002 Mdot
.74 .43027 Mdot
.74 .4304 Mdot
.74 .43056 Mdot
.74 .43064 Mdot
.74 .43071 Mdot
.74 .4308 Mdot
.74 .43107 Mdot
.74 .43116 Mdot
.74 .43122 Mdot
.74 .43124 Mdot
.74 .43157 Mdot
.74 .43176 Mdot
.74 .43179 Mdot
.74 .43184 Mdot
.74 .43186 Mdot
.74 .43195 Mdot
.74 .43233 Mdot
.74 .43238 Mdot
.74 .43264 Mdot
.74 .43282 Mdot
.74 .43287 Mdot
.74 .43316 Mdot
.74 .43338 Mdot
.74 .43346 Mdot
.74 .4335 Mdot
.74 .4335 Mdot
.74 .43358 Mdot
.74 .43367 Mdot
.74 .4337 Mdot
.74 .4339 Mdot
.74 .43393 Mdot
.74 .43396 Mdot
.74 .43405 Mdot
.74 .43407 Mdot
.74 .43427 Mdot
.74 .43448 Mdot
.74 .43453 Mdot
.74 .4346 Mdot
.74 .43473 Mdot
.74 .43478 Mdot
.74 .4353 Mdot
.74 .43548 Mdot
.74 .43561 Mdot
.74 .43568 Mdot
.74 .43574 Mdot
.74 .43578 Mdot
.74 .43584 Mdot
.74 .43591 Mdot
.74 .43595 Mdot
.74 .43656 Mdot
.74 .4367 Mdot
.74 .43673 Mdot
.74 .43678 Mdot
.74 .43688 Mdot
.74 .43691 Mdot
.74 .43695 Mdot
.74 .43707 Mdot
.74 .43708 Mdot
.74 .43718 Mdot
.74 .43719 Mdot
.74 .43719 Mdot
.74 .43746 Mdot
.74 .43754 Mdot
.74 .43754 Mdot
.74 .43762 Mdot
.74 .43784 Mdot
.74 .43786 Mdot
.74 .43789 Mdot
.74 .4379 Mdot
.74 .43791 Mdot
.74 .43792 Mdot
.74 .43799 Mdot
.74 .43802 Mdot
.74 .43826 Mdot
.74 .43827 Mdot
.74 .43845 Mdot
.74 .43868 Mdot
.74 .4387 Mdot
.74 .43907 Mdot
.74 .43959 Mdot
.74 .43966 Mdot
.74 .43968 Mdot
.74 .43983 Mdot
.74 .43992 Mdot
.74 .43994 Mdot
.74 .43996 Mdot
.74 .44002 Mdot
.74 .44003 Mdot
.74 .4401 Mdot
.74 .44028 Mdot
.74 .44043 Mdot
.74 .44058 Mdot
.74 .44069 Mdot
.74 .44069 Mdot
.74 .44076 Mdot
.74 .44091 Mdot
.74 .44091 Mdot
.74 .44093 Mdot
.74 .44102 Mdot
.74 .44104 Mdot
.74 .44112 Mdot
.74 .44115 Mdot
.74 .4412 Mdot
.74 .44126 Mdot
.74 .44129 Mdot
.74 .44156 Mdot
.74 .44201 Mdot
.74 .44208 Mdot
.74 .44214 Mdot
.74 .44231 Mdot
.74 .44255 Mdot
.74 .44289 Mdot
.74 .44308 Mdot
.74 .44332 Mdot
.74 .44354 Mdot
.74 .44382 Mdot
.74 .44384 Mdot
.74 .4442 Mdot
.74 .44455 Mdot
.74 .4446 Mdot
.74 .4447 Mdot
.74 .44473 Mdot
.74 .44474 Mdot
.74 .44477 Mdot
.74 .44483 Mdot
.74 .44484 Mdot
.74 .44487 Mdot
.74 .44489 Mdot
.74 .44493 Mdot
.74 .44496 Mdot
.74 .44497 Mdot
.74 .44504 Mdot
.74 .44508 Mdot
.74 .44511 Mdot
.74 .44512 Mdot
.74 .44523 Mdot
.74 .44539 Mdot
.74 .44543 Mdot
.74 .44554 Mdot
.74 .44554 Mdot
.74 .44561 Mdot
.74 .44562 Mdot
.74 .44574 Mdot
.74 .44577 Mdot
.74 .44598 Mdot
.74 .44599 Mdot
.74 .44599 Mdot
.74 .446 Mdot
.74 .446 Mdot
.74 .44604 Mdot
.74 .44617 Mdot
.74 .44631 Mdot
.74 .44638 Mdot
.74 .44641 Mdot
.74 .44647 Mdot
.74 .44656 Mdot
.74 .44658 Mdot
.74 .44663 Mdot
.74 .44663 Mdot
.74 .44665 Mdot
.74 .44668 Mdot
.74 .44672 Mdot
.74 .4468 Mdot
.74 .44683 Mdot
.74 .44683 Mdot
.74 .44684 Mdot
.74 .44687 Mdot
.74 .44688 Mdot
.74 .44692 Mdot
.74 .44694 Mdot
.74 .44695 Mdot
.74 .44696 Mdot
.74 .44698 Mdot
.74 .44719 Mdot
.74 .44721 Mdot
.74 .44727 Mdot
.74 .44733 Mdot
.74 .44735 Mdot
.74 .44744 Mdot
.74 .44745 Mdot
.74 .44746 Mdot
.74 .44758 Mdot
.74 .44762 Mdot
.74 .44762 Mdot
.74 .44775 Mdot
.74 .44776 Mdot
.74 .44777 Mdot
.74 .44778 Mdot
.74 .44787 Mdot
.74 .44802 Mdot
.74 .44814 Mdot
.74 .44817 Mdot
.74 .44827 Mdot
.74 .44828 Mdot
.74 .4483 Mdot
.74 .44834 Mdot
.74 .44837 Mdot
.74 .44846 Mdot
.74 .44848 Mdot
.74 .44848 Mdot
.74 .44858 Mdot
.74 .44868 Mdot
.74 .44868 Mdot
.74 .44869 Mdot
.74 .4487 Mdot
.74 .44875 Mdot
.74 .44876 Mdot
.74 .44877 Mdot
.74 .4488 Mdot
.74 .44882 Mdot
.74 .44883 Mdot
.74 .44895 Mdot
.74 .44897 Mdot
.74 .44902 Mdot
.74 .44906 Mdot
.74 .44907 Mdot
.74 .44911 Mdot
.74 .44919 Mdot
.74 .44922 Mdot
.74 .44927 Mdot
.74 .4493 Mdot
.74 .44933 Mdot
.74 .44936 Mdot
.74 .4494 Mdot
.74 .44942 Mdot
.74 .44945 Mdot
.74 .4495 Mdot
.74 .4496 Mdot
.74 .44964 Mdot
.74 .44965 Mdot
.74 .44974 Mdot
.74 .44975 Mdot
.74 .44976 Mdot
.74 .44983 Mdot
.74 .44986 Mdot
.74 .4499 Mdot
.74 .44992 Mdot
.74 .44994 Mdot
.74 .44997 Mdot
.74 .44998 Mdot
.74 .45003 Mdot
.74 .45004 Mdot
.74 .45006 Mdot
.74 .45008 Mdot
.74 .45008 Mdot
.74 .45011 Mdot
.74 .45012 Mdot
.74 .45015 Mdot
.74 .45015 Mdot
.74 .45016 Mdot
.74 .45017 Mdot
.74 .4502 Mdot
.74 .4502 Mdot
.74 .45024 Mdot
.74 .45027 Mdot
.74 .45028 Mdot
.74 .45028 Mdot
.74 .4503 Mdot
.74 .45032 Mdot
.74 .45034 Mdot
.74 .45035 Mdot
.74 .45037 Mdot
.74 .45038 Mdot
.74 .45038 Mdot
.74 .4504 Mdot
.74 .4504 Mdot
.74 .45041 Mdot
.74 .45041 Mdot
.74 .45042 Mdot
.74 .45042 Mdot
.74 .45042 Mdot
.74 .45043 Mdot
.742 .25789 Mdot
.742 .25789 Mdot
.742 .25789 Mdot
.742 .25789 Mdot
.742 .25789 Mdot
.742 .25789 Mdot
.742 .25789 Mdot
.742 .2579 Mdot
.742 .2579 Mdot
.742 .2579 Mdot
.742 .2579 Mdot
.742 .2579 Mdot
.742 .2579 Mdot
.742 .2579 Mdot
.742 .2579 Mdot
.742 .25791 Mdot
.742 .25791 Mdot
.742 .25791 Mdot
.742 .25791 Mdot
.742 .25791 Mdot
.742 .25792 Mdot
.742 .25792 Mdot
.742 .25792 Mdot
.742 .25792 Mdot
.742 .25793 Mdot
.742 .25793 Mdot
.742 .25794 Mdot
.742 .25794 Mdot
.742 .25794 Mdot
.742 .25795 Mdot
.742 .25795 Mdot
.742 .25796 Mdot
.742 .25796 Mdot
.742 .25796 Mdot
.742 .25796 Mdot
.742 .25796 Mdot
.742 .25796 Mdot
.742 .25798 Mdot
.742 .25798 Mdot
.742 .25798 Mdot
.742 .25798 Mdot
.742 .25799 Mdot
.742 .25799 Mdot
.742 .25799 Mdot
.742 .258 Mdot
.742 .258 Mdot
.742 .258 Mdot
.742 .258 Mdot
.742 .25801 Mdot
.742 .25803 Mdot
.742 .25804 Mdot
.742 .25805 Mdot
.742 .25805 Mdot
.742 .25806 Mdot
.742 .25807 Mdot
.742 .25807 Mdot
.742 .25807 Mdot
.742 .25807 Mdot
.742 .25807 Mdot
.742 .25808 Mdot
.742 .25808 Mdot
.742 .2581 Mdot
.742 .2581 Mdot
.742 .2581 Mdot
.742 .2581 Mdot
.742 .25811 Mdot
.742 .25812 Mdot
.742 .25812 Mdot
.742 .25812 Mdot
.742 .25812 Mdot
.742 .25812 Mdot
.742 .25812 Mdot
.742 .25813 Mdot
.742 .25813 Mdot
.742 .25814 Mdot
.742 .25814 Mdot
.742 .25816 Mdot
.742 .25817 Mdot
.742 .25817 Mdot
.742 .25817 Mdot
.742 .25817 Mdot
.742 .25818 Mdot
.742 .25818 Mdot
.742 .25818 Mdot
.742 .25819 Mdot
.742 .25819 Mdot
.742 .25819 Mdot
.742 .2582 Mdot
.742 .2582 Mdot
.742 .2582 Mdot
.742 .25821 Mdot
.742 .25821 Mdot
.742 .25823 Mdot
.742 .25824 Mdot
.742 .25826 Mdot
.742 .25826 Mdot
.742 .25827 Mdot
.742 .2583 Mdot
.742 .25833 Mdot
.742 .25837 Mdot
.742 .25838 Mdot
.742 .25839 Mdot
.742 .2584 Mdot
.742 .25841 Mdot
.742 .25841 Mdot
.742 .25841 Mdot
.742 .25842 Mdot
.742 .25842 Mdot
.742 .25843 Mdot
.742 .25843 Mdot
.742 .25844 Mdot
.742 .25848 Mdot
.742 .25849 Mdot
.742 .25849 Mdot
.742 .25849 Mdot
.742 .25854 Mdot
.742 .25855 Mdot
.742 .25855 Mdot
.742 .25856 Mdot
.742 .25856 Mdot
.742 .25857 Mdot
.742 .25857 Mdot
.742 .25857 Mdot
.742 .25858 Mdot
.742 .25858 Mdot
.742 .2586 Mdot
.742 .2586 Mdot
.742 .25861 Mdot
.742 .25866 Mdot
.742 .25866 Mdot
.742 .25867 Mdot
.742 .25871 Mdot
.742 .25871 Mdot
.742 .25872 Mdot
.742 .25872 Mdot
.742 .25875 Mdot
.742 .25876 Mdot
.742 .25877 Mdot
.742 .25877 Mdot
.742 .25879 Mdot
.742 .2588 Mdot
.742 .25881 Mdot
.742 .25881 Mdot
.742 .25882 Mdot
.742 .25883 Mdot
.742 .25883 Mdot
.742 .25883 Mdot
.742 .25886 Mdot
.742 .25886 Mdot
.742 .25886 Mdot
.742 .25888 Mdot
.742 .25888 Mdot
.742 .25889 Mdot
.742 .2589 Mdot
.742 .2589 Mdot
.742 .25891 Mdot
.742 .25892 Mdot
.742 .25894 Mdot
.742 .25894 Mdot
.742 .25895 Mdot
.742 .25895 Mdot
.742 .25896 Mdot
.742 .25897 Mdot
.742 .25897 Mdot
.742 .259 Mdot
.742 .25901 Mdot
.742 .25903 Mdot
.742 .25905 Mdot
.742 .25906 Mdot
.742 .2591 Mdot
.742 .25912 Mdot
.742 .25914 Mdot
.742 .25914 Mdot
.742 .25927 Mdot
.742 .2593 Mdot
.742 .25932 Mdot
.742 .25943 Mdot
.742 .25946 Mdot
.742 .25948 Mdot
.742 .25954 Mdot
.742 .25954 Mdot
.742 .25956 Mdot
.742 .25967 Mdot
.742 .25975 Mdot
.742 .25986 Mdot
.742 .2599 Mdot
.742 .25991 Mdot
.742 .25992 Mdot
.742 .25998 Mdot
.742 .25998 Mdot
.742 .26003 Mdot
.742 .2601 Mdot
.742 .2601 Mdot
.742 .26042 Mdot
.742 .26053 Mdot
.742 .26071 Mdot
.742 .26082 Mdot
.742 .26085 Mdot
.742 .26087 Mdot
.742 .26102 Mdot
.742 .26142 Mdot
.742 .26147 Mdot
.742 .26163 Mdot
.742 .26167 Mdot
.742 .26191 Mdot
.742 .26195 Mdot
.742 .26199 Mdot
.742 .26213 Mdot
.742 .26251 Mdot
.742 .26392 Mdot
.742 .2642 Mdot
.742 .26442 Mdot
.742 .26451 Mdot
.742 .26469 Mdot
.742 .26471 Mdot
.742 .26524 Mdot
.742 .26629 Mdot
.742 .26698 Mdot
.742 .26761 Mdot
.742 .26762 Mdot
.742 .26763 Mdot
.742 .26807 Mdot
.742 .26935 Mdot
.742 .26939 Mdot
.742 .26945 Mdot
.742 .26986 Mdot
.742 .26993 Mdot
.742 .2702 Mdot
.742 .27084 Mdot
.742 .27144 Mdot
.742 .27144 Mdot
.742 .27242 Mdot
.742 .27269 Mdot
.742 .27277 Mdot
.742 .27293 Mdot
.742 .2742 Mdot
.742 .27429 Mdot
.742 .27454 Mdot
.742 .2747 Mdot
.742 .27528 Mdot
.742 .27761 Mdot
.742 .27885 Mdot
.742 .28011 Mdot
.742 .2804 Mdot
.742 .2805 Mdot
.742 .28066 Mdot
.742 .281 Mdot
.742 .28271 Mdot
.742 .28275 Mdot
.742 .28305 Mdot
.742 .28313 Mdot
.742 .2832 Mdot
.742 .28353 Mdot
.742 .2843 Mdot
.742 .28442 Mdot
.742 .28519 Mdot
.742 .28524 Mdot
.742 .28677 Mdot
.742 .28677 Mdot
.742 .28691 Mdot
.742 .28728 Mdot
.742 .28757 Mdot
.742 .28785 Mdot
.742 .28888 Mdot
.742 .28964 Mdot
.742 .28994 Mdot
.742 .29077 Mdot
.742 .2913 Mdot
.742 .29148 Mdot
.742 .29267 Mdot
.742 .2944 Mdot
.742 .29717 Mdot
.742 .29917 Mdot
.742 .29931 Mdot
.742 .29962 Mdot
.742 .2999 Mdot
.742 .30051 Mdot
.742 .30113 Mdot
.742 .30364 Mdot
.742 .30383 Mdot
.742 .30477 Mdot
.742 .30509 Mdot
.742 .30538 Mdot
.742 .30614 Mdot
.742 .30624 Mdot
.742 .30672 Mdot
.742 .3071 Mdot
.742 .30741 Mdot
.742 .30811 Mdot
.742 .30876 Mdot
.742 .31068 Mdot
.742 .32485 Mdot
.742 .32903 Mdot
.742 .3305 Mdot
.742 .33097 Mdot
.742 .33142 Mdot
.742 .33411 Mdot
.742 .33458 Mdot
.742 .33638 Mdot
.742 .33707 Mdot
.742 .34166 Mdot
.742 .3435 Mdot
.742 .34377 Mdot
.742 .34409 Mdot
.742 .34541 Mdot
.742 .34759 Mdot
.742 .34901 Mdot
.742 .35291 Mdot
.742 .35291 Mdot
.742 .35381 Mdot
.742 .35437 Mdot
.742 .35439 Mdot
.742 .35525 Mdot
.742 .35536 Mdot
.742 .35585 Mdot
.742 .35633 Mdot
.742 .35727 Mdot
.742 .35828 Mdot
.742 .35972 Mdot
.742 .35993 Mdot
.742 .35996 Mdot
.742 .36065 Mdot
.742 .36091 Mdot
.742 .36127 Mdot
.742 .36272 Mdot
.742 .36292 Mdot
.742 .36329 Mdot
.742 .36498 Mdot
.742 .36502 Mdot
.742 .3653 Mdot
.742 .36553 Mdot
.742 .36598 Mdot
.742 .36616 Mdot
.742 .36636 Mdot
.742 .36659 Mdot
.742 .36674 Mdot
.742 .36719 Mdot
.742 .36719 Mdot
.742 .3673 Mdot
.742 .36737 Mdot
.742 .36747 Mdot
.742 .36748 Mdot
.742 .3675 Mdot
.742 .36774 Mdot
.742 .36788 Mdot
.742 .36811 Mdot
.742 .36812 Mdot
.742 .36822 Mdot
.742 .36826 Mdot
.742 .36831 Mdot
.742 .36853 Mdot
.742 .36856 Mdot
.742 .36862 Mdot
.742 .36891 Mdot
.742 .36896 Mdot
.742 .369 Mdot
.742 .36911 Mdot
.742 .36915 Mdot
.742 .36919 Mdot
.742 .36936 Mdot
.742 .36944 Mdot
.742 .36966 Mdot
.742 .36969 Mdot
.742 .36981 Mdot
.742 .36996 Mdot
.742 .37036 Mdot
.742 .37037 Mdot
.742 .37045 Mdot
.742 .37047 Mdot
.742 .37098 Mdot
.742 .37109 Mdot
.742 .37114 Mdot
.742 .37175 Mdot
.742 .37184 Mdot
.742 .37195 Mdot
.742 .3721 Mdot
.742 .37213 Mdot
.742 .37227 Mdot
.742 .37229 Mdot
.742 .37234 Mdot
.742 .37238 Mdot
.742 .37244 Mdot
.742 .3725 Mdot
.742 .37252 Mdot
.742 .37267 Mdot
.742 .37325 Mdot
.742 .37326 Mdot
.742 .37334 Mdot
.742 .37347 Mdot
.742 .3739 Mdot
.742 .37404 Mdot
.742 .37407 Mdot
.742 .3742 Mdot
.742 .37424 Mdot
.742 .37431 Mdot
.742 .37436 Mdot
.742 .37438 Mdot
.742 .37442 Mdot
.742 .37463 Mdot
.742 .3747 Mdot
.742 .37486 Mdot
.742 .37533 Mdot
.742 .3758 Mdot
.742 .37616 Mdot
.742 .37626 Mdot
.742 .37628 Mdot
.742 .3765 Mdot
.742 .37663 Mdot
.742 .37686 Mdot
.742 .37688 Mdot
.742 .37701 Mdot
.742 .37703 Mdot
.742 .37705 Mdot
.742 .37712 Mdot
.742 .37713 Mdot
.742 .37714 Mdot
.742 .3773 Mdot
.742 .37732 Mdot
.742 .37734 Mdot
.742 .37744 Mdot
.742 .37745 Mdot
.742 .37747 Mdot
.742 .37748 Mdot
.742 .37755 Mdot
.742 .37776 Mdot
.742 .37785 Mdot
.742 .3779 Mdot
.742 .37797 Mdot
.742 .37799 Mdot
.742 .378 Mdot
.742 .37802 Mdot
.742 .37805 Mdot
.742 .37806 Mdot
.742 .37809 Mdot
.742 .37821 Mdot
.742 .37833 Mdot
.742 .37834 Mdot
.742 .37835 Mdot
.742 .37837 Mdot
.742 .37858 Mdot
.742 .37863 Mdot
.742 .37864 Mdot
.742 .37865 Mdot
.742 .37872 Mdot
.742 .37874 Mdot
.742 .37876 Mdot
.742 .37881 Mdot
.742 .37894 Mdot
.742 .37902 Mdot
.742 .37902 Mdot
.742 .37917 Mdot
.742 .37952 Mdot
.742 .37958 Mdot
.742 .3796 Mdot
.742 .37962 Mdot
.742 .37963 Mdot
.742 .37967 Mdot
.742 .37967 Mdot
.742 .37971 Mdot
.742 .37982 Mdot
.742 .37985 Mdot
.742 .37987 Mdot
.742 .37987 Mdot
.742 .38005 Mdot
.742 .38007 Mdot
.742 .38008 Mdot
.742 .38009 Mdot
.742 .3801 Mdot
.742 .38017 Mdot
.742 .38019 Mdot
.742 .38021 Mdot
.742 .38034 Mdot
.742 .38035 Mdot
.742 .38037 Mdot
.742 .38047 Mdot
.742 .3805 Mdot
.742 .38057 Mdot
.742 .3806 Mdot
.742 .38063 Mdot
.742 .38067 Mdot
.742 .38068 Mdot
.742 .38072 Mdot
.742 .38073 Mdot
.742 .38076 Mdot
.742 .38077 Mdot
.742 .38082 Mdot
.742 .38083 Mdot
.742 .38083 Mdot
.742 .38087 Mdot
.742 .38088 Mdot
.742 .38089 Mdot
.742 .3809 Mdot
.742 .3809 Mdot
.742 .38097 Mdot
.742 .38101 Mdot
.742 .38101 Mdot
.742 .38103 Mdot
.742 .38104 Mdot
.742 .38106 Mdot
.742 .38106 Mdot
.742 .40857 Mdot
.742 .40857 Mdot
.742 .40858 Mdot
.742 .40858 Mdot
.742 .40859 Mdot
.742 .40859 Mdot
.742 .4086 Mdot
.742 .40861 Mdot
.742 .40861 Mdot
.742 .40862 Mdot
.742 .40862 Mdot
.742 .40862 Mdot
.742 .40863 Mdot
.742 .40863 Mdot
.742 .40864 Mdot
.742 .40865 Mdot
.742 .40865 Mdot
.742 .40866 Mdot
.742 .40866 Mdot
.742 .40867 Mdot
.742 .40867 Mdot
.742 .40868 Mdot
.742 .40869 Mdot
.742 .4087 Mdot
.742 .40872 Mdot
.742 .40872 Mdot
.742 .40875 Mdot
.742 .40876 Mdot
.742 .40876 Mdot
.742 .40879 Mdot
.742 .4088 Mdot
.742 .4088 Mdot
.742 .40882 Mdot
.742 .40882 Mdot
.742 .40882 Mdot
.742 .40883 Mdot
.742 .40883 Mdot
.742 .40888 Mdot
.742 .40888 Mdot
.742 .40889 Mdot
.742 .40889 Mdot
.742 .40892 Mdot
.742 .40893 Mdot
.742 .40893 Mdot
.742 .40894 Mdot
.742 .40894 Mdot
.742 .40895 Mdot
.742 .40895 Mdot
.742 .40897 Mdot
.742 .40906 Mdot
.742 .4091 Mdot
.742 .4091 Mdot
.742 .40912 Mdot
.742 .40915 Mdot
.742 .40916 Mdot
.742 .40917 Mdot
.742 .40917 Mdot
.742 .40919 Mdot
.742 .40919 Mdot
.742 .4092 Mdot
.742 .40921 Mdot
.742 .40926 Mdot
.742 .40927 Mdot
.742 .40927 Mdot
.742 .40927 Mdot
.742 .40931 Mdot
.742 .40934 Mdot
.742 .40934 Mdot
.742 .40935 Mdot
.742 .40935 Mdot
.742 .40936 Mdot
.742 .40936 Mdot
.742 .40937 Mdot
.742 .40938 Mdot
.742 .4094 Mdot
.742 .40942 Mdot
.742 .40947 Mdot
.742 .40949 Mdot
.742 .40949 Mdot
.742 .4095 Mdot
.742 .4095 Mdot
.742 .40953 Mdot
.742 .40953 Mdot
.742 .40954 Mdot
.742 .40958 Mdot
.742 .40958 Mdot
.742 .40958 Mdot
.742 .4096 Mdot
.742 .40961 Mdot
.742 .40961 Mdot
.742 .40964 Mdot
.742 .40965 Mdot
.742 .40971 Mdot
.742 .40974 Mdot
.742 .4098 Mdot
.742 .4098 Mdot
.742 .40983 Mdot
.742 .40992 Mdot
.742 .41004 Mdot
.742 .41016 Mdot
.742 .4102 Mdot
.742 .41022 Mdot
.742 .41027 Mdot
.742 .41028 Mdot
.742 .41028 Mdot
.742 .4103 Mdot
.742 .41032 Mdot
.742 .41032 Mdot
.742 .41036 Mdot
.742 .41036 Mdot
.742 .4104 Mdot
.742 .41051 Mdot
.742 .41054 Mdot
.742 .41056 Mdot
.742 .41056 Mdot
.742 .41071 Mdot
.742 .41075 Mdot
.742 .41075 Mdot
.742 .41077 Mdot
.742 .41078 Mdot
.742 .41079 Mdot
.742 .41081 Mdot
.742 .41081 Mdot
.742 .41085 Mdot
.742 .41085 Mdot
.742 .41089 Mdot
.742 .41092 Mdot
.742 .41094 Mdot
.742 .4111 Mdot
.742 .41111 Mdot
.742 .41113 Mdot
.742 .41126 Mdot
.742 .41127 Mdot
.742 .41129 Mdot
.742 .41129 Mdot
.742 .41139 Mdot
.742 .41143 Mdot
.742 .41146 Mdot
.742 .41147 Mdot
.742 .41152 Mdot
.742 .41154 Mdot
.742 .41158 Mdot
.742 .41159 Mdot
.742 .4116 Mdot
.742 .41163 Mdot
.742 .41164 Mdot
.742 .41166 Mdot
.742 .41173 Mdot
.742 .41174 Mdot
.742 .41175 Mdot
.742 .4118 Mdot
.742 .41182 Mdot
.742 .41183 Mdot
.742 .41185 Mdot
.742 .41185 Mdot
.742 .41191 Mdot
.742 .41195 Mdot
.742 .41201 Mdot
.742 .41201 Mdot
.742 .41201 Mdot
.742 .41204 Mdot
.742 .41206 Mdot
.742 .41208 Mdot
.742 .41208 Mdot
.742 .4122 Mdot
.742 .41223 Mdot
.742 .41229 Mdot
.742 .41234 Mdot
.742 .41239 Mdot
.742 .4125 Mdot
.742 .41255 Mdot
.742 .41262 Mdot
.742 .41263 Mdot
.742 .41305 Mdot
.742 .41315 Mdot
.742 .4132 Mdot
.742 .41355 Mdot
.742 .41364 Mdot
.742 .41371 Mdot
.742 .41388 Mdot
.742 .41389 Mdot
.742 .41394 Mdot
.742 .4143 Mdot
.742 .41454 Mdot
.742 .41478 Mdot
.742 .4149 Mdot
.742 .41502 Mdot
.742 .41504 Mdot
.742 .41506 Mdot
.742 .41526 Mdot
.742 .41526 Mdot
.742 .4154 Mdot
.742 .41562 Mdot
.742 .41562 Mdot
.742 .41659 Mdot
.742 .41694 Mdot
.742 .41748 Mdot
.742 .41781 Mdot
.742 .41788 Mdot
.742 .41795 Mdot
.742 .41841 Mdot
.742 .41956 Mdot
.742 .41973 Mdot
.742 .42019 Mdot
.742 .42031 Mdot
.742 .42099 Mdot
.742 .4211 Mdot
.742 .42123 Mdot
.742 .4216 Mdot
.742 .42268 Mdot
.742 .4265 Mdot
.742 .42704 Mdot
.742 .42722 Mdot
.742 .42742 Mdot
.742 .42751 Mdot
.742 .42762 Mdot
.742 .42776 Mdot
.742 .42779 Mdot
.742 .42801 Mdot
.742 .42809 Mdot
.742 .42818 Mdot
.742 .42846 Mdot
.742 .42851 Mdot
.742 .42926 Mdot
.742 .42945 Mdot
.742 .42963 Mdot
.742 .42972 Mdot
.742 .42981 Mdot
.742 .42985 Mdot
.742 .43047 Mdot
.742 .43135 Mdot
.742 .43191 Mdot
.742 .4323 Mdot
.742 .43237 Mdot
.742 .43254 Mdot
.742 .43282 Mdot
.742 .43293 Mdot
.742 .43318 Mdot
.742 .43354 Mdot
.742 .43364 Mdot
.742 .43374 Mdot
.742 .43387 Mdot
.742 .43392 Mdot
.742 .43392 Mdot
.742 .43447 Mdot
.742 .43449 Mdot
.742 .43477 Mdot
.742 .43482 Mdot
.742 .4351 Mdot
.742 .43523 Mdot
.742 .43525 Mdot
.742 .43529 Mdot
.742 .4354 Mdot
.742 .43541 Mdot
.742 .43607 Mdot
.742 .43621 Mdot
.742 .43627 Mdot
.742 .43631 Mdot
.742 .43643 Mdot
.742 .43694 Mdot
.742 .43745 Mdot
.742 .43847 Mdot
.742 .43873 Mdot
.742 .4388 Mdot
.742 .43891 Mdot
.742 .43896 Mdot
.742 .43955 Mdot
.742 .43963 Mdot
.742 .43967 Mdot
.742 .4398 Mdot
.742 .44028 Mdot
.742 .44029 Mdot
.742 .44059 Mdot
.742 .44092 Mdot
.742 .44106 Mdot
.742 .4411 Mdot
.742 .44132 Mdot
.742 .44136 Mdot
.742 .44138 Mdot
.742 .44209 Mdot
.742 .44235 Mdot
.742 .44236 Mdot
.742 .44237 Mdot
.742 .44274 Mdot
.742 .44317 Mdot
.742 .44386 Mdot
.742 .44421 Mdot
.742 .44423 Mdot
.742 .44436 Mdot
.742 .44442 Mdot
.742 .44458 Mdot
.742 .44478 Mdot
.742 .44588 Mdot
.742 .44621 Mdot
.742 .44633 Mdot
.742 .44636 Mdot
.742 .4464 Mdot
.742 .44661 Mdot
.742 .44665 Mdot
.742 .4468 Mdot
.742 .44685 Mdot
.742 .44723 Mdot
.742 .44738 Mdot
.742 .4474 Mdot
.742 .44743 Mdot
.742 .44754 Mdot
.742 .44773 Mdot
.742 .44785 Mdot
.742 .4482 Mdot
.742 .4482 Mdot
.742 .44829 Mdot
.742 .44834 Mdot
.742 .44834 Mdot
.742 .44842 Mdot
.742 .44842 Mdot
.742 .44843 Mdot
.742 .44848 Mdot
.742 .44861 Mdot
.742 .44871 Mdot
.742 .44886 Mdot
.742 .44888 Mdot
.742 .44888 Mdot
.742 .44895 Mdot
.742 .44898 Mdot
.742 .44901 Mdot
.742 .44916 Mdot
.742 .44918 Mdot
.742 .44922 Mdot
.742 .44941 Mdot
.742 .44941 Mdot
.742 .44944 Mdot
.742 .44947 Mdot
.742 .44952 Mdot
.742 .44954 Mdot
.742 .44956 Mdot
.742 .44958 Mdot
.742 .4496 Mdot
.742 .44965 Mdot
.742 .44965 Mdot
.742 .44967 Mdot
.742 .44967 Mdot
.742 .44969 Mdot
.742 .44969 Mdot
.742 .44969 Mdot
.742 .44972 Mdot
.742 .44973 Mdot
.742 .44976 Mdot
.742 .44976 Mdot
.742 .44977 Mdot
.742 .44978 Mdot
.742 .44978 Mdot
.742 .44981 Mdot
.742 .44981 Mdot
.742 .44982 Mdot
.742 .44985 Mdot
.742 .44986 Mdot
.742 .44986 Mdot
.742 .44988 Mdot
.742 .44988 Mdot
.742 .44989 Mdot
.742 .44991 Mdot
.742 .44992 Mdot
.742 .44994 Mdot
.742 .44995 Mdot
.742 .44996 Mdot
.742 .44998 Mdot
.742 .45003 Mdot
.742 .45003 Mdot
.742 .45004 Mdot
.742 .45004 Mdot
.742 .45011 Mdot
.742 .45012 Mdot
.742 .45013 Mdot
.742 .4502 Mdot
.742 .45021 Mdot
.742 .45023 Mdot
.742 .45025 Mdot
.742 .45025 Mdot
.742 .45027 Mdot
.742 .45027 Mdot
.742 .45028 Mdot
.742 .45028 Mdot
.742 .45029 Mdot
.742 .4503 Mdot
.742 .4503 Mdot
.742 .45032 Mdot
.742 .4504 Mdot
.742 .4504 Mdot
.742 .45041 Mdot
.742 .45043 Mdot
.742 .45049 Mdot
.742 .45051 Mdot
.742 .45051 Mdot
.742 .45053 Mdot
.742 .45053 Mdot
.742 .45054 Mdot
.742 .45055 Mdot
.742 .45055 Mdot
.742 .45056 Mdot
.742 .45059 Mdot
.742 .4506 Mdot
.742 .45062 Mdot
.742 .45069 Mdot
.742 .45075 Mdot
.742 .45081 Mdot
.742 .45082 Mdot
.742 .45082 Mdot
.742 .45086 Mdot
.742 .45088 Mdot
.742 .45091 Mdot
.742 .45091 Mdot
.742 .45093 Mdot
.742 .45094 Mdot
.742 .45094 Mdot
.742 .45095 Mdot
.742 .45095 Mdot
.742 .45095 Mdot
.742 .45098 Mdot
.742 .45098 Mdot
.742 .45098 Mdot
.742 .451 Mdot
.742 .451 Mdot
.742 .451 Mdot
.742 .451 Mdot
.742 .45102 Mdot
.742 .45105 Mdot
.742 .45106 Mdot
.742 .45107 Mdot
.742 .45108 Mdot
.742 .45108 Mdot
.742 .45109 Mdot
.742 .45109 Mdot
.742 .45109 Mdot
.742 .45109 Mdot
.742 .4511 Mdot
.742 .45112 Mdot
.742 .45114 Mdot
.742 .45114 Mdot
.742 .45114 Mdot
.742 .45114 Mdot
.742 .45118 Mdot
.742 .45119 Mdot
.742 .45119 Mdot
.742 .45119 Mdot
.742 .4512 Mdot
.742 .4512 Mdot
.742 .45121 Mdot
.742 .45122 Mdot
.742 .45124 Mdot
.742 .45125 Mdot
.742 .45125 Mdot
.742 .45128 Mdot
.742 .45133 Mdot
.742 .45134 Mdot
.742 .45135 Mdot
.742 .45135 Mdot
.742 .45135 Mdot
.742 .45136 Mdot
.742 .45136 Mdot
.742 .45137 Mdot
.742 .45138 Mdot
.742 .45139 Mdot
.742 .45139 Mdot
.742 .45139 Mdot
.742 .45142 Mdot
.742 .45143 Mdot
.742 .45143 Mdot
.742 .45143 Mdot
.742 .45143 Mdot
.742 .45144 Mdot
.742 .45145 Mdot
.742 .45145 Mdot
.742 .45147 Mdot
.742 .45148 Mdot
.742 .45148 Mdot
.742 .4515 Mdot
.742 .4515 Mdot
.742 .45152 Mdot
.742 .45152 Mdot
.742 .45153 Mdot
.742 .45153 Mdot
.742 .45154 Mdot
.742 .45154 Mdot
.742 .45154 Mdot
.742 .45155 Mdot
.742 .45155 Mdot
.742 .45156 Mdot
.742 .45156 Mdot
.742 .45156 Mdot
.742 .45157 Mdot
.742 .45157 Mdot
.742 .45157 Mdot
.742 .45158 Mdot
.742 .45158 Mdot
.742 .45159 Mdot
.742 .45159 Mdot
.742 .45159 Mdot
.742 .4516 Mdot
.742 .4516 Mdot
.742 .4516 Mdot
.742 .4516 Mdot
.744 .25813 Mdot
.744 .37466 Mdot
.744 .41045 Mdot
.744 .45275 Mdot
.746 .25853 Mdot
.746 .25854 Mdot
.746 .25854 Mdot
.746 .25854 Mdot
.746 .25854 Mdot
.746 .25854 Mdot
.746 .25854 Mdot
.746 .25854 Mdot
.746 .25854 Mdot
.746 .25854 Mdot
.746 .25855 Mdot
.746 .25855 Mdot
.746 .25855 Mdot
.746 .25856 Mdot
.746 .25857 Mdot
.746 .25858 Mdot
.746 .2586 Mdot
.746 .25861 Mdot
.746 .25861 Mdot
.746 .25862 Mdot
.746 .25866 Mdot
.746 .25866 Mdot
.746 .25868 Mdot
.746 .25868 Mdot
.746 .25869 Mdot
.746 .25871 Mdot
.746 .25871 Mdot
.746 .25871 Mdot
.746 .25872 Mdot
.746 .25873 Mdot
.746 .25873 Mdot
.746 .25874 Mdot
.746 .25875 Mdot
.746 .25875 Mdot
.746 .25876 Mdot
.746 .25878 Mdot
.746 .2588 Mdot
.746 .25883 Mdot
.746 .25884 Mdot
.746 .25887 Mdot
.746 .25892 Mdot
.746 .25906 Mdot
.746 .25916 Mdot
.746 .25918 Mdot
.746 .25921 Mdot
.746 .25922 Mdot
.746 .25922 Mdot
.746 .25928 Mdot
.746 .25944 Mdot
.746 .2595 Mdot
.746 .25972 Mdot
.746 .25979 Mdot
.746 .25981 Mdot
.746 .26018 Mdot
.746 .26028 Mdot
.746 .26028 Mdot
.746 .2603 Mdot
.746 .2603 Mdot
.746 .2603 Mdot
.746 .26031 Mdot
.746 .26031 Mdot
.746 .26032 Mdot
.746 .26033 Mdot
.746 .26033 Mdot
.746 .26033 Mdot
.746 .26035 Mdot
.746 .26036 Mdot
.746 .2604 Mdot
.746 .26044 Mdot
.746 .26044 Mdot
.746 .26048 Mdot
.746 .26052 Mdot
.746 .26059 Mdot
.746 .26061 Mdot
.746 .26063 Mdot
.746 .26064 Mdot
.746 .26065 Mdot
.746 .26065 Mdot
.746 .26068 Mdot
.746 .26069 Mdot
.746 .26074 Mdot
.746 .26074 Mdot
.746 .26078 Mdot
.746 .26085 Mdot
.746 .2609 Mdot
.746 .26093 Mdot
.746 .26095 Mdot
.746 .26105 Mdot
.746 .26106 Mdot
.746 .26108 Mdot
.746 .26111 Mdot
.746 .26112 Mdot
.746 .26116 Mdot
.746 .2613 Mdot
.746 .26132 Mdot
.746 .26136 Mdot
.746 .26138 Mdot
.746 .2614 Mdot
.746 .26141 Mdot
.746 .26142 Mdot
.746 .26162 Mdot
.746 .26168 Mdot
.746 .26169 Mdot
.746 .2617 Mdot
.746 .26171 Mdot
.746 .26172 Mdot
.746 .26173 Mdot
.746 .26177 Mdot
.746 .26177 Mdot
.746 .26186 Mdot
.746 .26195 Mdot
.746 .26199 Mdot
.746 .26202 Mdot
.746 .26203 Mdot
.746 .2621 Mdot
.746 .26212 Mdot
.746 .26223 Mdot
.746 .26227 Mdot
.746 .26234 Mdot
.746 .26246 Mdot
.746 .26248 Mdot
.746 .26249 Mdot
.746 .26264 Mdot
.746 .26266 Mdot
.746 .26267 Mdot
.746 .26273 Mdot
.746 .26288 Mdot
.746 .26295 Mdot
.746 .26326 Mdot
.746 .26327 Mdot
.746 .26337 Mdot
.746 .26373 Mdot
.746 .26375 Mdot
.746 .26378 Mdot
.746 .26387 Mdot
.746 .26389 Mdot
.746 .26389 Mdot
.746 .26389 Mdot
.746 .2639 Mdot
.746 .26405 Mdot
.746 .26409 Mdot
.746 .26442 Mdot
.746 .26448 Mdot
.746 .2645 Mdot
.746 .26456 Mdot
.746 .26457 Mdot
.746 .26458 Mdot
.746 .26459 Mdot
.746 .26462 Mdot
.746 .26464 Mdot
.746 .26485 Mdot
.746 .26489 Mdot
.746 .265 Mdot
.746 .26511 Mdot
.746 .26531 Mdot
.746 .26536 Mdot
.746 .26539 Mdot
.746 .26569 Mdot
.746 .26603 Mdot
.746 .26612 Mdot
.746 .26615 Mdot
.746 .26616 Mdot
.746 .26631 Mdot
.746 .26664 Mdot
.746 .26667 Mdot
.746 .2667 Mdot
.746 .26692 Mdot
.746 .26701 Mdot
.746 .26715 Mdot
.746 .26725 Mdot
.746 .26739 Mdot
.746 .26749 Mdot
.746 .2675 Mdot
.746 .26769 Mdot
.746 .26792 Mdot
.746 .26793 Mdot
.746 .26808 Mdot
.746 .26823 Mdot
.746 .26863 Mdot
.746 .26923 Mdot
.746 .26927 Mdot
.746 .2706 Mdot
.746 .27064 Mdot
.746 .27093 Mdot
.746 .27112 Mdot
.746 .27114 Mdot
.746 .27118 Mdot
.746 .27146 Mdot
.746 .27147 Mdot
.746 .27169 Mdot
.746 .27171 Mdot
.746 .27182 Mdot
.746 .27184 Mdot
.746 .27185 Mdot
.746 .27185 Mdot
.746 .27185 Mdot
.746 .27188 Mdot
.746 .27189 Mdot
.746 .2721 Mdot
.746 .27212 Mdot
.746 .2722 Mdot
.746 .27221 Mdot
.746 .27222 Mdot
.746 .27228 Mdot
.746 .27257 Mdot
.746 .27281 Mdot
.746 .27296 Mdot
.746 .27297 Mdot
.746 .27327 Mdot
.746 .27336 Mdot
.746 .27355 Mdot
.746 .27363 Mdot
.746 .27363 Mdot
.746 .27367 Mdot
.746 .27375 Mdot
.746 .27395 Mdot
.746 .27397 Mdot
.746 .27398 Mdot
.746 .27402 Mdot
.746 .27417 Mdot
.746 .27421 Mdot
.746 .27425 Mdot
.746 .27427 Mdot
.746 .27443 Mdot
.746 .27456 Mdot
.746 .27461 Mdot
.746 .27467 Mdot
.746 .27468 Mdot
.746 .27471 Mdot
.746 .27518 Mdot
.746 .27591 Mdot
.746 .27594 Mdot
.746 .27664 Mdot
.746 .27732 Mdot
.746 .27739 Mdot
.746 .2785 Mdot
.746 .27872 Mdot
.746 .27916 Mdot
.746 .27926 Mdot
.746 .27926 Mdot
.746 .27939 Mdot
.746 .27948 Mdot
.746 .27954 Mdot
.746 .27978 Mdot
.746 .28005 Mdot
.746 .28062 Mdot
.746 .2808 Mdot
.746 .28132 Mdot
.746 .28175 Mdot
.746 .28189 Mdot
.746 .28212 Mdot
.746 .28235 Mdot
.746 .2824 Mdot
.746 .28262 Mdot
.746 .28266 Mdot
.746 .283 Mdot
.746 .28346 Mdot
.746 .28391 Mdot
.746 .28412 Mdot
.746 .28429 Mdot
.746 .28429 Mdot
.746 .285 Mdot
.746 .28574 Mdot
.746 .28635 Mdot
.746 .28654 Mdot
.746 .28702 Mdot
.746 .28728 Mdot
.746 .28733 Mdot
.746 .28751 Mdot
.746 .28756 Mdot
.746 .28771 Mdot
.746 .28779 Mdot
.746 .28814 Mdot
.746 .28829 Mdot
.746 .28855 Mdot
.746 .28902 Mdot
.746 .28964 Mdot
.746 .29022 Mdot
.746 .29025 Mdot
.746 .29027 Mdot
.746 .29047 Mdot
.746 .29111 Mdot
.746 .29164 Mdot
.746 .29258 Mdot
.746 .2928 Mdot
.746 .29282 Mdot
.746 .29316 Mdot
.746 .29327 Mdot
.746 .29334 Mdot
.746 .29334 Mdot
.746 .2935 Mdot
.746 .29426 Mdot
.746 .29473 Mdot
.746 .29473 Mdot
.746 .29506 Mdot
.746 .29555 Mdot
.746 .2958 Mdot
.746 .29638 Mdot
.746 .29672 Mdot
.746 .29681 Mdot
.746 .29738 Mdot
.746 .29765 Mdot
.746 .29773 Mdot
.746 .29813 Mdot
.746 .29844 Mdot
.746 .29853 Mdot
.746 .29876 Mdot
.746 .29878 Mdot
.746 .29892 Mdot
.746 .29897 Mdot
.746 .29906 Mdot
.746 .29912 Mdot
.746 .29926 Mdot
.746 .29938 Mdot
.746 .29951 Mdot
.746 .29952 Mdot
.746 .29969 Mdot
.746 .29991 Mdot
.746 .30023 Mdot
.746 .30025 Mdot
.746 .30096 Mdot
.746 .30111 Mdot
.746 .3012 Mdot
.746 .30121 Mdot
.746 .30137 Mdot
.746 .30137 Mdot
.746 .30148 Mdot
.746 .30154 Mdot
.746 .30155 Mdot
.746 .30155 Mdot
.746 .30156 Mdot
.746 .30157 Mdot
.746 .30168 Mdot
.746 .30172 Mdot
.746 .30173 Mdot
.746 .30173 Mdot
.746 .30189 Mdot
.746 .30201 Mdot
.746 .30208 Mdot
.746 .30208 Mdot
.746 .30222 Mdot
.746 .30226 Mdot
.746 .30235 Mdot
.746 .30238 Mdot
.746 .30238 Mdot
.746 .3024 Mdot
.746 .30244 Mdot
.746 .30253 Mdot
.746 .30254 Mdot
.746 .30254 Mdot
.746 .30263 Mdot
.746 .30266 Mdot
.746 .30267 Mdot
.746 .30274 Mdot
.746 .3028 Mdot
.746 .30282 Mdot
.746 .30285 Mdot
.746 .30285 Mdot
.746 .30287 Mdot
.746 .30307 Mdot
.746 .30339 Mdot
.746 .30475 Mdot
.746 .30479 Mdot
.746 .30479 Mdot
.746 .30484 Mdot
.746 .30499 Mdot
.746 .30584 Mdot
.746 .30605 Mdot
.746 .30629 Mdot
.746 .30958 Mdot
.746 .31056 Mdot
.746 .31063 Mdot
.746 .31369 Mdot
.746 .31439 Mdot
.746 .3159 Mdot
.746 .31653 Mdot
.746 .31659 Mdot
.746 .31686 Mdot
.746 .31845 Mdot
.746 .31851 Mdot
.746 .31867 Mdot
.746 .31994 Mdot
.746 .32076 Mdot
.746 .32116 Mdot
.746 .32237 Mdot
.746 .32252 Mdot
.746 .32326 Mdot
.746 .32343 Mdot
.746 .32369 Mdot
.746 .32413 Mdot
.746 .32513 Mdot
.746 .32619 Mdot
.746 .3262 Mdot
.746 .32659 Mdot
.746 .32674 Mdot
.746 .32682 Mdot
.746 .32698 Mdot
.746 .327 Mdot
.746 .32722 Mdot
.746 .32782 Mdot
.746 .3301 Mdot
.746 .33027 Mdot
.746 .33035 Mdot
.746 .33059 Mdot
.746 .33083 Mdot
.746 .33126 Mdot
.746 .3315 Mdot
.746 .33314 Mdot
.746 .33355 Mdot
.746 .33375 Mdot
.746 .33409 Mdot
.746 .33428 Mdot
.746 .33441 Mdot
.746 .33556 Mdot
.746 .3358 Mdot
.746 .33614 Mdot
.746 .33682 Mdot
.746 .33758 Mdot
.746 .33808 Mdot
.746 .33809 Mdot
.746 .33868 Mdot
.746 .33886 Mdot
.746 .33913 Mdot
.746 .33919 Mdot
.746 .33935 Mdot
.746 .33939 Mdot
.746 .33965 Mdot
.746 .33987 Mdot
.746 .34075 Mdot
.746 .34126 Mdot
.746 .34168 Mdot
.746 .34179 Mdot
.746 .34227 Mdot
.746 .34272 Mdot
.746 .34281 Mdot
.746 .34314 Mdot
.746 .34315 Mdot
.746 .34315 Mdot
.746 .34319 Mdot
.746 .34331 Mdot
.746 .34333 Mdot
.746 .34341 Mdot
.746 .34351 Mdot
.746 .34352 Mdot
.746 .34367 Mdot
.746 .34368 Mdot
.746 .345 Mdot
.746 .34965 Mdot
.746 .3499 Mdot
.746 .35077 Mdot
.746 .35352 Mdot
.746 .35429 Mdot
.746 .3563 Mdot
.746 .35709 Mdot
.746 .35718 Mdot
.746 .35728 Mdot
.746 .35763 Mdot
.746 .35791 Mdot
.746 .35926 Mdot
.746 .36098 Mdot
.746 .36163 Mdot
.746 .36205 Mdot
.746 .36218 Mdot
.746 .36257 Mdot
.746 .36285 Mdot
.746 .36311 Mdot
.746 .36329 Mdot
.746 .3633 Mdot
.746 .36343 Mdot
.746 .36351 Mdot
.746 .36356 Mdot
.746 .36367 Mdot
.746 .36375 Mdot
.746 .36377 Mdot
.746 .36384 Mdot
.746 .36409 Mdot
.746 .36411 Mdot
.746 .36415 Mdot
.746 .36445 Mdot
.746 .36447 Mdot
.746 .36493 Mdot
.746 .36506 Mdot
.746 .36509 Mdot
.746 .36521 Mdot
.746 .3655 Mdot
.746 .36555 Mdot
.746 .36576 Mdot
.746 .36582 Mdot
.746 .36583 Mdot
.746 .3659 Mdot
.746 .36596 Mdot
.746 .36597 Mdot
.746 .36602 Mdot
.746 .36602 Mdot
.746 .36602 Mdot
.746 .36602 Mdot
.746 .36604 Mdot
.746 .36607 Mdot
.746 .36607 Mdot
.746 .36609 Mdot
.746 .41283 Mdot
.746 .41283 Mdot
.746 .41283 Mdot
.746 .41284 Mdot
.746 .41284 Mdot
.746 .41284 Mdot
.746 .41284 Mdot
.746 .41284 Mdot
.746 .41286 Mdot
.746 .41286 Mdot
.746 .41287 Mdot
.746 .41289 Mdot
.746 .41289 Mdot
.746 .41291 Mdot
.746 .41296 Mdot
.746 .41297 Mdot
.746 .41305 Mdot
.746 .41307 Mdot
.746 .41308 Mdot
.746 .41311 Mdot
.746 .41323 Mdot
.746 .41323 Mdot
.746 .41331 Mdot
.746 .41332 Mdot
.746 .41332 Mdot
.746 .41338 Mdot
.746 .4134 Mdot
.746 .4134 Mdot
.746 .41342 Mdot
.746 .41345 Mdot
.746 .41346 Mdot
.746 .41348 Mdot
.746 .41352 Mdot
.746 .41352 Mdot
.746 .41356 Mdot
.746 .41363 Mdot
.746 .41369 Mdot
.746 .41379 Mdot
.746 .41382 Mdot
.746 .41393 Mdot
.746 .41409 Mdot
.746 .41451 Mdot
.746 .41484 Mdot
.746 .41491 Mdot
.746 .415 Mdot
.746 .41502 Mdot
.746 .41504 Mdot
.746 .41524 Mdot
.746 .41573 Mdot
.746 .41592 Mdot
.746 .4166 Mdot
.746 .41681 Mdot
.746 .41687 Mdot
.746 .41802 Mdot
.746 .41835 Mdot
.746 .41835 Mdot
.746 .41839 Mdot
.746 .41839 Mdot
.746 .41841 Mdot
.746 .41843 Mdot
.746 .41844 Mdot
.746 .41847 Mdot
.746 .41848 Mdot
.746 .41848 Mdot
.746 .41848 Mdot
.746 .41856 Mdot
.746 .41858 Mdot
.746 .4187 Mdot
.746 .41882 Mdot
.746 .41884 Mdot
.746 .41895 Mdot
.746 .41907 Mdot
.746 .41929 Mdot
.746 .41935 Mdot
.746 .41942 Mdot
.746 .41942 Mdot
.746 .41946 Mdot
.746 .41948 Mdot
.746 .41955 Mdot
.746 .41959 Mdot
.746 .41974 Mdot
.746 .41974 Mdot
.746 .41987 Mdot
.746 .42006 Mdot
.746 .42023 Mdot
.746 .42031 Mdot
.746 .42037 Mdot
.746 .42066 Mdot
.746 .4207 Mdot
.746 .42074 Mdot
.746 .42083 Mdot
.746 .42088 Mdot
.746 .42099 Mdot
.746 .4214 Mdot
.746 .42147 Mdot
.746 .42157 Mdot
.746 .42164 Mdot
.746 .4217 Mdot
.746 .42172 Mdot
.746 .42176 Mdot
.746 .42235 Mdot
.746 .4225 Mdot
.746 .42256 Mdot
.746 .42256 Mdot
.746 .4226 Mdot
.746 .42263 Mdot
.746 .42266 Mdot
.746 .42277 Mdot
.746 .42277 Mdot
.746 .42304 Mdot
.746 .4233 Mdot
.746 .42342 Mdot
.746 .42349 Mdot
.746 .42353 Mdot
.746 .42373 Mdot
.746 .42377 Mdot
.746 .42409 Mdot
.746 .42419 Mdot
.746 .42441 Mdot
.746 .42475 Mdot
.746 .42479 Mdot
.746 .42481 Mdot
.746 .42524 Mdot
.746 .42531 Mdot
.746 .42533 Mdot
.746 .4255 Mdot
.746 .42591 Mdot
.746 .42611 Mdot
.746 .42696 Mdot
.746 .42698 Mdot
.746 .42725 Mdot
.746 .4282 Mdot
.746 .42827 Mdot
.746 .42833 Mdot
.746 .42857 Mdot
.746 .42862 Mdot
.746 .42863 Mdot
.746 .42864 Mdot
.746 .42865 Mdot
.746 .42905 Mdot
.746 .42914 Mdot
.746 .4292 Mdot
.746 .42921 Mdot
.746 .42921 Mdot
.746 .42922 Mdot
.746 .42922 Mdot
.746 .42924 Mdot
.746 .42926 Mdot
.746 .42926 Mdot
.746 .42927 Mdot
.746 .4293 Mdot
.746 .4293 Mdot
.746 .4293 Mdot
.746 .42933 Mdot
.746 .42934 Mdot
.746 .42935 Mdot
.746 .42935 Mdot
.746 .42936 Mdot
.746 .42938 Mdot
.746 .4294 Mdot
.746 .42944 Mdot
.746 .42944 Mdot
.746 .42946 Mdot
.746 .42949 Mdot
.746 .42954 Mdot
.746 .42955 Mdot
.746 .42955 Mdot
.746 .42956 Mdot
.746 .42959 Mdot
.746 .4296 Mdot
.746 .4296 Mdot
.746 .4296 Mdot
.746 .4296 Mdot
.746 .42962 Mdot
.746 .42965 Mdot
.746 .42965 Mdot
.746 .4297 Mdot
.746 .4297 Mdot
.746 .42973 Mdot
.746 .42978 Mdot
.746 .42999 Mdot
.746 .43 Mdot
.746 .4301 Mdot
.746 .43017 Mdot
.746 .43022 Mdot
.746 .43022 Mdot
.746 .43026 Mdot
.746 .4303 Mdot
.746 .43034 Mdot
.746 .43036 Mdot
.746 .43039 Mdot
.746 .4304 Mdot
.746 .43044 Mdot
.746 .43045 Mdot
.746 .43052 Mdot
.746 .43055 Mdot
.746 .43065 Mdot
.746 .43077 Mdot
.746 .4308 Mdot
.746 .43088 Mdot
.746 .43106 Mdot
.746 .43109 Mdot
.746 .4312 Mdot
.746 .43138 Mdot
.746 .43147 Mdot
.746 .43162 Mdot
.746 .43173 Mdot
.746 .43173 Mdot
.746 .43188 Mdot
.746 .43213 Mdot
.746 .43218 Mdot
.746 .43218 Mdot
.746 .4322 Mdot
.746 .43224 Mdot
.746 .43236 Mdot
.746 .43236 Mdot
.746 .43244 Mdot
.746 .43275 Mdot
.746 .43293 Mdot
.746 .43315 Mdot
.746 .43322 Mdot
.746 .43322 Mdot
.746 .43323 Mdot
.746 .43343 Mdot
.746 .43365 Mdot
.746 .43381 Mdot
.746 .4339 Mdot
.746 .43396 Mdot
.746 .43408 Mdot
.746 .43411 Mdot
.746 .43416 Mdot
.746 .43418 Mdot
.746 .43425 Mdot
.746 .43426 Mdot
.746 .43436 Mdot
.746 .43453 Mdot
.746 .4346 Mdot
.746 .43482 Mdot
.746 .4351 Mdot
.746 .43536 Mdot
.746 .43536 Mdot
.746 .43542 Mdot
.746 .43551 Mdot
.746 .43568 Mdot
.746 .43585 Mdot
.746 .43599 Mdot
.746 .436 Mdot
.746 .43609 Mdot
.746 .43611 Mdot
.746 .43619 Mdot
.746 .43629 Mdot
.746 .43634 Mdot
.746 .43651 Mdot
.746 .43672 Mdot
.746 .43679 Mdot
.746 .43703 Mdot
.746 .43714 Mdot
.746 .43724 Mdot
.746 .43726 Mdot
.746 .4373 Mdot
.746 .43735 Mdot
.746 .43735 Mdot
.746 .43739 Mdot
.746 .43758 Mdot
.746 .43767 Mdot
.746 .43815 Mdot
.746 .43818 Mdot
.746 .43848 Mdot
.746 .4388 Mdot
.746 .43881 Mdot
.746 .43915 Mdot
.746 .43937 Mdot
.746 .43938 Mdot
.746 .43939 Mdot
.746 .43941 Mdot
.746 .43944 Mdot
.746 .4395 Mdot
.746 .43958 Mdot
.746 .43958 Mdot
.746 .43961 Mdot
.746 .43962 Mdot
.746 .4397 Mdot
.746 .43971 Mdot
.746 .43972 Mdot
.746 .43973 Mdot
.746 .43983 Mdot
.746 .43987 Mdot
.746 .43989 Mdot
.746 .43989 Mdot
.746 .43992 Mdot
.746 .44002 Mdot
.746 .44006 Mdot
.746 .44021 Mdot
.746 .44022 Mdot
.746 .44029 Mdot
.746 .44041 Mdot
.746 .44056 Mdot
.746 .44059 Mdot
.746 .4406 Mdot
.746 .4406 Mdot
.746 .44064 Mdot
.746 .44065 Mdot
.746 .44076 Mdot
.746 .44076 Mdot
.746 .44078 Mdot
.746 .44078 Mdot
.746 .44078 Mdot
.746 .44079 Mdot
.746 .4408 Mdot
.746 .44085 Mdot
.746 .44086 Mdot
.746 .44098 Mdot
.746 .44099 Mdot
.746 .44113 Mdot
.746 .44115 Mdot
.746 .44116 Mdot
.746 .44127 Mdot
.746 .44142 Mdot
.746 .44145 Mdot
.746 .44219 Mdot
.746 .44221 Mdot
.746 .44257 Mdot
.746 .44281 Mdot
.746 .4429 Mdot
.746 .44299 Mdot
.746 .443 Mdot
.746 .44314 Mdot
.746 .44326 Mdot
.746 .44327 Mdot
.746 .44333 Mdot
.746 .44342 Mdot
.746 .44348 Mdot
.746 .44358 Mdot
.746 .44364 Mdot
.746 .44378 Mdot
.746 .4438 Mdot
.746 .44382 Mdot
.746 .44405 Mdot
.746 .44414 Mdot
.746 .44415 Mdot
.746 .44417 Mdot
.746 .44424 Mdot
.746 .44448 Mdot
.746 .44469 Mdot
.746 .44471 Mdot
.746 .44474 Mdot
.746 .4449 Mdot
.746 .44498 Mdot
.746 .44506 Mdot
.746 .44509 Mdot
.746 .44525 Mdot
.746 .44526 Mdot
.746 .44529 Mdot
.746 .4453 Mdot
.746 .4453 Mdot
.746 .44531 Mdot
.746 .44536 Mdot
.746 .44537 Mdot
.746 .44542 Mdot
.746 .44569 Mdot
.746 .44572 Mdot
.746 .44584 Mdot
.746 .44585 Mdot
.746 .44585 Mdot
.746 .44585 Mdot
.746 .44587 Mdot
.746 .44594 Mdot
.746 .44596 Mdot
.746 .44598 Mdot
.746 .44629 Mdot
.746 .44637 Mdot
.746 .44638 Mdot
.746 .44666 Mdot
.746 .44672 Mdot
.746 .44686 Mdot
.746 .44692 Mdot
.746 .44693 Mdot
.746 .44695 Mdot
.746 .4471 Mdot
.746 .4471 Mdot
.746 .44712 Mdot
.746 .44724 Mdot
.746 .44731 Mdot
.746 .44735 Mdot
.746 .44736 Mdot
.746 .44746 Mdot
.746 .44748 Mdot
.746 .44755 Mdot
.746 .44756 Mdot
.746 .44759 Mdot
.746 .44763 Mdot
.746 .44772 Mdot
.746 .44782 Mdot
.746 .44783 Mdot
.746 .44786 Mdot
.746 .44788 Mdot
.746 .44789 Mdot
.746 .4479 Mdot
.746 .4479 Mdot
.746 .44792 Mdot
.746 .44798 Mdot
.746 .4482 Mdot
.746 .44822 Mdot
.746 .44823 Mdot
.746 .44825 Mdot
.746 .44828 Mdot
.746 .44832 Mdot
.746 .44834 Mdot
.746 .44851 Mdot
.746 .44855 Mdot
.746 .44857 Mdot
.746 .44861 Mdot
.746 .44863 Mdot
.746 .44864 Mdot
.746 .44876 Mdot
.746 .44878 Mdot
.746 .44882 Mdot
.746 .44889 Mdot
.746 .44897 Mdot
.746 .44903 Mdot
.746 .44903 Mdot
.746 .44909 Mdot
.746 .44911 Mdot
.746 .44914 Mdot
.746 .44915 Mdot
.746 .44916 Mdot
.746 .44917 Mdot
.746 .4492 Mdot
.746 .44922 Mdot
.746 .44932 Mdot
.746 .44938 Mdot
.746 .44942 Mdot
.746 .44944 Mdot
.746 .44949 Mdot
.746 .44954 Mdot
.746 .44955 Mdot
.746 .44959 Mdot
.746 .44959 Mdot
.746 .44959 Mdot
.746 .4496 Mdot
.746 .44961 Mdot
.746 .44961 Mdot
.746 .44962 Mdot
.746 .44964 Mdot
.746 .44964 Mdot
.746 .44965 Mdot
.746 .44966 Mdot
.746 .44981 Mdot
.746 .45041 Mdot
.746 .45044 Mdot
.746 .45056 Mdot
.746 .45096 Mdot
.746 .45108 Mdot
.746 .4514 Mdot
.746 .45154 Mdot
.746 .45156 Mdot
.746 .45158 Mdot
.746 .45164 Mdot
.746 .45169 Mdot
.746 .45195 Mdot
.746 .45231 Mdot
.746 .45246 Mdot
.746 .45256 Mdot
.746 .4526 Mdot
.746 .4527 Mdot
.746 .45277 Mdot
.746 .45285 Mdot
.746 .4529 Mdot
.746 .4529 Mdot
.746 .45294 Mdot
.746 .45296 Mdot
.746 .45297 Mdot
.746 .45301 Mdot
.746 .45303 Mdot
.746 .45304 Mdot
.746 .45306 Mdot
.746 .45314 Mdot
.746 .45315 Mdot
.746 .45316 Mdot
.746 .45326 Mdot
.746 .45327 Mdot
.746 .45343 Mdot
.746 .45348 Mdot
.746 .45349 Mdot
.746 .45354 Mdot
.746 .45366 Mdot
.746 .45369 Mdot
.746 .45379 Mdot
.746 .45382 Mdot
.746 .45382 Mdot
.746 .45386 Mdot
.746 .45389 Mdot
.746 .45389 Mdot
.746 .45392 Mdot
.746 .45392 Mdot
.746 .45392 Mdot
.746 .45392 Mdot
.746 .45393 Mdot
.746 .45395 Mdot
.746 .45395 Mdot
.746 .45396 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25911 Mdot
.748 .25912 Mdot
.748 .25912 Mdot
.748 .25912 Mdot
.748 .25912 Mdot
.748 .25913 Mdot
.748 .25913 Mdot
.748 .25913 Mdot
.748 .25914 Mdot
.748 .25915 Mdot
.748 .25915 Mdot
.748 .25916 Mdot
.748 .25916 Mdot
.748 .25916 Mdot
.748 .25916 Mdot
.748 .25917 Mdot
.748 .25917 Mdot
.748 .25917 Mdot
.748 .25917 Mdot
.748 .25917 Mdot
.748 .25917 Mdot
.748 .25917 Mdot
.748 .25917 Mdot
.748 .25917 Mdot
.748 .25917 Mdot
.748 .25917 Mdot
.748 .25918 Mdot
.748 .25918 Mdot
.748 .25918 Mdot
.748 .25918 Mdot
.748 .25919 Mdot
.748 .25919 Mdot
.748 .25919 Mdot
.748 .25919 Mdot
.748 .2592 Mdot
.748 .25922 Mdot
.748 .25922 Mdot
.748 .25923 Mdot
.748 .25925 Mdot
.748 .25926 Mdot
.748 .25926 Mdot
.748 .25928 Mdot
.748 .25928 Mdot
.748 .25929 Mdot
.748 .25931 Mdot
.748 .25932 Mdot
.748 .25934 Mdot
.748 .25935 Mdot
.748 .25936 Mdot
.748 .25937 Mdot
.748 .25937 Mdot
.748 .25938 Mdot
.748 .2594 Mdot
.748 .25941 Mdot
.748 .25942 Mdot
.748 .25943 Mdot
.748 .25943 Mdot
.748 .25943 Mdot
.748 .25943 Mdot
.748 .25944 Mdot
.748 .25945 Mdot
.748 .25945 Mdot
.748 .25945 Mdot
.748 .25946 Mdot
.748 .25947 Mdot
.748 .25949 Mdot
.748 .2595 Mdot
.748 .25952 Mdot
.748 .25954 Mdot
.748 .25954 Mdot
.748 .25954 Mdot
.748 .25954 Mdot
.748 .25956 Mdot
.748 .25956 Mdot
.748 .25958 Mdot
.748 .25959 Mdot
.748 .2596 Mdot
.748 .2596 Mdot
.748 .2596 Mdot
.748 .25961 Mdot
.748 .25961 Mdot
.748 .25961 Mdot
.748 .25961 Mdot
.748 .25962 Mdot
.748 .25979 Mdot
.748 .2598 Mdot
.748 .25984 Mdot
.748 .25994 Mdot
.748 .25997 Mdot
.748 .26 Mdot
.748 .26007 Mdot
.748 .26012 Mdot
.748 .26023 Mdot
.748 .26024 Mdot
.748 .26024 Mdot
.748 .26028 Mdot
.748 .26029 Mdot
.748 .2603 Mdot
.748 .26031 Mdot
.748 .26031 Mdot
.748 .26032 Mdot
.748 .26033 Mdot
.748 .26033 Mdot
.748 .26033 Mdot
.748 .26034 Mdot
.748 .26034 Mdot
.748 .26034 Mdot
.748 .26034 Mdot
.748 .26034 Mdot
.748 .26034 Mdot
.748 .26034 Mdot
.748 .26034 Mdot
.748 .26034 Mdot
.748 .26034 Mdot
.748 .26034 Mdot
.748 .26034 Mdot
.748 .26034 Mdot
.748 .26034 Mdot
.748 .26124 Mdot
.748 .26136 Mdot
.748 .262 Mdot
.748 .26333 Mdot
.748 .26391 Mdot
.748 .26448 Mdot
.748 .26515 Mdot
.748 .26611 Mdot
.748 .26617 Mdot
.748 .26619 Mdot
.748 .26682 Mdot
.748 .26713 Mdot
.748 .26713 Mdot
.748 .26713 Mdot
.748 .26713 Mdot
.748 .26713 Mdot
.748 .26713 Mdot
.748 .26713 Mdot
.748 .26714 Mdot
.748 .26715 Mdot
.748 .26716 Mdot
.748 .26716 Mdot
.748 .26716 Mdot
.748 .26717 Mdot
.748 .26718 Mdot
.748 .2672 Mdot
.748 .26721 Mdot
.748 .26723 Mdot
.748 .26733 Mdot
.748 .26734 Mdot
.748 .26737 Mdot
.748 .26743 Mdot
.748 .26747 Mdot
.748 .2675 Mdot
.748 .26757 Mdot
.748 .26757 Mdot
.748 .26757 Mdot
.748 .27074 Mdot
.748 .27499 Mdot
.748 .27499 Mdot
.748 .27499 Mdot
.748 .27499 Mdot
.748 .27499 Mdot
.748 .27499 Mdot
.748 .27499 Mdot
.748 .27499 Mdot
.748 .27499 Mdot
.748 .27499 Mdot
.748 .27499 Mdot
.748 .27499 Mdot
.748 .27499 Mdot
.748 .275 Mdot
.748 .275 Mdot
.748 .275 Mdot
.748 .27501 Mdot
.748 .27503 Mdot
.748 .27503 Mdot
.748 .27504 Mdot
.748 .27506 Mdot
.748 .27507 Mdot
.748 .27508 Mdot
.748 .27515 Mdot
.748 .27516 Mdot
.748 .27517 Mdot
.748 .27538 Mdot
.748 .27547 Mdot
.748 .2756 Mdot
.748 .27568 Mdot
.748 .27574 Mdot
.748 .27607 Mdot
.748 .27609 Mdot
.748 .27659 Mdot
.748 .27659 Mdot
.748 .27659 Mdot
.748 .27659 Mdot
.748 .27661 Mdot
.748 .27663 Mdot
.748 .27664 Mdot
.748 .27664 Mdot
.748 .27668 Mdot
.748 .2767 Mdot
.748 .27679 Mdot
.748 .27684 Mdot
.748 .27684 Mdot
.748 .27685 Mdot
.748 .27687 Mdot
.748 .27693 Mdot
.748 .27699 Mdot
.748 .27705 Mdot
.748 .27712 Mdot
.748 .27718 Mdot
.748 .27719 Mdot
.748 .27721 Mdot
.748 .27722 Mdot
.748 .27726 Mdot
.748 .27733 Mdot
.748 .27746 Mdot
.748 .27752 Mdot
.748 .27769 Mdot
.748 .27775 Mdot
.748 .27788 Mdot
.748 .27813 Mdot
.748 .27816 Mdot
.748 .27834 Mdot
.748 .27834 Mdot
.748 .27839 Mdot
.748 .27865 Mdot
.748 .27886 Mdot
.748 .27898 Mdot
.748 .27903 Mdot
.748 .27916 Mdot
.748 .27919 Mdot
.748 .27922 Mdot
.748 .27925 Mdot
.748 .27926 Mdot
.748 .27927 Mdot
.748 .27929 Mdot
.748 .27934 Mdot
.748 .27935 Mdot
.748 .27938 Mdot
.748 .27938 Mdot
.748 .27938 Mdot
.748 .2794 Mdot
.748 .27941 Mdot
.748 .27941 Mdot
.748 .27941 Mdot
.748 .27941 Mdot
.748 .27976 Mdot
.748 .28006 Mdot
.748 .28022 Mdot
.748 .28039 Mdot
.748 .281 Mdot
.748 .28108 Mdot
.748 .28134 Mdot
.748 .28201 Mdot
.748 .28227 Mdot
.748 .28233 Mdot
.748 .28262 Mdot
.748 .28275 Mdot
.748 .28289 Mdot
.748 .28329 Mdot
.748 .28365 Mdot
.748 .28399 Mdot
.748 .28421 Mdot
.748 .28449 Mdot
.748 .28463 Mdot
.748 .28463 Mdot
.748 .28469 Mdot
.748 .28476 Mdot
.748 .28486 Mdot
.748 .28487 Mdot
.748 .28499 Mdot
.748 .28524 Mdot
.748 .28526 Mdot
.748 .28534 Mdot
.748 .28546 Mdot
.748 .28554 Mdot
.748 .28594 Mdot
.748 .28648 Mdot
.748 .28692 Mdot
.748 .28734 Mdot
.748 .28787 Mdot
.748 .28803 Mdot
.748 .28807 Mdot
.748 .2881 Mdot
.748 .28849 Mdot
.748 .28869 Mdot
.748 .28922 Mdot
.748 .28938 Mdot
.748 .28974 Mdot
.748 .28977 Mdot
.748 .2898 Mdot
.748 .29002 Mdot
.748 .29013 Mdot
.748 .29013 Mdot
.748 .29014 Mdot
.748 .29018 Mdot
.748 .29175 Mdot
.748 .29455 Mdot
.748 .29472 Mdot
.748 .29552 Mdot
.748 .29689 Mdot
.748 .29739 Mdot
.748 .29786 Mdot
.748 .29837 Mdot
.748 .29908 Mdot
.748 .29909 Mdot
.748 .2995 Mdot
.748 .2997 Mdot
.748 .2997 Mdot
.748 .2997 Mdot
.748 .2997 Mdot
.748 .2997 Mdot
.748 .2997 Mdot
.748 .2997 Mdot
.748 .2997 Mdot
.748 .29971 Mdot
.748 .29971 Mdot
.748 .29971 Mdot
.748 .29971 Mdot
.748 .29972 Mdot
.748 .29973 Mdot
.748 .29974 Mdot
.748 .29975 Mdot
.748 .29976 Mdot
.748 .29982 Mdot
.748 .29983 Mdot
.748 .29985 Mdot
.748 .29988 Mdot
.748 .2999 Mdot
.748 .29993 Mdot
.748 .29996 Mdot
.748 .29997 Mdot
.748 .29997 Mdot
.748 .30172 Mdot
.748 .30687 Mdot
.748 .32034 Mdot
.748 .32737 Mdot
.748 .32873 Mdot
.748 .33947 Mdot
.748 .33948 Mdot
.748 .33948 Mdot
.748 .33948 Mdot
.748 .33948 Mdot
.748 .33948 Mdot
.748 .33948 Mdot
.748 .33949 Mdot
.748 .3395 Mdot
.748 .33951 Mdot
.748 .33951 Mdot
.748 .33952 Mdot
.748 .33952 Mdot
.748 .33954 Mdot
.748 .33958 Mdot
.748 .33959 Mdot
.748 .33963 Mdot
.748 .33978 Mdot
.748 .3398 Mdot
.748 .33987 Mdot
.748 .33999 Mdot
.748 .34009 Mdot
.748 .34019 Mdot
.748 .34067 Mdot
.748 .34076 Mdot
.748 .34083 Mdot
.748 .34226 Mdot
.748 .34287 Mdot
.748 .34366 Mdot
.748 .34412 Mdot
.748 .3445 Mdot
.748 .34578 Mdot
.748 .34626 Mdot
.748 .34635 Mdot
.748 .34857 Mdot
.748 .34858 Mdot
.748 .34859 Mdot
.748 .34859 Mdot
.748 .34864 Mdot
.748 .34874 Mdot
.748 .34875 Mdot
.748 .34877 Mdot
.748 .34893 Mdot
.748 .34901 Mdot
.748 .34925 Mdot
.748 .34933 Mdot
.748 .34951 Mdot
.748 .34952 Mdot
.748 .34954 Mdot
.748 .34961 Mdot
.748 .34984 Mdot
.748 .35002 Mdot
.748 .35021 Mdot
.748 .35044 Mdot
.748 .35061 Mdot
.748 .35064 Mdot
.748 .3507 Mdot
.748 .35073 Mdot
.748 .35084 Mdot
.748 .35089 Mdot
.748 .35097 Mdot
.748 .35099 Mdot
.748 .351 Mdot
.748 .35105 Mdot
.748 .35126 Mdot
.748 .35141 Mdot
.748 .35156 Mdot
.748 .35172 Mdot
.748 .35178 Mdot
.748 .35184 Mdot
.748 .35196 Mdot
.748 .35209 Mdot
.748 .35237 Mdot
.748 .35251 Mdot
.748 .35277 Mdot
.748 .35284 Mdot
.748 .35291 Mdot
.748 .3532 Mdot
.748 .35321 Mdot
.748 .35328 Mdot
.748 .35351 Mdot
.748 .35364 Mdot
.748 .35373 Mdot
.748 .35389 Mdot
.748 .35402 Mdot
.748 .35407 Mdot
.748 .35411 Mdot
.748 .35413 Mdot
.748 .35416 Mdot
.748 .3542 Mdot
.748 .35422 Mdot
.748 .35425 Mdot
.748 .35427 Mdot
.748 .35428 Mdot
.748 .35429 Mdot
.748 .35429 Mdot
.748 .35431 Mdot
.748 .35435 Mdot
.748 .35436 Mdot
.748 .35437 Mdot
.748 .35438 Mdot
.748 .35438 Mdot
.748 .35439 Mdot
.748 .35439 Mdot
.748 .35439 Mdot
.748 .35439 Mdot
.748 .3544 Mdot
.748 .35461 Mdot
.748 .35462 Mdot
.748 .35477 Mdot
.748 .3548 Mdot
.748 .35483 Mdot
.748 .35489 Mdot
.748 .35493 Mdot
.748 .35502 Mdot
.748 .35503 Mdot
.748 .35503 Mdot
.748 .35506 Mdot
.748 .35507 Mdot
.748 .35508 Mdot
.748 .35508 Mdot
.748 .35509 Mdot
.748 .35509 Mdot
.748 .3551 Mdot
.748 .3551 Mdot
.748 .3551 Mdot
.748 .3551 Mdot
.748 .3551 Mdot
.748 .35511 Mdot
.748 .35511 Mdot
.748 .35511 Mdot
.748 .35511 Mdot
.748 .35511 Mdot
.748 .35511 Mdot
.748 .35511 Mdot
.748 .35511 Mdot
.748 .35511 Mdot
.748 .35511 Mdot
.748 .35511 Mdot
.748 .35511 Mdot
.748 .41575 Mdot
.748 .41575 Mdot
.748 .41575 Mdot
.748 .41575 Mdot
.748 .41575 Mdot
.748 .41575 Mdot
.748 .41575 Mdot
.748 .41575 Mdot
.748 .41575 Mdot
.748 .41575 Mdot
.748 .41575 Mdot
.748 .41575 Mdot
.748 .41575 Mdot
.748 .41575 Mdot
.748 .41575 Mdot
.748 .41575 Mdot
.748 .41575 Mdot
.748 .41576 Mdot
.748 .41576 Mdot
.748 .41576 Mdot
.748 .41576 Mdot
.748 .41576 Mdot
.748 .41576 Mdot
.748 .41576 Mdot
.748 .41577 Mdot
.748 .41577 Mdot
.748 .41577 Mdot
.748 .4158 Mdot
.748 .41581 Mdot
.748 .41582 Mdot
.748 .41583 Mdot
.748 .41584 Mdot
.748 .41587 Mdot
.748 .41587 Mdot
.748 .41593 Mdot
.748 .41593 Mdot
.748 .41593 Mdot
.748 .41593 Mdot
.748 .41593 Mdot
.748 .41593 Mdot
.748 .41593 Mdot
.748 .41593 Mdot
.748 .41594 Mdot
.748 .41594 Mdot
.748 .41595 Mdot
.748 .41595 Mdot
.748 .41595 Mdot
.748 .41596 Mdot
.748 .41596 Mdot
.748 .41596 Mdot
.748 .41597 Mdot
.748 .41598 Mdot
.748 .41598 Mdot
.748 .41599 Mdot
.748 .416 Mdot
.748 .41601 Mdot
.748 .41602 Mdot
.748 .41605 Mdot
.748 .41609 Mdot
.748 .41611 Mdot
.748 .41615 Mdot
.748 .4162 Mdot
.748 .41622 Mdot
.748 .41622 Mdot
.748 .41629 Mdot
.748 .41631 Mdot
.748 .41633 Mdot
.748 .41639 Mdot
.748 .41642 Mdot
.748 .41649 Mdot
.748 .41652 Mdot
.748 .41655 Mdot
.748 .41657 Mdot
.748 .41658 Mdot
.748 .41662 Mdot
.748 .41666 Mdot
.748 .4167 Mdot
.748 .41675 Mdot
.748 .41676 Mdot
.748 .41676 Mdot
.748 .41677 Mdot
.748 .41679 Mdot
.748 .4168 Mdot
.748 .41683 Mdot
.748 .41684 Mdot
.748 .41685 Mdot
.748 .41686 Mdot
.748 .4169 Mdot
.748 .41695 Mdot
.748 .417 Mdot
.748 .41705 Mdot
.748 .4171 Mdot
.748 .41712 Mdot
.748 .41713 Mdot
.748 .41713 Mdot
.748 .41717 Mdot
.748 .41719 Mdot
.748 .41725 Mdot
.748 .41727 Mdot
.748 .41731 Mdot
.748 .41731 Mdot
.748 .41732 Mdot
.748 .41734 Mdot
.748 .41735 Mdot
.748 .41735 Mdot
.748 .41735 Mdot
.748 .41736 Mdot
.748 .4179 Mdot
.748 .41793 Mdot
.748 .41805 Mdot
.748 .41836 Mdot
.748 .41846 Mdot
.748 .41857 Mdot
.748 .41877 Mdot
.748 .41892 Mdot
.748 .41927 Mdot
.748 .41929 Mdot
.748 .41931 Mdot
.748 .41943 Mdot
.748 .41946 Mdot
.748 .41948 Mdot
.748 .41951 Mdot
.748 .41953 Mdot
.748 .41953 Mdot
.748 .41957 Mdot
.748 .41958 Mdot
.748 .41958 Mdot
.748 .41959 Mdot
.748 .4196 Mdot
.748 .4196 Mdot
.748 .4196 Mdot
.748 .4196 Mdot
.748 .4196 Mdot
.748 .41961 Mdot
.748 .41961 Mdot
.748 .41961 Mdot
.748 .41961 Mdot
.748 .41961 Mdot
.748 .41961 Mdot
.748 .41961 Mdot
.748 .41961 Mdot
.748 .42233 Mdot
.748 .42268 Mdot
.748 .42452 Mdot
.748 .42825 Mdot
.748 .42978 Mdot
.748 .43031 Mdot
.748 .43031 Mdot
.748 .43032 Mdot
.748 .43033 Mdot
.748 .43033 Mdot
.748 .43034 Mdot
.748 .43035 Mdot
.748 .43036 Mdot
.748 .43036 Mdot
.748 .43038 Mdot
.748 .43038 Mdot
.748 .43038 Mdot
.748 .43039 Mdot
.748 .43039 Mdot
.748 .43039 Mdot
.748 .43039 Mdot
.748 .43039 Mdot
.748 .43039 Mdot
.748 .4304 Mdot
.748 .4304 Mdot
.748 .4304 Mdot
.748 .4304 Mdot
.748 .4304 Mdot
.748 .4304 Mdot
.748 .4304 Mdot
.748 .4304 Mdot
.748 .43046 Mdot
.748 .43058 Mdot
.748 .43059 Mdot
.748 .43081 Mdot
.748 .43097 Mdot
.748 .43112 Mdot
.748 .43128 Mdot
.748 .43172 Mdot
.748 .43198 Mdot
.748 .43203 Mdot
.748 .43296 Mdot
.748 .4335 Mdot
.748 .43351 Mdot
.748 .43352 Mdot
.748 .43352 Mdot
.748 .43356 Mdot
.748 .43363 Mdot
.748 .43364 Mdot
.748 .43365 Mdot
.748 .43378 Mdot
.748 .43383 Mdot
.748 .43402 Mdot
.748 .43409 Mdot
.748 .43423 Mdot
.748 .43424 Mdot
.748 .43426 Mdot
.748 .43431 Mdot
.748 .4345 Mdot
.748 .43466 Mdot
.748 .43482 Mdot
.748 .43502 Mdot
.748 .43516 Mdot
.748 .43519 Mdot
.748 .43524 Mdot
.748 .43527 Mdot
.748 .43528 Mdot
.748 .43537 Mdot
.748 .43541 Mdot
.748 .43542 Mdot
.748 .43546 Mdot
.748 .43548 Mdot
.748 .4355 Mdot
.748 .43551 Mdot
.748 .43556 Mdot
.748 .43566 Mdot
.748 .43575 Mdot
.748 .43588 Mdot
.748 .43602 Mdot
.748 .43617 Mdot
.748 .43623 Mdot
.748 .43628 Mdot
.748 .4364 Mdot
.748 .43642 Mdot
.748 .43652 Mdot
.748 .43679 Mdot
.748 .4369 Mdot
.748 .43693 Mdot
.748 .43718 Mdot
.748 .43725 Mdot
.748 .43732 Mdot
.748 .43744 Mdot
.748 .43759 Mdot
.748 .43759 Mdot
.748 .43759 Mdot
.748 .43759 Mdot
.748 .43759 Mdot
.748 .4376 Mdot
.748 .4376 Mdot
.748 .4376 Mdot
.748 .43761 Mdot
.748 .43762 Mdot
.748 .43764 Mdot
.748 .43765 Mdot
.748 .43765 Mdot
.748 .43765 Mdot
.748 .43767 Mdot
.748 .43768 Mdot
.748 .43769 Mdot
.748 .43775 Mdot
.748 .43777 Mdot
.748 .43782 Mdot
.748 .43791 Mdot
.748 .43802 Mdot
.748 .43804 Mdot
.748 .43805 Mdot
.748 .43812 Mdot
.748 .43814 Mdot
.748 .43825 Mdot
.748 .4383 Mdot
.748 .43833 Mdot
.748 .4384 Mdot
.748 .43843 Mdot
.748 .43849 Mdot
.748 .43852 Mdot
.748 .43854 Mdot
.748 .43854 Mdot
.748 .43855 Mdot
.748 .43856 Mdot
.748 .43858 Mdot
.748 .43861 Mdot
.748 .43864 Mdot
.748 .43867 Mdot
.748 .4387 Mdot
.748 .4387 Mdot
.748 .43871 Mdot
.748 .43871 Mdot
.748 .43873 Mdot
.748 .43877 Mdot
.748 .43878 Mdot
.748 .4388 Mdot
.748 .4388 Mdot
.748 .4388 Mdot
.748 .43881 Mdot
.748 .43882 Mdot
.748 .43882 Mdot
.748 .43882 Mdot
.748 .43882 Mdot
.748 .43905 Mdot
.748 .43906 Mdot
.748 .43921 Mdot
.748 .43924 Mdot
.748 .43928 Mdot
.748 .43934 Mdot
.748 .43938 Mdot
.748 .43948 Mdot
.748 .43948 Mdot
.748 .43949 Mdot
.748 .43952 Mdot
.748 .43953 Mdot
.748 .43953 Mdot
.748 .43954 Mdot
.748 .43955 Mdot
.748 .43955 Mdot
.748 .43956 Mdot
.748 .43956 Mdot
.748 .43956 Mdot
.748 .43956 Mdot
.748 .43956 Mdot
.748 .43956 Mdot
.748 .43956 Mdot
.748 .43956 Mdot
.748 .43956 Mdot
.748 .43957 Mdot
.748 .43957 Mdot
.748 .43957 Mdot
.748 .43957 Mdot
.748 .43957 Mdot
.748 .43957 Mdot
.748 .43957 Mdot
.748 .43957 Mdot
.748 .44175 Mdot
.748 .44365 Mdot
.748 .44365 Mdot
.748 .44365 Mdot
.748 .4437 Mdot
.748 .44372 Mdot
.748 .44374 Mdot
.748 .44378 Mdot
.748 .44381 Mdot
.748 .44381 Mdot
.748 .44387 Mdot
.748 .44389 Mdot
.748 .4439 Mdot
.748 .44391 Mdot
.748 .44392 Mdot
.748 .44392 Mdot
.748 .44393 Mdot
.748 .44393 Mdot
.748 .44393 Mdot
.748 .44394 Mdot
.748 .44394 Mdot
.748 .44394 Mdot
.748 .44394 Mdot
.748 .44394 Mdot
.748 .44394 Mdot
.748 .44394 Mdot
.748 .44394 Mdot
.748 .44416 Mdot
.748 .4446 Mdot
.748 .44461 Mdot
.748 .44465 Mdot
.748 .44537 Mdot
.748 .44591 Mdot
.748 .4464 Mdot
.748 .44692 Mdot
.748 .4483 Mdot
.748 .44908 Mdot
.748 .44923 Mdot
.748 .45062 Mdot
.748 .45062 Mdot
.748 .45062 Mdot
.748 .45062 Mdot
.748 .45062 Mdot
.748 .45062 Mdot
.748 .45062 Mdot
.748 .45062 Mdot
.748 .45062 Mdot
.748 .45062 Mdot
.748 .45062 Mdot
.748 .45062 Mdot
.748 .45062 Mdot
.748 .45063 Mdot
.748 .45063 Mdot
.748 .45063 Mdot
.748 .45064 Mdot
.748 .45066 Mdot
.748 .45066 Mdot
.748 .45067 Mdot
.748 .45069 Mdot
.748 .45071 Mdot
.748 .45072 Mdot
.748 .45079 Mdot
.748 .45081 Mdot
.748 .45082 Mdot
.748 .45104 Mdot
.748 .45114 Mdot
.748 .45127 Mdot
.748 .45135 Mdot
.748 .45141 Mdot
.748 .45164 Mdot
.748 .45173 Mdot
.748 .45175 Mdot
.748 .4522 Mdot
.748 .45221 Mdot
.748 .45221 Mdot
.748 .45221 Mdot
.748 .45222 Mdot
.748 .45224 Mdot
.748 .45225 Mdot
.748 .45225 Mdot
.748 .45229 Mdot
.748 .4523 Mdot
.748 .45236 Mdot
.748 .45238 Mdot
.748 .45242 Mdot
.748 .45242 Mdot
.748 .45243 Mdot
.748 .45244 Mdot
.748 .4525 Mdot
.748 .45255 Mdot
.748 .45259 Mdot
.748 .45265 Mdot
.748 .4527 Mdot
.748 .45271 Mdot
.748 .45272 Mdot
.748 .45273 Mdot
.748 .45276 Mdot
.748 .45277 Mdot
.748 .4528 Mdot
.748 .4528 Mdot
.748 .4528 Mdot
.748 .45282 Mdot
.748 .45288 Mdot
.748 .45292 Mdot
.748 .45297 Mdot
.748 .45302 Mdot
.748 .45303 Mdot
.748 .45305 Mdot
.748 .45309 Mdot
.748 .45313 Mdot
.748 .45323 Mdot
.748 .45328 Mdot
.748 .45337 Mdot
.748 .4534 Mdot
.748 .45342 Mdot
.748 .45353 Mdot
.748 .45354 Mdot
.748 .45357 Mdot
.748 .45367 Mdot
.748 .45373 Mdot
.748 .45377 Mdot
.748 .45385 Mdot
.748 .45392 Mdot
.748 .45395 Mdot
.748 .45397 Mdot
.748 .45398 Mdot
.748 .454 Mdot
.748 .45402 Mdot
.748 .45403 Mdot
.748 .45405 Mdot
.748 .45407 Mdot
.748 .45407 Mdot
.748 .45407 Mdot
.748 .45407 Mdot
.748 .45409 Mdot
.748 .45411 Mdot
.748 .45412 Mdot
.748 .45413 Mdot
.748 .45413 Mdot
.748 .45413 Mdot
.748 .45414 Mdot
.748 .45414 Mdot
.748 .45414 Mdot
.748 .45414 Mdot
.748 .45415 Mdot
.748 .45431 Mdot
.748 .45431 Mdot
.748 .45444 Mdot
.748 .45447 Mdot
.748 .45451 Mdot
.748 .45457 Mdot
.748 .45463 Mdot
.748 .45478 Mdot
.748 .45479 Mdot
.748 .4548 Mdot
.748 .45487 Mdot
.748 .45489 Mdot
.748 .45491 Mdot
.748 .45493 Mdot
.748 .45495 Mdot
.748 .45496 Mdot
.748 .455 Mdot
.748 .45501 Mdot
.748 .45502 Mdot
.748 .45502 Mdot
.748 .45504 Mdot
.748 .45505 Mdot
.748 .45505 Mdot
.748 .45506 Mdot
.748 .45506 Mdot
.748 .45506 Mdot
.748 .45507 Mdot
.748 .4551 Mdot
.748 .4551 Mdot
.748 .45511 Mdot
.748 .45512 Mdot
.748 .45512 Mdot
.748 .45513 Mdot
.748 .45513 Mdot
.75 .25976 Mdot
.75 .25976 Mdot
.75 .25976 Mdot
.75 .25977 Mdot
.75 .25977 Mdot
.75 .25977 Mdot
.75 .25977 Mdot
.75 .25977 Mdot
.75 .25977 Mdot
.75 .25977 Mdot
.75 .25977 Mdot
.75 .25978 Mdot
.75 .25978 Mdot
.75 .25978 Mdot
.75 .25978 Mdot
.75 .25979 Mdot
.75 .25979 Mdot
.75 .25979 Mdot
.75 .25979 Mdot
.75 .2598 Mdot
.75 .2598 Mdot
.75 .2598 Mdot
.75 .2598 Mdot
.75 .2598 Mdot
.75 .2598 Mdot
.75 .2598 Mdot
.75 .2598 Mdot
.75 .2598 Mdot
.75 .2598 Mdot
.75 .2598 Mdot
.75 .25981 Mdot
.75 .25981 Mdot
.75 .25981 Mdot
.75 .25983 Mdot
.75 .25984 Mdot
.75 .25984 Mdot
.75 .25984 Mdot
.75 .25985 Mdot
.75 .25985 Mdot
.75 .25985 Mdot
.75 .25987 Mdot
.75 .2599 Mdot
.75 .2599 Mdot
.75 .25992 Mdot
.75 .25994 Mdot
.75 .25995 Mdot
.75 .25999 Mdot
.75 .26 Mdot
.75 .26002 Mdot
.75 .26004 Mdot
.75 .26004 Mdot
.75 .26007 Mdot
.75 .26007 Mdot
.75 .2601 Mdot
.75 .26012 Mdot
.75 .26013 Mdot
.75 .26013 Mdot
.75 .26019 Mdot
.75 .26022 Mdot
.75 .26023 Mdot
.75 .26031 Mdot
.75 .26033 Mdot
.75 .26035 Mdot
.75 .26038 Mdot
.75 .26041 Mdot
.75 .26042 Mdot
.75 .26055 Mdot
.75 .2606 Mdot
.75 .26069 Mdot
.75 .2607 Mdot
.75 .2608 Mdot
.75 .26092 Mdot
.75 .26104 Mdot
.75 .26106 Mdot
.75 .26128 Mdot
.75 .2613 Mdot
.75 .26136 Mdot
.75 .26139 Mdot
.75 .26151 Mdot
.75 .26157 Mdot
.75 .26165 Mdot
.75 .26168 Mdot
.75 .26178 Mdot
.75 .26185 Mdot
.75 .26188 Mdot
.75 .26188 Mdot
.75 .26188 Mdot
.75 .26191 Mdot
.75 .26191 Mdot
.75 .26192 Mdot
.75 .26196 Mdot
.75 .26198 Mdot
.75 .2621 Mdot
.75 .26212 Mdot
.75 .26212 Mdot
.75 .26213 Mdot
.75 .26213 Mdot
.75 .26214 Mdot
.75 .26216 Mdot
.75 .26216 Mdot
.75 .26216 Mdot
.75 .26217 Mdot
.75 .26217 Mdot
.75 .26217 Mdot
.75 .26217 Mdot
.75 .26218 Mdot
.75 .26219 Mdot
.75 .2622 Mdot
.75 .26223 Mdot
.75 .26224 Mdot
.75 .26224 Mdot
.75 .26228 Mdot
.75 .26228 Mdot
.75 .2623 Mdot
.75 .26233 Mdot
.75 .26235 Mdot
.75 .26235 Mdot
.75 .26238 Mdot
.75 .26238 Mdot
.75 .26239 Mdot
.75 .26239 Mdot
.75 .2624 Mdot
.75 .26241 Mdot
.75 .26242 Mdot
.75 .26244 Mdot
.75 .26244 Mdot
.75 .26244 Mdot
.75 .26244 Mdot
.75 .26245 Mdot
.75 .26245 Mdot
.75 .26246 Mdot
.75 .26247 Mdot
.75 .26249 Mdot
.75 .26251 Mdot
.75 .26251 Mdot
.75 .26252 Mdot
.75 .26263 Mdot
.75 .26266 Mdot
.75 .26269 Mdot
.75 .26273 Mdot
.75 .26274 Mdot
.75 .26275 Mdot
.75 .26275 Mdot
.75 .26275 Mdot
.75 .26281 Mdot
.75 .26285 Mdot
.75 .26287 Mdot
.75 .26287 Mdot
.75 .26298 Mdot
.75 .26299 Mdot
.75 .26299 Mdot
.75 .26302 Mdot
.75 .26303 Mdot
.75 .26305 Mdot
.75 .26305 Mdot
.75 .26307 Mdot
.75 .26309 Mdot
.75 .26309 Mdot
.75 .26311 Mdot
.75 .26311 Mdot
.75 .26312 Mdot
.75 .26312 Mdot
.75 .26313 Mdot
.75 .26313 Mdot
.75 .26313 Mdot
.75 .26313 Mdot
.75 .26313 Mdot
.75 .27662 Mdot
.75 .27772 Mdot
.75 .27774 Mdot
.75 .27774 Mdot
.75 .27776 Mdot
.75 .27777 Mdot
.75 .27785 Mdot
.75 .278 Mdot
.75 .27808 Mdot
.75 .27813 Mdot
.75 .27854 Mdot
.75 .27857 Mdot
.75 .27895 Mdot
.75 .27895 Mdot
.75 .27942 Mdot
.75 .27951 Mdot
.75 .27991 Mdot
.75 .28013 Mdot
.75 .28066 Mdot
.75 .28076 Mdot
.75 .28085 Mdot
.75 .28101 Mdot
.75 .28185 Mdot
.75 .28268 Mdot
.75 .28288 Mdot
.75 .28328 Mdot
.75 .2833 Mdot
.75 .2838 Mdot
.75 .28463 Mdot
.75 .28578 Mdot
.75 .28578 Mdot
.75 .28588 Mdot
.75 .28609 Mdot
.75 .2862 Mdot
.75 .28636 Mdot
.75 .28714 Mdot
.75 .28765 Mdot
.75 .28765 Mdot
.75 .28833 Mdot
.75 .28875 Mdot
.75 .28937 Mdot
.75 .29041 Mdot
.75 .2907 Mdot
.75 .29072 Mdot
.75 .29083 Mdot
.75 .29106 Mdot
.75 .29131 Mdot
.75 .29137 Mdot
.75 .29146 Mdot
.75 .29154 Mdot
.75 .29155 Mdot
.75 .29169 Mdot
.75 .29173 Mdot
.75 .29183 Mdot
.75 .29192 Mdot
.75 .29199 Mdot
.75 .29199 Mdot
.75 .2922 Mdot
.75 .29233 Mdot
.75 .29236 Mdot
.75 .29265 Mdot
.75 .29271 Mdot
.75 .29276 Mdot
.75 .29285 Mdot
.75 .29295 Mdot
.75 .29297 Mdot
.75 .29333 Mdot
.75 .29344 Mdot
.75 .29368 Mdot
.75 .29369 Mdot
.75 .29392 Mdot
.75 .29415 Mdot
.75 .29439 Mdot
.75 .29443 Mdot
.75 .29482 Mdot
.75 .29486 Mdot
.75 .29495 Mdot
.75 .295 Mdot
.75 .29519 Mdot
.75 .29527 Mdot
.75 .29539 Mdot
.75 .29544 Mdot
.75 .29558 Mdot
.75 .29567 Mdot
.75 .29571 Mdot
.75 .29572 Mdot
.75 .29572 Mdot
.75 .29575 Mdot
.75 .29577 Mdot
.75 .29578 Mdot
.75 .29583 Mdot
.75 .29585 Mdot
.75 .29601 Mdot
.75 .29604 Mdot
.75 .29604 Mdot
.75 .29605 Mdot
.75 .29605 Mdot
.75 .29606 Mdot
.75 .29608 Mdot
.75 .29609 Mdot
.75 .29609 Mdot
.75 .29609 Mdot
.75 .29609 Mdot
.75 .2961 Mdot
.75 .29611 Mdot
.75 .29613 Mdot
.75 .29613 Mdot
.75 .29617 Mdot
.75 .29618 Mdot
.75 .29619 Mdot
.75 .29623 Mdot
.75 .29623 Mdot
.75 .29625 Mdot
.75 .29629 Mdot
.75 .29631 Mdot
.75 .29632 Mdot
.75 .29635 Mdot
.75 .29636 Mdot
.75 .29636 Mdot
.75 .29637 Mdot
.75 .29637 Mdot
.75 .29639 Mdot
.75 .2964 Mdot
.75 .29642 Mdot
.75 .29642 Mdot
.75 .29642 Mdot
.75 .29643 Mdot
.75 .29644 Mdot
.75 .29644 Mdot
.75 .29645 Mdot
.75 .29646 Mdot
.75 .29648 Mdot
.75 .2965 Mdot
.75 .2965 Mdot
.75 .29652 Mdot
.75 .29664 Mdot
.75 .29668 Mdot
.75 .29671 Mdot
.75 .29675 Mdot
.75 .29676 Mdot
.75 .29677 Mdot
.75 .29678 Mdot
.75 .29678 Mdot
.75 .29684 Mdot
.75 .29688 Mdot
.75 .2969 Mdot
.75 .2969 Mdot
.75 .29702 Mdot
.75 .29703 Mdot
.75 .29703 Mdot
.75 .29706 Mdot
.75 .29707 Mdot
.75 .29709 Mdot
.75 .29709 Mdot
.75 .29712 Mdot
.75 .29713 Mdot
.75 .29714 Mdot
.75 .29716 Mdot
.75 .29716 Mdot
.75 .29716 Mdot
.75 .29717 Mdot
.75 .29717 Mdot
.75 .29717 Mdot
.75 .29717 Mdot
.75 .29717 Mdot
.75 .29718 Mdot
.75 .30576 Mdot
.75 .30577 Mdot
.75 .30577 Mdot
.75 .30578 Mdot
.75 .30579 Mdot
.75 .30582 Mdot
.75 .30589 Mdot
.75 .30592 Mdot
.75 .30594 Mdot
.75 .30613 Mdot
.75 .30614 Mdot
.75 .30631 Mdot
.75 .30652 Mdot
.75 .30656 Mdot
.75 .30674 Mdot
.75 .30684 Mdot
.75 .30707 Mdot
.75 .30711 Mdot
.75 .30715 Mdot
.75 .30823 Mdot
.75 .30824 Mdot
.75 .30846 Mdot
.75 .30884 Mdot
.75 .30936 Mdot
.75 .30936 Mdot
.75 .30941 Mdot
.75 .30951 Mdot
.75 .30963 Mdot
.75 .31 Mdot
.75 .31024 Mdot
.75 .31058 Mdot
.75 .31164 Mdot
.75 .31179 Mdot
.75 .31181 Mdot
.75 .31199 Mdot
.75 .31217 Mdot
.75 .31227 Mdot
.75 .31236 Mdot
.75 .31237 Mdot
.75 .31243 Mdot
.75 .31248 Mdot
.75 .31253 Mdot
.75 .31253 Mdot
.75 .31266 Mdot
.75 .31275 Mdot
.75 .31293 Mdot
.75 .31296 Mdot
.75 .313 Mdot
.75 .31305 Mdot
.75 .31312 Mdot
.75 .31337 Mdot
.75 .31344 Mdot
.75 .31361 Mdot
.75 .31395 Mdot
.75 .31412 Mdot
.75 .31416 Mdot
.75 .3145 Mdot
.75 .31458 Mdot
.75 .31462 Mdot
.75 .31496 Mdot
.75 .31501 Mdot
.75 .31515 Mdot
.75 .31524 Mdot
.75 .31528 Mdot
.75 .31528 Mdot
.75 .31528 Mdot
.75 .31533 Mdot
.75 .31534 Mdot
.75 .3154 Mdot
.75 .3156 Mdot
.75 .31563 Mdot
.75 .31563 Mdot
.75 .31573 Mdot
.75 .31574 Mdot
.75 .31598 Mdot
.75 .31726 Mdot
.75 .31748 Mdot
.75 .31788 Mdot
.75 .31795 Mdot
.75 .31805 Mdot
.75 .31834 Mdot
.75 .31834 Mdot
.75 .31836 Mdot
.75 .31868 Mdot
.75 .31941 Mdot
.75 .32049 Mdot
.75 .32085 Mdot
.75 .32174 Mdot
.75 .32236 Mdot
.75 .32367 Mdot
.75 .32402 Mdot
.75 .32467 Mdot
.75 .32492 Mdot
.75 .32744 Mdot
.75 .32771 Mdot
.75 .32912 Mdot
.75 .33047 Mdot
.75 .3317 Mdot
.75 .33176 Mdot
.75 .33294 Mdot
.75 .33349 Mdot
.75 .33506 Mdot
.75 .33514 Mdot
.75 .33558 Mdot
.75 .33593 Mdot
.75 .33614 Mdot
.75 .33635 Mdot
.75 .33741 Mdot
.75 .33748 Mdot
.75 .33791 Mdot
.75 .33856 Mdot
.75 .33857 Mdot
.75 .33879 Mdot
.75 .33903 Mdot
.75 .33931 Mdot
.75 .3394 Mdot
.75 .33976 Mdot
.75 .33978 Mdot
.75 .33999 Mdot
.75 .34018 Mdot
.75 .34033 Mdot
.75 .34085 Mdot
.75 .34103 Mdot
.75 .34126 Mdot
.75 .34145 Mdot
.75 .34149 Mdot
.75 .34191 Mdot
.75 .34217 Mdot
.75 .34217 Mdot
.75 .34218 Mdot
.75 .3422 Mdot
.75 .34223 Mdot
.75 .3423 Mdot
.75 .34241 Mdot
.75 .34263 Mdot
.75 .34263 Mdot
.75 .34266 Mdot
.75 .34269 Mdot
.75 .34271 Mdot
.75 .34272 Mdot
.75 .34272 Mdot
.75 .34273 Mdot
.75 .34274 Mdot
.75 .34275 Mdot
.75 .34275 Mdot
.75 .34277 Mdot
.75 .34278 Mdot
.75 .34281 Mdot
.75 .34282 Mdot
.75 .34282 Mdot
.75 .34289 Mdot
.75 .34292 Mdot
.75 .34297 Mdot
.75 .34299 Mdot
.75 .343 Mdot
.75 .34306 Mdot
.75 .34307 Mdot
.75 .34314 Mdot
.75 .34316 Mdot
.75 .34316 Mdot
.75 .34316 Mdot
.75 .34317 Mdot
.75 .34317 Mdot
.75 .34318 Mdot
.75 .34321 Mdot
.75 .34321 Mdot
.75 .34321 Mdot
.75 .4189 Mdot
.75 .4189 Mdot
.75 .4189 Mdot
.75 .41891 Mdot
.75 .41891 Mdot
.75 .41891 Mdot
.75 .41891 Mdot
.75 .41891 Mdot
.75 .41891 Mdot
.75 .41892 Mdot
.75 .41893 Mdot
.75 .41894 Mdot
.75 .41895 Mdot
.75 .41895 Mdot
.75 .41896 Mdot
.75 .41897 Mdot
.75 .41898 Mdot
.75 .41899 Mdot
.75 .419 Mdot
.75 .419 Mdot
.75 .419 Mdot
.75 .41901 Mdot
.75 .41901 Mdot
.75 .41901 Mdot
.75 .41901 Mdot
.75 .41902 Mdot
.75 .41902 Mdot
.75 .41902 Mdot
.75 .41902 Mdot
.75 .41903 Mdot
.75 .41903 Mdot
.75 .41904 Mdot
.75 .41904 Mdot
.75 .4191 Mdot
.75 .41912 Mdot
.75 .41914 Mdot
.75 .41915 Mdot
.75 .41915 Mdot
.75 .41916 Mdot
.75 .41916 Mdot
.75 .41922 Mdot
.75 .41933 Mdot
.75 .41933 Mdot
.75 .41938 Mdot
.75 .41944 Mdot
.75 .41948 Mdot
.75 .41961 Mdot
.75 .41965 Mdot
.75 .4197 Mdot
.75 .41975 Mdot
.75 .41975 Mdot
.75 .41985 Mdot
.75 .41987 Mdot
.75 .41994 Mdot
.75 .42 Mdot
.75 .42005 Mdot
.75 .42006 Mdot
.75 .42022 Mdot
.75 .42033 Mdot
.75 .42034 Mdot
.75 .42061 Mdot
.75 .42066 Mdot
.75 .42071 Mdot
.75 .4208 Mdot
.75 .42091 Mdot
.75 .42093 Mdot
.75 .42133 Mdot
.75 .42147 Mdot
.75 .42177 Mdot
.75 .42178 Mdot
.75 .4221 Mdot
.75 .42244 Mdot
.75 .42281 Mdot
.75 .42288 Mdot
.75 .42353 Mdot
.75 .4236 Mdot
.75 .42377 Mdot
.75 .42386 Mdot
.75 .4242 Mdot
.75 .42437 Mdot
.75 .4246 Mdot
.75 .4247 Mdot
.75 .42499 Mdot
.75 .42518 Mdot
.75 .42527 Mdot
.75 .42528 Mdot
.75 .42528 Mdot
.75 .42536 Mdot
.75 .42538 Mdot
.75 .4254 Mdot
.75 .42551 Mdot
.75 .42557 Mdot
.75 .42592 Mdot
.75 .42598 Mdot
.75 .42598 Mdot
.75 .42601 Mdot
.75 .42601 Mdot
.75 .42602 Mdot
.75 .42608 Mdot
.75 .42609 Mdot
.75 .42609 Mdot
.75 .42611 Mdot
.75 .42611 Mdot
.75 .42611 Mdot
.75 .42612 Mdot
.75 .42615 Mdot
.75 .42618 Mdot
.75 .4262 Mdot
.75 .42629 Mdot
.75 .4263 Mdot
.75 .42632 Mdot
.75 .42642 Mdot
.75 .42643 Mdot
.75 .42648 Mdot
.75 .42657 Mdot
.75 .42662 Mdot
.75 .42664 Mdot
.75 .4267 Mdot
.75 .42672 Mdot
.75 .42674 Mdot
.75 .42675 Mdot
.75 .42676 Mdot
.75 .42681 Mdot
.75 .42683 Mdot
.75 .42687 Mdot
.75 .42687 Mdot
.75 .42688 Mdot
.75 .4269 Mdot
.75 .42691 Mdot
.75 .42692 Mdot
.75 .42694 Mdot
.75 .42697 Mdot
.75 .42702 Mdot
.75 .42707 Mdot
.75 .42707 Mdot
.75 .42712 Mdot
.75 .42742 Mdot
.75 .42751 Mdot
.75 .42758 Mdot
.75 .42769 Mdot
.75 .42772 Mdot
.75 .42775 Mdot
.75 .42776 Mdot
.75 .42776 Mdot
.75 .42791 Mdot
.75 .42802 Mdot
.75 .42808 Mdot
.75 .42809 Mdot
.75 .4284 Mdot
.75 .42841 Mdot
.75 .42842 Mdot
.75 .42849 Mdot
.75 .42852 Mdot
.75 .42857 Mdot
.75 .42858 Mdot
.75 .42864 Mdot
.75 .42869 Mdot
.75 .4287 Mdot
.75 .42875 Mdot
.75 .42876 Mdot
.75 .42877 Mdot
.75 .42879 Mdot
.75 .4288 Mdot
.75 .4288 Mdot
.75 .4288 Mdot
.75 .4288 Mdot
.75 .4288 Mdot
.75 .43143 Mdot
.75 .43143 Mdot
.75 .43143 Mdot
.75 .43143 Mdot
.75 .43143 Mdot
.75 .43143 Mdot
.75 .43143 Mdot
.75 .43143 Mdot
.75 .43143 Mdot
.75 .43144 Mdot
.75 .43144 Mdot
.75 .43145 Mdot
.75 .43145 Mdot
.75 .43145 Mdot
.75 .43146 Mdot
.75 .43146 Mdot
.75 .43147 Mdot
.75 .43147 Mdot
.75 .43147 Mdot
.75 .43151 Mdot
.75 .43151 Mdot
.75 .43152 Mdot
.75 .43153 Mdot
.75 .43155 Mdot
.75 .43155 Mdot
.75 .43155 Mdot
.75 .43156 Mdot
.75 .43156 Mdot
.75 .43158 Mdot
.75 .43158 Mdot
.75 .4316 Mdot
.75 .43164 Mdot
.75 .43164 Mdot
.75 .43164 Mdot
.75 .43165 Mdot
.75 .43166 Mdot
.75 .43166 Mdot
.75 .43166 Mdot
.75 .43166 Mdot
.75 .43167 Mdot
.75 .43167 Mdot
.75 .43167 Mdot
.75 .43167 Mdot
.75 .43167 Mdot
.75 .43168 Mdot
.75 .43168 Mdot
.75 .43168 Mdot
.75 .43169 Mdot
.75 .43169 Mdot
.75 .43169 Mdot
.75 .4317 Mdot
.75 .4317 Mdot
.75 .43171 Mdot
.75 .43172 Mdot
.75 .43173 Mdot
.75 .43173 Mdot
.75 .43174 Mdot
.75 .43175 Mdot
.75 .43175 Mdot
.75 .43176 Mdot
.75 .43176 Mdot
.75 .43177 Mdot
.75 .43177 Mdot
.75 .43177 Mdot
.75 .43177 Mdot
.75 .43178 Mdot
.75 .43178 Mdot
.75 .43178 Mdot
.75 .43179 Mdot
.75 .43179 Mdot
.75 .43179 Mdot
.75 .43179 Mdot
.75 .43179 Mdot
.75 .4318 Mdot
.75 .43185 Mdot
.75 .43186 Mdot
.75 .43188 Mdot
.75 .43188 Mdot
.75 .43188 Mdot
.75 .4319 Mdot
.75 .4319 Mdot
.75 .4319 Mdot
.75 .43191 Mdot
.75 .43194 Mdot
.75 .43199 Mdot
.75 .432 Mdot
.75 .43204 Mdot
.75 .43207 Mdot
.75 .43213 Mdot
.75 .43214 Mdot
.75 .43218 Mdot
.75 .43219 Mdot
.75 .43231 Mdot
.75 .43233 Mdot
.75 .43241 Mdot
.75 .43249 Mdot
.75 .43256 Mdot
.75 .43257 Mdot
.75 .43264 Mdot
.75 .43268 Mdot
.75 .43268 Mdot
.75 .4328 Mdot
.75 .43281 Mdot
.75 .43284 Mdot
.75 .43287 Mdot
.75 .43289 Mdot
.75 .43291 Mdot
.75 .43301 Mdot
.75 .43302 Mdot
.75 .43306 Mdot
.75 .43313 Mdot
.75 .43313 Mdot
.75 .43316 Mdot
.75 .43319 Mdot
.75 .43322 Mdot
.75 .43323 Mdot
.75 .43328 Mdot
.75 .43328 Mdot
.75 .43331 Mdot
.75 .43334 Mdot
.75 .43337 Mdot
.75 .43345 Mdot
.75 .43353 Mdot
.75 .43357 Mdot
.75 .43358 Mdot
.75 .43368 Mdot
.75 .43404 Mdot
.75 .43426 Mdot
.75 .43441 Mdot
.75 .43465 Mdot
.75 .43466 Mdot
.75 .43484 Mdot
.75 .43513 Mdot
.75 .43519 Mdot
.75 .43523 Mdot
.75 .43531 Mdot
.75 .43534 Mdot
.75 .43535 Mdot
.75 .43578 Mdot
.75 .4361 Mdot
.75 .43629 Mdot
.75 .4363 Mdot
.75 .43646 Mdot
.75 .43654 Mdot
.75 .43687 Mdot
.75 .43722 Mdot
.75 .43728 Mdot
.75 .43732 Mdot
.75 .43736 Mdot
.75 .43758 Mdot
.75 .43768 Mdot
.75 .43784 Mdot
.75 .43788 Mdot
.75 .43808 Mdot
.75 .43809 Mdot
.75 .43825 Mdot
.75 .43827 Mdot
.75 .43845 Mdot
.75 .43847 Mdot
.75 .4385 Mdot
.75 .43857 Mdot
.75 .43861 Mdot
.75 .43861 Mdot
.75 .43862 Mdot
.75 .43862 Mdot
.75 .43863 Mdot
.75 .43913 Mdot
.75 .44778 Mdot
.75 .44778 Mdot
.75 .44778 Mdot
.75 .44779 Mdot
.75 .44779 Mdot
.75 .44779 Mdot
.75 .4478 Mdot
.75 .4478 Mdot
.75 .4478 Mdot
.75 .44783 Mdot
.75 .44783 Mdot
.75 .44785 Mdot
.75 .44787 Mdot
.75 .44787 Mdot
.75 .44789 Mdot
.75 .44791 Mdot
.75 .44793 Mdot
.75 .44794 Mdot
.75 .44794 Mdot
.75 .44806 Mdot
.75 .44807 Mdot
.75 .44809 Mdot
.75 .44813 Mdot
.75 .44819 Mdot
.75 .44819 Mdot
.75 .4482 Mdot
.75 .44821 Mdot
.75 .44822 Mdot
.75 .44827 Mdot
.75 .4483 Mdot
.75 .44833 Mdot
.75 .44846 Mdot
.75 .44848 Mdot
.75 .44848 Mdot
.75 .4485 Mdot
.75 .44852 Mdot
.75 .44853 Mdot
.75 .44854 Mdot
.75 .44854 Mdot
.75 .44855 Mdot
.75 .44856 Mdot
.75 .44856 Mdot
.75 .44856 Mdot
.75 .44858 Mdot
.75 .44859 Mdot
.75 .44861 Mdot
.75 .44861 Mdot
.75 .44862 Mdot
.75 .44862 Mdot
.75 .44863 Mdot
.75 .44866 Mdot
.75 .44867 Mdot
.75 .44869 Mdot
.75 .44873 Mdot
.75 .44875 Mdot
.75 .44876 Mdot
.75 .4488 Mdot
.75 .44881 Mdot
.75 .44881 Mdot
.75 .44885 Mdot
.75 .44886 Mdot
.75 .44887 Mdot
.75 .44888 Mdot
.75 .44889 Mdot
.75 .44889 Mdot
.75 .44889 Mdot
.75 .4489 Mdot
.75 .4489 Mdot
.75 .4489 Mdot
.75 .44893 Mdot
.75 .44893 Mdot
.75 .44893 Mdot
.75 .44894 Mdot
.75 .44895 Mdot
.75 .44897 Mdot
.75 .44913 Mdot
.75 .44916 Mdot
.75 .44921 Mdot
.75 .44922 Mdot
.75 .44923 Mdot
.75 .44927 Mdot
.75 .44927 Mdot
.75 .44927 Mdot
.75 .44931 Mdot
.75 .4494 Mdot
.75 .44954 Mdot
.75 .44959 Mdot
.75 .4497 Mdot
.75 .44979 Mdot
.75 .44996 Mdot
.75 .45001 Mdot
.75 .4501 Mdot
.75 .45014 Mdot
.75 .4505 Mdot
.75 .45054 Mdot
.75 .45076 Mdot
.75 .45098 Mdot
.75 .45119 Mdot
.75 .4512 Mdot
.75 .45141 Mdot
.75 .45151 Mdot
.75 .45181 Mdot
.75 .45183 Mdot
.75 .45192 Mdot
.75 .45199 Mdot
.75 .45204 Mdot
.75 .45208 Mdot
.75 .45233 Mdot
.75 .45235 Mdot
.75 .45245 Mdot
.75 .45262 Mdot
.75 .45262 Mdot
.75 .45268 Mdot
.75 .45275 Mdot
.75 .45283 Mdot
.75 .45285 Mdot
.75 .45297 Mdot
.75 .45297 Mdot
.75 .45303 Mdot
.75 .4531 Mdot
.75 .45315 Mdot
.75 .45333 Mdot
.75 .4534 Mdot
.75 .4535 Mdot
.75 .45358 Mdot
.75 .45359 Mdot
.75 .45379 Mdot
.75 .45429 Mdot
.75 .4543 Mdot
.75 .4543 Mdot
.75 .45431 Mdot
.75 .45432 Mdot
.75 .45438 Mdot
.75 .45445 Mdot
.75 .45448 Mdot
.75 .45454 Mdot
.75 .45457 Mdot
.75 .4548 Mdot
.75 .45484 Mdot
.75 .45485 Mdot
.75 .45502 Mdot
.75 .45508 Mdot
.75 .45508 Mdot
.75 .45533 Mdot
.75 .45535 Mdot
.75 .45535 Mdot
.75 .45537 Mdot
.75 .45556 Mdot
.75 .45557 Mdot
.75 .45565 Mdot
.75 .45584 Mdot
.75 .45585 Mdot
.75 .45588 Mdot
.75 .45589 Mdot
.75 .45591 Mdot
.75 .45592 Mdot
.75 .45596 Mdot
.75 .45598 Mdot
.75 .45601 Mdot
.75 .45601 Mdot
.75 .45616 Mdot
.75 .45623 Mdot
.75 .45628 Mdot
.75 .45629 Mdot
.75 .45631 Mdot
.75 .45631 Mdot
.75 .45631 Mdot
.752 .26042 Mdot
.752 .26042 Mdot
.752 .26042 Mdot
.752 .26042 Mdot
.752 .26042 Mdot
.752 .26042 Mdot
.752 .26042 Mdot
.752 .26042 Mdot
.752 .26042 Mdot
.752 .26042 Mdot
.752 .26042 Mdot
.752 .26042 Mdot
.752 .26042 Mdot
.752 .26042 Mdot
.752 .26042 Mdot
.752 .26043 Mdot
.752 .26043 Mdot
.752 .26043 Mdot
.752 .26043 Mdot
.752 .26043 Mdot
.752 .26043 Mdot
.752 .26043 Mdot
.752 .26043 Mdot
.752 .26043 Mdot
.752 .26043 Mdot
.752 .26043 Mdot
.752 .26043 Mdot
.752 .26043 Mdot
.752 .26044 Mdot
.752 .26044 Mdot
.752 .26044 Mdot
.752 .26044 Mdot
.752 .26044 Mdot
.752 .26044 Mdot
.752 .26045 Mdot
.752 .26045 Mdot
.752 .26045 Mdot
.752 .26045 Mdot
.752 .26045 Mdot
.752 .26046 Mdot
.752 .26046 Mdot
.752 .26046 Mdot
.752 .26046 Mdot
.752 .26046 Mdot
.752 .26046 Mdot
.752 .26047 Mdot
.752 .26047 Mdot
.752 .26047 Mdot
.752 .26047 Mdot
.752 .26047 Mdot
.752 .26048 Mdot
.752 .26048 Mdot
.752 .26048 Mdot
.752 .26048 Mdot
.752 .26048 Mdot
.752 .26048 Mdot
.752 .26049 Mdot
.752 .26049 Mdot
.752 .26049 Mdot
.752 .2605 Mdot
.752 .2605 Mdot
.752 .2605 Mdot
.752 .26051 Mdot
.752 .26051 Mdot
.752 .26051 Mdot
.752 .26051 Mdot
.752 .26051 Mdot
.752 .26051 Mdot
.752 .26052 Mdot
.752 .26052 Mdot
.752 .26052 Mdot
.752 .26053 Mdot
.752 .26053 Mdot
.752 .26053 Mdot
.752 .26053 Mdot
.752 .26054 Mdot
.752 .26055 Mdot
.752 .26055 Mdot
.752 .26055 Mdot
.752 .26056 Mdot
.752 .26056 Mdot
.752 .26057 Mdot
.752 .26057 Mdot
.752 .26057 Mdot
.752 .26057 Mdot
.752 .26057 Mdot
.752 .26057 Mdot
.752 .26058 Mdot
.752 .26058 Mdot
.752 .26058 Mdot
.752 .26058 Mdot
.752 .26058 Mdot
.752 .26058 Mdot
.752 .26058 Mdot
.752 .26059 Mdot
.752 .26059 Mdot
.752 .26059 Mdot
.752 .2606 Mdot
.752 .2606 Mdot
.752 .2606 Mdot
.752 .26061 Mdot
.752 .26061 Mdot
.752 .26061 Mdot
.752 .26061 Mdot
.752 .26061 Mdot
.752 .26061 Mdot
.752 .26061 Mdot
.752 .26062 Mdot
.752 .26062 Mdot
.752 .26062 Mdot
.752 .26062 Mdot
.752 .26062 Mdot
.752 .26062 Mdot
.752 .26062 Mdot
.752 .26062 Mdot
.752 .26063 Mdot
.752 .26065 Mdot
.752 .26066 Mdot
.752 .26066 Mdot
.752 .26069 Mdot
.752 .26069 Mdot
.752 .26069 Mdot
.752 .26069 Mdot
.752 .26069 Mdot
.752 .2607 Mdot
.752 .26071 Mdot
.752 .26072 Mdot
.752 .26072 Mdot
.752 .26072 Mdot
.752 .26072 Mdot
.752 .26072 Mdot
.752 .26072 Mdot
.752 .26072 Mdot
.752 .26072 Mdot
.752 .26072 Mdot
.752 .26073 Mdot
.752 .26073 Mdot
.752 .26073 Mdot
.752 .26073 Mdot
.752 .26073 Mdot
.752 .26074 Mdot
.752 .26074 Mdot
.752 .26074 Mdot
.752 .26074 Mdot
.752 .26074 Mdot
.752 .26078 Mdot
.752 .26084 Mdot
.752 .26085 Mdot
.752 .26087 Mdot
.752 .26087 Mdot
.752 .26087 Mdot
.752 .26088 Mdot
.752 .26088 Mdot
.752 .26088 Mdot
.752 .26089 Mdot
.752 .26089 Mdot
.752 .2609 Mdot
.752 .26092 Mdot
.752 .26092 Mdot
.752 .26092 Mdot
.752 .26092 Mdot
.752 .26092 Mdot
.752 .26094 Mdot
.752 .26095 Mdot
.752 .26097 Mdot
.752 .26103 Mdot
.752 .27412 Mdot
.752 .27425 Mdot
.752 .2743 Mdot
.752 .2743 Mdot
.752 .27435 Mdot
.752 .27435 Mdot
.752 .27435 Mdot
.752 .27435 Mdot
.752 .27436 Mdot
.752 .27441 Mdot
.752 .27442 Mdot
.752 .27444 Mdot
.752 .27445 Mdot
.752 .27445 Mdot
.752 .27445 Mdot
.752 .27448 Mdot
.752 .27449 Mdot
.752 .27449 Mdot
.752 .27453 Mdot
.752 .27457 Mdot
.752 .27474 Mdot
.752 .27484 Mdot
.752 .2749 Mdot
.752 .27491 Mdot
.752 .27492 Mdot
.752 .27494 Mdot
.752 .275 Mdot
.752 .27501 Mdot
.752 .27501 Mdot
.752 .27511 Mdot
.752 .27516 Mdot
.752 .27524 Mdot
.752 .27526 Mdot
.752 .27539 Mdot
.752 .27539 Mdot
.752 .27567 Mdot
.752 .27573 Mdot
.752 .27576 Mdot
.752 .27585 Mdot
.752 .27586 Mdot
.752 .27588 Mdot
.752 .276 Mdot
.752 .27611 Mdot
.752 .2763 Mdot
.752 .27652 Mdot
.752 .27665 Mdot
.752 .27665 Mdot
.752 .27669 Mdot
.752 .27686 Mdot
.752 .27693 Mdot
.752 .27699 Mdot
.752 .27702 Mdot
.752 .27705 Mdot
.752 .27706 Mdot
.752 .27714 Mdot
.752 .2772 Mdot
.752 .27733 Mdot
.752 .27735 Mdot
.752 .27739 Mdot
.752 .27739 Mdot
.752 .27741 Mdot
.752 .27743 Mdot
.752 .27749 Mdot
.752 .27775 Mdot
.752 .27777 Mdot
.752 .27783 Mdot
.752 .27784 Mdot
.752 .27793 Mdot
.752 .27793 Mdot
.752 .27794 Mdot
.752 .27796 Mdot
.752 .27798 Mdot
.752 .278 Mdot
.752 .27802 Mdot
.752 .27805 Mdot
.752 .27805 Mdot
.752 .27813 Mdot
.752 .27815 Mdot
.752 .27818 Mdot
.752 .27828 Mdot
.752 .27831 Mdot
.752 .27832 Mdot
.752 .27836 Mdot
.752 .27837 Mdot
.752 .27844 Mdot
.752 .27845 Mdot
.752 .27851 Mdot
.752 .27852 Mdot
.752 .27852 Mdot
.752 .27858 Mdot
.752 .27861 Mdot
.752 .27861 Mdot
.752 .27862 Mdot
.752 .27862 Mdot
.752 .2788 Mdot
.752 .2788 Mdot
.752 .27882 Mdot
.752 .27883 Mdot
.752 .27884 Mdot
.752 .27888 Mdot
.752 .27897 Mdot
.752 .27901 Mdot
.752 .27902 Mdot
.752 .27904 Mdot
.752 .27917 Mdot
.752 .27917 Mdot
.752 .27918 Mdot
.752 .27933 Mdot
.752 .27935 Mdot
.752 .27944 Mdot
.752 .27945 Mdot
.752 .2795 Mdot
.752 .27969 Mdot
.752 .27974 Mdot
.752 .27977 Mdot
.752 .27978 Mdot
.752 .2799 Mdot
.752 .2799 Mdot
.752 .27995 Mdot
.752 .27996 Mdot
.752 .27999 Mdot
.752 .28 Mdot
.752 .28004 Mdot
.752 .28004 Mdot
.752 .28004 Mdot
.752 .28006 Mdot
.752 .28007 Mdot
.752 .28008 Mdot
.752 .2801 Mdot
.752 .2802 Mdot
.752 .28021 Mdot
.752 .28027 Mdot
.752 .2803 Mdot
.752 .28042 Mdot
.752 .28046 Mdot
.752 .28048 Mdot
.752 .2805 Mdot
.752 .2805 Mdot
.752 .2805 Mdot
.752 .28053 Mdot
.752 .28054 Mdot
.752 .28054 Mdot
.752 .28054 Mdot
.752 .28054 Mdot
.752 .28055 Mdot
.752 .28056 Mdot
.752 .28056 Mdot
.752 .28189 Mdot
.752 .28235 Mdot
.752 .28287 Mdot
.752 .28288 Mdot
.752 .28299 Mdot
.752 .28329 Mdot
.752 .2833 Mdot
.752 .28337 Mdot
.752 .2835 Mdot
.752 .28371 Mdot
.752 .28389 Mdot
.752 .28441 Mdot
.752 .28453 Mdot
.752 .28459 Mdot
.752 .28461 Mdot
.752 .28461 Mdot
.752 .28514 Mdot
.752 .28523 Mdot
.752 .28584 Mdot
.752 .28735 Mdot
.752 .32451 Mdot
.752 .32517 Mdot
.752 .32542 Mdot
.752 .32546 Mdot
.752 .32567 Mdot
.752 .32567 Mdot
.752 .32568 Mdot
.752 .3257 Mdot
.752 .32575 Mdot
.752 .32596 Mdot
.752 .32602 Mdot
.752 .3261 Mdot
.752 .32616 Mdot
.752 .32618 Mdot
.752 .32618 Mdot
.752 .3263 Mdot
.752 .32634 Mdot
.752 .32635 Mdot
.752 .32654 Mdot
.752 .32671 Mdot
.752 .3274 Mdot
.752 .32779 Mdot
.752 .32787 Mdot
.752 .32787 Mdot
.752 .32787 Mdot
.752 .32787 Mdot
.752 .32788 Mdot
.752 .3279 Mdot
.752 .32791 Mdot
.752 .32793 Mdot
.752 .32793 Mdot
.752 .32803 Mdot
.752 .32804 Mdot
.752 .32807 Mdot
.752 .32808 Mdot
.752 .32808 Mdot
.752 .32809 Mdot
.752 .3281 Mdot
.752 .32811 Mdot
.752 .32811 Mdot
.752 .32817 Mdot
.752 .32831 Mdot
.752 .32836 Mdot
.752 .32838 Mdot
.752 .32841 Mdot
.752 .32841 Mdot
.752 .32842 Mdot
.752 .32873 Mdot
.752 .32881 Mdot
.752 .32888 Mdot
.752 .32913 Mdot
.752 .3292 Mdot
.752 .32928 Mdot
.752 .32928 Mdot
.752 .32928 Mdot
.752 .32929 Mdot
.752 .32929 Mdot
.752 .32929 Mdot
.752 .3293 Mdot
.752 .3293 Mdot
.752 .32933 Mdot
.752 .32933 Mdot
.752 .32933 Mdot
.752 .32934 Mdot
.752 .32936 Mdot
.752 .3294 Mdot
.752 .32951 Mdot
.752 .32953 Mdot
.752 .32953 Mdot
.752 .32955 Mdot
.752 .32959 Mdot
.752 .3296 Mdot
.752 .3297 Mdot
.752 .32972 Mdot
.752 .32972 Mdot
.752 .32973 Mdot
.752 .32975 Mdot
.752 .32975 Mdot
.752 .32976 Mdot
.752 .32979 Mdot
.752 .3298 Mdot
.752 .32983 Mdot
.752 .32984 Mdot
.752 .32988 Mdot
.752 .32988 Mdot
.752 .33 Mdot
.752 .33001 Mdot
.752 .33004 Mdot
.752 .33004 Mdot
.752 .33009 Mdot
.752 .33019 Mdot
.752 .33027 Mdot
.752 .33031 Mdot
.752 .33031 Mdot
.752 .33032 Mdot
.752 .33038 Mdot
.752 .33041 Mdot
.752 .33043 Mdot
.752 .33054 Mdot
.752 .33056 Mdot
.752 .33056 Mdot
.752 .33057 Mdot
.752 .33058 Mdot
.752 .3306 Mdot
.752 .33069 Mdot
.752 .33071 Mdot
.752 .33072 Mdot
.752 .33075 Mdot
.752 .33079 Mdot
.752 .33084 Mdot
.752 .33087 Mdot
.752 .33088 Mdot
.752 .33088 Mdot
.752 .3309 Mdot
.752 .3309 Mdot
.752 .33095 Mdot
.752 .33105 Mdot
.752 .33105 Mdot
.752 .33106 Mdot
.752 .33106 Mdot
.752 .33108 Mdot
.752 .33111 Mdot
.752 .33112 Mdot
.752 .33113 Mdot
.752 .33113 Mdot
.752 .33118 Mdot
.752 .33118 Mdot
.752 .33118 Mdot
.752 .33123 Mdot
.752 .33124 Mdot
.752 .33127 Mdot
.752 .33128 Mdot
.752 .33129 Mdot
.752 .33136 Mdot
.752 .33138 Mdot
.752 .33139 Mdot
.752 .33139 Mdot
.752 .33143 Mdot
.752 .33144 Mdot
.752 .33145 Mdot
.752 .33146 Mdot
.752 .33147 Mdot
.752 .33148 Mdot
.752 .33148 Mdot
.752 .33148 Mdot
.752 .33149 Mdot
.752 .3315 Mdot
.752 .3315 Mdot
.752 .33151 Mdot
.752 .33154 Mdot
.752 .33154 Mdot
.752 .33157 Mdot
.752 .33157 Mdot
.752 .33162 Mdot
.752 .33163 Mdot
.752 .33164 Mdot
.752 .33165 Mdot
.752 .33165 Mdot
.752 .33165 Mdot
.752 .33166 Mdot
.752 .33166 Mdot
.752 .33166 Mdot
.752 .33166 Mdot
.752 .33166 Mdot
.752 .33167 Mdot
.752 .33167 Mdot
.752 .33167 Mdot
.752 .42201 Mdot
.752 .42201 Mdot
.752 .42201 Mdot
.752 .42201 Mdot
.752 .42201 Mdot
.752 .42201 Mdot
.752 .42201 Mdot
.752 .42201 Mdot
.752 .42201 Mdot
.752 .42201 Mdot
.752 .42201 Mdot
.752 .42201 Mdot
.752 .42202 Mdot
.752 .42202 Mdot
.752 .42203 Mdot
.752 .42203 Mdot
.752 .42204 Mdot
.752 .42204 Mdot
.752 .42205 Mdot
.752 .42205 Mdot
.752 .42205 Mdot
.752 .42205 Mdot
.752 .42205 Mdot
.752 .42205 Mdot
.752 .42205 Mdot
.752 .42206 Mdot
.752 .42206 Mdot
.752 .42206 Mdot
.752 .42207 Mdot
.752 .42207 Mdot
.752 .42208 Mdot
.752 .42208 Mdot
.752 .42208 Mdot
.752 .42209 Mdot
.752 .4221 Mdot
.752 .42211 Mdot
.752 .42211 Mdot
.752 .42212 Mdot
.752 .42212 Mdot
.752 .42213 Mdot
.752 .42213 Mdot
.752 .42213 Mdot
.752 .42214 Mdot
.752 .42215 Mdot
.752 .42215 Mdot
.752 .42215 Mdot
.752 .42216 Mdot
.752 .42216 Mdot
.752 .42216 Mdot
.752 .42216 Mdot
.752 .42216 Mdot
.752 .42219 Mdot
.752 .4222 Mdot
.752 .4222 Mdot
.752 .42221 Mdot
.752 .42221 Mdot
.752 .42221 Mdot
.752 .42222 Mdot
.752 .42223 Mdot
.752 .42224 Mdot
.752 .42225 Mdot
.752 .42225 Mdot
.752 .42226 Mdot
.752 .42228 Mdot
.752 .42229 Mdot
.752 .42229 Mdot
.752 .42229 Mdot
.752 .42229 Mdot
.752 .42229 Mdot
.752 .42232 Mdot
.752 .42233 Mdot
.752 .42234 Mdot
.752 .42235 Mdot
.752 .42235 Mdot
.752 .42235 Mdot
.752 .42236 Mdot
.752 .42238 Mdot
.752 .42241 Mdot
.752 .42242 Mdot
.752 .42242 Mdot
.752 .42243 Mdot
.752 .42243 Mdot
.752 .42246 Mdot
.752 .42246 Mdot
.752 .42247 Mdot
.752 .42248 Mdot
.752 .42248 Mdot
.752 .42249 Mdot
.752 .4225 Mdot
.752 .4225 Mdot
.752 .4225 Mdot
.752 .4225 Mdot
.752 .4225 Mdot
.752 .42251 Mdot
.752 .42251 Mdot
.752 .42253 Mdot
.752 .42254 Mdot
.752 .42255 Mdot
.752 .42255 Mdot
.752 .42255 Mdot
.752 .42256 Mdot
.752 .42259 Mdot
.752 .4226 Mdot
.752 .4226 Mdot
.752 .42261 Mdot
.752 .42261 Mdot
.752 .42261 Mdot
.752 .42261 Mdot
.752 .42261 Mdot
.752 .42261 Mdot
.752 .42261 Mdot
.752 .42261 Mdot
.752 .42262 Mdot
.752 .42262 Mdot
.752 .42262 Mdot
.752 .42264 Mdot
.752 .42266 Mdot
.752 .42272 Mdot
.752 .42274 Mdot
.752 .42276 Mdot
.752 .42284 Mdot
.752 .42284 Mdot
.752 .42284 Mdot
.752 .42285 Mdot
.752 .42286 Mdot
.752 .42287 Mdot
.752 .4229 Mdot
.752 .42292 Mdot
.752 .42292 Mdot
.752 .42292 Mdot
.752 .42292 Mdot
.752 .42293 Mdot
.752 .42293 Mdot
.752 .42293 Mdot
.752 .42294 Mdot
.752 .42294 Mdot
.752 .42297 Mdot
.752 .42297 Mdot
.752 .42297 Mdot
.752 .42297 Mdot
.752 .42298 Mdot
.752 .42298 Mdot
.752 .42298 Mdot
.752 .42298 Mdot
.752 .42298 Mdot
.752 .423 Mdot
.752 .4231 Mdot
.752 .42328 Mdot
.752 .42333 Mdot
.752 .42338 Mdot
.752 .42338 Mdot
.752 .42339 Mdot
.752 .42342 Mdot
.752 .42342 Mdot
.752 .42343 Mdot
.752 .42344 Mdot
.752 .42346 Mdot
.752 .42348 Mdot
.752 .42353 Mdot
.752 .42354 Mdot
.752 .42355 Mdot
.752 .42355 Mdot
.752 .42355 Mdot
.752 .42361 Mdot
.752 .42362 Mdot
.752 .42368 Mdot
.752 .42385 Mdot
.752 .43503 Mdot
.752 .43559 Mdot
.752 .43583 Mdot
.752 .43586 Mdot
.752 .43606 Mdot
.752 .43606 Mdot
.752 .43607 Mdot
.752 .43609 Mdot
.752 .43614 Mdot
.752 .43635 Mdot
.752 .43642 Mdot
.752 .4365 Mdot
.752 .43655 Mdot
.752 .43658 Mdot
.752 .43658 Mdot
.752 .4367 Mdot
.752 .43675 Mdot
.752 .43675 Mdot
.752 .43696 Mdot
.752 .43715 Mdot
.752 .4377 Mdot
.752 .4377 Mdot
.752 .4377 Mdot
.752 .43771 Mdot
.752 .43771 Mdot
.752 .43771 Mdot
.752 .43771 Mdot
.752 .43771 Mdot
.752 .43772 Mdot
.752 .43772 Mdot
.752 .43772 Mdot
.752 .43773 Mdot
.752 .43774 Mdot
.752 .43776 Mdot
.752 .43781 Mdot
.752 .43782 Mdot
.752 .43785 Mdot
.752 .43785 Mdot
.752 .43789 Mdot
.752 .43791 Mdot
.752 .43791 Mdot
.752 .43791 Mdot
.752 .43792 Mdot
.752 .43792 Mdot
.752 .43792 Mdot
.752 .43794 Mdot
.752 .43794 Mdot
.752 .43796 Mdot
.752 .43796 Mdot
.752 .43798 Mdot
.752 .43798 Mdot
.752 .43803 Mdot
.752 .43804 Mdot
.752 .43805 Mdot
.752 .43807 Mdot
.752 .43815 Mdot
.752 .43817 Mdot
.752 .43818 Mdot
.752 .43822 Mdot
.752 .43823 Mdot
.752 .43829 Mdot
.752 .4383 Mdot
.752 .4383 Mdot
.752 .43836 Mdot
.752 .43836 Mdot
.752 .43837 Mdot
.752 .43838 Mdot
.752 .43843 Mdot
.752 .43844 Mdot
.752 .43845 Mdot
.752 .43845 Mdot
.752 .43846 Mdot
.752 .43846 Mdot
.752 .43854 Mdot
.752 .43854 Mdot
.752 .43854 Mdot
.752 .43855 Mdot
.752 .43856 Mdot
.752 .43858 Mdot
.752 .43858 Mdot
.752 .43859 Mdot
.752 .43862 Mdot
.752 .43862 Mdot
.752 .43865 Mdot
.752 .43865 Mdot
.752 .43868 Mdot
.752 .43868 Mdot
.752 .43869 Mdot
.752 .43874 Mdot
.752 .43875 Mdot
.752 .43876 Mdot
.752 .43879 Mdot
.752 .43879 Mdot
.752 .43881 Mdot
.752 .43882 Mdot
.752 .43882 Mdot
.752 .43884 Mdot
.752 .43884 Mdot
.752 .43885 Mdot
.752 .43885 Mdot
.752 .43889 Mdot
.752 .4389 Mdot
.752 .43892 Mdot
.752 .43893 Mdot
.752 .43905 Mdot
.752 .43908 Mdot
.752 .43909 Mdot
.752 .43909 Mdot
.752 .43909 Mdot
.752 .43911 Mdot
.752 .43912 Mdot
.752 .43918 Mdot
.752 .43921 Mdot
.752 .43925 Mdot
.752 .43925 Mdot
.752 .43927 Mdot
.752 .43928 Mdot
.752 .43931 Mdot
.752 .43934 Mdot
.752 .43942 Mdot
.752 .43944 Mdot
.752 .43944 Mdot
.752 .4395 Mdot
.752 .4396 Mdot
.752 .43969 Mdot
.752 .43975 Mdot
.752 .4398 Mdot
.752 .43981 Mdot
.752 .43982 Mdot
.752 .43986 Mdot
.752 .43988 Mdot
.752 .43991 Mdot
.752 .44004 Mdot
.752 .44004 Mdot
.752 .4401 Mdot
.752 .44011 Mdot
.752 .44016 Mdot
.752 .44018 Mdot
.752 .44023 Mdot
.752 .44023 Mdot
.752 .44023 Mdot
.752 .44026 Mdot
.752 .44027 Mdot
.752 .44028 Mdot
.752 .44028 Mdot
.752 .44031 Mdot
.752 .44036 Mdot
.752 .44045 Mdot
.752 .44047 Mdot
.752 .44049 Mdot
.752 .44049 Mdot
.752 .44049 Mdot
.752 .44051 Mdot
.752 .44051 Mdot
.752 .44051 Mdot
.752 .44052 Mdot
.752 .44052 Mdot
.752 .44053 Mdot
.752 .44055 Mdot
.752 .44056 Mdot
.752 .44056 Mdot
.752 .44056 Mdot
.752 .44056 Mdot
.752 .44058 Mdot
.752 .44059 Mdot
.752 .44061 Mdot
.752 .44067 Mdot
.752 .45194 Mdot
.752 .45209 Mdot
.752 .45215 Mdot
.752 .45216 Mdot
.752 .45221 Mdot
.752 .45221 Mdot
.752 .45221 Mdot
.752 .45222 Mdot
.752 .45223 Mdot
.752 .45228 Mdot
.752 .4523 Mdot
.752 .45232 Mdot
.752 .45233 Mdot
.752 .45234 Mdot
.752 .45234 Mdot
.752 .45236 Mdot
.752 .45238 Mdot
.752 .45238 Mdot
.752 .45243 Mdot
.752 .45247 Mdot
.752 .45266 Mdot
.752 .45278 Mdot
.752 .45285 Mdot
.752 .45286 Mdot
.752 .45287 Mdot
.752 .45289 Mdot
.752 .45296 Mdot
.752 .45297 Mdot
.752 .45298 Mdot
.752 .45308 Mdot
.752 .45313 Mdot
.752 .45322 Mdot
.752 .45325 Mdot
.752 .45338 Mdot
.752 .45339 Mdot
.752 .45367 Mdot
.752 .45373 Mdot
.752 .45377 Mdot
.752 .45385 Mdot
.752 .45386 Mdot
.752 .45388 Mdot
.752 .454 Mdot
.752 .45411 Mdot
.752 .45428 Mdot
.752 .45449 Mdot
.752 .4546 Mdot
.752 .4546 Mdot
.752 .45463 Mdot
.752 .45477 Mdot
.752 .45484 Mdot
.752 .45489 Mdot
.752 .45491 Mdot
.752 .45494 Mdot
.752 .45494 Mdot
.752 .45501 Mdot
.752 .45506 Mdot
.752 .45516 Mdot
.752 .45518 Mdot
.752 .45521 Mdot
.752 .45521 Mdot
.752 .45522 Mdot
.752 .45524 Mdot
.752 .45528 Mdot
.752 .45548 Mdot
.752 .45549 Mdot
.752 .45553 Mdot
.752 .45554 Mdot
.752 .45561 Mdot
.752 .45561 Mdot
.752 .45561 Mdot
.752 .45563 Mdot
.752 .45564 Mdot
.752 .45565 Mdot
.752 .45567 Mdot
.752 .45569 Mdot
.752 .45569 Mdot
.752 .45575 Mdot
.752 .45576 Mdot
.752 .45578 Mdot
.752 .45585 Mdot
.752 .45586 Mdot
.752 .45587 Mdot
.752 .4559 Mdot
.752 .4559 Mdot
.752 .45595 Mdot
.752 .45595 Mdot
.752 .45599 Mdot
.752 .456 Mdot
.752 .456 Mdot
.752 .45604 Mdot
.752 .45605 Mdot
.752 .45605 Mdot
.752 .45606 Mdot
.752 .45606 Mdot
.752 .45617 Mdot
.752 .45617 Mdot
.752 .45618 Mdot
.752 .45618 Mdot
.752 .45619 Mdot
.752 .45621 Mdot
.752 .45626 Mdot
.752 .45629 Mdot
.752 .45629 Mdot
.752 .4563 Mdot
.752 .45637 Mdot
.752 .45637 Mdot
.752 .45638 Mdot
.752 .45646 Mdot
.752 .45647 Mdot
.752 .45651 Mdot
.752 .45652 Mdot
.752 .45654 Mdot
.752 .45663 Mdot
.752 .45665 Mdot
.752 .45665 Mdot
.752 .45667 Mdot
.752 .45667 Mdot
.752 .45673 Mdot
.752 .45673 Mdot
.752 .45675 Mdot
.752 .45675 Mdot
.752 .45676 Mdot
.752 .45677 Mdot
.752 .45679 Mdot
.752 .45679 Mdot
.752 .45679 Mdot
.752 .4568 Mdot
.752 .4568 Mdot
.752 .4568 Mdot
.752 .45681 Mdot
.752 .45685 Mdot
.752 .45686 Mdot
.752 .45688 Mdot
.752 .45689 Mdot
.752 .45694 Mdot
.752 .45695 Mdot
.752 .45696 Mdot
.752 .45697 Mdot
.752 .45697 Mdot
.752 .45697 Mdot
.752 .45698 Mdot
.752 .45698 Mdot
.752 .45698 Mdot
.752 .45698 Mdot
.752 .45698 Mdot
.752 .45699 Mdot
.752 .45699 Mdot
.752 .45699 Mdot
.752 .45717 Mdot
.752 .45731 Mdot
.752 .45733 Mdot
.752 .45735 Mdot
.752 .45741 Mdot
.752 .45741 Mdot
.752 .45742 Mdot
.752 .45742 Mdot
.752 .45742 Mdot
.752 .45744 Mdot
.752 .45747 Mdot
.752 .45747 Mdot
.752 .45748 Mdot
.752 .45748 Mdot
.752 .45749 Mdot
.752 .45749 Mdot
.752 .45749 Mdot
.752 .45749 Mdot
.752 .45749 Mdot
.754 .26109 Mdot
.754 .29105 Mdot
.754 .32049 Mdot
.754 .42513 Mdot
.754 .43397 Mdot
.754 .45568 Mdot
.756 .26172 Mdot
.756 .26173 Mdot
.756 .26173 Mdot
.756 .26173 Mdot
.756 .26174 Mdot
.756 .26174 Mdot
.756 .26174 Mdot
.756 .26174 Mdot
.756 .26175 Mdot
.756 .26175 Mdot
.756 .26175 Mdot
.756 .26176 Mdot
.756 .26176 Mdot
.756 .26176 Mdot
.756 .26177 Mdot
.756 .26178 Mdot
.756 .26178 Mdot
.756 .26179 Mdot
.756 .26182 Mdot
.756 .26182 Mdot
.756 .26184 Mdot
.756 .26184 Mdot
.756 .26184 Mdot
.756 .26185 Mdot
.756 .26185 Mdot
.756 .26186 Mdot
.756 .26187 Mdot
.756 .26187 Mdot
.756 .26187 Mdot
.756 .26189 Mdot
.756 .26189 Mdot
.756 .2619 Mdot
.756 .2619 Mdot
.756 .2619 Mdot
.756 .2619 Mdot
.756 .26192 Mdot
.756 .26192 Mdot
.756 .26197 Mdot
.756 .26198 Mdot
.756 .262 Mdot
.756 .262 Mdot
.756 .26201 Mdot
.756 .26201 Mdot
.756 .26202 Mdot
.756 .26202 Mdot
.756 .26206 Mdot
.756 .26206 Mdot
.756 .26208 Mdot
.756 .26209 Mdot
.756 .26212 Mdot
.756 .26214 Mdot
.756 .26216 Mdot
.756 .26219 Mdot
.756 .26219 Mdot
.756 .26221 Mdot
.756 .26223 Mdot
.756 .26229 Mdot
.756 .2623 Mdot
.756 .2623 Mdot
.756 .2623 Mdot
.756 .2623 Mdot
.756 .26231 Mdot
.756 .26231 Mdot
.756 .26231 Mdot
.756 .26231 Mdot
.756 .26232 Mdot
.756 .26233 Mdot
.756 .26237 Mdot
.756 .2624 Mdot
.756 .26242 Mdot
.756 .26242 Mdot
.756 .26242 Mdot
.756 .26245 Mdot
.756 .26246 Mdot
.756 .26247 Mdot
.756 .26248 Mdot
.756 .26249 Mdot
.756 .2625 Mdot
.756 .26251 Mdot
.756 .26253 Mdot
.756 .26254 Mdot
.756 .26254 Mdot
.756 .26255 Mdot
.756 .26257 Mdot
.756 .26259 Mdot
.756 .2626 Mdot
.756 .2626 Mdot
.756 .26261 Mdot
.756 .26261 Mdot
.756 .26262 Mdot
.756 .26262 Mdot
.756 .26266 Mdot
.756 .2627 Mdot
.756 .2627 Mdot
.756 .26271 Mdot
.756 .26271 Mdot
.756 .26272 Mdot
.756 .26273 Mdot
.756 .26274 Mdot
.756 .26276 Mdot
.756 .26277 Mdot
.756 .26277 Mdot
.756 .26278 Mdot
.756 .26279 Mdot
.756 .2628 Mdot
.756 .2628 Mdot
.756 .26281 Mdot
.756 .26281 Mdot
.756 .26282 Mdot
.756 .26282 Mdot
.756 .26283 Mdot
.756 .26284 Mdot
.756 .26284 Mdot
.756 .26284 Mdot
.756 .26285 Mdot
.756 .26286 Mdot
.756 .26287 Mdot
.756 .26288 Mdot
.756 .26288 Mdot
.756 .2629 Mdot
.756 .26292 Mdot
.756 .26293 Mdot
.756 .26293 Mdot
.756 .26293 Mdot
.756 .26294 Mdot
.756 .26294 Mdot
.756 .26294 Mdot
.756 .263 Mdot
.756 .26318 Mdot
.756 .26325 Mdot
.756 .2633 Mdot
.756 .26332 Mdot
.756 .26334 Mdot
.756 .2634 Mdot
.756 .2634 Mdot
.756 .26342 Mdot
.756 .26349 Mdot
.756 .26352 Mdot
.756 .26356 Mdot
.756 .26369 Mdot
.756 .26374 Mdot
.756 .26375 Mdot
.756 .26376 Mdot
.756 .26378 Mdot
.756 .26383 Mdot
.756 .26385 Mdot
.756 .26388 Mdot
.756 .2639 Mdot
.756 .26401 Mdot
.756 .26401 Mdot
.756 .26404 Mdot
.756 .26423 Mdot
.756 .26423 Mdot
.756 .2643 Mdot
.756 .26441 Mdot
.756 .26443 Mdot
.756 .26446 Mdot
.756 .26451 Mdot
.756 .26454 Mdot
.756 .26457 Mdot
.756 .26458 Mdot
.756 .26466 Mdot
.756 .26471 Mdot
.756 .26475 Mdot
.756 .26477 Mdot
.756 .26482 Mdot
.756 .26486 Mdot
.756 .26487 Mdot
.756 .26493 Mdot
.756 .26495 Mdot
.756 .26509 Mdot
.756 .26513 Mdot
.756 .26514 Mdot
.756 .26527 Mdot
.756 .2655 Mdot
.756 .2656 Mdot
.756 .2656 Mdot
.756 .26563 Mdot
.756 .26572 Mdot
.756 .26575 Mdot
.756 .26583 Mdot
.756 .26589 Mdot
.756 .2659 Mdot
.756 .26598 Mdot
.756 .26603 Mdot
.756 .26609 Mdot
.756 .26618 Mdot
.756 .26627 Mdot
.756 .26648 Mdot
.756 .26668 Mdot
.756 .26676 Mdot
.756 .26677 Mdot
.756 .26689 Mdot
.756 .26691 Mdot
.756 .26699 Mdot
.756 .26699 Mdot
.756 .26713 Mdot
.756 .26715 Mdot
.756 .26729 Mdot
.756 .26734 Mdot
.756 .26761 Mdot
.756 .26766 Mdot
.756 .26773 Mdot
.756 .26773 Mdot
.756 .26782 Mdot
.756 .26791 Mdot
.756 .26808 Mdot
.756 .26809 Mdot
.756 .2682 Mdot
.756 .26833 Mdot
.756 .26839 Mdot
.756 .26846 Mdot
.756 .26857 Mdot
.756 .26857 Mdot
.756 .2687 Mdot
.756 .26875 Mdot
.756 .26888 Mdot
.756 .26894 Mdot
.756 .26914 Mdot
.756 .26922 Mdot
.756 .26936 Mdot
.756 .26941 Mdot
.756 .26944 Mdot
.756 .26946 Mdot
.756 .2695 Mdot
.756 .26965 Mdot
.756 .27002 Mdot
.756 .27024 Mdot
.756 .27032 Mdot
.756 .27063 Mdot
.756 .27063 Mdot
.756 .27084 Mdot
.756 .27088 Mdot
.756 .27099 Mdot
.756 .27102 Mdot
.756 .27105 Mdot
.756 .27111 Mdot
.756 .27113 Mdot
.756 .27118 Mdot
.756 .27121 Mdot
.756 .27122 Mdot
.756 .27126 Mdot
.756 .27134 Mdot
.756 .27153 Mdot
.756 .272 Mdot
.756 .2722 Mdot
.756 .27244 Mdot
.756 .27271 Mdot
.756 .27275 Mdot
.756 .27283 Mdot
.756 .2731 Mdot
.756 .27313 Mdot
.756 .27336 Mdot
.756 .27338 Mdot
.756 .27367 Mdot
.756 .27371 Mdot
.756 .27379 Mdot
.756 .274 Mdot
.756 .2743 Mdot
.756 .27433 Mdot
.756 .27437 Mdot
.756 .27469 Mdot
.756 .2749 Mdot
.756 .27514 Mdot
.756 .27538 Mdot
.756 .27546 Mdot
.756 .27556 Mdot
.756 .27621 Mdot
.756 .27629 Mdot
.756 .27638 Mdot
.756 .27638 Mdot
.756 .27654 Mdot
.756 .27655 Mdot
.756 .27655 Mdot
.756 .27695 Mdot
.756 .27699 Mdot
.756 .2771 Mdot
.756 .27747 Mdot
.756 .27776 Mdot
.756 .27799 Mdot
.756 .27799 Mdot
.756 .2781 Mdot
.756 .27842 Mdot
.756 .27847 Mdot
.756 .27849 Mdot
.756 .2785 Mdot
.756 .27851 Mdot
.756 .27851 Mdot
.756 .27855 Mdot
.756 .27861 Mdot
.756 .27879 Mdot
.756 .27903 Mdot
.756 .27904 Mdot
.756 .27906 Mdot
.756 .2792 Mdot
.756 .27922 Mdot
.756 .27932 Mdot
.756 .27936 Mdot
.756 .27946 Mdot
.756 .27956 Mdot
.756 .2796 Mdot
.756 .27964 Mdot
.756 .27988 Mdot
.756 .27994 Mdot
.756 .27994 Mdot
.756 .28004 Mdot
.756 .28005 Mdot
.756 .28054 Mdot
.756 .28058 Mdot
.756 .2806 Mdot
.756 .28068 Mdot
.756 .2809 Mdot
.756 .28099 Mdot
.756 .281 Mdot
.756 .28104 Mdot
.756 .28114 Mdot
.756 .28121 Mdot
.756 .28126 Mdot
.756 .28131 Mdot
.756 .28132 Mdot
.756 .28136 Mdot
.756 .28141 Mdot
.756 .2815 Mdot
.756 .28157 Mdot
.756 .28166 Mdot
.756 .28168 Mdot
.756 .28192 Mdot
.756 .28266 Mdot
.756 .28272 Mdot
.756 .28301 Mdot
.756 .28384 Mdot
.756 .28398 Mdot
.756 .28434 Mdot
.756 .2844 Mdot
.756 .28471 Mdot
.756 .28501 Mdot
.756 .28511 Mdot
.756 .28542 Mdot
.756 .28574 Mdot
.756 .28626 Mdot
.756 .28634 Mdot
.756 .28652 Mdot
.756 .28675 Mdot
.756 .28707 Mdot
.756 .28729 Mdot
.756 .28743 Mdot
.756 .28821 Mdot
.756 .2887 Mdot
.756 .28871 Mdot
.756 .29004 Mdot
.756 .29027 Mdot
.756 .2903 Mdot
.756 .29109 Mdot
.756 .29125 Mdot
.756 .29149 Mdot
.756 .29164 Mdot
.756 .29203 Mdot
.756 .29217 Mdot
.756 .29224 Mdot
.756 .29235 Mdot
.756 .29272 Mdot
.756 .29377 Mdot
.756 .29409 Mdot
.756 .29434 Mdot
.756 .29484 Mdot
.756 .29504 Mdot
.756 .29504 Mdot
.756 .29553 Mdot
.756 .29573 Mdot
.756 .29582 Mdot
.756 .29624 Mdot
.756 .29689 Mdot
.756 .29843 Mdot
.756 .2989 Mdot
.756 .29891 Mdot
.756 .29893 Mdot
.756 .29899 Mdot
.756 .29902 Mdot
.756 .29906 Mdot
.756 .29908 Mdot
.756 .29925 Mdot
.756 .29946 Mdot
.756 .29946 Mdot
.756 .29954 Mdot
.756 .29966 Mdot
.756 .29968 Mdot
.756 .29977 Mdot
.756 .2998 Mdot
.756 .29983 Mdot
.756 .29992 Mdot
.756 .29998 Mdot
.756 .30002 Mdot
.756 .30004 Mdot
.756 .30009 Mdot
.756 .30013 Mdot
.756 .30014 Mdot
.756 .30022 Mdot
.756 .30035 Mdot
.756 .3004 Mdot
.756 .30041 Mdot
.756 .30052 Mdot
.756 .30073 Mdot
.756 .30082 Mdot
.756 .30085 Mdot
.756 .30093 Mdot
.756 .30095 Mdot
.756 .30102 Mdot
.756 .30108 Mdot
.756 .3014 Mdot
.756 .30179 Mdot
.756 .30179 Mdot
.756 .30188 Mdot
.756 .3019 Mdot
.756 .30196 Mdot
.756 .30196 Mdot
.756 .30206 Mdot
.756 .30223 Mdot
.756 .30245 Mdot
.756 .3025 Mdot
.756 .30257 Mdot
.756 .30264 Mdot
.756 .30283 Mdot
.756 .30293 Mdot
.756 .30301 Mdot
.756 .30309 Mdot
.756 .30318 Mdot
.756 .30329 Mdot
.756 .30333 Mdot
.756 .30361 Mdot
.756 .30364 Mdot
.756 .30366 Mdot
.756 .30379 Mdot
.756 .30416 Mdot
.756 .30452 Mdot
.756 .30461 Mdot
.756 .30465 Mdot
.756 .30468 Mdot
.756 .3047 Mdot
.756 .30473 Mdot
.756 .30474 Mdot
.756 .30475 Mdot
.756 .30478 Mdot
.756 .30482 Mdot
.756 .30493 Mdot
.756 .30546 Mdot
.756 .30561 Mdot
.756 .30583 Mdot
.756 .30584 Mdot
.756 .30614 Mdot
.756 .30632 Mdot
.756 .30653 Mdot
.756 .30681 Mdot
.756 .30695 Mdot
.756 .30707 Mdot
.756 .30711 Mdot
.756 .30752 Mdot
.756 .30756 Mdot
.756 .30761 Mdot
.756 .30761 Mdot
.756 .30769 Mdot
.756 .3077 Mdot
.756 .30792 Mdot
.756 .308 Mdot
.756 .30847 Mdot
.756 .30853 Mdot
.756 .30874 Mdot
.756 .30875 Mdot
.756 .30875 Mdot
.756 .30875 Mdot
.756 .30877 Mdot
.756 .3088 Mdot
.756 .30903 Mdot
.756 .30904 Mdot
.756 .30905 Mdot
.756 .30912 Mdot
.756 .30919 Mdot
.756 .30926 Mdot
.756 .30932 Mdot
.756 .30934 Mdot
.756 .30936 Mdot
.756 .30953 Mdot
.756 .30953 Mdot
.756 .30985 Mdot
.756 .30989 Mdot
.756 .30993 Mdot
.756 .31006 Mdot
.756 .31011 Mdot
.756 .31011 Mdot
.756 .31013 Mdot
.756 .31019 Mdot
.756 .31023 Mdot
.756 .31026 Mdot
.756 .31028 Mdot
.756 .31029 Mdot
.756 .31032 Mdot
.756 .31034 Mdot
.756 .3104 Mdot
.756 .31043 Mdot
.756 .31048 Mdot
.756 .3105 Mdot
.756 .42811 Mdot
.756 .42811 Mdot
.756 .42813 Mdot
.756 .42814 Mdot
.756 .42815 Mdot
.756 .42816 Mdot
.756 .42817 Mdot
.756 .42817 Mdot
.756 .42818 Mdot
.756 .42819 Mdot
.756 .4282 Mdot
.756 .42821 Mdot
.756 .42822 Mdot
.756 .42822 Mdot
.756 .42824 Mdot
.756 .42827 Mdot
.756 .42828 Mdot
.756 .42829 Mdot
.756 .42839 Mdot
.756 .42839 Mdot
.756 .42844 Mdot
.756 .42844 Mdot
.756 .42845 Mdot
.756 .42846 Mdot
.756 .42849 Mdot
.756 .42851 Mdot
.756 .42853 Mdot
.756 .42853 Mdot
.756 .42853 Mdot
.756 .4286 Mdot
.756 .42861 Mdot
.756 .42861 Mdot
.756 .42861 Mdot
.756 .42861 Mdot
.756 .42862 Mdot
.756 .42868 Mdot
.756 .42869 Mdot
.756 .42883 Mdot
.756 .42885 Mdot
.756 .42892 Mdot
.756 .42892 Mdot
.756 .42894 Mdot
.756 .42894 Mdot
.756 .42896 Mdot
.756 .42897 Mdot
.756 .42909 Mdot
.756 .4291 Mdot
.756 .42914 Mdot
.756 .42918 Mdot
.756 .42926 Mdot
.756 .42932 Mdot
.756 .42938 Mdot
.756 .42947 Mdot
.756 .42947 Mdot
.756 .42953 Mdot
.756 .42958 Mdot
.756 .42974 Mdot
.756 .42977 Mdot
.756 .42978 Mdot
.756 .42979 Mdot
.756 .42979 Mdot
.756 .4298 Mdot
.756 .42981 Mdot
.756 .42981 Mdot
.756 .42982 Mdot
.756 .42983 Mdot
.756 .42986 Mdot
.756 .42997 Mdot
.756 .43008 Mdot
.756 .43012 Mdot
.756 .43013 Mdot
.756 .43013 Mdot
.756 .43022 Mdot
.756 .43023 Mdot
.756 .43027 Mdot
.756 .43029 Mdot
.756 .43032 Mdot
.756 .43034 Mdot
.756 .43037 Mdot
.756 .43043 Mdot
.756 .43045 Mdot
.756 .43047 Mdot
.756 .43049 Mdot
.756 .43056 Mdot
.756 .43061 Mdot
.756 .43064 Mdot
.756 .43064 Mdot
.756 .43066 Mdot
.756 .43066 Mdot
.756 .43069 Mdot
.756 .43069 Mdot
.756 .43081 Mdot
.756 .43091 Mdot
.756 .43093 Mdot
.756 .43095 Mdot
.756 .43096 Mdot
.756 .43098 Mdot
.756 .43099 Mdot
.756 .43102 Mdot
.756 .43108 Mdot
.756 .43112 Mdot
.756 .43112 Mdot
.756 .43114 Mdot
.756 .43118 Mdot
.756 .4312 Mdot
.756 .43121 Mdot
.756 .43122 Mdot
.756 .43124 Mdot
.756 .43124 Mdot
.756 .43126 Mdot
.756 .43127 Mdot
.756 .4313 Mdot
.756 .43131 Mdot
.756 .43132 Mdot
.756 .43135 Mdot
.756 .43135 Mdot
.756 .43139 Mdot
.756 .43142 Mdot
.756 .43142 Mdot
.756 .43148 Mdot
.756 .43154 Mdot
.756 .43155 Mdot
.756 .43156 Mdot
.756 .43157 Mdot
.756 .43159 Mdot
.756 .43159 Mdot
.756 .4316 Mdot
.756 .43175 Mdot
.756 .43224 Mdot
.756 .43246 Mdot
.756 .4326 Mdot
.756 .43262 Mdot
.756 .43269 Mdot
.756 .43285 Mdot
.756 .43285 Mdot
.756 .43292 Mdot
.756 .43309 Mdot
.756 .43317 Mdot
.756 .43328 Mdot
.756 .43364 Mdot
.756 .43377 Mdot
.756 .43381 Mdot
.756 .43383 Mdot
.756 .43388 Mdot
.756 .43401 Mdot
.756 .43407 Mdot
.756 .43415 Mdot
.756 .43421 Mdot
.756 .43449 Mdot
.756 .4345 Mdot
.756 .43458 Mdot
.756 .43506 Mdot
.756 .43507 Mdot
.756 .43525 Mdot
.756 .43554 Mdot
.756 .43559 Mdot
.756 .43567 Mdot
.756 .4358 Mdot
.756 .43588 Mdot
.756 .43595 Mdot
.756 .43598 Mdot
.756 .43618 Mdot
.756 .43631 Mdot
.756 .43643 Mdot
.756 .43647 Mdot
.756 .43659 Mdot
.756 .43671 Mdot
.756 .43673 Mdot
.756 .43688 Mdot
.756 .43693 Mdot
.756 .43727 Mdot
.756 .43739 Mdot
.756 .43741 Mdot
.756 .43772 Mdot
.756 .43782 Mdot
.756 .43783 Mdot
.756 .43787 Mdot
.756 .4379 Mdot
.756 .43794 Mdot
.756 .43796 Mdot
.756 .43798 Mdot
.756 .43798 Mdot
.756 .438 Mdot
.756 .43802 Mdot
.756 .43805 Mdot
.756 .4381 Mdot
.756 .43811 Mdot
.756 .43812 Mdot
.756 .43816 Mdot
.756 .43825 Mdot
.756 .43829 Mdot
.756 .43829 Mdot
.756 .43832 Mdot
.756 .43853 Mdot
.756 .43853 Mdot
.756 .43857 Mdot
.756 .43858 Mdot
.756 .4386 Mdot
.756 .43871 Mdot
.756 .43873 Mdot
.756 .43874 Mdot
.756 .43879 Mdot
.756 .43883 Mdot
.756 .43885 Mdot
.756 .4389 Mdot
.756 .43891 Mdot
.756 .43897 Mdot
.756 .43898 Mdot
.756 .43898 Mdot
.756 .4391 Mdot
.756 .43918 Mdot
.756 .4392 Mdot
.756 .43922 Mdot
.756 .43922 Mdot
.756 .43922 Mdot
.756 .43923 Mdot
.756 .43924 Mdot
.756 .43926 Mdot
.756 .43941 Mdot
.756 .43946 Mdot
.756 .43946 Mdot
.756 .43957 Mdot
.756 .43971 Mdot
.756 .43988 Mdot
.756 .43994 Mdot
.756 .43996 Mdot
.756 .44015 Mdot
.756 .44015 Mdot
.756 .44016 Mdot
.756 .44024 Mdot
.756 .44024 Mdot
.756 .44028 Mdot
.756 .44032 Mdot
.756 .44064 Mdot
.756 .4407 Mdot
.756 .44074 Mdot
.756 .44086 Mdot
.756 .44098 Mdot
.756 .44109 Mdot
.756 .44126 Mdot
.756 .44129 Mdot
.756 .4413 Mdot
.756 .44146 Mdot
.756 .44157 Mdot
.756 .44162 Mdot
.756 .44164 Mdot
.756 .4418 Mdot
.756 .44181 Mdot
.756 .44194 Mdot
.756 .44195 Mdot
.756 .4421 Mdot
.756 .44215 Mdot
.756 .44218 Mdot
.756 .44233 Mdot
.756 .44247 Mdot
.756 .44259 Mdot
.756 .44287 Mdot
.756 .44298 Mdot
.756 .44303 Mdot
.756 .44306 Mdot
.756 .44306 Mdot
.756 .44308 Mdot
.756 .44311 Mdot
.756 .44313 Mdot
.756 .44316 Mdot
.756 .44318 Mdot
.756 .4432 Mdot
.756 .44327 Mdot
.756 .44329 Mdot
.756 .44342 Mdot
.756 .44342 Mdot
.756 .44362 Mdot
.756 .44368 Mdot
.756 .44382 Mdot
.756 .44406 Mdot
.756 .44416 Mdot
.756 .44419 Mdot
.756 .44421 Mdot
.756 .44423 Mdot
.756 .44426 Mdot
.756 .44436 Mdot
.756 .44442 Mdot
.756 .44456 Mdot
.756 .4446 Mdot
.756 .44469 Mdot
.756 .44472 Mdot
.756 .44482 Mdot
.756 .44482 Mdot
.756 .4449 Mdot
.756 .44495 Mdot
.756 .445 Mdot
.756 .44509 Mdot
.756 .44517 Mdot
.756 .44519 Mdot
.756 .44531 Mdot
.756 .44538 Mdot
.756 .44545 Mdot
.756 .44545 Mdot
.756 .44551 Mdot
.756 .44554 Mdot
.756 .44576 Mdot
.756 .4458 Mdot
.756 .44592 Mdot
.756 .44593 Mdot
.756 .44604 Mdot
.756 .44605 Mdot
.756 .44611 Mdot
.756 .44613 Mdot
.756 .44623 Mdot
.756 .44624 Mdot
.756 .44631 Mdot
.756 .44648 Mdot
.756 .44667 Mdot
.756 .44675 Mdot
.756 .44684 Mdot
.756 .44689 Mdot
.756 .44693 Mdot
.756 .44701 Mdot
.756 .44702 Mdot
.756 .44708 Mdot
.756 .44715 Mdot
.756 .44718 Mdot
.756 .44727 Mdot
.756 .4473 Mdot
.756 .4473 Mdot
.756 .4474 Mdot
.756 .44763 Mdot
.756 .44776 Mdot
.756 .44777 Mdot
.756 .44782 Mdot
.756 .44796 Mdot
.756 .44798 Mdot
.756 .44805 Mdot
.756 .44806 Mdot
.756 .44811 Mdot
.756 .44816 Mdot
.756 .44818 Mdot
.756 .44823 Mdot
.756 .44829 Mdot
.756 .44837 Mdot
.756 .44839 Mdot
.756 .44842 Mdot
.756 .44846 Mdot
.756 .44851 Mdot
.756 .44855 Mdot
.756 .44857 Mdot
.756 .44871 Mdot
.756 .44879 Mdot
.756 .44879 Mdot
.756 .44902 Mdot
.756 .44906 Mdot
.756 .44907 Mdot
.756 .4492 Mdot
.756 .44923 Mdot
.756 .44927 Mdot
.756 .4493 Mdot
.756 .44937 Mdot
.756 .4494 Mdot
.756 .44941 Mdot
.756 .44943 Mdot
.756 .44949 Mdot
.756 .44968 Mdot
.756 .44974 Mdot
.756 .44978 Mdot
.756 .44988 Mdot
.756 .44991 Mdot
.756 .44991 Mdot
.756 .45 Mdot
.756 .45004 Mdot
.756 .45006 Mdot
.756 .45014 Mdot
.756 .45026 Mdot
.756 .45057 Mdot
.756 .45131 Mdot
.756 .45155 Mdot
.756 .45161 Mdot
.756 .45198 Mdot
.756 .45222 Mdot
.756 .45237 Mdot
.756 .45243 Mdot
.756 .45255 Mdot
.756 .45264 Mdot
.756 .45273 Mdot
.756 .45293 Mdot
.756 .45293 Mdot
.756 .45296 Mdot
.756 .45328 Mdot
.756 .45331 Mdot
.756 .45341 Mdot
.756 .45341 Mdot
.756 .4536 Mdot
.756 .45368 Mdot
.756 .45374 Mdot
.756 .45384 Mdot
.756 .45408 Mdot
.756 .45411 Mdot
.756 .45431 Mdot
.756 .45448 Mdot
.756 .45451 Mdot
.756 .45456 Mdot
.756 .4546 Mdot
.756 .45495 Mdot
.756 .45518 Mdot
.756 .45545 Mdot
.756 .45553 Mdot
.756 .4557 Mdot
.756 .45578 Mdot
.756 .45583 Mdot
.756 .4559 Mdot
.756 .45593 Mdot
.756 .45598 Mdot
.756 .45609 Mdot
.756 .4564 Mdot
.756 .45652 Mdot
.756 .45653 Mdot
.756 .45661 Mdot
.756 .45669 Mdot
.756 .4567 Mdot
.756 .4567 Mdot
.756 .45682 Mdot
.756 .45684 Mdot
.756 .45685 Mdot
.756 .45685 Mdot
.756 .4572 Mdot
.756 .45723 Mdot
.756 .45732 Mdot
.756 .45738 Mdot
.756 .4574 Mdot
.756 .45755 Mdot
.756 .45761 Mdot
.756 .45783 Mdot
.756 .45799 Mdot
.756 .458 Mdot
.756 .45807 Mdot
.756 .45828 Mdot
.756 .45831 Mdot
.756 .45833 Mdot
.756 .45833 Mdot
.756 .45834 Mdot
.756 .45834 Mdot
.756 .45835 Mdot
.756 .45835 Mdot
.756 .45836 Mdot
.756 .4584 Mdot
.756 .45851 Mdot
.756 .45861 Mdot
.756 .45865 Mdot
.756 .45865 Mdot
.756 .45866 Mdot
.756 .45874 Mdot
.756 .45875 Mdot
.756 .4588 Mdot
.756 .45882 Mdot
.756 .45887 Mdot
.756 .45892 Mdot
.756 .45894 Mdot
.756 .45896 Mdot
.756 .45897 Mdot
.756 .45903 Mdot
.756 .45907 Mdot
.756 .4591 Mdot
.756 .4591 Mdot
.756 .45912 Mdot
.756 .45914 Mdot
.756 .45914 Mdot
.756 .45924 Mdot
.756 .45932 Mdot
.756 .45933 Mdot
.756 .45935 Mdot
.756 .45936 Mdot
.756 .45938 Mdot
.756 .45938 Mdot
.756 .4594 Mdot
.756 .45945 Mdot
.756 .45948 Mdot
.756 .45949 Mdot
.756 .4595 Mdot
.756 .45953 Mdot
.756 .45955 Mdot
.756 .45955 Mdot
.756 .45956 Mdot
.756 .45957 Mdot
.756 .45957 Mdot
.756 .45959 Mdot
.756 .4596 Mdot
.756 .45962 Mdot
.756 .45963 Mdot
.756 .45963 Mdot
.756 .45965 Mdot
.756 .45966 Mdot
.756 .45969 Mdot
.756 .45971 Mdot
.756 .45971 Mdot
.756 .45976 Mdot
.756 .45979 Mdot
.756 .4598 Mdot
.756 .45981 Mdot
.756 .45982 Mdot
.756 .45983 Mdot
.756 .45984 Mdot
.756 .45984 Mdot
.758 .26238 Mdot
.758 .26238 Mdot
.758 .26238 Mdot
.758 .26238 Mdot
.758 .26238 Mdot
.758 .26238 Mdot
.758 .26238 Mdot
.758 .26238 Mdot
.758 .26238 Mdot
.758 .26239 Mdot
.758 .26239 Mdot
.758 .26239 Mdot
.758 .26239 Mdot
.758 .26239 Mdot
.758 .2624 Mdot
.758 .2624 Mdot
.758 .2624 Mdot
.758 .26241 Mdot
.758 .26242 Mdot
.758 .26242 Mdot
.758 .26242 Mdot
.758 .26242 Mdot
.758 .26242 Mdot
.758 .26244 Mdot
.758 .26245 Mdot
.758 .26248 Mdot
.758 .2625 Mdot
.758 .2625 Mdot
.758 .2625 Mdot
.758 .2625 Mdot
.758 .26251 Mdot
.758 .26251 Mdot
.758 .26253 Mdot
.758 .26254 Mdot
.758 .26254 Mdot
.758 .26256 Mdot
.758 .26256 Mdot
.758 .26256 Mdot
.758 .26257 Mdot
.758 .26257 Mdot
.758 .26258 Mdot
.758 .26258 Mdot
.758 .26259 Mdot
.758 .26261 Mdot
.758 .26262 Mdot
.758 .26262 Mdot
.758 .26263 Mdot
.758 .26265 Mdot
.758 .26265 Mdot
.758 .26266 Mdot
.758 .26266 Mdot
.758 .26266 Mdot
.758 .26267 Mdot
.758 .26269 Mdot
.758 .26269 Mdot
.758 .26269 Mdot
.758 .2627 Mdot
.758 .2627 Mdot
.758 .26271 Mdot
.758 .26272 Mdot
.758 .26272 Mdot
.758 .26273 Mdot
.758 .26273 Mdot
.758 .26273 Mdot
.758 .26274 Mdot
.758 .26275 Mdot
.758 .26275 Mdot
.758 .26276 Mdot
.758 .26276 Mdot
.758 .26277 Mdot
.758 .26279 Mdot
.758 .26279 Mdot
.758 .26279 Mdot
.758 .2628 Mdot
.758 .2628 Mdot
.758 .2628 Mdot
.758 .26282 Mdot
.758 .26282 Mdot
.758 .26282 Mdot
.758 .26283 Mdot
.758 .26284 Mdot
.758 .26286 Mdot
.758 .26286 Mdot
.758 .26287 Mdot
.758 .26288 Mdot
.758 .26288 Mdot
.758 .2629 Mdot
.758 .26291 Mdot
.758 .26291 Mdot
.758 .26293 Mdot
.758 .26294 Mdot
.758 .26295 Mdot
.758 .26296 Mdot
.758 .26296 Mdot
.758 .26297 Mdot
.758 .26305 Mdot
.758 .26305 Mdot
.758 .26305 Mdot
.758 .26306 Mdot
.758 .26307 Mdot
.758 .26308 Mdot
.758 .2631 Mdot
.758 .26311 Mdot
.758 .26312 Mdot
.758 .26312 Mdot
.758 .26313 Mdot
.758 .26314 Mdot
.758 .26314 Mdot
.758 .26317 Mdot
.758 .26318 Mdot
.758 .2632 Mdot
.758 .2632 Mdot
.758 .2632 Mdot
.758 .26321 Mdot
.758 .26321 Mdot
.758 .26323 Mdot
.758 .26324 Mdot
.758 .26328 Mdot
.758 .26328 Mdot
.758 .26329 Mdot
.758 .26331 Mdot
.758 .26334 Mdot
.758 .26335 Mdot
.758 .26336 Mdot
.758 .26336 Mdot
.758 .26336 Mdot
.758 .26336 Mdot
.758 .2634 Mdot
.758 .26341 Mdot
.758 .26341 Mdot
.758 .26341 Mdot
.758 .26342 Mdot
.758 .26343 Mdot
.758 .26344 Mdot
.758 .26345 Mdot
.758 .26347 Mdot
.758 .26347 Mdot
.758 .26348 Mdot
.758 .26348 Mdot
.758 .26348 Mdot
.758 .26349 Mdot
.758 .2635 Mdot
.758 .2635 Mdot
.758 .26351 Mdot
.758 .26352 Mdot
.758 .26352 Mdot
.758 .26352 Mdot
.758 .26352 Mdot
.758 .26353 Mdot
.758 .26354 Mdot
.758 .26354 Mdot
.758 .26354 Mdot
.758 .26355 Mdot
.758 .26356 Mdot
.758 .26356 Mdot
.758 .26356 Mdot
.758 .26356 Mdot
.758 .26356 Mdot
.758 .26357 Mdot
.758 .26357 Mdot
.758 .26358 Mdot
.758 .26359 Mdot
.758 .26361 Mdot
.758 .26362 Mdot
.758 .26362 Mdot
.758 .26365 Mdot
.758 .2637 Mdot
.758 .2637 Mdot
.758 .2637 Mdot
.758 .26372 Mdot
.758 .26374 Mdot
.758 .26374 Mdot
.758 .26374 Mdot
.758 .26376 Mdot
.758 .26377 Mdot
.758 .26377 Mdot
.758 .26378 Mdot
.758 .26382 Mdot
.758 .26382 Mdot
.758 .26383 Mdot
.758 .26385 Mdot
.758 .26386 Mdot
.758 .2639 Mdot
.758 .26393 Mdot
.758 .26393 Mdot
.758 .26393 Mdot
.758 .26393 Mdot
.758 .26394 Mdot
.758 .26395 Mdot
.758 .26396 Mdot
.758 .26397 Mdot
.758 .26397 Mdot
.758 .26397 Mdot
.758 .26397 Mdot
.758 .26398 Mdot
.758 .26399 Mdot
.758 .264 Mdot
.758 .264 Mdot
.758 .26402 Mdot
.758 .26405 Mdot
.758 .26407 Mdot
.758 .26408 Mdot
.758 .26409 Mdot
.758 .2641 Mdot
.758 .26414 Mdot
.758 .26415 Mdot
.758 .26416 Mdot
.758 .26418 Mdot
.758 .2642 Mdot
.758 .26421 Mdot
.758 .26422 Mdot
.758 .26423 Mdot
.758 .26424 Mdot
.758 .26425 Mdot
.758 .26426 Mdot
.758 .26428 Mdot
.758 .26431 Mdot
.758 .26446 Mdot
.758 .2645 Mdot
.758 .26451 Mdot
.758 .26453 Mdot
.758 .26455 Mdot
.758 .26458 Mdot
.758 .26469 Mdot
.758 .26496 Mdot
.758 .26505 Mdot
.758 .26516 Mdot
.758 .26517 Mdot
.758 .26517 Mdot
.758 .26519 Mdot
.758 .2652 Mdot
.758 .26529 Mdot
.758 .26535 Mdot
.758 .26536 Mdot
.758 .26538 Mdot
.758 .26543 Mdot
.758 .26546 Mdot
.758 .26549 Mdot
.758 .2655 Mdot
.758 .2655 Mdot
.758 .26551 Mdot
.758 .26553 Mdot
.758 .26553 Mdot
.758 .26553 Mdot
.758 .26555 Mdot
.758 .26555 Mdot
.758 .26557 Mdot
.758 .26557 Mdot
.758 .26557 Mdot
.758 .26558 Mdot
.758 .27838 Mdot
.758 .2784 Mdot
.758 .27841 Mdot
.758 .27844 Mdot
.758 .2785 Mdot
.758 .27852 Mdot
.758 .27861 Mdot
.758 .27861 Mdot
.758 .27862 Mdot
.758 .27876 Mdot
.758 .27877 Mdot
.758 .27879 Mdot
.758 .27886 Mdot
.758 .27898 Mdot
.758 .27914 Mdot
.758 .27945 Mdot
.758 .27952 Mdot
.758 .27958 Mdot
.758 .2799 Mdot
.758 .28044 Mdot
.758 .28049 Mdot
.758 .28059 Mdot
.758 .28061 Mdot
.758 .28064 Mdot
.758 .2813 Mdot
.758 .2818 Mdot
.758 .28347 Mdot
.758 .28416 Mdot
.758 .28431 Mdot
.758 .28443 Mdot
.758 .28457 Mdot
.758 .28465 Mdot
.758 .28489 Mdot
.758 .28592 Mdot
.758 .28611 Mdot
.758 .28622 Mdot
.758 .28629 Mdot
.758 .28641 Mdot
.758 .28646 Mdot
.758 .28652 Mdot
.758 .28658 Mdot
.758 .28663 Mdot
.758 .28678 Mdot
.758 .28695 Mdot
.758 .28701 Mdot
.758 .2871 Mdot
.758 .28736 Mdot
.758 .28742 Mdot
.758 .28749 Mdot
.758 .28753 Mdot
.758 .2877 Mdot
.758 .28791 Mdot
.758 .28804 Mdot
.758 .28808 Mdot
.758 .28813 Mdot
.758 .28821 Mdot
.758 .28823 Mdot
.758 .28827 Mdot
.758 .28828 Mdot
.758 .28829 Mdot
.758 .28835 Mdot
.758 .28842 Mdot
.758 .28844 Mdot
.758 .28851 Mdot
.758 .28851 Mdot
.758 .28854 Mdot
.758 .28857 Mdot
.758 .28879 Mdot
.758 .28904 Mdot
.758 .28913 Mdot
.758 .28926 Mdot
.758 .28931 Mdot
.758 .28937 Mdot
.758 .28964 Mdot
.758 .28967 Mdot
.758 .28968 Mdot
.758 .28978 Mdot
.758 .2899 Mdot
.758 .28995 Mdot
.758 .28996 Mdot
.758 .29007 Mdot
.758 .29019 Mdot
.758 .29025 Mdot
.758 .29026 Mdot
.758 .29063 Mdot
.758 .29082 Mdot
.758 .29087 Mdot
.758 .29093 Mdot
.758 .29103 Mdot
.758 .29115 Mdot
.758 .29119 Mdot
.758 .29121 Mdot
.758 .29126 Mdot
.758 .29128 Mdot
.758 .29129 Mdot
.758 .29131 Mdot
.758 .29131 Mdot
.758 .29133 Mdot
.758 .29142 Mdot
.758 .29145 Mdot
.758 .29145 Mdot
.758 .2915 Mdot
.758 .29157 Mdot
.758 .29159 Mdot
.758 .29161 Mdot
.758 .29162 Mdot
.758 .29164 Mdot
.758 .29176 Mdot
.758 .29176 Mdot
.758 .29181 Mdot
.758 .29188 Mdot
.758 .29193 Mdot
.758 .29194 Mdot
.758 .29196 Mdot
.758 .29196 Mdot
.758 .29216 Mdot
.758 .29221 Mdot
.758 .2923 Mdot
.758 .29234 Mdot
.758 .29243 Mdot
.758 .29245 Mdot
.758 .29249 Mdot
.758 .2925 Mdot
.758 .29282 Mdot
.758 .29283 Mdot
.758 .29285 Mdot
.758 .29287 Mdot
.758 .29289 Mdot
.758 .29299 Mdot
.758 .29327 Mdot
.758 .29337 Mdot
.758 .2935 Mdot
.758 .29351 Mdot
.758 .2938 Mdot
.758 .29391 Mdot
.758 .29402 Mdot
.758 .29407 Mdot
.758 .29415 Mdot
.758 .29415 Mdot
.758 .29428 Mdot
.758 .29436 Mdot
.758 .29462 Mdot
.758 .29463 Mdot
.758 .29472 Mdot
.758 .29474 Mdot
.758 .2948 Mdot
.758 .29489 Mdot
.758 .29497 Mdot
.758 .29514 Mdot
.758 .29516 Mdot
.758 .29524 Mdot
.758 .29535 Mdot
.758 .29536 Mdot
.758 .29539 Mdot
.758 .296 Mdot
.758 .29612 Mdot
.758 .29614 Mdot
.758 .29615 Mdot
.758 .29628 Mdot
.758 .29634 Mdot
.758 .29649 Mdot
.758 .29654 Mdot
.758 .29664 Mdot
.758 .29678 Mdot
.758 .29678 Mdot
.758 .29684 Mdot
.758 .29694 Mdot
.758 .29697 Mdot
.758 .29716 Mdot
.758 .29721 Mdot
.758 .29729 Mdot
.758 .29732 Mdot
.758 .29734 Mdot
.758 .29743 Mdot
.758 .29747 Mdot
.758 .29749 Mdot
.758 .29753 Mdot
.758 .29754 Mdot
.758 .29757 Mdot
.758 .29775 Mdot
.758 .29781 Mdot
.758 .29781 Mdot
.758 .29788 Mdot
.758 .2979 Mdot
.758 .29795 Mdot
.758 .29804 Mdot
.758 .29807 Mdot
.758 .2981 Mdot
.758 .29813 Mdot
.758 .29815 Mdot
.758 .29823 Mdot
.758 .29837 Mdot
.758 .29838 Mdot
.758 .29838 Mdot
.758 .29839 Mdot
.758 .29847 Mdot
.758 .29859 Mdot
.758 .29869 Mdot
.758 .2987 Mdot
.758 .29873 Mdot
.758 .29874 Mdot
.758 .29874 Mdot
.758 .29896 Mdot
.758 .29908 Mdot
.758 .29908 Mdot
.758 .29915 Mdot
.758 .29931 Mdot
.758 .29937 Mdot
.758 .2994 Mdot
.758 .29951 Mdot
.758 .29952 Mdot
.758 .29954 Mdot
.758 .29959 Mdot
.758 .29961 Mdot
.758 .29976 Mdot
.758 .29978 Mdot
.758 .29982 Mdot
.758 .30001 Mdot
.758 .30006 Mdot
.758 .30007 Mdot
.758 .3001 Mdot
.758 .30012 Mdot
.758 .30015 Mdot
.758 .30028 Mdot
.758 .30059 Mdot
.758 .30068 Mdot
.758 .3008 Mdot
.758 .30081 Mdot
.758 .30081 Mdot
.758 .30083 Mdot
.758 .30084 Mdot
.758 .30094 Mdot
.758 .301 Mdot
.758 .30101 Mdot
.758 .30102 Mdot
.758 .30108 Mdot
.758 .30111 Mdot
.758 .30113 Mdot
.758 .30115 Mdot
.758 .30115 Mdot
.758 .30115 Mdot
.758 .30118 Mdot
.758 .30118 Mdot
.758 .30118 Mdot
.758 .3012 Mdot
.758 .3012 Mdot
.758 .30121 Mdot
.758 .30122 Mdot
.758 .30122 Mdot
.758 .30122 Mdot
.758 .4311 Mdot
.758 .4311 Mdot
.758 .4311 Mdot
.758 .43111 Mdot
.758 .43111 Mdot
.758 .43111 Mdot
.758 .43112 Mdot
.758 .43112 Mdot
.758 .43112 Mdot
.758 .43112 Mdot
.758 .43112 Mdot
.758 .43113 Mdot
.758 .43113 Mdot
.758 .43114 Mdot
.758 .43115 Mdot
.758 .43116 Mdot
.758 .43117 Mdot
.758 .43117 Mdot
.758 .43119 Mdot
.758 .43122 Mdot
.758 .43122 Mdot
.758 .43123 Mdot
.758 .43123 Mdot
.758 .43123 Mdot
.758 .43127 Mdot
.758 .4313 Mdot
.758 .4314 Mdot
.758 .43144 Mdot
.758 .43145 Mdot
.758 .43145 Mdot
.758 .43146 Mdot
.758 .43147 Mdot
.758 .43148 Mdot
.758 .43154 Mdot
.758 .43155 Mdot
.758 .43156 Mdot
.758 .43161 Mdot
.758 .43161 Mdot
.758 .43163 Mdot
.758 .43164 Mdot
.758 .43164 Mdot
.758 .43168 Mdot
.758 .43168 Mdot
.758 .43171 Mdot
.758 .43175 Mdot
.758 .43178 Mdot
.758 .43178 Mdot
.758 .43182 Mdot
.758 .43189 Mdot
.758 .43189 Mdot
.758 .43189 Mdot
.758 .4319 Mdot
.758 .4319 Mdot
.758 .43193 Mdot
.758 .43197 Mdot
.758 .432 Mdot
.758 .432 Mdot
.758 .432 Mdot
.758 .432 Mdot
.758 .43205 Mdot
.758 .43208 Mdot
.758 .43208 Mdot
.758 .43209 Mdot
.758 .4321 Mdot
.758 .43211 Mdot
.758 .43214 Mdot
.758 .43216 Mdot
.758 .43216 Mdot
.758 .43219 Mdot
.758 .43219 Mdot
.758 .43221 Mdot
.758 .43226 Mdot
.758 .43228 Mdot
.758 .43228 Mdot
.758 .43229 Mdot
.758 .4323 Mdot
.758 .43231 Mdot
.758 .43234 Mdot
.758 .43235 Mdot
.758 .43236 Mdot
.758 .43238 Mdot
.758 .4324 Mdot
.758 .43246 Mdot
.758 .43247 Mdot
.758 .4325 Mdot
.758 .43252 Mdot
.758 .43252 Mdot
.758 .43257 Mdot
.758 .4326 Mdot
.758 .43262 Mdot
.758 .43267 Mdot
.758 .43269 Mdot
.758 .43273 Mdot
.758 .43274 Mdot
.758 .43274 Mdot
.758 .43278 Mdot
.758 .43299 Mdot
.758 .43299 Mdot
.758 .433 Mdot
.758 .43304 Mdot
.758 .43306 Mdot
.758 .43307 Mdot
.758 .43313 Mdot
.758 .43315 Mdot
.758 .43318 Mdot
.758 .4332 Mdot
.758 .43321 Mdot
.758 .43324 Mdot
.758 .43324 Mdot
.758 .43333 Mdot
.758 .43336 Mdot
.758 .4334 Mdot
.758 .4334 Mdot
.758 .43341 Mdot
.758 .43343 Mdot
.758 .43345 Mdot
.758 .43348 Mdot
.758 .43352 Mdot
.758 .43362 Mdot
.758 .43362 Mdot
.758 .43367 Mdot
.758 .4337 Mdot
.758 .4338 Mdot
.758 .43384 Mdot
.758 .43384 Mdot
.758 .43385 Mdot
.758 .43386 Mdot
.758 .43386 Mdot
.758 .43397 Mdot
.758 .43398 Mdot
.758 .43399 Mdot
.758 .43399 Mdot
.758 .43402 Mdot
.758 .43404 Mdot
.758 .43407 Mdot
.758 .43409 Mdot
.758 .43416 Mdot
.758 .43416 Mdot
.758 .43417 Mdot
.758 .43417 Mdot
.758 .43419 Mdot
.758 .43421 Mdot
.758 .43423 Mdot
.758 .43423 Mdot
.758 .43427 Mdot
.758 .43428 Mdot
.758 .43428 Mdot
.758 .43429 Mdot
.758 .4343 Mdot
.758 .43432 Mdot
.758 .43434 Mdot
.758 .43434 Mdot
.758 .43435 Mdot
.758 .43438 Mdot
.758 .43439 Mdot
.758 .43439 Mdot
.758 .4344 Mdot
.758 .4344 Mdot
.758 .43441 Mdot
.758 .43442 Mdot
.758 .43443 Mdot
.758 .43445 Mdot
.758 .43449 Mdot
.758 .43452 Mdot
.758 .43455 Mdot
.758 .43456 Mdot
.758 .43463 Mdot
.758 .43476 Mdot
.758 .43477 Mdot
.758 .43479 Mdot
.758 .43483 Mdot
.758 .43487 Mdot
.758 .43488 Mdot
.758 .43489 Mdot
.758 .43494 Mdot
.758 .43497 Mdot
.758 .43498 Mdot
.758 .43499 Mdot
.758 .43509 Mdot
.758 .43511 Mdot
.758 .43513 Mdot
.758 .43518 Mdot
.758 .43521 Mdot
.758 .4353 Mdot
.758 .43538 Mdot
.758 .43539 Mdot
.758 .4354 Mdot
.758 .4354 Mdot
.758 .43543 Mdot
.758 .43544 Mdot
.758 .43546 Mdot
.758 .43549 Mdot
.758 .43549 Mdot
.758 .4355 Mdot
.758 .43551 Mdot
.758 .43552 Mdot
.758 .43555 Mdot
.758 .43557 Mdot
.758 .43558 Mdot
.758 .43563 Mdot
.758 .43571 Mdot
.758 .43577 Mdot
.758 .43579 Mdot
.758 .43581 Mdot
.758 .43584 Mdot
.758 .43594 Mdot
.758 .43597 Mdot
.758 .43599 Mdot
.758 .43606 Mdot
.758 .43612 Mdot
.758 .43613 Mdot
.758 .43616 Mdot
.758 .43618 Mdot
.758 .4362 Mdot
.758 .43625 Mdot
.758 .43627 Mdot
.758 .43632 Mdot
.758 .43639 Mdot
.758 .4368 Mdot
.758 .43689 Mdot
.758 .43693 Mdot
.758 .43698 Mdot
.758 .43703 Mdot
.758 .43709 Mdot
.758 .43737 Mdot
.758 .43807 Mdot
.758 .43829 Mdot
.758 .43858 Mdot
.758 .43859 Mdot
.758 .4386 Mdot
.758 .43865 Mdot
.758 .43867 Mdot
.758 .43891 Mdot
.758 .43905 Mdot
.758 .43908 Mdot
.758 .43911 Mdot
.758 .43925 Mdot
.758 .43933 Mdot
.758 .43938 Mdot
.758 .43942 Mdot
.758 .43942 Mdot
.758 .43943 Mdot
.758 .43949 Mdot
.758 .4395 Mdot
.758 .4395 Mdot
.758 .43954 Mdot
.758 .43955 Mdot
.758 .43958 Mdot
.758 .43959 Mdot
.758 .4396 Mdot
.758 .43961 Mdot
.758 .448 Mdot
.758 .448 Mdot
.758 .448 Mdot
.758 .44801 Mdot
.758 .44803 Mdot
.758 .44803 Mdot
.758 .44805 Mdot
.758 .44805 Mdot
.758 .44805 Mdot
.758 .44808 Mdot
.758 .44808 Mdot
.758 .44808 Mdot
.758 .4481 Mdot
.758 .44812 Mdot
.758 .44816 Mdot
.758 .44822 Mdot
.758 .44823 Mdot
.758 .44825 Mdot
.758 .44831 Mdot
.758 .44842 Mdot
.758 .44843 Mdot
.758 .44845 Mdot
.758 .44846 Mdot
.758 .44846 Mdot
.758 .4486 Mdot
.758 .4487 Mdot
.758 .44904 Mdot
.758 .44918 Mdot
.758 .44921 Mdot
.758 .44924 Mdot
.758 .44927 Mdot
.758 .44928 Mdot
.758 .44934 Mdot
.758 .44955 Mdot
.758 .44959 Mdot
.758 .44961 Mdot
.758 .44978 Mdot
.758 .4498 Mdot
.758 .44985 Mdot
.758 .44988 Mdot
.758 .44989 Mdot
.758 .45001 Mdot
.758 .45004 Mdot
.758 .45011 Mdot
.758 .45028 Mdot
.758 .45035 Mdot
.758 .45036 Mdot
.758 .45049 Mdot
.758 .45073 Mdot
.758 .45073 Mdot
.758 .45074 Mdot
.758 .45077 Mdot
.758 .45078 Mdot
.758 .45089 Mdot
.758 .45102 Mdot
.758 .45111 Mdot
.758 .45111 Mdot
.758 .45112 Mdot
.758 .45112 Mdot
.758 .45128 Mdot
.758 .45136 Mdot
.758 .45139 Mdot
.758 .45142 Mdot
.758 .45145 Mdot
.758 .45149 Mdot
.758 .45158 Mdot
.758 .45163 Mdot
.758 .45166 Mdot
.758 .45173 Mdot
.758 .45173 Mdot
.758 .45179 Mdot
.758 .45199 Mdot
.758 .45202 Mdot
.758 .45203 Mdot
.758 .45207 Mdot
.758 .45209 Mdot
.758 .45214 Mdot
.758 .45223 Mdot
.758 .45225 Mdot
.758 .45229 Mdot
.758 .45236 Mdot
.758 .45242 Mdot
.758 .45262 Mdot
.758 .45265 Mdot
.758 .45275 Mdot
.758 .45281 Mdot
.758 .45282 Mdot
.758 .45296 Mdot
.758 .45306 Mdot
.758 .45312 Mdot
.758 .45327 Mdot
.758 .45333 Mdot
.758 .45347 Mdot
.758 .45348 Mdot
.758 .4535 Mdot
.758 .45361 Mdot
.758 .45423 Mdot
.758 .45425 Mdot
.758 .45426 Mdot
.758 .45438 Mdot
.758 .45446 Mdot
.758 .45447 Mdot
.758 .45464 Mdot
.758 .45472 Mdot
.758 .4548 Mdot
.758 .45486 Mdot
.758 .45488 Mdot
.758 .45497 Mdot
.758 .45498 Mdot
.758 .45522 Mdot
.758 .4553 Mdot
.758 .45542 Mdot
.758 .45542 Mdot
.758 .45549 Mdot
.758 .45553 Mdot
.758 .45564 Mdot
.758 .45574 Mdot
.758 .456 Mdot
.758 .45601 Mdot
.758 .45613 Mdot
.758 .45621 Mdot
.758 .45646 Mdot
.758 .45655 Mdot
.758 .45657 Mdot
.758 .45658 Mdot
.758 .4566 Mdot
.758 .45661 Mdot
.758 .45688 Mdot
.758 .45689 Mdot
.758 .45692 Mdot
.758 .45693 Mdot
.758 .45701 Mdot
.758 .45704 Mdot
.758 .45712 Mdot
.758 .45715 Mdot
.758 .45732 Mdot
.758 .45732 Mdot
.758 .45734 Mdot
.758 .45734 Mdot
.758 .45738 Mdot
.758 .45744 Mdot
.758 .45747 Mdot
.758 .45748 Mdot
.758 .45757 Mdot
.758 .45758 Mdot
.758 .4576 Mdot
.758 .45761 Mdot
.758 .45762 Mdot
.758 .45768 Mdot
.758 .45771 Mdot
.758 .45771 Mdot
.758 .45774 Mdot
.758 .45781 Mdot
.758 .45782 Mdot
.758 .45782 Mdot
.758 .45784 Mdot
.758 .45785 Mdot
.758 .45786 Mdot
.758 .4579 Mdot
.758 .45792 Mdot
.758 .45794 Mdot
.758 .45803 Mdot
.758 .4581 Mdot
.758 .45815 Mdot
.758 .45819 Mdot
.758 .45832 Mdot
.758 .45857 Mdot
.758 .45858 Mdot
.758 .45862 Mdot
.758 .4587 Mdot
.758 .45877 Mdot
.758 .45878 Mdot
.758 .45881 Mdot
.758 .45889 Mdot
.758 .45895 Mdot
.758 .45896 Mdot
.758 .45898 Mdot
.758 .45914 Mdot
.758 .45918 Mdot
.758 .45921 Mdot
.758 .45929 Mdot
.758 .45934 Mdot
.758 .45943 Mdot
.758 .45944 Mdot
.758 .45944 Mdot
.758 .45947 Mdot
.758 .45948 Mdot
.758 .45951 Mdot
.758 .45952 Mdot
.758 .45957 Mdot
.758 .45957 Mdot
.758 .45958 Mdot
.758 .4596 Mdot
.758 .45962 Mdot
.758 .45963 Mdot
.758 .45963 Mdot
.758 .45966 Mdot
.758 .45967 Mdot
.758 .45967 Mdot
.758 .45967 Mdot
.758 .45968 Mdot
.758 .45971 Mdot
.758 .45972 Mdot
.758 .45974 Mdot
.758 .45975 Mdot
.758 .45976 Mdot
.758 .45978 Mdot
.758 .45978 Mdot
.758 .45979 Mdot
.758 .45983 Mdot
.758 .45985 Mdot
.758 .45987 Mdot
.758 .45988 Mdot
.758 .45993 Mdot
.758 .46003 Mdot
.758 .46004 Mdot
.758 .46008 Mdot
.758 .4601 Mdot
.758 .46011 Mdot
.758 .46012 Mdot
.758 .46015 Mdot
.758 .46018 Mdot
.758 .46026 Mdot
.758 .46028 Mdot
.758 .46032 Mdot
.758 .46034 Mdot
.758 .4604 Mdot
.758 .46046 Mdot
.758 .46047 Mdot
.758 .46047 Mdot
.758 .46049 Mdot
.758 .4605 Mdot
.758 .46051 Mdot
.758 .46053 Mdot
.758 .46053 Mdot
.758 .46053 Mdot
.758 .46055 Mdot
.758 .46057 Mdot
.758 .46059 Mdot
.758 .46062 Mdot
.758 .46068 Mdot
.758 .46075 Mdot
.758 .46086 Mdot
.758 .4609 Mdot
.758 .46094 Mdot
.758 .46095 Mdot
.758 .46097 Mdot
.758 .46098 Mdot
.758 .461 Mdot
.758 .46102 Mdot
.76 .26385 Mdot
.76 .26385 Mdot
.76 .26385 Mdot
.76 .26385 Mdot
.76 .26385 Mdot
.76 .26385 Mdot
.76 .26385 Mdot
.76 .26385 Mdot
.76 .26385 Mdot
.76 .26385 Mdot
.76 .26385 Mdot
.76 .26385 Mdot
.76 .26385 Mdot
.76 .26385 Mdot
.76 .26385 Mdot
.76 .26386 Mdot
.76 .26386 Mdot
.76 .26386 Mdot
.76 .26386 Mdot
.76 .26387 Mdot
.76 .26388 Mdot
.76 .2639 Mdot
.76 .2639 Mdot
.76 .2639 Mdot
.76 .26392 Mdot
.76 .26395 Mdot
.76 .26395 Mdot
.76 .26395 Mdot
.76 .26395 Mdot
.76 .26395 Mdot
.76 .26396 Mdot
.76 .26396 Mdot
.76 .26396 Mdot
.76 .26397 Mdot
.76 .26397 Mdot
.76 .26397 Mdot
.76 .26397 Mdot
.76 .26398 Mdot
.76 .26398 Mdot
.76 .26398 Mdot
.76 .26398 Mdot
.76 .26399 Mdot
.76 .26399 Mdot
.76 .26399 Mdot
.76 .264 Mdot
.76 .264 Mdot
.76 .26402 Mdot
.76 .26402 Mdot
.76 .26403 Mdot
.76 .26405 Mdot
.76 .26406 Mdot
.76 .26407 Mdot
.76 .26411 Mdot
.76 .26413 Mdot
.76 .26414 Mdot
.76 .26414 Mdot
.76 .26415 Mdot
.76 .26415 Mdot
.76 .26416 Mdot
.76 .26416 Mdot
.76 .26416 Mdot
.76 .26416 Mdot
.76 .26417 Mdot
.76 .26417 Mdot
.76 .26417 Mdot
.76 .26417 Mdot
.76 .26417 Mdot
.76 .26418 Mdot
.76 .26418 Mdot
.76 .26419 Mdot
.76 .26419 Mdot
.76 .26419 Mdot
.76 .26419 Mdot
.76 .26419 Mdot
.76 .26419 Mdot
.76 .26422 Mdot
.76 .26424 Mdot
.76 .26425 Mdot
.76 .26428 Mdot
.76 .26429 Mdot
.76 .2643 Mdot
.76 .26432 Mdot
.76 .26433 Mdot
.76 .26433 Mdot
.76 .26434 Mdot
.76 .26435 Mdot
.76 .26435 Mdot
.76 .26436 Mdot
.76 .26436 Mdot
.76 .26437 Mdot
.76 .26437 Mdot
.76 .26438 Mdot
.76 .26439 Mdot
.76 .2644 Mdot
.76 .26441 Mdot
.76 .26441 Mdot
.76 .26441 Mdot
.76 .26441 Mdot
.76 .26441 Mdot
.76 .2645 Mdot
.76 .26455 Mdot
.76 .26457 Mdot
.76 .26458 Mdot
.76 .26464 Mdot
.76 .26464 Mdot
.76 .26467 Mdot
.76 .26468 Mdot
.76 .26469 Mdot
.76 .2647 Mdot
.76 .2647 Mdot
.76 .2647 Mdot
.76 .2647 Mdot
.76 .2647 Mdot
.76 .2647 Mdot
.76 .2647 Mdot
.76 .26471 Mdot
.76 .26471 Mdot
.76 .26471 Mdot
.76 .26471 Mdot
.76 .26471 Mdot
.76 .26471 Mdot
.76 .26472 Mdot
.76 .26472 Mdot
.76 .26472 Mdot
.76 .26472 Mdot
.76 .26523 Mdot
.76 .26523 Mdot
.76 .26523 Mdot
.76 .26523 Mdot
.76 .26523 Mdot
.76 .26523 Mdot
.76 .26523 Mdot
.76 .26523 Mdot
.76 .26524 Mdot
.76 .26524 Mdot
.76 .26524 Mdot
.76 .26524 Mdot
.76 .26524 Mdot
.76 .26524 Mdot
.76 .26524 Mdot
.76 .26524 Mdot
.76 .26524 Mdot
.76 .26524 Mdot
.76 .26525 Mdot
.76 .26525 Mdot
.76 .26527 Mdot
.76 .26527 Mdot
.76 .2653 Mdot
.76 .26531 Mdot
.76 .26532 Mdot
.76 .26534 Mdot
.76 .26539 Mdot
.76 .26539 Mdot
.76 .26539 Mdot
.76 .26539 Mdot
.76 .26539 Mdot
.76 .26539 Mdot
.76 .2654 Mdot
.76 .2654 Mdot
.76 .26541 Mdot
.76 .26541 Mdot
.76 .26541 Mdot
.76 .26541 Mdot
.76 .26542 Mdot
.76 .26542 Mdot
.76 .26543 Mdot
.76 .26543 Mdot
.76 .26543 Mdot
.76 .26543 Mdot
.76 .26544 Mdot
.76 .26545 Mdot
.76 .26545 Mdot
.76 .26547 Mdot
.76 .26548 Mdot
.76 .26549 Mdot
.76 .2655 Mdot
.76 .2655 Mdot
.76 .2655 Mdot
.76 .2655 Mdot
.76 .2655 Mdot
.76 .2655 Mdot
.76 .26551 Mdot
.76 .26551 Mdot
.76 .26551 Mdot
.76 .26551 Mdot
.76 .26551 Mdot
.76 .26551 Mdot
.76 .26551 Mdot
.76 .26551 Mdot
.76 .26551 Mdot
.76 .26552 Mdot
.76 .26552 Mdot
.76 .26552 Mdot
.76 .26552 Mdot
.76 .26553 Mdot
.76 .26553 Mdot
.76 .26553 Mdot
.76 .26554 Mdot
.76 .26556 Mdot
.76 .26557 Mdot
.76 .26557 Mdot
.76 .26558 Mdot
.76 .26559 Mdot
.76 .26559 Mdot
.76 .2656 Mdot
.76 .2656 Mdot
.76 .2656 Mdot
.76 .26561 Mdot
.76 .26561 Mdot
.76 .26561 Mdot
.76 .26561 Mdot
.76 .26561 Mdot
.76 .26561 Mdot
.76 .26561 Mdot
.76 .26562 Mdot
.76 .26562 Mdot
.76 .26562 Mdot
.76 .26562 Mdot
.76 .26562 Mdot
.76 .26562 Mdot
.76 .26562 Mdot
.76 .26562 Mdot
.76 .26562 Mdot
.76 .26562 Mdot
.76 .26562 Mdot
.76 .26564 Mdot
.76 .26565 Mdot
.76 .26565 Mdot
.76 .26566 Mdot
.76 .26567 Mdot
.76 .26567 Mdot
.76 .26567 Mdot
.76 .26568 Mdot
.76 .26568 Mdot
.76 .26568 Mdot
.76 .26568 Mdot
.76 .26568 Mdot
.76 .26568 Mdot
.76 .26568 Mdot
.76 .26568 Mdot
.76 .26568 Mdot
.76 .26568 Mdot
.76 .26568 Mdot
.76 .26568 Mdot
.76 .26568 Mdot
.76 .26568 Mdot
.76 .26568 Mdot
.76 .26568 Mdot
.76 .26568 Mdot
.76 .26568 Mdot
.76 .27629 Mdot
.76 .27629 Mdot
.76 .27629 Mdot
.76 .27629 Mdot
.76 .27629 Mdot
.76 .27629 Mdot
.76 .27629 Mdot
.76 .27629 Mdot
.76 .2763 Mdot
.76 .2763 Mdot
.76 .2763 Mdot
.76 .2763 Mdot
.76 .2763 Mdot
.76 .2763 Mdot
.76 .2763 Mdot
.76 .2763 Mdot
.76 .27631 Mdot
.76 .27631 Mdot
.76 .27633 Mdot
.76 .27635 Mdot
.76 .27635 Mdot
.76 .27641 Mdot
.76 .27641 Mdot
.76 .27642 Mdot
.76 .27647 Mdot
.76 .27655 Mdot
.76 .27655 Mdot
.76 .27655 Mdot
.76 .27655 Mdot
.76 .27656 Mdot
.76 .27656 Mdot
.76 .27657 Mdot
.76 .27658 Mdot
.76 .27659 Mdot
.76 .27659 Mdot
.76 .2766 Mdot
.76 .2766 Mdot
.76 .27661 Mdot
.76 .27661 Mdot
.76 .27662 Mdot
.76 .27663 Mdot
.76 .27663 Mdot
.76 .27664 Mdot
.76 .27666 Mdot
.76 .27668 Mdot
.76 .27668 Mdot
.76 .27671 Mdot
.76 .27672 Mdot
.76 .27675 Mdot
.76 .2768 Mdot
.76 .27683 Mdot
.76 .27685 Mdot
.76 .27694 Mdot
.76 .277 Mdot
.76 .27702 Mdot
.76 .27703 Mdot
.76 .27705 Mdot
.76 .27705 Mdot
.76 .27707 Mdot
.76 .27708 Mdot
.76 .27708 Mdot
.76 .27709 Mdot
.76 .27709 Mdot
.76 .2771 Mdot
.76 .2771 Mdot
.76 .27711 Mdot
.76 .27711 Mdot
.76 .27712 Mdot
.76 .27713 Mdot
.76 .27714 Mdot
.76 .27715 Mdot
.76 .27715 Mdot
.76 .27715 Mdot
.76 .27715 Mdot
.76 .27715 Mdot
.76 .27723 Mdot
.76 .27728 Mdot
.76 .2773 Mdot
.76 .27738 Mdot
.76 .27739 Mdot
.76 .27744 Mdot
.76 .27748 Mdot
.76 .2775 Mdot
.76 .2775 Mdot
.76 .27753 Mdot
.76 .27754 Mdot
.76 .27756 Mdot
.76 .27759 Mdot
.76 .27759 Mdot
.76 .2776 Mdot
.76 .27761 Mdot
.76 .27763 Mdot
.76 .27765 Mdot
.76 .27769 Mdot
.76 .2777 Mdot
.76 .27771 Mdot
.76 .27771 Mdot
.76 .27772 Mdot
.76 .27772 Mdot
.76 .27794 Mdot
.76 .27808 Mdot
.76 .27813 Mdot
.76 .27814 Mdot
.76 .2783 Mdot
.76 .27833 Mdot
.76 .2784 Mdot
.76 .27844 Mdot
.76 .27845 Mdot
.76 .27847 Mdot
.76 .27847 Mdot
.76 .27848 Mdot
.76 .27848 Mdot
.76 .27848 Mdot
.76 .27849 Mdot
.76 .27849 Mdot
.76 .27849 Mdot
.76 .2785 Mdot
.76 .2785 Mdot
.76 .27851 Mdot
.76 .27852 Mdot
.76 .27852 Mdot
.76 .27852 Mdot
.76 .27852 Mdot
.76 .27852 Mdot
.76 .27852 Mdot
.76 .28138 Mdot
.76 .28138 Mdot
.76 .28138 Mdot
.76 .28138 Mdot
.76 .28138 Mdot
.76 .28139 Mdot
.76 .2814 Mdot
.76 .28142 Mdot
.76 .28142 Mdot
.76 .28143 Mdot
.76 .28144 Mdot
.76 .28145 Mdot
.76 .28145 Mdot
.76 .28146 Mdot
.76 .28146 Mdot
.76 .28148 Mdot
.76 .2815 Mdot
.76 .28153 Mdot
.76 .28156 Mdot
.76 .28164 Mdot
.76 .2818 Mdot
.76 .28184 Mdot
.76 .28221 Mdot
.76 .28223 Mdot
.76 .28267 Mdot
.76 .2832 Mdot
.76 .28321 Mdot
.76 .28321 Mdot
.76 .28322 Mdot
.76 .28324 Mdot
.76 .28326 Mdot
.76 .28336 Mdot
.76 .28341 Mdot
.76 .28347 Mdot
.76 .28349 Mdot
.76 .28351 Mdot
.76 .28352 Mdot
.76 .28358 Mdot
.76 .28362 Mdot
.76 .28367 Mdot
.76 .28372 Mdot
.76 .28374 Mdot
.76 .28378 Mdot
.76 .28389 Mdot
.76 .284 Mdot
.76 .28403 Mdot
.76 .28423 Mdot
.76 .28429 Mdot
.76 .28442 Mdot
.76 .28462 Mdot
.76 .28462 Mdot
.76 .28462 Mdot
.76 .28462 Mdot
.76 .28463 Mdot
.76 .28464 Mdot
.76 .28467 Mdot
.76 .2847 Mdot
.76 .28472 Mdot
.76 .28472 Mdot
.76 .28474 Mdot
.76 .28475 Mdot
.76 .28477 Mdot
.76 .28479 Mdot
.76 .28479 Mdot
.76 .2848 Mdot
.76 .28484 Mdot
.76 .28487 Mdot
.76 .28488 Mdot
.76 .28494 Mdot
.76 .28496 Mdot
.76 .285 Mdot
.76 .28516 Mdot
.76 .28541 Mdot
.76 .28545 Mdot
.76 .28553 Mdot
.76 .28567 Mdot
.76 .28573 Mdot
.76 .28576 Mdot
.76 .28585 Mdot
.76 .28586 Mdot
.76 .28591 Mdot
.76 .28596 Mdot
.76 .28597 Mdot
.76 .28598 Mdot
.76 .28601 Mdot
.76 .28603 Mdot
.76 .28604 Mdot
.76 .28607 Mdot
.76 .28607 Mdot
.76 .28608 Mdot
.76 .28609 Mdot
.76 .28611 Mdot
.76 .28613 Mdot
.76 .28617 Mdot
.76 .28618 Mdot
.76 .28619 Mdot
.76 .2862 Mdot
.76 .2862 Mdot
.76 .2862 Mdot
.76 .28641 Mdot
.76 .28654 Mdot
.76 .28658 Mdot
.76 .28659 Mdot
.76 .28673 Mdot
.76 .28674 Mdot
.76 .2868 Mdot
.76 .28683 Mdot
.76 .28684 Mdot
.76 .28685 Mdot
.76 .28686 Mdot
.76 .28687 Mdot
.76 .28687 Mdot
.76 .28687 Mdot
.76 .28687 Mdot
.76 .28688 Mdot
.76 .28688 Mdot
.76 .28688 Mdot
.76 .28688 Mdot
.76 .28689 Mdot
.76 .2869 Mdot
.76 .2869 Mdot
.76 .2869 Mdot
.76 .2869 Mdot
.76 .2869 Mdot
.76 .2869 Mdot
.76 .43629 Mdot
.76 .43629 Mdot
.76 .43629 Mdot
.76 .43629 Mdot
.76 .43629 Mdot
.76 .43629 Mdot
.76 .43629 Mdot
.76 .43629 Mdot
.76 .4363 Mdot
.76 .4363 Mdot
.76 .4363 Mdot
.76 .4363 Mdot
.76 .4363 Mdot
.76 .4363 Mdot
.76 .4363 Mdot
.76 .4363 Mdot
.76 .43631 Mdot
.76 .43631 Mdot
.76 .43631 Mdot
.76 .43633 Mdot
.76 .43635 Mdot
.76 .43636 Mdot
.76 .43641 Mdot
.76 .43641 Mdot
.76 .43643 Mdot
.76 .43648 Mdot
.76 .43656 Mdot
.76 .43656 Mdot
.76 .43656 Mdot
.76 .43657 Mdot
.76 .43657 Mdot
.76 .43657 Mdot
.76 .43659 Mdot
.76 .4366 Mdot
.76 .4366 Mdot
.76 .43661 Mdot
.76 .43661 Mdot
.76 .43661 Mdot
.76 .43662 Mdot
.76 .43663 Mdot
.76 .43664 Mdot
.76 .43665 Mdot
.76 .43665 Mdot
.76 .43666 Mdot
.76 .43667 Mdot
.76 .43669 Mdot
.76 .4367 Mdot
.76 .43673 Mdot
.76 .43675 Mdot
.76 .43677 Mdot
.76 .43683 Mdot
.76 .43686 Mdot
.76 .43687 Mdot
.76 .43697 Mdot
.76 .43704 Mdot
.76 .43706 Mdot
.76 .43706 Mdot
.76 .43709 Mdot
.76 .43709 Mdot
.76 .4371 Mdot
.76 .43712 Mdot
.76 .43712 Mdot
.76 .43713 Mdot
.76 .43713 Mdot
.76 .43714 Mdot
.76 .43714 Mdot
.76 .43715 Mdot
.76 .43715 Mdot
.76 .43716 Mdot
.76 .43717 Mdot
.76 .43719 Mdot
.76 .43719 Mdot
.76 .43719 Mdot
.76 .43719 Mdot
.76 .43719 Mdot
.76 .43719 Mdot
.76 .43727 Mdot
.76 .43733 Mdot
.76 .43735 Mdot
.76 .43743 Mdot
.76 .43745 Mdot
.76 .43749 Mdot
.76 .43754 Mdot
.76 .43755 Mdot
.76 .43756 Mdot
.76 .43758 Mdot
.76 .4376 Mdot
.76 .43762 Mdot
.76 .43764 Mdot
.76 .43765 Mdot
.76 .43766 Mdot
.76 .43767 Mdot
.76 .43769 Mdot
.76 .43771 Mdot
.76 .43775 Mdot
.76 .43776 Mdot
.76 .43777 Mdot
.76 .43777 Mdot
.76 .43778 Mdot
.76 .43778 Mdot
.76 .438 Mdot
.76 .43814 Mdot
.76 .43819 Mdot
.76 .4382 Mdot
.76 .43836 Mdot
.76 .43838 Mdot
.76 .43845 Mdot
.76 .43848 Mdot
.76 .43849 Mdot
.76 .43851 Mdot
.76 .43852 Mdot
.76 .43852 Mdot
.76 .43853 Mdot
.76 .43853 Mdot
.76 .43853 Mdot
.76 .43853 Mdot
.76 .43854 Mdot
.76 .43854 Mdot
.76 .43854 Mdot
.76 .43855 Mdot
.76 .43856 Mdot
.76 .43856 Mdot
.76 .43856 Mdot
.76 .43856 Mdot
.76 .43856 Mdot
.76 .43856 Mdot
.76 .43987 Mdot
.76 .43987 Mdot
.76 .43987 Mdot
.76 .43987 Mdot
.76 .43987 Mdot
.76 .43987 Mdot
.76 .43987 Mdot
.76 .43988 Mdot
.76 .43988 Mdot
.76 .43988 Mdot
.76 .43988 Mdot
.76 .43989 Mdot
.76 .43989 Mdot
.76 .43989 Mdot
.76 .43989 Mdot
.76 .43989 Mdot
.76 .4399 Mdot
.76 .4399 Mdot
.76 .43991 Mdot
.76 .43993 Mdot
.76 .43996 Mdot
.76 .43997 Mdot
.76 .44005 Mdot
.76 .44006 Mdot
.76 .44008 Mdot
.76 .44015 Mdot
.76 .44026 Mdot
.76 .44026 Mdot
.76 .44026 Mdot
.76 .44026 Mdot
.76 .44027 Mdot
.76 .44027 Mdot
.76 .44029 Mdot
.76 .4403 Mdot
.76 .44031 Mdot
.76 .44032 Mdot
.76 .44032 Mdot
.76 .44032 Mdot
.76 .44034 Mdot
.76 .44034 Mdot
.76 .44035 Mdot
.76 .44036 Mdot
.76 .44037 Mdot
.76 .44038 Mdot
.76 .4404 Mdot
.76 .44042 Mdot
.76 .44042 Mdot
.76 .44046 Mdot
.76 .44048 Mdot
.76 .4405 Mdot
.76 .44054 Mdot
.76 .44054 Mdot
.76 .44054 Mdot
.76 .44054 Mdot
.76 .44054 Mdot
.76 .44054 Mdot
.76 .44055 Mdot
.76 .44056 Mdot
.76 .44056 Mdot
.76 .44056 Mdot
.76 .44056 Mdot
.76 .44057 Mdot
.76 .44057 Mdot
.76 .44057 Mdot
.76 .44057 Mdot
.76 .44058 Mdot
.76 .44058 Mdot
.76 .44059 Mdot
.76 .44059 Mdot
.76 .4406 Mdot
.76 .44061 Mdot
.76 .44061 Mdot
.76 .44064 Mdot
.76 .44069 Mdot
.76 .4407 Mdot
.76 .44072 Mdot
.76 .44074 Mdot
.76 .44075 Mdot
.76 .44076 Mdot
.76 .44078 Mdot
.76 .44078 Mdot
.76 .44079 Mdot
.76 .4408 Mdot
.76 .4408 Mdot
.76 .4408 Mdot
.76 .44081 Mdot
.76 .44081 Mdot
.76 .44081 Mdot
.76 .44082 Mdot
.76 .44082 Mdot
.76 .44082 Mdot
.76 .44082 Mdot
.76 .44083 Mdot
.76 .44083 Mdot
.76 .44084 Mdot
.76 .44084 Mdot
.76 .44084 Mdot
.76 .44084 Mdot
.76 .44084 Mdot
.76 .44084 Mdot
.76 .44088 Mdot
.76 .44091 Mdot
.76 .44092 Mdot
.76 .44092 Mdot
.76 .44094 Mdot
.76 .44095 Mdot
.76 .44096 Mdot
.76 .44097 Mdot
.76 .44097 Mdot
.76 .44097 Mdot
.76 .44097 Mdot
.76 .44097 Mdot
.76 .44097 Mdot
.76 .44097 Mdot
.76 .44097 Mdot
.76 .44097 Mdot
.76 .44097 Mdot
.76 .44098 Mdot
.76 .44098 Mdot
.76 .44098 Mdot
.76 .44098 Mdot
.76 .44098 Mdot
.76 .44098 Mdot
.76 .44098 Mdot
.76 .44098 Mdot
.76 .45895 Mdot
.76 .45895 Mdot
.76 .45895 Mdot
.76 .45895 Mdot
.76 .45895 Mdot
.76 .45895 Mdot
.76 .45895 Mdot
.76 .45895 Mdot
.76 .45895 Mdot
.76 .45896 Mdot
.76 .45896 Mdot
.76 .45896 Mdot
.76 .45896 Mdot
.76 .45896 Mdot
.76 .45896 Mdot
.76 .45896 Mdot
.76 .45896 Mdot
.76 .45897 Mdot
.76 .45898 Mdot
.76 .459 Mdot
.76 .45901 Mdot
.76 .45906 Mdot
.76 .45906 Mdot
.76 .45907 Mdot
.76 .45912 Mdot
.76 .45919 Mdot
.76 .45919 Mdot
.76 .45919 Mdot
.76 .45919 Mdot
.76 .45919 Mdot
.76 .4592 Mdot
.76 .45921 Mdot
.76 .45922 Mdot
.76 .45922 Mdot
.76 .45923 Mdot
.76 .45923 Mdot
.76 .45923 Mdot
.76 .45924 Mdot
.76 .45925 Mdot
.76 .45925 Mdot
.76 .45926 Mdot
.76 .45926 Mdot
.76 .45927 Mdot
.76 .45928 Mdot
.76 .4593 Mdot
.76 .4593 Mdot
.76 .45933 Mdot
.76 .45934 Mdot
.76 .45936 Mdot
.76 .45941 Mdot
.76 .45944 Mdot
.76 .45945 Mdot
.76 .45953 Mdot
.76 .45958 Mdot
.76 .45959 Mdot
.76 .4596 Mdot
.76 .45962 Mdot
.76 .45962 Mdot
.76 .45963 Mdot
.76 .45964 Mdot
.76 .45965 Mdot
.76 .45965 Mdot
.76 .45966 Mdot
.76 .45966 Mdot
.76 .45966 Mdot
.76 .45967 Mdot
.76 .45967 Mdot
.76 .45968 Mdot
.76 .45969 Mdot
.76 .4597 Mdot
.76 .4597 Mdot
.76 .4597 Mdot
.76 .4597 Mdot
.76 .4597 Mdot
.76 .4597 Mdot
.76 .45976 Mdot
.76 .45981 Mdot
.76 .45983 Mdot
.76 .45989 Mdot
.76 .4599 Mdot
.76 .45993 Mdot
.76 .45996 Mdot
.76 .45998 Mdot
.76 .45998 Mdot
.76 .46 Mdot
.76 .46001 Mdot
.76 .46003 Mdot
.76 .46004 Mdot
.76 .46005 Mdot
.76 .46005 Mdot
.76 .46006 Mdot
.76 .46008 Mdot
.76 .46009 Mdot
.76 .46012 Mdot
.76 .46013 Mdot
.76 .46014 Mdot
.76 .46014 Mdot
.76 .46014 Mdot
.76 .46014 Mdot
.76 .4603 Mdot
.76 .4604 Mdot
.76 .46044 Mdot
.76 .46044 Mdot
.76 .46055 Mdot
.76 .46057 Mdot
.76 .46061 Mdot
.76 .46064 Mdot
.76 .46065 Mdot
.76 .46066 Mdot
.76 .46066 Mdot
.76 .46067 Mdot
.76 .46067 Mdot
.76 .46067 Mdot
.76 .46067 Mdot
.76 .46067 Mdot
.76 .46067 Mdot
.76 .46068 Mdot
.76 .46068 Mdot
.76 .46068 Mdot
.76 .46069 Mdot
.76 .46069 Mdot
.76 .46069 Mdot
.76 .46069 Mdot
.76 .46069 Mdot
.76 .46069 Mdot
.76 .46154 Mdot
.76 .46154 Mdot
.76 .46154 Mdot
.76 .46154 Mdot
.76 .46154 Mdot
.76 .46154 Mdot
.76 .46154 Mdot
.76 .46154 Mdot
.76 .46154 Mdot
.76 .46154 Mdot
.76 .46154 Mdot
.76 .46155 Mdot
.76 .46155 Mdot
.76 .46155 Mdot
.76 .46155 Mdot
.76 .46155 Mdot
.76 .46155 Mdot
.76 .46156 Mdot
.76 .46156 Mdot
.76 .46157 Mdot
.76 .46159 Mdot
.76 .4616 Mdot
.76 .46165 Mdot
.76 .46165 Mdot
.76 .46167 Mdot
.76 .46171 Mdot
.76 .46177 Mdot
.76 .46177 Mdot
.76 .46177 Mdot
.76 .46178 Mdot
.76 .46178 Mdot
.76 .46178 Mdot
.76 .46179 Mdot
.76 .4618 Mdot
.76 .46181 Mdot
.76 .46181 Mdot
.76 .46181 Mdot
.76 .46181 Mdot
.76 .46182 Mdot
.76 .46183 Mdot
.76 .46183 Mdot
.76 .46184 Mdot
.76 .46184 Mdot
.76 .46184 Mdot
.76 .46186 Mdot
.76 .46187 Mdot
.76 .46187 Mdot
.76 .4619 Mdot
.76 .4619 Mdot
.76 .46192 Mdot
.76 .46194 Mdot
.76 .46194 Mdot
.76 .46194 Mdot
.76 .46194 Mdot
.76 .46194 Mdot
.76 .46195 Mdot
.76 .46195 Mdot
.76 .46195 Mdot
.76 .46195 Mdot
.76 .46195 Mdot
.76 .46196 Mdot
.76 .46196 Mdot
.76 .46196 Mdot
.76 .46196 Mdot
.76 .46196 Mdot
.76 .46196 Mdot
.76 .46197 Mdot
.76 .46197 Mdot
.76 .46197 Mdot
.76 .46198 Mdot
.76 .46198 Mdot
.76 .46199 Mdot
.76 .46201 Mdot
.76 .46203 Mdot
.76 .46204 Mdot
.76 .46205 Mdot
.76 .46206 Mdot
.76 .46207 Mdot
.76 .46207 Mdot
.76 .46208 Mdot
.76 .46209 Mdot
.76 .46209 Mdot
.76 .4621 Mdot
.76 .4621 Mdot
.76 .4621 Mdot
.76 .4621 Mdot
.76 .4621 Mdot
.76 .46211 Mdot
.76 .46211 Mdot
.76 .46211 Mdot
.76 .46211 Mdot
.76 .46211 Mdot
.76 .46211 Mdot
.76 .46212 Mdot
.76 .46212 Mdot
.76 .46212 Mdot
.76 .46212 Mdot
.76 .46212 Mdot
.76 .46212 Mdot
.76 .46212 Mdot
.76 .46215 Mdot
.76 .46216 Mdot
.76 .46217 Mdot
.76 .46217 Mdot
.76 .46218 Mdot
.76 .46218 Mdot
.76 .46219 Mdot
.76 .4622 Mdot
.76 .4622 Mdot
.76 .4622 Mdot
.76 .4622 Mdot
.76 .4622 Mdot
.76 .4622 Mdot
.76 .4622 Mdot
.76 .4622 Mdot
.76 .4622 Mdot
.76 .4622 Mdot
.76 .4622 Mdot
.76 .4622 Mdot
.76 .4622 Mdot
.76 .4622 Mdot
.76 .4622 Mdot
.76 .4622 Mdot
.76 .4622 Mdot
.76 .4622 Mdot
.762 .26368 Mdot
.762 .26369 Mdot
.762 .26369 Mdot
.762 .26371 Mdot
.762 .26371 Mdot
.762 .26374 Mdot
.762 .26375 Mdot
.762 .26382 Mdot
.762 .26387 Mdot
.762 .26391 Mdot
.762 .26391 Mdot
.762 .26393 Mdot
.762 .26395 Mdot
.762 .26395 Mdot
.762 .26395 Mdot
.762 .26396 Mdot
.762 .26397 Mdot
.762 .26401 Mdot
.762 .26403 Mdot
.762 .26404 Mdot
.762 .26404 Mdot
.762 .26405 Mdot
.762 .26406 Mdot
.762 .26407 Mdot
.762 .26408 Mdot
.762 .26408 Mdot
.762 .26409 Mdot
.762 .26416 Mdot
.762 .26416 Mdot
.762 .26416 Mdot
.762 .26417 Mdot
.762 .26417 Mdot
.762 .26417 Mdot
.762 .26417 Mdot
.762 .26418 Mdot
.762 .2642 Mdot
.762 .2642 Mdot
.762 .2642 Mdot
.762 .26421 Mdot
.762 .26421 Mdot
.762 .26421 Mdot
.762 .26422 Mdot
.762 .26422 Mdot
.762 .26422 Mdot
.762 .26423 Mdot
.762 .26425 Mdot
.762 .26427 Mdot
.762 .26428 Mdot
.762 .26428 Mdot
.762 .2643 Mdot
.762 .2643 Mdot
.762 .26437 Mdot
.762 .26437 Mdot
.762 .26437 Mdot
.762 .2644 Mdot
.762 .26441 Mdot
.762 .26441 Mdot
.762 .26444 Mdot
.762 .26444 Mdot
.762 .26444 Mdot
.762 .26444 Mdot
.762 .26444 Mdot
.762 .26445 Mdot
.762 .26445 Mdot
.762 .26445 Mdot
.762 .26449 Mdot
.762 .26451 Mdot
.762 .26451 Mdot
.762 .26452 Mdot
.762 .26452 Mdot
.762 .26452 Mdot
.762 .26453 Mdot
.762 .26453 Mdot
.762 .26453 Mdot
.762 .26453 Mdot
.762 .26453 Mdot
.762 .26456 Mdot
.762 .26457 Mdot
.762 .26463 Mdot
.762 .26463 Mdot
.762 .26465 Mdot
.762 .26479 Mdot
.762 .26482 Mdot
.762 .26483 Mdot
.762 .26486 Mdot
.762 .26486 Mdot
.762 .26489 Mdot
.762 .2649 Mdot
.762 .26494 Mdot
.762 .26498 Mdot
.762 .26499 Mdot
.762 .26499 Mdot
.762 .26499 Mdot
.762 .26499 Mdot
.762 .265 Mdot
.762 .26501 Mdot
.762 .26501 Mdot
.762 .26502 Mdot
.762 .26502 Mdot
.762 .26502 Mdot
.762 .26503 Mdot
.762 .26503 Mdot
.762 .26505 Mdot
.762 .26505 Mdot
.762 .26506 Mdot
.762 .26506 Mdot
.762 .26506 Mdot
.762 .26507 Mdot
.762 .26507 Mdot
.762 .26507 Mdot
.762 .26507 Mdot
.762 .26508 Mdot
.762 .26508 Mdot
.762 .26508 Mdot
.762 .26509 Mdot
.762 .26512 Mdot
.762 .26513 Mdot
.762 .26513 Mdot
.762 .26513 Mdot
.762 .26513 Mdot
.762 .26514 Mdot
.762 .26514 Mdot
.762 .26514 Mdot
.762 .26514 Mdot
.762 .26514 Mdot
.762 .26561 Mdot
.762 .26561 Mdot
.762 .26561 Mdot
.762 .26561 Mdot
.762 .26561 Mdot
.762 .26562 Mdot
.762 .26562 Mdot
.762 .26562 Mdot
.762 .26563 Mdot
.762 .26565 Mdot
.762 .26573 Mdot
.762 .26574 Mdot
.762 .26574 Mdot
.762 .26574 Mdot
.762 .26576 Mdot
.762 .26577 Mdot
.762 .26577 Mdot
.762 .26578 Mdot
.762 .26578 Mdot
.762 .26578 Mdot
.762 .26579 Mdot
.762 .26581 Mdot
.762 .26581 Mdot
.762 .26586 Mdot
.762 .26586 Mdot
.762 .26587 Mdot
.762 .26588 Mdot
.762 .26589 Mdot
.762 .2659 Mdot
.762 .26591 Mdot
.762 .26594 Mdot
.762 .26595 Mdot
.762 .26595 Mdot
.762 .26595 Mdot
.762 .26596 Mdot
.762 .26597 Mdot
.762 .26607 Mdot
.762 .26616 Mdot
.762 .26618 Mdot
.762 .26624 Mdot
.762 .26624 Mdot
.762 .26631 Mdot
.762 .26633 Mdot
.762 .26639 Mdot
.762 .26666 Mdot
.762 .26669 Mdot
.762 .26669 Mdot
.762 .26678 Mdot
.762 .26681 Mdot
.762 .26685 Mdot
.762 .26685 Mdot
.762 .26685 Mdot
.762 .26685 Mdot
.762 .26686 Mdot
.762 .26686 Mdot
.762 .26687 Mdot
.762 .26687 Mdot
.762 .26688 Mdot
.762 .26688 Mdot
.762 .26692 Mdot
.762 .26695 Mdot
.762 .26695 Mdot
.762 .26695 Mdot
.762 .26696 Mdot
.762 .26696 Mdot
.762 .26697 Mdot
.762 .26697 Mdot
.762 .26697 Mdot
.762 .26698 Mdot
.762 .26698 Mdot
.762 .26698 Mdot
.762 .26698 Mdot
.762 .26698 Mdot
.762 .26701 Mdot
.762 .26701 Mdot
.762 .26701 Mdot
.762 .26702 Mdot
.762 .26703 Mdot
.762 .26705 Mdot
.762 .26705 Mdot
.762 .26706 Mdot
.762 .26711 Mdot
.762 .26712 Mdot
.762 .26712 Mdot
.762 .26713 Mdot
.762 .26713 Mdot
.762 .26714 Mdot
.762 .26714 Mdot
.762 .26716 Mdot
.762 .26717 Mdot
.762 .26717 Mdot
.762 .26717 Mdot
.762 .26717 Mdot
.762 .26717 Mdot
.762 .26717 Mdot
.762 .26718 Mdot
.762 .26718 Mdot
.762 .26718 Mdot
.762 .26718 Mdot
.762 .26718 Mdot
.762 .26718 Mdot
.762 .26719 Mdot
.762 .26719 Mdot
.762 .26719 Mdot
.762 .26719 Mdot
.762 .2672 Mdot
.762 .2672 Mdot
.762 .2672 Mdot
.762 .2672 Mdot
.762 .2672 Mdot
.762 .2672 Mdot
.762 .2672 Mdot
.762 .2672 Mdot
.762 .2672 Mdot
.762 .2672 Mdot
.762 .26721 Mdot
.762 .26721 Mdot
.762 .26722 Mdot
.762 .26722 Mdot
.762 .26722 Mdot
.762 .26722 Mdot
.762 .26722 Mdot
.762 .26722 Mdot
.762 .26722 Mdot
.762 .26722 Mdot
.762 .26942 Mdot
.762 .26942 Mdot
.762 .26942 Mdot
.762 .26942 Mdot
.762 .26942 Mdot
.762 .26942 Mdot
.762 .26942 Mdot
.762 .26942 Mdot
.762 .26943 Mdot
.762 .26943 Mdot
.762 .26946 Mdot
.762 .26946 Mdot
.762 .26946 Mdot
.762 .26947 Mdot
.762 .26947 Mdot
.762 .26948 Mdot
.762 .26948 Mdot
.762 .26948 Mdot
.762 .26948 Mdot
.762 .26948 Mdot
.762 .26948 Mdot
.762 .26949 Mdot
.762 .26949 Mdot
.762 .26951 Mdot
.762 .26951 Mdot
.762 .26951 Mdot
.762 .26952 Mdot
.762 .26952 Mdot
.762 .26952 Mdot
.762 .26953 Mdot
.762 .26954 Mdot
.762 .26954 Mdot
.762 .26954 Mdot
.762 .26954 Mdot
.762 .26955 Mdot
.762 .26955 Mdot
.762 .26959 Mdot
.762 .26963 Mdot
.762 .26964 Mdot
.762 .26966 Mdot
.762 .26966 Mdot
.762 .2697 Mdot
.762 .26971 Mdot
.762 .26973 Mdot
.762 .26988 Mdot
.762 .2699 Mdot
.762 .2699 Mdot
.762 .26996 Mdot
.762 .26998 Mdot
.762 .27001 Mdot
.762 .27003 Mdot
.762 .27011 Mdot
.762 .27011 Mdot
.762 .27012 Mdot
.762 .27012 Mdot
.762 .27012 Mdot
.762 .27013 Mdot
.762 .27013 Mdot
.762 .27016 Mdot
.762 .27016 Mdot
.762 .27017 Mdot
.762 .27021 Mdot
.762 .27021 Mdot
.762 .27022 Mdot
.762 .27031 Mdot
.762 .27042 Mdot
.762 .27042 Mdot
.762 .27044 Mdot
.762 .27045 Mdot
.762 .27048 Mdot
.762 .2705 Mdot
.762 .2705 Mdot
.762 .2705 Mdot
.762 .27051 Mdot
.762 .27052 Mdot
.762 .27064 Mdot
.762 .27073 Mdot
.762 .27102 Mdot
.762 .27102 Mdot
.762 .27113 Mdot
.762 .27207 Mdot
.762 .27229 Mdot
.762 .27236 Mdot
.762 .27263 Mdot
.762 .27263 Mdot
.762 .27285 Mdot
.762 .27293 Mdot
.762 .27329 Mdot
.762 .27369 Mdot
.762 .27373 Mdot
.762 .27376 Mdot
.762 .27376 Mdot
.762 .27376 Mdot
.762 .2738 Mdot
.762 .27393 Mdot
.762 .27397 Mdot
.762 .27401 Mdot
.762 .27405 Mdot
.762 .27406 Mdot
.762 .27411 Mdot
.762 .27411 Mdot
.762 .27412 Mdot
.762 .27432 Mdot
.762 .27433 Mdot
.762 .27443 Mdot
.762 .27444 Mdot
.762 .27445 Mdot
.762 .27446 Mdot
.762 .27448 Mdot
.762 .27449 Mdot
.762 .27456 Mdot
.762 .27461 Mdot
.762 .27464 Mdot
.762 .27464 Mdot
.762 .27468 Mdot
.762 .27502 Mdot
.762 .2751 Mdot
.762 .27515 Mdot
.762 .27515 Mdot
.762 .27516 Mdot
.762 .27518 Mdot
.762 .27519 Mdot
.762 .27519 Mdot
.762 .27519 Mdot
.762 .2752 Mdot
.762 .27742 Mdot
.762 .27742 Mdot
.762 .27742 Mdot
.762 .27742 Mdot
.762 .27743 Mdot
.762 .27744 Mdot
.762 .27744 Mdot
.762 .27744 Mdot
.762 .27747 Mdot
.762 .2775 Mdot
.762 .27767 Mdot
.762 .27769 Mdot
.762 .27769 Mdot
.762 .27771 Mdot
.762 .27773 Mdot
.762 .27777 Mdot
.762 .27777 Mdot
.762 .27778 Mdot
.762 .27779 Mdot
.762 .27779 Mdot
.762 .2778 Mdot
.762 .27785 Mdot
.762 .27785 Mdot
.762 .27796 Mdot
.762 .27797 Mdot
.762 .27799 Mdot
.762 .27799 Mdot
.762 .27802 Mdot
.762 .27804 Mdot
.762 .27806 Mdot
.762 .27813 Mdot
.762 .27815 Mdot
.762 .27815 Mdot
.762 .27816 Mdot
.762 .27817 Mdot
.762 .27819 Mdot
.762 .27842 Mdot
.762 .27864 Mdot
.762 .27869 Mdot
.762 .27883 Mdot
.762 .27883 Mdot
.762 .27901 Mdot
.762 .27906 Mdot
.762 .27922 Mdot
.762 .27999 Mdot
.762 .28011 Mdot
.762 .28011 Mdot
.762 .2804 Mdot
.762 .28051 Mdot
.762 .28064 Mdot
.762 .28066 Mdot
.762 .28067 Mdot
.762 .28067 Mdot
.762 .28067 Mdot
.762 .28069 Mdot
.762 .28073 Mdot
.762 .28074 Mdot
.762 .28077 Mdot
.762 .28078 Mdot
.762 .28092 Mdot
.762 .28111 Mdot
.762 .28112 Mdot
.762 .28113 Mdot
.762 .28118 Mdot
.762 .28118 Mdot
.762 .28119 Mdot
.762 .2812 Mdot
.762 .2812 Mdot
.762 .28134 Mdot
.762 .28137 Mdot
.762 .28142 Mdot
.762 .28156 Mdot
.762 .28156 Mdot
.762 .2816 Mdot
.762 .28198 Mdot
.762 .28201 Mdot
.762 .28209 Mdot
.762 .2821 Mdot
.762 .28217 Mdot
.762 .28231 Mdot
.762 .28245 Mdot
.762 .28247 Mdot
.762 .28248 Mdot
.762 .28249 Mdot
.762 .28254 Mdot
.762 .28256 Mdot
.762 .28257 Mdot
.762 .28259 Mdot
.762 .28259 Mdot
.762 .28261 Mdot
.762 .2827 Mdot
.762 .28277 Mdot
.762 .28278 Mdot
.762 .28278 Mdot
.762 .28281 Mdot
.762 .28286 Mdot
.762 .28286 Mdot
.762 .28288 Mdot
.762 .28329 Mdot
.762 .28335 Mdot
.762 .28338 Mdot
.762 .28339 Mdot
.762 .28348 Mdot
.762 .28351 Mdot
.762 .28359 Mdot
.762 .28362 Mdot
.762 .2837 Mdot
.762 .28378 Mdot
.762 .28406 Mdot
.762 .28414 Mdot
.762 .28415 Mdot
.762 .28415 Mdot
.762 .2842 Mdot
.762 .28429 Mdot
.762 .28443 Mdot
.762 .28444 Mdot
.762 .28473 Mdot
.762 .28501 Mdot
.762 .2855 Mdot
.762 .28559 Mdot
.762 .28578 Mdot
.762 .28578 Mdot
.762 .28591 Mdot
.762 .28591 Mdot
.762 .28593 Mdot
.762 .43695 Mdot
.762 .43696 Mdot
.762 .43696 Mdot
.762 .43701 Mdot
.762 .43701 Mdot
.762 .43709 Mdot
.762 .43712 Mdot
.762 .43732 Mdot
.762 .43744 Mdot
.762 .43756 Mdot
.762 .43756 Mdot
.762 .43762 Mdot
.762 .43766 Mdot
.762 .43768 Mdot
.762 .43768 Mdot
.762 .43768 Mdot
.762 .43771 Mdot
.762 .43783 Mdot
.762 .43787 Mdot
.762 .4379 Mdot
.762 .43791 Mdot
.762 .43795 Mdot
.762 .43796 Mdot
.762 .438 Mdot
.762 .438 Mdot
.762 .43801 Mdot
.762 .43804 Mdot
.762 .43821 Mdot
.762 .43822 Mdot
.762 .43822 Mdot
.762 .43824 Mdot
.762 .43826 Mdot
.762 .43826 Mdot
.762 .43826 Mdot
.762 .43829 Mdot
.762 .43833 Mdot
.762 .43834 Mdot
.762 .43834 Mdot
.762 .43835 Mdot
.762 .43835 Mdot
.762 .43836 Mdot
.762 .43838 Mdot
.762 .43839 Mdot
.762 .43839 Mdot
.762 .4384 Mdot
.762 .43846 Mdot
.762 .43852 Mdot
.762 .43855 Mdot
.762 .43856 Mdot
.762 .43859 Mdot
.762 .4386 Mdot
.762 .43877 Mdot
.762 .43879 Mdot
.762 .43879 Mdot
.762 .43886 Mdot
.762 .43888 Mdot
.762 .43889 Mdot
.762 .43895 Mdot
.762 .43895 Mdot
.762 .43896 Mdot
.762 .43896 Mdot
.762 .43896 Mdot
.762 .43898 Mdot
.762 .43899 Mdot
.762 .43899 Mdot
.762 .43908 Mdot
.762 .43914 Mdot
.762 .43915 Mdot
.762 .43916 Mdot
.762 .43916 Mdot
.762 .43918 Mdot
.762 .43919 Mdot
.762 .43919 Mdot
.762 .43919 Mdot
.762 .4392 Mdot
.762 .4392 Mdot
.762 .43927 Mdot
.762 .43931 Mdot
.762 .43945 Mdot
.762 .43945 Mdot
.762 .4395 Mdot
.762 .43987 Mdot
.762 .43994 Mdot
.762 .43997 Mdot
.762 .44005 Mdot
.762 .44005 Mdot
.762 .44012 Mdot
.762 .44015 Mdot
.762 .44025 Mdot
.762 .44036 Mdot
.762 .44038 Mdot
.762 .44038 Mdot
.762 .44038 Mdot
.762 .44038 Mdot
.762 .4404 Mdot
.762 .44043 Mdot
.762 .44044 Mdot
.762 .44045 Mdot
.762 .44046 Mdot
.762 .44047 Mdot
.762 .44048 Mdot
.762 .44048 Mdot
.762 .44053 Mdot
.762 .44054 Mdot
.762 .44056 Mdot
.762 .44056 Mdot
.762 .44057 Mdot
.762 .44057 Mdot
.762 .44057 Mdot
.762 .44058 Mdot
.762 .44059 Mdot
.762 .44061 Mdot
.762 .44061 Mdot
.762 .44061 Mdot
.762 .44063 Mdot
.762 .44071 Mdot
.762 .44073 Mdot
.762 .44074 Mdot
.762 .44074 Mdot
.762 .44074 Mdot
.762 .44075 Mdot
.762 .44075 Mdot
.762 .44075 Mdot
.762 .44075 Mdot
.762 .44075 Mdot
.762 .44193 Mdot
.762 .44193 Mdot
.762 .44193 Mdot
.762 .44193 Mdot
.762 .44194 Mdot
.762 .44195 Mdot
.762 .44195 Mdot
.762 .44195 Mdot
.762 .44198 Mdot
.762 .44203 Mdot
.762 .44222 Mdot
.762 .44224 Mdot
.762 .44224 Mdot
.762 .44226 Mdot
.762 .44229 Mdot
.762 .44233 Mdot
.762 .44233 Mdot
.762 .44234 Mdot
.762 .44235 Mdot
.762 .44236 Mdot
.762 .44236 Mdot
.762 .44242 Mdot
.762 .44242 Mdot
.762 .44254 Mdot
.762 .44255 Mdot
.762 .44255 Mdot
.762 .44257 Mdot
.762 .44258 Mdot
.762 .44261 Mdot
.762 .44263 Mdot
.762 .44265 Mdot
.762 .44273 Mdot
.762 .44275 Mdot
.762 .44275 Mdot
.762 .44275 Mdot
.762 .44277 Mdot
.762 .4428 Mdot
.762 .44304 Mdot
.762 .44325 Mdot
.762 .4433 Mdot
.762 .44344 Mdot
.762 .44344 Mdot
.762 .44361 Mdot
.762 .44366 Mdot
.762 .4438 Mdot
.762 .44443 Mdot
.762 .44451 Mdot
.762 .44451 Mdot
.762 .44472 Mdot
.762 .44478 Mdot
.762 .44487 Mdot
.762 .44487 Mdot
.762 .44488 Mdot
.762 .44488 Mdot
.762 .44488 Mdot
.762 .4449 Mdot
.762 .44492 Mdot
.762 .44492 Mdot
.762 .44494 Mdot
.762 .44494 Mdot
.762 .44502 Mdot
.762 .44509 Mdot
.762 .4451 Mdot
.762 .4451 Mdot
.762 .44512 Mdot
.762 .44513 Mdot
.762 .44513 Mdot
.762 .44515 Mdot
.762 .44516 Mdot
.762 .44516 Mdot
.762 .44516 Mdot
.762 .44516 Mdot
.762 .44517 Mdot
.762 .44517 Mdot
.762 .44523 Mdot
.762 .44524 Mdot
.762 .44524 Mdot
.762 .44526 Mdot
.762 .44528 Mdot
.762 .44532 Mdot
.762 .44532 Mdot
.762 .44534 Mdot
.762 .44545 Mdot
.762 .44548 Mdot
.762 .44548 Mdot
.762 .44551 Mdot
.762 .44551 Mdot
.762 .44553 Mdot
.762 .44554 Mdot
.762 .44557 Mdot
.762 .4456 Mdot
.762 .4456 Mdot
.762 .4456 Mdot
.762 .4456 Mdot
.762 .4456 Mdot
.762 .44561 Mdot
.762 .44562 Mdot
.762 .44562 Mdot
.762 .44562 Mdot
.762 .44562 Mdot
.762 .44563 Mdot
.762 .44563 Mdot
.762 .44563 Mdot
.762 .44564 Mdot
.762 .44564 Mdot
.762 .44565 Mdot
.762 .44565 Mdot
.762 .44565 Mdot
.762 .44565 Mdot
.762 .44565 Mdot
.762 .44566 Mdot
.762 .44566 Mdot
.762 .44566 Mdot
.762 .44567 Mdot
.762 .44567 Mdot
.762 .44567 Mdot
.762 .44569 Mdot
.762 .4457 Mdot
.762 .4457 Mdot
.762 .4457 Mdot
.762 .4457 Mdot
.762 .4457 Mdot
.762 .4457 Mdot
.762 .4457 Mdot
.762 .4457 Mdot
.762 .4457 Mdot
.762 .45028 Mdot
.762 .45028 Mdot
.762 .45028 Mdot
.762 .45028 Mdot
.762 .45028 Mdot
.762 .45029 Mdot
.762 .45029 Mdot
.762 .45029 Mdot
.762 .4503 Mdot
.762 .45031 Mdot
.762 .45036 Mdot
.762 .45037 Mdot
.762 .45037 Mdot
.762 .45037 Mdot
.762 .45038 Mdot
.762 .45039 Mdot
.762 .4504 Mdot
.762 .4504 Mdot
.762 .4504 Mdot
.762 .4504 Mdot
.762 .4504 Mdot
.762 .45042 Mdot
.762 .45042 Mdot
.762 .45046 Mdot
.762 .45046 Mdot
.762 .45047 Mdot
.762 .45047 Mdot
.762 .45048 Mdot
.762 .45049 Mdot
.762 .45049 Mdot
.762 .45052 Mdot
.762 .45052 Mdot
.762 .45052 Mdot
.762 .45052 Mdot
.762 .45053 Mdot
.762 .45054 Mdot
.762 .45061 Mdot
.762 .45069 Mdot
.762 .4507 Mdot
.762 .45075 Mdot
.762 .45075 Mdot
.762 .45081 Mdot
.762 .45083 Mdot
.762 .45088 Mdot
.762 .45116 Mdot
.762 .4512 Mdot
.762 .4512 Mdot
.762 .45131 Mdot
.762 .45135 Mdot
.762 .4514 Mdot
.762 .45143 Mdot
.762 .45158 Mdot
.762 .45159 Mdot
.762 .4516 Mdot
.762 .4516 Mdot
.762 .45161 Mdot
.762 .45161 Mdot
.762 .45161 Mdot
.762 .45167 Mdot
.762 .45168 Mdot
.762 .4517 Mdot
.762 .45176 Mdot
.762 .45176 Mdot
.762 .45177 Mdot
.762 .45194 Mdot
.762 .45213 Mdot
.762 .45214 Mdot
.762 .45218 Mdot
.762 .4522 Mdot
.762 .45225 Mdot
.762 .45228 Mdot
.762 .45228 Mdot
.762 .45228 Mdot
.762 .4523 Mdot
.762 .45232 Mdot
.762 .45253 Mdot
.762 .45268 Mdot
.762 .45318 Mdot
.762 .45318 Mdot
.762 .45338 Mdot
.762 .45489 Mdot
.762 .45522 Mdot
.762 .45533 Mdot
.762 .45573 Mdot
.762 .45573 Mdot
.762 .45605 Mdot
.762 .45616 Mdot
.762 .45665 Mdot
.762 .45719 Mdot
.762 .45725 Mdot
.762 .45728 Mdot
.762 .45728 Mdot
.762 .45729 Mdot
.762 .45734 Mdot
.762 .45751 Mdot
.762 .45756 Mdot
.762 .4576 Mdot
.762 .45766 Mdot
.762 .45768 Mdot
.762 .45773 Mdot
.762 .45773 Mdot
.762 .45775 Mdot
.762 .458 Mdot
.762 .45801 Mdot
.762 .45813 Mdot
.762 .45814 Mdot
.762 .45815 Mdot
.762 .45817 Mdot
.762 .45819 Mdot
.762 .4582 Mdot
.762 .45828 Mdot
.762 .45834 Mdot
.762 .45838 Mdot
.762 .45838 Mdot
.762 .45843 Mdot
.762 .45882 Mdot
.762 .4589 Mdot
.762 .45896 Mdot
.762 .45896 Mdot
.762 .45897 Mdot
.762 .45899 Mdot
.762 .459 Mdot
.762 .459 Mdot
.762 .459 Mdot
.762 .45901 Mdot
.762 .46109 Mdot
.762 .46109 Mdot
.762 .46109 Mdot
.762 .46109 Mdot
.762 .4611 Mdot
.762 .4611 Mdot
.762 .46111 Mdot
.762 .46111 Mdot
.762 .46113 Mdot
.762 .46115 Mdot
.762 .46128 Mdot
.762 .4613 Mdot
.762 .4613 Mdot
.762 .46131 Mdot
.762 .46133 Mdot
.762 .46135 Mdot
.762 .46135 Mdot
.762 .46136 Mdot
.762 .46137 Mdot
.762 .46137 Mdot
.762 .46137 Mdot
.762 .46141 Mdot
.762 .46141 Mdot
.762 .46149 Mdot
.762 .46149 Mdot
.762 .46151 Mdot
.762 .46151 Mdot
.762 .46153 Mdot
.762 .46155 Mdot
.762 .46156 Mdot
.762 .46161 Mdot
.762 .46162 Mdot
.762 .46163 Mdot
.762 .46163 Mdot
.762 .46163 Mdot
.762 .46165 Mdot
.762 .4618 Mdot
.762 .46194 Mdot
.762 .46197 Mdot
.762 .46205 Mdot
.762 .46205 Mdot
.762 .46216 Mdot
.762 .46219 Mdot
.762 .46227 Mdot
.762 .46265 Mdot
.762 .46269 Mdot
.762 .46269 Mdot
.762 .46281 Mdot
.762 .46285 Mdot
.762 .4629 Mdot
.762 .4629 Mdot
.762 .46291 Mdot
.762 .46291 Mdot
.762 .46291 Mdot
.762 .46292 Mdot
.762 .46293 Mdot
.762 .46293 Mdot
.762 .46294 Mdot
.762 .46294 Mdot
.762 .46299 Mdot
.762 .46303 Mdot
.762 .46303 Mdot
.762 .46303 Mdot
.762 .46305 Mdot
.762 .46305 Mdot
.762 .46305 Mdot
.762 .46307 Mdot
.762 .46307 Mdot
.762 .46307 Mdot
.762 .46307 Mdot
.762 .46307 Mdot
.762 .46307 Mdot
.762 .46307 Mdot
.762 .46311 Mdot
.762 .46312 Mdot
.762 .46312 Mdot
.762 .46313 Mdot
.762 .46314 Mdot
.762 .46316 Mdot
.762 .46316 Mdot
.762 .46317 Mdot
.762 .46324 Mdot
.762 .46325 Mdot
.762 .46325 Mdot
.762 .46327 Mdot
.762 .46327 Mdot
.762 .46328 Mdot
.762 .46328 Mdot
.762 .4633 Mdot
.762 .46332 Mdot
.762 .46332 Mdot
.762 .46332 Mdot
.762 .46332 Mdot
.762 .46332 Mdot
.762 .46332 Mdot
.762 .46333 Mdot
.762 .46333 Mdot
.762 .46333 Mdot
.762 .46334 Mdot
.762 .46334 Mdot
.762 .46334 Mdot
.762 .46334 Mdot
.762 .46335 Mdot
.762 .46335 Mdot
.762 .46335 Mdot
.762 .46335 Mdot
.762 .46335 Mdot
.762 .46335 Mdot
.762 .46335 Mdot
.762 .46335 Mdot
.762 .46336 Mdot
.762 .46336 Mdot
.762 .46336 Mdot
.762 .46336 Mdot
.762 .46336 Mdot
.762 .46337 Mdot
.762 .46338 Mdot
.762 .46338 Mdot
.762 .46338 Mdot
.762 .46338 Mdot
.762 .46338 Mdot
.762 .46338 Mdot
.762 .46338 Mdot
.762 .46338 Mdot
.762 .46338 Mdot
.764 .26434 Mdot
.764 .26434 Mdot
.764 .26434 Mdot
.764 .26434 Mdot
.764 .26434 Mdot
.764 .26434 Mdot
.764 .26435 Mdot
.764 .26435 Mdot
.764 .26435 Mdot
.764 .26435 Mdot
.764 .26436 Mdot
.764 .26437 Mdot
.764 .26437 Mdot
.764 .26437 Mdot
.764 .26437 Mdot
.764 .26438 Mdot
.764 .26439 Mdot
.764 .2644 Mdot
.764 .2644 Mdot
.764 .26442 Mdot
.764 .26444 Mdot
.764 .26449 Mdot
.764 .26451 Mdot
.764 .26452 Mdot
.764 .26454 Mdot
.764 .26454 Mdot
.764 .26455 Mdot
.764 .26457 Mdot
.764 .26457 Mdot
.764 .26457 Mdot
.764 .26458 Mdot
.764 .26458 Mdot
.764 .26458 Mdot
.764 .26458 Mdot
.764 .26459 Mdot
.764 .26461 Mdot
.764 .26461 Mdot
.764 .26461 Mdot
.764 .26462 Mdot
.764 .26462 Mdot
.764 .26463 Mdot
.764 .26465 Mdot
.764 .26465 Mdot
.764 .26466 Mdot
.764 .26467 Mdot
.764 .26467 Mdot
.764 .26469 Mdot
.764 .2647 Mdot
.764 .26471 Mdot
.764 .26472 Mdot
.764 .26472 Mdot
.764 .26472 Mdot
.764 .26474 Mdot
.764 .26477 Mdot
.764 .26478 Mdot
.764 .26479 Mdot
.764 .26481 Mdot
.764 .26481 Mdot
.764 .26482 Mdot
.764 .26484 Mdot
.764 .26488 Mdot
.764 .2649 Mdot
.764 .26491 Mdot
.764 .26491 Mdot
.764 .26493 Mdot
.764 .26496 Mdot
.764 .26496 Mdot
.764 .26497 Mdot
.764 .26498 Mdot
.764 .26499 Mdot
.764 .26499 Mdot
.764 .26508 Mdot
.764 .2651 Mdot
.764 .2651 Mdot
.764 .26512 Mdot
.764 .26512 Mdot
.764 .26512 Mdot
.764 .26517 Mdot
.764 .26519 Mdot
.764 .26523 Mdot
.764 .26526 Mdot
.764 .26529 Mdot
.764 .26532 Mdot
.764 .26535 Mdot
.764 .26539 Mdot
.764 .2654 Mdot
.764 .26542 Mdot
.764 .26543 Mdot
.764 .26544 Mdot
.764 .26546 Mdot
.764 .26547 Mdot
.764 .26553 Mdot
.764 .26554 Mdot
.764 .26556 Mdot
.764 .26558 Mdot
.764 .26559 Mdot
.764 .26559 Mdot
.764 .26565 Mdot
.764 .26574 Mdot
.764 .26576 Mdot
.764 .2658 Mdot
.764 .26581 Mdot
.764 .26587 Mdot
.764 .2659 Mdot
.764 .26592 Mdot
.764 .26596 Mdot
.764 .26606 Mdot
.764 .26608 Mdot
.764 .26609 Mdot
.764 .26612 Mdot
.764 .26613 Mdot
.764 .26614 Mdot
.764 .26619 Mdot
.764 .26619 Mdot
.764 .26626 Mdot
.764 .26627 Mdot
.764 .26627 Mdot
.764 .2663 Mdot
.764 .26632 Mdot
.764 .26632 Mdot
.764 .26634 Mdot
.764 .26636 Mdot
.764 .26637 Mdot
.764 .2664 Mdot
.764 .2664 Mdot
.764 .2664 Mdot
.764 .26644 Mdot
.764 .26651 Mdot
.764 .26657 Mdot
.764 .26659 Mdot
.764 .26661 Mdot
.764 .26661 Mdot
.764 .26664 Mdot
.764 .26664 Mdot
.764 .26664 Mdot
.764 .26664 Mdot
.764 .26664 Mdot
.764 .26664 Mdot
.764 .26665 Mdot
.764 .26666 Mdot
.764 .26666 Mdot
.764 .26667 Mdot
.764 .26667 Mdot
.764 .26668 Mdot
.764 .26669 Mdot
.764 .26669 Mdot
.764 .2667 Mdot
.764 .2667 Mdot
.764 .2667 Mdot
.764 .26671 Mdot
.764 .26673 Mdot
.764 .26673 Mdot
.764 .26673 Mdot
.764 .26675 Mdot
.764 .26677 Mdot
.764 .26678 Mdot
.764 .26679 Mdot
.764 .26679 Mdot
.764 .2668 Mdot
.764 .26682 Mdot
.764 .26683 Mdot
.764 .26684 Mdot
.764 .26684 Mdot
.764 .26685 Mdot
.764 .26686 Mdot
.764 .26687 Mdot
.764 .26687 Mdot
.764 .26688 Mdot
.764 .26688 Mdot
.764 .26692 Mdot
.764 .26693 Mdot
.764 .26693 Mdot
.764 .26699 Mdot
.764 .26701 Mdot
.764 .26705 Mdot
.764 .26705 Mdot
.764 .26706 Mdot
.764 .2671 Mdot
.764 .26711 Mdot
.764 .26711 Mdot
.764 .26711 Mdot
.764 .26717 Mdot
.764 .26719 Mdot
.764 .26721 Mdot
.764 .26722 Mdot
.764 .26727 Mdot
.764 .26727 Mdot
.764 .26728 Mdot
.764 .26729 Mdot
.764 .2673 Mdot
.764 .2673 Mdot
.764 .26734 Mdot
.764 .26735 Mdot
.764 .26735 Mdot
.764 .26736 Mdot
.764 .26736 Mdot
.764 .26736 Mdot
.764 .26737 Mdot
.764 .26739 Mdot
.764 .26741 Mdot
.764 .26742 Mdot
.764 .26744 Mdot
.764 .26744 Mdot
.764 .26745 Mdot
.764 .26747 Mdot
.764 .26747 Mdot
.764 .26748 Mdot
.764 .26749 Mdot
.764 .26749 Mdot
.764 .26749 Mdot
.764 .26749 Mdot
.764 .2675 Mdot
.764 .26752 Mdot
.764 .26753 Mdot
.764 .26754 Mdot
.764 .26755 Mdot
.764 .26759 Mdot
.764 .26759 Mdot
.764 .26759 Mdot
.764 .2676 Mdot
.764 .2676 Mdot
.764 .26761 Mdot
.764 .26761 Mdot
.764 .26762 Mdot
.764 .26763 Mdot
.764 .26763 Mdot
.764 .26764 Mdot
.764 .26764 Mdot
.764 .26765 Mdot
.764 .26765 Mdot
.764 .26767 Mdot
.764 .26768 Mdot
.764 .26769 Mdot
.764 .26769 Mdot
.764 .2677 Mdot
.764 .26771 Mdot
.764 .26771 Mdot
.764 .26772 Mdot
.764 .26772 Mdot
.764 .26773 Mdot
.764 .26773 Mdot
.764 .26773 Mdot
.764 .26776 Mdot
.764 .26777 Mdot
.764 .26778 Mdot
.764 .26778 Mdot
.764 .26779 Mdot
.764 .26779 Mdot
.764 .26779 Mdot
.764 .2678 Mdot
.764 .26781 Mdot
.764 .26782 Mdot
.764 .26784 Mdot
.764 .26785 Mdot
.764 .26786 Mdot
.764 .26786 Mdot
.764 .26788 Mdot
.764 .26789 Mdot
.764 .26789 Mdot
.764 .26789 Mdot
.764 .26789 Mdot
.764 .26792 Mdot
.764 .26798 Mdot
.764 .26801 Mdot
.764 .26801 Mdot
.764 .26803 Mdot
.764 .26804 Mdot
.764 .26808 Mdot
.764 .26809 Mdot
.764 .26811 Mdot
.764 .26811 Mdot
.764 .26811 Mdot
.764 .26812 Mdot
.764 .26813 Mdot
.764 .26813 Mdot
.764 .26814 Mdot
.764 .26815 Mdot
.764 .26816 Mdot
.764 .26816 Mdot
.764 .26817 Mdot
.764 .26819 Mdot
.764 .26819 Mdot
.764 .26819 Mdot
.764 .2682 Mdot
.764 .26821 Mdot
.764 .26821 Mdot
.764 .26821 Mdot
.764 .26822 Mdot
.764 .26823 Mdot
.764 .26823 Mdot
.764 .26823 Mdot
.764 .26824 Mdot
.764 .26824 Mdot
.764 .26825 Mdot
.764 .26825 Mdot
.764 .26825 Mdot
.764 .26825 Mdot
.764 .26825 Mdot
.764 .26828 Mdot
.764 .26829 Mdot
.764 .26833 Mdot
.764 .26838 Mdot
.764 .2684 Mdot
.764 .2684 Mdot
.764 .2684 Mdot
.764 .26843 Mdot
.764 .26844 Mdot
.764 .26845 Mdot
.764 .26854 Mdot
.764 .26854 Mdot
.764 .26858 Mdot
.764 .26859 Mdot
.764 .26861 Mdot
.764 .26862 Mdot
.764 .26874 Mdot
.764 .26876 Mdot
.764 .26882 Mdot
.764 .26887 Mdot
.764 .26901 Mdot
.764 .26901 Mdot
.764 .26902 Mdot
.764 .26905 Mdot
.764 .26915 Mdot
.764 .26916 Mdot
.764 .26919 Mdot
.764 .26927 Mdot
.764 .26932 Mdot
.764 .26948 Mdot
.764 .26949 Mdot
.764 .26953 Mdot
.764 .26964 Mdot
.764 .26964 Mdot
.764 .26966 Mdot
.764 .26967 Mdot
.764 .26968 Mdot
.764 .26972 Mdot
.764 .26974 Mdot
.764 .26975 Mdot
.764 .26976 Mdot
.764 .2698 Mdot
.764 .26986 Mdot
.764 .26989 Mdot
.764 .26989 Mdot
.764 .26993 Mdot
.764 .26995 Mdot
.764 .27001 Mdot
.764 .27005 Mdot
.764 .27005 Mdot
.764 .27007 Mdot
.764 .2701 Mdot
.764 .27013 Mdot
.764 .27014 Mdot
.764 .27015 Mdot
.764 .27017 Mdot
.764 .27018 Mdot
.764 .27022 Mdot
.764 .27023 Mdot
.764 .27023 Mdot
.764 .27025 Mdot
.764 .27026 Mdot
.764 .2703 Mdot
.764 .27031 Mdot
.764 .27032 Mdot
.764 .27032 Mdot
.764 .27034 Mdot
.764 .27034 Mdot
.764 .27034 Mdot
.764 .27041 Mdot
.764 .27041 Mdot
.764 .27046 Mdot
.764 .27054 Mdot
.764 .27072 Mdot
.764 .27094 Mdot
.764 .27106 Mdot
.764 .27106 Mdot
.764 .27107 Mdot
.764 .27116 Mdot
.764 .27122 Mdot
.764 .27126 Mdot
.764 .27132 Mdot
.764 .27135 Mdot
.764 .27139 Mdot
.764 .2715 Mdot
.764 .2715 Mdot
.764 .27152 Mdot
.764 .27176 Mdot
.764 .27177 Mdot
.764 .27196 Mdot
.764 .27198 Mdot
.764 .272 Mdot
.764 .27212 Mdot
.764 .27214 Mdot
.764 .27223 Mdot
.764 .27259 Mdot
.764 .27274 Mdot
.764 .27283 Mdot
.764 .27292 Mdot
.764 .27315 Mdot
.764 .2732 Mdot
.764 .27336 Mdot
.764 .27343 Mdot
.764 .27379 Mdot
.764 .27403 Mdot
.764 .27404 Mdot
.764 .27406 Mdot
.764 .27416 Mdot
.764 .27421 Mdot
.764 .27428 Mdot
.764 .2744 Mdot
.764 .27451 Mdot
.764 .27457 Mdot
.764 .27465 Mdot
.764 .2747 Mdot
.764 .27473 Mdot
.764 .27482 Mdot
.764 .27487 Mdot
.764 .27503 Mdot
.764 .27519 Mdot
.764 .27529 Mdot
.764 .27542 Mdot
.764 .27556 Mdot
.764 .27573 Mdot
.764 .27586 Mdot
.764 .27608 Mdot
.764 .27608 Mdot
.764 .27609 Mdot
.764 .27614 Mdot
.764 .27616 Mdot
.764 .27626 Mdot
.764 .27667 Mdot
.764 .27667 Mdot
.764 .27672 Mdot
.764 .27676 Mdot
.764 .2768 Mdot
.764 .27682 Mdot
.764 .27695 Mdot
.764 .27705 Mdot
.764 .27706 Mdot
.764 .2771 Mdot
.764 .27723 Mdot
.764 .27743 Mdot
.764 .27752 Mdot
.764 .27754 Mdot
.764 .27755 Mdot
.764 .27765 Mdot
.764 .27769 Mdot
.764 .27774 Mdot
.764 .2779 Mdot
.764 .27802 Mdot
.764 .27802 Mdot
.764 .27802 Mdot
.764 .27808 Mdot
.764 .27812 Mdot
.764 .27818 Mdot
.764 .27826 Mdot
.764 .27827 Mdot
.764 .27829 Mdot
.764 .27836 Mdot
.764 .27838 Mdot
.764 .27848 Mdot
.764 .2785 Mdot
.764 .2785 Mdot
.764 .27856 Mdot
.764 .27857 Mdot
.764 .27859 Mdot
.764 .27867 Mdot
.764 .27871 Mdot
.764 .27872 Mdot
.764 .27872 Mdot
.764 .27874 Mdot
.764 .27877 Mdot
.764 .27877 Mdot
.764 .27877 Mdot
.764 .27888 Mdot
.764 .27893 Mdot
.764 .27893 Mdot
.764 .27904 Mdot
.764 .27911 Mdot
.764 .27919 Mdot
.764 .27949 Mdot
.764 .2796 Mdot
.764 .27969 Mdot
.764 .27971 Mdot
.764 .27977 Mdot
.764 .27982 Mdot
.764 .27985 Mdot
.764 .27988 Mdot
.764 .27988 Mdot
.764 .27989 Mdot
.764 .27994 Mdot
.764 .27997 Mdot
.764 .27998 Mdot
.764 .27998 Mdot
.764 .28 Mdot
.764 .28002 Mdot
.764 .28003 Mdot
.764 .28003 Mdot
.764 .28004 Mdot
.764 .28004 Mdot
.764 .28004 Mdot
.764 .43981 Mdot
.764 .43981 Mdot
.764 .43981 Mdot
.764 .43981 Mdot
.764 .43981 Mdot
.764 .43982 Mdot
.764 .43983 Mdot
.764 .43984 Mdot
.764 .43984 Mdot
.764 .43984 Mdot
.764 .43985 Mdot
.764 .43988 Mdot
.764 .43989 Mdot
.764 .43989 Mdot
.764 .4399 Mdot
.764 .43991 Mdot
.764 .43994 Mdot
.764 .43996 Mdot
.764 .43997 Mdot
.764 .44002 Mdot
.764 .44007 Mdot
.764 .44022 Mdot
.764 .44025 Mdot
.764 .44029 Mdot
.764 .44034 Mdot
.764 .44035 Mdot
.764 .44037 Mdot
.764 .44042 Mdot
.764 .44042 Mdot
.764 .44042 Mdot
.764 .44044 Mdot
.764 .44044 Mdot
.764 .44045 Mdot
.764 .44045 Mdot
.764 .44047 Mdot
.764 .44051 Mdot
.764 .44052 Mdot
.764 .44053 Mdot
.764 .44055 Mdot
.764 .44056 Mdot
.764 .44057 Mdot
.764 .44061 Mdot
.764 .44063 Mdot
.764 .44066 Mdot
.764 .44067 Mdot
.764 .44068 Mdot
.764 .44072 Mdot
.764 .44075 Mdot
.764 .44077 Mdot
.764 .4408 Mdot
.764 .4408 Mdot
.764 .4408 Mdot
.764 .44086 Mdot
.764 .44094 Mdot
.764 .44097 Mdot
.764 .44098 Mdot
.764 .44104 Mdot
.764 .44104 Mdot
.764 .44105 Mdot
.764 .4411 Mdot
.764 .44121 Mdot
.764 .44127 Mdot
.764 .44129 Mdot
.764 .4413 Mdot
.764 .44135 Mdot
.764 .44142 Mdot
.764 .44143 Mdot
.764 .44145 Mdot
.764 .44147 Mdot
.764 .4415 Mdot
.764 .4415 Mdot
.764 .44172 Mdot
.764 .44177 Mdot
.764 .44178 Mdot
.764 .44182 Mdot
.764 .44182 Mdot
.764 .44182 Mdot
.764 .44194 Mdot
.764 .44201 Mdot
.764 .4421 Mdot
.764 .44219 Mdot
.764 .44226 Mdot
.764 .44232 Mdot
.764 .44241 Mdot
.764 .4425 Mdot
.764 .44253 Mdot
.764 .44258 Mdot
.764 .4426 Mdot
.764 .44263 Mdot
.764 .44267 Mdot
.764 .44271 Mdot
.764 .44278 Mdot
.764 .44285 Mdot
.764 .44289 Mdot
.764 .44292 Mdot
.764 .44298 Mdot
.764 .44299 Mdot
.764 .443 Mdot
.764 .44314 Mdot
.764 .44336 Mdot
.764 .44341 Mdot
.764 .44351 Mdot
.764 .44354 Mdot
.764 .44369 Mdot
.764 .44375 Mdot
.764 .44381 Mdot
.764 .4439 Mdot
.764 .44414 Mdot
.764 .4442 Mdot
.764 .44421 Mdot
.764 .4443 Mdot
.764 .44431 Mdot
.764 .44433 Mdot
.764 .44446 Mdot
.764 .44446 Mdot
.764 .44463 Mdot
.764 .44464 Mdot
.764 .44465 Mdot
.764 .44473 Mdot
.764 .44475 Mdot
.764 .44477 Mdot
.764 .44482 Mdot
.764 .44485 Mdot
.764 .44489 Mdot
.764 .44495 Mdot
.764 .44496 Mdot
.764 .44496 Mdot
.764 .44505 Mdot
.764 .44521 Mdot
.764 .44535 Mdot
.764 .44541 Mdot
.764 .44545 Mdot
.764 .44545 Mdot
.764 .4455 Mdot
.764 .4455 Mdot
.764 .44551 Mdot
.764 .44552 Mdot
.764 .44552 Mdot
.764 .44553 Mdot
.764 .44554 Mdot
.764 .44556 Mdot
.764 .44557 Mdot
.764 .44559 Mdot
.764 .44559 Mdot
.764 .4456 Mdot
.764 .44563 Mdot
.764 .44564 Mdot
.764 .44565 Mdot
.764 .44566 Mdot
.764 .44566 Mdot
.764 .44569 Mdot
.764 .44572 Mdot
.764 .44573 Mdot
.764 .44573 Mdot
.764 .44576 Mdot
.764 .44581 Mdot
.764 .44583 Mdot
.764 .44586 Mdot
.764 .44586 Mdot
.764 .44589 Mdot
.764 .44593 Mdot
.764 .44596 Mdot
.764 .44597 Mdot
.764 .44598 Mdot
.764 .446 Mdot
.764 .44603 Mdot
.764 .44603 Mdot
.764 .44604 Mdot
.764 .44606 Mdot
.764 .44606 Mdot
.764 .44615 Mdot
.764 .44619 Mdot
.764 .44619 Mdot
.764 .44633 Mdot
.764 .44637 Mdot
.764 .44645 Mdot
.764 .44647 Mdot
.764 .44648 Mdot
.764 .44656 Mdot
.764 .44659 Mdot
.764 .4466 Mdot
.764 .4466 Mdot
.764 .44673 Mdot
.764 .44677 Mdot
.764 .44683 Mdot
.764 .44684 Mdot
.764 .44695 Mdot
.764 .44696 Mdot
.764 .44698 Mdot
.764 .44699 Mdot
.764 .44702 Mdot
.764 .44703 Mdot
.764 .44711 Mdot
.764 .44712 Mdot
.764 .44713 Mdot
.764 .44716 Mdot
.764 .44716 Mdot
.764 .44716 Mdot
.764 .44718 Mdot
.764 .44722 Mdot
.764 .44726 Mdot
.764 .44727 Mdot
.764 .44734 Mdot
.764 .44734 Mdot
.764 .44734 Mdot
.764 .44739 Mdot
.764 .44739 Mdot
.764 .44741 Mdot
.764 .44743 Mdot
.764 .44743 Mdot
.764 .44744 Mdot
.764 .44744 Mdot
.764 .44747 Mdot
.764 .44751 Mdot
.764 .44754 Mdot
.764 .44754 Mdot
.764 .44757 Mdot
.764 .44765 Mdot
.764 .44765 Mdot
.764 .44766 Mdot
.764 .44767 Mdot
.764 .44769 Mdot
.764 .4477 Mdot
.764 .44771 Mdot
.764 .44773 Mdot
.764 .44776 Mdot
.764 .44776 Mdot
.764 .44776 Mdot
.764 .44777 Mdot
.764 .44779 Mdot
.764 .44779 Mdot
.764 .44783 Mdot
.764 .44786 Mdot
.764 .44787 Mdot
.764 .44789 Mdot
.764 .44791 Mdot
.764 .44792 Mdot
.764 .44792 Mdot
.764 .44794 Mdot
.764 .44795 Mdot
.764 .44797 Mdot
.764 .44797 Mdot
.764 .44797 Mdot
.764 .44803 Mdot
.764 .44804 Mdot
.764 .44808 Mdot
.764 .44808 Mdot
.764 .44809 Mdot
.764 .4481 Mdot
.764 .4481 Mdot
.764 .44812 Mdot
.764 .44813 Mdot
.764 .44817 Mdot
.764 .44821 Mdot
.764 .44823 Mdot
.764 .44824 Mdot
.764 .44824 Mdot
.764 .44828 Mdot
.764 .4483 Mdot
.764 .44831 Mdot
.764 .44832 Mdot
.764 .44832 Mdot
.764 .44838 Mdot
.764 .4485 Mdot
.764 .44856 Mdot
.764 .44857 Mdot
.764 .44862 Mdot
.764 .44864 Mdot
.764 .44871 Mdot
.764 .44873 Mdot
.764 .44878 Mdot
.764 .44878 Mdot
.764 .44879 Mdot
.764 .4488 Mdot
.764 .44881 Mdot
.764 .44883 Mdot
.764 .44885 Mdot
.764 .44887 Mdot
.764 .44889 Mdot
.764 .44889 Mdot
.764 .44891 Mdot
.764 .44894 Mdot
.764 .44896 Mdot
.764 .44896 Mdot
.764 .44896 Mdot
.764 .44898 Mdot
.764 .44899 Mdot
.764 .449 Mdot
.764 .44901 Mdot
.764 .44903 Mdot
.764 .44903 Mdot
.764 .44903 Mdot
.764 .44905 Mdot
.764 .44906 Mdot
.764 .44907 Mdot
.764 .44907 Mdot
.764 .44908 Mdot
.764 .44908 Mdot
.764 .44908 Mdot
.764 .44913 Mdot
.764 .44917 Mdot
.764 .44924 Mdot
.764 .44934 Mdot
.764 .44938 Mdot
.764 .44938 Mdot
.764 .44939 Mdot
.764 .44945 Mdot
.764 .44947 Mdot
.764 .44949 Mdot
.764 .44968 Mdot
.764 .44968 Mdot
.764 .44977 Mdot
.764 .44978 Mdot
.764 .44983 Mdot
.764 .44983 Mdot
.764 .45008 Mdot
.764 .45012 Mdot
.764 .45025 Mdot
.764 .45034 Mdot
.764 .45063 Mdot
.764 .45063 Mdot
.764 .45064 Mdot
.764 .45071 Mdot
.764 .4509 Mdot
.764 .45093 Mdot
.764 .45097 Mdot
.764 .45114 Mdot
.764 .45124 Mdot
.764 .45155 Mdot
.764 .45156 Mdot
.764 .45164 Mdot
.764 .45185 Mdot
.764 .45185 Mdot
.764 .45189 Mdot
.764 .45192 Mdot
.764 .45193 Mdot
.764 .452 Mdot
.764 .45205 Mdot
.764 .45206 Mdot
.764 .45208 Mdot
.764 .45215 Mdot
.764 .45226 Mdot
.764 .45233 Mdot
.764 .45233 Mdot
.764 .45239 Mdot
.764 .45244 Mdot
.764 .45254 Mdot
.764 .45261 Mdot
.764 .45261 Mdot
.764 .45265 Mdot
.764 .45272 Mdot
.764 .45277 Mdot
.764 .45278 Mdot
.764 .45279 Mdot
.764 .45284 Mdot
.764 .45286 Mdot
.764 .45292 Mdot
.764 .45294 Mdot
.764 .45294 Mdot
.764 .45299 Mdot
.764 .453 Mdot
.764 .45307 Mdot
.764 .45309 Mdot
.764 .4531 Mdot
.764 .45312 Mdot
.764 .45314 Mdot
.764 .45314 Mdot
.764 .45314 Mdot
.764 .45327 Mdot
.764 .45327 Mdot
.764 .45337 Mdot
.764 .4535 Mdot
.764 .45382 Mdot
.764 .45421 Mdot
.764 .4544 Mdot
.764 .4544 Mdot
.764 .45443 Mdot
.764 .45457 Mdot
.764 .45467 Mdot
.764 .45474 Mdot
.764 .45484 Mdot
.764 .45489 Mdot
.764 .45495 Mdot
.764 .45514 Mdot
.764 .45514 Mdot
.764 .45517 Mdot
.764 .45556 Mdot
.764 .45557 Mdot
.764 .45587 Mdot
.764 .4559 Mdot
.764 .45593 Mdot
.764 .45612 Mdot
.764 .45615 Mdot
.764 .45629 Mdot
.764 .45683 Mdot
.764 .45704 Mdot
.764 .45718 Mdot
.764 .4573 Mdot
.764 .45762 Mdot
.764 .45769 Mdot
.764 .45791 Mdot
.764 .45802 Mdot
.764 .45849 Mdot
.764 .4588 Mdot
.764 .45881 Mdot
.764 .45884 Mdot
.764 .45896 Mdot
.764 .45902 Mdot
.764 .45911 Mdot
.764 .45925 Mdot
.764 .45938 Mdot
.764 .45946 Mdot
.764 .45955 Mdot
.764 .45961 Mdot
.764 .45964 Mdot
.764 .45975 Mdot
.764 .45981 Mdot
.764 .45999 Mdot
.764 .46016 Mdot
.764 .46028 Mdot
.764 .46041 Mdot
.764 .46057 Mdot
.764 .46074 Mdot
.764 .46087 Mdot
.764 .46108 Mdot
.764 .46109 Mdot
.764 .46109 Mdot
.764 .46115 Mdot
.764 .46117 Mdot
.764 .46126 Mdot
.764 .46163 Mdot
.764 .46163 Mdot
.764 .46168 Mdot
.764 .46171 Mdot
.764 .46175 Mdot
.764 .46177 Mdot
.764 .46188 Mdot
.764 .46196 Mdot
.764 .46197 Mdot
.764 .46201 Mdot
.764 .46211 Mdot
.764 .46227 Mdot
.764 .46234 Mdot
.764 .46236 Mdot
.764 .46236 Mdot
.764 .46244 Mdot
.764 .46246 Mdot
.764 .4625 Mdot
.764 .46262 Mdot
.764 .4627 Mdot
.764 .4627 Mdot
.764 .4627 Mdot
.764 .46274 Mdot
.764 .46277 Mdot
.764 .46281 Mdot
.764 .46287 Mdot
.764 .46287 Mdot
.764 .46289 Mdot
.764 .46293 Mdot
.764 .46295 Mdot
.764 .46301 Mdot
.764 .46302 Mdot
.764 .46303 Mdot
.764 .46306 Mdot
.764 .46307 Mdot
.764 .46308 Mdot
.764 .46313 Mdot
.764 .46315 Mdot
.764 .46316 Mdot
.764 .46316 Mdot
.764 .46317 Mdot
.764 .46319 Mdot
.764 .46319 Mdot
.764 .46319 Mdot
.764 .46326 Mdot
.764 .46328 Mdot
.764 .46329 Mdot
.764 .46335 Mdot
.764 .46339 Mdot
.764 .46343 Mdot
.764 .46359 Mdot
.764 .46364 Mdot
.764 .46369 Mdot
.764 .46369 Mdot
.764 .46372 Mdot
.764 .46375 Mdot
.764 .46376 Mdot
.764 .46377 Mdot
.764 .46377 Mdot
.764 .46378 Mdot
.764 .4638 Mdot
.764 .46381 Mdot
.764 .46381 Mdot
.764 .46381 Mdot
.764 .46382 Mdot
.764 .46383 Mdot
.764 .46384 Mdot
.764 .46384 Mdot
.764 .46384 Mdot
.764 .46384 Mdot
.764 .46384 Mdot
.766 .26499 Mdot
.766 .26499 Mdot
.766 .26499 Mdot
.766 .26499 Mdot
.766 .26499 Mdot
.766 .26499 Mdot
.766 .26499 Mdot
.766 .26499 Mdot
.766 .26499 Mdot
.766 .26499 Mdot
.766 .265 Mdot
.766 .265 Mdot
.766 .265 Mdot
.766 .265 Mdot
.766 .265 Mdot
.766 .265 Mdot
.766 .265 Mdot
.766 .265 Mdot
.766 .265 Mdot
.766 .265 Mdot
.766 .26501 Mdot
.766 .26501 Mdot
.766 .26501 Mdot
.766 .26501 Mdot
.766 .26501 Mdot
.766 .26501 Mdot
.766 .26501 Mdot
.766 .26501 Mdot
.766 .26502 Mdot
.766 .26502 Mdot
.766 .26502 Mdot
.766 .26503 Mdot
.766 .26503 Mdot
.766 .26503 Mdot
.766 .26503 Mdot
.766 .26503 Mdot
.766 .26503 Mdot
.766 .26503 Mdot
.766 .26503 Mdot
.766 .26504 Mdot
.766 .26504 Mdot
.766 .26504 Mdot
.766 .26504 Mdot
.766 .26504 Mdot
.766 .26504 Mdot
.766 .26505 Mdot
.766 .26505 Mdot
.766 .26505 Mdot
.766 .26505 Mdot
.766 .26505 Mdot
.766 .26506 Mdot
.766 .26506 Mdot
.766 .26506 Mdot
.766 .26507 Mdot
.766 .26507 Mdot
.766 .26507 Mdot
.766 .26507 Mdot
.766 .26507 Mdot
.766 .26508 Mdot
.766 .26509 Mdot
.766 .26509 Mdot
.766 .2651 Mdot
.766 .26512 Mdot
.766 .26512 Mdot
.766 .26512 Mdot
.766 .26512 Mdot
.766 .26514 Mdot
.766 .26514 Mdot
.766 .26514 Mdot
.766 .26516 Mdot
.766 .26518 Mdot
.766 .26522 Mdot
.766 .26522 Mdot
.766 .26525 Mdot
.766 .26525 Mdot
.766 .26525 Mdot
.766 .26527 Mdot
.766 .26527 Mdot
.766 .26527 Mdot
.766 .2653 Mdot
.766 .2653 Mdot
.766 .26533 Mdot
.766 .26536 Mdot
.766 .26538 Mdot
.766 .26541 Mdot
.766 .26542 Mdot
.766 .26543 Mdot
.766 .26544 Mdot
.766 .26545 Mdot
.766 .2655 Mdot
.766 .2655 Mdot
.766 .26551 Mdot
.766 .26551 Mdot
.766 .26554 Mdot
.766 .26566 Mdot
.766 .26569 Mdot
.766 .26571 Mdot
.766 .26573 Mdot
.766 .26575 Mdot
.766 .26579 Mdot
.766 .26579 Mdot
.766 .26581 Mdot
.766 .26581 Mdot
.766 .26582 Mdot
.766 .26583 Mdot
.766 .26583 Mdot
.766 .26585 Mdot
.766 .26585 Mdot
.766 .2659 Mdot
.766 .2659 Mdot
.766 .26592 Mdot
.766 .26592 Mdot
.766 .26593 Mdot
.766 .26594 Mdot
.766 .26595 Mdot
.766 .26597 Mdot
.766 .26598 Mdot
.766 .26598 Mdot
.766 .26599 Mdot
.766 .266 Mdot
.766 .26601 Mdot
.766 .26601 Mdot
.766 .26602 Mdot
.766 .26603 Mdot
.766 .26603 Mdot
.766 .26603 Mdot
.766 .26605 Mdot
.766 .26607 Mdot
.766 .26608 Mdot
.766 .26608 Mdot
.766 .26609 Mdot
.766 .2661 Mdot
.766 .26611 Mdot
.766 .26612 Mdot
.766 .26613 Mdot
.766 .26614 Mdot
.766 .26615 Mdot
.766 .26615 Mdot
.766 .26617 Mdot
.766 .26621 Mdot
.766 .26623 Mdot
.766 .26624 Mdot
.766 .26625 Mdot
.766 .26626 Mdot
.766 .26626 Mdot
.766 .26626 Mdot
.766 .26627 Mdot
.766 .26627 Mdot
.766 .26627 Mdot
.766 .2663 Mdot
.766 .2663 Mdot
.766 .2663 Mdot
.766 .2663 Mdot
.766 .26632 Mdot
.766 .26633 Mdot
.766 .26633 Mdot
.766 .26633 Mdot
.766 .26633 Mdot
.766 .26633 Mdot
.766 .26634 Mdot
.766 .26637 Mdot
.766 .26638 Mdot
.766 .26638 Mdot
.766 .26638 Mdot
.766 .26638 Mdot
.766 .26639 Mdot
.766 .26639 Mdot
.766 .2664 Mdot
.766 .2664 Mdot
.766 .2664 Mdot
.766 .2664 Mdot
.766 .26641 Mdot
.766 .26641 Mdot
.766 .26641 Mdot
.766 .26643 Mdot
.766 .26644 Mdot
.766 .26644 Mdot
.766 .26651 Mdot
.766 .26651 Mdot
.766 .26664 Mdot
.766 .26668 Mdot
.766 .26674 Mdot
.766 .26675 Mdot
.766 .26676 Mdot
.766 .26679 Mdot
.766 .26679 Mdot
.766 .2668 Mdot
.766 .26681 Mdot
.766 .26688 Mdot
.766 .26689 Mdot
.766 .2669 Mdot
.766 .26692 Mdot
.766 .26694 Mdot
.766 .26695 Mdot
.766 .26695 Mdot
.766 .26696 Mdot
.766 .26696 Mdot
.766 .26699 Mdot
.766 .26699 Mdot
.766 .267 Mdot
.766 .267 Mdot
.766 .267 Mdot
.766 .26702 Mdot
.766 .26702 Mdot
.766 .26702 Mdot
.766 .26703 Mdot
.766 .26703 Mdot
.766 .26704 Mdot
.766 .26704 Mdot
.766 .26704 Mdot
.766 .26705 Mdot
.766 .26706 Mdot
.766 .26706 Mdot
.766 .26706 Mdot
.766 .26707 Mdot
.766 .26707 Mdot
.766 .26708 Mdot
.766 .26709 Mdot
.766 .26709 Mdot
.766 .26709 Mdot
.766 .2671 Mdot
.766 .26712 Mdot
.766 .26712 Mdot
.766 .26713 Mdot
.766 .26713 Mdot
.766 .26713 Mdot
.766 .26713 Mdot
.766 .26714 Mdot
.766 .26714 Mdot
.766 .26714 Mdot
.766 .26715 Mdot
.766 .26715 Mdot
.766 .26715 Mdot
.766 .26716 Mdot
.766 .26716 Mdot
.766 .26716 Mdot
.766 .26716 Mdot
.766 .26716 Mdot
.766 .26716 Mdot
.766 .26718 Mdot
.766 .26718 Mdot
.766 .26718 Mdot
.766 .26718 Mdot
.766 .26719 Mdot
.766 .26719 Mdot
.766 .26719 Mdot
.766 .26719 Mdot
.766 .26719 Mdot
.766 .26719 Mdot
.766 .26719 Mdot
.766 .26832 Mdot
.766 .26832 Mdot
.766 .26832 Mdot
.766 .26832 Mdot
.766 .26833 Mdot
.766 .26833 Mdot
.766 .26833 Mdot
.766 .26833 Mdot
.766 .26834 Mdot
.766 .26834 Mdot
.766 .26835 Mdot
.766 .26837 Mdot
.766 .26838 Mdot
.766 .26838 Mdot
.766 .26838 Mdot
.766 .26838 Mdot
.766 .26838 Mdot
.766 .2684 Mdot
.766 .2684 Mdot
.766 .2684 Mdot
.766 .26843 Mdot
.766 .26843 Mdot
.766 .26843 Mdot
.766 .26844 Mdot
.766 .26844 Mdot
.766 .26844 Mdot
.766 .26845 Mdot
.766 .26846 Mdot
.766 .26848 Mdot
.766 .26851 Mdot
.766 .26853 Mdot
.766 .26854 Mdot
.766 .26855 Mdot
.766 .26856 Mdot
.766 .26857 Mdot
.766 .26859 Mdot
.766 .26859 Mdot
.766 .2686 Mdot
.766 .26861 Mdot
.766 .26863 Mdot
.766 .26864 Mdot
.766 .26864 Mdot
.766 .26864 Mdot
.766 .26866 Mdot
.766 .26867 Mdot
.766 .26869 Mdot
.766 .26869 Mdot
.766 .2687 Mdot
.766 .26874 Mdot
.766 .26875 Mdot
.766 .26875 Mdot
.766 .26877 Mdot
.766 .26877 Mdot
.766 .26882 Mdot
.766 .26882 Mdot
.766 .26885 Mdot
.766 .26885 Mdot
.766 .26888 Mdot
.766 .26893 Mdot
.766 .26897 Mdot
.766 .269 Mdot
.766 .26903 Mdot
.766 .26919 Mdot
.766 .26922 Mdot
.766 .26924 Mdot
.766 .26924 Mdot
.766 .26933 Mdot
.766 .26935 Mdot
.766 .26938 Mdot
.766 .26952 Mdot
.766 .26962 Mdot
.766 .26997 Mdot
.766 .26998 Mdot
.766 .27017 Mdot
.766 .27017 Mdot
.766 .2702 Mdot
.766 .27025 Mdot
.766 .27026 Mdot
.766 .27026 Mdot
.766 .27027 Mdot
.766 .27029 Mdot
.766 .27029 Mdot
.766 .27029 Mdot
.766 .27031 Mdot
.766 .27032 Mdot
.766 .27033 Mdot
.766 .27033 Mdot
.766 .27035 Mdot
.766 .27036 Mdot
.766 .27037 Mdot
.766 .27047 Mdot
.766 .27048 Mdot
.766 .27048 Mdot
.766 .27049 Mdot
.766 .27049 Mdot
.766 .2705 Mdot
.766 .27053 Mdot
.766 .27057 Mdot
.766 .27057 Mdot
.766 .27057 Mdot
.766 .27057 Mdot
.766 .27067 Mdot
.766 .27067 Mdot
.766 .27068 Mdot
.766 .27071 Mdot
.766 .27071 Mdot
.766 .27071 Mdot
.766 .27074 Mdot
.766 .27077 Mdot
.766 .27079 Mdot
.766 .27084 Mdot
.766 .27097 Mdot
.766 .27103 Mdot
.766 .27104 Mdot
.766 .27108 Mdot
.766 .27108 Mdot
.766 .27113 Mdot
.766 .27116 Mdot
.766 .27118 Mdot
.766 .27122 Mdot
.766 .27124 Mdot
.766 .27125 Mdot
.766 .27129 Mdot
.766 .27136 Mdot
.766 .27142 Mdot
.766 .27142 Mdot
.766 .27142 Mdot
.766 .27144 Mdot
.766 .27149 Mdot
.766 .27149 Mdot
.766 .27151 Mdot
.766 .27154 Mdot
.766 .27157 Mdot
.766 .27158 Mdot
.766 .2716 Mdot
.766 .27168 Mdot
.766 .27171 Mdot
.766 .27175 Mdot
.766 .27177 Mdot
.766 .27177 Mdot
.766 .27184 Mdot
.766 .27188 Mdot
.766 .27202 Mdot
.766 .27202 Mdot
.766 .27209 Mdot
.766 .27209 Mdot
.766 .2721 Mdot
.766 .27214 Mdot
.766 .27215 Mdot
.766 .27221 Mdot
.766 .27222 Mdot
.766 .27237 Mdot
.766 .27241 Mdot
.766 .2725 Mdot
.766 .27256 Mdot
.766 .27267 Mdot
.766 .27312 Mdot
.766 .27322 Mdot
.766 .27325 Mdot
.766 .27326 Mdot
.766 .27328 Mdot
.766 .27347 Mdot
.766 .27349 Mdot
.766 .27356 Mdot
.766 .27358 Mdot
.766 .27361 Mdot
.766 .27374 Mdot
.766 .27382 Mdot
.766 .27395 Mdot
.766 .27405 Mdot
.766 .27407 Mdot
.766 .27416 Mdot
.766 .27417 Mdot
.766 .27419 Mdot
.766 .27424 Mdot
.766 .27426 Mdot
.766 .27426 Mdot
.766 .27436 Mdot
.766 .27437 Mdot
.766 .27456 Mdot
.766 .27462 Mdot
.766 .2747 Mdot
.766 .27471 Mdot
.766 .27473 Mdot
.766 .27478 Mdot
.766 .27478 Mdot
.766 .27479 Mdot
.766 .27481 Mdot
.766 .2749 Mdot
.766 .27492 Mdot
.766 .27493 Mdot
.766 .27496 Mdot
.766 .27499 Mdot
.766 .27501 Mdot
.766 .27501 Mdot
.766 .27503 Mdot
.766 .27503 Mdot
.766 .27506 Mdot
.766 .27506 Mdot
.766 .27507 Mdot
.766 .27507 Mdot
.766 .27508 Mdot
.766 .2751 Mdot
.766 .27511 Mdot
.766 .27511 Mdot
.766 .27512 Mdot
.766 .27512 Mdot
.766 .27514 Mdot
.766 .27514 Mdot
.766 .27514 Mdot
.766 .27515 Mdot
.766 .27516 Mdot
.766 .27517 Mdot
.766 .27517 Mdot
.766 .27517 Mdot
.766 .27519 Mdot
.766 .27519 Mdot
.766 .2752 Mdot
.766 .2752 Mdot
.766 .27521 Mdot
.766 .27522 Mdot
.766 .27524 Mdot
.766 .27525 Mdot
.766 .27526 Mdot
.766 .27527 Mdot
.766 .27527 Mdot
.766 .27527 Mdot
.766 .27527 Mdot
.766 .27528 Mdot
.766 .27528 Mdot
.766 .27529 Mdot
.766 .27529 Mdot
.766 .27529 Mdot
.766 .27531 Mdot
.766 .27531 Mdot
.766 .27531 Mdot
.766 .27531 Mdot
.766 .27531 Mdot
.766 .27531 Mdot
.766 .27533 Mdot
.766 .27534 Mdot
.766 .27534 Mdot
.766 .27534 Mdot
.766 .27534 Mdot
.766 .27534 Mdot
.766 .27534 Mdot
.766 .27535 Mdot
.766 .27535 Mdot
.766 .27535 Mdot
.766 .27535 Mdot
.766 .44262 Mdot
.766 .44262 Mdot
.766 .44262 Mdot
.766 .44262 Mdot
.766 .44262 Mdot
.766 .44262 Mdot
.766 .44262 Mdot
.766 .44262 Mdot
.766 .44262 Mdot
.766 .44263 Mdot
.766 .44263 Mdot
.766 .44264 Mdot
.766 .44264 Mdot
.766 .44264 Mdot
.766 .44264 Mdot
.766 .44264 Mdot
.766 .44264 Mdot
.766 .44265 Mdot
.766 .44265 Mdot
.766 .44265 Mdot
.766 .44266 Mdot
.766 .44266 Mdot
.766 .44266 Mdot
.766 .44267 Mdot
.766 .44267 Mdot
.766 .44267 Mdot
.766 .44267 Mdot
.766 .44267 Mdot
.766 .44268 Mdot
.766 .44269 Mdot
.766 .4427 Mdot
.766 .4427 Mdot
.766 .44271 Mdot
.766 .44271 Mdot
.766 .44271 Mdot
.766 .44272 Mdot
.766 .44272 Mdot
.766 .44272 Mdot
.766 .44273 Mdot
.766 .44274 Mdot
.766 .44274 Mdot
.766 .44274 Mdot
.766 .44274 Mdot
.766 .44275 Mdot
.766 .44275 Mdot
.766 .44276 Mdot
.766 .44276 Mdot
.766 .44276 Mdot
.766 .44278 Mdot
.766 .44278 Mdot
.766 .44278 Mdot
.766 .44279 Mdot
.766 .44279 Mdot
.766 .44281 Mdot
.766 .44281 Mdot
.766 .44282 Mdot
.766 .44282 Mdot
.766 .44283 Mdot
.766 .44285 Mdot
.766 .44286 Mdot
.766 .44287 Mdot
.766 .44288 Mdot
.766 .44294 Mdot
.766 .44295 Mdot
.766 .44296 Mdot
.766 .44296 Mdot
.766 .44299 Mdot
.766 .443 Mdot
.766 .443 Mdot
.766 .44305 Mdot
.766 .44309 Mdot
.766 .44321 Mdot
.766 .44321 Mdot
.766 .44327 Mdot
.766 .44327 Mdot
.766 .44328 Mdot
.766 .44331 Mdot
.766 .44333 Mdot
.766 .44333 Mdot
.766 .44339 Mdot
.766 .4434 Mdot
.766 .44346 Mdot
.766 .44355 Mdot
.766 .4436 Mdot
.766 .44368 Mdot
.766 .4437 Mdot
.766 .44371 Mdot
.766 .44376 Mdot
.766 .44377 Mdot
.766 .44389 Mdot
.766 .44391 Mdot
.766 .44391 Mdot
.766 .44394 Mdot
.766 .444 Mdot
.766 .4443 Mdot
.766 .44438 Mdot
.766 .44442 Mdot
.766 .44448 Mdot
.766 .44451 Mdot
.766 .44461 Mdot
.766 .44462 Mdot
.766 .44466 Mdot
.766 .44467 Mdot
.766 .4447 Mdot
.766 .4447 Mdot
.766 .4447 Mdot
.766 .44475 Mdot
.766 .44475 Mdot
.766 .44485 Mdot
.766 .44487 Mdot
.766 .44488 Mdot
.766 .44493 Mdot
.766 .44494 Mdot
.766 .44495 Mdot
.766 .44498 Mdot
.766 .445 Mdot
.766 .44506 Mdot
.766 .44507 Mdot
.766 .44508 Mdot
.766 .4451 Mdot
.766 .44512 Mdot
.766 .44514 Mdot
.766 .44514 Mdot
.766 .44518 Mdot
.766 .44519 Mdot
.766 .44519 Mdot
.766 .44519 Mdot
.766 .44524 Mdot
.766 .44529 Mdot
.766 .44532 Mdot
.766 .44532 Mdot
.766 .44534 Mdot
.766 .44537 Mdot
.766 .44539 Mdot
.766 .44541 Mdot
.766 .44545 Mdot
.766 .44545 Mdot
.766 .44548 Mdot
.766 .44549 Mdot
.766 .44553 Mdot
.766 .44563 Mdot
.766 .44568 Mdot
.766 .44569 Mdot
.766 .44572 Mdot
.766 .44574 Mdot
.766 .44574 Mdot
.766 .44574 Mdot
.766 .44576 Mdot
.766 .44577 Mdot
.766 .44577 Mdot
.766 .44585 Mdot
.766 .44585 Mdot
.766 .44585 Mdot
.766 .44585 Mdot
.766 .44588 Mdot
.766 .44591 Mdot
.766 .44591 Mdot
.766 .44591 Mdot
.766 .44592 Mdot
.766 .44592 Mdot
.766 .44593 Mdot
.766 .44601 Mdot
.766 .44602 Mdot
.766 .44603 Mdot
.766 .44604 Mdot
.766 .44604 Mdot
.766 .44605 Mdot
.766 .44606 Mdot
.766 .44607 Mdot
.766 .44608 Mdot
.766 .44608 Mdot
.766 .44609 Mdot
.766 .4461 Mdot
.766 .4461 Mdot
.766 .44611 Mdot
.766 .44615 Mdot
.766 .44617 Mdot
.766 .44617 Mdot
.766 .44634 Mdot
.766 .44634 Mdot
.766 .44665 Mdot
.766 .44674 Mdot
.766 .44687 Mdot
.766 .44689 Mdot
.766 .44691 Mdot
.766 .44699 Mdot
.766 .447 Mdot
.766 .44701 Mdot
.766 .44704 Mdot
.766 .44719 Mdot
.766 .44722 Mdot
.766 .44724 Mdot
.766 .44728 Mdot
.766 .44733 Mdot
.766 .44736 Mdot
.766 .44737 Mdot
.766 .44739 Mdot
.766 .44739 Mdot
.766 .44744 Mdot
.766 .44744 Mdot
.766 .44746 Mdot
.766 .44747 Mdot
.766 .44747 Mdot
.766 .44751 Mdot
.766 .44752 Mdot
.766 .44752 Mdot
.766 .44754 Mdot
.766 .44755 Mdot
.766 .44757 Mdot
.766 .44757 Mdot
.766 .44757 Mdot
.766 .44759 Mdot
.766 .4476 Mdot
.766 .44762 Mdot
.766 .44762 Mdot
.766 .44762 Mdot
.766 .44764 Mdot
.766 .44765 Mdot
.766 .44767 Mdot
.766 .44767 Mdot
.766 .44768 Mdot
.766 .4477 Mdot
.766 .44773 Mdot
.766 .44775 Mdot
.766 .44777 Mdot
.766 .44777 Mdot
.766 .44777 Mdot
.766 .44777 Mdot
.766 .44778 Mdot
.766 .44778 Mdot
.766 .44778 Mdot
.766 .44781 Mdot
.766 .44781 Mdot
.766 .44781 Mdot
.766 .44783 Mdot
.766 .44783 Mdot
.766 .44784 Mdot
.766 .44784 Mdot
.766 .44784 Mdot
.766 .44784 Mdot
.766 .44787 Mdot
.766 .44788 Mdot
.766 .44788 Mdot
.766 .44788 Mdot
.766 .44789 Mdot
.766 .44789 Mdot
.766 .44789 Mdot
.766 .4479 Mdot
.766 .4479 Mdot
.766 .4479 Mdot
.766 .4479 Mdot
.766 .45035 Mdot
.766 .45035 Mdot
.766 .45035 Mdot
.766 .45036 Mdot
.766 .45037 Mdot
.766 .45037 Mdot
.766 .45037 Mdot
.766 .45039 Mdot
.766 .45039 Mdot
.766 .45039 Mdot
.766 .45042 Mdot
.766 .45047 Mdot
.766 .45048 Mdot
.766 .45048 Mdot
.766 .45048 Mdot
.766 .45049 Mdot
.766 .45049 Mdot
.766 .45053 Mdot
.766 .45053 Mdot
.766 .45053 Mdot
.766 .45059 Mdot
.766 .45059 Mdot
.766 .45059 Mdot
.766 .45061 Mdot
.766 .45061 Mdot
.766 .45061 Mdot
.766 .45063 Mdot
.766 .45065 Mdot
.766 .45069 Mdot
.766 .45076 Mdot
.766 .4508 Mdot
.766 .45082 Mdot
.766 .45083 Mdot
.766 .45086 Mdot
.766 .45087 Mdot
.766 .45091 Mdot
.766 .45092 Mdot
.766 .45093 Mdot
.766 .45095 Mdot
.766 .45099 Mdot
.766 .45103 Mdot
.766 .45103 Mdot
.766 .45103 Mdot
.766 .45107 Mdot
.766 .45108 Mdot
.766 .45112 Mdot
.766 .45112 Mdot
.766 .45114 Mdot
.766 .45123 Mdot
.766 .45123 Mdot
.766 .45124 Mdot
.766 .45128 Mdot
.766 .45129 Mdot
.766 .45139 Mdot
.766 .45139 Mdot
.766 .45144 Mdot
.766 .45144 Mdot
.766 .45151 Mdot
.766 .45161 Mdot
.766 .4517 Mdot
.766 .45174 Mdot
.766 .45181 Mdot
.766 .45212 Mdot
.766 .45219 Mdot
.766 .45221 Mdot
.766 .45222 Mdot
.766 .45239 Mdot
.766 .45245 Mdot
.766 .45249 Mdot
.766 .45277 Mdot
.766 .45296 Mdot
.766 .45362 Mdot
.766 .45364 Mdot
.766 .45399 Mdot
.766 .45399 Mdot
.766 .45405 Mdot
.766 .45414 Mdot
.766 .45415 Mdot
.766 .45415 Mdot
.766 .45417 Mdot
.766 .45421 Mdot
.766 .45421 Mdot
.766 .45421 Mdot
.766 .45423 Mdot
.766 .45426 Mdot
.766 .45427 Mdot
.766 .45428 Mdot
.766 .45431 Mdot
.766 .45433 Mdot
.766 .45435 Mdot
.766 .45453 Mdot
.766 .45455 Mdot
.766 .45455 Mdot
.766 .45457 Mdot
.766 .45457 Mdot
.766 .45457 Mdot
.766 .45464 Mdot
.766 .4547 Mdot
.766 .4547 Mdot
.766 .45471 Mdot
.766 .45471 Mdot
.766 .45488 Mdot
.766 .45488 Mdot
.766 .45489 Mdot
.766 .45494 Mdot
.766 .45495 Mdot
.766 .45495 Mdot
.766 .455 Mdot
.766 .45505 Mdot
.766 .45508 Mdot
.766 .45518 Mdot
.766 .4554 Mdot
.766 .4555 Mdot
.766 .45552 Mdot
.766 .45558 Mdot
.766 .45559 Mdot
.766 .45568 Mdot
.766 .45573 Mdot
.766 .45576 Mdot
.766 .45583 Mdot
.766 .45586 Mdot
.766 .45588 Mdot
.766 .45594 Mdot
.766 .45605 Mdot
.766 .45615 Mdot
.766 .45616 Mdot
.766 .45616 Mdot
.766 .45618 Mdot
.766 .45627 Mdot
.766 .45627 Mdot
.766 .45631 Mdot
.766 .45636 Mdot
.766 .4564 Mdot
.766 .45642 Mdot
.766 .45645 Mdot
.766 .45659 Mdot
.766 .45662 Mdot
.766 .45669 Mdot
.766 .45672 Mdot
.766 .45673 Mdot
.766 .45683 Mdot
.766 .4569 Mdot
.766 .45712 Mdot
.766 .45712 Mdot
.766 .45723 Mdot
.766 .45723 Mdot
.766 .45725 Mdot
.766 .4573 Mdot
.766 .45733 Mdot
.766 .45741 Mdot
.766 .45743 Mdot
.766 .45765 Mdot
.766 .45772 Mdot
.766 .45785 Mdot
.766 .45794 Mdot
.766 .4581 Mdot
.766 .45875 Mdot
.766 .45888 Mdot
.766 .45893 Mdot
.766 .45894 Mdot
.766 .45897 Mdot
.766 .45923 Mdot
.766 .45925 Mdot
.766 .45934 Mdot
.766 .45938 Mdot
.766 .45942 Mdot
.766 .45958 Mdot
.766 .45968 Mdot
.766 .45986 Mdot
.766 .45999 Mdot
.766 .46001 Mdot
.766 .46013 Mdot
.766 .46013 Mdot
.766 .46016 Mdot
.766 .46023 Mdot
.766 .46025 Mdot
.766 .46025 Mdot
.766 .46037 Mdot
.766 .46038 Mdot
.766 .46061 Mdot
.766 .46068 Mdot
.766 .46077 Mdot
.766 .46079 Mdot
.766 .46081 Mdot
.766 .46087 Mdot
.766 .46087 Mdot
.766 .46088 Mdot
.766 .4609 Mdot
.766 .46101 Mdot
.766 .46103 Mdot
.766 .46105 Mdot
.766 .46107 Mdot
.766 .46111 Mdot
.766 .46113 Mdot
.766 .46113 Mdot
.766 .46115 Mdot
.766 .46115 Mdot
.766 .46118 Mdot
.766 .46119 Mdot
.766 .4612 Mdot
.766 .4612 Mdot
.766 .46121 Mdot
.766 .46124 Mdot
.766 .46124 Mdot
.766 .46124 Mdot
.766 .46126 Mdot
.766 .46126 Mdot
.766 .46127 Mdot
.766 .46127 Mdot
.766 .46127 Mdot
.766 .46129 Mdot
.766 .4613 Mdot
.766 .46131 Mdot
.766 .46131 Mdot
.766 .46131 Mdot
.766 .46133 Mdot
.766 .46133 Mdot
.766 .46134 Mdot
.766 .46134 Mdot
.766 .46135 Mdot
.766 .46137 Mdot
.766 .46139 Mdot
.766 .4614 Mdot
.766 .46141 Mdot
.766 .46142 Mdot
.766 .46142 Mdot
.766 .46142 Mdot
.766 .46142 Mdot
.766 .46143 Mdot
.766 .46143 Mdot
.766 .46144 Mdot
.766 .46144 Mdot
.766 .46145 Mdot
.766 .46146 Mdot
.766 .46146 Mdot
.766 .46146 Mdot
.766 .46146 Mdot
.766 .46146 Mdot
.766 .46146 Mdot
.766 .46148 Mdot
.766 .46149 Mdot
.766 .46149 Mdot
.766 .46149 Mdot
.766 .4615 Mdot
.766 .4615 Mdot
.766 .4615 Mdot
.766 .4615 Mdot
.766 .46151 Mdot
.766 .46151 Mdot
.766 .46151 Mdot
.768 .26567 Mdot
.768 .26607 Mdot
.768 .27055 Mdot
.768 .27175 Mdot
.768 .44545 Mdot
.768 .44642 Mdot
.768 .45582 Mdot
.768 .45784 Mdot
.77 .2663 Mdot
.77 .26946 Mdot
.77 .44809 Mdot
.77 .45494 Mdot
.772 .26753 Mdot
.772 .45206 Mdot
.774 .26774 Mdot
.774 .45365 Mdot
.776 .27823 Mdot
.776 .46989 Mdot
.778 .28205 Mdot
.778 .47268 Mdot
.78 .28417 Mdot
.78 .47395 Mdot
.782 .28584 Mdot
.782 .47482 Mdot
.784 .28728 Mdot
.784 .47549 Mdot
.786 .28857 Mdot
.786 .47603 Mdot
.788 .28976 Mdot
.788 .47648 Mdot
.79 .29087 Mdot
.79 .47687 Mdot
.792 .29193 Mdot
.792 .4772 Mdot
.794 .29293 Mdot
.794 .47749 Mdot
.796 .29262 Mdot
.796 .29511 Mdot
.796 .47655 Mdot
.796 .47894 Mdot
.798 .29077 Mdot
.798 .29826 Mdot
.798 .47428 Mdot
.798 .48162 Mdot
.8 .2903 Mdot
.8 .30014 Mdot
.8 .47327 Mdot
.8 .48314 Mdot
.802 .29032 Mdot
.802 .3016 Mdot
.802 .47271 Mdot
.802 .48429 Mdot
.804 .29068 Mdot
.804 .30283 Mdot
.804 .47242 Mdot
.804 .4852 Mdot
.806 .29128 Mdot
.806 .30389 Mdot
.806 .47235 Mdot
.806 .48591 Mdot
.808 .29206 Mdot
.808 .30483 Mdot
.808 .47243 Mdot
.808 .48643 Mdot
.81 .29299 Mdot
.81 .30568 Mdot
.81 .47263 Mdot
.81 .48677 Mdot
.812 .29403 Mdot
.812 .30645 Mdot
.812 .47294 Mdot
.812 .48693 Mdot
.814 .29518 Mdot
.814 .30717 Mdot
.814 .47333 Mdot
.814 .48692 Mdot
.816 .29644 Mdot
.816 .30781 Mdot
.816 .47381 Mdot
.816 .48672 Mdot
.818 .29782 Mdot
.818 .30838 Mdot
.818 .47439 Mdot
.818 .48632 Mdot
.82 .29936 Mdot
.82 .3088 Mdot
.82 .47511 Mdot
.82 .48566 Mdot
.822 .30115 Mdot
.822 .30899 Mdot
.822 .47606 Mdot
.822 .48467 Mdot
.824 .30344 Mdot
.824 .30866 Mdot
.824 .47749 Mdot
.824 .48309 Mdot
.826 .30699 Mdot
.826 .48027 Mdot
.828 .3079 Mdot
.828 .48048 Mdot
.83 .30882 Mdot
.83 .48071 Mdot
.832 .30977 Mdot
.832 .48097 Mdot
.834 .31075 Mdot
.834 .48127 Mdot
.836 .31177 Mdot
.836 .48163 Mdot
.838 .31283 Mdot
.838 .48204 Mdot
.84 .31394 Mdot
.84 .48253 Mdot
.842 .31511 Mdot
.842 .48313 Mdot
.844 .31635 Mdot
.844 .48387 Mdot
.846 .31765 Mdot
.846 .48478 Mdot
.848 .31896 Mdot
.848 .48592 Mdot
.85 .32022 Mdot
.85 .48727 Mdot
.852 .32129 Mdot
.852 .48875 Mdot
.854 .32207 Mdot
.854 .49025 Mdot
.856 .32258 Mdot
.856 .49166 Mdot
.858 .32286 Mdot
.858 .49296 Mdot
.86 .32296 Mdot
.86 .49414 Mdot
.862 .32291 Mdot
.862 .49523 Mdot
.864 .32276 Mdot
.864 .49624 Mdot
.866 .3225 Mdot
.866 .49719 Mdot
.868 .32215 Mdot
.868 .49809 Mdot
.87 .32171 Mdot
.87 .49897 Mdot
.872 .32116 Mdot
.872 .49983 Mdot
.874 .32048 Mdot
.874 .50069 Mdot
.876 .31961 Mdot
.876 .50157 Mdot
.878 .31844 Mdot
.878 .50255 Mdot
.88 .31628 Mdot
.88 .5039 Mdot
.882 .19585 Mdot
.882 .19585 Mdot
.882 .19589 Mdot
.882 .1959 Mdot
.882 .19592 Mdot
.882 .19603 Mdot
.882 .19607 Mdot
.882 .19616 Mdot
.882 .19626 Mdot
.882 .19632 Mdot
.882 .19642 Mdot
.882 .19695 Mdot
.882 .19696 Mdot
.882 .19697 Mdot
.882 .19698 Mdot
.882 .19701 Mdot
.882 .19706 Mdot
.882 .19786 Mdot
.882 .19812 Mdot
.882 .19834 Mdot
.882 .19874 Mdot
.882 .19877 Mdot
.882 .19945 Mdot
.882 .20085 Mdot
.882 .20107 Mdot
.882 .20139 Mdot
.882 .20214 Mdot
.882 .20218 Mdot
.882 .20261 Mdot
.882 .20262 Mdot
.882 .20291 Mdot
.882 .20352 Mdot
.882 .20428 Mdot
.882 .2043 Mdot
.882 .20446 Mdot
.882 .20447 Mdot
.882 .20459 Mdot
.882 .20473 Mdot
.882 .20476 Mdot
.882 .20507 Mdot
.882 .20527 Mdot
.882 .20534 Mdot
.882 .2054 Mdot
.882 .20583 Mdot
.882 .20594 Mdot
.882 .20634 Mdot
.882 .20783 Mdot
.882 .20801 Mdot
.882 .20807 Mdot
.882 .20868 Mdot
.882 .209 Mdot
.882 .2093 Mdot
.882 .20931 Mdot
.882 .2094 Mdot
.882 .2099 Mdot
.882 .21108 Mdot
.882 .21211 Mdot
.882 .21217 Mdot
.882 .21242 Mdot
.882 .2125 Mdot
.882 .21261 Mdot
.882 .21281 Mdot
.882 .21285 Mdot
.882 .21288 Mdot
.882 .21352 Mdot
.882 .21353 Mdot
.882 .21395 Mdot
.882 .21429 Mdot
.882 .21488 Mdot
.882 .21492 Mdot
.882 .21534 Mdot
.882 .2154 Mdot
.882 .21543 Mdot
.882 .21543 Mdot
.882 .21584 Mdot
.882 .21593 Mdot
.882 .21595 Mdot
.882 .21598 Mdot
.882 .21617 Mdot
.882 .21623 Mdot
.882 .21631 Mdot
.882 .21635 Mdot
.882 .21674 Mdot
.882 .21679 Mdot
.882 .21712 Mdot
.882 .21722 Mdot
.882 .21724 Mdot
.882 .21726 Mdot
.882 .21728 Mdot
.882 .21751 Mdot
.882 .21789 Mdot
.882 .21971 Mdot
.882 .22009 Mdot
.882 .22017 Mdot
.882 .22078 Mdot
.882 .22078 Mdot
.882 .22079 Mdot
.882 .22184 Mdot
.882 .22297 Mdot
.882 .22332 Mdot
.882 .22385 Mdot
.882 .22386 Mdot
.882 .22492 Mdot
.882 .22566 Mdot
.882 .2261 Mdot
.882 .22694 Mdot
.882 .22708 Mdot
.882 .22744 Mdot
.882 .22757 Mdot
.882 .22963 Mdot
.882 .22989 Mdot
.882 .23007 Mdot
.882 .2301 Mdot
.882 .23039 Mdot
.882 .23048 Mdot
.882 .2325 Mdot
.882 .23502 Mdot
.882 .23613 Mdot
.882 .23893 Mdot
.882 .24249 Mdot
.882 .24311 Mdot
.882 .24465 Mdot
.882 .24624 Mdot
.882 .24723 Mdot
.882 .24804 Mdot
.882 .24986 Mdot
.882 .24986 Mdot
.882 .24994 Mdot
.882 .25069 Mdot
.882 .25144 Mdot
.882 .25513 Mdot
.882 .25708 Mdot
.882 .25779 Mdot
.882 .259 Mdot
.882 .2593 Mdot
.882 .25942 Mdot
.882 .2597 Mdot
.882 .26084 Mdot
.882 .26117 Mdot
.882 .26123 Mdot
.882 .26205 Mdot
.882 .26255 Mdot
.882 .2628 Mdot
.882 .26652 Mdot
.882 .26664 Mdot
.882 .26722 Mdot
.882 .26763 Mdot
.882 .26809 Mdot
.882 .26815 Mdot
.882 .26889 Mdot
.882 .26915 Mdot
.882 .26933 Mdot
.882 .26944 Mdot
.882 .26991 Mdot
.882 .27185 Mdot
.882 .27203 Mdot
.882 .27337 Mdot
.882 .27364 Mdot
.882 .27372 Mdot
.882 .27426 Mdot
.882 .27491 Mdot
.882 .27567 Mdot
.882 .27567 Mdot
.882 .2757 Mdot
.882 .27576 Mdot
.882 .27577 Mdot
.882 .27584 Mdot
.882 .27584 Mdot
.882 .2759 Mdot
.882 .27591 Mdot
.882 .276 Mdot
.882 .27602 Mdot
.882 .2761 Mdot
.882 .27611 Mdot
.882 .27628 Mdot
.882 .27636 Mdot
.882 .27649 Mdot
.882 .27649 Mdot
.882 .27654 Mdot
.882 .27656 Mdot
.882 .27663 Mdot
.882 .27721 Mdot
.882 .27738 Mdot
.882 .27753 Mdot
.882 .27804 Mdot
.882 .27807 Mdot
.882 .27837 Mdot
.882 .27844 Mdot
.882 .27891 Mdot
.882 .279 Mdot
.882 .279 Mdot
.882 .27953 Mdot
.882 .27961 Mdot
.882 .28158 Mdot
.882 .2816 Mdot
.882 .28162 Mdot
.882 .28162 Mdot
.882 .28214 Mdot
.882 .28233 Mdot
.882 .28248 Mdot
.882 .28271 Mdot
.882 .283 Mdot
.882 .28309 Mdot
.882 .28311 Mdot
.882 .28341 Mdot
.882 .28349 Mdot
.882 .28406 Mdot
.882 .28428 Mdot
.882 .28466 Mdot
.882 .28532 Mdot
.882 .28541 Mdot
.882 .28598 Mdot
.882 .28615 Mdot
.882 .2865 Mdot
.882 .28652 Mdot
.882 .28686 Mdot
.882 .288 Mdot
.882 .28802 Mdot
.882 .2885 Mdot
.882 .28876 Mdot
.882 .28881 Mdot
.882 .28885 Mdot
.882 .2889 Mdot
.882 .289 Mdot
.882 .28907 Mdot
.882 .28909 Mdot
.882 .2891 Mdot
.882 .28939 Mdot
.882 .28982 Mdot
.882 .28989 Mdot
.882 .29014 Mdot
.882 .29022 Mdot
.882 .29022 Mdot
.882 .29038 Mdot
.882 .29068 Mdot
.882 .29094 Mdot
.882 .29101 Mdot
.882 .29111 Mdot
.882 .29128 Mdot
.882 .29146 Mdot
.882 .29172 Mdot
.882 .29181 Mdot
.882 .29184 Mdot
.882 .29189 Mdot
.882 .2919 Mdot
.882 .29213 Mdot
.882 .29219 Mdot
.882 .29227 Mdot
.882 .29266 Mdot
.882 .29274 Mdot
.882 .29276 Mdot
.882 .29289 Mdot
.882 .29289 Mdot
.882 .29289 Mdot
.882 .29333 Mdot
.882 .29341 Mdot
.882 .29351 Mdot
.882 .29351 Mdot
.882 .29372 Mdot
.882 .29387 Mdot
.882 .29412 Mdot
.882 .29414 Mdot
.882 .29422 Mdot
.882 .29424 Mdot
.882 .29463 Mdot
.882 .29471 Mdot
.882 .29472 Mdot
.882 .29477 Mdot
.882 .29563 Mdot
.882 .29583 Mdot
.882 .29633 Mdot
.882 .29696 Mdot
.882 .29762 Mdot
.882 .29779 Mdot
.882 .29793 Mdot
.882 .29825 Mdot
.882 .29825 Mdot
.882 .29826 Mdot
.882 .29839 Mdot
.882 .29852 Mdot
.882 .29916 Mdot
.882 .2995 Mdot
.882 .29963 Mdot
.882 .29984 Mdot
.882 .29989 Mdot
.882 .29991 Mdot
.882 .29996 Mdot
.882 .30022 Mdot
.882 .30023 Mdot
.882 .30047 Mdot
.882 .3012 Mdot
.882 .30131 Mdot
.882 .30148 Mdot
.882 .30161 Mdot
.882 .30172 Mdot
.882 .3022 Mdot
.882 .30245 Mdot
.882 .30252 Mdot
.882 .30262 Mdot
.882 .30275 Mdot
.882 .30289 Mdot
.882 .3029 Mdot
.882 .3029 Mdot
.882 .30291 Mdot
.882 .30291 Mdot
.882 .30293 Mdot
.882 .30293 Mdot
.882 .30294 Mdot
.882 .30294 Mdot
.882 .30296 Mdot
.882 .30296 Mdot
.882 .30298 Mdot
.882 .30298 Mdot
.882 .30301 Mdot
.882 .30303 Mdot
.882 .30305 Mdot
.882 .30306 Mdot
.882 .30306 Mdot
.882 .30307 Mdot
.882 .30308 Mdot
.882 .3032 Mdot
.882 .30323 Mdot
.882 .30326 Mdot
.882 .30336 Mdot
.882 .30337 Mdot
.882 .30343 Mdot
.882 .30344 Mdot
.882 .30355 Mdot
.882 .30366 Mdot
.882 .30408 Mdot
.882 .30408 Mdot
.882 .30409 Mdot
.882 .30409 Mdot
.882 .3042 Mdot
.882 .30423 Mdot
.882 .30427 Mdot
.882 .30432 Mdot
.882 .30438 Mdot
.882 .30439 Mdot
.882 .3044 Mdot
.882 .30446 Mdot
.882 .30448 Mdot
.882 .30465 Mdot
.882 .30473 Mdot
.882 .30487 Mdot
.882 .30489 Mdot
.882 .30502 Mdot
.882 .30506 Mdot
.882 .30514 Mdot
.882 .30514 Mdot
.882 .30522 Mdot
.882 .30547 Mdot
.882 .30565 Mdot
.882 .30566 Mdot
.882 .30568 Mdot
.882 .3057 Mdot
.882 .30572 Mdot
.882 .30572 Mdot
.882 .30573 Mdot
.882 .30579 Mdot
.882 .30591 Mdot
.882 .30597 Mdot
.882 .30599 Mdot
.882 .30599 Mdot
.882 .30603 Mdot
.882 .3061 Mdot
.882 .30616 Mdot
.882 .30618 Mdot
.882 .30625 Mdot
.882 .30629 Mdot
.882 .30635 Mdot
.882 .30638 Mdot
.882 .30638 Mdot
.882 .3064 Mdot
.882 .3064 Mdot
.882 .30645 Mdot
.882 .30647 Mdot
.882 .30649 Mdot
.882 .30659 Mdot
.882 .30661 Mdot
.882 .30661 Mdot
.882 .30664 Mdot
.882 .30664 Mdot
.882 .30664 Mdot
.882 .30676 Mdot
.882 .30678 Mdot
.882 .3068 Mdot
.882 .30686 Mdot
.882 .30689 Mdot
.882 .30696 Mdot
.882 .30697 Mdot
.882 .30699 Mdot
.882 .30711 Mdot
.882 .30712 Mdot
.882 .30713 Mdot
.882 .30736 Mdot
.882 .30741 Mdot
.882 .30755 Mdot
.882 .30772 Mdot
.882 .30791 Mdot
.882 .308 Mdot
.882 .30809 Mdot
.882 .30817 Mdot
.882 .3085 Mdot
.882 .30858 Mdot
.882 .30859 Mdot
.882 .3086 Mdot
.882 .30869 Mdot
.882 .30869 Mdot
.882 .30876 Mdot
.882 .309 Mdot
.882 .30903 Mdot
.882 .30909 Mdot
.882 .30913 Mdot
.882 .30932 Mdot
.882 .30941 Mdot
.882 .30943 Mdot
.882 .30947 Mdot
.882 .30956 Mdot
.882 .30961 Mdot
.882 .30975 Mdot
.882 .30983 Mdot
.882 .30998 Mdot
.882 .30998 Mdot
.882 .31007 Mdot
.882 .31009 Mdot
.882 .31033 Mdot
.882 .31051 Mdot
.882 .31064 Mdot
.882 .31069 Mdot
.882 .31071 Mdot
.882 .31072 Mdot
.882 .31073 Mdot
.882 .31076 Mdot
.882 .3108 Mdot
.882 .31087 Mdot
.882 .31088 Mdot
.882 .31091 Mdot
.882 .31104 Mdot
.882 .31106 Mdot
.882 .31109 Mdot
.882 .31112 Mdot
.882 .31113 Mdot
.882 .31114 Mdot
.882 .31119 Mdot
.882 .31119 Mdot
.882 .3112 Mdot
.882 .3113 Mdot
.882 .31132 Mdot
.882 .31138 Mdot
.882 .31187 Mdot
.882 .31192 Mdot
.882 .31224 Mdot
.882 .31228 Mdot
.882 .3123 Mdot
.882 .31236 Mdot
.882 .31239 Mdot
.882 .31246 Mdot
.882 .31251 Mdot
.882 .31259 Mdot
.882 .31279 Mdot
.882 .31289 Mdot
.882 .31297 Mdot
.882 .313 Mdot
.882 .31301 Mdot
.882 .31302 Mdot
.882 .31304 Mdot
.882 .31306 Mdot
.882 .31311 Mdot
.882 .31312 Mdot
.882 .31314 Mdot
.882 .31322 Mdot
.882 .31323 Mdot
.882 .31327 Mdot
.882 .31327 Mdot
.882 .31328 Mdot
.882 .31331 Mdot
.882 .31331 Mdot
.882 .31332 Mdot
.882 .3134 Mdot
.882 .3138 Mdot
.882 .31404 Mdot
.882 .31408 Mdot
.882 .31416 Mdot
.882 .31422 Mdot
.882 .31425 Mdot
.882 .31432 Mdot
.882 .31449 Mdot
.882 .31457 Mdot
.882 .31464 Mdot
.882 .31467 Mdot
.882 .31468 Mdot
.882 .31468 Mdot
.882 .31471 Mdot
.882 .31473 Mdot
.882 .31479 Mdot
.882 .31488 Mdot
.882 .31496 Mdot
.882 .31496 Mdot
.882 .31496 Mdot
.882 .31504 Mdot
.882 .31584 Mdot
.882 .31594 Mdot
.882 .31646 Mdot
.882 .31663 Mdot
.882 .31683 Mdot
.882 .31687 Mdot
.882 .31693 Mdot
.882 .31697 Mdot
.882 .31746 Mdot
.882 .31831 Mdot
.882 .32132 Mdot
.882 .32266 Mdot
.882 .3234 Mdot
.882 .32364 Mdot
.882 .32385 Mdot
.882 .32402 Mdot
.882 .32472 Mdot
.882 .32548 Mdot
.882 .32548 Mdot
.882 .32552 Mdot
.882 .32623 Mdot
.882 .32706 Mdot
.882 .32846 Mdot
.882 .3289 Mdot
.882 .33002 Mdot
.882 .33018 Mdot
.882 .33096 Mdot
.882 .33169 Mdot
.882 .3318 Mdot
.882 .33183 Mdot
.882 .332 Mdot
.882 .33208 Mdot
.882 .33216 Mdot
.882 .3329 Mdot
.882 .33457 Mdot
.882 .3346 Mdot
.882 .33806 Mdot
.882 .34056 Mdot
.882 .34209 Mdot
.882 .34509 Mdot
.882 .34561 Mdot
.882 .34694 Mdot
.882 .3474 Mdot
.882 .34787 Mdot
.882 .35532 Mdot
.882 .35635 Mdot
.882 .35705 Mdot
.882 .35719 Mdot
.882 .35739 Mdot
.882 .35834 Mdot
.882 .35869 Mdot
.882 .36714 Mdot
.882 .37814 Mdot
.882 .37944 Mdot
.882 .38036 Mdot
.882 .38317 Mdot
.882 .39617 Mdot
.882 .41313 Mdot
.882 .41424 Mdot
.882 .41614 Mdot
.882 .42334 Mdot
.882 .42355 Mdot
.882 .4287 Mdot
.882 .43116 Mdot
.882 .43588 Mdot
.882 .43968 Mdot
.882 .4482 Mdot
.882 .44821 Mdot
.882 .44861 Mdot
.882 .45206 Mdot
.882 .45546 Mdot
.882 .47165 Mdot
.882 .47971 Mdot
.882 .48253 Mdot
.882 .48718 Mdot
.882 .48831 Mdot
.882 .48876 Mdot
.882 .4898 Mdot
.882 .49394 Mdot
.882 .49508 Mdot
.882 .49529 Mdot
.882 .49813 Mdot
.882 .4998 Mdot
.882 .50024 Mdot
.882 .50061 Mdot
.882 .50477 Mdot
.882 .50477 Mdot
.882 .5048 Mdot
.882 .50487 Mdot
.882 .50487 Mdot
.882 .50488 Mdot
.882 .50489 Mdot
.882 .5049 Mdot
.882 .50493 Mdot
.882 .50497 Mdot
.882 .5051 Mdot
.882 .50513 Mdot
.882 .50525 Mdot
.882 .50541 Mdot
.882 .50544 Mdot
.882 .50545 Mdot
.882 .50545 Mdot
.882 .50546 Mdot
.882 .50548 Mdot
.882 .50551 Mdot
.882 .50553 Mdot
.882 .50554 Mdot
.882 .50555 Mdot
.882 .50556 Mdot
.882 .50556 Mdot
.882 .50557 Mdot
.882 .50558 Mdot
.882 .50561 Mdot
.882 .50565 Mdot
.882 .50573 Mdot
.882 .50577 Mdot
.882 .50578 Mdot
.882 .50581 Mdot
.882 .50585 Mdot
.882 .50587 Mdot
.882 .506 Mdot
.882 .50602 Mdot
.882 .5062 Mdot
.882 .50623 Mdot
.882 .50627 Mdot
.882 .50628 Mdot
.882 .50628 Mdot
.882 .5063 Mdot
.882 .5063 Mdot
.882 .5063 Mdot
.882 .50631 Mdot
.882 .50633 Mdot
.882 .50633 Mdot
.882 .50638 Mdot
.882 .50639 Mdot
.882 .5064 Mdot
.882 .50643 Mdot
.882 .50644 Mdot
.882 .50646 Mdot
.882 .50646 Mdot
.882 .50647 Mdot
.882 .50649 Mdot
.882 .50653 Mdot
.882 .5066 Mdot
.882 .50673 Mdot
.882 .50673 Mdot
.882 .50679 Mdot
.882 .50682 Mdot
.882 .50687 Mdot
.882 .50689 Mdot
.882 .50692 Mdot
.882 .50693 Mdot
.882 .50694 Mdot
.882 .50697 Mdot
.882 .50709 Mdot
.882 .5072 Mdot
.882 .50721 Mdot
.882 .50724 Mdot
.882 .50724 Mdot
.882 .50745 Mdot
.882 .50748 Mdot
.882 .50755 Mdot
.882 .50761 Mdot
.882 .50766 Mdot
.882 .50768 Mdot
.882 .50776 Mdot
.882 .50776 Mdot
.882 .50776 Mdot
.882 .50781 Mdot
.882 .50782 Mdot
.882 .50782 Mdot
.882 .50784 Mdot
.882 .50787 Mdot
.882 .50788 Mdot
.882 .50789 Mdot
.882 .50793 Mdot
.882 .50799 Mdot
.882 .50802 Mdot
.882 .50803 Mdot
.882 .50809 Mdot
.882 .50812 Mdot
.882 .50814 Mdot
.882 .50815 Mdot
.882 .50816 Mdot
.882 .50818 Mdot
.882 .50822 Mdot
.882 .50833 Mdot
.882 .50848 Mdot
.882 .50869 Mdot
.882 .50869 Mdot
.882 .5087 Mdot
.882 .50872 Mdot
.882 .50874 Mdot
.882 .5088 Mdot
.882 .5088 Mdot
.882 .50894 Mdot
.882 .50901 Mdot
.882 .50914 Mdot
.882 .50919 Mdot
.882 .50923 Mdot
.882 .50928 Mdot
.882 .50931 Mdot
.882 .50933 Mdot
.882 .50941 Mdot
.882 .50957 Mdot
.882 .5096 Mdot
.882 .50964 Mdot
.882 .5097 Mdot
.882 .50973 Mdot
.882 .50996 Mdot
.882 .51003 Mdot
.882 .51004 Mdot
.882 .51012 Mdot
.882 .51013 Mdot
.882 .51014 Mdot
.882 .51016 Mdot
.882 .51022 Mdot
.882 .51026 Mdot
.882 .51037 Mdot
.882 .51056 Mdot
.882 .5106 Mdot
.882 .51064 Mdot
.882 .51065 Mdot
.882 .51065 Mdot
.882 .51074 Mdot
.882 .51079 Mdot
.882 .51084 Mdot
.882 .51103 Mdot
.882 .51122 Mdot
.882 .51137 Mdot
.882 .51143 Mdot
.882 .51168 Mdot
.882 .51169 Mdot
.882 .5117 Mdot
.882 .51172 Mdot
.882 .51183 Mdot
.882 .51184 Mdot
.882 .51186 Mdot
.882 .51187 Mdot
.882 .51194 Mdot
.882 .51198 Mdot
.882 .51204 Mdot
.882 .51204 Mdot
.882 .51207 Mdot
.882 .51209 Mdot
.882 .51222 Mdot
.882 .51222 Mdot
.882 .51222 Mdot
.882 .51226 Mdot
.882 .51226 Mdot
.882 .51229 Mdot
.882 .5124 Mdot
.882 .51242 Mdot
.882 .51244 Mdot
.882 .5125 Mdot
.882 .5125 Mdot
.882 .51252 Mdot
.882 .51253 Mdot
.882 .51255 Mdot
.882 .51262 Mdot
.882 .51268 Mdot
.882 .51272 Mdot
.882 .51275 Mdot
.882 .51277 Mdot
.882 .51284 Mdot
.882 .51293 Mdot
.882 .51297 Mdot
.882 .51297 Mdot
.882 .51299 Mdot
.882 .51306 Mdot
.882 .51308 Mdot
.882 .5132 Mdot
.882 .51328 Mdot
.882 .51328 Mdot
.882 .51329 Mdot
.882 .51331 Mdot
.882 .51333 Mdot
.882 .51335 Mdot
.882 .51336 Mdot
.882 .51337 Mdot
.882 .51344 Mdot
.882 .51357 Mdot
.882 .51358 Mdot
.882 .51388 Mdot
.882 .51398 Mdot
.882 .51398 Mdot
.882 .51407 Mdot
.882 .51412 Mdot
.882 .51427 Mdot
.882 .51429 Mdot
.882 .51447 Mdot
.882 .51457 Mdot
.882 .51463 Mdot
.882 .51478 Mdot
.882 .51479 Mdot
.882 .51487 Mdot
.882 .51488 Mdot
.882 .5149 Mdot
.882 .51498 Mdot
.882 .51504 Mdot
.882 .51507 Mdot
.882 .51512 Mdot
.882 .51526 Mdot
.882 .51526 Mdot
.882 .51526 Mdot
.882 .51527 Mdot
.882 .51577 Mdot
.882 .51579 Mdot
.882 .51592 Mdot
.882 .51592 Mdot
.882 .51595 Mdot
.882 .51606 Mdot
.882 .51608 Mdot
.882 .51615 Mdot
.882 .51616 Mdot
.882 .51629 Mdot
.882 .51633 Mdot
.882 .51637 Mdot
.882 .51651 Mdot
.882 .51653 Mdot
.882 .51653 Mdot
.882 .51655 Mdot
.882 .51655 Mdot
.882 .51658 Mdot
.882 .5166 Mdot
.882 .51664 Mdot
.882 .51664 Mdot
.882 .51666 Mdot
.882 .51667 Mdot
.882 .51669 Mdot
.882 .51669 Mdot
.882 .51671 Mdot
.882 .51671 Mdot
.882 .51672 Mdot
.882 .51673 Mdot
.882 .51674 Mdot
.882 .51675 Mdot
.882 .51675 Mdot
.882 .51693 Mdot
.882 .51709 Mdot
.882 .51722 Mdot
.882 .51724 Mdot
.882 .51731 Mdot
.882 .51763 Mdot
.882 .51768 Mdot
.882 .51814 Mdot
.882 .51825 Mdot
.882 .51828 Mdot
.882 .51832 Mdot
.882 .51838 Mdot
.882 .51855 Mdot
.882 .51857 Mdot
.882 .51867 Mdot
.882 .51877 Mdot
.882 .51891 Mdot
.882 .51893 Mdot
.882 .51979 Mdot
.882 .51985 Mdot
.882 .51996 Mdot
.882 .52015 Mdot
.882 .52016 Mdot
.882 .52024 Mdot
.882 .5205 Mdot
.882 .52056 Mdot
.882 .52059 Mdot
.882 .52065 Mdot
.882 .52092 Mdot
.882 .52108 Mdot
.882 .52152 Mdot
.882 .52233 Mdot
.882 .5225 Mdot
.882 .52266 Mdot
.882 .52268 Mdot
.882 .52268 Mdot
.882 .52307 Mdot
.882 .52325 Mdot
.882 .52346 Mdot
.882 .5238 Mdot
.882 .52413 Mdot
.882 .52427 Mdot
.882 .52502 Mdot
.882 .52562 Mdot
.882 .52585 Mdot
.882 .52638 Mdot
.882 .52681 Mdot
.882 .52683 Mdot
.882 .52688 Mdot
.882 .52689 Mdot
.882 .52693 Mdot
.882 .52698 Mdot
.882 .52742 Mdot
.882 .52744 Mdot
.882 .52752 Mdot
.882 .52755 Mdot
.882 .52772 Mdot
.882 .52781 Mdot
.882 .52797 Mdot
.882 .52819 Mdot
.882 .52819 Mdot
.882 .5283 Mdot
.882 .52837 Mdot
.882 .52861 Mdot
.882 .52883 Mdot
.882 .52883 Mdot
.882 .52883 Mdot
.882 .52896 Mdot
.882 .52897 Mdot
.882 .52905 Mdot
.882 .52943 Mdot
.882 .52951 Mdot
.882 .52956 Mdot
.882 .52956 Mdot
.882 .52957 Mdot
.882 .52957 Mdot
.882 .52959 Mdot
.882 .52966 Mdot
.882 .52967 Mdot
.882 .52975 Mdot
.882 .52976 Mdot
.882 .52978 Mdot
.882 .52979 Mdot
.882 .52983 Mdot
.882 .52983 Mdot
.882 .52984 Mdot
.882 .52986 Mdot
.882 .52994 Mdot
.882 .52994 Mdot
.882 .52995 Mdot
.882 .52996 Mdot
.882 .53005 Mdot
.882 .53006 Mdot
.882 .53018 Mdot
.882 .53025 Mdot
.882 .53034 Mdot
.882 .53034 Mdot
.882 .53047 Mdot
.882 .53048 Mdot
.882 .53049 Mdot
.882 .53053 Mdot
.882 .53055 Mdot
.882 .53057 Mdot
.882 .53062 Mdot
.882 .53063 Mdot
.882 .53085 Mdot
.882 .53109 Mdot
.882 .5312 Mdot
.882 .53121 Mdot
.882 .53122 Mdot
.882 .53128 Mdot
.882 .53135 Mdot
.882 .53147 Mdot
.882 .53149 Mdot
.882 .53152 Mdot
.882 .53183 Mdot
.882 .53192 Mdot
.882 .53194 Mdot
.882 .53203 Mdot
.882 .53204 Mdot
.882 .53206 Mdot
.882 .5321 Mdot
.882 .53216 Mdot
.882 .53217 Mdot
.882 .5322 Mdot
.882 .53222 Mdot
.882 .53223 Mdot
.882 .53226 Mdot
.882 .53226 Mdot
.882 .53242 Mdot
.882 .53255 Mdot
.882 .53261 Mdot
.882 .53261 Mdot
.882 .5327 Mdot
.882 .53271 Mdot
.882 .53287 Mdot
.882 .53294 Mdot
.882 .53298 Mdot
.882 .53328 Mdot
.882 .53342 Mdot
.882 .53343 Mdot
.882 .53351 Mdot
.882 .53356 Mdot
.882 .53361 Mdot
.882 .53378 Mdot
.882 .53379 Mdot
.882 .5338 Mdot
.882 .5338 Mdot
.882 .5338 Mdot
.882 .5338 Mdot
.882 .53392 Mdot
.882 .53394 Mdot
.882 .53395 Mdot
.882 .53397 Mdot
.882 .53399 Mdot
.882 .534 Mdot
.882 .53401 Mdot
.882 .53402 Mdot
.882 .53403 Mdot
.882 .53403 Mdot
.882 .53404 Mdot
.882 .53404 Mdot
.884 .19072 Mdot
.884 .19073 Mdot
.884 .19073 Mdot
.884 .19078 Mdot
.884 .19092 Mdot
.884 .19104 Mdot
.884 .19119 Mdot
.884 .19123 Mdot
.884 .19143 Mdot
.884 .19192 Mdot
.884 .19197 Mdot
.884 .19206 Mdot
.884 .19217 Mdot
.884 .19225 Mdot
.884 .19239 Mdot
.884 .19249 Mdot
.884 .19299 Mdot
.884 .19305 Mdot
.884 .19324 Mdot
.884 .19345 Mdot
.884 .19408 Mdot
.884 .19408 Mdot
.884 .19409 Mdot
.884 .19422 Mdot
.884 .19422 Mdot
.884 .19428 Mdot
.884 .1944 Mdot
.884 .19444 Mdot
.884 .19504 Mdot
.884 .19523 Mdot
.884 .19533 Mdot
.884 .19535 Mdot
.884 .19547 Mdot
.884 .19558 Mdot
.884 .19567 Mdot
.884 .19585 Mdot
.884 .196 Mdot
.884 .19605 Mdot
.884 .19675 Mdot
.884 .19686 Mdot
.884 .19691 Mdot
.884 .19731 Mdot
.884 .19776 Mdot
.884 .19844 Mdot
.884 .19879 Mdot
.884 .19894 Mdot
.884 .19971 Mdot
.884 .20013 Mdot
.884 .20015 Mdot
.884 .20016 Mdot
.884 .20022 Mdot
.884 .20028 Mdot
.884 .20082 Mdot
.884 .20094 Mdot
.884 .2012 Mdot
.884 .2016 Mdot
.884 .20163 Mdot
.884 .20165 Mdot
.884 .20207 Mdot
.884 .20234 Mdot
.884 .20248 Mdot
.884 .20257 Mdot
.884 .20257 Mdot
.884 .20263 Mdot
.884 .20274 Mdot
.884 .2028 Mdot
.884 .20286 Mdot
.884 .20417 Mdot
.884 .20457 Mdot
.884 .20485 Mdot
.884 .20544 Mdot
.884 .20593 Mdot
.884 .20667 Mdot
.884 .20675 Mdot
.884 .20755 Mdot
.884 .2076 Mdot
.884 .2076 Mdot
.884 .20775 Mdot
.884 .2078 Mdot
.884 .2079 Mdot
.884 .20825 Mdot
.884 .20865 Mdot
.884 .20877 Mdot
.884 .20907 Mdot
.884 .20956 Mdot
.884 .20979 Mdot
.884 .21032 Mdot
.884 .21047 Mdot
.884 .21071 Mdot
.884 .2114 Mdot
.884 .21162 Mdot
.884 .21214 Mdot
.884 .21227 Mdot
.884 .21304 Mdot
.884 .21346 Mdot
.884 .21362 Mdot
.884 .21373 Mdot
.884 .21375 Mdot
.884 .21426 Mdot
.884 .2145 Mdot
.884 .2147 Mdot
.884 .21489 Mdot
.884 .21496 Mdot
.884 .21501 Mdot
.884 .21593 Mdot
.884 .216 Mdot
.884 .2166 Mdot
.884 .21742 Mdot
.884 .21845 Mdot
.884 .21885 Mdot
.884 .21949 Mdot
.884 .22001 Mdot
.884 .22025 Mdot
.884 .22033 Mdot
.884 .22061 Mdot
.884 .22089 Mdot
.884 .22151 Mdot
.884 .22171 Mdot
.884 .22222 Mdot
.884 .22264 Mdot
.884 .22273 Mdot
.884 .22284 Mdot
.884 .22295 Mdot
.884 .22309 Mdot
.884 .22523 Mdot
.884 .22615 Mdot
.884 .22679 Mdot
.884 .22687 Mdot
.884 .22709 Mdot
.884 .22711 Mdot
.884 .22744 Mdot
.884 .22827 Mdot
.884 .22835 Mdot
.884 .23072 Mdot
.884 .23203 Mdot
.884 .23276 Mdot
.884 .2328 Mdot
.884 .23465 Mdot
.884 .2358 Mdot
.884 .23776 Mdot
.884 .23806 Mdot
.884 .23808 Mdot
.884 .23859 Mdot
.884 .24039 Mdot
.884 .24048 Mdot
.884 .2409 Mdot
.884 .24108 Mdot
.884 .24127 Mdot
.884 .24149 Mdot
.884 .24209 Mdot
.884 .24216 Mdot
.884 .24409 Mdot
.884 .24441 Mdot
.884 .24443 Mdot
.884 .24473 Mdot
.884 .24483 Mdot
.884 .24487 Mdot
.884 .24594 Mdot
.884 .24818 Mdot
.884 .24896 Mdot
.884 .25254 Mdot
.884 .25374 Mdot
.884 .25429 Mdot
.884 .25689 Mdot
.884 .25891 Mdot
.884 .25932 Mdot
.884 .26075 Mdot
.884 .26328 Mdot
.884 .26415 Mdot
.884 .26516 Mdot
.884 .27167 Mdot
.884 .27268 Mdot
.884 .27325 Mdot
.884 .27367 Mdot
.884 .2748 Mdot
.884 .27502 Mdot
.884 .2752 Mdot
.884 .27523 Mdot
.884 .27527 Mdot
.884 .27531 Mdot
.884 .27539 Mdot
.884 .27539 Mdot
.884 .27544 Mdot
.884 .27551 Mdot
.884 .27564 Mdot
.884 .27592 Mdot
.884 .27596 Mdot
.884 .27599 Mdot
.884 .27645 Mdot
.884 .27647 Mdot
.884 .27648 Mdot
.884 .27651 Mdot
.884 .27652 Mdot
.884 .27668 Mdot
.884 .27685 Mdot
.884 .27695 Mdot
.884 .27714 Mdot
.884 .27754 Mdot
.884 .27759 Mdot
.884 .27765 Mdot
.884 .27782 Mdot
.884 .27782 Mdot
.884 .278 Mdot
.884 .27803 Mdot
.884 .27819 Mdot
.884 .2782 Mdot
.884 .27821 Mdot
.884 .27859 Mdot
.884 .2789 Mdot
.884 .27904 Mdot
.884 .27917 Mdot
.884 .27919 Mdot
.884 .27923 Mdot
.884 .27955 Mdot
.884 .27961 Mdot
.884 .27965 Mdot
.884 .27974 Mdot
.884 .28011 Mdot
.884 .28013 Mdot
.884 .28021 Mdot
.884 .28027 Mdot
.884 .28028 Mdot
.884 .28069 Mdot
.884 .2808 Mdot
.884 .28083 Mdot
.884 .28113 Mdot
.884 .28135 Mdot
.884 .28219 Mdot
.884 .28224 Mdot
.884 .28266 Mdot
.884 .28326 Mdot
.884 .28348 Mdot
.884 .28368 Mdot
.884 .28389 Mdot
.884 .28496 Mdot
.884 .28545 Mdot
.884 .28552 Mdot
.884 .28567 Mdot
.884 .28577 Mdot
.884 .28676 Mdot
.884 .28683 Mdot
.884 .28686 Mdot
.884 .28722 Mdot
.884 .2873 Mdot
.884 .2874 Mdot
.884 .28762 Mdot
.884 .28764 Mdot
.884 .28853 Mdot
.884 .28869 Mdot
.884 .28895 Mdot
.884 .28908 Mdot
.884 .28912 Mdot
.884 .2894 Mdot
.884 .28977 Mdot
.884 .2898 Mdot
.884 .28981 Mdot
.884 .29023 Mdot
.884 .29041 Mdot
.884 .29087 Mdot
.884 .2911 Mdot
.884 .29135 Mdot
.884 .29138 Mdot
.884 .29145 Mdot
.884 .29156 Mdot
.884 .29162 Mdot
.884 .29198 Mdot
.884 .29203 Mdot
.884 .29214 Mdot
.884 .29246 Mdot
.884 .29275 Mdot
.884 .29276 Mdot
.884 .29309 Mdot
.884 .29346 Mdot
.884 .29354 Mdot
.884 .29366 Mdot
.884 .29377 Mdot
.884 .29381 Mdot
.884 .29383 Mdot
.884 .29388 Mdot
.884 .29394 Mdot
.884 .29406 Mdot
.884 .2941 Mdot
.884 .29419 Mdot
.884 .29427 Mdot
.884 .29429 Mdot
.884 .29431 Mdot
.884 .29433 Mdot
.884 .29436 Mdot
.884 .29493 Mdot
.884 .29505 Mdot
.884 .29506 Mdot
.884 .2951 Mdot
.884 .29511 Mdot
.884 .29517 Mdot
.884 .29532 Mdot
.884 .29576 Mdot
.884 .29599 Mdot
.884 .29612 Mdot
.884 .29645 Mdot
.884 .29665 Mdot
.884 .29699 Mdot
.884 .29705 Mdot
.884 .29705 Mdot
.884 .29714 Mdot
.884 .29745 Mdot
.884 .29746 Mdot
.884 .29754 Mdot
.884 .29757 Mdot
.884 .29764 Mdot
.884 .29774 Mdot
.884 .29775 Mdot
.884 .29808 Mdot
.884 .29814 Mdot
.884 .29814 Mdot
.884 .29819 Mdot
.884 .29821 Mdot
.884 .29821 Mdot
.884 .29878 Mdot
.884 .29891 Mdot
.884 .29973 Mdot
.884 .29982 Mdot
.884 .30027 Mdot
.884 .30062 Mdot
.884 .30069 Mdot
.884 .30094 Mdot
.884 .30139 Mdot
.884 .30154 Mdot
.884 .30172 Mdot
.884 .30292 Mdot
.884 .30311 Mdot
.884 .30322 Mdot
.884 .3033 Mdot
.884 .30351 Mdot
.884 .30356 Mdot
.884 .30359 Mdot
.884 .3036 Mdot
.884 .30361 Mdot
.884 .30361 Mdot
.884 .30363 Mdot
.884 .30363 Mdot
.884 .30364 Mdot
.884 .30365 Mdot
.884 .30368 Mdot
.884 .30373 Mdot
.884 .30374 Mdot
.884 .30375 Mdot
.884 .30384 Mdot
.884 .30384 Mdot
.884 .30384 Mdot
.884 .30385 Mdot
.884 .30385 Mdot
.884 .30388 Mdot
.884 .30392 Mdot
.884 .30394 Mdot
.884 .30397 Mdot
.884 .30405 Mdot
.884 .30406 Mdot
.884 .30407 Mdot
.884 .30411 Mdot
.884 .30411 Mdot
.884 .30414 Mdot
.884 .30415 Mdot
.884 .30418 Mdot
.884 .30419 Mdot
.884 .30419 Mdot
.884 .30426 Mdot
.884 .30433 Mdot
.884 .30436 Mdot
.884 .30438 Mdot
.884 .30439 Mdot
.884 .30439 Mdot
.884 .30446 Mdot
.884 .30447 Mdot
.884 .30448 Mdot
.884 .3045 Mdot
.884 .30457 Mdot
.884 .30458 Mdot
.884 .30459 Mdot
.884 .30461 Mdot
.884 .30461 Mdot
.884 .30469 Mdot
.884 .30472 Mdot
.884 .30472 Mdot
.884 .30479 Mdot
.884 .30483 Mdot
.884 .30501 Mdot
.884 .30502 Mdot
.884 .30511 Mdot
.884 .30528 Mdot
.884 .30533 Mdot
.884 .30537 Mdot
.884 .30561 Mdot
.884 .30572 Mdot
.884 .30577 Mdot
.884 .30579 Mdot
.884 .30601 Mdot
.884 .30603 Mdot
.884 .30612 Mdot
.884 .30613 Mdot
.884 .30616 Mdot
.884 .30621 Mdot
.884 .30621 Mdot
.884 .30642 Mdot
.884 .30646 Mdot
.884 .30655 Mdot
.884 .30656 Mdot
.884 .30663 Mdot
.884 .30672 Mdot
.884 .30672 Mdot
.884 .30673 Mdot
.884 .30683 Mdot
.884 .30688 Mdot
.884 .30699 Mdot
.884 .30705 Mdot
.884 .30711 Mdot
.884 .30712 Mdot
.884 .30713 Mdot
.884 .30716 Mdot
.884 .30717 Mdot
.884 .30728 Mdot
.884 .30731 Mdot
.884 .30739 Mdot
.884 .30746 Mdot
.884 .30747 Mdot
.884 .30755 Mdot
.884 .30765 Mdot
.884 .30767 Mdot
.884 .3077 Mdot
.884 .30775 Mdot
.884 .30776 Mdot
.884 .30778 Mdot
.884 .30781 Mdot
.884 .30782 Mdot
.884 .30785 Mdot
.884 .30787 Mdot
.884 .30788 Mdot
.884 .30788 Mdot
.884 .30789 Mdot
.884 .30805 Mdot
.884 .30808 Mdot
.884 .3081 Mdot
.884 .30811 Mdot
.884 .30815 Mdot
.884 .30828 Mdot
.884 .30838 Mdot
.884 .30848 Mdot
.884 .30863 Mdot
.884 .30865 Mdot
.884 .30867 Mdot
.884 .30877 Mdot
.884 .30877 Mdot
.884 .30879 Mdot
.884 .3088 Mdot
.884 .30885 Mdot
.884 .30886 Mdot
.884 .30897 Mdot
.884 .30899 Mdot
.884 .309 Mdot
.884 .309 Mdot
.884 .30921 Mdot
.884 .30965 Mdot
.884 .30977 Mdot
.884 .30988 Mdot
.884 .31003 Mdot
.884 .31008 Mdot
.884 .31015 Mdot
.884 .31058 Mdot
.884 .31065 Mdot
.884 .31069 Mdot
.884 .31081 Mdot
.884 .31089 Mdot
.884 .31096 Mdot
.884 .31102 Mdot
.884 .31104 Mdot
.884 .31105 Mdot
.884 .31107 Mdot
.884 .31107 Mdot
.884 .3111 Mdot
.884 .31118 Mdot
.884 .31119 Mdot
.884 .3112 Mdot
.884 .31123 Mdot
.884 .31129 Mdot
.884 .31134 Mdot
.884 .31191 Mdot
.884 .31192 Mdot
.884 .31194 Mdot
.884 .31211 Mdot
.884 .31214 Mdot
.884 .31218 Mdot
.884 .31219 Mdot
.884 .31224 Mdot
.884 .31231 Mdot
.884 .31237 Mdot
.884 .31251 Mdot
.884 .31255 Mdot
.884 .31266 Mdot
.884 .31268 Mdot
.884 .3127 Mdot
.884 .31273 Mdot
.884 .31274 Mdot
.884 .31275 Mdot
.884 .31277 Mdot
.884 .31277 Mdot
.884 .31288 Mdot
.884 .31289 Mdot
.884 .3129 Mdot
.884 .31299 Mdot
.884 .3131 Mdot
.884 .3132 Mdot
.884 .31391 Mdot
.884 .31487 Mdot
.884 .31489 Mdot
.884 .31504 Mdot
.884 .31623 Mdot
.884 .31712 Mdot
.884 .31787 Mdot
.884 .31796 Mdot
.884 .31821 Mdot
.884 .31903 Mdot
.884 .32027 Mdot
.884 .32122 Mdot
.884 .3228 Mdot
.884 .32415 Mdot
.884 .32477 Mdot
.884 .32498 Mdot
.884 .32573 Mdot
.884 .3265 Mdot
.884 .32723 Mdot
.884 .32823 Mdot
.884 .3288 Mdot
.884 .33027 Mdot
.884 .33117 Mdot
.884 .33152 Mdot
.884 .3318 Mdot
.884 .33213 Mdot
.884 .33248 Mdot
.884 .33263 Mdot
.884 .33287 Mdot
.884 .3329 Mdot
.884 .33716 Mdot
.884 .33983 Mdot
.884 .34271 Mdot
.884 .34303 Mdot
.884 .34531 Mdot
.884 .34559 Mdot
.884 .3464 Mdot
.884 .34646 Mdot
.884 .34767 Mdot
.884 .35051 Mdot
.884 .35077 Mdot
.884 .35111 Mdot
.884 .36046 Mdot
.884 .36591 Mdot
.884 .36901 Mdot
.884 .3692 Mdot
.884 .37151 Mdot
.884 .37243 Mdot
.884 .3744 Mdot
.884 .37732 Mdot
.884 .38103 Mdot
.884 .38133 Mdot
.884 .38248 Mdot
.884 .38842 Mdot
.884 .39153 Mdot
.884 .39294 Mdot
.884 .39305 Mdot
.884 .39541 Mdot
.884 .40398 Mdot
.884 .40439 Mdot
.884 .4064 Mdot
.884 .40725 Mdot
.884 .40816 Mdot
.884 .40921 Mdot
.884 .41213 Mdot
.884 .41247 Mdot
.884 .42177 Mdot
.884 .42331 Mdot
.884 .42338 Mdot
.884 .42486 Mdot
.884 .42531 Mdot
.884 .42552 Mdot
.884 .43066 Mdot
.884 .4328 Mdot
.884 .43443 Mdot
.884 .44132 Mdot
.884 .44502 Mdot
.884 .44822 Mdot
.884 .45306 Mdot
.884 .45725 Mdot
.884 .46107 Mdot
.884 .46144 Mdot
.884 .4667 Mdot
.884 .46909 Mdot
.884 .46986 Mdot
.884 .47163 Mdot
.884 .47999 Mdot
.884 .48792 Mdot
.884 .48946 Mdot
.884 .49471 Mdot
.884 .50326 Mdot
.884 .5038 Mdot
.884 .50588 Mdot
.884 .50588 Mdot
.884 .50588 Mdot
.884 .50593 Mdot
.884 .50593 Mdot
.884 .50595 Mdot
.884 .50601 Mdot
.884 .50613 Mdot
.884 .50615 Mdot
.884 .50618 Mdot
.884 .50625 Mdot
.884 .50653 Mdot
.884 .50653 Mdot
.884 .50659 Mdot
.884 .50659 Mdot
.884 .50676 Mdot
.884 .50706 Mdot
.884 .50726 Mdot
.884 .50741 Mdot
.884 .50742 Mdot
.884 .50746 Mdot
.884 .50752 Mdot
.884 .50759 Mdot
.884 .50765 Mdot
.884 .50765 Mdot
.884 .50766 Mdot
.884 .50773 Mdot
.884 .50773 Mdot
.884 .50774 Mdot
.884 .50775 Mdot
.884 .50775 Mdot
.884 .50777 Mdot
.884 .50779 Mdot
.884 .5078 Mdot
.884 .50787 Mdot
.884 .5079 Mdot
.884 .50794 Mdot
.884 .50798 Mdot
.884 .508 Mdot
.884 .50804 Mdot
.884 .50809 Mdot
.884 .50813 Mdot
.884 .50813 Mdot
.884 .50816 Mdot
.884 .50818 Mdot
.884 .5083 Mdot
.884 .50832 Mdot
.884 .50833 Mdot
.884 .50847 Mdot
.884 .50877 Mdot
.884 .5088 Mdot
.884 .50885 Mdot
.884 .50888 Mdot
.884 .50888 Mdot
.884 .50889 Mdot
.884 .50889 Mdot
.884 .50895 Mdot
.884 .50898 Mdot
.884 .50898 Mdot
.884 .50899 Mdot
.884 .509 Mdot
.884 .50902 Mdot
.884 .50902 Mdot
.884 .50906 Mdot
.884 .50907 Mdot
.884 .50912 Mdot
.884 .5092 Mdot
.884 .50927 Mdot
.884 .50929 Mdot
.884 .50933 Mdot
.884 .50939 Mdot
.884 .50977 Mdot
.884 .50983 Mdot
.884 .50988 Mdot
.884 .51002 Mdot
.884 .51009 Mdot
.884 .51012 Mdot
.884 .51022 Mdot
.884 .51036 Mdot
.884 .51039 Mdot
.884 .51064 Mdot
.884 .51068 Mdot
.884 .51085 Mdot
.884 .51085 Mdot
.884 .51086 Mdot
.884 .51087 Mdot
.884 .51087 Mdot
.884 .51089 Mdot
.884 .51099 Mdot
.884 .51099 Mdot
.884 .51102 Mdot
.884 .51104 Mdot
.884 .51105 Mdot
.884 .51108 Mdot
.884 .51108 Mdot
.884 .51117 Mdot
.884 .5112 Mdot
.884 .5112 Mdot
.884 .51121 Mdot
.884 .51132 Mdot
.884 .51137 Mdot
.884 .51147 Mdot
.884 .51151 Mdot
.884 .51158 Mdot
.884 .51171 Mdot
.884 .51175 Mdot
.884 .51177 Mdot
.884 .51177 Mdot
.884 .51178 Mdot
.884 .51178 Mdot
.884 .51182 Mdot
.884 .51198 Mdot
.884 .51199 Mdot
.884 .512 Mdot
.884 .512 Mdot
.884 .51201 Mdot
.884 .51203 Mdot
.884 .51206 Mdot
.884 .51207 Mdot
.884 .5121 Mdot
.884 .51212 Mdot
.884 .51213 Mdot
.884 .51214 Mdot
.884 .51215 Mdot
.884 .51218 Mdot
.884 .51222 Mdot
.884 .51224 Mdot
.884 .51234 Mdot
.884 .51244 Mdot
.884 .51244 Mdot
.884 .51252 Mdot
.884 .51261 Mdot
.884 .51264 Mdot
.884 .51266 Mdot
.884 .51276 Mdot
.884 .51277 Mdot
.884 .5128 Mdot
.884 .51282 Mdot
.884 .51283 Mdot
.884 .5129 Mdot
.884 .51296 Mdot
.884 .51309 Mdot
.884 .51314 Mdot
.884 .51325 Mdot
.884 .51326 Mdot
.884 .51327 Mdot
.884 .51337 Mdot
.884 .51344 Mdot
.884 .51345 Mdot
.884 .51349 Mdot
.884 .51356 Mdot
.884 .5136 Mdot
.884 .51384 Mdot
.884 .51385 Mdot
.884 .5139 Mdot
.884 .51393 Mdot
.884 .51395 Mdot
.884 .51405 Mdot
.884 .51406 Mdot
.884 .51408 Mdot
.884 .51434 Mdot
.884 .51436 Mdot
.884 .5144 Mdot
.884 .51442 Mdot
.884 .51455 Mdot
.884 .51483 Mdot
.884 .51488 Mdot
.884 .51493 Mdot
.884 .51499 Mdot
.884 .51514 Mdot
.884 .51525 Mdot
.884 .51527 Mdot
.884 .51548 Mdot
.884 .51554 Mdot
.884 .51561 Mdot
.884 .51562 Mdot
.884 .51565 Mdot
.884 .51575 Mdot
.884 .51575 Mdot
.884 .51577 Mdot
.884 .51579 Mdot
.884 .51579 Mdot
.884 .51589 Mdot
.884 .51591 Mdot
.884 .51592 Mdot
.884 .51593 Mdot
.884 .51601 Mdot
.884 .51602 Mdot
.884 .51603 Mdot
.884 .51606 Mdot
.884 .5161 Mdot
.884 .51617 Mdot
.884 .51627 Mdot
.884 .51627 Mdot
.884 .51627 Mdot
.884 .51631 Mdot
.884 .51632 Mdot
.884 .51636 Mdot
.884 .51637 Mdot
.884 .51641 Mdot
.884 .51642 Mdot
.884 .51643 Mdot
.884 .51653 Mdot
.884 .51658 Mdot
.884 .51661 Mdot
.884 .51665 Mdot
.884 .51669 Mdot
.884 .51669 Mdot
.884 .5167 Mdot
.884 .5167 Mdot
.884 .5167 Mdot
.884 .51681 Mdot
.884 .51682 Mdot
.884 .51683 Mdot
.884 .5169 Mdot
.884 .51693 Mdot
.884 .51695 Mdot
.884 .51696 Mdot
.884 .51696 Mdot
.884 .51698 Mdot
.884 .51699 Mdot
.884 .517 Mdot
.884 .51701 Mdot
.884 .51705 Mdot
.884 .51711 Mdot
.884 .51738 Mdot
.884 .51748 Mdot
.884 .51762 Mdot
.884 .51786 Mdot
.884 .51938 Mdot
.884 .51961 Mdot
.884 .51981 Mdot
.884 .52038 Mdot
.884 .52071 Mdot
.884 .5208 Mdot
.884 .52125 Mdot
.884 .52183 Mdot
.884 .52195 Mdot
.884 .52221 Mdot
.884 .52299 Mdot
.884 .52316 Mdot
.884 .52364 Mdot
.884 .52387 Mdot
.884 .52388 Mdot
.884 .5239 Mdot
.884 .52396 Mdot
.884 .52397 Mdot
.884 .52404 Mdot
.884 .52445 Mdot
.884 .52446 Mdot
.884 .52459 Mdot
.884 .52464 Mdot
.884 .52468 Mdot
.884 .52472 Mdot
.884 .5248 Mdot
.884 .52482 Mdot
.884 .52521 Mdot
.884 .52531 Mdot
.884 .52532 Mdot
.884 .52538 Mdot
.884 .52579 Mdot
.884 .52603 Mdot
.884 .52642 Mdot
.884 .52643 Mdot
.884 .52658 Mdot
.884 .52686 Mdot
.884 .52735 Mdot
.884 .52737 Mdot
.884 .52754 Mdot
.884 .52761 Mdot
.884 .52761 Mdot
.884 .52766 Mdot
.884 .52768 Mdot
.884 .52781 Mdot
.884 .528 Mdot
.884 .52845 Mdot
.884 .52848 Mdot
.884 .5285 Mdot
.884 .52852 Mdot
.884 .52854 Mdot
.884 .52863 Mdot
.884 .52873 Mdot
.884 .52877 Mdot
.884 .5289 Mdot
.884 .52896 Mdot
.884 .52902 Mdot
.884 .52904 Mdot
.884 .52909 Mdot
.884 .52919 Mdot
.884 .52933 Mdot
.884 .52941 Mdot
.884 .52962 Mdot
.884 .52979 Mdot
.884 .52992 Mdot
.884 .52993 Mdot
.884 .53012 Mdot
.884 .53013 Mdot
.884 .53015 Mdot
.884 .53019 Mdot
.884 .53023 Mdot
.884 .53028 Mdot
.884 .53038 Mdot
.884 .53039 Mdot
.884 .53041 Mdot
.884 .53044 Mdot
.884 .53053 Mdot
.884 .53069 Mdot
.884 .53072 Mdot
.884 .53083 Mdot
.884 .53087 Mdot
.884 .53102 Mdot
.884 .53106 Mdot
.884 .5311 Mdot
.884 .53121 Mdot
.884 .53125 Mdot
.884 .53136 Mdot
.884 .53142 Mdot
.884 .53144 Mdot
.884 .53153 Mdot
.884 .5316 Mdot
.884 .53162 Mdot
.884 .53163 Mdot
.884 .53166 Mdot
.884 .53166 Mdot
.884 .53167 Mdot
.884 .53184 Mdot
.884 .53186 Mdot
.884 .53201 Mdot
.884 .53211 Mdot
.884 .53223 Mdot
.884 .53229 Mdot
.884 .53238 Mdot
.884 .53265 Mdot
.884 .53266 Mdot
.884 .53267 Mdot
.884 .5327 Mdot
.884 .53271 Mdot
.884 .53271 Mdot
.884 .53273 Mdot
.884 .53276 Mdot
.884 .53282 Mdot
.884 .5329 Mdot
.884 .53291 Mdot
.884 .53291 Mdot
.884 .533 Mdot
.884 .53305 Mdot
.884 .53308 Mdot
.884 .53319 Mdot
.884 .5332 Mdot
.884 .53322 Mdot
.884 .53322 Mdot
.884 .53322 Mdot
.884 .53331 Mdot
.884 .53347 Mdot
.884 .5335 Mdot
.884 .53358 Mdot
.884 .53372 Mdot
.884 .53382 Mdot
.884 .5339 Mdot
.884 .53391 Mdot
.884 .53393 Mdot
.884 .53408 Mdot
.884 .53409 Mdot
.884 .53412 Mdot
.884 .53416 Mdot
.884 .53418 Mdot
.884 .5342 Mdot
.884 .53423 Mdot
.884 .53423 Mdot
.884 .53425 Mdot
.884 .53429 Mdot
.884 .53442 Mdot
.884 .53443 Mdot
.884 .53446 Mdot
.884 .53447 Mdot
.884 .53447 Mdot
.884 .5345 Mdot
.884 .5345 Mdot
.884 .5345 Mdot
.884 .53463 Mdot
.884 .53468 Mdot
.884 .53472 Mdot
.884 .53473 Mdot
.884 .53483 Mdot
.884 .53486 Mdot
.884 .53489 Mdot
.884 .5349 Mdot
.884 .53493 Mdot
.884 .53495 Mdot
.884 .53496 Mdot
.884 .53506 Mdot
.884 .5351 Mdot
.884 .53511 Mdot
.884 .53514 Mdot
.884 .53517 Mdot
.884 .5352 Mdot
.884 .53521 Mdot
.884 .53521 Mdot
.884 .53521 Mdot
.886 .18562 Mdot
.886 .1857 Mdot
.886 .18575 Mdot
.886 .18575 Mdot
.886 .18598 Mdot
.886 .1861 Mdot
.886 .18619 Mdot
.886 .18627 Mdot
.886 .18637 Mdot
.886 .1867 Mdot
.886 .18671 Mdot
.886 .18688 Mdot
.886 .18699 Mdot
.886 .18702 Mdot
.886 .18709 Mdot
.886 .18711 Mdot
.886 .18711 Mdot
.886 .18718 Mdot
.886 .18733 Mdot
.886 .18791 Mdot
.886 .18811 Mdot
.886 .18864 Mdot
.886 .18969 Mdot
.886 .1906 Mdot
.886 .19148 Mdot
.886 .19238 Mdot
.886 .19362 Mdot
.886 .19411 Mdot
.886 .1944 Mdot
.886 .19441 Mdot
.886 .19473 Mdot
.886 .19537 Mdot
.886 .1957 Mdot
.886 .19593 Mdot
.886 .19616 Mdot
.886 .19636 Mdot
.886 .19658 Mdot
.886 .19686 Mdot
.886 .19765 Mdot
.886 .19775 Mdot
.886 .1979 Mdot
.886 .19809 Mdot
.886 .19874 Mdot
.886 .19894 Mdot
.886 .199 Mdot
.886 .19902 Mdot
.886 .19992 Mdot
.886 .20008 Mdot
.886 .20022 Mdot
.886 .20048 Mdot
.886 .20074 Mdot
.886 .20188 Mdot
.886 .20204 Mdot
.886 .20244 Mdot
.886 .20247 Mdot
.886 .20262 Mdot
.886 .20311 Mdot
.886 .20397 Mdot
.886 .20494 Mdot
.886 .20531 Mdot
.886 .20776 Mdot
.886 .20847 Mdot
.886 .20851 Mdot
.886 .20868 Mdot
.886 .20965 Mdot
.886 .20996 Mdot
.886 .21038 Mdot
.886 .21062 Mdot
.886 .21188 Mdot
.886 .21222 Mdot
.886 .21243 Mdot
.886 .21277 Mdot
.886 .21317 Mdot
.886 .21319 Mdot
.886 .2133 Mdot
.886 .21392 Mdot
.886 .21521 Mdot
.886 .21528 Mdot
.886 .21528 Mdot
.886 .21541 Mdot
.886 .21566 Mdot
.886 .21579 Mdot
.886 .21594 Mdot
.886 .21605 Mdot
.886 .21617 Mdot
.886 .21617 Mdot
.886 .21654 Mdot
.886 .2166 Mdot
.886 .21665 Mdot
.886 .21846 Mdot
.886 .21987 Mdot
.886 .22097 Mdot
.886 .2219 Mdot
.886 .22245 Mdot
.886 .22351 Mdot
.886 .22408 Mdot
.886 .22461 Mdot
.886 .22541 Mdot
.886 .22548 Mdot
.886 .22789 Mdot
.886 .22807 Mdot
.886 .22808 Mdot
.886 .2287 Mdot
.886 .23028 Mdot
.886 .23248 Mdot
.886 .23255 Mdot
.886 .23354 Mdot
.886 .23472 Mdot
.886 .23527 Mdot
.886 .23556 Mdot
.886 .2361 Mdot
.886 .23623 Mdot
.886 .23634 Mdot
.886 .23636 Mdot
.886 .23747 Mdot
.886 .23754 Mdot
.886 .23888 Mdot
.886 .2395 Mdot
.886 .24112 Mdot
.886 .24126 Mdot
.886 .24165 Mdot
.886 .2425 Mdot
.886 .24275 Mdot
.886 .2429 Mdot
.886 .24346 Mdot
.886 .2435 Mdot
.886 .24383 Mdot
.886 .24444 Mdot
.886 .24497 Mdot
.886 .24508 Mdot
.886 .24569 Mdot
.886 .24588 Mdot
.886 .24601 Mdot
.886 .24611 Mdot
.886 .24628 Mdot
.886 .24678 Mdot
.886 .24711 Mdot
.886 .24745 Mdot
.886 .24801 Mdot
.886 .24814 Mdot
.886 .24824 Mdot
.886 .24824 Mdot
.886 .24827 Mdot
.886 .24883 Mdot
.886 .24945 Mdot
.886 .24952 Mdot
.886 .24982 Mdot
.886 .25032 Mdot
.886 .25034 Mdot
.886 .25079 Mdot
.886 .25086 Mdot
.886 .25091 Mdot
.886 .25094 Mdot
.886 .25101 Mdot
.886 .25102 Mdot
.886 .25106 Mdot
.886 .25114 Mdot
.886 .25117 Mdot
.886 .25117 Mdot
.886 .25453 Mdot
.886 .25459 Mdot
.886 .25566 Mdot
.886 .25597 Mdot
.886 .25738 Mdot
.886 .25861 Mdot
.886 .26231 Mdot
.886 .26295 Mdot
.886 .26444 Mdot
.886 .26807 Mdot
.886 .27099 Mdot
.886 .27154 Mdot
.886 .27167 Mdot
.886 .27167 Mdot
.886 .27264 Mdot
.886 .27416 Mdot
.886 .27421 Mdot
.886 .27421 Mdot
.886 .27423 Mdot
.886 .27425 Mdot
.886 .27427 Mdot
.886 .27429 Mdot
.886 .27433 Mdot
.886 .27434 Mdot
.886 .27434 Mdot
.886 .27435 Mdot
.886 .27455 Mdot
.886 .27464 Mdot
.886 .27466 Mdot
.886 .27466 Mdot
.886 .27472 Mdot
.886 .27477 Mdot
.886 .2748 Mdot
.886 .27509 Mdot
.886 .27521 Mdot
.886 .27537 Mdot
.886 .27541 Mdot
.886 .27637 Mdot
.886 .27685 Mdot
.886 .27696 Mdot
.886 .27699 Mdot
.886 .27722 Mdot
.886 .27751 Mdot
.886 .27772 Mdot
.886 .27802 Mdot
.886 .27828 Mdot
.886 .27837 Mdot
.886 .27837 Mdot
.886 .27859 Mdot
.886 .27897 Mdot
.886 .27995 Mdot
.886 .28127 Mdot
.886 .28132 Mdot
.886 .2814 Mdot
.886 .28149 Mdot
.886 .28162 Mdot
.886 .28204 Mdot
.886 .28213 Mdot
.886 .28224 Mdot
.886 .28282 Mdot
.886 .28283 Mdot
.886 .28347 Mdot
.886 .28393 Mdot
.886 .28452 Mdot
.886 .285 Mdot
.886 .28531 Mdot
.886 .28565 Mdot
.886 .28581 Mdot
.886 .28618 Mdot
.886 .2863 Mdot
.886 .28751 Mdot
.886 .28787 Mdot
.886 .2888 Mdot
.886 .2892 Mdot
.886 .28944 Mdot
.886 .2895 Mdot
.886 .28956 Mdot
.886 .28987 Mdot
.886 .28999 Mdot
.886 .29016 Mdot
.886 .29022 Mdot
.886 .29048 Mdot
.886 .29062 Mdot
.886 .29101 Mdot
.886 .29111 Mdot
.886 .29111 Mdot
.886 .29115 Mdot
.886 .29147 Mdot
.886 .29169 Mdot
.886 .29178 Mdot
.886 .29232 Mdot
.886 .29278 Mdot
.886 .29292 Mdot
.886 .29318 Mdot
.886 .2941 Mdot
.886 .29446 Mdot
.886 .29509 Mdot
.886 .29519 Mdot
.886 .29538 Mdot
.886 .29548 Mdot
.886 .29572 Mdot
.886 .29616 Mdot
.886 .29619 Mdot
.886 .2963 Mdot
.886 .29657 Mdot
.886 .29695 Mdot
.886 .29696 Mdot
.886 .29713 Mdot
.886 .29733 Mdot
.886 .29742 Mdot
.886 .29747 Mdot
.886 .29756 Mdot
.886 .29759 Mdot
.886 .29779 Mdot
.886 .29803 Mdot
.886 .29814 Mdot
.886 .29841 Mdot
.886 .29843 Mdot
.886 .2985 Mdot
.886 .29868 Mdot
.886 .29871 Mdot
.886 .2988 Mdot
.886 .29881 Mdot
.886 .29886 Mdot
.886 .29896 Mdot
.886 .29905 Mdot
.886 .29907 Mdot
.886 .29917 Mdot
.886 .2992 Mdot
.886 .29923 Mdot
.886 .29924 Mdot
.886 .29927 Mdot
.886 .29935 Mdot
.886 .29947 Mdot
.886 .29956 Mdot
.886 .29958 Mdot
.886 .2996 Mdot
.886 .2996 Mdot
.886 .29961 Mdot
.886 .2997 Mdot
.886 .2998 Mdot
.886 .29982 Mdot
.886 .29987 Mdot
.886 .29995 Mdot
.886 .29995 Mdot
.886 .30003 Mdot
.886 .30004 Mdot
.886 .30005 Mdot
.886 .30005 Mdot
.886 .30007 Mdot
.886 .30007 Mdot
.886 .30007 Mdot
.886 .30009 Mdot
.886 .30009 Mdot
.886 .30009 Mdot
.886 .30066 Mdot
.886 .30067 Mdot
.886 .30086 Mdot
.886 .30091 Mdot
.886 .30115 Mdot
.886 .30136 Mdot
.886 .30201 Mdot
.886 .30212 Mdot
.886 .30238 Mdot
.886 .30358 Mdot
.886 .30369 Mdot
.886 .3039 Mdot
.886 .30419 Mdot
.886 .3042 Mdot
.886 .3042 Mdot
.886 .3042 Mdot
.886 .30421 Mdot
.886 .30421 Mdot
.886 .30421 Mdot
.886 .30422 Mdot
.886 .30422 Mdot
.886 .30423 Mdot
.886 .30426 Mdot
.886 .30428 Mdot
.886 .30429 Mdot
.886 .30429 Mdot
.886 .3043 Mdot
.886 .30431 Mdot
.886 .30431 Mdot
.886 .30437 Mdot
.886 .30439 Mdot
.886 .30443 Mdot
.886 .30443 Mdot
.886 .30462 Mdot
.886 .30472 Mdot
.886 .30474 Mdot
.886 .30475 Mdot
.886 .30479 Mdot
.886 .3049 Mdot
.886 .30501 Mdot
.886 .30503 Mdot
.886 .30507 Mdot
.886 .30515 Mdot
.886 .30535 Mdot
.886 .30563 Mdot
.886 .30564 Mdot
.886 .30568 Mdot
.886 .3058 Mdot
.886 .30581 Mdot
.886 .30584 Mdot
.886 .30597 Mdot
.886 .30597 Mdot
.886 .30611 Mdot
.886 .30621 Mdot
.886 .30634 Mdot
.886 .30645 Mdot
.886 .30652 Mdot
.886 .30672 Mdot
.886 .30675 Mdot
.886 .30703 Mdot
.886 .30712 Mdot
.886 .30735 Mdot
.886 .30744 Mdot
.886 .3075 Mdot
.886 .30752 Mdot
.886 .30753 Mdot
.886 .30764 Mdot
.886 .30768 Mdot
.886 .3077 Mdot
.886 .30776 Mdot
.886 .3078 Mdot
.886 .3079 Mdot
.886 .30793 Mdot
.886 .30793 Mdot
.886 .3081 Mdot
.886 .30824 Mdot
.886 .30837 Mdot
.886 .30841 Mdot
.886 .30883 Mdot
.886 .30902 Mdot
.886 .30905 Mdot
.886 .3091 Mdot
.886 .30913 Mdot
.886 .3092 Mdot
.886 .30933 Mdot
.886 .30934 Mdot
.886 .30937 Mdot
.886 .30957 Mdot
.886 .30958 Mdot
.886 .30963 Mdot
.886 .30969 Mdot
.886 .30972 Mdot
.886 .30974 Mdot
.886 .30977 Mdot
.886 .30978 Mdot
.886 .30984 Mdot
.886 .30992 Mdot
.886 .30995 Mdot
.886 .31007 Mdot
.886 .31013 Mdot
.886 .31014 Mdot
.886 .31017 Mdot
.886 .31017 Mdot
.886 .31019 Mdot
.886 .31023 Mdot
.886 .31026 Mdot
.886 .3103 Mdot
.886 .31031 Mdot
.886 .31032 Mdot
.886 .31032 Mdot
.886 .31033 Mdot
.886 .31036 Mdot
.886 .3104 Mdot
.886 .31043 Mdot
.886 .31044 Mdot
.886 .31044 Mdot
.886 .31044 Mdot
.886 .31045 Mdot
.886 .31048 Mdot
.886 .31052 Mdot
.886 .31052 Mdot
.886 .31054 Mdot
.886 .31057 Mdot
.886 .31057 Mdot
.886 .3106 Mdot
.886 .3106 Mdot
.886 .3106 Mdot
.886 .3106 Mdot
.886 .31061 Mdot
.886 .31061 Mdot
.886 .31061 Mdot
.886 .31062 Mdot
.886 .31062 Mdot
.886 .31062 Mdot
.886 .31089 Mdot
.886 .31091 Mdot
.886 .31108 Mdot
.886 .31138 Mdot
.886 .31148 Mdot
.886 .31203 Mdot
.886 .31252 Mdot
.886 .31357 Mdot
.886 .31424 Mdot
.886 .31435 Mdot
.886 .31435 Mdot
.886 .31459 Mdot
.886 .31468 Mdot
.886 .31507 Mdot
.886 .31531 Mdot
.886 .31559 Mdot
.886 .31581 Mdot
.886 .31598 Mdot
.886 .316 Mdot
.886 .31604 Mdot
.886 .31605 Mdot
.886 .31624 Mdot
.886 .31629 Mdot
.886 .31667 Mdot
.886 .31679 Mdot
.886 .31691 Mdot
.886 .31692 Mdot
.886 .31701 Mdot
.886 .31718 Mdot
.886 .31722 Mdot
.886 .31753 Mdot
.886 .31767 Mdot
.886 .31786 Mdot
.886 .31795 Mdot
.886 .31796 Mdot
.886 .31799 Mdot
.886 .31806 Mdot
.886 .31811 Mdot
.886 .31825 Mdot
.886 .31847 Mdot
.886 .31848 Mdot
.886 .31854 Mdot
.886 .31891 Mdot
.886 .31904 Mdot
.886 .31914 Mdot
.886 .31914 Mdot
.886 .31926 Mdot
.886 .31941 Mdot
.886 .31961 Mdot
.886 .31971 Mdot
.886 .31971 Mdot
.886 .31978 Mdot
.886 .31987 Mdot
.886 .32101 Mdot
.886 .32334 Mdot
.886 .3238 Mdot
.886 .32447 Mdot
.886 .32489 Mdot
.886 .32489 Mdot
.886 .32743 Mdot
.886 .32929 Mdot
.886 .32934 Mdot
.886 .33004 Mdot
.886 .33071 Mdot
.886 .33168 Mdot
.886 .33209 Mdot
.886 .33286 Mdot
.886 .33333 Mdot
.886 .33351 Mdot
.886 .33411 Mdot
.886 .33494 Mdot
.886 .33676 Mdot
.886 .33799 Mdot
.886 .33849 Mdot
.886 .34119 Mdot
.886 .34141 Mdot
.886 .34198 Mdot
.886 .3448 Mdot
.886 .3466 Mdot
.886 .34881 Mdot
.886 .35012 Mdot
.886 .35078 Mdot
.886 .35084 Mdot
.886 .35226 Mdot
.886 .3532 Mdot
.886 .35945 Mdot
.886 .36414 Mdot
.886 .36638 Mdot
.886 .36862 Mdot
.886 .36892 Mdot
.886 .37323 Mdot
.886 .37748 Mdot
.886 .37843 Mdot
.886 .3809 Mdot
.886 .38224 Mdot
.886 .38471 Mdot
.886 .38531 Mdot
.886 .38578 Mdot
.886 .38589 Mdot
.886 .39044 Mdot
.886 .39079 Mdot
.886 .39104 Mdot
.886 .39135 Mdot
.886 .39763 Mdot
.886 .39849 Mdot
.886 .39941 Mdot
.886 .4006 Mdot
.886 .40832 Mdot
.886 .40846 Mdot
.886 .409 Mdot
.886 .41091 Mdot
.886 .41233 Mdot
.886 .41501 Mdot
.886 .41579 Mdot
.886 .41619 Mdot
.886 .41691 Mdot
.886 .41771 Mdot
.886 .41961 Mdot
.886 .4198 Mdot
.886 .42144 Mdot
.886 .42151 Mdot
.886 .42435 Mdot
.886 .42691 Mdot
.886 .42744 Mdot
.886 .4304 Mdot
.886 .43132 Mdot
.886 .43192 Mdot
.886 .43242 Mdot
.886 .43321 Mdot
.886 .4344 Mdot
.886 .43561 Mdot
.886 .4372 Mdot
.886 .43883 Mdot
.886 .44121 Mdot
.886 .44148 Mdot
.886 .44212 Mdot
.886 .44256 Mdot
.886 .44259 Mdot
.886 .44272 Mdot
.886 .44536 Mdot
.886 .44828 Mdot
.886 .44999 Mdot
.886 .45018 Mdot
.886 .45235 Mdot
.886 .4524 Mdot
.886 .45266 Mdot
.886 .45331 Mdot
.886 .4545 Mdot
.886 .4548 Mdot
.886 .45504 Mdot
.886 .45516 Mdot
.886 .45551 Mdot
.886 .45557 Mdot
.886 .45572 Mdot
.886 .45609 Mdot
.886 .45622 Mdot
.886 .45624 Mdot
.886 .47118 Mdot
.886 .47141 Mdot
.886 .47597 Mdot
.886 .47726 Mdot
.886 .483 Mdot
.886 .48648 Mdot
.886 .48782 Mdot
.886 .49102 Mdot
.886 .49442 Mdot
.886 .49747 Mdot
.886 .50119 Mdot
.886 .50331 Mdot
.886 .50699 Mdot
.886 .50699 Mdot
.886 .50699 Mdot
.886 .50699 Mdot
.886 .50699 Mdot
.886 .50699 Mdot
.886 .50699 Mdot
.886 .50699 Mdot
.886 .507 Mdot
.886 .507 Mdot
.886 .50701 Mdot
.886 .50701 Mdot
.886 .50702 Mdot
.886 .50702 Mdot
.886 .50703 Mdot
.886 .50704 Mdot
.886 .50705 Mdot
.886 .50705 Mdot
.886 .50705 Mdot
.886 .50706 Mdot
.886 .50707 Mdot
.886 .50708 Mdot
.886 .50709 Mdot
.886 .5071 Mdot
.886 .5071 Mdot
.886 .50711 Mdot
.886 .50712 Mdot
.886 .50713 Mdot
.886 .50714 Mdot
.886 .50715 Mdot
.886 .50715 Mdot
.886 .50716 Mdot
.886 .50719 Mdot
.886 .50723 Mdot
.886 .50724 Mdot
.886 .50729 Mdot
.886 .5073 Mdot
.886 .50731 Mdot
.886 .50731 Mdot
.886 .50732 Mdot
.886 .50736 Mdot
.886 .50744 Mdot
.886 .5075 Mdot
.886 .50753 Mdot
.886 .50755 Mdot
.886 .50763 Mdot
.886 .50779 Mdot
.886 .50783 Mdot
.886 .50794 Mdot
.886 .50794 Mdot
.886 .50799 Mdot
.886 .508 Mdot
.886 .50808 Mdot
.886 .50809 Mdot
.886 .50835 Mdot
.886 .50892 Mdot
.886 .50901 Mdot
.886 .50919 Mdot
.886 .50929 Mdot
.886 .50935 Mdot
.886 .50939 Mdot
.886 .50977 Mdot
.886 .50985 Mdot
.886 .50989 Mdot
.886 .51009 Mdot
.886 .51015 Mdot
.886 .51023 Mdot
.886 .51024 Mdot
.886 .5103 Mdot
.886 .5103 Mdot
.886 .51048 Mdot
.886 .51048 Mdot
.886 .51048 Mdot
.886 .51048 Mdot
.886 .51048 Mdot
.886 .51048 Mdot
.886 .51049 Mdot
.886 .51049 Mdot
.886 .51049 Mdot
.886 .5105 Mdot
.886 .51052 Mdot
.886 .51052 Mdot
.886 .51055 Mdot
.886 .51056 Mdot
.886 .51056 Mdot
.886 .5106 Mdot
.886 .51063 Mdot
.886 .51063 Mdot
.886 .51063 Mdot
.886 .51063 Mdot
.886 .51064 Mdot
.886 .51067 Mdot
.886 .5107 Mdot
.886 .51073 Mdot
.886 .51073 Mdot
.886 .51074 Mdot
.886 .51075 Mdot
.886 .51076 Mdot
.886 .51079 Mdot
.886 .51079 Mdot
.886 .51082 Mdot
.886 .51085 Mdot
.886 .51087 Mdot
.886 .51087 Mdot
.886 .5109 Mdot
.886 .5109 Mdot
.886 .51096 Mdot
.886 .51098 Mdot
.886 .51099 Mdot
.886 .51107 Mdot
.886 .5111 Mdot
.886 .51117 Mdot
.886 .51123 Mdot
.886 .51124 Mdot
.886 .51126 Mdot
.886 .51128 Mdot
.886 .5113 Mdot
.886 .51136 Mdot
.886 .51141 Mdot
.886 .51142 Mdot
.886 .51153 Mdot
.886 .51161 Mdot
.886 .51164 Mdot
.886 .51165 Mdot
.886 .51177 Mdot
.886 .51184 Mdot
.886 .51187 Mdot
.886 .51193 Mdot
.886 .51195 Mdot
.886 .51213 Mdot
.886 .51223 Mdot
.886 .5125 Mdot
.886 .51257 Mdot
.886 .51261 Mdot
.886 .51274 Mdot
.886 .51289 Mdot
.886 .51291 Mdot
.886 .51297 Mdot
.886 .51306 Mdot
.886 .51307 Mdot
.886 .51307 Mdot
.886 .5131 Mdot
.886 .5132 Mdot
.886 .51324 Mdot
.886 .51331 Mdot
.886 .51333 Mdot
.886 .51337 Mdot
.886 .51341 Mdot
.886 .51349 Mdot
.886 .51351 Mdot
.886 .51352 Mdot
.886 .51359 Mdot
.886 .5137 Mdot
.886 .51395 Mdot
.886 .51404 Mdot
.886 .51436 Mdot
.886 .51439 Mdot
.886 .51449 Mdot
.886 .51453 Mdot
.886 .51462 Mdot
.886 .5147 Mdot
.886 .51482 Mdot
.886 .51497 Mdot
.886 .51509 Mdot
.886 .51526 Mdot
.886 .51526 Mdot
.886 .51541 Mdot
.886 .51544 Mdot
.886 .51546 Mdot
.886 .51556 Mdot
.886 .5156 Mdot
.886 .51562 Mdot
.886 .51564 Mdot
.886 .51565 Mdot
.886 .51598 Mdot
.886 .51623 Mdot
.886 .51632 Mdot
.886 .51638 Mdot
.886 .51638 Mdot
.886 .5164 Mdot
.886 .51646 Mdot
.886 .51654 Mdot
.886 .51659 Mdot
.886 .51666 Mdot
.886 .51672 Mdot
.886 .51672 Mdot
.886 .51675 Mdot
.886 .51687 Mdot
.886 .5171 Mdot
.886 .51711 Mdot
.886 .51715 Mdot
.886 .51718 Mdot
.886 .51725 Mdot
.886 .51725 Mdot
.886 .51727 Mdot
.886 .51728 Mdot
.886 .51728 Mdot
.886 .51729 Mdot
.886 .51731 Mdot
.886 .51735 Mdot
.886 .51736 Mdot
.886 .51736 Mdot
.886 .51736 Mdot
.886 .51737 Mdot
.886 .51738 Mdot
.886 .51738 Mdot
.886 .51738 Mdot
.886 .51739 Mdot
.886 .51739 Mdot
.886 .5174 Mdot
.886 .51776 Mdot
.886 .51799 Mdot
.886 .518 Mdot
.886 .51803 Mdot
.886 .51815 Mdot
.886 .51884 Mdot
.886 .51968 Mdot
.886 .52001 Mdot
.886 .52016 Mdot
.886 .52099 Mdot
.886 .52126 Mdot
.886 .52157 Mdot
.886 .52164 Mdot
.886 .52188 Mdot
.886 .52189 Mdot
.886 .52262 Mdot
.886 .52262 Mdot
.886 .52263 Mdot
.886 .52265 Mdot
.886 .52266 Mdot
.886 .52266 Mdot
.886 .52267 Mdot
.886 .52268 Mdot
.886 .52269 Mdot
.886 .52271 Mdot
.886 .5228 Mdot
.886 .52281 Mdot
.886 .52292 Mdot
.886 .52298 Mdot
.886 .523 Mdot
.886 .52313 Mdot
.886 .52325 Mdot
.886 .52326 Mdot
.886 .52326 Mdot
.886 .52328 Mdot
.886 .52331 Mdot
.886 .52343 Mdot
.886 .5235 Mdot
.886 .52357 Mdot
.886 .52368 Mdot
.886 .52371 Mdot
.886 .52374 Mdot
.886 .52376 Mdot
.886 .5238 Mdot
.886 .52394 Mdot
.886 .52396 Mdot
.886 .52407 Mdot
.886 .5242 Mdot
.886 .52427 Mdot
.886 .52428 Mdot
.886 .5244 Mdot
.886 .52443 Mdot
.886 .52448 Mdot
.886 .52466 Mdot
.886 .52475 Mdot
.886 .52478 Mdot
.886 .52512 Mdot
.886 .52525 Mdot
.886 .52553 Mdot
.886 .52555 Mdot
.886 .52578 Mdot
.886 .52579 Mdot
.886 .52581 Mdot
.886 .52583 Mdot
.886 .52595 Mdot
.886 .52601 Mdot
.886 .52613 Mdot
.886 .52637 Mdot
.886 .52658 Mdot
.886 .52659 Mdot
.886 .52705 Mdot
.886 .52738 Mdot
.886 .52751 Mdot
.886 .52751 Mdot
.886 .52755 Mdot
.886 .52805 Mdot
.886 .52806 Mdot
.886 .52823 Mdot
.886 .52834 Mdot
.886 .52846 Mdot
.886 .52868 Mdot
.886 .52879 Mdot
.886 .52898 Mdot
.886 .52921 Mdot
.886 .5295 Mdot
.886 .52988 Mdot
.886 .52989 Mdot
.886 .5299 Mdot
.886 .52998 Mdot
.886 .52998 Mdot
.886 .53 Mdot
.886 .53003 Mdot
.886 .53005 Mdot
.886 .53008 Mdot
.886 .53013 Mdot
.886 .53016 Mdot
.886 .53016 Mdot
.886 .53017 Mdot
.886 .53044 Mdot
.886 .53057 Mdot
.886 .53059 Mdot
.886 .5306 Mdot
.886 .53068 Mdot
.886 .53075 Mdot
.886 .53079 Mdot
.886 .53086 Mdot
.886 .53113 Mdot
.886 .53117 Mdot
.886 .53126 Mdot
.886 .53133 Mdot
.886 .53153 Mdot
.886 .53156 Mdot
.886 .53157 Mdot
.886 .53172 Mdot
.886 .53223 Mdot
.886 .53231 Mdot
.886 .53251 Mdot
.886 .53269 Mdot
.886 .53279 Mdot
.886 .53282 Mdot
.886 .53283 Mdot
.886 .53291 Mdot
.886 .53294 Mdot
.886 .53318 Mdot
.886 .53324 Mdot
.886 .53329 Mdot
.886 .53332 Mdot
.886 .53335 Mdot
.886 .53354 Mdot
.886 .53355 Mdot
.886 .53356 Mdot
.886 .5336 Mdot
.886 .53374 Mdot
.886 .53378 Mdot
.886 .53381 Mdot
.886 .53383 Mdot
.886 .534 Mdot
.886 .53405 Mdot
.886 .5341 Mdot
.886 .53414 Mdot
.886 .53419 Mdot
.886 .53424 Mdot
.886 .53431 Mdot
.886 .53445 Mdot
.886 .53451 Mdot
.886 .53452 Mdot
.886 .53458 Mdot
.886 .53468 Mdot
.886 .53494 Mdot
.886 .53514 Mdot
.886 .53532 Mdot
.886 .53552 Mdot
.886 .53574 Mdot
.886 .53586 Mdot
.886 .5359 Mdot
.886 .53602 Mdot
.886 .53605 Mdot
.886 .53607 Mdot
.886 .53607 Mdot
.886 .53608 Mdot
.886 .53609 Mdot
.886 .5361 Mdot
.886 .53612 Mdot
.886 .53616 Mdot
.886 .53616 Mdot
.886 .53623 Mdot
.886 .53625 Mdot
.886 .53627 Mdot
.886 .53629 Mdot
.886 .53631 Mdot
.886 .53636 Mdot
.886 .53636 Mdot
.886 .53637 Mdot
.886 .53639 Mdot
.888 .18752 Mdot
.888 .18767 Mdot
.888 .2883 Mdot
.888 .28835 Mdot
.888 .30812 Mdot
.888 .30813 Mdot
.888 .31791 Mdot
.888 .31811 Mdot
.888 .5081 Mdot
.888 .5081 Mdot
.888 .51398 Mdot
.888 .514 Mdot
.888 .53603 Mdot
.888 .53607 Mdot
.89 .17563 Mdot
.89 .17564 Mdot
.89 .17564 Mdot
.89 .17565 Mdot
.89 .17566 Mdot
.89 .17566 Mdot
.89 .17567 Mdot
.89 .17568 Mdot
.89 .17569 Mdot
.89 .17571 Mdot
.89 .17572 Mdot
.89 .17573 Mdot
.89 .17575 Mdot
.89 .17576 Mdot
.89 .17579 Mdot
.89 .17584 Mdot
.89 .17586 Mdot
.89 .17587 Mdot
.89 .1759 Mdot
.89 .17616 Mdot
.89 .17621 Mdot
.89 .17636 Mdot
.89 .17638 Mdot
.89 .17643 Mdot
.89 .17661 Mdot
.89 .17681 Mdot
.89 .17707 Mdot
.89 .17724 Mdot
.89 .17774 Mdot
.89 .17782 Mdot
.89 .17788 Mdot
.89 .17795 Mdot
.89 .17796 Mdot
.89 .17845 Mdot
.89 .17847 Mdot
.89 .17869 Mdot
.89 .17872 Mdot
.89 .17891 Mdot
.89 .17895 Mdot
.89 .17903 Mdot
.89 .17925 Mdot
.89 .17932 Mdot
.89 .17939 Mdot
.89 .17946 Mdot
.89 .1795 Mdot
.89 .17951 Mdot
.89 .17964 Mdot
.89 .17967 Mdot
.89 .17969 Mdot
.89 .17988 Mdot
.89 .18009 Mdot
.89 .18015 Mdot
.89 .18058 Mdot
.89 .18076 Mdot
.89 .18083 Mdot
.89 .18164 Mdot
.89 .18247 Mdot
.89 .18265 Mdot
.89 .18265 Mdot
.89 .18284 Mdot
.89 .18299 Mdot
.89 .18333 Mdot
.89 .18333 Mdot
.89 .18436 Mdot
.89 .185 Mdot
.89 .1865 Mdot
.89 .18771 Mdot
.89 .18822 Mdot
.89 .18824 Mdot
.89 .1886 Mdot
.89 .1888 Mdot
.89 .18908 Mdot
.89 .18948 Mdot
.89 .18973 Mdot
.89 .18992 Mdot
.89 .19082 Mdot
.89 .19086 Mdot
.89 .19118 Mdot
.89 .19203 Mdot
.89 .19354 Mdot
.89 .19463 Mdot
.89 .19482 Mdot
.89 .19542 Mdot
.89 .19549 Mdot
.89 .19632 Mdot
.89 .19641 Mdot
.89 .19641 Mdot
.89 .1969 Mdot
.89 .19746 Mdot
.89 .19817 Mdot
.89 .19829 Mdot
.89 .1993 Mdot
.89 .19934 Mdot
.89 .19987 Mdot
.89 .20002 Mdot
.89 .20013 Mdot
.89 .20038 Mdot
.89 .20108 Mdot
.89 .20132 Mdot
.89 .20188 Mdot
.89 .20359 Mdot
.89 .20387 Mdot
.89 .20397 Mdot
.89 .20463 Mdot
.89 .20469 Mdot
.89 .20543 Mdot
.89 .2059 Mdot
.89 .20595 Mdot
.89 .20627 Mdot
.89 .20732 Mdot
.89 .20743 Mdot
.89 .20878 Mdot
.89 .20931 Mdot
.89 .20943 Mdot
.89 .20951 Mdot
.89 .21014 Mdot
.89 .21068 Mdot
.89 .21181 Mdot
.89 .21284 Mdot
.89 .21381 Mdot
.89 .21606 Mdot
.89 .2164 Mdot
.89 .21742 Mdot
.89 .21851 Mdot
.89 .21859 Mdot
.89 .21861 Mdot
.89 .21865 Mdot
.89 .21867 Mdot
.89 .21898 Mdot
.89 .22084 Mdot
.89 .22084 Mdot
.89 .22199 Mdot
.89 .222 Mdot
.89 .22219 Mdot
.89 .2226 Mdot
.89 .22272 Mdot
.89 .22274 Mdot
.89 .22276 Mdot
.89 .223 Mdot
.89 .22404 Mdot
.89 .22489 Mdot
.89 .22614 Mdot
.89 .22635 Mdot
.89 .22639 Mdot
.89 .2274 Mdot
.89 .22768 Mdot
.89 .2288 Mdot
.89 .2307 Mdot
.89 .23167 Mdot
.89 .23225 Mdot
.89 .23346 Mdot
.89 .23426 Mdot
.89 .23553 Mdot
.89 .23649 Mdot
.89 .23676 Mdot
.89 .23899 Mdot
.89 .23995 Mdot
.89 .24148 Mdot
.89 .24259 Mdot
.89 .24274 Mdot
.89 .24281 Mdot
.89 .24287 Mdot
.89 .24307 Mdot
.89 .24315 Mdot
.89 .24424 Mdot
.89 .24431 Mdot
.89 .24458 Mdot
.89 .2453 Mdot
.89 .24583 Mdot
.89 .2462 Mdot
.89 .24666 Mdot
.89 .24771 Mdot
.89 .24795 Mdot
.89 .24811 Mdot
.89 .24969 Mdot
.89 .25309 Mdot
.89 .25411 Mdot
.89 .2567 Mdot
.89 .25755 Mdot
.89 .25803 Mdot
.89 .25983 Mdot
.89 .26085 Mdot
.89 .26148 Mdot
.89 .263 Mdot
.89 .26395 Mdot
.89 .2641 Mdot
.89 .26457 Mdot
.89 .26559 Mdot
.89 .26614 Mdot
.89 .26682 Mdot
.89 .26726 Mdot
.89 .26792 Mdot
.89 .26826 Mdot
.89 .26835 Mdot
.89 .2693 Mdot
.89 .26958 Mdot
.89 .26966 Mdot
.89 .26981 Mdot
.89 .26996 Mdot
.89 .27009 Mdot
.89 .27024 Mdot
.89 .27081 Mdot
.89 .2709 Mdot
.89 .27102 Mdot
.89 .27108 Mdot
.89 .27151 Mdot
.89 .27154 Mdot
.89 .27165 Mdot
.89 .27166 Mdot
.89 .27168 Mdot
.89 .27192 Mdot
.89 .27203 Mdot
.89 .27206 Mdot
.89 .27206 Mdot
.89 .27208 Mdot
.89 .27213 Mdot
.89 .27254 Mdot
.89 .27254 Mdot
.89 .27254 Mdot
.89 .27255 Mdot
.89 .27256 Mdot
.89 .27281 Mdot
.89 .27285 Mdot
.89 .27314 Mdot
.89 .27354 Mdot
.89 .27361 Mdot
.89 .27371 Mdot
.89 .27419 Mdot
.89 .2742 Mdot
.89 .27427 Mdot
.89 .27448 Mdot
.89 .2745 Mdot
.89 .27454 Mdot
.89 .2748 Mdot
.89 .27489 Mdot
.89 .27509 Mdot
.89 .2752 Mdot
.89 .27538 Mdot
.89 .27552 Mdot
.89 .27562 Mdot
.89 .2757 Mdot
.89 .27587 Mdot
.89 .27588 Mdot
.89 .27599 Mdot
.89 .27602 Mdot
.89 .27623 Mdot
.89 .27652 Mdot
.89 .27676 Mdot
.89 .27677 Mdot
.89 .277 Mdot
.89 .27706 Mdot
.89 .27725 Mdot
.89 .27734 Mdot
.89 .27734 Mdot
.89 .27746 Mdot
.89 .27832 Mdot
.89 .27863 Mdot
.89 .27873 Mdot
.89 .27877 Mdot
.89 .27917 Mdot
.89 .27949 Mdot
.89 .27955 Mdot
.89 .28048 Mdot
.89 .28132 Mdot
.89 .28152 Mdot
.89 .28186 Mdot
.89 .2819 Mdot
.89 .28209 Mdot
.89 .28288 Mdot
.89 .28306 Mdot
.89 .28316 Mdot
.89 .28328 Mdot
.89 .28336 Mdot
.89 .28358 Mdot
.89 .28373 Mdot
.89 .28376 Mdot
.89 .28388 Mdot
.89 .28397 Mdot
.89 .28401 Mdot
.89 .28409 Mdot
.89 .2841 Mdot
.89 .28418 Mdot
.89 .28428 Mdot
.89 .28432 Mdot
.89 .28434 Mdot
.89 .28477 Mdot
.89 .285 Mdot
.89 .28577 Mdot
.89 .28611 Mdot
.89 .2862 Mdot
.89 .28624 Mdot
.89 .28625 Mdot
.89 .28633 Mdot
.89 .28653 Mdot
.89 .28666 Mdot
.89 .28668 Mdot
.89 .28678 Mdot
.89 .2868 Mdot
.89 .28684 Mdot
.89 .28695 Mdot
.89 .28698 Mdot
.89 .28701 Mdot
.89 .28705 Mdot
.89 .28707 Mdot
.89 .28707 Mdot
.89 .28714 Mdot
.89 .28715 Mdot
.89 .28716 Mdot
.89 .28725 Mdot
.89 .28734 Mdot
.89 .28737 Mdot
.89 .28766 Mdot
.89 .2883 Mdot
.89 .28836 Mdot
.89 .28836 Mdot
.89 .2886 Mdot
.89 .29025 Mdot
.89 .29033 Mdot
.89 .29055 Mdot
.89 .2921 Mdot
.89 .29248 Mdot
.89 .29272 Mdot
.89 .29289 Mdot
.89 .29294 Mdot
.89 .29309 Mdot
.89 .29379 Mdot
.89 .29381 Mdot
.89 .29411 Mdot
.89 .29431 Mdot
.89 .29433 Mdot
.89 .29458 Mdot
.89 .29468 Mdot
.89 .29471 Mdot
.89 .29513 Mdot
.89 .29532 Mdot
.89 .29639 Mdot
.89 .2967 Mdot
.89 .2967 Mdot
.89 .2969 Mdot
.89 .2969 Mdot
.89 .29703 Mdot
.89 .29738 Mdot
.89 .29803 Mdot
.89 .29834 Mdot
.89 .29928 Mdot
.89 .29933 Mdot
.89 .29969 Mdot
.89 .30027 Mdot
.89 .3003 Mdot
.89 .30032 Mdot
.89 .30035 Mdot
.89 .30037 Mdot
.89 .30054 Mdot
.89 .3006 Mdot
.89 .30072 Mdot
.89 .30086 Mdot
.89 .30111 Mdot
.89 .30118 Mdot
.89 .30201 Mdot
.89 .30218 Mdot
.89 .30262 Mdot
.89 .30277 Mdot
.89 .30285 Mdot
.89 .30345 Mdot
.89 .30389 Mdot
.89 .30392 Mdot
.89 .30419 Mdot
.89 .30429 Mdot
.89 .30442 Mdot
.89 .3045 Mdot
.89 .30462 Mdot
.89 .30468 Mdot
.89 .3047 Mdot
.89 .30488 Mdot
.89 .30503 Mdot
.89 .30521 Mdot
.89 .30522 Mdot
.89 .3053 Mdot
.89 .30533 Mdot
.89 .30533 Mdot
.89 .30541 Mdot
.89 .30541 Mdot
.89 .30541 Mdot
.89 .30542 Mdot
.89 .30542 Mdot
.89 .30551 Mdot
.89 .30551 Mdot
.89 .30551 Mdot
.89 .30551 Mdot
.89 .30556 Mdot
.89 .30557 Mdot
.89 .3057 Mdot
.89 .30574 Mdot
.89 .30584 Mdot
.89 .30585 Mdot
.89 .3059 Mdot
.89 .30596 Mdot
.89 .30598 Mdot
.89 .30608 Mdot
.89 .30625 Mdot
.89 .30636 Mdot
.89 .30641 Mdot
.89 .30642 Mdot
.89 .30648 Mdot
.89 .30648 Mdot
.89 .30651 Mdot
.89 .30669 Mdot
.89 .30676 Mdot
.89 .30678 Mdot
.89 .30694 Mdot
.89 .30735 Mdot
.89 .3074 Mdot
.89 .30747 Mdot
.89 .30778 Mdot
.89 .30788 Mdot
.89 .30795 Mdot
.89 .30798 Mdot
.89 .30841 Mdot
.89 .30852 Mdot
.89 .30881 Mdot
.89 .30881 Mdot
.89 .30889 Mdot
.89 .30908 Mdot
.89 .30962 Mdot
.89 .30968 Mdot
.89 .31025 Mdot
.89 .31038 Mdot
.89 .31044 Mdot
.89 .31156 Mdot
.89 .31175 Mdot
.89 .31219 Mdot
.89 .31321 Mdot
.89 .31323 Mdot
.89 .31332 Mdot
.89 .31422 Mdot
.89 .3146 Mdot
.89 .31466 Mdot
.89 .3151 Mdot
.89 .31547 Mdot
.89 .31575 Mdot
.89 .31598 Mdot
.89 .3163 Mdot
.89 .31656 Mdot
.89 .3168 Mdot
.89 .31716 Mdot
.89 .31718 Mdot
.89 .31741 Mdot
.89 .31787 Mdot
.89 .31787 Mdot
.89 .31789 Mdot
.89 .31855 Mdot
.89 .31887 Mdot
.89 .31887 Mdot
.89 .32001 Mdot
.89 .32011 Mdot
.89 .32025 Mdot
.89 .32205 Mdot
.89 .3225 Mdot
.89 .32268 Mdot
.89 .32274 Mdot
.89 .32284 Mdot
.89 .32287 Mdot
.89 .32288 Mdot
.89 .32363 Mdot
.89 .32418 Mdot
.89 .32418 Mdot
.89 .3246 Mdot
.89 .32478 Mdot
.89 .32502 Mdot
.89 .32502 Mdot
.89 .32524 Mdot
.89 .32625 Mdot
.89 .3263 Mdot
.89 .32709 Mdot
.89 .3272 Mdot
.89 .32728 Mdot
.89 .32749 Mdot
.89 .32797 Mdot
.89 .32803 Mdot
.89 .32827 Mdot
.89 .32846 Mdot
.89 .32848 Mdot
.89 .32848 Mdot
.89 .3285 Mdot
.89 .32853 Mdot
.89 .32867 Mdot
.89 .32868 Mdot
.89 .32872 Mdot
.89 .32881 Mdot
.89 .32887 Mdot
.89 .32896 Mdot
.89 .32918 Mdot
.89 .32927 Mdot
.89 .3293 Mdot
.89 .3295 Mdot
.89 .32953 Mdot
.89 .32967 Mdot
.89 .32976 Mdot
.89 .32978 Mdot
.89 .33026 Mdot
.89 .33028 Mdot
.89 .33034 Mdot
.89 .3304 Mdot
.89 .33048 Mdot
.89 .33095 Mdot
.89 .3311 Mdot
.89 .33134 Mdot
.89 .33151 Mdot
.89 .33154 Mdot
.89 .33159 Mdot
.89 .33166 Mdot
.89 .3317 Mdot
.89 .33172 Mdot
.89 .33173 Mdot
.89 .33176 Mdot
.89 .33185 Mdot
.89 .33189 Mdot
.89 .3321 Mdot
.89 .33212 Mdot
.89 .33213 Mdot
.89 .33215 Mdot
.89 .33219 Mdot
.89 .33221 Mdot
.89 .33221 Mdot
.89 .33223 Mdot
.89 .33224 Mdot
.89 .33225 Mdot
.89 .33227 Mdot
.89 .33228 Mdot
.89 .33228 Mdot
.89 .33229 Mdot
.89 .33229 Mdot
.89 .33229 Mdot
.89 .33231 Mdot
.89 .33231 Mdot
.89 .33231 Mdot
.89 .33233 Mdot
.89 .3334 Mdot
.89 .33356 Mdot
.89 .33392 Mdot
.89 .33397 Mdot
.89 .33398 Mdot
.89 .33405 Mdot
.89 .33409 Mdot
.89 .3342 Mdot
.89 .33474 Mdot
.89 .33478 Mdot
.89 .33489 Mdot
.89 .33557 Mdot
.89 .33807 Mdot
.89 .3384 Mdot
.89 .34088 Mdot
.89 .34435 Mdot
.89 .34521 Mdot
.89 .34595 Mdot
.89 .34611 Mdot
.89 .3498 Mdot
.89 .35084 Mdot
.89 .35391 Mdot
.89 .35514 Mdot
.89 .36274 Mdot
.89 .36678 Mdot
.89 .36799 Mdot
.89 .36925 Mdot
.89 .3736 Mdot
.89 .37447 Mdot
.89 .37505 Mdot
.89 .37802 Mdot
.89 .38374 Mdot
.89 .38817 Mdot
.89 .3894 Mdot
.89 .39938 Mdot
.89 .3999 Mdot
.89 .40125 Mdot
.89 .4045 Mdot
.89 .40599 Mdot
.89 .40743 Mdot
.89 .40897 Mdot
.89 .41187 Mdot
.89 .41248 Mdot
.89 .41725 Mdot
.89 .41797 Mdot
.89 .41829 Mdot
.89 .41859 Mdot
.89 .41958 Mdot
.89 .41998 Mdot
.89 .42527 Mdot
.89 .4256 Mdot
.89 .4269 Mdot
.89 .43037 Mdot
.89 .43296 Mdot
.89 .43472 Mdot
.89 .4356 Mdot
.89 .43693 Mdot
.89 .43852 Mdot
.89 .44197 Mdot
.89 .44312 Mdot
.89 .44392 Mdot
.89 .45138 Mdot
.89 .45228 Mdot
.89 .45939 Mdot
.89 .46591 Mdot
.89 .46691 Mdot
.89 .4714 Mdot
.89 .47246 Mdot
.89 .48234 Mdot
.89 .48579 Mdot
.89 .48602 Mdot
.89 .48772 Mdot
.89 .49129 Mdot
.89 .49327 Mdot
.89 .4946 Mdot
.89 .49831 Mdot
.89 .50055 Mdot
.89 .50566 Mdot
.89 .50872 Mdot
.89 .50919 Mdot
.89 .50921 Mdot
.89 .50922 Mdot
.89 .50922 Mdot
.89 .50922 Mdot
.89 .50922 Mdot
.89 .50924 Mdot
.89 .50924 Mdot
.89 .50925 Mdot
.89 .50928 Mdot
.89 .50928 Mdot
.89 .50934 Mdot
.89 .50939 Mdot
.89 .50945 Mdot
.89 .50945 Mdot
.89 .50947 Mdot
.89 .50951 Mdot
.89 .50954 Mdot
.89 .50958 Mdot
.89 .50961 Mdot
.89 .50969 Mdot
.89 .5097 Mdot
.89 .50984 Mdot
.89 .51003 Mdot
.89 .51005 Mdot
.89 .5101 Mdot
.89 .51023 Mdot
.89 .51029 Mdot
.89 .51054 Mdot
.89 .51056 Mdot
.89 .51063 Mdot
.89 .51068 Mdot
.89 .51071 Mdot
.89 .51073 Mdot
.89 .51078 Mdot
.89 .51079 Mdot
.89 .5108 Mdot
.89 .5108 Mdot
.89 .51081 Mdot
.89 .51098 Mdot
.89 .51109 Mdot
.89 .5111 Mdot
.89 .51138 Mdot
.89 .51147 Mdot
.89 .51166 Mdot
.89 .51176 Mdot
.89 .5118 Mdot
.89 .5118 Mdot
.89 .51185 Mdot
.89 .51185 Mdot
.89 .51194 Mdot
.89 .51225 Mdot
.89 .5123 Mdot
.89 .51242 Mdot
.89 .51243 Mdot
.89 .51246 Mdot
.89 .51253 Mdot
.89 .51253 Mdot
.89 .51259 Mdot
.89 .51267 Mdot
.89 .51267 Mdot
.89 .51287 Mdot
.89 .51291 Mdot
.89 .51292 Mdot
.89 .51297 Mdot
.89 .51304 Mdot
.89 .51314 Mdot
.89 .51356 Mdot
.89 .51362 Mdot
.89 .51364 Mdot
.89 .51408 Mdot
.89 .51414 Mdot
.89 .51414 Mdot
.89 .51416 Mdot
.89 .51432 Mdot
.89 .5144 Mdot
.89 .51441 Mdot
.89 .51443 Mdot
.89 .51446 Mdot
.89 .51446 Mdot
.89 .51446 Mdot
.89 .51448 Mdot
.89 .51448 Mdot
.89 .51448 Mdot
.89 .51449 Mdot
.89 .5145 Mdot
.89 .51451 Mdot
.89 .51454 Mdot
.89 .51455 Mdot
.89 .51455 Mdot
.89 .51458 Mdot
.89 .51458 Mdot
.89 .51462 Mdot
.89 .51467 Mdot
.89 .51469 Mdot
.89 .51469 Mdot
.89 .5147 Mdot
.89 .51473 Mdot
.89 .51482 Mdot
.89 .51501 Mdot
.89 .51507 Mdot
.89 .51518 Mdot
.89 .51519 Mdot
.89 .5152 Mdot
.89 .51522 Mdot
.89 .51524 Mdot
.89 .51524 Mdot
.89 .51527 Mdot
.89 .51527 Mdot
.89 .5153 Mdot
.89 .51533 Mdot
.89 .51534 Mdot
.89 .51537 Mdot
.89 .51543 Mdot
.89 .51545 Mdot
.89 .51548 Mdot
.89 .51551 Mdot
.89 .51555 Mdot
.89 .51575 Mdot
.89 .5158 Mdot
.89 .51581 Mdot
.89 .51589 Mdot
.89 .51594 Mdot
.89 .51615 Mdot
.89 .51638 Mdot
.89 .51639 Mdot
.89 .51647 Mdot
.89 .51657 Mdot
.89 .51658 Mdot
.89 .5166 Mdot
.89 .51668 Mdot
.89 .51689 Mdot
.89 .51692 Mdot
.89 .51692 Mdot
.89 .51694 Mdot
.89 .51699 Mdot
.89 .517 Mdot
.89 .51705 Mdot
.89 .51706 Mdot
.89 .51711 Mdot
.89 .51719 Mdot
.89 .51724 Mdot
.89 .51724 Mdot
.89 .51727 Mdot
.89 .51727 Mdot
.89 .51731 Mdot
.89 .51733 Mdot
.89 .51736 Mdot
.89 .51739 Mdot
.89 .51743 Mdot
.89 .51746 Mdot
.89 .51751 Mdot
.89 .51753 Mdot
.89 .51759 Mdot
.89 .5176 Mdot
.89 .5176 Mdot
.89 .51765 Mdot
.89 .51767 Mdot
.89 .51767 Mdot
.89 .51779 Mdot
.89 .51781 Mdot
.89 .51783 Mdot
.89 .51792 Mdot
.89 .51799 Mdot
.89 .518 Mdot
.89 .51806 Mdot
.89 .51806 Mdot
.89 .51806 Mdot
.89 .51806 Mdot
.89 .51806 Mdot
.89 .51816 Mdot
.89 .51817 Mdot
.89 .51818 Mdot
.89 .51818 Mdot
.89 .51818 Mdot
.89 .51821 Mdot
.89 .51827 Mdot
.89 .51827 Mdot
.89 .51827 Mdot
.89 .5183 Mdot
.89 .5183 Mdot
.89 .5184 Mdot
.89 .51842 Mdot
.89 .51845 Mdot
.89 .51847 Mdot
.89 .5186 Mdot
.89 .51864 Mdot
.89 .51867 Mdot
.89 .5187 Mdot
.89 .51874 Mdot
.89 .51875 Mdot
.89 .51882 Mdot
.89 .51904 Mdot
.89 .51906 Mdot
.89 .51914 Mdot
.89 .51929 Mdot
.89 .51939 Mdot
.89 .51955 Mdot
.89 .51967 Mdot
.89 .5199 Mdot
.89 .52001 Mdot
.89 .52004 Mdot
.89 .52026 Mdot
.89 .52059 Mdot
.89 .52074 Mdot
.89 .52096 Mdot
.89 .52136 Mdot
.89 .52147 Mdot
.89 .52165 Mdot
.89 .52222 Mdot
.89 .52244 Mdot
.89 .52317 Mdot
.89 .52351 Mdot
.89 .52355 Mdot
.89 .5236 Mdot
.89 .52382 Mdot
.89 .52392 Mdot
.89 .524 Mdot
.89 .52411 Mdot
.89 .52426 Mdot
.89 .52432 Mdot
.89 .52433 Mdot
.89 .52456 Mdot
.89 .52458 Mdot
.89 .52462 Mdot
.89 .52464 Mdot
.89 .52465 Mdot
.89 .52468 Mdot
.89 .52492 Mdot
.89 .52524 Mdot
.89 .52544 Mdot
.89 .52591 Mdot
.89 .52596 Mdot
.89 .52616 Mdot
.89 .52643 Mdot
.89 .52659 Mdot
.89 .52684 Mdot
.89 .52697 Mdot
.89 .52717 Mdot
.89 .52756 Mdot
.89 .52779 Mdot
.89 .52785 Mdot
.89 .52806 Mdot
.89 .52807 Mdot
.89 .52811 Mdot
.89 .52837 Mdot
.89 .52854 Mdot
.89 .52876 Mdot
.89 .52881 Mdot
.89 .52881 Mdot
.89 .52881 Mdot
.89 .52884 Mdot
.89 .52892 Mdot
.89 .52896 Mdot
.89 .52897 Mdot
.89 .5292 Mdot
.89 .5292 Mdot
.89 .52958 Mdot
.89 .52965 Mdot
.89 .52965 Mdot
.89 .52966 Mdot
.89 .52967 Mdot
.89 .52968 Mdot
.89 .52991 Mdot
.89 .53012 Mdot
.89 .53019 Mdot
.89 .53065 Mdot
.89 .53085 Mdot
.89 .53106 Mdot
.89 .5313 Mdot
.89 .53141 Mdot
.89 .53154 Mdot
.89 .53155 Mdot
.89 .53158 Mdot
.89 .53169 Mdot
.89 .53197 Mdot
.89 .53199 Mdot
.89 .53221 Mdot
.89 .53227 Mdot
.89 .53228 Mdot
.89 .53238 Mdot
.89 .53254 Mdot
.89 .53255 Mdot
.89 .53268 Mdot
.89 .5327 Mdot
.89 .53276 Mdot
.89 .53312 Mdot
.89 .53324 Mdot
.89 .53329 Mdot
.89 .53343 Mdot
.89 .53349 Mdot
.89 .53351 Mdot
.89 .53354 Mdot
.89 .53365 Mdot
.89 .53366 Mdot
.89 .53387 Mdot
.89 .53389 Mdot
.89 .53404 Mdot
.89 .53416 Mdot
.89 .53426 Mdot
.89 .53426 Mdot
.89 .53428 Mdot
.89 .53446 Mdot
.89 .53447 Mdot
.89 .5346 Mdot
.89 .53464 Mdot
.89 .53487 Mdot
.89 .53519 Mdot
.89 .53537 Mdot
.89 .53544 Mdot
.89 .53545 Mdot
.89 .53564 Mdot
.89 .53568 Mdot
.89 .53573 Mdot
.89 .53582 Mdot
.89 .53588 Mdot
.89 .53592 Mdot
.89 .53599 Mdot
.89 .536 Mdot
.89 .53611 Mdot
.89 .53637 Mdot
.89 .53683 Mdot
.89 .53705 Mdot
.89 .53705 Mdot
.89 .53713 Mdot
.89 .53716 Mdot
.89 .5372 Mdot
.89 .5372 Mdot
.89 .53724 Mdot
.89 .53742 Mdot
.89 .5376 Mdot
.89 .53761 Mdot
.89 .53765 Mdot
.89 .53775 Mdot
.89 .53776 Mdot
.89 .53781 Mdot
.89 .53785 Mdot
.89 .53785 Mdot
.89 .53786 Mdot
.89 .53789 Mdot
.89 .53789 Mdot
.89 .5379 Mdot
.89 .53791 Mdot
.89 .53793 Mdot
.89 .53794 Mdot
.89 .53799 Mdot
.89 .53801 Mdot
.89 .53802 Mdot
.89 .53806 Mdot
.89 .53807 Mdot
.89 .53812 Mdot
.89 .53812 Mdot
.89 .53823 Mdot
.89 .53823 Mdot
.89 .53825 Mdot
.89 .53826 Mdot
.89 .53828 Mdot
.89 .53839 Mdot
.89 .53842 Mdot
.89 .53848 Mdot
.89 .53853 Mdot
.89 .53857 Mdot
.89 .53858 Mdot
.89 .53858 Mdot
.89 .53862 Mdot
.89 .53863 Mdot
.89 .53869 Mdot
.89 .53869 Mdot
.89 .53869 Mdot
.89 .5387 Mdot
.89 .53871 Mdot
.89 .53872 Mdot
.89 .53872 Mdot
.89 .53872 Mdot
.89 .53872 Mdot
.89 .53873 Mdot
.89 .53873 Mdot
.89 .53874 Mdot
.89 .53874 Mdot
.89 .53874 Mdot
.89 .53874 Mdot
.89 .53874 Mdot
.89 .53874 Mdot
.89 .53874 Mdot
.89 .53875 Mdot
.892 .17076 Mdot
.892 .17085 Mdot
.892 .17085 Mdot
.892 .17085 Mdot
.892 .17102 Mdot
.892 .17109 Mdot
.892 .17109 Mdot
.892 .17122 Mdot
.892 .1713 Mdot
.892 .17143 Mdot
.892 .17145 Mdot
.892 .17154 Mdot
.892 .17162 Mdot
.892 .17167 Mdot
.892 .1717 Mdot
.892 .17172 Mdot
.892 .17175 Mdot
.892 .17177 Mdot
.892 .17205 Mdot
.892 .17205 Mdot
.892 .17223 Mdot
.892 .17229 Mdot
.892 .17245 Mdot
.892 .1725 Mdot
.892 .1728 Mdot
.892 .17291 Mdot
.892 .17299 Mdot
.892 .17312 Mdot
.892 .17352 Mdot
.892 .17353 Mdot
.892 .17395 Mdot
.892 .17416 Mdot
.892 .17428 Mdot
.892 .17433 Mdot
.892 .17441 Mdot
.892 .17483 Mdot
.892 .1754 Mdot
.892 .17559 Mdot
.892 .1756 Mdot
.892 .17572 Mdot
.892 .17581 Mdot
.892 .1759 Mdot
.892 .17652 Mdot
.892 .17661 Mdot
.892 .17669 Mdot
.892 .17681 Mdot
.892 .17699 Mdot
.892 .17742 Mdot
.892 .17762 Mdot
.892 .17868 Mdot
.892 .17916 Mdot
.892 .1792 Mdot
.892 .17945 Mdot
.892 .17996 Mdot
.892 .18044 Mdot
.892 .1808 Mdot
.892 .18147 Mdot
.892 .1817 Mdot
.892 .18171 Mdot
.892 .18227 Mdot
.892 .18329 Mdot
.892 .18362 Mdot
.892 .18371 Mdot
.892 .18389 Mdot
.892 .18418 Mdot
.892 .18422 Mdot
.892 .18436 Mdot
.892 .18465 Mdot
.892 .18487 Mdot
.892 .1854 Mdot
.892 .18563 Mdot
.892 .18617 Mdot
.892 .18637 Mdot
.892 .18647 Mdot
.892 .18674 Mdot
.892 .18734 Mdot
.892 .18865 Mdot
.892 .18928 Mdot
.892 .18951 Mdot
.892 .1899 Mdot
.892 .19091 Mdot
.892 .19174 Mdot
.892 .19196 Mdot
.892 .19249 Mdot
.892 .19325 Mdot
.892 .19336 Mdot
.892 .19346 Mdot
.892 .19366 Mdot
.892 .19421 Mdot
.892 .19508 Mdot
.892 .19513 Mdot
.892 .19654 Mdot
.892 .19693 Mdot
.892 .19745 Mdot
.892 .19771 Mdot
.892 .198 Mdot
.892 .1986 Mdot
.892 .19864 Mdot
.892 .19954 Mdot
.892 .19956 Mdot
.892 .19958 Mdot
.892 .20156 Mdot
.892 .20184 Mdot
.892 .20222 Mdot
.892 .20312 Mdot
.892 .20335 Mdot
.892 .20357 Mdot
.892 .20377 Mdot
.892 .20437 Mdot
.892 .20495 Mdot
.892 .20496 Mdot
.892 .20582 Mdot
.892 .20608 Mdot
.892 .2067 Mdot
.892 .20679 Mdot
.892 .2069 Mdot
.892 .20696 Mdot
.892 .20709 Mdot
.892 .20721 Mdot
.892 .20728 Mdot
.892 .20755 Mdot
.892 .20756 Mdot
.892 .20797 Mdot
.892 .20836 Mdot
.892 .20845 Mdot
.892 .20857 Mdot
.892 .20886 Mdot
.892 .20913 Mdot
.892 .2092 Mdot
.892 .20921 Mdot
.892 .20956 Mdot
.892 .21015 Mdot
.892 .21017 Mdot
.892 .21027 Mdot
.892 .21047 Mdot
.892 .21114 Mdot
.892 .21114 Mdot
.892 .21117 Mdot
.892 .21135 Mdot
.892 .21149 Mdot
.892 .21281 Mdot
.892 .21291 Mdot
.892 .2131 Mdot
.892 .21318 Mdot
.892 .21334 Mdot
.892 .21412 Mdot
.892 .21434 Mdot
.892 .2149 Mdot
.892 .21724 Mdot
.892 .2173 Mdot
.892 .21739 Mdot
.892 .21744 Mdot
.892 .21919 Mdot
.892 .21936 Mdot
.892 .22034 Mdot
.892 .22064 Mdot
.892 .22067 Mdot
.892 .2214 Mdot
.892 .22168 Mdot
.892 .22172 Mdot
.892 .22179 Mdot
.892 .22188 Mdot
.892 .22694 Mdot
.892 .22755 Mdot
.892 .22891 Mdot
.892 .23047 Mdot
.892 .23059 Mdot
.892 .23111 Mdot
.892 .23189 Mdot
.892 .23467 Mdot
.892 .23551 Mdot
.892 .23678 Mdot
.892 .23799 Mdot
.892 .23958 Mdot
.892 .24031 Mdot
.892 .24133 Mdot
.892 .24212 Mdot
.892 .24299 Mdot
.892 .243 Mdot
.892 .24321 Mdot
.892 .24323 Mdot
.892 .24395 Mdot
.892 .24433 Mdot
.892 .24494 Mdot
.892 .24509 Mdot
.892 .24518 Mdot
.892 .24743 Mdot
.892 .24823 Mdot
.892 .24829 Mdot
.892 .2494 Mdot
.892 .25023 Mdot
.892 .25034 Mdot
.892 .25144 Mdot
.892 .25145 Mdot
.892 .25158 Mdot
.892 .25336 Mdot
.892 .25983 Mdot
.892 .26469 Mdot
.892 .26678 Mdot
.892 .2671 Mdot
.892 .26869 Mdot
.892 .26879 Mdot
.892 .26945 Mdot
.892 .27006 Mdot
.892 .27062 Mdot
.892 .27084 Mdot
.892 .27159 Mdot
.892 .2716 Mdot
.892 .2716 Mdot
.892 .27161 Mdot
.892 .27164 Mdot
.892 .27172 Mdot
.892 .27172 Mdot
.892 .2721 Mdot
.892 .2721 Mdot
.892 .27237 Mdot
.892 .27261 Mdot
.892 .2728 Mdot
.892 .27307 Mdot
.892 .27317 Mdot
.892 .2735 Mdot
.892 .27408 Mdot
.892 .27465 Mdot
.892 .27483 Mdot
.892 .27506 Mdot
.892 .2752 Mdot
.892 .27533 Mdot
.892 .27549 Mdot
.892 .27577 Mdot
.892 .27595 Mdot
.892 .27602 Mdot
.892 .27619 Mdot
.892 .27662 Mdot
.892 .27664 Mdot
.892 .27701 Mdot
.892 .27707 Mdot
.892 .2771 Mdot
.892 .27756 Mdot
.892 .2777 Mdot
.892 .27775 Mdot
.892 .27885 Mdot
.892 .27892 Mdot
.892 .27912 Mdot
.892 .27919 Mdot
.892 .27922 Mdot
.892 .27945 Mdot
.892 .27952 Mdot
.892 .27956 Mdot
.892 .27957 Mdot
.892 .27964 Mdot
.892 .27988 Mdot
.892 .28012 Mdot
.892 .28018 Mdot
.892 .28027 Mdot
.892 .28049 Mdot
.892 .2809 Mdot
.892 .28109 Mdot
.892 .28128 Mdot
.892 .28141 Mdot
.892 .28165 Mdot
.892 .28166 Mdot
.892 .28169 Mdot
.892 .28171 Mdot
.892 .28195 Mdot
.892 .28198 Mdot
.892 .28213 Mdot
.892 .2824 Mdot
.892 .28253 Mdot
.892 .28289 Mdot
.892 .28289 Mdot
.892 .28291 Mdot
.892 .28332 Mdot
.892 .2845 Mdot
.892 .2847 Mdot
.892 .28507 Mdot
.892 .28515 Mdot
.892 .2852 Mdot
.892 .28554 Mdot
.892 .28573 Mdot
.892 .28585 Mdot
.892 .28621 Mdot
.892 .28629 Mdot
.892 .28653 Mdot
.892 .28696 Mdot
.892 .28699 Mdot
.892 .28763 Mdot
.892 .28799 Mdot
.892 .28811 Mdot
.892 .28888 Mdot
.892 .2889 Mdot
.892 .28898 Mdot
.892 .28929 Mdot
.892 .28941 Mdot
.892 .28968 Mdot
.892 .29013 Mdot
.892 .29022 Mdot
.892 .29024 Mdot
.892 .29029 Mdot
.892 .29055 Mdot
.892 .29069 Mdot
.892 .29075 Mdot
.892 .29089 Mdot
.892 .29103 Mdot
.892 .29118 Mdot
.892 .29164 Mdot
.892 .2922 Mdot
.892 .29225 Mdot
.892 .29253 Mdot
.892 .29255 Mdot
.892 .29262 Mdot
.892 .29293 Mdot
.892 .29329 Mdot
.892 .2934 Mdot
.892 .29351 Mdot
.892 .29363 Mdot
.892 .29381 Mdot
.892 .29382 Mdot
.892 .29425 Mdot
.892 .29432 Mdot
.892 .29449 Mdot
.892 .29453 Mdot
.892 .29457 Mdot
.892 .29461 Mdot
.892 .29472 Mdot
.892 .29483 Mdot
.892 .29483 Mdot
.892 .29503 Mdot
.892 .29515 Mdot
.892 .29516 Mdot
.892 .29518 Mdot
.892 .29519 Mdot
.892 .29521 Mdot
.892 .29524 Mdot
.892 .29525 Mdot
.892 .2953 Mdot
.892 .2953 Mdot
.892 .29537 Mdot
.892 .29546 Mdot
.892 .29548 Mdot
.892 .29553 Mdot
.892 .29559 Mdot
.892 .29559 Mdot
.892 .29565 Mdot
.892 .29576 Mdot
.892 .29576 Mdot
.892 .29581 Mdot
.892 .29593 Mdot
.892 .29593 Mdot
.892 .29593 Mdot
.892 .29599 Mdot
.892 .29622 Mdot
.892 .29627 Mdot
.892 .29628 Mdot
.892 .29644 Mdot
.892 .29648 Mdot
.892 .29699 Mdot
.892 .297 Mdot
.892 .29729 Mdot
.892 .29732 Mdot
.892 .29748 Mdot
.892 .29856 Mdot
.892 .29865 Mdot
.892 .29912 Mdot
.892 .29914 Mdot
.892 .29935 Mdot
.892 .2998 Mdot
.892 .29993 Mdot
.892 .30033 Mdot
.892 .30059 Mdot
.892 .30071 Mdot
.892 .30087 Mdot
.892 .301 Mdot
.892 .30114 Mdot
.892 .30118 Mdot
.892 .3013 Mdot
.892 .30136 Mdot
.892 .30146 Mdot
.892 .30148 Mdot
.892 .30149 Mdot
.892 .30186 Mdot
.892 .30199 Mdot
.892 .30201 Mdot
.892 .30219 Mdot
.892 .30233 Mdot
.892 .30253 Mdot
.892 .30616 Mdot
.892 .30616 Mdot
.892 .30616 Mdot
.892 .30616 Mdot
.892 .30617 Mdot
.892 .30619 Mdot
.892 .30619 Mdot
.892 .30626 Mdot
.892 .30626 Mdot
.892 .30632 Mdot
.892 .3064 Mdot
.892 .30648 Mdot
.892 .30655 Mdot
.892 .30678 Mdot
.892 .30682 Mdot
.892 .30687 Mdot
.892 .3069 Mdot
.892 .30696 Mdot
.892 .30702 Mdot
.892 .30706 Mdot
.892 .3072 Mdot
.892 .30721 Mdot
.892 .30729 Mdot
.892 .3073 Mdot
.892 .30731 Mdot
.892 .30741 Mdot
.892 .30745 Mdot
.892 .30771 Mdot
.892 .30777 Mdot
.892 .30783 Mdot
.892 .30785 Mdot
.892 .30786 Mdot
.892 .308 Mdot
.892 .30802 Mdot
.892 .30807 Mdot
.892 .30825 Mdot
.892 .30828 Mdot
.892 .30834 Mdot
.892 .30835 Mdot
.892 .30841 Mdot
.892 .30846 Mdot
.892 .30864 Mdot
.892 .30865 Mdot
.892 .30905 Mdot
.892 .3091 Mdot
.892 .30919 Mdot
.892 .30921 Mdot
.892 .30932 Mdot
.892 .30936 Mdot
.892 .30951 Mdot
.892 .31024 Mdot
.892 .31025 Mdot
.892 .31027 Mdot
.892 .31048 Mdot
.892 .31062 Mdot
.892 .31064 Mdot
.892 .31067 Mdot
.892 .31153 Mdot
.892 .3121 Mdot
.892 .31231 Mdot
.892 .31237 Mdot
.892 .31242 Mdot
.892 .31251 Mdot
.892 .31253 Mdot
.892 .3128 Mdot
.892 .31282 Mdot
.892 .31291 Mdot
.892 .31314 Mdot
.892 .31328 Mdot
.892 .31337 Mdot
.892 .31397 Mdot
.892 .31424 Mdot
.892 .31437 Mdot
.892 .31466 Mdot
.892 .31474 Mdot
.892 .31521 Mdot
.892 .31571 Mdot
.892 .31645 Mdot
.892 .31665 Mdot
.892 .31694 Mdot
.892 .31722 Mdot
.892 .31802 Mdot
.892 .31971 Mdot
.892 .32029 Mdot
.892 .32031 Mdot
.892 .32043 Mdot
.892 .32048 Mdot
.892 .32062 Mdot
.892 .32074 Mdot
.892 .32084 Mdot
.892 .32097 Mdot
.892 .32123 Mdot
.892 .32193 Mdot
.892 .32223 Mdot
.892 .32292 Mdot
.892 .3232 Mdot
.892 .32357 Mdot
.892 .32374 Mdot
.892 .32379 Mdot
.892 .32416 Mdot
.892 .32439 Mdot
.892 .32451 Mdot
.892 .32483 Mdot
.892 .32492 Mdot
.892 .32527 Mdot
.892 .32618 Mdot
.892 .32686 Mdot
.892 .32687 Mdot
.892 .32714 Mdot
.892 .32723 Mdot
.892 .32725 Mdot
.892 .3278 Mdot
.892 .32793 Mdot
.892 .32834 Mdot
.892 .32863 Mdot
.892 .32871 Mdot
.892 .32888 Mdot
.892 .32944 Mdot
.892 .32971 Mdot
.892 .32975 Mdot
.892 .33026 Mdot
.892 .33073 Mdot
.892 .3313 Mdot
.892 .33149 Mdot
.892 .33156 Mdot
.892 .33167 Mdot
.892 .33185 Mdot
.892 .33188 Mdot
.892 .33205 Mdot
.892 .33213 Mdot
.892 .33215 Mdot
.892 .33222 Mdot
.892 .3323 Mdot
.892 .33281 Mdot
.892 .33289 Mdot
.892 .33296 Mdot
.892 .33305 Mdot
.892 .33306 Mdot
.892 .3332 Mdot
.892 .33328 Mdot
.892 .33361 Mdot
.892 .33382 Mdot
.892 .3339 Mdot
.892 .33395 Mdot
.892 .33399 Mdot
.892 .33407 Mdot
.892 .33419 Mdot
.892 .33436 Mdot
.892 .33444 Mdot
.892 .33444 Mdot
.892 .33466 Mdot
.892 .33473 Mdot
.892 .33476 Mdot
.892 .33482 Mdot
.892 .33482 Mdot
.892 .33496 Mdot
.892 .33498 Mdot
.892 .33505 Mdot
.892 .33508 Mdot
.892 .33515 Mdot
.892 .33515 Mdot
.892 .33525 Mdot
.892 .33526 Mdot
.892 .33527 Mdot
.892 .33528 Mdot
.892 .33529 Mdot
.892 .33531 Mdot
.892 .33533 Mdot
.892 .33536 Mdot
.892 .33537 Mdot
.892 .33541 Mdot
.892 .33543 Mdot
.892 .33547 Mdot
.892 .33547 Mdot
.892 .33549 Mdot
.892 .33553 Mdot
.892 .33553 Mdot
.892 .33553 Mdot
.892 .33555 Mdot
.892 .34884 Mdot
.892 .3511 Mdot
.892 .35326 Mdot
.892 .35489 Mdot
.892 .35631 Mdot
.892 .35772 Mdot
.892 .36255 Mdot
.892 .36308 Mdot
.892 .36523 Mdot
.892 .36848 Mdot
.892 .37014 Mdot
.892 .37803 Mdot
.892 .3807 Mdot
.892 .38449 Mdot
.892 .39034 Mdot
.892 .39425 Mdot
.892 .39464 Mdot
.892 .39602 Mdot
.892 .39921 Mdot
.892 .39941 Mdot
.892 .39961 Mdot
.892 .40358 Mdot
.892 .40708 Mdot
.892 .41202 Mdot
.892 .41584 Mdot
.892 .42011 Mdot
.892 .42015 Mdot
.892 .42019 Mdot
.892 .42116 Mdot
.892 .42124 Mdot
.892 .42478 Mdot
.892 .42658 Mdot
.892 .42959 Mdot
.892 .43031 Mdot
.892 .43074 Mdot
.892 .43874 Mdot
.892 .44161 Mdot
.892 .44543 Mdot
.892 .44573 Mdot
.892 .45096 Mdot
.892 .45489 Mdot
.892 .45536 Mdot
.892 .46048 Mdot
.892 .46051 Mdot
.892 .46109 Mdot
.892 .46199 Mdot
.892 .46911 Mdot
.892 .47747 Mdot
.892 .49346 Mdot
.892 .49424 Mdot
.892 .495 Mdot
.892 .49565 Mdot
.892 .50624 Mdot
.892 .51032 Mdot
.892 .51039 Mdot
.892 .51043 Mdot
.892 .51048 Mdot
.892 .51049 Mdot
.892 .51053 Mdot
.892 .51064 Mdot
.892 .51064 Mdot
.892 .51065 Mdot
.892 .51068 Mdot
.892 .5107 Mdot
.892 .51073 Mdot
.892 .51074 Mdot
.892 .51079 Mdot
.892 .51082 Mdot
.892 .51087 Mdot
.892 .51091 Mdot
.892 .51098 Mdot
.892 .5111 Mdot
.892 .51114 Mdot
.892 .51127 Mdot
.892 .51133 Mdot
.892 .51134 Mdot
.892 .51148 Mdot
.892 .5115 Mdot
.892 .51181 Mdot
.892 .51186 Mdot
.892 .51187 Mdot
.892 .51195 Mdot
.892 .51195 Mdot
.892 .5121 Mdot
.892 .51211 Mdot
.892 .51215 Mdot
.892 .51216 Mdot
.892 .51217 Mdot
.892 .51224 Mdot
.892 .51225 Mdot
.892 .51225 Mdot
.892 .51225 Mdot
.892 .51229 Mdot
.892 .5123 Mdot
.892 .5123 Mdot
.892 .51233 Mdot
.892 .51235 Mdot
.892 .51235 Mdot
.892 .51237 Mdot
.892 .51238 Mdot
.892 .51239 Mdot
.892 .51241 Mdot
.892 .51243 Mdot
.892 .51243 Mdot
.892 .51244 Mdot
.892 .51245 Mdot
.892 .51245 Mdot
.892 .51246 Mdot
.892 .51246 Mdot
.892 .51247 Mdot
.892 .51247 Mdot
.892 .5125 Mdot
.892 .51256 Mdot
.892 .51256 Mdot
.892 .51259 Mdot
.892 .51262 Mdot
.892 .51263 Mdot
.892 .51264 Mdot
.892 .51265 Mdot
.892 .5127 Mdot
.892 .51272 Mdot
.892 .51284 Mdot
.892 .51284 Mdot
.892 .51289 Mdot
.892 .51293 Mdot
.892 .51296 Mdot
.892 .51298 Mdot
.892 .51308 Mdot
.892 .51317 Mdot
.892 .51319 Mdot
.892 .51319 Mdot
.892 .51327 Mdot
.892 .51328 Mdot
.892 .51343 Mdot
.892 .51356 Mdot
.892 .5136 Mdot
.892 .51363 Mdot
.892 .51367 Mdot
.892 .51369 Mdot
.892 .51372 Mdot
.892 .51379 Mdot
.892 .51381 Mdot
.892 .51381 Mdot
.892 .51384 Mdot
.892 .51396 Mdot
.892 .51403 Mdot
.892 .51406 Mdot
.892 .51414 Mdot
.892 .51416 Mdot
.892 .51417 Mdot
.892 .51437 Mdot
.892 .5144 Mdot
.892 .51449 Mdot
.892 .51466 Mdot
.892 .51467 Mdot
.892 .51478 Mdot
.892 .51484 Mdot
.892 .51486 Mdot
.892 .51495 Mdot
.892 .51498 Mdot
.892 .51503 Mdot
.892 .51512 Mdot
.892 .51513 Mdot
.892 .51515 Mdot
.892 .51524 Mdot
.892 .51529 Mdot
.892 .51559 Mdot
.892 .51569 Mdot
.892 .5157 Mdot
.892 .5157 Mdot
.892 .51579 Mdot
.892 .51582 Mdot
.892 .51589 Mdot
.892 .51593 Mdot
.892 .51593 Mdot
.892 .51599 Mdot
.892 .516 Mdot
.892 .51601 Mdot
.892 .51601 Mdot
.892 .51607 Mdot
.892 .5161 Mdot
.892 .51615 Mdot
.892 .51619 Mdot
.892 .51629 Mdot
.892 .51635 Mdot
.892 .51637 Mdot
.892 .51638 Mdot
.892 .51644 Mdot
.892 .5165 Mdot
.892 .51652 Mdot
.892 .51652 Mdot
.892 .51653 Mdot
.892 .51655 Mdot
.892 .5166 Mdot
.892 .51661 Mdot
.892 .51663 Mdot
.892 .51668 Mdot
.892 .51669 Mdot
.892 .51696 Mdot
.892 .51697 Mdot
.892 .51701 Mdot
.892 .51712 Mdot
.892 .51712 Mdot
.892 .51714 Mdot
.892 .51723 Mdot
.892 .51723 Mdot
.892 .51734 Mdot
.892 .51739 Mdot
.892 .51744 Mdot
.892 .5175 Mdot
.892 .51754 Mdot
.892 .51757 Mdot
.892 .51761 Mdot
.892 .51766 Mdot
.892 .5177 Mdot
.892 .51784 Mdot
.892 .51797 Mdot
.892 .51805 Mdot
.892 .51807 Mdot
.892 .51814 Mdot
.892 .51818 Mdot
.892 .51824 Mdot
.892 .5183 Mdot
.892 .5183 Mdot
.892 .51839 Mdot
.892 .51839 Mdot
.892 .51841 Mdot
.892 .51842 Mdot
.892 .51842 Mdot
.892 .51842 Mdot
.892 .51842 Mdot
.892 .51859 Mdot
.892 .51865 Mdot
.892 .51878 Mdot
.892 .51892 Mdot
.892 .51907 Mdot
.892 .51909 Mdot
.892 .51946 Mdot
.892 .51953 Mdot
.892 .52 Mdot
.892 .52109 Mdot
.892 .5225 Mdot
.892 .52288 Mdot
.892 .52291 Mdot
.892 .52291 Mdot
.892 .52315 Mdot
.892 .52317 Mdot
.892 .52335 Mdot
.892 .52358 Mdot
.892 .5236 Mdot
.892 .52377 Mdot
.892 .52424 Mdot
.892 .52426 Mdot
.892 .52429 Mdot
.892 .52442 Mdot
.892 .5245 Mdot
.892 .52466 Mdot
.892 .52466 Mdot
.892 .5247 Mdot
.892 .52471 Mdot
.892 .52489 Mdot
.892 .52506 Mdot
.892 .52527 Mdot
.892 .52542 Mdot
.892 .52575 Mdot
.892 .52601 Mdot
.892 .52627 Mdot
.892 .52644 Mdot
.892 .52702 Mdot
.892 .52718 Mdot
.892 .52729 Mdot
.892 .52732 Mdot
.892 .52764 Mdot
.892 .52792 Mdot
.892 .52804 Mdot
.892 .52908 Mdot
.892 .5291 Mdot
.892 .52912 Mdot
.892 .52912 Mdot
.892 .52918 Mdot
.892 .52933 Mdot
.892 .52934 Mdot
.892 .5294 Mdot
.892 .5296 Mdot
.892 .52964 Mdot
.892 .53 Mdot
.892 .53001 Mdot
.892 .53003 Mdot
.892 .53004 Mdot
.892 .53052 Mdot
.892 .53063 Mdot
.892 .53068 Mdot
.892 .53084 Mdot
.892 .53087 Mdot
.892 .53089 Mdot
.892 .53093 Mdot
.892 .53095 Mdot
.892 .53122 Mdot
.892 .53125 Mdot
.892 .53129 Mdot
.892 .53129 Mdot
.892 .53129 Mdot
.892 .53143 Mdot
.892 .53147 Mdot
.892 .53149 Mdot
.892 .5315 Mdot
.892 .53162 Mdot
.892 .53169 Mdot
.892 .53169 Mdot
.892 .53171 Mdot
.892 .53176 Mdot
.892 .53182 Mdot
.892 .53185 Mdot
.892 .53187 Mdot
.892 .53195 Mdot
.892 .53203 Mdot
.892 .53203 Mdot
.892 .53209 Mdot
.892 .5321 Mdot
.892 .53213 Mdot
.892 .53215 Mdot
.892 .53217 Mdot
.892 .53219 Mdot
.892 .53221 Mdot
.892 .53234 Mdot
.892 .53239 Mdot
.892 .53257 Mdot
.892 .53257 Mdot
.892 .53269 Mdot
.892 .53281 Mdot
.892 .53286 Mdot
.892 .5329 Mdot
.892 .53295 Mdot
.892 .53314 Mdot
.892 .53322 Mdot
.892 .53327 Mdot
.892 .53369 Mdot
.892 .53369 Mdot
.892 .53369 Mdot
.892 .53388 Mdot
.892 .53389 Mdot
.892 .53402 Mdot
.892 .53408 Mdot
.892 .53413 Mdot
.892 .53424 Mdot
.892 .53432 Mdot
.892 .53462 Mdot
.892 .53463 Mdot
.892 .53481 Mdot
.892 .53493 Mdot
.892 .53497 Mdot
.892 .53499 Mdot
.892 .53501 Mdot
.892 .53517 Mdot
.892 .53529 Mdot
.892 .53533 Mdot
.892 .53551 Mdot
.892 .53572 Mdot
.892 .53581 Mdot
.892 .53586 Mdot
.892 .53599 Mdot
.892 .53627 Mdot
.892 .5364 Mdot
.892 .53646 Mdot
.892 .53648 Mdot
.892 .53652 Mdot
.892 .53664 Mdot
.892 .53669 Mdot
.892 .5368 Mdot
.892 .53685 Mdot
.892 .53691 Mdot
.892 .53694 Mdot
.892 .53695 Mdot
.892 .53701 Mdot
.892 .53705 Mdot
.892 .53707 Mdot
.892 .53714 Mdot
.892 .53736 Mdot
.892 .53749 Mdot
.892 .53749 Mdot
.892 .53754 Mdot
.892 .53769 Mdot
.892 .53776 Mdot
.892 .53787 Mdot
.892 .53798 Mdot
.892 .53804 Mdot
.892 .53804 Mdot
.892 .53815 Mdot
.892 .53838 Mdot
.892 .53843 Mdot
.892 .53852 Mdot
.892 .53856 Mdot
.892 .53859 Mdot
.892 .53861 Mdot
.892 .53863 Mdot
.892 .53877 Mdot
.892 .53879 Mdot
.892 .53881 Mdot
.892 .53883 Mdot
.892 .53883 Mdot
.892 .53888 Mdot
.892 .539 Mdot
.892 .5391 Mdot
.892 .53912 Mdot
.892 .53913 Mdot
.892 .53916 Mdot
.892 .5392 Mdot
.892 .5393 Mdot
.892 .5393 Mdot
.892 .53939 Mdot
.892 .53942 Mdot
.892 .53943 Mdot
.892 .53946 Mdot
.892 .53953 Mdot
.892 .53954 Mdot
.892 .53958 Mdot
.892 .53959 Mdot
.892 .53963 Mdot
.892 .53963 Mdot
.892 .53969 Mdot
.892 .5397 Mdot
.892 .5397 Mdot
.892 .53971 Mdot
.892 .53972 Mdot
.892 .53973 Mdot
.892 .53975 Mdot
.892 .53977 Mdot
.892 .53977 Mdot
.892 .5398 Mdot
.892 .53982 Mdot
.892 .53985 Mdot
.892 .53985 Mdot
.892 .53986 Mdot
.892 .5399 Mdot
.892 .5399 Mdot
.892 .5399 Mdot
.892 .53992 Mdot
.894 .16601 Mdot
.894 .16603 Mdot
.894 .16608 Mdot
.894 .16617 Mdot
.894 .16626 Mdot
.894 .16627 Mdot
.894 .16631 Mdot
.894 .16632 Mdot
.894 .16638 Mdot
.894 .16648 Mdot
.894 .16668 Mdot
.894 .16672 Mdot
.894 .16676 Mdot
.894 .16676 Mdot
.894 .16694 Mdot
.894 .16709 Mdot
.894 .1673 Mdot
.894 .16768 Mdot
.894 .16789 Mdot
.894 .16813 Mdot
.894 .16853 Mdot
.894 .16865 Mdot
.894 .16869 Mdot
.894 .169 Mdot
.894 .16909 Mdot
.894 .16912 Mdot
.894 .16984 Mdot
.894 .17005 Mdot
.894 .17035 Mdot
.894 .17085 Mdot
.894 .17093 Mdot
.894 .17121 Mdot
.894 .17126 Mdot
.894 .17159 Mdot
.894 .17184 Mdot
.894 .17185 Mdot
.894 .17251 Mdot
.894 .17324 Mdot
.894 .17336 Mdot
.894 .17361 Mdot
.894 .17362 Mdot
.894 .17396 Mdot
.894 .1741 Mdot
.894 .17421 Mdot
.894 .17424 Mdot
.894 .17494 Mdot
.894 .17554 Mdot
.894 .17582 Mdot
.894 .17598 Mdot
.894 .17678 Mdot
.894 .17711 Mdot
.894 .1775 Mdot
.894 .17773 Mdot
.894 .17794 Mdot
.894 .178 Mdot
.894 .178 Mdot
.894 .17841 Mdot
.894 .17867 Mdot
.894 .1788 Mdot
.894 .17883 Mdot
.894 .1789 Mdot
.894 .17928 Mdot
.894 .17971 Mdot
.894 .17984 Mdot
.894 .18077 Mdot
.894 .18242 Mdot
.894 .1825 Mdot
.894 .18271 Mdot
.894 .18336 Mdot
.894 .18348 Mdot
.894 .18399 Mdot
.894 .18422 Mdot
.894 .18431 Mdot
.894 .1845 Mdot
.894 .18485 Mdot
.894 .18515 Mdot
.894 .1858 Mdot
.894 .18595 Mdot
.894 .18655 Mdot
.894 .18661 Mdot
.894 .18662 Mdot
.894 .1871 Mdot
.894 .18733 Mdot
.894 .18734 Mdot
.894 .18787 Mdot
.894 .18855 Mdot
.894 .18898 Mdot
.894 .18906 Mdot
.894 .18906 Mdot
.894 .18989 Mdot
.894 .19015 Mdot
.894 .19028 Mdot
.894 .19087 Mdot
.894 .19149 Mdot
.894 .19156 Mdot
.894 .19166 Mdot
.894 .1919 Mdot
.894 .19202 Mdot
.894 .19204 Mdot
.894 .19209 Mdot
.894 .19217 Mdot
.894 .19234 Mdot
.894 .19244 Mdot
.894 .19292 Mdot
.894 .19343 Mdot
.894 .19345 Mdot
.894 .19346 Mdot
.894 .19351 Mdot
.894 .19356 Mdot
.894 .19366 Mdot
.894 .1937 Mdot
.894 .19386 Mdot
.894 .19401 Mdot
.894 .19451 Mdot
.894 .19464 Mdot
.894 .19496 Mdot
.894 .19504 Mdot
.894 .19511 Mdot
.894 .19541 Mdot
.894 .19559 Mdot
.894 .19575 Mdot
.894 .19575 Mdot
.894 .19599 Mdot
.894 .1962 Mdot
.894 .19646 Mdot
.894 .19649 Mdot
.894 .19703 Mdot
.894 .19718 Mdot
.894 .19743 Mdot
.894 .19763 Mdot
.894 .19773 Mdot
.894 .19819 Mdot
.894 .19856 Mdot
.894 .19876 Mdot
.894 .19877 Mdot
.894 .19921 Mdot
.894 .19938 Mdot
.894 .19963 Mdot
.894 .19972 Mdot
.894 .19995 Mdot
.894 .20009 Mdot
.894 .20011 Mdot
.894 .20019 Mdot
.894 .20022 Mdot
.894 .20029 Mdot
.894 .2003 Mdot
.894 .2003 Mdot
.894 .20203 Mdot
.894 .20207 Mdot
.894 .2024 Mdot
.894 .20353 Mdot
.894 .2041 Mdot
.894 .20519 Mdot
.894 .20726 Mdot
.894 .20817 Mdot
.894 .20866 Mdot
.894 .20893 Mdot
.894 .20899 Mdot
.894 .21018 Mdot
.894 .21029 Mdot
.894 .21107 Mdot
.894 .21186 Mdot
.894 .21191 Mdot
.894 .21199 Mdot
.894 .2128 Mdot
.894 .21384 Mdot
.894 .21447 Mdot
.894 .2174 Mdot
.894 .21748 Mdot
.894 .2178 Mdot
.894 .2178 Mdot
.894 .21824 Mdot
.894 .21972 Mdot
.894 .21981 Mdot
.894 .21981 Mdot
.894 .21995 Mdot
.894 .22081 Mdot
.894 .22093 Mdot
.894 .22119 Mdot
.894 .22268 Mdot
.894 .22302 Mdot
.894 .22376 Mdot
.894 .22386 Mdot
.894 .22455 Mdot
.894 .2257 Mdot
.894 .22627 Mdot
.894 .22644 Mdot
.894 .22668 Mdot
.894 .22689 Mdot
.894 .227 Mdot
.894 .2273 Mdot
.894 .22732 Mdot
.894 .22732 Mdot
.894 .22892 Mdot
.894 .23437 Mdot
.894 .24186 Mdot
.894 .26241 Mdot
.894 .26307 Mdot
.894 .26351 Mdot
.894 .26499 Mdot
.894 .26556 Mdot
.894 .26589 Mdot
.894 .26622 Mdot
.894 .267 Mdot
.894 .26981 Mdot
.894 .27033 Mdot
.894 .27052 Mdot
.894 .27055 Mdot
.894 .27058 Mdot
.894 .2706 Mdot
.894 .27114 Mdot
.894 .27126 Mdot
.894 .27142 Mdot
.894 .27147 Mdot
.894 .27151 Mdot
.894 .27312 Mdot
.894 .27407 Mdot
.894 .27427 Mdot
.894 .27428 Mdot
.894 .27429 Mdot
.894 .27445 Mdot
.894 .2745 Mdot
.894 .27468 Mdot
.894 .27472 Mdot
.894 .27479 Mdot
.894 .27503 Mdot
.894 .27541 Mdot
.894 .2755 Mdot
.894 .2755 Mdot
.894 .27554 Mdot
.894 .27563 Mdot
.894 .27564 Mdot
.894 .27575 Mdot
.894 .27577 Mdot
.894 .27601 Mdot
.894 .27621 Mdot
.894 .27623 Mdot
.894 .27636 Mdot
.894 .27676 Mdot
.894 .27717 Mdot
.894 .27719 Mdot
.894 .2776 Mdot
.894 .27789 Mdot
.894 .27794 Mdot
.894 .27842 Mdot
.894 .27846 Mdot
.894 .27857 Mdot
.894 .27864 Mdot
.894 .27915 Mdot
.894 .27924 Mdot
.894 .27949 Mdot
.894 .27952 Mdot
.894 .27972 Mdot
.894 .28034 Mdot
.894 .2805 Mdot
.894 .28058 Mdot
.894 .28081 Mdot
.894 .2811 Mdot
.894 .28168 Mdot
.894 .28185 Mdot
.894 .28217 Mdot
.894 .28241 Mdot
.894 .28288 Mdot
.894 .28315 Mdot
.894 .28385 Mdot
.894 .28424 Mdot
.894 .28442 Mdot
.894 .28443 Mdot
.894 .28451 Mdot
.894 .28461 Mdot
.894 .28499 Mdot
.894 .28504 Mdot
.894 .28508 Mdot
.894 .2854 Mdot
.894 .28558 Mdot
.894 .28602 Mdot
.894 .2865 Mdot
.894 .28674 Mdot
.894 .28676 Mdot
.894 .28713 Mdot
.894 .28723 Mdot
.894 .28775 Mdot
.894 .28777 Mdot
.894 .288 Mdot
.894 .28827 Mdot
.894 .28867 Mdot
.894 .28887 Mdot
.894 .28888 Mdot
.894 .28912 Mdot
.894 .28931 Mdot
.894 .28969 Mdot
.894 .2899 Mdot
.894 .28997 Mdot
.894 .29003 Mdot
.894 .29004 Mdot
.894 .29005 Mdot
.894 .29016 Mdot
.894 .29023 Mdot
.894 .29027 Mdot
.894 .2904 Mdot
.894 .29052 Mdot
.894 .29055 Mdot
.894 .29121 Mdot
.894 .29123 Mdot
.894 .29159 Mdot
.894 .29164 Mdot
.894 .29167 Mdot
.894 .29179 Mdot
.894 .29186 Mdot
.894 .29219 Mdot
.894 .29261 Mdot
.894 .29271 Mdot
.894 .29272 Mdot
.894 .29272 Mdot
.894 .2929 Mdot
.894 .29298 Mdot
.894 .2931 Mdot
.894 .29323 Mdot
.894 .29324 Mdot
.894 .29331 Mdot
.894 .29334 Mdot
.894 .29334 Mdot
.894 .29337 Mdot
.894 .29342 Mdot
.894 .29352 Mdot
.894 .29362 Mdot
.894 .29362 Mdot
.894 .29363 Mdot
.894 .29364 Mdot
.894 .29366 Mdot
.894 .29367 Mdot
.894 .29373 Mdot
.894 .29383 Mdot
.894 .29386 Mdot
.894 .29401 Mdot
.894 .29404 Mdot
.894 .29407 Mdot
.894 .29407 Mdot
.894 .29412 Mdot
.894 .29416 Mdot
.894 .29421 Mdot
.894 .29432 Mdot
.894 .29435 Mdot
.894 .29439 Mdot
.894 .29443 Mdot
.894 .29445 Mdot
.894 .29453 Mdot
.894 .2946 Mdot
.894 .29464 Mdot
.894 .29464 Mdot
.894 .29472 Mdot
.894 .29475 Mdot
.894 .2948 Mdot
.894 .29482 Mdot
.894 .29486 Mdot
.894 .29488 Mdot
.894 .29489 Mdot
.894 .2949 Mdot
.894 .29491 Mdot
.894 .29492 Mdot
.894 .29492 Mdot
.894 .29492 Mdot
.894 .29524 Mdot
.894 .29524 Mdot
.894 .2953 Mdot
.894 .2956 Mdot
.894 .29579 Mdot
.894 .29615 Mdot
.894 .29631 Mdot
.894 .29639 Mdot
.894 .29644 Mdot
.894 .29645 Mdot
.894 .29665 Mdot
.894 .29667 Mdot
.894 .2968 Mdot
.894 .29693 Mdot
.894 .29694 Mdot
.894 .29695 Mdot
.894 .29709 Mdot
.894 .29726 Mdot
.894 .29736 Mdot
.894 .29786 Mdot
.894 .29791 Mdot
.894 .29822 Mdot
.894 .29823 Mdot
.894 .29826 Mdot
.894 .2984 Mdot
.894 .29846 Mdot
.894 .2987 Mdot
.894 .29887 Mdot
.894 .29888 Mdot
.894 .29899 Mdot
.894 .29918 Mdot
.894 .29933 Mdot
.894 .29937 Mdot
.894 .29943 Mdot
.894 .29944 Mdot
.894 .29944 Mdot
.894 .30573 Mdot
.894 .30682 Mdot
.894 .30682 Mdot
.894 .30694 Mdot
.894 .30696 Mdot
.894 .307 Mdot
.894 .30701 Mdot
.894 .30759 Mdot
.894 .3076 Mdot
.894 .3076 Mdot
.894 .30763 Mdot
.894 .30764 Mdot
.894 .30768 Mdot
.894 .30769 Mdot
.894 .30771 Mdot
.894 .30776 Mdot
.894 .30787 Mdot
.894 .30792 Mdot
.894 .30805 Mdot
.894 .30814 Mdot
.894 .30824 Mdot
.894 .3084 Mdot
.894 .30841 Mdot
.894 .30853 Mdot
.894 .30858 Mdot
.894 .30878 Mdot
.894 .30878 Mdot
.894 .30883 Mdot
.894 .3091 Mdot
.894 .30917 Mdot
.894 .30932 Mdot
.894 .30951 Mdot
.894 .30963 Mdot
.894 .30989 Mdot
.894 .30999 Mdot
.894 .31004 Mdot
.894 .31007 Mdot
.894 .31009 Mdot
.894 .31031 Mdot
.894 .31049 Mdot
.894 .31071 Mdot
.894 .31071 Mdot
.894 .31082 Mdot
.894 .31085 Mdot
.894 .31102 Mdot
.894 .3113 Mdot
.894 .31137 Mdot
.894 .31145 Mdot
.894 .31176 Mdot
.894 .31176 Mdot
.894 .31183 Mdot
.894 .31189 Mdot
.894 .31193 Mdot
.894 .3124 Mdot
.894 .31255 Mdot
.894 .31272 Mdot
.894 .31277 Mdot
.894 .31287 Mdot
.894 .31292 Mdot
.894 .31298 Mdot
.894 .31298 Mdot
.894 .31301 Mdot
.894 .31302 Mdot
.894 .31356 Mdot
.894 .3141 Mdot
.894 .31421 Mdot
.894 .31441 Mdot
.894 .3145 Mdot
.894 .31455 Mdot
.894 .31458 Mdot
.894 .31459 Mdot
.894 .31472 Mdot
.894 .315 Mdot
.894 .31512 Mdot
.894 .3152 Mdot
.894 .31562 Mdot
.894 .31594 Mdot
.894 .31614 Mdot
.894 .31665 Mdot
.894 .31682 Mdot
.894 .31714 Mdot
.894 .31818 Mdot
.894 .31819 Mdot
.894 .31829 Mdot
.894 .31883 Mdot
.894 .31971 Mdot
.894 .32039 Mdot
.894 .32041 Mdot
.894 .32071 Mdot
.894 .32133 Mdot
.894 .32134 Mdot
.894 .32134 Mdot
.894 .32142 Mdot
.894 .32151 Mdot
.894 .3222 Mdot
.894 .32223 Mdot
.894 .32224 Mdot
.894 .32239 Mdot
.894 .32325 Mdot
.894 .32325 Mdot
.894 .32363 Mdot
.894 .32407 Mdot
.894 .32432 Mdot
.894 .32444 Mdot
.894 .32474 Mdot
.894 .32538 Mdot
.894 .32553 Mdot
.894 .32634 Mdot
.894 .3266 Mdot
.894 .3267 Mdot
.894 .32688 Mdot
.894 .32711 Mdot
.894 .32712 Mdot
.894 .32747 Mdot
.894 .32868 Mdot
.894 .32972 Mdot
.894 .32981 Mdot
.894 .32986 Mdot
.894 .33013 Mdot
.894 .33033 Mdot
.894 .33073 Mdot
.894 .33081 Mdot
.894 .33084 Mdot
.894 .33085 Mdot
.894 .33097 Mdot
.894 .33124 Mdot
.894 .33164 Mdot
.894 .33164 Mdot
.894 .33171 Mdot
.894 .33191 Mdot
.894 .33213 Mdot
.894 .33248 Mdot
.894 .33278 Mdot
.894 .33346 Mdot
.894 .33359 Mdot
.894 .33381 Mdot
.894 .33425 Mdot
.894 .33473 Mdot
.894 .33475 Mdot
.894 .33482 Mdot
.894 .3349 Mdot
.894 .3351 Mdot
.894 .33511 Mdot
.894 .33524 Mdot
.894 .33525 Mdot
.894 .33531 Mdot
.894 .33567 Mdot
.894 .33584 Mdot
.894 .33585 Mdot
.894 .33587 Mdot
.894 .3359 Mdot
.894 .33594 Mdot
.894 .33594 Mdot
.894 .33594 Mdot
.894 .33595 Mdot
.894 .33596 Mdot
.894 .33596 Mdot
.894 .33599 Mdot
.894 .33602 Mdot
.894 .33603 Mdot
.894 .33609 Mdot
.894 .33611 Mdot
.894 .33612 Mdot
.894 .33612 Mdot
.894 .33614 Mdot
.894 .33616 Mdot
.894 .33618 Mdot
.894 .33622 Mdot
.894 .33623 Mdot
.894 .33625 Mdot
.894 .33627 Mdot
.894 .33627 Mdot
.894 .33634 Mdot
.894 .33636 Mdot
.894 .33636 Mdot
.894 .33639 Mdot
.894 .33641 Mdot
.894 .33643 Mdot
.894 .33643 Mdot
.894 .33646 Mdot
.894 .33647 Mdot
.894 .33647 Mdot
.894 .33648 Mdot
.894 .33648 Mdot
.894 .33648 Mdot
.894 .33861 Mdot
.894 .33893 Mdot
.894 .34121 Mdot
.894 .34514 Mdot
.894 .34714 Mdot
.894 .34777 Mdot
.894 .34866 Mdot
.894 .34941 Mdot
.894 .34981 Mdot
.894 .35093 Mdot
.894 .35099 Mdot
.894 .351 Mdot
.894 .3571 Mdot
.894 .38017 Mdot
.894 .38793 Mdot
.894 .4155 Mdot
.894 .42278 Mdot
.894 .50593 Mdot
.894 .50812 Mdot
.894 .50953 Mdot
.894 .51143 Mdot
.894 .51143 Mdot
.894 .51143 Mdot
.894 .51145 Mdot
.894 .51146 Mdot
.894 .51151 Mdot
.894 .51156 Mdot
.894 .51159 Mdot
.894 .5116 Mdot
.894 .51165 Mdot
.894 .51172 Mdot
.894 .51173 Mdot
.894 .51177 Mdot
.894 .51178 Mdot
.894 .51178 Mdot
.894 .51187 Mdot
.894 .51189 Mdot
.894 .51203 Mdot
.894 .51206 Mdot
.894 .5121 Mdot
.894 .51214 Mdot
.894 .51215 Mdot
.894 .51215 Mdot
.894 .51219 Mdot
.894 .51222 Mdot
.894 .51223 Mdot
.894 .51228 Mdot
.894 .51229 Mdot
.894 .5123 Mdot
.894 .51232 Mdot
.894 .51237 Mdot
.894 .51247 Mdot
.894 .51252 Mdot
.894 .5126 Mdot
.894 .51262 Mdot
.894 .51262 Mdot
.894 .51271 Mdot
.894 .51271 Mdot
.894 .51271 Mdot
.894 .51271 Mdot
.894 .51271 Mdot
.894 .51272 Mdot
.894 .51272 Mdot
.894 .51273 Mdot
.894 .51274 Mdot
.894 .51274 Mdot
.894 .51276 Mdot
.894 .51276 Mdot
.894 .51279 Mdot
.894 .51279 Mdot
.894 .5128 Mdot
.894 .51282 Mdot
.894 .51284 Mdot
.894 .51284 Mdot
.894 .51285 Mdot
.894 .51287 Mdot
.894 .51288 Mdot
.894 .5129 Mdot
.894 .51292 Mdot
.894 .51293 Mdot
.894 .51294 Mdot
.894 .51294 Mdot
.894 .51295 Mdot
.894 .51296 Mdot
.894 .513 Mdot
.894 .51301 Mdot
.894 .51303 Mdot
.894 .51305 Mdot
.894 .51305 Mdot
.894 .51306 Mdot
.894 .51306 Mdot
.894 .51306 Mdot
.894 .51307 Mdot
.894 .51309 Mdot
.894 .51312 Mdot
.894 .51313 Mdot
.894 .51314 Mdot
.894 .51314 Mdot
.894 .51315 Mdot
.894 .51317 Mdot
.894 .51317 Mdot
.894 .51321 Mdot
.894 .51324 Mdot
.894 .51326 Mdot
.894 .51331 Mdot
.894 .51331 Mdot
.894 .51331 Mdot
.894 .51334 Mdot
.894 .51345 Mdot
.894 .51354 Mdot
.894 .51356 Mdot
.894 .51359 Mdot
.894 .5136 Mdot
.894 .51361 Mdot
.894 .51371 Mdot
.894 .51371 Mdot
.894 .51389 Mdot
.894 .5139 Mdot
.894 .51393 Mdot
.894 .51396 Mdot
.894 .51397 Mdot
.894 .51399 Mdot
.894 .51402 Mdot
.894 .51402 Mdot
.894 .51403 Mdot
.894 .51404 Mdot
.894 .51406 Mdot
.894 .51411 Mdot
.894 .51421 Mdot
.894 .51426 Mdot
.894 .51433 Mdot
.894 .51433 Mdot
.894 .51438 Mdot
.894 .51449 Mdot
.894 .51455 Mdot
.894 .51461 Mdot
.894 .51462 Mdot
.894 .51475 Mdot
.894 .51478 Mdot
.894 .51487 Mdot
.894 .51488 Mdot
.894 .51494 Mdot
.894 .51506 Mdot
.894 .51517 Mdot
.894 .51522 Mdot
.894 .5153 Mdot
.894 .51531 Mdot
.894 .51532 Mdot
.894 .51542 Mdot
.894 .51544 Mdot
.894 .51546 Mdot
.894 .51547 Mdot
.894 .51551 Mdot
.894 .51561 Mdot
.894 .51578 Mdot
.894 .51585 Mdot
.894 .51597 Mdot
.894 .51603 Mdot
.894 .51611 Mdot
.894 .51615 Mdot
.894 .51629 Mdot
.894 .51636 Mdot
.894 .51642 Mdot
.894 .51644 Mdot
.894 .51648 Mdot
.894 .51663 Mdot
.894 .51668 Mdot
.894 .51668 Mdot
.894 .51674 Mdot
.894 .51677 Mdot
.894 .51689 Mdot
.894 .51691 Mdot
.894 .51693 Mdot
.894 .51694 Mdot
.894 .51706 Mdot
.894 .51707 Mdot
.894 .51714 Mdot
.894 .51724 Mdot
.894 .51724 Mdot
.894 .51734 Mdot
.894 .51744 Mdot
.894 .51747 Mdot
.894 .51747 Mdot
.894 .51752 Mdot
.894 .51757 Mdot
.894 .51758 Mdot
.894 .51761 Mdot
.894 .51761 Mdot
.894 .51763 Mdot
.894 .51764 Mdot
.894 .51764 Mdot
.894 .51766 Mdot
.894 .51775 Mdot
.894 .51781 Mdot
.894 .51782 Mdot
.894 .51783 Mdot
.894 .51788 Mdot
.894 .51789 Mdot
.894 .51792 Mdot
.894 .51793 Mdot
.894 .51793 Mdot
.894 .51798 Mdot
.894 .5182 Mdot
.894 .51857 Mdot
.894 .51858 Mdot
.894 .51859 Mdot
.894 .51863 Mdot
.894 .51866 Mdot
.894 .51878 Mdot
.894 .51879 Mdot
.894 .51879 Mdot
.894 .5188 Mdot
.894 .51884 Mdot
.894 .51897 Mdot
.894 .51961 Mdot
.894 .51978 Mdot
.894 .51986 Mdot
.894 .51993 Mdot
.894 .52006 Mdot
.894 .52039 Mdot
.894 .52049 Mdot
.894 .52063 Mdot
.894 .52505 Mdot
.894 .52661 Mdot
.894 .52773 Mdot
.894 .52806 Mdot
.894 .52806 Mdot
.894 .52807 Mdot
.894 .52813 Mdot
.894 .52815 Mdot
.894 .52819 Mdot
.894 .52824 Mdot
.894 .52828 Mdot
.894 .5284 Mdot
.894 .52863 Mdot
.894 .52877 Mdot
.894 .52879 Mdot
.894 .52895 Mdot
.894 .52901 Mdot
.894 .52932 Mdot
.894 .52937 Mdot
.894 .5294 Mdot
.894 .52958 Mdot
.894 .5296 Mdot
.894 .5296 Mdot
.894 .52962 Mdot
.894 .52992 Mdot
.894 .53001 Mdot
.894 .53002 Mdot
.894 .53008 Mdot
.894 .5301 Mdot
.894 .5307 Mdot
.894 .53083 Mdot
.894 .53104 Mdot
.894 .53121 Mdot
.894 .53122 Mdot
.894 .53123 Mdot
.894 .5314 Mdot
.894 .53156 Mdot
.894 .53158 Mdot
.894 .53182 Mdot
.894 .53184 Mdot
.894 .53189 Mdot
.894 .53199 Mdot
.894 .53218 Mdot
.894 .53261 Mdot
.894 .53283 Mdot
.894 .53295 Mdot
.894 .53319 Mdot
.894 .53326 Mdot
.894 .53326 Mdot
.894 .53362 Mdot
.894 .53362 Mdot
.894 .53362 Mdot
.894 .53364 Mdot
.894 .53364 Mdot
.894 .53366 Mdot
.894 .53367 Mdot
.894 .5337 Mdot
.894 .53374 Mdot
.894 .53376 Mdot
.894 .53381 Mdot
.894 .53385 Mdot
.894 .53394 Mdot
.894 .53394 Mdot
.894 .53398 Mdot
.894 .53406 Mdot
.894 .53416 Mdot
.894 .53418 Mdot
.894 .53422 Mdot
.894 .53427 Mdot
.894 .53431 Mdot
.894 .53442 Mdot
.894 .53442 Mdot
.894 .53448 Mdot
.894 .53452 Mdot
.894 .53457 Mdot
.894 .53457 Mdot
.894 .53461 Mdot
.894 .53464 Mdot
.894 .53471 Mdot
.894 .53472 Mdot
.894 .53474 Mdot
.894 .53481 Mdot
.894 .53483 Mdot
.894 .53494 Mdot
.894 .53497 Mdot
.894 .535 Mdot
.894 .53501 Mdot
.894 .53503 Mdot
.894 .53504 Mdot
.894 .53505 Mdot
.894 .53506 Mdot
.894 .53506 Mdot
.894 .53517 Mdot
.894 .53527 Mdot
.894 .53529 Mdot
.894 .53533 Mdot
.894 .53534 Mdot
.894 .53535 Mdot
.894 .53536 Mdot
.894 .53538 Mdot
.894 .53543 Mdot
.894 .53546 Mdot
.894 .53547 Mdot
.894 .5356 Mdot
.894 .53573 Mdot
.894 .53575 Mdot
.894 .53581 Mdot
.894 .53599 Mdot
.894 .53599 Mdot
.894 .536 Mdot
.894 .5361 Mdot
.894 .53624 Mdot
.894 .53635 Mdot
.894 .53636 Mdot
.894 .53641 Mdot
.894 .53651 Mdot
.894 .53651 Mdot
.894 .53652 Mdot
.894 .53665 Mdot
.894 .53668 Mdot
.894 .53682 Mdot
.894 .53689 Mdot
.894 .53696 Mdot
.894 .537 Mdot
.894 .53702 Mdot
.894 .53707 Mdot
.894 .53718 Mdot
.894 .53721 Mdot
.894 .53735 Mdot
.894 .5374 Mdot
.894 .53741 Mdot
.894 .53777 Mdot
.894 .53798 Mdot
.894 .538 Mdot
.894 .5381 Mdot
.894 .53818 Mdot
.894 .5382 Mdot
.894 .5382 Mdot
.894 .53823 Mdot
.894 .53829 Mdot
.894 .53838 Mdot
.894 .53838 Mdot
.894 .53839 Mdot
.894 .53844 Mdot
.894 .53849 Mdot
.894 .53858 Mdot
.894 .53865 Mdot
.894 .53883 Mdot
.894 .53886 Mdot
.894 .53893 Mdot
.894 .53906 Mdot
.894 .53922 Mdot
.894 .53922 Mdot
.894 .53925 Mdot
.894 .53928 Mdot
.894 .53936 Mdot
.894 .53936 Mdot
.894 .53941 Mdot
.894 .53944 Mdot
.894 .53961 Mdot
.894 .53976 Mdot
.894 .53976 Mdot
.894 .53981 Mdot
.894 .53989 Mdot
.894 .5399 Mdot
.894 .53996 Mdot
.894 .53998 Mdot
.894 .5401 Mdot
.894 .54016 Mdot
.894 .54021 Mdot
.894 .54038 Mdot
.894 .54038 Mdot
.894 .54041 Mdot
.894 .54048 Mdot
.894 .54048 Mdot
.894 .54051 Mdot
.894 .5406 Mdot
.894 .54066 Mdot
.894 .54071 Mdot
.894 .5408 Mdot
.894 .54084 Mdot
.894 .54088 Mdot
.894 .54092 Mdot
.894 .54092 Mdot
.894 .54093 Mdot
.894 .54094 Mdot
.894 .54099 Mdot
.894 .54101 Mdot
.894 .54102 Mdot
.894 .54103 Mdot
.894 .54103 Mdot
.894 .54104 Mdot
.894 .54106 Mdot
.894 .54108 Mdot
.894 .54109 Mdot
.894 .54109 Mdot
.896 .16133 Mdot
.896 .16133 Mdot
.896 .16134 Mdot
.896 .16137 Mdot
.896 .16137 Mdot
.896 .16138 Mdot
.896 .16138 Mdot
.896 .16139 Mdot
.896 .16142 Mdot
.896 .16145 Mdot
.896 .1615 Mdot
.896 .16151 Mdot
.896 .16153 Mdot
.896 .16158 Mdot
.896 .16168 Mdot
.896 .1617 Mdot
.896 .16174 Mdot
.896 .16175 Mdot
.896 .16182 Mdot
.896 .1619 Mdot
.896 .16192 Mdot
.896 .16204 Mdot
.896 .16206 Mdot
.896 .1621 Mdot
.896 .16213 Mdot
.896 .1622 Mdot
.896 .16224 Mdot
.896 .16232 Mdot
.896 .16235 Mdot
.896 .16243 Mdot
.896 .16254 Mdot
.896 .16254 Mdot
.896 .16261 Mdot
.896 .16276 Mdot
.896 .16297 Mdot
.896 .163 Mdot
.896 .16311 Mdot
.896 .16322 Mdot
.896 .16331 Mdot
.896 .16337 Mdot
.896 .16351 Mdot
.896 .16394 Mdot
.896 .16395 Mdot
.896 .16395 Mdot
.896 .16395 Mdot
.896 .16395 Mdot
.896 .16396 Mdot
.896 .16427 Mdot
.896 .16442 Mdot
.896 .16464 Mdot
.896 .16468 Mdot
.896 .16469 Mdot
.896 .16473 Mdot
.896 .16478 Mdot
.896 .16479 Mdot
.896 .16505 Mdot
.896 .16512 Mdot
.896 .16522 Mdot
.896 .16528 Mdot
.896 .1653 Mdot
.896 .16553 Mdot
.896 .16554 Mdot
.896 .16635 Mdot
.896 .16656 Mdot
.896 .16661 Mdot
.896 .16665 Mdot
.896 .16692 Mdot
.896 .16724 Mdot
.896 .16756 Mdot
.896 .1676 Mdot
.896 .16763 Mdot
.896 .16763 Mdot
.896 .16764 Mdot
.896 .16767 Mdot
.896 .1677 Mdot
.896 .16773 Mdot
.896 .16808 Mdot
.896 .16826 Mdot
.896 .16832 Mdot
.896 .16833 Mdot
.896 .16914 Mdot
.896 .16914 Mdot
.896 .16961 Mdot
.896 .16972 Mdot
.896 .16989 Mdot
.896 .17037 Mdot
.896 .17041 Mdot
.896 .17043 Mdot
.896 .17043 Mdot
.896 .17048 Mdot
.896 .17053 Mdot
.896 .17082 Mdot
.896 .17084 Mdot
.896 .17093 Mdot
.896 .17131 Mdot
.896 .17134 Mdot
.896 .17159 Mdot
.896 .17164 Mdot
.896 .17187 Mdot
.896 .17213 Mdot
.896 .17217 Mdot
.896 .17218 Mdot
.896 .17242 Mdot
.896 .17271 Mdot
.896 .17276 Mdot
.896 .1743 Mdot
.896 .17463 Mdot
.896 .17489 Mdot
.896 .17521 Mdot
.896 .17551 Mdot
.896 .1756 Mdot
.896 .17631 Mdot
.896 .1765 Mdot
.896 .17652 Mdot
.896 .17655 Mdot
.896 .17678 Mdot
.896 .17687 Mdot
.896 .17732 Mdot
.896 .17783 Mdot
.896 .17847 Mdot
.896 .1788 Mdot
.896 .17883 Mdot
.896 .179 Mdot
.896 .17998 Mdot
.896 .18034 Mdot
.896 .18076 Mdot
.896 .18092 Mdot
.896 .18108 Mdot
.896 .18126 Mdot
.896 .1814 Mdot
.896 .18169 Mdot
.896 .18177 Mdot
.896 .1821 Mdot
.896 .18219 Mdot
.896 .18278 Mdot
.896 .18297 Mdot
.896 .18302 Mdot
.896 .18303 Mdot
.896 .18305 Mdot
.896 .1833 Mdot
.896 .18362 Mdot
.896 .18371 Mdot
.896 .18372 Mdot
.896 .18378 Mdot
.896 .1838 Mdot
.896 .18382 Mdot
.896 .18384 Mdot
.896 .18385 Mdot
.896 .18385 Mdot
.896 .18385 Mdot
.896 .18391 Mdot
.896 .18391 Mdot
.896 .18397 Mdot
.896 .18401 Mdot
.896 .18448 Mdot
.896 .18452 Mdot
.896 .18458 Mdot
.896 .18471 Mdot
.896 .18475 Mdot
.896 .18476 Mdot
.896 .18478 Mdot
.896 .18484 Mdot
.896 .18505 Mdot
.896 .18505 Mdot
.896 .18559 Mdot
.896 .1857 Mdot
.896 .18665 Mdot
.896 .18695 Mdot
.896 .18932 Mdot
.896 .1908 Mdot
.896 .191 Mdot
.896 .19116 Mdot
.896 .19404 Mdot
.896 .19633 Mdot
.896 .19688 Mdot
.896 .19784 Mdot
.896 .1982 Mdot
.896 .19876 Mdot
.896 .19891 Mdot
.896 .19978 Mdot
.896 .19999 Mdot
.896 .20028 Mdot
.896 .20063 Mdot
.896 .20185 Mdot
.896 .20214 Mdot
.896 .20418 Mdot
.896 .2195 Mdot
.896 .22146 Mdot
.896 .22165 Mdot
.896 .22502 Mdot
.896 .23293 Mdot
.896 .23329 Mdot
.896 .24435 Mdot
.896 .25313 Mdot
.896 .25577 Mdot
.896 .25732 Mdot
.896 .25874 Mdot
.896 .2589 Mdot
.896 .25892 Mdot
.896 .26047 Mdot
.896 .2617 Mdot
.896 .26207 Mdot
.896 .26429 Mdot
.896 .26492 Mdot
.896 .26771 Mdot
.896 .26846 Mdot
.896 .26944 Mdot
.896 .26947 Mdot
.896 .27022 Mdot
.896 .27054 Mdot
.896 .27056 Mdot
.896 .27076 Mdot
.896 .27241 Mdot
.896 .27266 Mdot
.896 .27284 Mdot
.896 .27295 Mdot
.896 .27308 Mdot
.896 .2737 Mdot
.896 .27415 Mdot
.896 .27437 Mdot
.896 .27473 Mdot
.896 .27478 Mdot
.896 .27495 Mdot
.896 .27533 Mdot
.896 .27621 Mdot
.896 .27644 Mdot
.896 .2766 Mdot
.896 .27661 Mdot
.896 .27775 Mdot
.896 .27777 Mdot
.896 .27784 Mdot
.896 .27797 Mdot
.896 .27797 Mdot
.896 .27807 Mdot
.896 .27808 Mdot
.896 .27809 Mdot
.896 .2781 Mdot
.896 .27823 Mdot
.896 .27828 Mdot
.896 .27846 Mdot
.896 .27872 Mdot
.896 .27874 Mdot
.896 .27879 Mdot
.896 .27892 Mdot
.896 .27896 Mdot
.896 .27908 Mdot
.896 .2792 Mdot
.896 .2793 Mdot
.896 .27931 Mdot
.896 .27941 Mdot
.896 .27974 Mdot
.896 .27975 Mdot
.896 .27985 Mdot
.896 .27988 Mdot
.896 .27993 Mdot
.896 .28008 Mdot
.896 .28008 Mdot
.896 .28011 Mdot
.896 .28013 Mdot
.896 .28013 Mdot
.896 .28015 Mdot
.896 .2805 Mdot
.896 .2805 Mdot
.896 .28051 Mdot
.896 .28084 Mdot
.896 .28088 Mdot
.896 .28094 Mdot
.896 .28101 Mdot
.896 .28111 Mdot
.896 .28126 Mdot
.896 .28159 Mdot
.896 .2817 Mdot
.896 .28184 Mdot
.896 .2819 Mdot
.896 .28204 Mdot
.896 .28216 Mdot
.896 .28226 Mdot
.896 .28233 Mdot
.896 .28236 Mdot
.896 .28253 Mdot
.896 .2829 Mdot
.896 .28302 Mdot
.896 .28303 Mdot
.896 .28336 Mdot
.896 .28344 Mdot
.896 .28367 Mdot
.896 .2838 Mdot
.896 .2838 Mdot
.896 .28389 Mdot
.896 .28409 Mdot
.896 .28421 Mdot
.896 .28464 Mdot
.896 .28487 Mdot
.896 .28505 Mdot
.896 .28513 Mdot
.896 .2852 Mdot
.896 .28532 Mdot
.896 .28542 Mdot
.896 .28552 Mdot
.896 .28552 Mdot
.896 .28558 Mdot
.896 .28589 Mdot
.896 .28624 Mdot
.896 .2865 Mdot
.896 .28651 Mdot
.896 .28651 Mdot
.896 .28669 Mdot
.896 .28678 Mdot
.896 .28711 Mdot
.896 .28722 Mdot
.896 .2878 Mdot
.896 .28821 Mdot
.896 .28824 Mdot
.896 .28824 Mdot
.896 .28824 Mdot
.896 .28825 Mdot
.896 .28827 Mdot
.896 .2885 Mdot
.896 .28879 Mdot
.896 .28895 Mdot
.896 .28923 Mdot
.896 .28926 Mdot
.896 .28939 Mdot
.896 .28952 Mdot
.896 .28968 Mdot
.896 .28976 Mdot
.896 .28977 Mdot
.896 .28977 Mdot
.896 .28984 Mdot
.896 .28993 Mdot
.896 .28995 Mdot
.896 .29038 Mdot
.896 .29048 Mdot
.896 .29054 Mdot
.896 .29063 Mdot
.896 .29071 Mdot
.896 .29074 Mdot
.896 .29092 Mdot
.896 .29098 Mdot
.896 .29104 Mdot
.896 .29106 Mdot
.896 .2913 Mdot
.896 .29154 Mdot
.896 .29155 Mdot
.896 .29159 Mdot
.896 .29182 Mdot
.896 .29191 Mdot
.896 .292 Mdot
.896 .29204 Mdot
.896 .29208 Mdot
.896 .29212 Mdot
.896 .29215 Mdot
.896 .29222 Mdot
.896 .29223 Mdot
.896 .29231 Mdot
.896 .29233 Mdot
.896 .29246 Mdot
.896 .2925 Mdot
.896 .29251 Mdot
.896 .29251 Mdot
.896 .29252 Mdot
.896 .29264 Mdot
.896 .29266 Mdot
.896 .29266 Mdot
.896 .29268 Mdot
.896 .29268 Mdot
.896 .29268 Mdot
.896 .29269 Mdot
.896 .29269 Mdot
.896 .29269 Mdot
.896 .29269 Mdot
.896 .2927 Mdot
.896 .2927 Mdot
.896 .29272 Mdot
.896 .29273 Mdot
.896 .29282 Mdot
.896 .29283 Mdot
.896 .29285 Mdot
.896 .29287 Mdot
.896 .29288 Mdot
.896 .29289 Mdot
.896 .29289 Mdot
.896 .2929 Mdot
.896 .29295 Mdot
.896 .29295 Mdot
.896 .29308 Mdot
.896 .29414 Mdot
.896 .29417 Mdot
.896 .29514 Mdot
.896 .29524 Mdot
.896 .29541 Mdot
.896 .2956 Mdot
.896 .29579 Mdot
.896 .29584 Mdot
.896 .29611 Mdot
.896 .30748 Mdot
.896 .30764 Mdot
.896 .30771 Mdot
.896 .30811 Mdot
.896 .30826 Mdot
.896 .3084 Mdot
.896 .3085 Mdot
.896 .30897 Mdot
.896 .30907 Mdot
.896 .30943 Mdot
.896 .30968 Mdot
.896 .31041 Mdot
.896 .31087 Mdot
.896 .31303 Mdot
.896 .31626 Mdot
.896 .31646 Mdot
.896 .3167 Mdot
.896 .31699 Mdot
.896 .31854 Mdot
.896 .31928 Mdot
.896 .32016 Mdot
.896 .32159 Mdot
.896 .32198 Mdot
.896 .32321 Mdot
.896 .32336 Mdot
.896 .32406 Mdot
.896 .32406 Mdot
.896 .32433 Mdot
.896 .32441 Mdot
.896 .32443 Mdot
.896 .32445 Mdot
.896 .3245 Mdot
.896 .32467 Mdot
.896 .32475 Mdot
.896 .3248 Mdot
.896 .3254 Mdot
.896 .32545 Mdot
.896 .32553 Mdot
.896 .32553 Mdot
.896 .3256 Mdot
.896 .3256 Mdot
.896 .32561 Mdot
.896 .32561 Mdot
.896 .32565 Mdot
.896 .32566 Mdot
.896 .32569 Mdot
.896 .32578 Mdot
.896 .32578 Mdot
.896 .3259 Mdot
.896 .3263 Mdot
.896 .32661 Mdot
.896 .32664 Mdot
.896 .32665 Mdot
.896 .32671 Mdot
.896 .32696 Mdot
.896 .32701 Mdot
.896 .32767 Mdot
.896 .32779 Mdot
.896 .32819 Mdot
.896 .32828 Mdot
.896 .32863 Mdot
.896 .3288 Mdot
.896 .329 Mdot
.896 .32902 Mdot
.896 .3292 Mdot
.896 .32939 Mdot
.896 .32986 Mdot
.896 .33027 Mdot
.896 .33134 Mdot
.896 .33151 Mdot
.896 .33154 Mdot
.896 .33188 Mdot
.896 .33232 Mdot
.896 .33252 Mdot
.896 .33277 Mdot
.896 .33277 Mdot
.896 .33279 Mdot
.896 .33281 Mdot
.896 .33281 Mdot
.896 .33283 Mdot
.896 .33283 Mdot
.896 .33284 Mdot
.896 .33286 Mdot
.896 .33287 Mdot
.896 .33291 Mdot
.896 .33296 Mdot
.896 .33298 Mdot
.896 .333 Mdot
.896 .33301 Mdot
.896 .33306 Mdot
.896 .3331 Mdot
.896 .33317 Mdot
.896 .3332 Mdot
.896 .33324 Mdot
.896 .33325 Mdot
.896 .33333 Mdot
.896 .33341 Mdot
.896 .33342 Mdot
.896 .33344 Mdot
.896 .3335 Mdot
.896 .33357 Mdot
.896 .33359 Mdot
.896 .33364 Mdot
.896 .33367 Mdot
.896 .3337 Mdot
.896 .33372 Mdot
.896 .33374 Mdot
.896 .33374 Mdot
.896 .33378 Mdot
.896 .33387 Mdot
.896 .3339 Mdot
.896 .3339 Mdot
.896 .33398 Mdot
.896 .33409 Mdot
.896 .33409 Mdot
.896 .33416 Mdot
.896 .3343 Mdot
.896 .33448 Mdot
.896 .3345 Mdot
.896 .33453 Mdot
.896 .33454 Mdot
.896 .33463 Mdot
.896 .33473 Mdot
.896 .33477 Mdot
.896 .3348 Mdot
.896 .33485 Mdot
.896 .33498 Mdot
.896 .33501 Mdot
.896 .33518 Mdot
.896 .33531 Mdot
.896 .33532 Mdot
.896 .33532 Mdot
.896 .33532 Mdot
.896 .33532 Mdot
.896 .33533 Mdot
.896 .33541 Mdot
.896 .33555 Mdot
.896 .33566 Mdot
.896 .3357 Mdot
.896 .33575 Mdot
.896 .33581 Mdot
.896 .33583 Mdot
.896 .33584 Mdot
.896 .33587 Mdot
.896 .3359 Mdot
.896 .3359 Mdot
.896 .33607 Mdot
.896 .3361 Mdot
.896 .33613 Mdot
.896 .33616 Mdot
.896 .33619 Mdot
.896 .3362 Mdot
.896 .33628 Mdot
.896 .3363 Mdot
.896 .33632 Mdot
.896 .33633 Mdot
.896 .33643 Mdot
.896 .33653 Mdot
.896 .33654 Mdot
.896 .33655 Mdot
.896 .33666 Mdot
.896 .33669 Mdot
.896 .33674 Mdot
.896 .33675 Mdot
.896 .33677 Mdot
.896 .33679 Mdot
.896 .3368 Mdot
.896 .33684 Mdot
.896 .33684 Mdot
.896 .33689 Mdot
.896 .33695 Mdot
.896 .33697 Mdot
.896 .33698 Mdot
.896 .33698 Mdot
.896 .33698 Mdot
.896 .33704 Mdot
.896 .33705 Mdot
.896 .33705 Mdot
.896 .33706 Mdot
.896 .33706 Mdot
.896 .33706 Mdot
.896 .33707 Mdot
.896 .33707 Mdot
.896 .33707 Mdot
.896 .33707 Mdot
.896 .33707 Mdot
.896 .33707 Mdot
.896 .33708 Mdot
.896 .33708 Mdot
.896 .33714 Mdot
.896 .33715 Mdot
.896 .33716 Mdot
.896 .33716 Mdot
.896 .33717 Mdot
.896 .33717 Mdot
.896 .33718 Mdot
.896 .3372 Mdot
.896 .3372 Mdot
.896 .34352 Mdot
.896 .36338 Mdot
.896 .37456 Mdot
.896 .37618 Mdot
.896 .42857 Mdot
.896 .47012 Mdot
.896 .48164 Mdot
.896 .48805 Mdot
.896 .4937 Mdot
.896 .49431 Mdot
.896 .49438 Mdot
.896 .50019 Mdot
.896 .50459 Mdot
.896 .50586 Mdot
.896 .51255 Mdot
.896 .51263 Mdot
.896 .51264 Mdot
.896 .51269 Mdot
.896 .51275 Mdot
.896 .51279 Mdot
.896 .51282 Mdot
.896 .51308 Mdot
.896 .51309 Mdot
.896 .51338 Mdot
.896 .51341 Mdot
.896 .51341 Mdot
.896 .51343 Mdot
.896 .51343 Mdot
.896 .51343 Mdot
.896 .51343 Mdot
.896 .51343 Mdot
.896 .51344 Mdot
.896 .51345 Mdot
.896 .51347 Mdot
.896 .51348 Mdot
.896 .51348 Mdot
.896 .51348 Mdot
.896 .51348 Mdot
.896 .51348 Mdot
.896 .51348 Mdot
.896 .51348 Mdot
.896 .51349 Mdot
.896 .51349 Mdot
.896 .51349 Mdot
.896 .51349 Mdot
.896 .51349 Mdot
.896 .5135 Mdot
.896 .51353 Mdot
.896 .51353 Mdot
.896 .51353 Mdot
.896 .51353 Mdot
.896 .51355 Mdot
.896 .51358 Mdot
.896 .51359 Mdot
.896 .51361 Mdot
.896 .51361 Mdot
.896 .51363 Mdot
.896 .51364 Mdot
.896 .51365 Mdot
.896 .51366 Mdot
.896 .51367 Mdot
.896 .51369 Mdot
.896 .51372 Mdot
.896 .51378 Mdot
.896 .51379 Mdot
.896 .51379 Mdot
.896 .51385 Mdot
.896 .51392 Mdot
.896 .51392 Mdot
.896 .51394 Mdot
.896 .51395 Mdot
.896 .514 Mdot
.896 .51401 Mdot
.896 .51403 Mdot
.896 .51405 Mdot
.896 .51407 Mdot
.896 .51409 Mdot
.896 .51421 Mdot
.896 .51421 Mdot
.896 .51423 Mdot
.896 .51425 Mdot
.896 .51425 Mdot
.896 .51426 Mdot
.896 .51428 Mdot
.896 .51432 Mdot
.896 .51435 Mdot
.896 .51439 Mdot
.896 .5144 Mdot
.896 .51447 Mdot
.896 .51451 Mdot
.896 .51458 Mdot
.896 .51464 Mdot
.896 .51465 Mdot
.896 .51465 Mdot
.896 .51465 Mdot
.896 .51465 Mdot
.896 .51466 Mdot
.896 .51476 Mdot
.896 .51491 Mdot
.896 .51494 Mdot
.896 .51502 Mdot
.896 .51505 Mdot
.896 .51509 Mdot
.896 .51509 Mdot
.896 .51509 Mdot
.896 .51516 Mdot
.896 .51525 Mdot
.896 .51533 Mdot
.896 .51534 Mdot
.896 .51534 Mdot
.896 .51537 Mdot
.896 .51539 Mdot
.896 .51542 Mdot
.896 .51544 Mdot
.896 .51546 Mdot
.896 .51551 Mdot
.896 .51556 Mdot
.896 .51567 Mdot
.896 .5157 Mdot
.896 .51575 Mdot
.896 .51577 Mdot
.896 .51577 Mdot
.896 .5158 Mdot
.896 .51586 Mdot
.896 .51588 Mdot
.896 .51596 Mdot
.896 .51597 Mdot
.896 .51599 Mdot
.896 .51609 Mdot
.896 .51613 Mdot
.896 .51614 Mdot
.896 .51615 Mdot
.896 .51618 Mdot
.896 .51621 Mdot
.896 .51624 Mdot
.896 .51626 Mdot
.896 .51629 Mdot
.896 .51632 Mdot
.896 .5164 Mdot
.896 .51643 Mdot
.896 .51646 Mdot
.896 .51648 Mdot
.896 .51649 Mdot
.896 .5165 Mdot
.896 .51658 Mdot
.896 .51658 Mdot
.896 .51658 Mdot
.896 .51667 Mdot
.896 .51667 Mdot
.896 .51667 Mdot
.896 .51668 Mdot
.896 .51668 Mdot
.896 .51668 Mdot
.896 .51672 Mdot
.896 .51673 Mdot
.896 .51674 Mdot
.896 .51676 Mdot
.896 .51677 Mdot
.896 .51684 Mdot
.896 .51687 Mdot
.896 .51687 Mdot
.896 .5169 Mdot
.896 .51692 Mdot
.896 .51695 Mdot
.896 .51696 Mdot
.896 .51699 Mdot
.896 .51701 Mdot
.896 .51701 Mdot
.896 .51707 Mdot
.896 .51712 Mdot
.896 .51713 Mdot
.896 .51716 Mdot
.896 .51716 Mdot
.896 .51716 Mdot
.896 .51717 Mdot
.896 .51719 Mdot
.896 .51719 Mdot
.896 .51722 Mdot
.896 .51724 Mdot
.896 .51724 Mdot
.896 .51751 Mdot
.896 .51752 Mdot
.896 .51755 Mdot
.896 .51761 Mdot
.896 .51782 Mdot
.896 .51791 Mdot
.896 .51795 Mdot
.896 .51796 Mdot
.896 .51804 Mdot
.896 .51809 Mdot
.896 .5182 Mdot
.896 .51834 Mdot
.896 .51837 Mdot
.896 .5184 Mdot
.896 .51844 Mdot
.896 .5185 Mdot
.896 .51888 Mdot
.896 .51892 Mdot
.896 .51893 Mdot
.896 .519 Mdot
.896 .51917 Mdot
.896 .51918 Mdot
.896 .5194 Mdot
.896 .51957 Mdot
.896 .5202 Mdot
.896 .52034 Mdot
.896 .52083 Mdot
.896 .52091 Mdot
.896 .52118 Mdot
.896 .52152 Mdot
.896 .52153 Mdot
.896 .52156 Mdot
.896 .52187 Mdot
.896 .52221 Mdot
.896 .52278 Mdot
.896 .52464 Mdot
.896 .52693 Mdot
.896 .52701 Mdot
.896 .52863 Mdot
.896 .52932 Mdot
.896 .52936 Mdot
.896 .52976 Mdot
.896 .5329 Mdot
.896 .53333 Mdot
.896 .53339 Mdot
.896 .53364 Mdot
.896 .53371 Mdot
.896 .53377 Mdot
.896 .53382 Mdot
.896 .534 Mdot
.896 .53403 Mdot
.896 .53415 Mdot
.896 .53422 Mdot
.896 .53442 Mdot
.896 .53454 Mdot
.896 .53502 Mdot
.896 .53562 Mdot
.896 .53566 Mdot
.896 .5357 Mdot
.896 .53601 Mdot
.896 .53652 Mdot
.896 .53658 Mdot
.896 .53679 Mdot
.896 .53681 Mdot
.896 .53693 Mdot
.896 .53693 Mdot
.896 .53697 Mdot
.896 .53699 Mdot
.896 .53699 Mdot
.896 .53699 Mdot
.896 .537 Mdot
.896 .53703 Mdot
.896 .53704 Mdot
.896 .53705 Mdot
.896 .53715 Mdot
.896 .53716 Mdot
.896 .53717 Mdot
.896 .53717 Mdot
.896 .53719 Mdot
.896 .53719 Mdot
.896 .53719 Mdot
.896 .53719 Mdot
.896 .53719 Mdot
.896 .5372 Mdot
.896 .5372 Mdot
.896 .53721 Mdot
.896 .53722 Mdot
.896 .53724 Mdot
.896 .53731 Mdot
.896 .53736 Mdot
.896 .53736 Mdot
.896 .53736 Mdot
.896 .53738 Mdot
.896 .53742 Mdot
.896 .53754 Mdot
.896 .53756 Mdot
.896 .53764 Mdot
.896 .53765 Mdot
.896 .53772 Mdot
.896 .53775 Mdot
.896 .53779 Mdot
.896 .53782 Mdot
.896 .53786 Mdot
.896 .53795 Mdot
.896 .53803 Mdot
.896 .53824 Mdot
.896 .53828 Mdot
.896 .53828 Mdot
.896 .53836 Mdot
.896 .5385 Mdot
.896 .53861 Mdot
.896 .53871 Mdot
.896 .53873 Mdot
.896 .53878 Mdot
.896 .53879 Mdot
.896 .53879 Mdot
.896 .53883 Mdot
.896 .53899 Mdot
.896 .53901 Mdot
.896 .53908 Mdot
.896 .53915 Mdot
.896 .53921 Mdot
.896 .53928 Mdot
.896 .53963 Mdot
.896 .53964 Mdot
.896 .53971 Mdot
.896 .53976 Mdot
.896 .53976 Mdot
.896 .53977 Mdot
.896 .53983 Mdot
.896 .53988 Mdot
.896 .53989 Mdot
.896 .53995 Mdot
.896 .53996 Mdot
.896 .54004 Mdot
.896 .54006 Mdot
.896 .54007 Mdot
.896 .54013 Mdot
.896 .54014 Mdot
.896 .54016 Mdot
.896 .54016 Mdot
.896 .54016 Mdot
.896 .54017 Mdot
.896 .54028 Mdot
.896 .54032 Mdot
.896 .54034 Mdot
.896 .54045 Mdot
.896 .54045 Mdot
.896 .54064 Mdot
.896 .54064 Mdot
.896 .54065 Mdot
.896 .54069 Mdot
.896 .54078 Mdot
.896 .54078 Mdot
.896 .54079 Mdot
.896 .5408 Mdot
.896 .5408 Mdot
.896 .5408 Mdot
.896 .54081 Mdot
.896 .54081 Mdot
.896 .54089 Mdot
.896 .54096 Mdot
.896 .54102 Mdot
.896 .54103 Mdot
.896 .54105 Mdot
.896 .54109 Mdot
.896 .54128 Mdot
.896 .54129 Mdot
.896 .54134 Mdot
.896 .54134 Mdot
.896 .54136 Mdot
.896 .54138 Mdot
.896 .5414 Mdot
.896 .54146 Mdot
.896 .54146 Mdot
.896 .54147 Mdot
.896 .54148 Mdot
.896 .54149 Mdot
.896 .5415 Mdot
.896 .54155 Mdot
.896 .54158 Mdot
.896 .54165 Mdot
.896 .54166 Mdot
.896 .54166 Mdot
.896 .54166 Mdot
.896 .54166 Mdot
.896 .54166 Mdot
.896 .54176 Mdot
.896 .54179 Mdot
.896 .54181 Mdot
.896 .54183 Mdot
.896 .54185 Mdot
.896 .54188 Mdot
.896 .54189 Mdot
.896 .54194 Mdot
.896 .54197 Mdot
.896 .54199 Mdot
.896 .54199 Mdot
.896 .54202 Mdot
.896 .54203 Mdot
.896 .54204 Mdot
.896 .54206 Mdot
.896 .54207 Mdot
.896 .54209 Mdot
.896 .54209 Mdot
.896 .5421 Mdot
.896 .54211 Mdot
.896 .54214 Mdot
.896 .54214 Mdot
.896 .54216 Mdot
.896 .54218 Mdot
.896 .54218 Mdot
.896 .54219 Mdot
.896 .5422 Mdot
.896 .54222 Mdot
.896 .54223 Mdot
.896 .54224 Mdot
.896 .54224 Mdot
.896 .54225 Mdot
.896 .54226 Mdot
.896 .54226 Mdot
.896 .54227 Mdot
.896 .54227 Mdot
.896 .54227 Mdot
.896 .54227 Mdot
.896 .54228 Mdot
.896 .54228 Mdot
.896 .54228 Mdot
.898 .16992 Mdot
.898 .29051 Mdot
.898 .33786 Mdot
.898 .51422 Mdot
.898 .54035 Mdot
.9 .15242 Mdot
.9 .15242 Mdot
.9 .15243 Mdot
.9 .15245 Mdot
.9 .15246 Mdot
.9 .15247 Mdot
.9 .15252 Mdot
.9 .15252 Mdot
.9 .15255 Mdot
.9 .15258 Mdot
.9 .15262 Mdot
.9 .15269 Mdot
.9 .15269 Mdot
.9 .15272 Mdot
.9 .15277 Mdot
.9 .15312 Mdot
.9 .15314 Mdot
.9 .15317 Mdot
.9 .15321 Mdot
.9 .15326 Mdot
.9 .15326 Mdot
.9 .15326 Mdot
.9 .15334 Mdot
.9 .15348 Mdot
.9 .15352 Mdot
.9 .15373 Mdot
.9 .15377 Mdot
.9 .15383 Mdot
.9 .15399 Mdot
.9 .15408 Mdot
.9 .15429 Mdot
.9 .15434 Mdot
.9 .15439 Mdot
.9 .15439 Mdot
.9 .15451 Mdot
.9 .15455 Mdot
.9 .15457 Mdot
.9 .15464 Mdot
.9 .15469 Mdot
.9 .15481 Mdot
.9 .15496 Mdot
.9 .1551 Mdot
.9 .15554 Mdot
.9 .15575 Mdot
.9 .15575 Mdot
.9 .1558 Mdot
.9 .15608 Mdot
.9 .15613 Mdot
.9 .15615 Mdot
.9 .15646 Mdot
.9 .15667 Mdot
.9 .15683 Mdot
.9 .15706 Mdot
.9 .15722 Mdot
.9 .15729 Mdot
.9 .1573 Mdot
.9 .15736 Mdot
.9 .15737 Mdot
.9 .15745 Mdot
.9 .15746 Mdot
.9 .15748 Mdot
.9 .15764 Mdot
.9 .15773 Mdot
.9 .15775 Mdot
.9 .15834 Mdot
.9 .15843 Mdot
.9 .15845 Mdot
.9 .15849 Mdot
.9 .15874 Mdot
.9 .15894 Mdot
.9 .15901 Mdot
.9 .15902 Mdot
.9 .15907 Mdot
.9 .15919 Mdot
.9 .15922 Mdot
.9 .15922 Mdot
.9 .15926 Mdot
.9 .15941 Mdot
.9 .15948 Mdot
.9 .1595 Mdot
.9 .15961 Mdot
.9 .15962 Mdot
.9 .1597 Mdot
.9 .15972 Mdot
.9 .15987 Mdot
.9 .15988 Mdot
.9 .15988 Mdot
.9 .15988 Mdot
.9 .15999 Mdot
.9 .16002 Mdot
.9 .16008 Mdot
.9 .16009 Mdot
.9 .16009 Mdot
.9 .16012 Mdot
.9 .16015 Mdot
.9 .16018 Mdot
.9 .1602 Mdot
.9 .16023 Mdot
.9 .16024 Mdot
.9 .16025 Mdot
.9 .16027 Mdot
.9 .1603 Mdot
.9 .16196 Mdot
.9 .16359 Mdot
.9 .16361 Mdot
.9 .16468 Mdot
.9 .16511 Mdot
.9 .16612 Mdot
.9 .16698 Mdot
.9 .16972 Mdot
.9 .17407 Mdot
.9 .17445 Mdot
.9 .17579 Mdot
.9 .17673 Mdot
.9 .17725 Mdot
.9 .17859 Mdot
.9 .17896 Mdot
.9 .18314 Mdot
.9 .18446 Mdot
.9 .19024 Mdot
.9 .19206 Mdot
.9 .19752 Mdot
.9 .19837 Mdot
.9 .20251 Mdot
.9 .20336 Mdot
.9 .20355 Mdot
.9 .20496 Mdot
.9 .20534 Mdot
.9 .20931 Mdot
.9 .2099 Mdot
.9 .21206 Mdot
.9 .21428 Mdot
.9 .21595 Mdot
.9 .2196 Mdot
.9 .22015 Mdot
.9 .22204 Mdot
.9 .22336 Mdot
.9 .22402 Mdot
.9 .22488 Mdot
.9 .22497 Mdot
.9 .22531 Mdot
.9 .2263 Mdot
.9 .22835 Mdot
.9 .22981 Mdot
.9 .23007 Mdot
.9 .23208 Mdot
.9 .2321 Mdot
.9 .23339 Mdot
.9 .23559 Mdot
.9 .23797 Mdot
.9 .23846 Mdot
.9 .23937 Mdot
.9 .24327 Mdot
.9 .24337 Mdot
.9 .24374 Mdot
.9 .24442 Mdot
.9 .24614 Mdot
.9 .24764 Mdot
.9 .24937 Mdot
.9 .25021 Mdot
.9 .25028 Mdot
.9 .25037 Mdot
.9 .25043 Mdot
.9 .25063 Mdot
.9 .25078 Mdot
.9 .25098 Mdot
.9 .25111 Mdot
.9 .25133 Mdot
.9 .25152 Mdot
.9 .25213 Mdot
.9 .25218 Mdot
.9 .25238 Mdot
.9 .25457 Mdot
.9 .25471 Mdot
.9 .25494 Mdot
.9 .25508 Mdot
.9 .25511 Mdot
.9 .2558 Mdot
.9 .25587 Mdot
.9 .2562 Mdot
.9 .25623 Mdot
.9 .25635 Mdot
.9 .25651 Mdot
.9 .25702 Mdot
.9 .25706 Mdot
.9 .25727 Mdot
.9 .25789 Mdot
.9 .2579 Mdot
.9 .25801 Mdot
.9 .25814 Mdot
.9 .25857 Mdot
.9 .25896 Mdot
.9 .25904 Mdot
.9 .25966 Mdot
.9 .25982 Mdot
.9 .26012 Mdot
.9 .26016 Mdot
.9 .26021 Mdot
.9 .26033 Mdot
.9 .2604 Mdot
.9 .26053 Mdot
.9 .26108 Mdot
.9 .26209 Mdot
.9 .2628 Mdot
.9 .263 Mdot
.9 .26318 Mdot
.9 .26321 Mdot
.9 .26399 Mdot
.9 .26411 Mdot
.9 .26417 Mdot
.9 .26485 Mdot
.9 .26489 Mdot
.9 .26504 Mdot
.9 .26524 Mdot
.9 .26636 Mdot
.9 .26642 Mdot
.9 .26647 Mdot
.9 .26648 Mdot
.9 .26669 Mdot
.9 .26672 Mdot
.9 .26672 Mdot
.9 .26715 Mdot
.9 .26715 Mdot
.9 .26737 Mdot
.9 .26749 Mdot
.9 .26763 Mdot
.9 .26769 Mdot
.9 .26773 Mdot
.9 .26804 Mdot
.9 .26812 Mdot
.9 .26816 Mdot
.9 .26836 Mdot
.9 .26854 Mdot
.9 .26865 Mdot
.9 .26883 Mdot
.9 .26898 Mdot
.9 .26924 Mdot
.9 .26927 Mdot
.9 .26928 Mdot
.9 .26936 Mdot
.9 .26942 Mdot
.9 .26953 Mdot
.9 .26971 Mdot
.9 .26976 Mdot
.9 .27047 Mdot
.9 .27074 Mdot
.9 .27114 Mdot
.9 .27118 Mdot
.9 .27133 Mdot
.9 .27135 Mdot
.9 .27144 Mdot
.9 .2719 Mdot
.9 .27199 Mdot
.9 .27263 Mdot
.9 .2738 Mdot
.9 .27442 Mdot
.9 .27447 Mdot
.9 .27469 Mdot
.9 .27477 Mdot
.9 .27492 Mdot
.9 .27515 Mdot
.9 .27522 Mdot
.9 .27602 Mdot
.9 .27659 Mdot
.9 .27678 Mdot
.9 .27712 Mdot
.9 .27738 Mdot
.9 .27739 Mdot
.9 .27782 Mdot
.9 .27865 Mdot
.9 .27896 Mdot
.9 .27918 Mdot
.9 .27919 Mdot
.9 .27922 Mdot
.9 .27936 Mdot
.9 .27971 Mdot
.9 .27986 Mdot
.9 .2807 Mdot
.9 .28071 Mdot
.9 .28085 Mdot
.9 .28164 Mdot
.9 .28176 Mdot
.9 .28184 Mdot
.9 .28275 Mdot
.9 .28323 Mdot
.9 .28352 Mdot
.9 .28356 Mdot
.9 .28382 Mdot
.9 .28384 Mdot
.9 .28388 Mdot
.9 .28406 Mdot
.9 .28407 Mdot
.9 .28422 Mdot
.9 .28432 Mdot
.9 .28445 Mdot
.9 .28446 Mdot
.9 .28451 Mdot
.9 .2846 Mdot
.9 .28507 Mdot
.9 .28513 Mdot
.9 .28522 Mdot
.9 .28522 Mdot
.9 .28523 Mdot
.9 .28545 Mdot
.9 .28548 Mdot
.9 .28567 Mdot
.9 .28571 Mdot
.9 .28575 Mdot
.9 .28595 Mdot
.9 .28611 Mdot
.9 .28618 Mdot
.9 .28618 Mdot
.9 .28646 Mdot
.9 .28655 Mdot
.9 .28664 Mdot
.9 .28689 Mdot
.9 .28701 Mdot
.9 .28701 Mdot
.9 .28704 Mdot
.9 .28718 Mdot
.9 .28721 Mdot
.9 .28748 Mdot
.9 .28756 Mdot
.9 .28766 Mdot
.9 .28774 Mdot
.9 .28777 Mdot
.9 .2878 Mdot
.9 .2878 Mdot
.9 .28784 Mdot
.9 .28784 Mdot
.9 .28785 Mdot
.9 .28825 Mdot
.9 .28828 Mdot
.9 .28838 Mdot
.9 .28846 Mdot
.9 .28849 Mdot
.9 .28849 Mdot
.9 .28851 Mdot
.9 .28855 Mdot
.9 .28857 Mdot
.9 .28858 Mdot
.9 .28864 Mdot
.9 .28867 Mdot
.9 .28867 Mdot
.9 .28871 Mdot
.9 .28872 Mdot
.9 .28875 Mdot
.9 .28875 Mdot
.9 .28881 Mdot
.9 .28881 Mdot
.9 .28882 Mdot
.9 .28882 Mdot
.9 .28885 Mdot
.9 .28887 Mdot
.9 .28889 Mdot
.9 .28889 Mdot
.9 .28889 Mdot
.9 .2889 Mdot
.9 .28891 Mdot
.9 .28892 Mdot
.9 .28893 Mdot
.9 .28894 Mdot
.9 .28895 Mdot
.9 .28895 Mdot
.9 .28897 Mdot
.9 .29049 Mdot
.9 .29982 Mdot
.9 .30008 Mdot
.9 .30224 Mdot
.9 .30442 Mdot
.9 .30878 Mdot
.9 .30878 Mdot
.9 .30878 Mdot
.9 .30888 Mdot
.9 .30888 Mdot
.9 .30895 Mdot
.9 .30964 Mdot
.9 .3098 Mdot
.9 .31001 Mdot
.9 .31017 Mdot
.9 .31063 Mdot
.9 .31077 Mdot
.9 .31107 Mdot
.9 .31123 Mdot
.9 .31128 Mdot
.9 .31159 Mdot
.9 .31202 Mdot
.9 .31207 Mdot
.9 .31253 Mdot
.9 .31348 Mdot
.9 .31402 Mdot
.9 .31439 Mdot
.9 .31451 Mdot
.9 .31655 Mdot
.9 .3168 Mdot
.9 .31681 Mdot
.9 .31683 Mdot
.9 .3169 Mdot
.9 .31691 Mdot
.9 .31693 Mdot
.9 .31707 Mdot
.9 .31708 Mdot
.9 .31716 Mdot
.9 .31723 Mdot
.9 .31735 Mdot
.9 .31753 Mdot
.9 .31754 Mdot
.9 .31754 Mdot
.9 .31761 Mdot
.9 .31774 Mdot
.9 .31782 Mdot
.9 .31866 Mdot
.9 .31871 Mdot
.9 .31873 Mdot
.9 .3188 Mdot
.9 .31889 Mdot
.9 .31892 Mdot
.9 .31901 Mdot
.9 .31901 Mdot
.9 .31902 Mdot
.9 .31921 Mdot
.9 .31959 Mdot
.9 .31968 Mdot
.9 .32021 Mdot
.9 .32031 Mdot
.9 .32037 Mdot
.9 .32045 Mdot
.9 .32084 Mdot
.9 .32106 Mdot
.9 .32133 Mdot
.9 .32155 Mdot
.9 .32157 Mdot
.9 .32168 Mdot
.9 .3218 Mdot
.9 .3218 Mdot
.9 .32208 Mdot
.9 .32219 Mdot
.9 .32224 Mdot
.9 .3224 Mdot
.9 .32251 Mdot
.9 .32279 Mdot
.9 .32312 Mdot
.9 .32346 Mdot
.9 .32443 Mdot
.9 .32487 Mdot
.9 .32489 Mdot
.9 .32499 Mdot
.9 .32558 Mdot
.9 .32569 Mdot
.9 .32572 Mdot
.9 .326 Mdot
.9 .32621 Mdot
.9 .32635 Mdot
.9 .32678 Mdot
.9 .32695 Mdot
.9 .3271 Mdot
.9 .32743 Mdot
.9 .32754 Mdot
.9 .32785 Mdot
.9 .32789 Mdot
.9 .32798 Mdot
.9 .32801 Mdot
.9 .3281 Mdot
.9 .32812 Mdot
.9 .32827 Mdot
.9 .32827 Mdot
.9 .32829 Mdot
.9 .32834 Mdot
.9 .32863 Mdot
.9 .32865 Mdot
.9 .32866 Mdot
.9 .32879 Mdot
.9 .32883 Mdot
.9 .32889 Mdot
.9 .3289 Mdot
.9 .32986 Mdot
.9 .33001 Mdot
.9 .33005 Mdot
.9 .3301 Mdot
.9 .33012 Mdot
.9 .33053 Mdot
.9 .33078 Mdot
.9 .33085 Mdot
.9 .33097 Mdot
.9 .33098 Mdot
.9 .33106 Mdot
.9 .33124 Mdot
.9 .33129 Mdot
.9 .33129 Mdot
.9 .3313 Mdot
.9 .33135 Mdot
.9 .33158 Mdot
.9 .33169 Mdot
.9 .33172 Mdot
.9 .33175 Mdot
.9 .33188 Mdot
.9 .3319 Mdot
.9 .33202 Mdot
.9 .33202 Mdot
.9 .33205 Mdot
.9 .33227 Mdot
.9 .33228 Mdot
.9 .33229 Mdot
.9 .33229 Mdot
.9 .33244 Mdot
.9 .33249 Mdot
.9 .3325 Mdot
.9 .33256 Mdot
.9 .33257 Mdot
.9 .33258 Mdot
.9 .33261 Mdot
.9 .33267 Mdot
.9 .3327 Mdot
.9 .33272 Mdot
.9 .33278 Mdot
.9 .33278 Mdot
.9 .33279 Mdot
.9 .33281 Mdot
.9 .33283 Mdot
.9 .33287 Mdot
.9 .33305 Mdot
.9 .33317 Mdot
.9 .33319 Mdot
.9 .33367 Mdot
.9 .33382 Mdot
.9 .3345 Mdot
.9 .33482 Mdot
.9 .3349 Mdot
.9 .33496 Mdot
.9 .33515 Mdot
.9 .33544 Mdot
.9 .33576 Mdot
.9 .33636 Mdot
.9 .33647 Mdot
.9 .33648 Mdot
.9 .33655 Mdot
.9 .33656 Mdot
.9 .33674 Mdot
.9 .33698 Mdot
.9 .33727 Mdot
.9 .33741 Mdot
.9 .33749 Mdot
.9 .33753 Mdot
.9 .33769 Mdot
.9 .33774 Mdot
.9 .33795 Mdot
.9 .33802 Mdot
.9 .33804 Mdot
.9 .33814 Mdot
.9 .33816 Mdot
.9 .33835 Mdot
.9 .33858 Mdot
.9 .3386 Mdot
.9 .3386 Mdot
.9 .33863 Mdot
.9 .33864 Mdot
.9 .33952 Mdot
.9 .34164 Mdot
.9 .34451 Mdot
.9 .34484 Mdot
.9 .346 Mdot
.9 .34951 Mdot
.9 .35626 Mdot
.9 .35717 Mdot
.9 .36298 Mdot
.9 .36403 Mdot
.9 .36991 Mdot
.9 .37248 Mdot
.9 .3726 Mdot
.9 .37776 Mdot
.9 .3782 Mdot
.9 .37994 Mdot
.9 .38817 Mdot
.9 .39933 Mdot
.9 .40168 Mdot
.9 .40606 Mdot
.9 .42508 Mdot
.9 .42557 Mdot
.9 .42738 Mdot
.9 .43075 Mdot
.9 .43917 Mdot
.9 .44643 Mdot
.9 .45475 Mdot
.9 .45873 Mdot
.9 .45906 Mdot
.9 .45946 Mdot
.9 .45974 Mdot
.9 .46069 Mdot
.9 .46141 Mdot
.9 .46233 Mdot
.9 .46292 Mdot
.9 .46394 Mdot
.9 .46484 Mdot
.9 .46764 Mdot
.9 .46787 Mdot
.9 .46876 Mdot
.9 .47066 Mdot
.9 .47854 Mdot
.9 .47918 Mdot
.9 .48015 Mdot
.9 .48076 Mdot
.9 .4809 Mdot
.9 .48386 Mdot
.9 .48415 Mdot
.9 .48552 Mdot
.9 .48567 Mdot
.9 .48616 Mdot
.9 .48681 Mdot
.9 .48892 Mdot
.9 .48909 Mdot
.9 .48957 Mdot
.9 .48994 Mdot
.9 .49244 Mdot
.9 .49249 Mdot
.9 .49294 Mdot
.9 .49347 Mdot
.9 .49516 Mdot
.9 .49667 Mdot
.9 .49698 Mdot
.9 .49832 Mdot
.9 .49883 Mdot
.9 .49934 Mdot
.9 .49996 Mdot
.9 .50107 Mdot
.9 .5012 Mdot
.9 .50141 Mdot
.9 .50186 Mdot
.9 .5021 Mdot
.9 .50257 Mdot
.9 .50458 Mdot
.9 .50811 Mdot
.9 .51053 Mdot
.9 .51118 Mdot
.9 .5118 Mdot
.9 .51187 Mdot
.9 .51439 Mdot
.9 .51478 Mdot
.9 .51478 Mdot
.9 .51478 Mdot
.9 .51478 Mdot
.9 .51479 Mdot
.9 .51479 Mdot
.9 .51479 Mdot
.9 .51479 Mdot
.9 .5148 Mdot
.9 .5148 Mdot
.9 .5148 Mdot
.9 .5148 Mdot
.9 .5148 Mdot
.9 .51481 Mdot
.9 .51481 Mdot
.9 .51482 Mdot
.9 .51482 Mdot
.9 .51483 Mdot
.9 .51483 Mdot
.9 .51484 Mdot
.9 .51484 Mdot
.9 .51485 Mdot
.9 .51485 Mdot
.9 .51486 Mdot
.9 .51487 Mdot
.9 .51488 Mdot
.9 .51488 Mdot
.9 .51489 Mdot
.9 .5149 Mdot
.9 .5149 Mdot
.9 .51491 Mdot
.9 .51493 Mdot
.9 .51495 Mdot
.9 .51496 Mdot
.9 .51506 Mdot
.9 .51506 Mdot
.9 .51506 Mdot
.9 .51507 Mdot
.9 .51507 Mdot
.9 .51508 Mdot
.9 .51509 Mdot
.9 .51511 Mdot
.9 .51513 Mdot
.9 .51515 Mdot
.9 .51522 Mdot
.9 .51523 Mdot
.9 .51526 Mdot
.9 .51527 Mdot
.9 .51527 Mdot
.9 .5153 Mdot
.9 .51536 Mdot
.9 .51539 Mdot
.9 .51541 Mdot
.9 .51548 Mdot
.9 .51548 Mdot
.9 .5155 Mdot
.9 .51554 Mdot
.9 .51559 Mdot
.9 .5156 Mdot
.9 .51561 Mdot
.9 .51565 Mdot
.9 .51566 Mdot
.9 .51572 Mdot
.9 .51572 Mdot
.9 .51572 Mdot
.9 .51574 Mdot
.9 .51575 Mdot
.9 .51587 Mdot
.9 .51589 Mdot
.9 .5159 Mdot
.9 .51591 Mdot
.9 .51594 Mdot
.9 .51596 Mdot
.9 .516 Mdot
.9 .516 Mdot
.9 .51605 Mdot
.9 .51606 Mdot
.9 .51606 Mdot
.9 .51613 Mdot
.9 .51614 Mdot
.9 .51621 Mdot
.9 .51632 Mdot
.9 .51654 Mdot
.9 .51656 Mdot
.9 .51659 Mdot
.9 .51678 Mdot
.9 .51682 Mdot
.9 .51682 Mdot
.9 .51702 Mdot
.9 .51706 Mdot
.9 .51714 Mdot
.9 .51717 Mdot
.9 .51718 Mdot
.9 .51718 Mdot
.9 .51723 Mdot
.9 .51731 Mdot
.9 .5175 Mdot
.9 .51761 Mdot
.9 .51761 Mdot
.9 .51767 Mdot
.9 .51775 Mdot
.9 .51779 Mdot
.9 .51793 Mdot
.9 .51811 Mdot
.9 .51813 Mdot
.9 .51818 Mdot
.9 .51822 Mdot
.9 .51824 Mdot
.9 .51829 Mdot
.9 .5183 Mdot
.9 .51844 Mdot
.9 .51871 Mdot
.9 .51886 Mdot
.9 .51888 Mdot
.9 .51898 Mdot
.9 .519 Mdot
.9 .51901 Mdot
.9 .51904 Mdot
.9 .51905 Mdot
.9 .51914 Mdot
.9 .5192 Mdot
.9 .51937 Mdot
.9 .51938 Mdot
.9 .51942 Mdot
.9 .51944 Mdot
.9 .51946 Mdot
.9 .51947 Mdot
.9 .51948 Mdot
.9 .51948 Mdot
.9 .51954 Mdot
.9 .51958 Mdot
.9 .51961 Mdot
.9 .51964 Mdot
.9 .51968 Mdot
.9 .51973 Mdot
.9 .51973 Mdot
.9 .51975 Mdot
.9 .51982 Mdot
.9 .51983 Mdot
.9 .51984 Mdot
.9 .51988 Mdot
.9 .5199 Mdot
.9 .51995 Mdot
.9 .51995 Mdot
.9 .52005 Mdot
.9 .52005 Mdot
.9 .52005 Mdot
.9 .5201 Mdot
.9 .5201 Mdot
.9 .52011 Mdot
.9 .52013 Mdot
.9 .52038 Mdot
.9 .52042 Mdot
.9 .52045 Mdot
.9 .52046 Mdot
.9 .52061 Mdot
.9 .52063 Mdot
.9 .52065 Mdot
.9 .52083 Mdot
.9 .52083 Mdot
.9 .52087 Mdot
.9 .52091 Mdot
.9 .52107 Mdot
.9 .52129 Mdot
.9 .52141 Mdot
.9 .52144 Mdot
.9 .52145 Mdot
.9 .52148 Mdot
.9 .52149 Mdot
.9 .5215 Mdot
.9 .52156 Mdot
.9 .5216 Mdot
.9 .52173 Mdot
.9 .52175 Mdot
.9 .52184 Mdot
.9 .52193 Mdot
.9 .52196 Mdot
.9 .52198 Mdot
.9 .52198 Mdot
.9 .52212 Mdot
.9 .52216 Mdot
.9 .52217 Mdot
.9 .52228 Mdot
.9 .52231 Mdot
.9 .52234 Mdot
.9 .52235 Mdot
.9 .52242 Mdot
.9 .52243 Mdot
.9 .52258 Mdot
.9 .52259 Mdot
.9 .52262 Mdot
.9 .52266 Mdot
.9 .5227 Mdot
.9 .52316 Mdot
.9 .5232 Mdot
.9 .52322 Mdot
.9 .52334 Mdot
.9 .52339 Mdot
.9 .52343 Mdot
.9 .52346 Mdot
.9 .5235 Mdot
.9 .52353 Mdot
.9 .52358 Mdot
.9 .52359 Mdot
.9 .52361 Mdot
.9 .52362 Mdot
.9 .5238 Mdot
.9 .52416 Mdot
.9 .52448 Mdot
.9 .52483 Mdot
.9 .52498 Mdot
.9 .52505 Mdot
.9 .52507 Mdot
.9 .52588 Mdot
.9 .52607 Mdot
.9 .52617 Mdot
.9 .52666 Mdot
.9 .52711 Mdot
.9 .52738 Mdot
.9 .52738 Mdot
.9 .52779 Mdot
.9 .52785 Mdot
.9 .52814 Mdot
.9 .52856 Mdot
.9 .52876 Mdot
.9 .52883 Mdot
.9 .52885 Mdot
.9 .52903 Mdot
.9 .52916 Mdot
.9 .52943 Mdot
.9 .52982 Mdot
.9 .52993 Mdot
.9 .53067 Mdot
.9 .53101 Mdot
.9 .53146 Mdot
.9 .53191 Mdot
.9 .53203 Mdot
.9 .53284 Mdot
.9 .53292 Mdot
.9 .53321 Mdot
.9 .53325 Mdot
.9 .53342 Mdot
.9 .53428 Mdot
.9 .53446 Mdot
.9 .5356 Mdot
.9 .53598 Mdot
.9 .53722 Mdot
.9 .5375 Mdot
.9 .53841 Mdot
.9 .53849 Mdot
.9 .53879 Mdot
.9 .5389 Mdot
.9 .53911 Mdot
.9 .53941 Mdot
.9 .53949 Mdot
.9 .54048 Mdot
.9 .5411 Mdot
.9 .5413 Mdot
.9 .54154 Mdot
.9 .54164 Mdot
.9 .54189 Mdot
.9 .5419 Mdot
.9 .54229 Mdot
.9 .54268 Mdot
.9 .54269 Mdot
.9 .54269 Mdot
.9 .5427 Mdot
.9 .5427 Mdot
.9 .54271 Mdot
.9 .54271 Mdot
.9 .54272 Mdot
.9 .54273 Mdot
.9 .54273 Mdot
.9 .54273 Mdot
.9 .54274 Mdot
.9 .54275 Mdot
.9 .54276 Mdot
.9 .54278 Mdot
.9 .54278 Mdot
.9 .54278 Mdot
.9 .54279 Mdot
.9 .54282 Mdot
.9 .54283 Mdot
.9 .54285 Mdot
.9 .54285 Mdot
.9 .54287 Mdot
.9 .54288 Mdot
.9 .5429 Mdot
.9 .54293 Mdot
.9 .54294 Mdot
.9 .54294 Mdot
.9 .54295 Mdot
.9 .54298 Mdot
.9 .54299 Mdot
.9 .54299 Mdot
.9 .54301 Mdot
.9 .54306 Mdot
.9 .54312 Mdot
.9 .54313 Mdot
.9 .54314 Mdot
.9 .54316 Mdot
.9 .5433 Mdot
.9 .54331 Mdot
.9 .54333 Mdot
.9 .54337 Mdot
.9 .54337 Mdot
.9 .54338 Mdot
.9 .5434 Mdot
.9 .5434 Mdot
.9 .54341 Mdot
.9 .54341 Mdot
.9 .54343 Mdot
.9 .54347 Mdot
.9 .54353 Mdot
.9 .54357 Mdot
.9 .54362 Mdot
.9 .5437 Mdot
.9 .5437 Mdot
.9 .54371 Mdot
.9 .54378 Mdot
.9 .54379 Mdot
.9 .5438 Mdot
.9 .54385 Mdot
.9 .54396 Mdot
.9 .54399 Mdot
.9 .54403 Mdot
.9 .54406 Mdot
.9 .54407 Mdot
.9 .54409 Mdot
.9 .54409 Mdot
.9 .54411 Mdot
.9 .54413 Mdot
.9 .54414 Mdot
.9 .54415 Mdot
.9 .54416 Mdot
.9 .54421 Mdot
.9 .54424 Mdot
.9 .54428 Mdot
.9 .54429 Mdot
.9 .5443 Mdot
.9 .54435 Mdot
.9 .54436 Mdot
.9 .5444 Mdot
.9 .54442 Mdot
.9 .54442 Mdot
.9 .54442 Mdot
.9 .54443 Mdot
.9 .54444 Mdot
.9 .54445 Mdot
.9 .54445 Mdot
.9 .54454 Mdot
.9 .54456 Mdot
.9 .54456 Mdot
.9 .54456 Mdot
.9 .54458 Mdot
.9 .54459 Mdot
.9 .5446 Mdot
.9 .54461 Mdot
.9 .54461 Mdot
.9 .54462 Mdot
.9 .54462 Mdot
.9 .54462 Mdot
.9 .54463 Mdot
.9 .54463 Mdot
.9 .54463 Mdot
.902 .14818 Mdot
.902 .14819 Mdot
.902 .14819 Mdot
.902 .14819 Mdot
.902 .1482 Mdot
.902 .14821 Mdot
.902 .14821 Mdot
.902 .14822 Mdot
.902 .14824 Mdot
.902 .14825 Mdot
.902 .14826 Mdot
.902 .14826 Mdot
.902 .14827 Mdot
.902 .1483 Mdot
.902 .14831 Mdot
.902 .14832 Mdot
.902 .14833 Mdot
.902 .14834 Mdot
.902 .14836 Mdot
.902 .14837 Mdot
.902 .1484 Mdot
.902 .1484 Mdot
.902 .14847 Mdot
.902 .14847 Mdot
.902 .14849 Mdot
.902 .14851 Mdot
.902 .14851 Mdot
.902 .14852 Mdot
.902 .14853 Mdot
.902 .14854 Mdot
.902 .14854 Mdot
.902 .14856 Mdot
.902 .14857 Mdot
.902 .1486 Mdot
.902 .14871 Mdot
.902 .14872 Mdot
.902 .14872 Mdot
.902 .14876 Mdot
.902 .14878 Mdot
.902 .14879 Mdot
.902 .1488 Mdot
.902 .14883 Mdot
.902 .14887 Mdot
.902 .14892 Mdot
.902 .14893 Mdot
.902 .14894 Mdot
.902 .14894 Mdot
.902 .14894 Mdot
.902 .14895 Mdot
.902 .14932 Mdot
.902 .14942 Mdot
.902 .15002 Mdot
.902 .15003 Mdot
.902 .15013 Mdot
.902 .15014 Mdot
.902 .15027 Mdot
.902 .15067 Mdot
.902 .15088 Mdot
.902 .15094 Mdot
.902 .15194 Mdot
.902 .1523 Mdot
.902 .15247 Mdot
.902 .15262 Mdot
.902 .15269 Mdot
.902 .1534 Mdot
.902 .15424 Mdot
.902 .15459 Mdot
.902 .1546 Mdot
.902 .15609 Mdot
.902 .15613 Mdot
.902 .15652 Mdot
.902 .15693 Mdot
.902 .1571 Mdot
.902 .15994 Mdot
.902 .16054 Mdot
.902 .16096 Mdot
.902 .16126 Mdot
.902 .16135 Mdot
.902 .16266 Mdot
.902 .16268 Mdot
.902 .16271 Mdot
.902 .16317 Mdot
.902 .16432 Mdot
.902 .16456 Mdot
.902 .16494 Mdot
.902 .16774 Mdot
.902 .16779 Mdot
.902 .16857 Mdot
.902 .16992 Mdot
.902 .17131 Mdot
.902 .1722 Mdot
.902 .17277 Mdot
.902 .17302 Mdot
.902 .17395 Mdot
.902 .17525 Mdot
.902 .17866 Mdot
.902 .17983 Mdot
.902 .18465 Mdot
.902 .18714 Mdot
.902 .1882 Mdot
.902 .18922 Mdot
.902 .1906 Mdot
.902 .19308 Mdot
.902 .19615 Mdot
.902 .19674 Mdot
.902 .20003 Mdot
.902 .20054 Mdot
.902 .20174 Mdot
.902 .20612 Mdot
.902 .20613 Mdot
.902 .20753 Mdot
.902 .2095 Mdot
.902 .21065 Mdot
.902 .21453 Mdot
.902 .21486 Mdot
.902 .21761 Mdot
.902 .21805 Mdot
.902 .2181 Mdot
.902 .21904 Mdot
.902 .22109 Mdot
.902 .22343 Mdot
.902 .23075 Mdot
.902 .23453 Mdot
.902 .23455 Mdot
.902 .23921 Mdot
.902 .23938 Mdot
.902 .23945 Mdot
.902 .23949 Mdot
.902 .23963 Mdot
.902 .23967 Mdot
.902 .23989 Mdot
.902 .24003 Mdot
.902 .2401 Mdot
.902 .24034 Mdot
.902 .24052 Mdot
.902 .24068 Mdot
.902 .24089 Mdot
.902 .24103 Mdot
.902 .24113 Mdot
.902 .24177 Mdot
.902 .24178 Mdot
.902 .24191 Mdot
.902 .24196 Mdot
.902 .24221 Mdot
.902 .2423 Mdot
.902 .24246 Mdot
.902 .24303 Mdot
.902 .24321 Mdot
.902 .24329 Mdot
.902 .24336 Mdot
.902 .24369 Mdot
.902 .24371 Mdot
.902 .24508 Mdot
.902 .24512 Mdot
.902 .2454 Mdot
.902 .24578 Mdot
.902 .24595 Mdot
.902 .24604 Mdot
.902 .24604 Mdot
.902 .2462 Mdot
.902 .24646 Mdot
.902 .24648 Mdot
.902 .24689 Mdot
.902 .24695 Mdot
.902 .2475 Mdot
.902 .24786 Mdot
.902 .24819 Mdot
.902 .2483 Mdot
.902 .24836 Mdot
.902 .24837 Mdot
.902 .24864 Mdot
.902 .24884 Mdot
.902 .24918 Mdot
.902 .24925 Mdot
.902 .24962 Mdot
.902 .24972 Mdot
.902 .24982 Mdot
.902 .24995 Mdot
.902 .25005 Mdot
.902 .25062 Mdot
.902 .25096 Mdot
.902 .25099 Mdot
.902 .25125 Mdot
.902 .25185 Mdot
.902 .25215 Mdot
.902 .2523 Mdot
.902 .2524 Mdot
.902 .25245 Mdot
.902 .25279 Mdot
.902 .25344 Mdot
.902 .25359 Mdot
.902 .25365 Mdot
.902 .25369 Mdot
.902 .25369 Mdot
.902 .25382 Mdot
.902 .25468 Mdot
.902 .25537 Mdot
.902 .25549 Mdot
.902 .25665 Mdot
.902 .25691 Mdot
.902 .25815 Mdot
.902 .25836 Mdot
.902 .25848 Mdot
.902 .25957 Mdot
.902 .25976 Mdot
.902 .25998 Mdot
.902 .26145 Mdot
.902 .26146 Mdot
.902 .26219 Mdot
.902 .2631 Mdot
.902 .26354 Mdot
.902 .26354 Mdot
.902 .26511 Mdot
.902 .26513 Mdot
.902 .26516 Mdot
.902 .26533 Mdot
.902 .26605 Mdot
.902 .26627 Mdot
.902 .26629 Mdot
.902 .26638 Mdot
.902 .26664 Mdot
.902 .26686 Mdot
.902 .26687 Mdot
.902 .26693 Mdot
.902 .26693 Mdot
.902 .26732 Mdot
.902 .26756 Mdot
.902 .26765 Mdot
.902 .26803 Mdot
.902 .26803 Mdot
.902 .26834 Mdot
.902 .26896 Mdot
.902 .26916 Mdot
.902 .26934 Mdot
.902 .26942 Mdot
.902 .26943 Mdot
.902 .26947 Mdot
.902 .26972 Mdot
.902 .26975 Mdot
.902 .27011 Mdot
.902 .27022 Mdot
.902 .27041 Mdot
.902 .27054 Mdot
.902 .27054 Mdot
.902 .27098 Mdot
.902 .27111 Mdot
.902 .27116 Mdot
.902 .27151 Mdot
.902 .27191 Mdot
.902 .2722 Mdot
.902 .27236 Mdot
.902 .27248 Mdot
.902 .27261 Mdot
.902 .27293 Mdot
.902 .27357 Mdot
.902 .27423 Mdot
.902 .27444 Mdot
.902 .27458 Mdot
.902 .27486 Mdot
.902 .2751 Mdot
.902 .27534 Mdot
.902 .27603 Mdot
.902 .27611 Mdot
.902 .2765 Mdot
.902 .27651 Mdot
.902 .27681 Mdot
.902 .27683 Mdot
.902 .277 Mdot
.902 .27715 Mdot
.902 .27792 Mdot
.902 .27797 Mdot
.902 .27809 Mdot
.902 .27821 Mdot
.902 .27822 Mdot
.902 .27871 Mdot
.902 .27872 Mdot
.902 .27884 Mdot
.902 .27916 Mdot
.902 .27945 Mdot
.902 .27948 Mdot
.902 .27954 Mdot
.902 .27962 Mdot
.902 .27979 Mdot
.902 .2803 Mdot
.902 .28033 Mdot
.902 .28045 Mdot
.902 .2807 Mdot
.902 .28078 Mdot
.902 .28079 Mdot
.902 .28086 Mdot
.902 .28132 Mdot
.902 .2814 Mdot
.902 .28195 Mdot
.902 .28203 Mdot
.902 .28204 Mdot
.902 .28229 Mdot
.902 .2826 Mdot
.902 .28262 Mdot
.902 .28269 Mdot
.902 .28278 Mdot
.902 .28292 Mdot
.902 .28295 Mdot
.902 .28329 Mdot
.902 .28332 Mdot
.902 .28352 Mdot
.902 .28367 Mdot
.902 .28369 Mdot
.902 .28376 Mdot
.902 .2838 Mdot
.902 .28382 Mdot
.902 .28392 Mdot
.902 .28401 Mdot
.902 .28403 Mdot
.902 .28414 Mdot
.902 .28419 Mdot
.902 .28436 Mdot
.902 .2845 Mdot
.902 .28453 Mdot
.902 .28457 Mdot
.902 .28458 Mdot
.902 .28459 Mdot
.902 .2846 Mdot
.902 .28463 Mdot
.902 .28466 Mdot
.902 .28467 Mdot
.902 .28471 Mdot
.902 .28488 Mdot
.902 .28495 Mdot
.902 .28497 Mdot
.902 .28499 Mdot
.902 .28504 Mdot
.902 .28508 Mdot
.902 .28514 Mdot
.902 .28515 Mdot
.902 .28516 Mdot
.902 .28516 Mdot
.902 .28516 Mdot
.902 .28517 Mdot
.902 .29236 Mdot
.902 .29238 Mdot
.902 .29775 Mdot
.902 .30458 Mdot
.902 .3046 Mdot
.902 .3046 Mdot
.902 .30462 Mdot
.902 .30463 Mdot
.902 .30467 Mdot
.902 .30469 Mdot
.902 .3047 Mdot
.902 .30477 Mdot
.902 .3048 Mdot
.902 .30483 Mdot
.902 .30486 Mdot
.902 .30487 Mdot
.902 .30498 Mdot
.902 .30501 Mdot
.902 .30506 Mdot
.902 .30507 Mdot
.902 .3051 Mdot
.902 .30519 Mdot
.902 .30522 Mdot
.902 .30531 Mdot
.902 .30531 Mdot
.902 .30554 Mdot
.902 .30555 Mdot
.902 .3056 Mdot
.902 .30567 Mdot
.902 .30569 Mdot
.902 .30571 Mdot
.902 .30574 Mdot
.902 .30578 Mdot
.902 .30579 Mdot
.902 .30586 Mdot
.902 .30587 Mdot
.902 .30597 Mdot
.902 .30634 Mdot
.902 .30636 Mdot
.902 .30638 Mdot
.902 .30652 Mdot
.902 .30658 Mdot
.902 .30659 Mdot
.902 .30664 Mdot
.902 .30675 Mdot
.902 .30686 Mdot
.902 .30704 Mdot
.902 .30707 Mdot
.902 .30708 Mdot
.902 .30709 Mdot
.902 .30709 Mdot
.902 .30711 Mdot
.902 .30824 Mdot
.902 .30832 Mdot
.902 .30863 Mdot
.902 .30943 Mdot
.902 .30943 Mdot
.902 .30948 Mdot
.902 .30964 Mdot
.902 .30969 Mdot
.902 .3097 Mdot
.902 .30978 Mdot
.902 .30983 Mdot
.902 .30983 Mdot
.902 .30985 Mdot
.902 .30994 Mdot
.902 .31002 Mdot
.902 .31011 Mdot
.902 .31019 Mdot
.902 .31034 Mdot
.902 .31039 Mdot
.902 .31047 Mdot
.902 .31053 Mdot
.902 .31054 Mdot
.902 .31066 Mdot
.902 .31071 Mdot
.902 .31075 Mdot
.902 .31086 Mdot
.902 .3109 Mdot
.902 .31091 Mdot
.902 .31127 Mdot
.902 .31131 Mdot
.902 .31158 Mdot
.902 .31189 Mdot
.902 .31205 Mdot
.902 .31212 Mdot
.902 .31237 Mdot
.902 .3125 Mdot
.902 .3125 Mdot
.902 .31272 Mdot
.902 .313 Mdot
.902 .31301 Mdot
.902 .31311 Mdot
.902 .3133 Mdot
.902 .31335 Mdot
.902 .31347 Mdot
.902 .31359 Mdot
.902 .31395 Mdot
.902 .31476 Mdot
.902 .3148 Mdot
.902 .31535 Mdot
.902 .31593 Mdot
.902 .31597 Mdot
.902 .31606 Mdot
.902 .31616 Mdot
.902 .3163 Mdot
.902 .31664 Mdot
.902 .31717 Mdot
.902 .31762 Mdot
.902 .31789 Mdot
.902 .31801 Mdot
.902 .31801 Mdot
.902 .3182 Mdot
.902 .31842 Mdot
.902 .31887 Mdot
.902 .31897 Mdot
.902 .31901 Mdot
.902 .31944 Mdot
.902 .31959 Mdot
.902 .32006 Mdot
.902 .32033 Mdot
.902 .32045 Mdot
.902 .32069 Mdot
.902 .32103 Mdot
.902 .3213 Mdot
.902 .322 Mdot
.902 .32214 Mdot
.902 .32278 Mdot
.902 .32295 Mdot
.902 .32299 Mdot
.902 .32333 Mdot
.902 .32338 Mdot
.902 .32339 Mdot
.902 .32361 Mdot
.902 .32455 Mdot
.902 .32519 Mdot
.902 .32556 Mdot
.902 .32569 Mdot
.902 .32601 Mdot
.902 .3263 Mdot
.902 .32637 Mdot
.902 .32653 Mdot
.902 .32665 Mdot
.902 .32714 Mdot
.902 .32717 Mdot
.902 .32794 Mdot
.902 .32799 Mdot
.902 .32801 Mdot
.902 .32831 Mdot
.902 .32832 Mdot
.902 .32846 Mdot
.902 .32849 Mdot
.902 .32853 Mdot
.902 .32854 Mdot
.902 .32859 Mdot
.902 .3293 Mdot
.902 .32954 Mdot
.902 .33004 Mdot
.902 .33128 Mdot
.902 .33174 Mdot
.902 .33256 Mdot
.902 .33307 Mdot
.902 .33338 Mdot
.902 .33367 Mdot
.902 .33381 Mdot
.902 .3339 Mdot
.902 .33444 Mdot
.902 .33477 Mdot
.902 .33482 Mdot
.902 .33493 Mdot
.902 .33634 Mdot
.902 .33637 Mdot
.902 .3364 Mdot
.902 .33646 Mdot
.902 .33667 Mdot
.902 .33682 Mdot
.902 .33685 Mdot
.902 .33689 Mdot
.902 .33709 Mdot
.902 .33712 Mdot
.902 .33743 Mdot
.902 .33773 Mdot
.902 .33774 Mdot
.902 .33778 Mdot
.902 .33791 Mdot
.902 .33815 Mdot
.902 .3383 Mdot
.902 .33843 Mdot
.902 .33868 Mdot
.902 .339 Mdot
.902 .33923 Mdot
.902 .33924 Mdot
.902 .33925 Mdot
.902 .3393 Mdot
.902 .33935 Mdot
.902 .33935 Mdot
.902 .34047 Mdot
.902 .34155 Mdot
.902 .34218 Mdot
.902 .35158 Mdot
.902 .36419 Mdot
.902 .36733 Mdot
.902 .36763 Mdot
.902 .36777 Mdot
.902 .37435 Mdot
.902 .37466 Mdot
.902 .37631 Mdot
.902 .378 Mdot
.902 .38195 Mdot
.902 .38414 Mdot
.902 .38423 Mdot
.902 .39853 Mdot
.902 .40061 Mdot
.902 .40616 Mdot
.902 .40657 Mdot
.902 .40698 Mdot
.902 .4073 Mdot
.902 .40749 Mdot
.902 .40779 Mdot
.902 .40817 Mdot
.902 .40839 Mdot
.902 .40944 Mdot
.902 .41012 Mdot
.902 .41047 Mdot
.902 .41085 Mdot
.902 .41112 Mdot
.902 .41163 Mdot
.902 .41254 Mdot
.902 .41329 Mdot
.902 .41433 Mdot
.902 .41499 Mdot
.902 .41548 Mdot
.902 .41862 Mdot
.902 .41868 Mdot
.902 .41931 Mdot
.902 .41956 Mdot
.902 .4208 Mdot
.902 .42124 Mdot
.902 .42481 Mdot
.902 .4257 Mdot
.902 .42608 Mdot
.902 .42646 Mdot
.902 .42653 Mdot
.902 .42808 Mdot
.902 .42818 Mdot
.902 .42894 Mdot
.902 .43219 Mdot
.902 .43489 Mdot
.902 .43509 Mdot
.902 .4365 Mdot
.902 .43729 Mdot
.902 .43836 Mdot
.902 .43919 Mdot
.902 .4396 Mdot
.902 .43961 Mdot
.902 .4404 Mdot
.902 .44097 Mdot
.902 .44167 Mdot
.902 .44178 Mdot
.902 .44375 Mdot
.902 .44407 Mdot
.902 .44542 Mdot
.902 .44674 Mdot
.902 .4479 Mdot
.902 .44848 Mdot
.902 .44918 Mdot
.902 .45006 Mdot
.902 .45062 Mdot
.902 .45086 Mdot
.902 .45092 Mdot
.902 .451 Mdot
.902 .45224 Mdot
.902 .45269 Mdot
.902 .45317 Mdot
.902 .45484 Mdot
.902 .45518 Mdot
.902 .45596 Mdot
.902 .4569 Mdot
.902 .4574 Mdot
.902 .45788 Mdot
.902 .4585 Mdot
.902 .45894 Mdot
.902 .46092 Mdot
.902 .46164 Mdot
.902 .46196 Mdot
.902 .46323 Mdot
.902 .46336 Mdot
.902 .46374 Mdot
.902 .4646 Mdot
.902 .46512 Mdot
.902 .466 Mdot
.902 .46737 Mdot
.902 .46747 Mdot
.902 .46876 Mdot
.902 .46935 Mdot
.902 .46944 Mdot
.902 .4699 Mdot
.902 .47011 Mdot
.902 .47125 Mdot
.902 .47167 Mdot
.902 .47458 Mdot
.902 .47526 Mdot
.902 .4755 Mdot
.902 .47568 Mdot
.902 .47571 Mdot
.902 .47628 Mdot
.902 .48006 Mdot
.902 .48305 Mdot
.902 .48357 Mdot
.902 .48846 Mdot
.902 .48954 Mdot
.902 .49456 Mdot
.902 .49496 Mdot
.902 .49538 Mdot
.902 .49586 Mdot
.902 .50009 Mdot
.902 .50081 Mdot
.902 .50164 Mdot
.902 .5029 Mdot
.902 .50699 Mdot
.902 .507 Mdot
.902 .50956 Mdot
.902 .51262 Mdot
.902 .51406 Mdot
.902 .51406 Mdot
.902 .51588 Mdot
.902 .51588 Mdot
.902 .51588 Mdot
.902 .51588 Mdot
.902 .51588 Mdot
.902 .51588 Mdot
.902 .5159 Mdot
.902 .51591 Mdot
.902 .51592 Mdot
.902 .51593 Mdot
.902 .51593 Mdot
.902 .51595 Mdot
.902 .51599 Mdot
.902 .516 Mdot
.902 .516 Mdot
.902 .51601 Mdot
.902 .51602 Mdot
.902 .51602 Mdot
.902 .51602 Mdot
.902 .51603 Mdot
.902 .51603 Mdot
.902 .51604 Mdot
.902 .51608 Mdot
.902 .51612 Mdot
.902 .51613 Mdot
.902 .51616 Mdot
.902 .51616 Mdot
.902 .51618 Mdot
.902 .51621 Mdot
.902 .51621 Mdot
.902 .51622 Mdot
.902 .51624 Mdot
.902 .51624 Mdot
.902 .51628 Mdot
.902 .51633 Mdot
.902 .51634 Mdot
.902 .51642 Mdot
.902 .51643 Mdot
.902 .51646 Mdot
.902 .51648 Mdot
.902 .5165 Mdot
.902 .5165 Mdot
.902 .51658 Mdot
.902 .51664 Mdot
.902 .51664 Mdot
.902 .51666 Mdot
.902 .51679 Mdot
.902 .51681 Mdot
.902 .51692 Mdot
.902 .51694 Mdot
.902 .51694 Mdot
.902 .51696 Mdot
.902 .51702 Mdot
.902 .51705 Mdot
.902 .51706 Mdot
.902 .51718 Mdot
.902 .51722 Mdot
.902 .51724 Mdot
.902 .51725 Mdot
.902 .51726 Mdot
.902 .51733 Mdot
.902 .5174 Mdot
.902 .51743 Mdot
.902 .51743 Mdot
.902 .51755 Mdot
.902 .51755 Mdot
.902 .51758 Mdot
.902 .51761 Mdot
.902 .51762 Mdot
.902 .5178 Mdot
.902 .51783 Mdot
.902 .51787 Mdot
.902 .51788 Mdot
.902 .51795 Mdot
.902 .51795 Mdot
.902 .51804 Mdot
.902 .51806 Mdot
.902 .51822 Mdot
.902 .51828 Mdot
.902 .51833 Mdot
.902 .5184 Mdot
.902 .51843 Mdot
.902 .51848 Mdot
.902 .51863 Mdot
.902 .51878 Mdot
.902 .51885 Mdot
.902 .51888 Mdot
.902 .5189 Mdot
.902 .51894 Mdot
.902 .51901 Mdot
.902 .5191 Mdot
.902 .51918 Mdot
.902 .51919 Mdot
.902 .51922 Mdot
.902 .51932 Mdot
.902 .51932 Mdot
.902 .51935 Mdot
.902 .51939 Mdot
.902 .51941 Mdot
.902 .5195 Mdot
.902 .5195 Mdot
.902 .51956 Mdot
.902 .51957 Mdot
.902 .51957 Mdot
.902 .51959 Mdot
.902 .51963 Mdot
.902 .51967 Mdot
.902 .51981 Mdot
.902 .51988 Mdot
.902 .51988 Mdot
.902 .51997 Mdot
.902 .51999 Mdot
.902 .52004 Mdot
.902 .52013 Mdot
.902 .52013 Mdot
.902 .52014 Mdot
.902 .52014 Mdot
.902 .52019 Mdot
.902 .52025 Mdot
.902 .52027 Mdot
.902 .52027 Mdot
.902 .52032 Mdot
.902 .52048 Mdot
.902 .52052 Mdot
.902 .52052 Mdot
.902 .52053 Mdot
.902 .52087 Mdot
.902 .52087 Mdot
.902 .52097 Mdot
.902 .52117 Mdot
.902 .52133 Mdot
.902 .52133 Mdot
.902 .52165 Mdot
.902 .5217 Mdot
.902 .52174 Mdot
.902 .52197 Mdot
.902 .522 Mdot
.902 .52204 Mdot
.902 .52231 Mdot
.902 .52237 Mdot
.902 .52261 Mdot
.902 .52264 Mdot
.902 .52279 Mdot
.902 .52297 Mdot
.902 .523 Mdot
.902 .523 Mdot
.902 .52301 Mdot
.902 .52302 Mdot
.902 .52305 Mdot
.902 .52319 Mdot
.902 .52326 Mdot
.902 .52327 Mdot
.902 .52329 Mdot
.902 .52332 Mdot
.902 .52339 Mdot
.902 .52351 Mdot
.902 .52357 Mdot
.902 .52357 Mdot
.902 .52364 Mdot
.902 .52377 Mdot
.902 .52379 Mdot
.902 .52381 Mdot
.902 .52383 Mdot
.902 .52386 Mdot
.902 .52393 Mdot
.902 .52395 Mdot
.902 .52402 Mdot
.902 .52406 Mdot
.902 .52412 Mdot
.902 .52412 Mdot
.902 .52413 Mdot
.902 .52416 Mdot
.902 .52422 Mdot
.902 .5243 Mdot
.902 .52441 Mdot
.902 .52443 Mdot
.902 .52451 Mdot
.902 .52452 Mdot
.902 .52457 Mdot
.902 .5246 Mdot
.902 .5246 Mdot
.902 .52462 Mdot
.902 .52466 Mdot
.902 .52474 Mdot
.902 .5248 Mdot
.902 .5248 Mdot
.902 .52509 Mdot
.902 .52509 Mdot
.902 .52516 Mdot
.902 .52518 Mdot
.902 .52519 Mdot
.902 .52523 Mdot
.902 .52535 Mdot
.902 .52538 Mdot
.902 .5254 Mdot
.902 .52545 Mdot
.902 .52546 Mdot
.902 .52549 Mdot
.902 .52549 Mdot
.902 .52562 Mdot
.902 .52564 Mdot
.902 .52567 Mdot
.902 .52572 Mdot
.902 .52575 Mdot
.902 .52579 Mdot
.902 .52583 Mdot
.902 .52585 Mdot
.902 .52588 Mdot
.902 .52592 Mdot
.902 .52593 Mdot
.902 .52596 Mdot
.902 .52597 Mdot
.902 .52598 Mdot
.902 .52602 Mdot
.902 .52697 Mdot
.902 .52698 Mdot
.902 .52775 Mdot
.902 .52924 Mdot
.902 .52972 Mdot
.902 .53013 Mdot
.902 .53032 Mdot
.902 .53033 Mdot
.902 .53042 Mdot
.902 .53098 Mdot
.902 .53105 Mdot
.902 .53184 Mdot
.902 .53208 Mdot
.902 .53248 Mdot
.902 .53277 Mdot
.902 .53277 Mdot
.902 .53367 Mdot
.902 .53392 Mdot
.902 .53402 Mdot
.902 .5347 Mdot
.902 .53483 Mdot
.902 .53547 Mdot
.902 .53599 Mdot
.902 .53628 Mdot
.902 .5365 Mdot
.902 .53672 Mdot
.902 .53726 Mdot
.902 .5383 Mdot
.902 .53856 Mdot
.902 .53931 Mdot
.902 .5396 Mdot
.902 .53981 Mdot
.902 .53986 Mdot
.902 .53999 Mdot
.902 .54019 Mdot
.902 .54051 Mdot
.902 .54082 Mdot
.902 .541 Mdot
.902 .54101 Mdot
.902 .54166 Mdot
.902 .54175 Mdot
.902 .5418 Mdot
.902 .54208 Mdot
.902 .54218 Mdot
.902 .54219 Mdot
.902 .5422 Mdot
.902 .54251 Mdot
.902 .54253 Mdot
.902 .5426 Mdot
.902 .5427 Mdot
.902 .54285 Mdot
.902 .54354 Mdot
.902 .54358 Mdot
.902 .54368 Mdot
.902 .54378 Mdot
.902 .54379 Mdot
.902 .54416 Mdot
.902 .54416 Mdot
.902 .54425 Mdot
.902 .54446 Mdot
.902 .54464 Mdot
.902 .54466 Mdot
.902 .5447 Mdot
.902 .54474 Mdot
.902 .54483 Mdot
.902 .54509 Mdot
.902 .54511 Mdot
.902 .54516 Mdot
.902 .54527 Mdot
.902 .5453 Mdot
.902 .5453 Mdot
.902 .54533 Mdot
.902 .54533 Mdot
.902 .54549 Mdot
.902 .54551 Mdot
.902 .54561 Mdot
.902 .54561 Mdot
.902 .54561 Mdot
.902 .54561 Mdot
.902 .54561 Mdot
.902 .54562 Mdot
.902 .54563 Mdot
.902 .54564 Mdot
.902 .54565 Mdot
.902 .54565 Mdot
.902 .54565 Mdot
.902 .54566 Mdot
.902 .54567 Mdot
.902 .54567 Mdot
.902 .54567 Mdot
.902 .5457 Mdot
.902 .54571 Mdot
.902 .54571 Mdot
.902 .54572 Mdot
.902 .54572 Mdot
.902 .54572 Mdot
.902 .54572 Mdot
.902 .54572 Mdot
.902 .54573 Mdot
.902 .54573 Mdot
.902 .54573 Mdot
.902 .54574 Mdot
.902 .54575 Mdot
.902 .54575 Mdot
.902 .54576 Mdot
.902 .54576 Mdot
.902 .54577 Mdot
.902 .54577 Mdot
.902 .54577 Mdot
.902 .54578 Mdot
.902 .54578 Mdot
.902 .54579 Mdot
.902 .54579 Mdot
.902 .54579 Mdot
.902 .54579 Mdot
.902 .5458 Mdot
.902 .5458 Mdot
.902 .5458 Mdot
.902 .5458 Mdot
.902 .54581 Mdot
.902 .54581 Mdot
.902 .54581 Mdot
.902 .54581 Mdot
.902 .54581 Mdot
.904 .14411 Mdot
.904 .14427 Mdot
.904 .14555 Mdot
.904 .14556 Mdot
.904 .14558 Mdot
.904 .14561 Mdot
.904 .14561 Mdot
.904 .14562 Mdot
.904 .14562 Mdot
.904 .14562 Mdot
.904 .14562 Mdot
.904 .14564 Mdot
.904 .14566 Mdot
.904 .14566 Mdot
.904 .14567 Mdot
.904 .14571 Mdot
.904 .14577 Mdot
.904 .1458 Mdot
.904 .14581 Mdot
.904 .1459 Mdot
.904 .1459 Mdot
.904 .14591 Mdot
.904 .14591 Mdot
.904 .14595 Mdot
.904 .14599 Mdot
.904 .14613 Mdot
.904 .14626 Mdot
.904 .14629 Mdot
.904 .14641 Mdot
.904 .1465 Mdot
.904 .14661 Mdot
.904 .14679 Mdot
.904 .14696 Mdot
.904 .14726 Mdot
.904 .14772 Mdot
.904 .14782 Mdot
.904 .14832 Mdot
.904 .14865 Mdot
.904 .14922 Mdot
.904 .14922 Mdot
.904 .14978 Mdot
.904 .14978 Mdot
.904 .15 Mdot
.904 .15005 Mdot
.904 .15021 Mdot
.904 .1503 Mdot
.904 .15036 Mdot
.904 .15048 Mdot
.904 .15072 Mdot
.904 .15079 Mdot
.904 .15142 Mdot
.904 .15153 Mdot
.904 .15171 Mdot
.904 .15205 Mdot
.904 .15296 Mdot
.904 .15364 Mdot
.904 .15382 Mdot
.904 .15422 Mdot
.904 .15435 Mdot
.904 .15474 Mdot
.904 .15484 Mdot
.904 .15499 Mdot
.904 .15512 Mdot
.904 .15543 Mdot
.904 .15551 Mdot
.904 .15557 Mdot
.904 .1557 Mdot
.904 .15641 Mdot
.904 .15667 Mdot
.904 .157 Mdot
.904 .15711 Mdot
.904 .15718 Mdot
.904 .15754 Mdot
.904 .15784 Mdot
.904 .15983 Mdot
.904 .15988 Mdot
.904 .16175 Mdot
.904 .16226 Mdot
.904 .16415 Mdot
.904 .16527 Mdot
.904 .16595 Mdot
.904 .1683 Mdot
.904 .16846 Mdot
.904 .16853 Mdot
.904 .17021 Mdot
.904 .17069 Mdot
.904 .17267 Mdot
.904 .17387 Mdot
.904 .17498 Mdot
.904 .17586 Mdot
.904 .17716 Mdot
.904 .17989 Mdot
.904 .18021 Mdot
.904 .18033 Mdot
.904 .1805 Mdot
.904 .18128 Mdot
.904 .18129 Mdot
.904 .18134 Mdot
.904 .18145 Mdot
.904 .18148 Mdot
.904 .18151 Mdot
.904 .18178 Mdot
.904 .18216 Mdot
.904 .18227 Mdot
.904 .18249 Mdot
.904 .18265 Mdot
.904 .18305 Mdot
.904 .18305 Mdot
.904 .1833 Mdot
.904 .18346 Mdot
.904 .18465 Mdot
.904 .18471 Mdot
.904 .18525 Mdot
.904 .18547 Mdot
.904 .18551 Mdot
.904 .1871 Mdot
.904 .18751 Mdot
.904 .18761 Mdot
.904 .18765 Mdot
.904 .18858 Mdot
.904 .18901 Mdot
.904 .1893 Mdot
.904 .19144 Mdot
.904 .19257 Mdot
.904 .19318 Mdot
.904 .19552 Mdot
.904 .19605 Mdot
.904 .19622 Mdot
.904 .1988 Mdot
.904 .1991 Mdot
.904 .20084 Mdot
.904 .20234 Mdot
.904 .20288 Mdot
.904 .20339 Mdot
.904 .2034 Mdot
.904 .20744 Mdot
.904 .20899 Mdot
.904 .20957 Mdot
.904 .21018 Mdot
.904 .21151 Mdot
.904 .21198 Mdot
.904 .21203 Mdot
.904 .21359 Mdot
.904 .21366 Mdot
.904 .21461 Mdot
.904 .21461 Mdot
.904 .21564 Mdot
.904 .21594 Mdot
.904 .21819 Mdot
.904 .21842 Mdot
.904 .21925 Mdot
.904 .22396 Mdot
.904 .2244 Mdot
.904 .22848 Mdot
.904 .22894 Mdot
.904 .23071 Mdot
.904 .23124 Mdot
.904 .23299 Mdot
.904 .23463 Mdot
.904 .23553 Mdot
.904 .23586 Mdot
.904 .23601 Mdot
.904 .23606 Mdot
.904 .23788 Mdot
.904 .23812 Mdot
.904 .23813 Mdot
.904 .23817 Mdot
.904 .23876 Mdot
.904 .23925 Mdot
.904 .23938 Mdot
.904 .23991 Mdot
.904 .24052 Mdot
.904 .24093 Mdot
.904 .24094 Mdot
.904 .24111 Mdot
.904 .24153 Mdot
.904 .24168 Mdot
.904 .24314 Mdot
.904 .24375 Mdot
.904 .2438 Mdot
.904 .24447 Mdot
.904 .24484 Mdot
.904 .24585 Mdot
.904 .2462 Mdot
.904 .24715 Mdot
.904 .24839 Mdot
.904 .24902 Mdot
.904 .24954 Mdot
.904 .25016 Mdot
.904 .25078 Mdot
.904 .25105 Mdot
.904 .2513 Mdot
.904 .25139 Mdot
.904 .25217 Mdot
.904 .25224 Mdot
.904 .2526 Mdot
.904 .2526 Mdot
.904 .2527 Mdot
.904 .25276 Mdot
.904 .2538 Mdot
.904 .25495 Mdot
.904 .25571 Mdot
.904 .25608 Mdot
.904 .25689 Mdot
.904 .25696 Mdot
.904 .25725 Mdot
.904 .25734 Mdot
.904 .25814 Mdot
.904 .25815 Mdot
.904 .25824 Mdot
.904 .25857 Mdot
.904 .25909 Mdot
.904 .25938 Mdot
.904 .25967 Mdot
.904 .25975 Mdot
.904 .26 Mdot
.904 .26052 Mdot
.904 .26136 Mdot
.904 .26208 Mdot
.904 .26239 Mdot
.904 .2625 Mdot
.904 .26306 Mdot
.904 .26337 Mdot
.904 .26337 Mdot
.904 .2634 Mdot
.904 .26341 Mdot
.904 .26359 Mdot
.904 .26393 Mdot
.904 .26473 Mdot
.904 .26478 Mdot
.904 .26479 Mdot
.904 .26499 Mdot
.904 .26501 Mdot
.904 .26506 Mdot
.904 .26512 Mdot
.904 .26531 Mdot
.904 .26569 Mdot
.904 .26582 Mdot
.904 .26601 Mdot
.904 .26624 Mdot
.904 .26651 Mdot
.904 .26695 Mdot
.904 .26736 Mdot
.904 .26754 Mdot
.904 .26761 Mdot
.904 .26788 Mdot
.904 .26807 Mdot
.904 .26844 Mdot
.904 .26887 Mdot
.904 .26896 Mdot
.904 .26919 Mdot
.904 .26927 Mdot
.904 .26936 Mdot
.904 .26936 Mdot
.904 .2695 Mdot
.904 .26951 Mdot
.904 .26973 Mdot
.904 .26978 Mdot
.904 .27031 Mdot
.904 .27041 Mdot
.904 .27073 Mdot
.904 .27102 Mdot
.904 .27134 Mdot
.904 .2718 Mdot
.904 .27202 Mdot
.904 .2722 Mdot
.904 .2723 Mdot
.904 .27245 Mdot
.904 .2725 Mdot
.904 .27255 Mdot
.904 .27284 Mdot
.904 .27356 Mdot
.904 .27389 Mdot
.904 .27419 Mdot
.904 .27427 Mdot
.904 .27453 Mdot
.904 .27455 Mdot
.904 .27457 Mdot
.904 .27497 Mdot
.904 .27509 Mdot
.904 .27529 Mdot
.904 .27565 Mdot
.904 .27575 Mdot
.904 .27613 Mdot
.904 .27614 Mdot
.904 .27658 Mdot
.904 .27678 Mdot
.904 .27685 Mdot
.904 .27714 Mdot
.904 .27725 Mdot
.904 .27728 Mdot
.904 .27732 Mdot
.904 .27735 Mdot
.904 .27745 Mdot
.904 .27749 Mdot
.904 .2776 Mdot
.904 .27765 Mdot
.904 .27785 Mdot
.904 .27812 Mdot
.904 .27823 Mdot
.904 .27829 Mdot
.904 .27833 Mdot
.904 .27854 Mdot
.904 .27865 Mdot
.904 .27869 Mdot
.904 .27872 Mdot
.904 .27875 Mdot
.904 .27881 Mdot
.904 .27891 Mdot
.904 .27913 Mdot
.904 .27937 Mdot
.904 .27951 Mdot
.904 .27974 Mdot
.904 .27979 Mdot
.904 .28002 Mdot
.904 .28018 Mdot
.904 .28028 Mdot
.904 .28039 Mdot
.904 .28045 Mdot
.904 .28051 Mdot
.904 .28059 Mdot
.904 .2806 Mdot
.904 .28069 Mdot
.904 .28081 Mdot
.904 .28084 Mdot
.904 .28084 Mdot
.904 .28084 Mdot
.904 .28084 Mdot
.904 .28091 Mdot
.904 .28092 Mdot
.904 .28094 Mdot
.904 .28099 Mdot
.904 .28102 Mdot
.904 .28102 Mdot
.904 .28103 Mdot
.904 .28104 Mdot
.904 .28105 Mdot
.904 .28105 Mdot
.904 .28105 Mdot
.904 .28106 Mdot
.904 .28106 Mdot
.904 .28106 Mdot
.904 .28109 Mdot
.904 .2811 Mdot
.904 .28111 Mdot
.904 .28349 Mdot
.904 .28803 Mdot
.904 .29031 Mdot
.904 .29035 Mdot
.904 .29039 Mdot
.904 .29081 Mdot
.904 .29083 Mdot
.904 .29093 Mdot
.904 .29469 Mdot
.904 .29582 Mdot
.904 .29588 Mdot
.904 .29593 Mdot
.904 .29607 Mdot
.904 .29608 Mdot
.904 .29609 Mdot
.904 .2961 Mdot
.904 .29611 Mdot
.904 .29612 Mdot
.904 .29616 Mdot
.904 .29623 Mdot
.904 .29625 Mdot
.904 .29629 Mdot
.904 .29643 Mdot
.904 .29667 Mdot
.904 .29677 Mdot
.904 .29681 Mdot
.904 .29716 Mdot
.904 .29716 Mdot
.904 .29718 Mdot
.904 .29718 Mdot
.904 .29734 Mdot
.904 .29746 Mdot
.904 .298 Mdot
.904 .29848 Mdot
.904 .29857 Mdot
.904 .29901 Mdot
.904 .29933 Mdot
.904 .29974 Mdot
.904 .30037 Mdot
.904 .301 Mdot
.904 .30168 Mdot
.904 .30207 Mdot
.904 .30293 Mdot
.904 .30364 Mdot
.904 .304 Mdot
.904 .30568 Mdot
.904 .30654 Mdot
.904 .30678 Mdot
.904 .30865 Mdot
.904 .30867 Mdot
.904 .30891 Mdot
.904 .31008 Mdot
.904 .31008 Mdot
.904 .31009 Mdot
.904 .31009 Mdot
.904 .31013 Mdot
.904 .31021 Mdot
.904 .31042 Mdot
.904 .31042 Mdot
.904 .31047 Mdot
.904 .31065 Mdot
.904 .31073 Mdot
.904 .31079 Mdot
.904 .31108 Mdot
.904 .31113 Mdot
.904 .31127 Mdot
.904 .31149 Mdot
.904 .31167 Mdot
.904 .31175 Mdot
.904 .31194 Mdot
.904 .31203 Mdot
.904 .31212 Mdot
.904 .31222 Mdot
.904 .31259 Mdot
.904 .31261 Mdot
.904 .31318 Mdot
.904 .31331 Mdot
.904 .31352 Mdot
.904 .3136 Mdot
.904 .31375 Mdot
.904 .31424 Mdot
.904 .31427 Mdot
.904 .31446 Mdot
.904 .31466 Mdot
.904 .31525 Mdot
.904 .31527 Mdot
.904 .3153 Mdot
.904 .31537 Mdot
.904 .31551 Mdot
.904 .31567 Mdot
.904 .31619 Mdot
.904 .31643 Mdot
.904 .31661 Mdot
.904 .31678 Mdot
.904 .31713 Mdot
.904 .31725 Mdot
.904 .3173 Mdot
.904 .31755 Mdot
.904 .31767 Mdot
.904 .31862 Mdot
.904 .31867 Mdot
.904 .31923 Mdot
.904 .31924 Mdot
.904 .31958 Mdot
.904 .32111 Mdot
.904 .32128 Mdot
.904 .32133 Mdot
.904 .32164 Mdot
.904 .32165 Mdot
.904 .3217 Mdot
.904 .32179 Mdot
.904 .32202 Mdot
.904 .3222 Mdot
.904 .32262 Mdot
.904 .32277 Mdot
.904 .32308 Mdot
.904 .32341 Mdot
.904 .32345 Mdot
.904 .32359 Mdot
.904 .32399 Mdot
.904 .32413 Mdot
.904 .32418 Mdot
.904 .32422 Mdot
.904 .32424 Mdot
.904 .32456 Mdot
.904 .32477 Mdot
.904 .32487 Mdot
.904 .32501 Mdot
.904 .32518 Mdot
.904 .32556 Mdot
.904 .32574 Mdot
.904 .32587 Mdot
.904 .32616 Mdot
.904 .32622 Mdot
.904 .32627 Mdot
.904 .32656 Mdot
.904 .32657 Mdot
.904 .32694 Mdot
.904 .32711 Mdot
.904 .32726 Mdot
.904 .32734 Mdot
.904 .32764 Mdot
.904 .32817 Mdot
.904 .32881 Mdot
.904 .32883 Mdot
.904 .32888 Mdot
.904 .32903 Mdot
.904 .32909 Mdot
.904 .32916 Mdot
.904 .32916 Mdot
.904 .32916 Mdot
.904 .3294 Mdot
.904 .32941 Mdot
.904 .32943 Mdot
.904 .32984 Mdot
.904 .3299 Mdot
.904 .3301 Mdot
.904 .33037 Mdot
.904 .33038 Mdot
.904 .33051 Mdot
.904 .33098 Mdot
.904 .33113 Mdot
.904 .33131 Mdot
.904 .33135 Mdot
.904 .33138 Mdot
.904 .33139 Mdot
.904 .33151 Mdot
.904 .33157 Mdot
.904 .33158 Mdot
.904 .3321 Mdot
.904 .3325 Mdot
.904 .33269 Mdot
.904 .33283 Mdot
.904 .33317 Mdot
.904 .33319 Mdot
.904 .33362 Mdot
.904 .33369 Mdot
.904 .33374 Mdot
.904 .33454 Mdot
.904 .33588 Mdot
.904 .336 Mdot
.904 .3361 Mdot
.904 .33651 Mdot
.904 .33665 Mdot
.904 .33713 Mdot
.904 .33727 Mdot
.904 .33739 Mdot
.904 .33761 Mdot
.904 .33763 Mdot
.904 .3378 Mdot
.904 .33833 Mdot
.904 .33854 Mdot
.904 .33886 Mdot
.904 .33906 Mdot
.904 .33919 Mdot
.904 .3394 Mdot
.904 .33957 Mdot
.904 .33962 Mdot
.904 .33975 Mdot
.904 .33989 Mdot
.904 .33995 Mdot
.904 .33997 Mdot
.904 .33998 Mdot
.904 .34001 Mdot
.904 .34004 Mdot
.904 .34005 Mdot
.904 .34006 Mdot
.904 .34006 Mdot
.904 .34006 Mdot
.904 .3429 Mdot
.904 .34362 Mdot
.904 .34437 Mdot
.904 .34992 Mdot
.904 .3592 Mdot
.904 .36104 Mdot
.904 .36247 Mdot
.904 .36354 Mdot
.904 .36826 Mdot
.904 .37019 Mdot
.904 .37048 Mdot
.904 .37058 Mdot
.904 .37619 Mdot
.904 .37807 Mdot
.904 .38542 Mdot
.904 .38919 Mdot
.904 .38958 Mdot
.904 .39111 Mdot
.904 .39179 Mdot
.904 .39201 Mdot
.904 .40065 Mdot
.904 .4018 Mdot
.904 .40183 Mdot
.904 .40201 Mdot
.904 .40488 Mdot
.904 .4072 Mdot
.904 .40786 Mdot
.904 .40983 Mdot
.904 .41044 Mdot
.904 .41336 Mdot
.904 .41342 Mdot
.904 .41543 Mdot
.904 .41545 Mdot
.904 .4163 Mdot
.904 .41835 Mdot
.904 .41907 Mdot
.904 .42341 Mdot
.904 .42629 Mdot
.904 .42759 Mdot
.904 .42769 Mdot
.904 .42929 Mdot
.904 .42956 Mdot
.904 .43285 Mdot
.904 .43468 Mdot
.904 .43761 Mdot
.904 .4379 Mdot
.904 .43961 Mdot
.904 .44135 Mdot
.904 .44601 Mdot
.904 .45199 Mdot
.904 .45212 Mdot
.904 .45503 Mdot
.904 .45507 Mdot
.904 .45752 Mdot
.904 .46047 Mdot
.904 .46338 Mdot
.904 .4644 Mdot
.904 .46464 Mdot
.904 .46583 Mdot
.904 .46624 Mdot
.904 .46746 Mdot
.904 .46985 Mdot
.904 .47014 Mdot
.904 .4718 Mdot
.904 .47182 Mdot
.904 .47224 Mdot
.904 .47255 Mdot
.904 .47721 Mdot
.904 .47801 Mdot
.904 .48227 Mdot
.904 .48555 Mdot
.904 .4871 Mdot
.904 .49031 Mdot
.904 .49052 Mdot
.904 .4908 Mdot
.904 .49109 Mdot
.904 .49119 Mdot
.904 .49198 Mdot
.904 .49237 Mdot
.904 .49558 Mdot
.904 .4956 Mdot
.904 .49585 Mdot
.904 .49598 Mdot
.904 .4973 Mdot
.904 .49933 Mdot
.904 .50044 Mdot
.904 .50153 Mdot
.904 .50185 Mdot
.904 .50279 Mdot
.904 .5047 Mdot
.904 .50775 Mdot
.904 .51028 Mdot
.904 .51135 Mdot
.904 .5117 Mdot
.904 .51361 Mdot
.904 .51461 Mdot
.904 .51462 Mdot
.904 .51472 Mdot
.904 .51473 Mdot
.904 .51532 Mdot
.904 .51643 Mdot
.904 .517 Mdot
.904 .51701 Mdot
.904 .51701 Mdot
.904 .51702 Mdot
.904 .51702 Mdot
.904 .51702 Mdot
.904 .51702 Mdot
.904 .51702 Mdot
.904 .51702 Mdot
.904 .51702 Mdot
.904 .51702 Mdot
.904 .51702 Mdot
.904 .51703 Mdot
.904 .51703 Mdot
.904 .51704 Mdot
.904 .51705 Mdot
.904 .51705 Mdot
.904 .51707 Mdot
.904 .51707 Mdot
.904 .51707 Mdot
.904 .51707 Mdot
.904 .51708 Mdot
.904 .5171 Mdot
.904 .51712 Mdot
.904 .51713 Mdot
.904 .51715 Mdot
.904 .51716 Mdot
.904 .51718 Mdot
.904 .5172 Mdot
.904 .51722 Mdot
.904 .51726 Mdot
.904 .51732 Mdot
.904 .51733 Mdot
.904 .51738 Mdot
.904 .51742 Mdot
.904 .51747 Mdot
.904 .51752 Mdot
.904 .51755 Mdot
.904 .51756 Mdot
.904 .51757 Mdot
.904 .51757 Mdot
.904 .51758 Mdot
.904 .51761 Mdot
.904 .51766 Mdot
.904 .51767 Mdot
.904 .51768 Mdot
.904 .51771 Mdot
.904 .51777 Mdot
.904 .51782 Mdot
.904 .51783 Mdot
.904 .51786 Mdot
.904 .51786 Mdot
.904 .51789 Mdot
.904 .5179 Mdot
.904 .5179 Mdot
.904 .51791 Mdot
.904 .51794 Mdot
.904 .518 Mdot
.904 .51802 Mdot
.904 .51807 Mdot
.904 .51817 Mdot
.904 .51817 Mdot
.904 .51826 Mdot
.904 .51828 Mdot
.904 .51836 Mdot
.904 .51841 Mdot
.904 .51844 Mdot
.904 .51853 Mdot
.904 .51854 Mdot
.904 .51854 Mdot
.904 .5186 Mdot
.904 .51862 Mdot
.904 .51869 Mdot
.904 .51876 Mdot
.904 .51892 Mdot
.904 .51899 Mdot
.904 .519 Mdot
.904 .51901 Mdot
.904 .51905 Mdot
.904 .51907 Mdot
.904 .51911 Mdot
.904 .51916 Mdot
.904 .51926 Mdot
.904 .51934 Mdot
.904 .5194 Mdot
.904 .51947 Mdot
.904 .5195 Mdot
.904 .51962 Mdot
.904 .51963 Mdot
.904 .51968 Mdot
.904 .51968 Mdot
.904 .51971 Mdot
.904 .51971 Mdot
.904 .51973 Mdot
.904 .51975 Mdot
.904 .5198 Mdot
.904 .51982 Mdot
.904 .51991 Mdot
.904 .52 Mdot
.904 .52004 Mdot
.904 .5201 Mdot
.904 .52011 Mdot
.904 .52015 Mdot
.904 .52024 Mdot
.904 .52034 Mdot
.904 .5204 Mdot
.904 .52045 Mdot
.904 .52049 Mdot
.904 .52052 Mdot
.904 .52061 Mdot
.904 .52065 Mdot
.904 .52066 Mdot
.904 .52067 Mdot
.904 .52068 Mdot
.904 .52072 Mdot
.904 .52072 Mdot
.904 .52073 Mdot
.904 .52091 Mdot
.904 .52098 Mdot
.904 .52102 Mdot
.904 .52102 Mdot
.904 .52103 Mdot
.904 .52103 Mdot
.904 .5211 Mdot
.904 .52122 Mdot
.904 .52124 Mdot
.904 .52131 Mdot
.904 .52147 Mdot
.904 .52165 Mdot
.904 .52176 Mdot
.904 .52182 Mdot
.904 .52183 Mdot
.904 .52189 Mdot
.904 .52196 Mdot
.904 .52207 Mdot
.904 .52214 Mdot
.904 .52216 Mdot
.904 .52216 Mdot
.904 .52233 Mdot
.904 .52235 Mdot
.904 .52241 Mdot
.904 .52243 Mdot
.904 .5226 Mdot
.904 .52268 Mdot
.904 .52284 Mdot
.904 .52309 Mdot
.904 .5233 Mdot
.904 .52332 Mdot
.904 .52334 Mdot
.904 .52334 Mdot
.904 .52342 Mdot
.904 .52343 Mdot
.904 .52359 Mdot
.904 .52361 Mdot
.904 .52367 Mdot
.904 .52372 Mdot
.904 .52385 Mdot
.904 .52398 Mdot
.904 .52409 Mdot
.904 .52422 Mdot
.904 .52448 Mdot
.904 .52468 Mdot
.904 .52475 Mdot
.904 .52496 Mdot
.904 .52504 Mdot
.904 .52517 Mdot
.904 .52519 Mdot
.904 .52531 Mdot
.904 .52561 Mdot
.904 .52564 Mdot
.904 .52573 Mdot
.904 .52577 Mdot
.904 .52577 Mdot
.904 .52585 Mdot
.904 .52598 Mdot
.904 .52609 Mdot
.904 .52611 Mdot
.904 .52621 Mdot
.904 .52633 Mdot
.904 .52634 Mdot
.904 .52634 Mdot
.904 .52639 Mdot
.904 .52677 Mdot
.904 .52678 Mdot
.904 .52681 Mdot
.904 .52687 Mdot
.904 .52706 Mdot
.904 .52739 Mdot
.904 .52775 Mdot
.904 .52786 Mdot
.904 .52822 Mdot
.904 .52831 Mdot
.904 .52914 Mdot
.904 .52923 Mdot
.904 .53018 Mdot
.904 .53035 Mdot
.904 .5304 Mdot
.904 .53085 Mdot
.904 .53092 Mdot
.904 .53112 Mdot
.904 .53112 Mdot
.904 .53132 Mdot
.904 .53133 Mdot
.904 .53165 Mdot
.904 .53166 Mdot
.904 .53175 Mdot
.904 .53203 Mdot
.904 .53215 Mdot
.904 .53227 Mdot
.904 .53258 Mdot
.904 .53341 Mdot
.904 .53341 Mdot
.904 .53352 Mdot
.904 .53363 Mdot
.904 .53394 Mdot
.904 .5343 Mdot
.904 .53436 Mdot
.904 .5349 Mdot
.904 .53493 Mdot
.904 .53504 Mdot
.904 .53553 Mdot
.904 .53566 Mdot
.904 .5359 Mdot
.904 .53635 Mdot
.904 .53641 Mdot
.904 .5365 Mdot
.904 .5367 Mdot
.904 .5367 Mdot
.904 .53673 Mdot
.904 .53673 Mdot
.904 .53681 Mdot
.904 .53715 Mdot
.904 .53716 Mdot
.904 .53721 Mdot
.904 .53732 Mdot
.904 .53734 Mdot
.904 .53759 Mdot
.904 .53763 Mdot
.904 .53768 Mdot
.904 .53768 Mdot
.904 .53777 Mdot
.904 .5378 Mdot
.904 .53785 Mdot
.904 .53787 Mdot
.904 .53796 Mdot
.904 .53802 Mdot
.904 .53802 Mdot
.904 .53803 Mdot
.904 .53805 Mdot
.904 .53806 Mdot
.904 .53807 Mdot
.904 .53824 Mdot
.904 .53827 Mdot
.904 .5383 Mdot
.904 .53837 Mdot
.904 .53897 Mdot
.904 .53925 Mdot
.904 .53945 Mdot
.904 .5397 Mdot
.904 .53996 Mdot
.904 .54041 Mdot
.904 .54052 Mdot
.904 .54091 Mdot
.904 .54092 Mdot
.904 .54096 Mdot
.904 .5415 Mdot
.904 .54166 Mdot
.904 .54192 Mdot
.904 .54237 Mdot
.904 .54249 Mdot
.904 .54294 Mdot
.904 .54295 Mdot
.904 .54344 Mdot
.904 .54351 Mdot
.904 .5436 Mdot
.904 .54361 Mdot
.904 .54364 Mdot
.904 .54372 Mdot
.904 .54379 Mdot
.904 .54396 Mdot
.904 .54399 Mdot
.904 .54401 Mdot
.904 .54403 Mdot
.904 .54411 Mdot
.904 .54414 Mdot
.904 .54418 Mdot
.904 .5442 Mdot
.904 .5443 Mdot
.904 .54433 Mdot
.904 .54443 Mdot
.904 .54448 Mdot
.904 .54465 Mdot
.904 .54488 Mdot
.904 .54497 Mdot
.904 .54502 Mdot
.904 .54504 Mdot
.904 .54521 Mdot
.904 .54522 Mdot
.904 .54529 Mdot
.904 .54532 Mdot
.904 .54533 Mdot
.904 .54536 Mdot
.904 .5454 Mdot
.904 .54541 Mdot
.904 .54547 Mdot
.904 .54547 Mdot
.904 .54561 Mdot
.904 .54562 Mdot
.904 .54577 Mdot
.904 .54585 Mdot
.904 .54599 Mdot
.904 .54601 Mdot
.904 .54613 Mdot
.904 .54621 Mdot
.904 .54626 Mdot
.904 .54631 Mdot
.904 .54634 Mdot
.904 .54636 Mdot
.904 .5464 Mdot
.904 .5464 Mdot
.904 .54644 Mdot
.904 .54648 Mdot
.904 .54649 Mdot
.904 .5465 Mdot
.904 .5465 Mdot
.904 .5465 Mdot
.904 .5465 Mdot
.904 .54652 Mdot
.904 .54653 Mdot
.904 .54653 Mdot
.904 .54655 Mdot
.904 .54656 Mdot
.904 .54657 Mdot
.904 .54657 Mdot
.904 .54657 Mdot
.904 .54657 Mdot
.904 .54658 Mdot
.904 .54658 Mdot
.904 .54658 Mdot
.904 .54658 Mdot
.904 .54658 Mdot
.904 .54659 Mdot
.904 .54659 Mdot
.904 .5466 Mdot
.904 .54695 Mdot
.904 .54699 Mdot
.906 .14062 Mdot
.906 .1407 Mdot
.906 .14096 Mdot
.906 .14099 Mdot
.906 .141 Mdot
.906 .14151 Mdot
.906 .14165 Mdot
.906 .14185 Mdot
.906 .14196 Mdot
.906 .14287 Mdot
.906 .14414 Mdot
.906 .14618 Mdot
.906 .14684 Mdot
.906 .14697 Mdot
.906 .14797 Mdot
.906 .14818 Mdot
.906 .14854 Mdot
.906 .14861 Mdot
.906 .14962 Mdot
.906 .1517 Mdot
.906 .1517 Mdot
.906 .1517 Mdot
.906 .1517 Mdot
.906 .1517 Mdot
.906 .1517 Mdot
.906 .1517 Mdot
.906 .15171 Mdot
.906 .15173 Mdot
.906 .15173 Mdot
.906 .15173 Mdot
.906 .15176 Mdot
.906 .15176 Mdot
.906 .15184 Mdot
.906 .15187 Mdot
.906 .15189 Mdot
.906 .15204 Mdot
.906 .15206 Mdot
.906 .15213 Mdot
.906 .15227 Mdot
.906 .15249 Mdot
.906 .15252 Mdot
.906 .15263 Mdot
.906 .15265 Mdot
.906 .1527 Mdot
.906 .15283 Mdot
.906 .15286 Mdot
.906 .15289 Mdot
.906 .15317 Mdot
.906 .15342 Mdot
.906 .15344 Mdot
.906 .15345 Mdot
.906 .15354 Mdot
.906 .15354 Mdot
.906 .15354 Mdot
.906 .15363 Mdot
.906 .15365 Mdot
.906 .15365 Mdot
.906 .15365 Mdot
.906 .15372 Mdot
.906 .1539 Mdot
.906 .15392 Mdot
.906 .15396 Mdot
.906 .15397 Mdot
.906 .15399 Mdot
.906 .15399 Mdot
.906 .15401 Mdot
.906 .15401 Mdot
.906 .15402 Mdot
.906 .15418 Mdot
.906 .15444 Mdot
.906 .15462 Mdot
.906 .15518 Mdot
.906 .1556 Mdot
.906 .15574 Mdot
.906 .15583 Mdot
.906 .1561 Mdot
.906 .15612 Mdot
.906 .15651 Mdot
.906 .15656 Mdot
.906 .15681 Mdot
.906 .15682 Mdot
.906 .15723 Mdot
.906 .15826 Mdot
.906 .16056 Mdot
.906 .16081 Mdot
.906 .16124 Mdot
.906 .16147 Mdot
.906 .16155 Mdot
.906 .16193 Mdot
.906 .16202 Mdot
.906 .16511 Mdot
.906 .16594 Mdot
.906 .16723 Mdot
.906 .16735 Mdot
.906 .1698 Mdot
.906 .17031 Mdot
.906 .1706 Mdot
.906 .17114 Mdot
.906 .17114 Mdot
.906 .17129 Mdot
.906 .17175 Mdot
.906 .17346 Mdot
.906 .17358 Mdot
.906 .1745 Mdot
.906 .17468 Mdot
.906 .17468 Mdot
.906 .17478 Mdot
.906 .17549 Mdot
.906 .17553 Mdot
.906 .17642 Mdot
.906 .1789 Mdot
.906 .17901 Mdot
.906 .18013 Mdot
.906 .18019 Mdot
.906 .18024 Mdot
.906 .18039 Mdot
.906 .18109 Mdot
.906 .1812 Mdot
.906 .18232 Mdot
.906 .18286 Mdot
.906 .18441 Mdot
.906 .1846 Mdot
.906 .18563 Mdot
.906 .18669 Mdot
.906 .18794 Mdot
.906 .18812 Mdot
.906 .18862 Mdot
.906 .19025 Mdot
.906 .19242 Mdot
.906 .1958 Mdot
.906 .19638 Mdot
.906 .19814 Mdot
.906 .2006 Mdot
.906 .20154 Mdot
.906 .20202 Mdot
.906 .20216 Mdot
.906 .2032 Mdot
.906 .20341 Mdot
.906 .20485 Mdot
.906 .20504 Mdot
.906 .20644 Mdot
.906 .20665 Mdot
.906 .20771 Mdot
.906 .20845 Mdot
.906 .20952 Mdot
.906 .21052 Mdot
.906 .21471 Mdot
.906 .21688 Mdot
.906 .21732 Mdot
.906 .21793 Mdot
.906 .21991 Mdot
.906 .22177 Mdot
.906 .22357 Mdot
.906 .22374 Mdot
.906 .22723 Mdot
.906 .22738 Mdot
.906 .22897 Mdot
.906 .22922 Mdot
.906 .22932 Mdot
.906 .2308 Mdot
.906 .23187 Mdot
.906 .2326 Mdot
.906 .23272 Mdot
.906 .23309 Mdot
.906 .23328 Mdot
.906 .23334 Mdot
.906 .23382 Mdot
.906 .23433 Mdot
.906 .23487 Mdot
.906 .23536 Mdot
.906 .23642 Mdot
.906 .23703 Mdot
.906 .23744 Mdot
.906 .23838 Mdot
.906 .2385 Mdot
.906 .23897 Mdot
.906 .23983 Mdot
.906 .24108 Mdot
.906 .24181 Mdot
.906 .24264 Mdot
.906 .24372 Mdot
.906 .24461 Mdot
.906 .24481 Mdot
.906 .24515 Mdot
.906 .24729 Mdot
.906 .2474 Mdot
.906 .24784 Mdot
.906 .24897 Mdot
.906 .24951 Mdot
.906 .25026 Mdot
.906 .25133 Mdot
.906 .25192 Mdot
.906 .25215 Mdot
.906 .25217 Mdot
.906 .25303 Mdot
.906 .25375 Mdot
.906 .25388 Mdot
.906 .25429 Mdot
.906 .25452 Mdot
.906 .2557 Mdot
.906 .25618 Mdot
.906 .25769 Mdot
.906 .25791 Mdot
.906 .25855 Mdot
.906 .25943 Mdot
.906 .2595 Mdot
.906 .25952 Mdot
.906 .25975 Mdot
.906 .25989 Mdot
.906 .26011 Mdot
.906 .26046 Mdot
.906 .26087 Mdot
.906 .26148 Mdot
.906 .26153 Mdot
.906 .26157 Mdot
.906 .26179 Mdot
.906 .26192 Mdot
.906 .26214 Mdot
.906 .26226 Mdot
.906 .26275 Mdot
.906 .26308 Mdot
.906 .2635 Mdot
.906 .26382 Mdot
.906 .264 Mdot
.906 .26407 Mdot
.906 .26416 Mdot
.906 .26437 Mdot
.906 .2644 Mdot
.906 .26576 Mdot
.906 .2658 Mdot
.906 .26591 Mdot
.906 .26626 Mdot
.906 .26673 Mdot
.906 .26689 Mdot
.906 .2672 Mdot
.906 .26737 Mdot
.906 .26763 Mdot
.906 .26764 Mdot
.906 .26766 Mdot
.906 .26778 Mdot
.906 .2678 Mdot
.906 .26809 Mdot
.906 .26823 Mdot
.906 .2686 Mdot
.906 .26864 Mdot
.906 .26882 Mdot
.906 .26952 Mdot
.906 .26954 Mdot
.906 .26967 Mdot
.906 .26968 Mdot
.906 .26982 Mdot
.906 .26984 Mdot
.906 .26993 Mdot
.906 .26995 Mdot
.906 .26999 Mdot
.906 .27008 Mdot
.906 .27032 Mdot
.906 .27049 Mdot
.906 .27054 Mdot
.906 .27111 Mdot
.906 .27129 Mdot
.906 .27134 Mdot
.906 .27136 Mdot
.906 .27161 Mdot
.906 .27175 Mdot
.906 .27193 Mdot
.906 .27199 Mdot
.906 .27214 Mdot
.906 .27222 Mdot
.906 .27224 Mdot
.906 .27224 Mdot
.906 .27225 Mdot
.906 .27239 Mdot
.906 .2724 Mdot
.906 .27271 Mdot
.906 .27283 Mdot
.906 .27292 Mdot
.906 .27294 Mdot
.906 .27294 Mdot
.906 .27296 Mdot
.906 .27308 Mdot
.906 .27333 Mdot
.906 .27342 Mdot
.906 .27342 Mdot
.906 .2735 Mdot
.906 .27354 Mdot
.906 .27361 Mdot
.906 .27399 Mdot
.906 .2742 Mdot
.906 .27433 Mdot
.906 .27485 Mdot
.906 .27493 Mdot
.906 .27495 Mdot
.906 .27499 Mdot
.906 .27506 Mdot
.906 .27511 Mdot
.906 .27554 Mdot
.906 .27575 Mdot
.906 .27583 Mdot
.906 .27584 Mdot
.906 .27589 Mdot
.906 .2759 Mdot
.906 .27598 Mdot
.906 .27598 Mdot
.906 .27604 Mdot
.906 .27606 Mdot
.906 .27609 Mdot
.906 .27618 Mdot
.906 .27635 Mdot
.906 .27641 Mdot
.906 .27644 Mdot
.906 .27645 Mdot
.906 .27645 Mdot
.906 .27645 Mdot
.906 .27645 Mdot
.906 .27646 Mdot
.906 .27646 Mdot
.906 .27647 Mdot
.906 .27647 Mdot
.906 .27651 Mdot
.906 .27653 Mdot
.906 .27653 Mdot
.906 .27653 Mdot
.906 .27654 Mdot
.906 .27656 Mdot
.906 .27656 Mdot
.906 .27658 Mdot
.906 .27658 Mdot
.906 .27659 Mdot
.906 .27665 Mdot
.906 .27671 Mdot
.906 .27673 Mdot
.906 .27676 Mdot
.906 .27677 Mdot
.906 .27678 Mdot
.906 .2768 Mdot
.906 .27681 Mdot
.906 .27687 Mdot
.906 .2769 Mdot
.906 .27692 Mdot
.906 .27692 Mdot
.906 .27696 Mdot
.906 .27697 Mdot
.906 .27698 Mdot
.906 .277 Mdot
.906 .277 Mdot
.906 .277 Mdot
.906 .277 Mdot
.906 .277 Mdot
.906 .27701 Mdot
.906 .27701 Mdot
.906 .27701 Mdot
.906 .27701 Mdot
.906 .27701 Mdot
.906 .27701 Mdot
.906 .27701 Mdot
.906 .27701 Mdot
.906 .27758 Mdot
.906 .2779 Mdot
.906 .27802 Mdot
.906 .27809 Mdot
.906 .27847 Mdot
.906 .28023 Mdot
.906 .28082 Mdot
.906 .28091 Mdot
.906 .28169 Mdot
.906 .28216 Mdot
.906 .28527 Mdot
.906 .28591 Mdot
.906 .29084 Mdot
.906 .29104 Mdot
.906 .29512 Mdot
.906 .29881 Mdot
.906 .30121 Mdot
.906 .30132 Mdot
.906 .30165 Mdot
.906 .30279 Mdot
.906 .30513 Mdot
.906 .30533 Mdot
.906 .30587 Mdot
.906 .30685 Mdot
.906 .30731 Mdot
.906 .30951 Mdot
.906 .30989 Mdot
.906 .31049 Mdot
.906 .31059 Mdot
.906 .31074 Mdot
.906 .31075 Mdot
.906 .31076 Mdot
.906 .31082 Mdot
.906 .31085 Mdot
.906 .31091 Mdot
.906 .31094 Mdot
.906 .31106 Mdot
.906 .31115 Mdot
.906 .31126 Mdot
.906 .31135 Mdot
.906 .3114 Mdot
.906 .31144 Mdot
.906 .31189 Mdot
.906 .31217 Mdot
.906 .31237 Mdot
.906 .31246 Mdot
.906 .31276 Mdot
.906 .31323 Mdot
.906 .31366 Mdot
.906 .31412 Mdot
.906 .3142 Mdot
.906 .31439 Mdot
.906 .31463 Mdot
.906 .31497 Mdot
.906 .31681 Mdot
.906 .31681 Mdot
.906 .31682 Mdot
.906 .31682 Mdot
.906 .31682 Mdot
.906 .31683 Mdot
.906 .31684 Mdot
.906 .31684 Mdot
.906 .3169 Mdot
.906 .31692 Mdot
.906 .31692 Mdot
.906 .31698 Mdot
.906 .31699 Mdot
.906 .31708 Mdot
.906 .31721 Mdot
.906 .31729 Mdot
.906 .31737 Mdot
.906 .31778 Mdot
.906 .31784 Mdot
.906 .31803 Mdot
.906 .31815 Mdot
.906 .31842 Mdot
.906 .31872 Mdot
.906 .31901 Mdot
.906 .31909 Mdot
.906 .3194 Mdot
.906 .31943 Mdot
.906 .31958 Mdot
.906 .31993 Mdot
.906 .31995 Mdot
.906 .32001 Mdot
.906 .32008 Mdot
.906 .32009 Mdot
.906 .32075 Mdot
.906 .32081 Mdot
.906 .3211 Mdot
.906 .32146 Mdot
.906 .32151 Mdot
.906 .32154 Mdot
.906 .32176 Mdot
.906 .32176 Mdot
.906 .32176 Mdot
.906 .32198 Mdot
.906 .32204 Mdot
.906 .32204 Mdot
.906 .32204 Mdot
.906 .32214 Mdot
.906 .32223 Mdot
.906 .32267 Mdot
.906 .32272 Mdot
.906 .3228 Mdot
.906 .32283 Mdot
.906 .32285 Mdot
.906 .32288 Mdot
.906 .32288 Mdot
.906 .32293 Mdot
.906 .32293 Mdot
.906 .32297 Mdot
.906 .32324 Mdot
.906 .32335 Mdot
.906 .32348 Mdot
.906 .32352 Mdot
.906 .32364 Mdot
.906 .32372 Mdot
.906 .32396 Mdot
.906 .32433 Mdot
.906 .32433 Mdot
.906 .3244 Mdot
.906 .32528 Mdot
.906 .32535 Mdot
.906 .32569 Mdot
.906 .32624 Mdot
.906 .32662 Mdot
.906 .32666 Mdot
.906 .32675 Mdot
.906 .32692 Mdot
.906 .32711 Mdot
.906 .32735 Mdot
.906 .3277 Mdot
.906 .32773 Mdot
.906 .3281 Mdot
.906 .32835 Mdot
.906 .32853 Mdot
.906 .32865 Mdot
.906 .32877 Mdot
.906 .32913 Mdot
.906 .32914 Mdot
.906 .32916 Mdot
.906 .3293 Mdot
.906 .32942 Mdot
.906 .32984 Mdot
.906 .32996 Mdot
.906 .33034 Mdot
.906 .33101 Mdot
.906 .33158 Mdot
.906 .33183 Mdot
.906 .33237 Mdot
.906 .33251 Mdot
.906 .33282 Mdot
.906 .33332 Mdot
.906 .33349 Mdot
.906 .3335 Mdot
.906 .33355 Mdot
.906 .33362 Mdot
.906 .33486 Mdot
.906 .33498 Mdot
.906 .33534 Mdot
.906 .33538 Mdot
.906 .33546 Mdot
.906 .33567 Mdot
.906 .33588 Mdot
.906 .33621 Mdot
.906 .33646 Mdot
.906 .33648 Mdot
.906 .33658 Mdot
.906 .3367 Mdot
.906 .33678 Mdot
.906 .33701 Mdot
.906 .33711 Mdot
.906 .33737 Mdot
.906 .3381 Mdot
.906 .33813 Mdot
.906 .33818 Mdot
.906 .33821 Mdot
.906 .33866 Mdot
.906 .33873 Mdot
.906 .33873 Mdot
.906 .33885 Mdot
.906 .33895 Mdot
.906 .33943 Mdot
.906 .33949 Mdot
.906 .33968 Mdot
.906 .33998 Mdot
.906 .34007 Mdot
.906 .34012 Mdot
.906 .34029 Mdot
.906 .34044 Mdot
.906 .34049 Mdot
.906 .34049 Mdot
.906 .34057 Mdot
.906 .3406 Mdot
.906 .34061 Mdot
.906 .34063 Mdot
.906 .34068 Mdot
.906 .34069 Mdot
.906 .34076 Mdot
.906 .3419 Mdot
.906 .34234 Mdot
.906 .3429 Mdot
.906 .34509 Mdot
.906 .35515 Mdot
.906 .35575 Mdot
.906 .36134 Mdot
.906 .36192 Mdot
.906 .36293 Mdot
.906 .36332 Mdot
.906 .3694 Mdot
.906 .37398 Mdot
.906 .37714 Mdot
.906 .37767 Mdot
.906 .37929 Mdot
.906 .38015 Mdot
.906 .38043 Mdot
.906 .38255 Mdot
.906 .38399 Mdot
.906 .38488 Mdot
.906 .38736 Mdot
.906 .38959 Mdot
.906 .39454 Mdot
.906 .39744 Mdot
.906 .39937 Mdot
.906 .40277 Mdot
.906 .4032 Mdot
.906 .40388 Mdot
.906 .40447 Mdot
.906 .40675 Mdot
.906 .41094 Mdot
.906 .41703 Mdot
.906 .42062 Mdot
.906 .42071 Mdot
.906 .42472 Mdot
.906 .43003 Mdot
.906 .43445 Mdot
.906 .43543 Mdot
.906 .43712 Mdot
.906 .44763 Mdot
.906 .44815 Mdot
.906 .45028 Mdot
.906 .45069 Mdot
.906 .45576 Mdot
.906 .45835 Mdot
.906 .46193 Mdot
.906 .46694 Mdot
.906 .46796 Mdot
.906 .4697 Mdot
.906 .47056 Mdot
.906 .47077 Mdot
.906 .47086 Mdot
.906 .47477 Mdot
.906 .47803 Mdot
.906 .47861 Mdot
.906 .48042 Mdot
.906 .48084 Mdot
.906 .48144 Mdot
.906 .48343 Mdot
.906 .48634 Mdot
.906 .48654 Mdot
.906 .48821 Mdot
.906 .48858 Mdot
.906 .49484 Mdot
.906 .49573 Mdot
.906 .49827 Mdot
.906 .50169 Mdot
.906 .5019 Mdot
.906 .50197 Mdot
.906 .50205 Mdot
.906 .50292 Mdot
.906 .50343 Mdot
.906 .50427 Mdot
.906 .50558 Mdot
.906 .50707 Mdot
.906 .50906 Mdot
.906 .50926 Mdot
.906 .50945 Mdot
.906 .50957 Mdot
.906 .51038 Mdot
.906 .51083 Mdot
.906 .51157 Mdot
.906 .51198 Mdot
.906 .51366 Mdot
.906 .51476 Mdot
.906 .51615 Mdot
.906 .51719 Mdot
.906 .51776 Mdot
.906 .51797 Mdot
.906 .5181 Mdot
.906 .5181 Mdot
.906 .5181 Mdot
.906 .5181 Mdot
.906 .5181 Mdot
.906 .5181 Mdot
.906 .5181 Mdot
.906 .5181 Mdot
.906 .5181 Mdot
.906 .5181 Mdot
.906 .5181 Mdot
.906 .5181 Mdot
.906 .5181 Mdot
.906 .51811 Mdot
.906 .51811 Mdot
.906 .51811 Mdot
.906 .51812 Mdot
.906 .51812 Mdot
.906 .51813 Mdot
.906 .51813 Mdot
.906 .51815 Mdot
.906 .51815 Mdot
.906 .51816 Mdot
.906 .51816 Mdot
.906 .51817 Mdot
.906 .51817 Mdot
.906 .51819 Mdot
.906 .5182 Mdot
.906 .5182 Mdot
.906 .5182 Mdot
.906 .51821 Mdot
.906 .51821 Mdot
.906 .51821 Mdot
.906 .51821 Mdot
.906 .51821 Mdot
.906 .51821 Mdot
.906 .51822 Mdot
.906 .51823 Mdot
.906 .51823 Mdot
.906 .51823 Mdot
.906 .51823 Mdot
.906 .51823 Mdot
.906 .51823 Mdot
.906 .51823 Mdot
.906 .51823 Mdot
.906 .51824 Mdot
.906 .51825 Mdot
.906 .51829 Mdot
.906 .51831 Mdot
.906 .51832 Mdot
.906 .51832 Mdot
.906 .51834 Mdot
.906 .51834 Mdot
.906 .51836 Mdot
.906 .51836 Mdot
.906 .51837 Mdot
.906 .51837 Mdot
.906 .51839 Mdot
.906 .51844 Mdot
.906 .51854 Mdot
.906 .51855 Mdot
.906 .51857 Mdot
.906 .51858 Mdot
.906 .51858 Mdot
.906 .5186 Mdot
.906 .51872 Mdot
.906 .51875 Mdot
.906 .51879 Mdot
.906 .51888 Mdot
.906 .5189 Mdot
.906 .51891 Mdot
.906 .51892 Mdot
.906 .51892 Mdot
.906 .51894 Mdot
.906 .519 Mdot
.906 .51903 Mdot
.906 .51903 Mdot
.906 .51903 Mdot
.906 .51904 Mdot
.906 .51906 Mdot
.906 .51908 Mdot
.906 .51915 Mdot
.906 .51916 Mdot
.906 .51919 Mdot
.906 .51919 Mdot
.906 .51919 Mdot
.906 .51919 Mdot
.906 .51921 Mdot
.906 .51925 Mdot
.906 .51926 Mdot
.906 .5193 Mdot
.906 .51933 Mdot
.906 .51939 Mdot
.906 .51939 Mdot
.906 .5194 Mdot
.906 .51944 Mdot
.906 .51957 Mdot
.906 .51958 Mdot
.906 .51962 Mdot
.906 .51967 Mdot
.906 .51969 Mdot
.906 .5197 Mdot
.906 .51971 Mdot
.906 .51973 Mdot
.906 .51973 Mdot
.906 .51976 Mdot
.906 .51977 Mdot
.906 .51979 Mdot
.906 .5198 Mdot
.906 .51995 Mdot
.906 .52 Mdot
.906 .52 Mdot
.906 .52008 Mdot
.906 .52012 Mdot
.906 .52018 Mdot
.906 .52018 Mdot
.906 .52021 Mdot
.906 .52022 Mdot
.906 .52022 Mdot
.906 .52028 Mdot
.906 .52031 Mdot
.906 .52038 Mdot
.906 .52042 Mdot
.906 .52052 Mdot
.906 .5206 Mdot
.906 .52062 Mdot
.906 .52063 Mdot
.906 .52093 Mdot
.906 .52093 Mdot
.906 .52098 Mdot
.906 .521 Mdot
.906 .52101 Mdot
.906 .52105 Mdot
.906 .52112 Mdot
.906 .52121 Mdot
.906 .52129 Mdot
.906 .52139 Mdot
.906 .52142 Mdot
.906 .52146 Mdot
.906 .52149 Mdot
.906 .52154 Mdot
.906 .52155 Mdot
.906 .52156 Mdot
.906 .52169 Mdot
.906 .52178 Mdot
.906 .52186 Mdot
.906 .5219 Mdot
.906 .52193 Mdot
.906 .52198 Mdot
.906 .52199 Mdot
.906 .522 Mdot
.906 .52219 Mdot
.906 .52233 Mdot
.906 .52237 Mdot
.906 .52269 Mdot
.906 .5228 Mdot
.906 .52304 Mdot
.906 .52309 Mdot
.906 .52318 Mdot
.906 .52321 Mdot
.906 .52336 Mdot
.906 .52354 Mdot
.906 .52354 Mdot
.906 .52359 Mdot
.906 .52372 Mdot
.906 .52394 Mdot
.906 .5241 Mdot
.906 .52421 Mdot
.906 .52444 Mdot
.906 .52454 Mdot
.906 .52456 Mdot
.906 .525 Mdot
.906 .52507 Mdot
.906 .52511 Mdot
.906 .5253 Mdot
.906 .52552 Mdot
.906 .52569 Mdot
.906 .52584 Mdot
.906 .52609 Mdot
.906 .52627 Mdot
.906 .52637 Mdot
.906 .52639 Mdot
.906 .52658 Mdot
.906 .52667 Mdot
.906 .52679 Mdot
.906 .52701 Mdot
.906 .52711 Mdot
.906 .52722 Mdot
.906 .52732 Mdot
.906 .52742 Mdot
.906 .52743 Mdot
.906 .52747 Mdot
.906 .52755 Mdot
.906 .52757 Mdot
.906 .52772 Mdot
.906 .52794 Mdot
.906 .52824 Mdot
.906 .52825 Mdot
.906 .52831 Mdot
.906 .52863 Mdot
.906 .52866 Mdot
.906 .52937 Mdot
.906 .5294 Mdot
.906 .52976 Mdot
.906 .53014 Mdot
.906 .53054 Mdot
.906 .53066 Mdot
.906 .53075 Mdot
.906 .53119 Mdot
.906 .53204 Mdot
.906 .53225 Mdot
.906 .53247 Mdot
.906 .53262 Mdot
.906 .53283 Mdot
.906 .53287 Mdot
.906 .53316 Mdot
.906 .5332 Mdot
.906 .53349 Mdot
.906 .53354 Mdot
.906 .53375 Mdot
.906 .53378 Mdot
.906 .53388 Mdot
.906 .53407 Mdot
.906 .53458 Mdot
.906 .53495 Mdot
.906 .53507 Mdot
.906 .53577 Mdot
.906 .53623 Mdot
.906 .53657 Mdot
.906 .53668 Mdot
.906 .53672 Mdot
.906 .53698 Mdot
.906 .53721 Mdot
.906 .53743 Mdot
.906 .53747 Mdot
.906 .5378 Mdot
.906 .53792 Mdot
.906 .53816 Mdot
.906 .53819 Mdot
.906 .53834 Mdot
.906 .53837 Mdot
.906 .53838 Mdot
.906 .53839 Mdot
.906 .53864 Mdot
.906 .53866 Mdot
.906 .53921 Mdot
.906 .5394 Mdot
.906 .53941 Mdot
.906 .53957 Mdot
.906 .53959 Mdot
.906 .53959 Mdot
.906 .53963 Mdot
.906 .53984 Mdot
.906 .53987 Mdot
.906 .54025 Mdot
.906 .54035 Mdot
.906 .54039 Mdot
.906 .54039 Mdot
.906 .54051 Mdot
.906 .54058 Mdot
.906 .54069 Mdot
.906 .54126 Mdot
.906 .54128 Mdot
.906 .54158 Mdot
.906 .54177 Mdot
.906 .5425 Mdot
.906 .54253 Mdot
.906 .54262 Mdot
.906 .54264 Mdot
.906 .54269 Mdot
.906 .54279 Mdot
.906 .54285 Mdot
.906 .54341 Mdot
.906 .54366 Mdot
.906 .54376 Mdot
.906 .54377 Mdot
.906 .54383 Mdot
.906 .54384 Mdot
.906 .54394 Mdot
.906 .54394 Mdot
.906 .54401 Mdot
.906 .54403 Mdot
.906 .54406 Mdot
.906 .54417 Mdot
.906 .54431 Mdot
.906 .54436 Mdot
.906 .54442 Mdot
.906 .54446 Mdot
.906 .54446 Mdot
.906 .54446 Mdot
.906 .54447 Mdot
.906 .54447 Mdot
.906 .54447 Mdot
.906 .54448 Mdot
.906 .54448 Mdot
.906 .54449 Mdot
.906 .54453 Mdot
.906 .54455 Mdot
.906 .54455 Mdot
.906 .54455 Mdot
.906 .54456 Mdot
.906 .54458 Mdot
.906 .54458 Mdot
.906 .54458 Mdot
.906 .5446 Mdot
.906 .54461 Mdot
.906 .54461 Mdot
.906 .54468 Mdot
.906 .54475 Mdot
.906 .54475 Mdot
.906 .54476 Mdot
.906 .54479 Mdot
.906 .54481 Mdot
.906 .54481 Mdot
.906 .54484 Mdot
.906 .54485 Mdot
.906 .5449 Mdot
.906 .54494 Mdot
.906 .54496 Mdot
.906 .54496 Mdot
.906 .545 Mdot
.906 .54501 Mdot
.906 .54502 Mdot
.906 .54504 Mdot
.906 .54504 Mdot
.906 .54504 Mdot
.906 .54504 Mdot
.906 .54504 Mdot
.906 .54505 Mdot
.906 .54505 Mdot
.906 .54505 Mdot
.906 .54505 Mdot
.906 .54505 Mdot
.906 .54505 Mdot
.906 .54505 Mdot
.906 .54505 Mdot
.906 .54559 Mdot
.906 .54585 Mdot
.906 .54587 Mdot
.906 .54597 Mdot
.906 .54602 Mdot
.906 .54629 Mdot
.906 .54632 Mdot
.906 .5465 Mdot
.906 .54706 Mdot
.906 .54741 Mdot
.906 .54767 Mdot
.906 .5477 Mdot
.906 .54776 Mdot
.906 .5478 Mdot
.906 .54794 Mdot
.906 .54794 Mdot
.906 .54795 Mdot
.906 .54803 Mdot
.906 .54805 Mdot
.908 .17183 Mdot
.908 .27268 Mdot
.908 .34098 Mdot
.908 .51922 Mdot
.908 .54031 Mdot
.91 .13299 Mdot
.91 .13299 Mdot
.91 .13299 Mdot
.91 .13323 Mdot
.91 .13337 Mdot
.91 .13351 Mdot
.91 .13353 Mdot
.91 .13358 Mdot
.91 .13478 Mdot
.91 .13645 Mdot
.91 .13651 Mdot
.91 .13707 Mdot
.91 .13773 Mdot
.91 .13778 Mdot
.91 .13822 Mdot
.91 .14133 Mdot
.91 .14224 Mdot
.91 .14495 Mdot
.91 .1458 Mdot
.91 .14654 Mdot
.91 .14671 Mdot
.91 .14913 Mdot
.91 .14968 Mdot
.91 .15018 Mdot
.91 .15135 Mdot
.91 .1525 Mdot
.91 .15436 Mdot
.91 .15448 Mdot
.91 .15478 Mdot
.91 .15488 Mdot
.91 .16342 Mdot
.91 .17441 Mdot
.91 .1747 Mdot
.91 .1794 Mdot
.91 .18125 Mdot
.91 .18909 Mdot
.91 .18948 Mdot
.91 .19034 Mdot
.91 .19363 Mdot
.91 .19427 Mdot
.91 .19482 Mdot
.91 .19724 Mdot
.91 .19746 Mdot
.91 .19836 Mdot
.91 .19844 Mdot
.91 .20238 Mdot
.91 .20578 Mdot
.91 .2092 Mdot
.91 .21099 Mdot
.91 .211 Mdot
.91 .21101 Mdot
.91 .21101 Mdot
.91 .21109 Mdot
.91 .2111 Mdot
.91 .21113 Mdot
.91 .21117 Mdot
.91 .21117 Mdot
.91 .21118 Mdot
.91 .21124 Mdot
.91 .21142 Mdot
.91 .2116 Mdot
.91 .21197 Mdot
.91 .212 Mdot
.91 .21209 Mdot
.91 .2121 Mdot
.91 .21215 Mdot
.91 .21221 Mdot
.91 .21263 Mdot
.91 .21265 Mdot
.91 .21269 Mdot
.91 .21279 Mdot
.91 .21304 Mdot
.91 .21312 Mdot
.91 .21313 Mdot
.91 .21338 Mdot
.91 .21348 Mdot
.91 .21351 Mdot
.91 .2138 Mdot
.91 .21395 Mdot
.91 .21438 Mdot
.91 .21461 Mdot
.91 .21489 Mdot
.91 .21511 Mdot
.91 .21515 Mdot
.91 .21532 Mdot
.91 .21538 Mdot
.91 .21568 Mdot
.91 .21627 Mdot
.91 .21641 Mdot
.91 .21679 Mdot
.91 .2168 Mdot
.91 .21683 Mdot
.91 .21717 Mdot
.91 .21736 Mdot
.91 .2176 Mdot
.91 .21778 Mdot
.91 .21779 Mdot
.91 .21797 Mdot
.91 .2192 Mdot
.91 .22033 Mdot
.91 .22073 Mdot
.91 .22093 Mdot
.91 .22097 Mdot
.91 .22182 Mdot
.91 .22317 Mdot
.91 .22381 Mdot
.91 .22416 Mdot
.91 .22443 Mdot
.91 .22453 Mdot
.91 .22461 Mdot
.91 .2249 Mdot
.91 .22496 Mdot
.91 .22498 Mdot
.91 .22511 Mdot
.91 .22511 Mdot
.91 .22605 Mdot
.91 .2262 Mdot
.91 .22634 Mdot
.91 .22686 Mdot
.91 .227 Mdot
.91 .22714 Mdot
.91 .22744 Mdot
.91 .22749 Mdot
.91 .22759 Mdot
.91 .22783 Mdot
.91 .22942 Mdot
.91 .22944 Mdot
.91 .22956 Mdot
.91 .22963 Mdot
.91 .22973 Mdot
.91 .23073 Mdot
.91 .23147 Mdot
.91 .23153 Mdot
.91 .2318 Mdot
.91 .23271 Mdot
.91 .23347 Mdot
.91 .23365 Mdot
.91 .23384 Mdot
.91 .23446 Mdot
.91 .23446 Mdot
.91 .23472 Mdot
.91 .23481 Mdot
.91 .23527 Mdot
.91 .23707 Mdot
.91 .2371 Mdot
.91 .2378 Mdot
.91 .23792 Mdot
.91 .24004 Mdot
.91 .24138 Mdot
.91 .24157 Mdot
.91 .24165 Mdot
.91 .24194 Mdot
.91 .24196 Mdot
.91 .24196 Mdot
.91 .24234 Mdot
.91 .24266 Mdot
.91 .24273 Mdot
.91 .24311 Mdot
.91 .24359 Mdot
.91 .24381 Mdot
.91 .24384 Mdot
.91 .24393 Mdot
.91 .24424 Mdot
.91 .24434 Mdot
.91 .24435 Mdot
.91 .2445 Mdot
.91 .24457 Mdot
.91 .2448 Mdot
.91 .24538 Mdot
.91 .24584 Mdot
.91 .24663 Mdot
.91 .24685 Mdot
.91 .2476 Mdot
.91 .2478 Mdot
.91 .24817 Mdot
.91 .24822 Mdot
.91 .24827 Mdot
.91 .24869 Mdot
.91 .24903 Mdot
.91 .2492 Mdot
.91 .24953 Mdot
.91 .25014 Mdot
.91 .25028 Mdot
.91 .25059 Mdot
.91 .25066 Mdot
.91 .25092 Mdot
.91 .25096 Mdot
.91 .25101 Mdot
.91 .25105 Mdot
.91 .25135 Mdot
.91 .25213 Mdot
.91 .25253 Mdot
.91 .25298 Mdot
.91 .25325 Mdot
.91 .25398 Mdot
.91 .25453 Mdot
.91 .25461 Mdot
.91 .25478 Mdot
.91 .25545 Mdot
.91 .25643 Mdot
.91 .25714 Mdot
.91 .25715 Mdot
.91 .25726 Mdot
.91 .25738 Mdot
.91 .25742 Mdot
.91 .25744 Mdot
.91 .25746 Mdot
.91 .25758 Mdot
.91 .25788 Mdot
.91 .25795 Mdot
.91 .25802 Mdot
.91 .2581 Mdot
.91 .25817 Mdot
.91 .25861 Mdot
.91 .2589 Mdot
.91 .2589 Mdot
.91 .25932 Mdot
.91 .2595 Mdot
.91 .26001 Mdot
.91 .26004 Mdot
.91 .26004 Mdot
.91 .26028 Mdot
.91 .26038 Mdot
.91 .26047 Mdot
.91 .26051 Mdot
.91 .26091 Mdot
.91 .26106 Mdot
.91 .26139 Mdot
.91 .2615 Mdot
.91 .26151 Mdot
.91 .26152 Mdot
.91 .26173 Mdot
.91 .26178 Mdot
.91 .26196 Mdot
.91 .26257 Mdot
.91 .2626 Mdot
.91 .26271 Mdot
.91 .26273 Mdot
.91 .26276 Mdot
.91 .26294 Mdot
.91 .26303 Mdot
.91 .26338 Mdot
.91 .26353 Mdot
.91 .26356 Mdot
.91 .2636 Mdot
.91 .26398 Mdot
.91 .26412 Mdot
.91 .26425 Mdot
.91 .26458 Mdot
.91 .26461 Mdot
.91 .26483 Mdot
.91 .26486 Mdot
.91 .26504 Mdot
.91 .2651 Mdot
.91 .2653 Mdot
.91 .26531 Mdot
.91 .26577 Mdot
.91 .26578 Mdot
.91 .26582 Mdot
.91 .26589 Mdot
.91 .26598 Mdot
.91 .26623 Mdot
.91 .26629 Mdot
.91 .26648 Mdot
.91 .2666 Mdot
.91 .26667 Mdot
.91 .26669 Mdot
.91 .26682 Mdot
.91 .26683 Mdot
.91 .26684 Mdot
.91 .26684 Mdot
.91 .26685 Mdot
.91 .26696 Mdot
.91 .26698 Mdot
.91 .26699 Mdot
.91 .26701 Mdot
.91 .26703 Mdot
.91 .26704 Mdot
.91 .26707 Mdot
.91 .26708 Mdot
.91 .2671 Mdot
.91 .26717 Mdot
.91 .26718 Mdot
.91 .2672 Mdot
.91 .26721 Mdot
.91 .26731 Mdot
.91 .26742 Mdot
.91 .26748 Mdot
.91 .2675 Mdot
.91 .26753 Mdot
.91 .26762 Mdot
.91 .26771 Mdot
.91 .26773 Mdot
.91 .26773 Mdot
.91 .26774 Mdot
.91 .26776 Mdot
.91 .26778 Mdot
.91 .2678 Mdot
.91 .2678 Mdot
.91 .26781 Mdot
.91 .26785 Mdot
.91 .26792 Mdot
.91 .26792 Mdot
.91 .26794 Mdot
.91 .26796 Mdot
.91 .26798 Mdot
.91 .268 Mdot
.91 .26804 Mdot
.91 .26806 Mdot
.91 .26807 Mdot
.91 .26808 Mdot
.91 .26809 Mdot
.91 .2681 Mdot
.91 .2681 Mdot
.91 .26812 Mdot
.91 .26813 Mdot
.91 .26814 Mdot
.91 .26817 Mdot
.91 .26817 Mdot
.91 .26818 Mdot
.91 .26818 Mdot
.91 .26819 Mdot
.91 .26819 Mdot
.91 .26822 Mdot
.91 .26823 Mdot
.91 .26825 Mdot
.91 .26825 Mdot
.91 .26825 Mdot
.91 .26825 Mdot
.91 .26826 Mdot
.91 .26826 Mdot
.91 .26826 Mdot
.91 .26827 Mdot
.91 .26827 Mdot
.91 .26827 Mdot
.91 .26827 Mdot
.91 .27008 Mdot
.91 .27565 Mdot
.91 .27619 Mdot
.91 .27663 Mdot
.91 .27879 Mdot
.91 .28066 Mdot
.91 .28365 Mdot
.91 .28451 Mdot
.91 .28502 Mdot
.91 .28752 Mdot
.91 .28783 Mdot
.91 .2882 Mdot
.91 .28972 Mdot
.91 .29005 Mdot
.91 .29542 Mdot
.91 .29832 Mdot
.91 .29863 Mdot
.91 .30062 Mdot
.91 .30122 Mdot
.91 .30136 Mdot
.91 .30199 Mdot
.91 .30398 Mdot
.91 .30406 Mdot
.91 .30418 Mdot
.91 .30557 Mdot
.91 .30959 Mdot
.91 .31031 Mdot
.91 .31138 Mdot
.91 .31208 Mdot
.91 .31208 Mdot
.91 .31211 Mdot
.91 .31215 Mdot
.91 .31216 Mdot
.91 .31217 Mdot
.91 .31234 Mdot
.91 .3126 Mdot
.91 .31273 Mdot
.91 .31296 Mdot
.91 .31326 Mdot
.91 .31363 Mdot
.91 .31386 Mdot
.91 .31387 Mdot
.91 .31393 Mdot
.91 .31427 Mdot
.91 .31457 Mdot
.91 .31474 Mdot
.91 .31588 Mdot
.91 .31604 Mdot
.91 .31604 Mdot
.91 .31605 Mdot
.91 .31605 Mdot
.91 .31615 Mdot
.91 .31616 Mdot
.91 .31619 Mdot
.91 .3162 Mdot
.91 .31623 Mdot
.91 .31624 Mdot
.91 .31625 Mdot
.91 .31631 Mdot
.91 .31632 Mdot
.91 .31654 Mdot
.91 .31661 Mdot
.91 .31675 Mdot
.91 .31686 Mdot
.91 .3169 Mdot
.91 .31714 Mdot
.91 .31723 Mdot
.91 .31726 Mdot
.91 .31734 Mdot
.91 .31739 Mdot
.91 .31739 Mdot
.91 .31745 Mdot
.91 .31747 Mdot
.91 .31754 Mdot
.91 .31803 Mdot
.91 .31812 Mdot
.91 .31813 Mdot
.91 .31815 Mdot
.91 .3182 Mdot
.91 .31835 Mdot
.91 .3184 Mdot
.91 .31844 Mdot
.91 .31871 Mdot
.91 .31873 Mdot
.91 .31884 Mdot
.91 .31886 Mdot
.91 .31923 Mdot
.91 .31938 Mdot
.91 .31943 Mdot
.91 .31989 Mdot
.91 .32014 Mdot
.91 .32015 Mdot
.91 .32037 Mdot
.91 .32038 Mdot
.91 .32067 Mdot
.91 .32086 Mdot
.91 .3209 Mdot
.91 .32092 Mdot
.91 .32092 Mdot
.91 .32116 Mdot
.91 .32126 Mdot
.91 .32175 Mdot
.91 .32199 Mdot
.91 .32215 Mdot
.91 .32223 Mdot
.91 .32254 Mdot
.91 .32263 Mdot
.91 .32267 Mdot
.91 .32307 Mdot
.91 .32323 Mdot
.91 .32358 Mdot
.91 .32442 Mdot
.91 .3247 Mdot
.91 .32485 Mdot
.91 .32516 Mdot
.91 .32542 Mdot
.91 .32548 Mdot
.91 .32552 Mdot
.91 .32558 Mdot
.91 .32577 Mdot
.91 .32607 Mdot
.91 .32614 Mdot
.91 .32631 Mdot
.91 .32637 Mdot
.91 .32673 Mdot
.91 .32674 Mdot
.91 .32729 Mdot
.91 .32739 Mdot
.91 .32763 Mdot
.91 .32769 Mdot
.91 .32771 Mdot
.91 .32813 Mdot
.91 .3289 Mdot
.91 .32981 Mdot
.91 .32993 Mdot
.91 .33101 Mdot
.91 .33104 Mdot
.91 .33112 Mdot
.91 .3323 Mdot
.91 .33247 Mdot
.91 .33292 Mdot
.91 .33312 Mdot
.91 .33372 Mdot
.91 .33393 Mdot
.91 .3341 Mdot
.91 .33522 Mdot
.91 .33578 Mdot
.91 .33585 Mdot
.91 .33588 Mdot
.91 .33592 Mdot
.91 .3363 Mdot
.91 .33674 Mdot
.91 .33716 Mdot
.91 .33748 Mdot
.91 .33757 Mdot
.91 .33769 Mdot
.91 .33834 Mdot
.91 .33887 Mdot
.91 .33938 Mdot
.91 .33944 Mdot
.91 .33953 Mdot
.91 .33966 Mdot
.91 .33969 Mdot
.91 .3399 Mdot
.91 .33994 Mdot
.91 .34012 Mdot
.91 .34014 Mdot
.91 .34034 Mdot
.91 .34045 Mdot
.91 .34046 Mdot
.91 .34048 Mdot
.91 .34106 Mdot
.91 .34117 Mdot
.91 .34188 Mdot
.91 .34188 Mdot
.91 .34198 Mdot
.91 .3422 Mdot
.91 .34223 Mdot
.91 .34251 Mdot
.91 .34458 Mdot
.91 .3446 Mdot
.91 .34492 Mdot
.91 .34575 Mdot
.91 .34649 Mdot
.91 .34665 Mdot
.91 .34697 Mdot
.91 .34724 Mdot
.91 .34827 Mdot
.91 .34844 Mdot
.91 .34851 Mdot
.91 .34897 Mdot
.91 .34899 Mdot
.91 .35184 Mdot
.91 .35232 Mdot
.91 .35287 Mdot
.91 .35338 Mdot
.91 .35343 Mdot
.91 .35395 Mdot
.91 .35527 Mdot
.91 .35581 Mdot
.91 .35634 Mdot
.91 .35748 Mdot
.91 .35767 Mdot
.91 .35805 Mdot
.91 .35813 Mdot
.91 .35896 Mdot
.91 .36526 Mdot
.91 .36535 Mdot
.91 .36583 Mdot
.91 .36611 Mdot
.91 .36654 Mdot
.91 .36764 Mdot
.91 .37068 Mdot
.91 .37382 Mdot
.91 .37407 Mdot
.91 .37525 Mdot
.91 .37562 Mdot
.91 .37703 Mdot
.91 .37924 Mdot
.91 .38262 Mdot
.91 .38343 Mdot
.91 .38423 Mdot
.91 .3843 Mdot
.91 .38709 Mdot
.91 .38712 Mdot
.91 .38869 Mdot
.91 .39083 Mdot
.91 .39278 Mdot
.91 .39294 Mdot
.91 .39336 Mdot
.91 .39933 Mdot
.91 .39943 Mdot
.91 .40013 Mdot
.91 .40192 Mdot
.91 .4028 Mdot
.91 .40341 Mdot
.91 .40648 Mdot
.91 .41371 Mdot
.91 .4203 Mdot
.91 .42124 Mdot
.91 .42162 Mdot
.91 .42305 Mdot
.91 .42314 Mdot
.91 .42317 Mdot
.91 .42503 Mdot
.91 .42665 Mdot
.91 .42697 Mdot
.91 .42886 Mdot
.91 .43124 Mdot
.91 .43236 Mdot
.91 .4325 Mdot
.91 .43294 Mdot
.91 .43447 Mdot
.91 .43494 Mdot
.91 .43504 Mdot
.91 .43578 Mdot
.91 .43611 Mdot
.91 .43726 Mdot
.91 .43896 Mdot
.91 .44013 Mdot
.91 .44237 Mdot
.91 .44629 Mdot
.91 .44738 Mdot
.91 .45105 Mdot
.91 .45203 Mdot
.91 .45381 Mdot
.91 .45409 Mdot
.91 .45434 Mdot
.91 .45638 Mdot
.91 .45799 Mdot
.91 .45881 Mdot
.91 .4604 Mdot
.91 .46332 Mdot
.91 .464 Mdot
.91 .46547 Mdot
.91 .46577 Mdot
.91 .46701 Mdot
.91 .46721 Mdot
.91 .46744 Mdot
.91 .46765 Mdot
.91 .46903 Mdot
.91 .47267 Mdot
.91 .47381 Mdot
.91 .4745 Mdot
.91 .47659 Mdot
.91 .47778 Mdot
.91 .48111 Mdot
.91 .48354 Mdot
.91 .48387 Mdot
.91 .48461 Mdot
.91 .48755 Mdot
.91 .48756 Mdot
.91 .49015 Mdot
.91 .49175 Mdot
.91 .49384 Mdot
.91 .49471 Mdot
.91 .49474 Mdot
.91 .49518 Mdot
.91 .4957 Mdot
.91 .49585 Mdot
.91 .49594 Mdot
.91 .49601 Mdot
.91 .49652 Mdot
.91 .49774 Mdot
.91 .49799 Mdot
.91 .49831 Mdot
.91 .49863 Mdot
.91 .4989 Mdot
.91 .50065 Mdot
.91 .50112 Mdot
.91 .50179 Mdot
.91 .5018 Mdot
.91 .50342 Mdot
.91 .50382 Mdot
.91 .50411 Mdot
.91 .50424 Mdot
.91 .50607 Mdot
.91 .50616 Mdot
.91 .50617 Mdot
.91 .50706 Mdot
.91 .50744 Mdot
.91 .50779 Mdot
.91 .50794 Mdot
.91 .5094 Mdot
.91 .50995 Mdot
.91 .51114 Mdot
.91 .51153 Mdot
.91 .51157 Mdot
.91 .51159 Mdot
.91 .51236 Mdot
.91 .51252 Mdot
.91 .51314 Mdot
.91 .51527 Mdot
.91 .51535 Mdot
.91 .51572 Mdot
.91 .51581 Mdot
.91 .51589 Mdot
.91 .5165 Mdot
.91 .51682 Mdot
.91 .51796 Mdot
.91 .51845 Mdot
.91 .51855 Mdot
.91 .51868 Mdot
.91 .51992 Mdot
.91 .52032 Mdot
.91 .52032 Mdot
.91 .52032 Mdot
.91 .52032 Mdot
.91 .52033 Mdot
.91 .52033 Mdot
.91 .52033 Mdot
.91 .52033 Mdot
.91 .52033 Mdot
.91 .52033 Mdot
.91 .52033 Mdot
.91 .52033 Mdot
.91 .52033 Mdot
.91 .52034 Mdot
.91 .52034 Mdot
.91 .52034 Mdot
.91 .52034 Mdot
.91 .52034 Mdot
.91 .52034 Mdot
.91 .52035 Mdot
.91 .52035 Mdot
.91 .52036 Mdot
.91 .52036 Mdot
.91 .52036 Mdot
.91 .52036 Mdot
.91 .52037 Mdot
.91 .52037 Mdot
.91 .52037 Mdot
.91 .52037 Mdot
.91 .52038 Mdot
.91 .52039 Mdot
.91 .52039 Mdot
.91 .5204 Mdot
.91 .5204 Mdot
.91 .5204 Mdot
.91 .52042 Mdot
.91 .52042 Mdot
.91 .52042 Mdot
.91 .52043 Mdot
.91 .52043 Mdot
.91 .52043 Mdot
.91 .52044 Mdot
.91 .52044 Mdot
.91 .52044 Mdot
.91 .52044 Mdot
.91 .52047 Mdot
.91 .52048 Mdot
.91 .52049 Mdot
.91 .5205 Mdot
.91 .52051 Mdot
.91 .52053 Mdot
.91 .52055 Mdot
.91 .52056 Mdot
.91 .52056 Mdot
.91 .52056 Mdot
.91 .52058 Mdot
.91 .52058 Mdot
.91 .52058 Mdot
.91 .52059 Mdot
.91 .5206 Mdot
.91 .5206 Mdot
.91 .5206 Mdot
.91 .5206 Mdot
.91 .52061 Mdot
.91 .52063 Mdot
.91 .52063 Mdot
.91 .52064 Mdot
.91 .52064 Mdot
.91 .52067 Mdot
.91 .52067 Mdot
.91 .52069 Mdot
.91 .52071 Mdot
.91 .52076 Mdot
.91 .52077 Mdot
.91 .52082 Mdot
.91 .52084 Mdot
.91 .52086 Mdot
.91 .52087 Mdot
.91 .52087 Mdot
.91 .52097 Mdot
.91 .52097 Mdot
.91 .52101 Mdot
.91 .52103 Mdot
.91 .52107 Mdot
.91 .52112 Mdot
.91 .5212 Mdot
.91 .52123 Mdot
.91 .52126 Mdot
.91 .52134 Mdot
.91 .52135 Mdot
.91 .52135 Mdot
.91 .52139 Mdot
.91 .52146 Mdot
.91 .52148 Mdot
.91 .52152 Mdot
.91 .52152 Mdot
.91 .52153 Mdot
.91 .52155 Mdot
.91 .52156 Mdot
.91 .52169 Mdot
.91 .52173 Mdot
.91 .52174 Mdot
.91 .52179 Mdot
.91 .52179 Mdot
.91 .52181 Mdot
.91 .52188 Mdot
.91 .52192 Mdot
.91 .522 Mdot
.91 .52201 Mdot
.91 .52203 Mdot
.91 .52205 Mdot
.91 .5221 Mdot
.91 .5221 Mdot
.91 .52211 Mdot
.91 .52222 Mdot
.91 .52225 Mdot
.91 .52234 Mdot
.91 .5225 Mdot
.91 .52251 Mdot
.91 .52253 Mdot
.91 .52255 Mdot
.91 .52256 Mdot
.91 .52262 Mdot
.91 .52265 Mdot
.91 .52265 Mdot
.91 .52266 Mdot
.91 .52266 Mdot
.91 .52269 Mdot
.91 .52271 Mdot
.91 .52272 Mdot
.91 .52286 Mdot
.91 .52307 Mdot
.91 .52321 Mdot
.91 .52325 Mdot
.91 .52326 Mdot
.91 .52338 Mdot
.91 .52353 Mdot
.91 .52359 Mdot
.91 .52368 Mdot
.91 .52377 Mdot
.91 .52393 Mdot
.91 .52399 Mdot
.91 .524 Mdot
.91 .52401 Mdot
.91 .52402 Mdot
.91 .52409 Mdot
.91 .52415 Mdot
.91 .52418 Mdot
.91 .52431 Mdot
.91 .52438 Mdot
.91 .52441 Mdot
.91 .52448 Mdot
.91 .52457 Mdot
.91 .52458 Mdot
.91 .52459 Mdot
.91 .52466 Mdot
.91 .52471 Mdot
.91 .52486 Mdot
.91 .52491 Mdot
.91 .52507 Mdot
.91 .52516 Mdot
.91 .52537 Mdot
.91 .52538 Mdot
.91 .5254 Mdot
.91 .52546 Mdot
.91 .52548 Mdot
.91 .52553 Mdot
.91 .52571 Mdot
.91 .52572 Mdot
.91 .52579 Mdot
.91 .52593 Mdot
.91 .52594 Mdot
.91 .52598 Mdot
.91 .52625 Mdot
.91 .52669 Mdot
.91 .52671 Mdot
.91 .52685 Mdot
.91 .52686 Mdot
.91 .52722 Mdot
.91 .52732 Mdot
.91 .52734 Mdot
.91 .52739 Mdot
.91 .52739 Mdot
.91 .52751 Mdot
.91 .52755 Mdot
.91 .52759 Mdot
.91 .52774 Mdot
.91 .52793 Mdot
.91 .52798 Mdot
.91 .52799 Mdot
.91 .52814 Mdot
.91 .52834 Mdot
.91 .52836 Mdot
.91 .52838 Mdot
.91 .5284 Mdot
.91 .52841 Mdot
.91 .52873 Mdot
.91 .52877 Mdot
.91 .52879 Mdot
.91 .5288 Mdot
.91 .52887 Mdot
.91 .52889 Mdot
.91 .52892 Mdot
.91 .52903 Mdot
.91 .52905 Mdot
.91 .52909 Mdot
.91 .52927 Mdot
.91 .52928 Mdot
.91 .5293 Mdot
.91 .52931 Mdot
.91 .52932 Mdot
.91 .52938 Mdot
.91 .52939 Mdot
.91 .52941 Mdot
.91 .52947 Mdot
.91 .52954 Mdot
.91 .52967 Mdot
.91 .52994 Mdot
.91 .53011 Mdot
.91 .53012 Mdot
.91 .53016 Mdot
.91 .53024 Mdot
.91 .53047 Mdot
.91 .53071 Mdot
.91 .53075 Mdot
.91 .53075 Mdot
.91 .53079 Mdot
.91 .53084 Mdot
.91 .53088 Mdot
.91 .53094 Mdot
.91 .53095 Mdot
.91 .53095 Mdot
.91 .53103 Mdot
.91 .53106 Mdot
.91 .53118 Mdot
.91 .53124 Mdot
.91 .53125 Mdot
.91 .53128 Mdot
.91 .53129 Mdot
.91 .53134 Mdot
.91 .53139 Mdot
.91 .53144 Mdot
.91 .53152 Mdot
.91 .53156 Mdot
.91 .53161 Mdot
.91 .53162 Mdot
.91 .53164 Mdot
.91 .53169 Mdot
.91 .53169 Mdot
.91 .53171 Mdot
.91 .53176 Mdot
.91 .53178 Mdot
.91 .53179 Mdot
.91 .53179 Mdot
.91 .53188 Mdot
.91 .53189 Mdot
.91 .5319 Mdot
.91 .5319 Mdot
.91 .53192 Mdot
.91 .53192 Mdot
.91 .532 Mdot
.91 .53204 Mdot
.91 .53207 Mdot
.91 .53208 Mdot
.91 .53209 Mdot
.91 .53209 Mdot
.91 .53209 Mdot
.91 .5321 Mdot
.91 .5321 Mdot
.91 .53212 Mdot
.91 .53212 Mdot
.91 .53212 Mdot
.91 .53212 Mdot
.91 .53249 Mdot
.91 .53318 Mdot
.91 .53388 Mdot
.91 .53469 Mdot
.91 .5347 Mdot
.91 .53489 Mdot
.91 .53493 Mdot
.91 .53544 Mdot
.91 .53555 Mdot
.91 .53568 Mdot
.91 .53637 Mdot
.91 .53655 Mdot
.91 .53664 Mdot
.91 .53831 Mdot
.91 .53871 Mdot
.91 .53975 Mdot
.91 .53981 Mdot
.91 .54233 Mdot
.91 .5444 Mdot
.91 .54442 Mdot
.91 .5445 Mdot
.91 .54453 Mdot
.91 .545 Mdot
.91 .5453 Mdot
.91 .5456 Mdot
.91 .54573 Mdot
.91 .54587 Mdot
.91 .54652 Mdot
.91 .54656 Mdot
.91 .54676 Mdot
.91 .54699 Mdot
.91 .54775 Mdot
.91 .54801 Mdot
.91 .54891 Mdot
.91 .54904 Mdot
.91 .54906 Mdot
.91 .54925 Mdot
.91 .54942 Mdot
.91 .54944 Mdot
.91 .54995 Mdot
.91 .55033 Mdot
.91 .55035 Mdot
.91 .55035 Mdot
.91 .5504 Mdot
.91 .55044 Mdot
.91 .55052 Mdot
.91 .55052 Mdot
.91 .55052 Mdot
.912 .12967 Mdot
.912 .12968 Mdot
.912 .1297 Mdot
.912 .12974 Mdot
.912 .12975 Mdot
.912 .1298 Mdot
.912 .12989 Mdot
.912 .12991 Mdot
.912 .12992 Mdot
.912 .13001 Mdot
.912 .13042 Mdot
.912 .13052 Mdot
.912 .13099 Mdot
.912 .1318 Mdot
.912 .13185 Mdot
.912 .13195 Mdot
.912 .13213 Mdot
.912 .13222 Mdot
.912 .13287 Mdot
.912 .13303 Mdot
.912 .13326 Mdot
.912 .13339 Mdot
.912 .13441 Mdot
.912 .13451 Mdot
.912 .13461 Mdot
.912 .13521 Mdot
.912 .13534 Mdot
.912 .13612 Mdot
.912 .13619 Mdot
.912 .13623 Mdot
.912 .13684 Mdot
.912 .13717 Mdot
.912 .1373 Mdot
.912 .13852 Mdot
.912 .13868 Mdot
.912 .13911 Mdot
.912 .13928 Mdot
.912 .14097 Mdot
.912 .14188 Mdot
.912 .14204 Mdot
.912 .14262 Mdot
.912 .14374 Mdot
.912 .14407 Mdot
.912 .14596 Mdot
.912 .14616 Mdot
.912 .14636 Mdot
.912 .14656 Mdot
.912 .1473 Mdot
.912 .14827 Mdot
.912 .14878 Mdot
.912 .14879 Mdot
.912 .15149 Mdot
.912 .15208 Mdot
.912 .15305 Mdot
.912 .15416 Mdot
.912 .15554 Mdot
.912 .1607 Mdot
.912 .16098 Mdot
.912 .16145 Mdot
.912 .16274 Mdot
.912 .16401 Mdot
.912 .16602 Mdot
.912 .16612 Mdot
.912 .16716 Mdot
.912 .16765 Mdot
.912 .16783 Mdot
.912 .16803 Mdot
.912 .16832 Mdot
.912 .16905 Mdot
.912 .17183 Mdot
.912 .1719 Mdot
.912 .17224 Mdot
.912 .1728 Mdot
.912 .17465 Mdot
.912 .17584 Mdot
.912 .17977 Mdot
.912 .1815 Mdot
.912 .18192 Mdot
.912 .18266 Mdot
.912 .18377 Mdot
.912 .18445 Mdot
.912 .18536 Mdot
.912 .18544 Mdot
.912 .18583 Mdot
.912 .18601 Mdot
.912 .18681 Mdot
.912 .18803 Mdot
.912 .18838 Mdot
.912 .1884 Mdot
.912 .18856 Mdot
.912 .19099 Mdot
.912 .19131 Mdot
.912 .19315 Mdot
.912 .19358 Mdot
.912 .19471 Mdot
.912 .1956 Mdot
.912 .19625 Mdot
.912 .1979 Mdot
.912 .1985 Mdot
.912 .19977 Mdot
.912 .20677 Mdot
.912 .20775 Mdot
.912 .20837 Mdot
.912 .21287 Mdot
.912 .21463 Mdot
.912 .21465 Mdot
.912 .21466 Mdot
.912 .21647 Mdot
.912 .21755 Mdot
.912 .21839 Mdot
.912 .21842 Mdot
.912 .21861 Mdot
.912 .21928 Mdot
.912 .21937 Mdot
.912 .22046 Mdot
.912 .22085 Mdot
.912 .22114 Mdot
.912 .22194 Mdot
.912 .22283 Mdot
.912 .22287 Mdot
.912 .22319 Mdot
.912 .22343 Mdot
.912 .22382 Mdot
.912 .22446 Mdot
.912 .22486 Mdot
.912 .22545 Mdot
.912 .22561 Mdot
.912 .22602 Mdot
.912 .22606 Mdot
.912 .22609 Mdot
.912 .22618 Mdot
.912 .22635 Mdot
.912 .22635 Mdot
.912 .22642 Mdot
.912 .22664 Mdot
.912 .22712 Mdot
.912 .22719 Mdot
.912 .22723 Mdot
.912 .22772 Mdot
.912 .22852 Mdot
.912 .22976 Mdot
.912 .23025 Mdot
.912 .23041 Mdot
.912 .23042 Mdot
.912 .23243 Mdot
.912 .23254 Mdot
.912 .23257 Mdot
.912 .23295 Mdot
.912 .23359 Mdot
.912 .2344 Mdot
.912 .23491 Mdot
.912 .23584 Mdot
.912 .23589 Mdot
.912 .23658 Mdot
.912 .23683 Mdot
.912 .2369 Mdot
.912 .23731 Mdot
.912 .23737 Mdot
.912 .2381 Mdot
.912 .23821 Mdot
.912 .23864 Mdot
.912 .24018 Mdot
.912 .24127 Mdot
.912 .24164 Mdot
.912 .24187 Mdot
.912 .24264 Mdot
.912 .24292 Mdot
.912 .24302 Mdot
.912 .24338 Mdot
.912 .24377 Mdot
.912 .24389 Mdot
.912 .24417 Mdot
.912 .24441 Mdot
.912 .24501 Mdot
.912 .24554 Mdot
.912 .24592 Mdot
.912 .24606 Mdot
.912 .24677 Mdot
.912 .24718 Mdot
.912 .2482 Mdot
.912 .24912 Mdot
.912 .24936 Mdot
.912 .24973 Mdot
.912 .24983 Mdot
.912 .25035 Mdot
.912 .25158 Mdot
.912 .25296 Mdot
.912 .25325 Mdot
.912 .25329 Mdot
.912 .25386 Mdot
.912 .25421 Mdot
.912 .2543 Mdot
.912 .25437 Mdot
.912 .25444 Mdot
.912 .25535 Mdot
.912 .25552 Mdot
.912 .25611 Mdot
.912 .25621 Mdot
.912 .25649 Mdot
.912 .25652 Mdot
.912 .2566 Mdot
.912 .25683 Mdot
.912 .25685 Mdot
.912 .25687 Mdot
.912 .25696 Mdot
.912 .25712 Mdot
.912 .25756 Mdot
.912 .25759 Mdot
.912 .25764 Mdot
.912 .25779 Mdot
.912 .25791 Mdot
.912 .25793 Mdot
.912 .25797 Mdot
.912 .25798 Mdot
.912 .25809 Mdot
.912 .25861 Mdot
.912 .25865 Mdot
.912 .25877 Mdot
.912 .25884 Mdot
.912 .25893 Mdot
.912 .25904 Mdot
.912 .25921 Mdot
.912 .25941 Mdot
.912 .25972 Mdot
.912 .25976 Mdot
.912 .25977 Mdot
.912 .25981 Mdot
.912 .25983 Mdot
.912 .26 Mdot
.912 .26005 Mdot
.912 .26016 Mdot
.912 .26029 Mdot
.912 .26059 Mdot
.912 .26097 Mdot
.912 .26106 Mdot
.912 .26109 Mdot
.912 .2613 Mdot
.912 .26144 Mdot
.912 .26149 Mdot
.912 .26153 Mdot
.912 .26159 Mdot
.912 .26178 Mdot
.912 .26185 Mdot
.912 .26188 Mdot
.912 .26203 Mdot
.912 .26207 Mdot
.912 .26208 Mdot
.912 .2621 Mdot
.912 .26212 Mdot
.912 .26212 Mdot
.912 .26217 Mdot
.912 .26217 Mdot
.912 .26221 Mdot
.912 .26223 Mdot
.912 .26228 Mdot
.912 .2623 Mdot
.912 .26236 Mdot
.912 .26242 Mdot
.912 .26242 Mdot
.912 .26246 Mdot
.912 .26253 Mdot
.912 .26269 Mdot
.912 .26272 Mdot
.912 .26272 Mdot
.912 .26275 Mdot
.912 .26279 Mdot
.912 .26284 Mdot
.912 .26285 Mdot
.912 .26289 Mdot
.912 .2629 Mdot
.912 .26293 Mdot
.912 .26298 Mdot
.912 .26299 Mdot
.912 .26308 Mdot
.912 .26313 Mdot
.912 .26313 Mdot
.912 .26315 Mdot
.912 .26319 Mdot
.912 .26327 Mdot
.912 .2634 Mdot
.912 .26342 Mdot
.912 .26343 Mdot
.912 .26349 Mdot
.912 .26349 Mdot
.912 .26353 Mdot
.912 .26354 Mdot
.912 .26355 Mdot
.912 .26355 Mdot
.912 .26355 Mdot
.912 .26356 Mdot
.912 .26358 Mdot
.912 .26359 Mdot
.912 .26361 Mdot
.912 .26364 Mdot
.912 .26367 Mdot
.912 .26368 Mdot
.912 .26368 Mdot
.912 .26368 Mdot
.912 .26368 Mdot
.912 .26369 Mdot
.912 .2637 Mdot
.912 .2637 Mdot
.912 .26877 Mdot
.912 .26952 Mdot
.912 .26979 Mdot
.912 .26979 Mdot
.912 .26994 Mdot
.912 .27001 Mdot
.912 .27003 Mdot
.912 .27007 Mdot
.912 .27008 Mdot
.912 .27017 Mdot
.912 .27064 Mdot
.912 .27106 Mdot
.912 .2714 Mdot
.912 .27146 Mdot
.912 .2715 Mdot
.912 .27184 Mdot
.912 .27193 Mdot
.912 .27199 Mdot
.912 .27201 Mdot
.912 .27207 Mdot
.912 .2722 Mdot
.912 .27221 Mdot
.912 .27282 Mdot
.912 .27293 Mdot
.912 .2737 Mdot
.912 .27392 Mdot
.912 .27411 Mdot
.912 .27731 Mdot
.912 .2778 Mdot
.912 .27814 Mdot
.912 .27816 Mdot
.912 .2788 Mdot
.912 .27966 Mdot
.912 .28011 Mdot
.912 .2803 Mdot
.912 .28098 Mdot
.912 .28145 Mdot
.912 .28157 Mdot
.912 .28217 Mdot
.912 .28236 Mdot
.912 .28303 Mdot
.912 .2836 Mdot
.912 .28369 Mdot
.912 .28403 Mdot
.912 .2841 Mdot
.912 .28424 Mdot
.912 .2845 Mdot
.912 .2867 Mdot
.912 .28681 Mdot
.912 .28775 Mdot
.912 .2883 Mdot
.912 .28835 Mdot
.912 .28911 Mdot
.912 .29007 Mdot
.912 .29035 Mdot
.912 .29093 Mdot
.912 .29122 Mdot
.912 .29127 Mdot
.912 .29179 Mdot
.912 .29188 Mdot
.912 .29247 Mdot
.912 .29252 Mdot
.912 .29257 Mdot
.912 .29277 Mdot
.912 .29302 Mdot
.912 .29315 Mdot
.912 .29381 Mdot
.912 .29394 Mdot
.912 .29584 Mdot
.912 .29618 Mdot
.912 .29717 Mdot
.912 .29967 Mdot
.912 .29985 Mdot
.912 .30054 Mdot
.912 .30062 Mdot
.912 .30101 Mdot
.912 .30135 Mdot
.912 .30173 Mdot
.912 .30209 Mdot
.912 .30348 Mdot
.912 .30473 Mdot
.912 .30623 Mdot
.912 .30651 Mdot
.912 .30662 Mdot
.912 .30774 Mdot
.912 .30811 Mdot
.912 .30981 Mdot
.912 .30983 Mdot
.912 .31235 Mdot
.912 .3127 Mdot
.912 .31336 Mdot
.912 .31375 Mdot
.912 .31388 Mdot
.912 .31391 Mdot
.912 .31428 Mdot
.912 .31449 Mdot
.912 .31465 Mdot
.912 .31468 Mdot
.912 .3149 Mdot
.912 .31578 Mdot
.912 .316 Mdot
.912 .31622 Mdot
.912 .31641 Mdot
.912 .31661 Mdot
.912 .31681 Mdot
.912 .31728 Mdot
.912 .31767 Mdot
.912 .31823 Mdot
.912 .31842 Mdot
.912 .31885 Mdot
.912 .31887 Mdot
.912 .31898 Mdot
.912 .31913 Mdot
.912 .31932 Mdot
.912 .31989 Mdot
.912 .32068 Mdot
.912 .32073 Mdot
.912 .32095 Mdot
.912 .3214 Mdot
.912 .32147 Mdot
.912 .32155 Mdot
.912 .32159 Mdot
.912 .32186 Mdot
.912 .32193 Mdot
.912 .32196 Mdot
.912 .322 Mdot
.912 .32202 Mdot
.912 .32253 Mdot
.912 .32284 Mdot
.912 .32337 Mdot
.912 .32401 Mdot
.912 .32494 Mdot
.912 .32502 Mdot
.912 .32515 Mdot
.912 .32518 Mdot
.912 .32535 Mdot
.912 .3255 Mdot
.912 .32564 Mdot
.912 .326 Mdot
.912 .32668 Mdot
.912 .32684 Mdot
.912 .32725 Mdot
.912 .32785 Mdot
.912 .32831 Mdot
.912 .32836 Mdot
.912 .32855 Mdot
.912 .32856 Mdot
.912 .32907 Mdot
.912 .32917 Mdot
.912 .32929 Mdot
.912 .3298 Mdot
.912 .32989 Mdot
.912 .33006 Mdot
.912 .33034 Mdot
.912 .33037 Mdot
.912 .33064 Mdot
.912 .33126 Mdot
.912 .33155 Mdot
.912 .33188 Mdot
.912 .33202 Mdot
.912 .33224 Mdot
.912 .33268 Mdot
.912 .33292 Mdot
.912 .3336 Mdot
.912 .33412 Mdot
.912 .3343 Mdot
.912 .33517 Mdot
.912 .33551 Mdot
.912 .33553 Mdot
.912 .3358 Mdot
.912 .33585 Mdot
.912 .33605 Mdot
.912 .33614 Mdot
.912 .33617 Mdot
.912 .33624 Mdot
.912 .33625 Mdot
.912 .3365 Mdot
.912 .33661 Mdot
.912 .33706 Mdot
.912 .33729 Mdot
.912 .33766 Mdot
.912 .33802 Mdot
.912 .33809 Mdot
.912 .33829 Mdot
.912 .33835 Mdot
.912 .33848 Mdot
.912 .3385 Mdot
.912 .33859 Mdot
.912 .33872 Mdot
.912 .33943 Mdot
.912 .33975 Mdot
.912 .33999 Mdot
.912 .34 Mdot
.912 .34008 Mdot
.912 .34042 Mdot
.912 .34042 Mdot
.912 .34063 Mdot
.912 .34085 Mdot
.912 .34089 Mdot
.912 .34095 Mdot
.912 .34109 Mdot
.912 .34125 Mdot
.912 .34132 Mdot
.912 .34138 Mdot
.912 .34148 Mdot
.912 .34197 Mdot
.912 .342 Mdot
.912 .34215 Mdot
.912 .34216 Mdot
.912 .34221 Mdot
.912 .34225 Mdot
.912 .34229 Mdot
.912 .34231 Mdot
.912 .34235 Mdot
.912 .34239 Mdot
.912 .34242 Mdot
.912 .34267 Mdot
.912 .34271 Mdot
.912 .34276 Mdot
.912 .34278 Mdot
.912 .34283 Mdot
.912 .34286 Mdot
.912 .34289 Mdot
.912 .34289 Mdot
.912 .34293 Mdot
.912 .34296 Mdot
.912 .34328 Mdot
.912 .34407 Mdot
.912 .34533 Mdot
.912 .34537 Mdot
.912 .34747 Mdot
.912 .34884 Mdot
.912 .35004 Mdot
.912 .3509 Mdot
.912 .35148 Mdot
.912 .35219 Mdot
.912 .35294 Mdot
.912 .35307 Mdot
.912 .35318 Mdot
.912 .35353 Mdot
.912 .35413 Mdot
.912 .35413 Mdot
.912 .35442 Mdot
.912 .35513 Mdot
.912 .35523 Mdot
.912 .35702 Mdot
.912 .35727 Mdot
.912 .35744 Mdot
.912 .3593 Mdot
.912 .35937 Mdot
.912 .36101 Mdot
.912 .36243 Mdot
.912 .36645 Mdot
.912 .36741 Mdot
.912 .36857 Mdot
.912 .36944 Mdot
.912 .3701 Mdot
.912 .37016 Mdot
.912 .37433 Mdot
.912 .3788 Mdot
.912 .37928 Mdot
.912 .37941 Mdot
.912 .3811 Mdot
.912 .38398 Mdot
.912 .38767 Mdot
.912 .38998 Mdot
.912 .39164 Mdot
.912 .39435 Mdot
.912 .39457 Mdot
.912 .39684 Mdot
.912 .3978 Mdot
.912 .39902 Mdot
.912 .39935 Mdot
.912 .4013 Mdot
.912 .40157 Mdot
.912 .4051 Mdot
.912 .40561 Mdot
.912 .40567 Mdot
.912 .40771 Mdot
.912 .41525 Mdot
.912 .42064 Mdot
.912 .42248 Mdot
.912 .42359 Mdot
.912 .42745 Mdot
.912 .42882 Mdot
.912 .42934 Mdot
.912 .43112 Mdot
.912 .43224 Mdot
.912 .43305 Mdot
.912 .43365 Mdot
.912 .43503 Mdot
.912 .43624 Mdot
.912 .43923 Mdot
.912 .44183 Mdot
.912 .44374 Mdot
.912 .44445 Mdot
.912 .44794 Mdot
.912 .44995 Mdot
.912 .45493 Mdot
.912 .45939 Mdot
.912 .46059 Mdot
.912 .46235 Mdot
.912 .46283 Mdot
.912 .4653 Mdot
.912 .46908 Mdot
.912 .4711 Mdot
.912 .47751 Mdot
.912 .47855 Mdot
.912 .47878 Mdot
.912 .47882 Mdot
.912 .479 Mdot
.912 .48112 Mdot
.912 .48157 Mdot
.912 .48312 Mdot
.912 .48356 Mdot
.912 .48383 Mdot
.912 .48415 Mdot
.912 .48817 Mdot
.912 .48888 Mdot
.912 .49143 Mdot
.912 .49186 Mdot
.912 .49304 Mdot
.912 .49317 Mdot
.912 .49351 Mdot
.912 .49445 Mdot
.912 .49453 Mdot
.912 .49464 Mdot
.912 .49503 Mdot
.912 .49565 Mdot
.912 .49636 Mdot
.912 .49749 Mdot
.912 .4975 Mdot
.912 .49761 Mdot
.912 .49782 Mdot
.912 .49843 Mdot
.912 .49891 Mdot
.912 .49899 Mdot
.912 .49916 Mdot
.912 .49921 Mdot
.912 .49964 Mdot
.912 .50171 Mdot
.912 .50188 Mdot
.912 .50234 Mdot
.912 .50261 Mdot
.912 .50298 Mdot
.912 .5034 Mdot
.912 .50407 Mdot
.912 .50483 Mdot
.912 .50523 Mdot
.912 .50603 Mdot
.912 .50618 Mdot
.912 .50623 Mdot
.912 .50639 Mdot
.912 .50647 Mdot
.912 .5065 Mdot
.912 .5071 Mdot
.912 .5073 Mdot
.912 .50769 Mdot
.912 .50819 Mdot
.912 .50929 Mdot
.912 .51069 Mdot
.912 .51102 Mdot
.912 .51105 Mdot
.912 .51113 Mdot
.912 .51191 Mdot
.912 .51239 Mdot
.912 .51259 Mdot
.912 .51272 Mdot
.912 .51295 Mdot
.912 .51361 Mdot
.912 .51387 Mdot
.912 .51396 Mdot
.912 .51444 Mdot
.912 .51448 Mdot
.912 .51464 Mdot
.912 .51468 Mdot
.912 .51474 Mdot
.912 .5148 Mdot
.912 .51482 Mdot
.912 .51496 Mdot
.912 .51499 Mdot
.912 .51513 Mdot
.912 .5152 Mdot
.912 .51534 Mdot
.912 .51541 Mdot
.912 .51565 Mdot
.912 .51583 Mdot
.912 .51585 Mdot
.912 .51598 Mdot
.912 .51621 Mdot
.912 .51676 Mdot
.912 .51686 Mdot
.912 .51687 Mdot
.912 .51695 Mdot
.912 .51711 Mdot
.912 .51726 Mdot
.912 .51731 Mdot
.912 .51745 Mdot
.912 .51748 Mdot
.912 .51759 Mdot
.912 .51774 Mdot
.912 .51779 Mdot
.912 .51809 Mdot
.912 .51824 Mdot
.912 .51824 Mdot
.912 .51832 Mdot
.912 .51843 Mdot
.912 .51915 Mdot
.912 .5192 Mdot
.912 .51925 Mdot
.912 .51942 Mdot
.912 .51944 Mdot
.912 .51958 Mdot
.912 .51961 Mdot
.912 .51962 Mdot
.912 .51963 Mdot
.912 .51964 Mdot
.912 .51966 Mdot
.912 .51973 Mdot
.912 .51976 Mdot
.912 .51983 Mdot
.912 .51992 Mdot
.912 .52003 Mdot
.912 .52005 Mdot
.912 .52005 Mdot
.912 .52006 Mdot
.912 .52006 Mdot
.912 .52008 Mdot
.912 .52011 Mdot
.912 .52011 Mdot
.912 .52143 Mdot
.912 .52143 Mdot
.912 .52144 Mdot
.912 .52144 Mdot
.912 .52144 Mdot
.912 .52144 Mdot
.912 .52144 Mdot
.912 .52144 Mdot
.912 .52145 Mdot
.912 .52145 Mdot
.912 .52146 Mdot
.912 .52146 Mdot
.912 .52146 Mdot
.912 .52147 Mdot
.912 .52147 Mdot
.912 .52147 Mdot
.912 .52147 Mdot
.912 .52147 Mdot
.912 .52148 Mdot
.912 .52148 Mdot
.912 .52149 Mdot
.912 .52149 Mdot
.912 .5215 Mdot
.912 .52153 Mdot
.912 .52154 Mdot
.912 .52155 Mdot
.912 .52156 Mdot
.912 .52157 Mdot
.912 .52159 Mdot
.912 .52159 Mdot
.912 .5216 Mdot
.912 .52161 Mdot
.912 .52161 Mdot
.912 .52162 Mdot
.912 .52162 Mdot
.912 .52163 Mdot
.912 .52164 Mdot
.912 .52164 Mdot
.912 .52165 Mdot
.912 .52165 Mdot
.912 .5217 Mdot
.912 .52171 Mdot
.912 .52171 Mdot
.912 .52172 Mdot
.912 .52174 Mdot
.912 .52174 Mdot
.912 .52175 Mdot
.912 .52175 Mdot
.912 .52176 Mdot
.912 .52176 Mdot
.912 .52177 Mdot
.912 .52177 Mdot
.912 .52178 Mdot
.912 .52178 Mdot
.912 .52178 Mdot
.912 .52179 Mdot
.912 .52182 Mdot
.912 .52183 Mdot
.912 .52185 Mdot
.912 .52189 Mdot
.912 .5219 Mdot
.912 .52191 Mdot
.912 .52192 Mdot
.912 .52195 Mdot
.912 .52199 Mdot
.912 .522 Mdot
.912 .5221 Mdot
.912 .52216 Mdot
.912 .52219 Mdot
.912 .52221 Mdot
.912 .52222 Mdot
.912 .52226 Mdot
.912 .52226 Mdot
.912 .52227 Mdot
.912 .52228 Mdot
.912 .52228 Mdot
.912 .52235 Mdot
.912 .52239 Mdot
.912 .52243 Mdot
.912 .52245 Mdot
.912 .52247 Mdot
.912 .52249 Mdot
.912 .52251 Mdot
.912 .52252 Mdot
.912 .52265 Mdot
.912 .52265 Mdot
.912 .52267 Mdot
.912 .52269 Mdot
.912 .52272 Mdot
.912 .52274 Mdot
.912 .52283 Mdot
.912 .52286 Mdot
.912 .52288 Mdot
.912 .52289 Mdot
.912 .52289 Mdot
.912 .52294 Mdot
.912 .52296 Mdot
.912 .52296 Mdot
.912 .52302 Mdot
.912 .52304 Mdot
.912 .52317 Mdot
.912 .5232 Mdot
.912 .52339 Mdot
.912 .52341 Mdot
.912 .52342 Mdot
.912 .52344 Mdot
.912 .52363 Mdot
.912 .5237 Mdot
.912 .52399 Mdot
.912 .52437 Mdot
.912 .5245 Mdot
.912 .52469 Mdot
.912 .5249 Mdot
.912 .52498 Mdot
.912 .52513 Mdot
.912 .52516 Mdot
.912 .52523 Mdot
.912 .52534 Mdot
.912 .52551 Mdot
.912 .52557 Mdot
.912 .52568 Mdot
.912 .52575 Mdot
.912 .52577 Mdot
.912 .52603 Mdot
.912 .52611 Mdot
.912 .52633 Mdot
.912 .52675 Mdot
.912 .5269 Mdot
.912 .52699 Mdot
.912 .5272 Mdot
.912 .52721 Mdot
.912 .5274 Mdot
.912 .5275 Mdot
.912 .52766 Mdot
.912 .52779 Mdot
.912 .52787 Mdot
.912 .52789 Mdot
.912 .5283 Mdot
.912 .5283 Mdot
.912 .52868 Mdot
.912 .52912 Mdot
.912 .52917 Mdot
.912 .52927 Mdot
.912 .5293 Mdot
.912 .52942 Mdot
.912 .5295 Mdot
.912 .52963 Mdot
.912 .52971 Mdot
.912 .52975 Mdot
.912 .52982 Mdot
.912 .52983 Mdot
.912 .53 Mdot
.912 .53017 Mdot
.912 .53023 Mdot
.912 .5303 Mdot
.912 .53052 Mdot
.912 .53054 Mdot
.912 .53068 Mdot
.912 .53071 Mdot
.912 .53072 Mdot
.912 .53089 Mdot
.912 .53111 Mdot
.912 .53147 Mdot
.912 .53147 Mdot
.912 .53148 Mdot
.912 .53183 Mdot
.912 .53274 Mdot
.912 .53287 Mdot
.912 .53307 Mdot
.912 .5345 Mdot
.912 .53476 Mdot
.912 .53488 Mdot
.912 .53522 Mdot
.912 .53536 Mdot
.912 .53554 Mdot
.912 .53578 Mdot
.912 .53587 Mdot
.912 .53625 Mdot
.912 .53632 Mdot
.912 .53683 Mdot
.912 .53686 Mdot
.912 .53687 Mdot
.912 .53694 Mdot
.912 .5372 Mdot
.912 .53737 Mdot
.912 .53741 Mdot
.912 .53749 Mdot
.912 .53751 Mdot
.912 .5377 Mdot
.912 .53785 Mdot
.912 .53809 Mdot
.912 .53824 Mdot
.912 .53834 Mdot
.912 .53871 Mdot
.912 .53957 Mdot
.912 .53983 Mdot
.912 .54025 Mdot
.912 .54037 Mdot
.912 .54045 Mdot
.912 .54047 Mdot
.912 .5411 Mdot
.912 .54126 Mdot
.912 .54133 Mdot
.912 .54138 Mdot
.912 .54142 Mdot
.912 .54153 Mdot
.912 .54177 Mdot
.912 .54179 Mdot
.912 .54226 Mdot
.912 .54256 Mdot
.912 .54287 Mdot
.912 .54298 Mdot
.912 .54305 Mdot
.912 .54431 Mdot
.912 .54466 Mdot
.912 .54494 Mdot
.912 .54519 Mdot
.912 .54534 Mdot
.912 .54604 Mdot
.912 .54604 Mdot
.912 .54618 Mdot
.912 .54644 Mdot
.912 .54663 Mdot
.912 .54669 Mdot
.912 .54674 Mdot
.912 .5468 Mdot
.912 .54732 Mdot
.912 .54741 Mdot
.912 .54772 Mdot
.912 .54788 Mdot
.912 .54793 Mdot
.912 .54819 Mdot
.912 .54868 Mdot
.912 .54873 Mdot
.912 .54885 Mdot
.912 .5489 Mdot
.912 .54927 Mdot
.912 .5493 Mdot
.912 .5494 Mdot
.912 .54959 Mdot
.912 .5496 Mdot
.912 .54962 Mdot
.912 .54986 Mdot
.912 .5499 Mdot
.912 .55009 Mdot
.912 .55012 Mdot
.912 .55015 Mdot
.912 .55047 Mdot
.912 .55052 Mdot
.912 .55059 Mdot
.912 .55064 Mdot
.912 .55085 Mdot
.912 .55088 Mdot
.912 .55094 Mdot
.912 .55097 Mdot
.912 .55099 Mdot
.912 .55126 Mdot
.912 .55141 Mdot
.912 .55144 Mdot
.912 .55158 Mdot
.912 .55161 Mdot
.912 .55162 Mdot
.912 .55162 Mdot
.912 .55166 Mdot
.912 .55167 Mdot
.912 .55168 Mdot
.912 .55169 Mdot
.912 .5517 Mdot
.912 .5517 Mdot
.914 .12656 Mdot
.914 .12663 Mdot
.914 .12676 Mdot
.914 .12677 Mdot
.914 .12725 Mdot
.914 .1273 Mdot
.914 .12755 Mdot
.914 .12765 Mdot
.914 .12783 Mdot
.914 .12854 Mdot
.914 .12857 Mdot
.914 .12926 Mdot
.914 .13 Mdot
.914 .13006 Mdot
.914 .13128 Mdot
.914 .13214 Mdot
.914 .13277 Mdot
.914 .1328 Mdot
.914 .13351 Mdot
.914 .13401 Mdot
.914 .13552 Mdot
.914 .14048 Mdot
.914 .15143 Mdot
.914 .15309 Mdot
.914 .15408 Mdot
.914 .15744 Mdot
.914 .15792 Mdot
.914 .16043 Mdot
.914 .16118 Mdot
.914 .1634 Mdot
.914 .16378 Mdot
.914 .16605 Mdot
.914 .16612 Mdot
.914 .17066 Mdot
.914 .17695 Mdot
.914 .1781 Mdot
.914 .18078 Mdot
.914 .18373 Mdot
.914 .18634 Mdot
.914 .18679 Mdot
.914 .19363 Mdot
.914 .19618 Mdot
.914 .19656 Mdot
.914 .2036 Mdot
.914 .21018 Mdot
.914 .211 Mdot
.914 .21134 Mdot
.914 .21136 Mdot
.914 .21162 Mdot
.914 .21171 Mdot
.914 .21197 Mdot
.914 .21202 Mdot
.914 .21202 Mdot
.914 .21207 Mdot
.914 .21246 Mdot
.914 .21254 Mdot
.914 .21304 Mdot
.914 .21357 Mdot
.914 .21421 Mdot
.914 .2144 Mdot
.914 .21462 Mdot
.914 .21469 Mdot
.914 .21503 Mdot
.914 .21507 Mdot
.914 .21554 Mdot
.914 .21593 Mdot
.914 .2162 Mdot
.914 .21623 Mdot
.914 .2164 Mdot
.914 .21675 Mdot
.914 .21697 Mdot
.914 .21728 Mdot
.914 .2174 Mdot
.914 .21764 Mdot
.914 .2181 Mdot
.914 .21945 Mdot
.914 .21946 Mdot
.914 .21955 Mdot
.914 .2198 Mdot
.914 .22062 Mdot
.914 .22081 Mdot
.914 .22086 Mdot
.914 .22098 Mdot
.914 .22127 Mdot
.914 .22132 Mdot
.914 .22182 Mdot
.914 .22186 Mdot
.914 .22244 Mdot
.914 .22247 Mdot
.914 .22268 Mdot
.914 .22273 Mdot
.914 .22277 Mdot
.914 .22399 Mdot
.914 .22431 Mdot
.914 .22441 Mdot
.914 .22442 Mdot
.914 .22451 Mdot
.914 .22514 Mdot
.914 .22545 Mdot
.914 .22554 Mdot
.914 .22569 Mdot
.914 .2258 Mdot
.914 .2267 Mdot
.914 .22671 Mdot
.914 .22682 Mdot
.914 .22711 Mdot
.914 .22713 Mdot
.914 .22724 Mdot
.914 .22748 Mdot
.914 .2278 Mdot
.914 .22801 Mdot
.914 .22801 Mdot
.914 .22812 Mdot
.914 .22814 Mdot
.914 .22825 Mdot
.914 .22828 Mdot
.914 .22843 Mdot
.914 .22999 Mdot
.914 .23012 Mdot
.914 .2303 Mdot
.914 .23059 Mdot
.914 .23071 Mdot
.914 .23071 Mdot
.914 .23087 Mdot
.914 .23091 Mdot
.914 .23094 Mdot
.914 .23101 Mdot
.914 .23103 Mdot
.914 .23123 Mdot
.914 .23133 Mdot
.914 .23321 Mdot
.914 .23448 Mdot
.914 .23577 Mdot
.914 .23595 Mdot
.914 .23705 Mdot
.914 .2373 Mdot
.914 .23792 Mdot
.914 .23808 Mdot
.914 .23815 Mdot
.914 .23839 Mdot
.914 .23841 Mdot
.914 .23845 Mdot
.914 .23873 Mdot
.914 .23905 Mdot
.914 .23957 Mdot
.914 .23957 Mdot
.914 .24079 Mdot
.914 .24093 Mdot
.914 .24093 Mdot
.914 .2415 Mdot
.914 .24186 Mdot
.914 .242 Mdot
.914 .24219 Mdot
.914 .24226 Mdot
.914 .24226 Mdot
.914 .24244 Mdot
.914 .2425 Mdot
.914 .24277 Mdot
.914 .24302 Mdot
.914 .24306 Mdot
.914 .24347 Mdot
.914 .24366 Mdot
.914 .24386 Mdot
.914 .24478 Mdot
.914 .24527 Mdot
.914 .24532 Mdot
.914 .24547 Mdot
.914 .24561 Mdot
.914 .24683 Mdot
.914 .2469 Mdot
.914 .24792 Mdot
.914 .24795 Mdot
.914 .24825 Mdot
.914 .24839 Mdot
.914 .24906 Mdot
.914 .24919 Mdot
.914 .24928 Mdot
.914 .24938 Mdot
.914 .24954 Mdot
.914 .25008 Mdot
.914 .25107 Mdot
.914 .25158 Mdot
.914 .25162 Mdot
.914 .25166 Mdot
.914 .25168 Mdot
.914 .25172 Mdot
.914 .25184 Mdot
.914 .25185 Mdot
.914 .25202 Mdot
.914 .25211 Mdot
.914 .25214 Mdot
.914 .25216 Mdot
.914 .25222 Mdot
.914 .25223 Mdot
.914 .25245 Mdot
.914 .25318 Mdot
.914 .25383 Mdot
.914 .254 Mdot
.914 .25412 Mdot
.914 .25423 Mdot
.914 .25438 Mdot
.914 .25442 Mdot
.914 .25507 Mdot
.914 .25513 Mdot
.914 .25523 Mdot
.914 .25569 Mdot
.914 .2559 Mdot
.914 .25618 Mdot
.914 .25627 Mdot
.914 .25637 Mdot
.914 .25642 Mdot
.914 .25644 Mdot
.914 .25648 Mdot
.914 .25651 Mdot
.914 .25651 Mdot
.914 .25653 Mdot
.914 .25654 Mdot
.914 .25664 Mdot
.914 .25683 Mdot
.914 .25698 Mdot
.914 .257 Mdot
.914 .25707 Mdot
.914 .25714 Mdot
.914 .25717 Mdot
.914 .25719 Mdot
.914 .25725 Mdot
.914 .25742 Mdot
.914 .25746 Mdot
.914 .25752 Mdot
.914 .25755 Mdot
.914 .25759 Mdot
.914 .25769 Mdot
.914 .2577 Mdot
.914 .25772 Mdot
.914 .25782 Mdot
.914 .25784 Mdot
.914 .25787 Mdot
.914 .25794 Mdot
.914 .25803 Mdot
.914 .25803 Mdot
.914 .25807 Mdot
.914 .25808 Mdot
.914 .25814 Mdot
.914 .25816 Mdot
.914 .2582 Mdot
.914 .2582 Mdot
.914 .25823 Mdot
.914 .25826 Mdot
.914 .25829 Mdot
.914 .25837 Mdot
.914 .25846 Mdot
.914 .2585 Mdot
.914 .2585 Mdot
.914 .25853 Mdot
.914 .25857 Mdot
.914 .25863 Mdot
.914 .25866 Mdot
.914 .25866 Mdot
.914 .25869 Mdot
.914 .2587 Mdot
.914 .25871 Mdot
.914 .25872 Mdot
.914 .25874 Mdot
.914 .25874 Mdot
.914 .25876 Mdot
.914 .25878 Mdot
.914 .25879 Mdot
.914 .2588 Mdot
.914 .25885 Mdot
.914 .25885 Mdot
.914 .25888 Mdot
.914 .25889 Mdot
.914 .25889 Mdot
.914 .25892 Mdot
.914 .25893 Mdot
.914 .25895 Mdot
.914 .25895 Mdot
.914 .25895 Mdot
.914 .25896 Mdot
.914 .25896 Mdot
.914 .25897 Mdot
.914 .25897 Mdot
.914 .259 Mdot
.914 .259 Mdot
.914 .25901 Mdot
.914 .25901 Mdot
.914 .25901 Mdot
.914 .25901 Mdot
.914 .26003 Mdot
.914 .2734 Mdot
.914 .27813 Mdot
.914 .28887 Mdot
.914 .31335 Mdot
.914 .31336 Mdot
.914 .31337 Mdot
.914 .31342 Mdot
.914 .31343 Mdot
.914 .31353 Mdot
.914 .31356 Mdot
.914 .31364 Mdot
.914 .31498 Mdot
.914 .3154 Mdot
.914 .31568 Mdot
.914 .3157 Mdot
.914 .316 Mdot
.914 .31607 Mdot
.914 .31618 Mdot
.914 .31649 Mdot
.914 .31661 Mdot
.914 .3167 Mdot
.914 .31694 Mdot
.914 .31737 Mdot
.914 .31776 Mdot
.914 .31778 Mdot
.914 .31798 Mdot
.914 .31811 Mdot
.914 .31822 Mdot
.914 .31855 Mdot
.914 .31862 Mdot
.914 .31863 Mdot
.914 .31868 Mdot
.914 .31872 Mdot
.914 .31921 Mdot
.914 .31921 Mdot
.914 .31933 Mdot
.914 .31947 Mdot
.914 .32005 Mdot
.914 .32087 Mdot
.914 .32191 Mdot
.914 .32224 Mdot
.914 .32262 Mdot
.914 .32275 Mdot
.914 .32332 Mdot
.914 .32336 Mdot
.914 .32344 Mdot
.914 .32361 Mdot
.914 .32364 Mdot
.914 .32432 Mdot
.914 .32469 Mdot
.914 .3249 Mdot
.914 .32508 Mdot
.914 .32562 Mdot
.914 .32563 Mdot
.914 .32569 Mdot
.914 .32582 Mdot
.914 .32604 Mdot
.914 .32607 Mdot
.914 .32677 Mdot
.914 .3268 Mdot
.914 .3268 Mdot
.914 .32682 Mdot
.914 .32682 Mdot
.914 .32684 Mdot
.914 .32693 Mdot
.914 .32695 Mdot
.914 .3272 Mdot
.914 .32721 Mdot
.914 .32726 Mdot
.914 .3273 Mdot
.914 .32733 Mdot
.914 .32735 Mdot
.914 .32739 Mdot
.914 .32741 Mdot
.914 .32741 Mdot
.914 .32758 Mdot
.914 .32762 Mdot
.914 .3277 Mdot
.914 .32793 Mdot
.914 .32793 Mdot
.914 .32794 Mdot
.914 .32796 Mdot
.914 .32804 Mdot
.914 .32805 Mdot
.914 .32817 Mdot
.914 .3282 Mdot
.914 .3283 Mdot
.914 .32833 Mdot
.914 .32834 Mdot
.914 .3285 Mdot
.914 .32856 Mdot
.914 .32867 Mdot
.914 .32873 Mdot
.914 .32873 Mdot
.914 .32881 Mdot
.914 .32892 Mdot
.914 .32896 Mdot
.914 .3291 Mdot
.914 .32925 Mdot
.914 .32926 Mdot
.914 .32944 Mdot
.914 .32957 Mdot
.914 .32965 Mdot
.914 .32965 Mdot
.914 .32969 Mdot
.914 .3297 Mdot
.914 .32982 Mdot
.914 .32999 Mdot
.914 .32999 Mdot
.914 .33027 Mdot
.914 .33074 Mdot
.914 .33075 Mdot
.914 .33109 Mdot
.914 .33129 Mdot
.914 .33131 Mdot
.914 .33133 Mdot
.914 .33151 Mdot
.914 .33163 Mdot
.914 .33163 Mdot
.914 .33167 Mdot
.914 .33199 Mdot
.914 .33201 Mdot
.914 .33204 Mdot
.914 .33238 Mdot
.914 .333 Mdot
.914 .33314 Mdot
.914 .33316 Mdot
.914 .33318 Mdot
.914 .33322 Mdot
.914 .33334 Mdot
.914 .33343 Mdot
.914 .33343 Mdot
.914 .33365 Mdot
.914 .33368 Mdot
.914 .33393 Mdot
.914 .33403 Mdot
.914 .33407 Mdot
.914 .33408 Mdot
.914 .3342 Mdot
.914 .33443 Mdot
.914 .33455 Mdot
.914 .33461 Mdot
.914 .33488 Mdot
.914 .3349 Mdot
.914 .33545 Mdot
.914 .33547 Mdot
.914 .33568 Mdot
.914 .33596 Mdot
.914 .33615 Mdot
.914 .33627 Mdot
.914 .33628 Mdot
.914 .33631 Mdot
.914 .33684 Mdot
.914 .3369 Mdot
.914 .33699 Mdot
.914 .33704 Mdot
.914 .33706 Mdot
.914 .33732 Mdot
.914 .33735 Mdot
.914 .33768 Mdot
.914 .33791 Mdot
.914 .338 Mdot
.914 .33805 Mdot
.914 .33816 Mdot
.914 .3383 Mdot
.914 .33841 Mdot
.914 .33859 Mdot
.914 .33864 Mdot
.914 .33897 Mdot
.914 .33947 Mdot
.914 .33974 Mdot
.914 .33978 Mdot
.914 .33978 Mdot
.914 .33983 Mdot
.914 .33988 Mdot
.914 .33997 Mdot
.914 .33997 Mdot
.914 .34026 Mdot
.914 .34031 Mdot
.914 .34058 Mdot
.914 .34068 Mdot
.914 .34089 Mdot
.914 .34127 Mdot
.914 .34128 Mdot
.914 .34131 Mdot
.914 .34154 Mdot
.914 .34163 Mdot
.914 .34165 Mdot
.914 .34166 Mdot
.914 .34175 Mdot
.914 .34192 Mdot
.914 .34207 Mdot
.914 .34219 Mdot
.914 .34221 Mdot
.914 .34225 Mdot
.914 .34228 Mdot
.914 .3423 Mdot
.914 .34236 Mdot
.914 .34241 Mdot
.914 .34248 Mdot
.914 .34254 Mdot
.914 .34256 Mdot
.914 .34266 Mdot
.914 .34268 Mdot
.914 .34288 Mdot
.914 .34304 Mdot
.914 .34305 Mdot
.914 .34307 Mdot
.914 .34344 Mdot
.914 .34346 Mdot
.914 .34349 Mdot
.914 .3435 Mdot
.914 .34358 Mdot
.914 .34363 Mdot
.914 .34663 Mdot
.914 .3477 Mdot
.914 .34803 Mdot
.914 .34808 Mdot
.914 .3481 Mdot
.914 .34839 Mdot
.914 .35056 Mdot
.914 .35163 Mdot
.914 .35165 Mdot
.914 .35198 Mdot
.914 .35249 Mdot
.914 .3529 Mdot
.914 .35506 Mdot
.914 .35617 Mdot
.914 .35623 Mdot
.914 .35663 Mdot
.914 .35772 Mdot
.914 .35779 Mdot
.914 .35821 Mdot
.914 .35912 Mdot
.914 .36038 Mdot
.914 .36119 Mdot
.914 .3612 Mdot
.914 .36161 Mdot
.914 .36168 Mdot
.914 .3621 Mdot
.914 .36225 Mdot
.914 .36274 Mdot
.914 .36283 Mdot
.914 .36353 Mdot
.914 .36856 Mdot
.914 .36915 Mdot
.914 .36968 Mdot
.914 .37042 Mdot
.914 .37164 Mdot
.914 .37216 Mdot
.914 .37218 Mdot
.914 .37283 Mdot
.914 .37302 Mdot
.914 .37313 Mdot
.914 .37343 Mdot
.914 .37351 Mdot
.914 .37437 Mdot
.914 .3744 Mdot
.914 .37479 Mdot
.914 .37554 Mdot
.914 .37944 Mdot
.914 .37947 Mdot
.914 .381 Mdot
.914 .38304 Mdot
.914 .38519 Mdot
.914 .38843 Mdot
.914 .38882 Mdot
.914 .39481 Mdot
.914 .3957 Mdot
.914 .39675 Mdot
.914 .40092 Mdot
.914 .40211 Mdot
.914 .4051 Mdot
.914 .40588 Mdot
.914 .40622 Mdot
.914 .40738 Mdot
.914 .40747 Mdot
.914 .40766 Mdot
.914 .40903 Mdot
.914 .4104 Mdot
.914 .41049 Mdot
.914 .41061 Mdot
.914 .41313 Mdot
.914 .41314 Mdot
.914 .41388 Mdot
.914 .41914 Mdot
.914 .41983 Mdot
.914 .41984 Mdot
.914 .42268 Mdot
.914 .42446 Mdot
.914 .42518 Mdot
.914 .42611 Mdot
.914 .42645 Mdot
.914 .42646 Mdot
.914 .42736 Mdot
.914 .42762 Mdot
.914 .42901 Mdot
.914 .43025 Mdot
.914 .43045 Mdot
.914 .43246 Mdot
.914 .4334 Mdot
.914 .43443 Mdot
.914 .43901 Mdot
.914 .44001 Mdot
.914 .44147 Mdot
.914 .44172 Mdot
.914 .44244 Mdot
.914 .44312 Mdot
.914 .44368 Mdot
.914 .44369 Mdot
.914 .44918 Mdot
.914 .44954 Mdot
.914 .45456 Mdot
.914 .45469 Mdot
.914 .45615 Mdot
.914 .45617 Mdot
.914 .45672 Mdot
.914 .45685 Mdot
.914 .45716 Mdot
.914 .46009 Mdot
.914 .46074 Mdot
.914 .46115 Mdot
.914 .46163 Mdot
.914 .4624 Mdot
.914 .46379 Mdot
.914 .46499 Mdot
.914 .46974 Mdot
.914 .4703 Mdot
.914 .47122 Mdot
.914 .47165 Mdot
.914 .47213 Mdot
.914 .47232 Mdot
.914 .47247 Mdot
.914 .4726 Mdot
.914 .47278 Mdot
.914 .47333 Mdot
.914 .47337 Mdot
.914 .47416 Mdot
.914 .47461 Mdot
.914 .47474 Mdot
.914 .47484 Mdot
.914 .47512 Mdot
.914 .47516 Mdot
.914 .47617 Mdot
.914 .47704 Mdot
.914 .47858 Mdot
.914 .47953 Mdot
.914 .48215 Mdot
.914 .48248 Mdot
.914 .48324 Mdot
.914 .48375 Mdot
.914 .48427 Mdot
.914 .48491 Mdot
.914 .48509 Mdot
.914 .48799 Mdot
.914 .48826 Mdot
.914 .48868 Mdot
.914 .49068 Mdot
.914 .49157 Mdot
.914 .49278 Mdot
.914 .49315 Mdot
.914 .49356 Mdot
.914 .49377 Mdot
.914 .49388 Mdot
.914 .49406 Mdot
.914 .49415 Mdot
.914 .49419 Mdot
.914 .49424 Mdot
.914 .49428 Mdot
.914 .4947 Mdot
.914 .49518 Mdot
.914 .4955 Mdot
.914 .49614 Mdot
.914 .49624 Mdot
.914 .4965 Mdot
.914 .49683 Mdot
.914 .49695 Mdot
.914 .497 Mdot
.914 .49726 Mdot
.914 .49798 Mdot
.914 .49812 Mdot
.914 .49839 Mdot
.914 .49849 Mdot
.914 .49865 Mdot
.914 .49909 Mdot
.914 .4991 Mdot
.914 .49919 Mdot
.914 .49959 Mdot
.914 .49968 Mdot
.914 .4998 Mdot
.914 .5001 Mdot
.914 .50011 Mdot
.914 .50044 Mdot
.914 .50045 Mdot
.914 .50061 Mdot
.914 .50064 Mdot
.914 .5009 Mdot
.914 .50099 Mdot
.914 .50113 Mdot
.914 .50114 Mdot
.914 .50126 Mdot
.914 .50137 Mdot
.914 .50149 Mdot
.914 .50181 Mdot
.914 .50217 Mdot
.914 .50234 Mdot
.914 .50235 Mdot
.914 .50245 Mdot
.914 .50262 Mdot
.914 .50285 Mdot
.914 .50297 Mdot
.914 .50298 Mdot
.914 .50311 Mdot
.914 .50313 Mdot
.914 .50317 Mdot
.914 .50323 Mdot
.914 .50331 Mdot
.914 .50332 Mdot
.914 .50338 Mdot
.914 .50344 Mdot
.914 .50351 Mdot
.914 .50355 Mdot
.914 .50372 Mdot
.914 .50372 Mdot
.914 .50385 Mdot
.914 .50389 Mdot
.914 .5039 Mdot
.914 .504 Mdot
.914 .50405 Mdot
.914 .50412 Mdot
.914 .50413 Mdot
.914 .50414 Mdot
.914 .50415 Mdot
.914 .50417 Mdot
.914 .5042 Mdot
.914 .50421 Mdot
.914 .50431 Mdot
.914 .50432 Mdot
.914 .50437 Mdot
.914 .50437 Mdot
.914 .50438 Mdot
.914 .50438 Mdot
.914 .50828 Mdot
.914 .51585 Mdot
.914 .51944 Mdot
.914 .52233 Mdot
.914 .52255 Mdot
.914 .52255 Mdot
.914 .52255 Mdot
.914 .52255 Mdot
.914 .52255 Mdot
.914 .52255 Mdot
.914 .52255 Mdot
.914 .52256 Mdot
.914 .52256 Mdot
.914 .52256 Mdot
.914 .52256 Mdot
.914 .52256 Mdot
.914 .52256 Mdot
.914 .52256 Mdot
.914 .52257 Mdot
.914 .52257 Mdot
.914 .52257 Mdot
.914 .52257 Mdot
.914 .52258 Mdot
.914 .52258 Mdot
.914 .52259 Mdot
.914 .52259 Mdot
.914 .5226 Mdot
.914 .5226 Mdot
.914 .5226 Mdot
.914 .5226 Mdot
.914 .52261 Mdot
.914 .52261 Mdot
.914 .52261 Mdot
.914 .52261 Mdot
.914 .52262 Mdot
.914 .52262 Mdot
.914 .52263 Mdot
.914 .52264 Mdot
.914 .52265 Mdot
.914 .52265 Mdot
.914 .52265 Mdot
.914 .52266 Mdot
.914 .52268 Mdot
.914 .5227 Mdot
.914 .52271 Mdot
.914 .52271 Mdot
.914 .52272 Mdot
.914 .52272 Mdot
.914 .52273 Mdot
.914 .52273 Mdot
.914 .52274 Mdot
.914 .52275 Mdot
.914 .52275 Mdot
.914 .52275 Mdot
.914 .52277 Mdot
.914 .52279 Mdot
.914 .52279 Mdot
.914 .5228 Mdot
.914 .52282 Mdot
.914 .52282 Mdot
.914 .52282 Mdot
.914 .52285 Mdot
.914 .52285 Mdot
.914 .52286 Mdot
.914 .52287 Mdot
.914 .52288 Mdot
.914 .52292 Mdot
.914 .52293 Mdot
.914 .52293 Mdot
.914 .52294 Mdot
.914 .52296 Mdot
.914 .52297 Mdot
.914 .52297 Mdot
.914 .52301 Mdot
.914 .52305 Mdot
.914 .52307 Mdot
.914 .52307 Mdot
.914 .52307 Mdot
.914 .52307 Mdot
.914 .52308 Mdot
.914 .52309 Mdot
.914 .52309 Mdot
.914 .5231 Mdot
.914 .52312 Mdot
.914 .52314 Mdot
.914 .5232 Mdot
.914 .52324 Mdot
.914 .52336 Mdot
.914 .52337 Mdot
.914 .52351 Mdot
.914 .52352 Mdot
.914 .52355 Mdot
.914 .52357 Mdot
.914 .52359 Mdot
.914 .52363 Mdot
.914 .52376 Mdot
.914 .52392 Mdot
.914 .52396 Mdot
.914 .52396 Mdot
.914 .52398 Mdot
.914 .52398 Mdot
.914 .52399 Mdot
.914 .52401 Mdot
.914 .52404 Mdot
.914 .52404 Mdot
.914 .52407 Mdot
.914 .52408 Mdot
.914 .52408 Mdot
.914 .52409 Mdot
.914 .5241 Mdot
.914 .5242 Mdot
.914 .52441 Mdot
.914 .52452 Mdot
.914 .52455 Mdot
.914 .52457 Mdot
.914 .52459 Mdot
.914 .52462 Mdot
.914 .52475 Mdot
.914 .52478 Mdot
.914 .52484 Mdot
.914 .52506 Mdot
.914 .52507 Mdot
.914 .52532 Mdot
.914 .52538 Mdot
.914 .52539 Mdot
.914 .52549 Mdot
.914 .52568 Mdot
.914 .52572 Mdot
.914 .52576 Mdot
.914 .52584 Mdot
.914 .52585 Mdot
.914 .5259 Mdot
.914 .52596 Mdot
.914 .52597 Mdot
.914 .526 Mdot
.914 .526 Mdot
.914 .52602 Mdot
.914 .52616 Mdot
.914 .52628 Mdot
.914 .52628 Mdot
.914 .5263 Mdot
.914 .52655 Mdot
.914 .52655 Mdot
.914 .52666 Mdot
.914 .52678 Mdot
.914 .52679 Mdot
.914 .52679 Mdot
.914 .52684 Mdot
.914 .52685 Mdot
.914 .52688 Mdot
.914 .52701 Mdot
.914 .52706 Mdot
.914 .52728 Mdot
.914 .52732 Mdot
.914 .52783 Mdot
.914 .52823 Mdot
.914 .52827 Mdot
.914 .52828 Mdot
.914 .52829 Mdot
.914 .5283 Mdot
.914 .5283 Mdot
.914 .52834 Mdot
.914 .52834 Mdot
.914 .52836 Mdot
.914 .52842 Mdot
.914 .52846 Mdot
.914 .52848 Mdot
.914 .52882 Mdot
.914 .52883 Mdot
.914 .52886 Mdot
.914 .52888 Mdot
.914 .52888 Mdot
.914 .52892 Mdot
.914 .52899 Mdot
.914 .52903 Mdot
.914 .52906 Mdot
.914 .52906 Mdot
.914 .52912 Mdot
.914 .52914 Mdot
.914 .52914 Mdot
.914 .52932 Mdot
.914 .52934 Mdot
.914 .52937 Mdot
.914 .52939 Mdot
.914 .52945 Mdot
.914 .52958 Mdot
.914 .5296 Mdot
.914 .52962 Mdot
.914 .52968 Mdot
.914 .52993 Mdot
.914 .52994 Mdot
.914 .52995 Mdot
.914 .52999 Mdot
.914 .53 Mdot
.914 .53011 Mdot
.914 .53012 Mdot
.914 .53022 Mdot
.914 .53023 Mdot
.914 .53032 Mdot
.914 .53036 Mdot
.914 .53053 Mdot
.914 .53058 Mdot
.914 .53059 Mdot
.914 .5306 Mdot
.914 .53087 Mdot
.914 .53096 Mdot
.914 .53101 Mdot
.914 .53109 Mdot
.914 .53114 Mdot
.914 .53124 Mdot
.914 .53125 Mdot
.914 .53138 Mdot
.914 .53148 Mdot
.914 .53148 Mdot
.914 .53157 Mdot
.914 .53165 Mdot
.914 .53178 Mdot
.914 .53188 Mdot
.914 .53198 Mdot
.914 .532 Mdot
.914 .53208 Mdot
.914 .53209 Mdot
.914 .53215 Mdot
.914 .53217 Mdot
.914 .53223 Mdot
.914 .53246 Mdot
.914 .5338 Mdot
.914 .53524 Mdot
.914 .53532 Mdot
.914 .53585 Mdot
.914 .53728 Mdot
.914 .53738 Mdot
.914 .53794 Mdot
.914 .53857 Mdot
.914 .53915 Mdot
.914 .5394 Mdot
.914 .54081 Mdot
.914 .54185 Mdot
.914 .54186 Mdot
.914 .54239 Mdot
.914 .54249 Mdot
.914 .54301 Mdot
.914 .54319 Mdot
.914 .5438 Mdot
.914 .54392 Mdot
.914 .54475 Mdot
.914 .545 Mdot
.914 .54543 Mdot
.914 .54841 Mdot
.914 .54989 Mdot
.914 .55036 Mdot
.914 .55052 Mdot
.914 .55075 Mdot
.914 .55076 Mdot
.914 .55096 Mdot
.914 .55124 Mdot
.914 .55165 Mdot
.914 .55167 Mdot
.914 .55192 Mdot
.914 .55216 Mdot
.914 .55217 Mdot
.914 .55242 Mdot
.914 .55249 Mdot
.914 .55252 Mdot
.914 .55261 Mdot
.914 .55263 Mdot
.914 .5528 Mdot
.914 .55281 Mdot
.914 .55285 Mdot
.914 .55288 Mdot
.916 .12379 Mdot
.916 .12409 Mdot
.916 .12485 Mdot
.916 .12497 Mdot
.916 .12529 Mdot
.916 .12545 Mdot
.916 .12623 Mdot
.916 .12643 Mdot
.916 .12655 Mdot
.916 .12729 Mdot
.916 .12871 Mdot
.916 .13071 Mdot
.916 .13679 Mdot
.916 .14024 Mdot
.916 .14586 Mdot
.916 .14924 Mdot
.916 .15051 Mdot
.916 .15069 Mdot
.916 .15158 Mdot
.916 .15599 Mdot
.916 .17134 Mdot
.916 .17935 Mdot
.916 .19086 Mdot
.916 .19781 Mdot
.916 .19928 Mdot
.916 .203 Mdot
.916 .20356 Mdot
.916 .20515 Mdot
.916 .20595 Mdot
.916 .20631 Mdot
.916 .20648 Mdot
.916 .20704 Mdot
.916 .20743 Mdot
.916 .2082 Mdot
.916 .20958 Mdot
.916 .20981 Mdot
.916 .21076 Mdot
.916 .21077 Mdot
.916 .21135 Mdot
.916 .21389 Mdot
.916 .21505 Mdot
.916 .21519 Mdot
.916 .21529 Mdot
.916 .21626 Mdot
.916 .21741 Mdot
.916 .21894 Mdot
.916 .22027 Mdot
.916 .22049 Mdot
.916 .22145 Mdot
.916 .22146 Mdot
.916 .22213 Mdot
.916 .22272 Mdot
.916 .22543 Mdot
.916 .22737 Mdot
.916 .22809 Mdot
.916 .22837 Mdot
.916 .22838 Mdot
.916 .22926 Mdot
.916 .23109 Mdot
.916 .23186 Mdot
.916 .23189 Mdot
.916 .23199 Mdot
.916 .23215 Mdot
.916 .23217 Mdot
.916 .23227 Mdot
.916 .2332 Mdot
.916 .23365 Mdot
.916 .23603 Mdot
.916 .2366 Mdot
.916 .23711 Mdot
.916 .23854 Mdot
.916 .2392 Mdot
.916 .23932 Mdot
.916 .24018 Mdot
.916 .24069 Mdot
.916 .24126 Mdot
.916 .24141 Mdot
.916 .24217 Mdot
.916 .24238 Mdot
.916 .24283 Mdot
.916 .24326 Mdot
.916 .24339 Mdot
.916 .24355 Mdot
.916 .2439 Mdot
.916 .2441 Mdot
.916 .24432 Mdot
.916 .2444 Mdot
.916 .2445 Mdot
.916 .24454 Mdot
.916 .24459 Mdot
.916 .24462 Mdot
.916 .24472 Mdot
.916 .24488 Mdot
.916 .24502 Mdot
.916 .24507 Mdot
.916 .2451 Mdot
.916 .24544 Mdot
.916 .24564 Mdot
.916 .24576 Mdot
.916 .24607 Mdot
.916 .24619 Mdot
.916 .24644 Mdot
.916 .24664 Mdot
.916 .24696 Mdot
.916 .24738 Mdot
.916 .2477 Mdot
.916 .24785 Mdot
.916 .24794 Mdot
.916 .24794 Mdot
.916 .24798 Mdot
.916 .2481 Mdot
.916 .24824 Mdot
.916 .24834 Mdot
.916 .24836 Mdot
.916 .24855 Mdot
.916 .24855 Mdot
.916 .24859 Mdot
.916 .24859 Mdot
.916 .24863 Mdot
.916 .24864 Mdot
.916 .24865 Mdot
.916 .24874 Mdot
.916 .24883 Mdot
.916 .24884 Mdot
.916 .24892 Mdot
.916 .24892 Mdot
.916 .24915 Mdot
.916 .24923 Mdot
.916 .24935 Mdot
.916 .24944 Mdot
.916 .2495 Mdot
.916 .2496 Mdot
.916 .24962 Mdot
.916 .24966 Mdot
.916 .24975 Mdot
.916 .2499 Mdot
.916 .25047 Mdot
.916 .25049 Mdot
.916 .25052 Mdot
.916 .25053 Mdot
.916 .2507 Mdot
.916 .25072 Mdot
.916 .25076 Mdot
.916 .2509 Mdot
.916 .2509 Mdot
.916 .25091 Mdot
.916 .25091 Mdot
.916 .25093 Mdot
.916 .251 Mdot
.916 .25116 Mdot
.916 .25119 Mdot
.916 .25129 Mdot
.916 .25144 Mdot
.916 .25153 Mdot
.916 .25165 Mdot
.916 .25169 Mdot
.916 .25175 Mdot
.916 .2518 Mdot
.916 .25189 Mdot
.916 .25194 Mdot
.916 .25196 Mdot
.916 .25206 Mdot
.916 .25209 Mdot
.916 .25235 Mdot
.916 .2524 Mdot
.916 .25242 Mdot
.916 .25243 Mdot
.916 .25244 Mdot
.916 .25247 Mdot
.916 .25249 Mdot
.916 .25249 Mdot
.916 .25251 Mdot
.916 .25251 Mdot
.916 .25251 Mdot
.916 .25253 Mdot
.916 .25254 Mdot
.916 .25255 Mdot
.916 .25256 Mdot
.916 .25257 Mdot
.916 .25259 Mdot
.916 .25263 Mdot
.916 .25266 Mdot
.916 .25267 Mdot
.916 .25267 Mdot
.916 .25268 Mdot
.916 .25269 Mdot
.916 .25271 Mdot
.916 .25273 Mdot
.916 .25276 Mdot
.916 .25277 Mdot
.916 .25286 Mdot
.916 .25288 Mdot
.916 .2529 Mdot
.916 .2529 Mdot
.916 .25291 Mdot
.916 .25295 Mdot
.916 .25297 Mdot
.916 .25299 Mdot
.916 .25301 Mdot
.916 .25303 Mdot
.916 .25304 Mdot
.916 .25307 Mdot
.916 .25312 Mdot
.916 .25315 Mdot
.916 .25318 Mdot
.916 .25318 Mdot
.916 .25318 Mdot
.916 .2532 Mdot
.916 .25325 Mdot
.916 .25331 Mdot
.916 .25332 Mdot
.916 .25336 Mdot
.916 .25336 Mdot
.916 .25339 Mdot
.916 .25339 Mdot
.916 .25342 Mdot
.916 .25343 Mdot
.916 .25344 Mdot
.916 .25346 Mdot
.916 .25348 Mdot
.916 .25348 Mdot
.916 .25356 Mdot
.916 .25358 Mdot
.916 .2536 Mdot
.916 .2536 Mdot
.916 .25361 Mdot
.916 .25366 Mdot
.916 .25368 Mdot
.916 .25369 Mdot
.916 .2537 Mdot
.916 .2537 Mdot
.916 .25377 Mdot
.916 .25384 Mdot
.916 .25387 Mdot
.916 .2539 Mdot
.916 .2539 Mdot
.916 .25394 Mdot
.916 .25394 Mdot
.916 .25403 Mdot
.916 .25403 Mdot
.916 .25403 Mdot
.916 .25404 Mdot
.916 .25408 Mdot
.916 .25408 Mdot
.916 .25409 Mdot
.916 .2541 Mdot
.916 .2541 Mdot
.916 .2541 Mdot
.916 .25411 Mdot
.916 .25413 Mdot
.916 .25414 Mdot
.916 .25415 Mdot
.916 .25416 Mdot
.916 .25416 Mdot
.916 .25416 Mdot
.916 .25416 Mdot
.916 .25417 Mdot
.916 .25418 Mdot
.916 .25419 Mdot
.916 .25419 Mdot
.916 .25419 Mdot
.916 .25419 Mdot
.916 .2542 Mdot
.916 .2542 Mdot
.916 .2542 Mdot
.916 .25421 Mdot
.916 .25421 Mdot
.916 .25421 Mdot
.916 .25422 Mdot
.916 .25422 Mdot
.916 .26184 Mdot
.916 .26527 Mdot
.916 .27765 Mdot
.916 .28725 Mdot
.916 .28877 Mdot
.916 .30074 Mdot
.916 .31261 Mdot
.916 .314 Mdot
.916 .314 Mdot
.916 .31402 Mdot
.916 .31402 Mdot
.916 .31403 Mdot
.916 .31404 Mdot
.916 .31404 Mdot
.916 .31411 Mdot
.916 .31414 Mdot
.916 .31427 Mdot
.916 .31435 Mdot
.916 .31438 Mdot
.916 .31442 Mdot
.916 .31444 Mdot
.916 .31448 Mdot
.916 .31455 Mdot
.916 .3148 Mdot
.916 .31481 Mdot
.916 .31482 Mdot
.916 .31491 Mdot
.916 .31492 Mdot
.916 .31501 Mdot
.916 .31501 Mdot
.916 .31502 Mdot
.916 .31505 Mdot
.916 .31528 Mdot
.916 .31533 Mdot
.916 .31542 Mdot
.916 .31548 Mdot
.916 .31556 Mdot
.916 .31557 Mdot
.916 .31581 Mdot
.916 .31584 Mdot
.916 .31607 Mdot
.916 .31628 Mdot
.916 .31654 Mdot
.916 .31658 Mdot
.916 .31664 Mdot
.916 .31664 Mdot
.916 .31666 Mdot
.916 .31678 Mdot
.916 .31694 Mdot
.916 .31717 Mdot
.916 .31742 Mdot
.916 .31767 Mdot
.916 .31776 Mdot
.916 .31777 Mdot
.916 .31783 Mdot
.916 .31809 Mdot
.916 .31845 Mdot
.916 .31852 Mdot
.916 .31861 Mdot
.916 .31881 Mdot
.916 .31916 Mdot
.916 .31924 Mdot
.916 .31955 Mdot
.916 .31981 Mdot
.916 .3199 Mdot
.916 .31991 Mdot
.916 .32002 Mdot
.916 .32003 Mdot
.916 .32206 Mdot
.916 .32231 Mdot
.916 .32243 Mdot
.916 .32318 Mdot
.916 .32332 Mdot
.916 .32334 Mdot
.916 .32337 Mdot
.916 .32349 Mdot
.916 .32358 Mdot
.916 .32407 Mdot
.916 .32434 Mdot
.916 .32452 Mdot
.916 .32454 Mdot
.916 .32467 Mdot
.916 .32495 Mdot
.916 .32515 Mdot
.916 .32581 Mdot
.916 .32583 Mdot
.916 .32586 Mdot
.916 .32587 Mdot
.916 .326 Mdot
.916 .32643 Mdot
.916 .32643 Mdot
.916 .32742 Mdot
.916 .32758 Mdot
.916 .32823 Mdot
.916 .32876 Mdot
.916 .3289 Mdot
.916 .32906 Mdot
.916 .32919 Mdot
.916 .3296 Mdot
.916 .32971 Mdot
.916 .33047 Mdot
.916 .33076 Mdot
.916 .33091 Mdot
.916 .33111 Mdot
.916 .33131 Mdot
.916 .33144 Mdot
.916 .33199 Mdot
.916 .33228 Mdot
.916 .33238 Mdot
.916 .33256 Mdot
.916 .33298 Mdot
.916 .3332 Mdot
.916 .33328 Mdot
.916 .33463 Mdot
.916 .33475 Mdot
.916 .33495 Mdot
.916 .335 Mdot
.916 .33511 Mdot
.916 .33521 Mdot
.916 .33524 Mdot
.916 .33541 Mdot
.916 .33553 Mdot
.916 .33555 Mdot
.916 .33557 Mdot
.916 .33561 Mdot
.916 .33565 Mdot
.916 .33567 Mdot
.916 .33576 Mdot
.916 .33582 Mdot
.916 .33585 Mdot
.916 .33594 Mdot
.916 .33597 Mdot
.916 .33604 Mdot
.916 .3361 Mdot
.916 .33619 Mdot
.916 .33632 Mdot
.916 .33647 Mdot
.916 .3365 Mdot
.916 .33651 Mdot
.916 .3366 Mdot
.916 .33663 Mdot
.916 .33664 Mdot
.916 .33677 Mdot
.916 .33683 Mdot
.916 .33699 Mdot
.916 .33708 Mdot
.916 .33755 Mdot
.916 .33762 Mdot
.916 .33762 Mdot
.916 .33773 Mdot
.916 .33775 Mdot
.916 .3378 Mdot
.916 .33797 Mdot
.916 .33803 Mdot
.916 .3381 Mdot
.916 .33821 Mdot
.916 .3384 Mdot
.916 .33847 Mdot
.916 .33858 Mdot
.916 .3387 Mdot
.916 .33885 Mdot
.916 .339 Mdot
.916 .3391 Mdot
.916 .33912 Mdot
.916 .33912 Mdot
.916 .33921 Mdot
.916 .3394 Mdot
.916 .33943 Mdot
.916 .33944 Mdot
.916 .33969 Mdot
.916 .33976 Mdot
.916 .33993 Mdot
.916 .33994 Mdot
.916 .34007 Mdot
.916 .34007 Mdot
.916 .3402 Mdot
.916 .34022 Mdot
.916 .34028 Mdot
.916 .34037 Mdot
.916 .34044 Mdot
.916 .34044 Mdot
.916 .34079 Mdot
.916 .34086 Mdot
.916 .34092 Mdot
.916 .34096 Mdot
.916 .34098 Mdot
.916 .34099 Mdot
.916 .34117 Mdot
.916 .34126 Mdot
.916 .34128 Mdot
.916 .34132 Mdot
.916 .34133 Mdot
.916 .34144 Mdot
.916 .34158 Mdot
.916 .34183 Mdot
.916 .34194 Mdot
.916 .34202 Mdot
.916 .34203 Mdot
.916 .34204 Mdot
.916 .34216 Mdot
.916 .34218 Mdot
.916 .34244 Mdot
.916 .34244 Mdot
.916 .34246 Mdot
.916 .34248 Mdot
.916 .34259 Mdot
.916 .34261 Mdot
.916 .34263 Mdot
.916 .34265 Mdot
.916 .34266 Mdot
.916 .34266 Mdot
.916 .34268 Mdot
.916 .34276 Mdot
.916 .34277 Mdot
.916 .3428 Mdot
.916 .34282 Mdot
.916 .34283 Mdot
.916 .34283 Mdot
.916 .34284 Mdot
.916 .34286 Mdot
.916 .34289 Mdot
.916 .3429 Mdot
.916 .34291 Mdot
.916 .34292 Mdot
.916 .34292 Mdot
.916 .34293 Mdot
.916 .34294 Mdot
.916 .34294 Mdot
.916 .34295 Mdot
.916 .34295 Mdot
.916 .34297 Mdot
.916 .34299 Mdot
.916 .34299 Mdot
.916 .34323 Mdot
.916 .34403 Mdot
.916 .34508 Mdot
.916 .35101 Mdot
.916 .35231 Mdot
.916 .3538 Mdot
.916 .35627 Mdot
.916 .35945 Mdot
.916 .36225 Mdot
.916 .36335 Mdot
.916 .36339 Mdot
.916 .36444 Mdot
.916 .3669 Mdot
.916 .37386 Mdot
.916 .37457 Mdot
.916 .37791 Mdot
.916 .37802 Mdot
.916 .37832 Mdot
.916 .37845 Mdot
.916 .37916 Mdot
.916 .37923 Mdot
.916 .37967 Mdot
.916 .38384 Mdot
.916 .38551 Mdot
.916 .38587 Mdot
.916 .39546 Mdot
.916 .39691 Mdot
.916 .39905 Mdot
.916 .39961 Mdot
.916 .40203 Mdot
.916 .40898 Mdot
.916 .41219 Mdot
.916 .41273 Mdot
.916 .4128 Mdot
.916 .41701 Mdot
.916 .41955 Mdot
.916 .42237 Mdot
.916 .42313 Mdot
.916 .42528 Mdot
.916 .4269 Mdot
.916 .42793 Mdot
.916 .43021 Mdot
.916 .43233 Mdot
.916 .43301 Mdot
.916 .4338 Mdot
.916 .43556 Mdot
.916 .43652 Mdot
.916 .43764 Mdot
.916 .43802 Mdot
.916 .43853 Mdot
.916 .43876 Mdot
.916 .43899 Mdot
.916 .43911 Mdot
.916 .43963 Mdot
.916 .44042 Mdot
.916 .44114 Mdot
.916 .44138 Mdot
.916 .44151 Mdot
.916 .44324 Mdot
.916 .44421 Mdot
.916 .44481 Mdot
.916 .4463 Mdot
.916 .44637 Mdot
.916 .44664 Mdot
.916 .44693 Mdot
.916 .44818 Mdot
.916 .44919 Mdot
.916 .44931 Mdot
.916 .45075 Mdot
.916 .45283 Mdot
.916 .45443 Mdot
.916 .45516 Mdot
.916 .45559 Mdot
.916 .45561 Mdot
.916 .45581 Mdot
.916 .45637 Mdot
.916 .45708 Mdot
.916 .45758 Mdot
.916 .45765 Mdot
.916 .45857 Mdot
.916 .4586 Mdot
.916 .45878 Mdot
.916 .4588 Mdot
.916 .45899 Mdot
.916 .45901 Mdot
.916 .45908 Mdot
.916 .4595 Mdot
.916 .45997 Mdot
.916 .45999 Mdot
.916 .46037 Mdot
.916 .46041 Mdot
.916 .46152 Mdot
.916 .46189 Mdot
.916 .46247 Mdot
.916 .46293 Mdot
.916 .46321 Mdot
.916 .46366 Mdot
.916 .46376 Mdot
.916 .46396 Mdot
.916 .46438 Mdot
.916 .46501 Mdot
.916 .46514 Mdot
.916 .46785 Mdot
.916 .46796 Mdot
.916 .4681 Mdot
.916 .46817 Mdot
.916 .46893 Mdot
.916 .46904 Mdot
.916 .46925 Mdot
.916 .46992 Mdot
.916 .46993 Mdot
.916 .46995 Mdot
.916 .46997 Mdot
.916 .47007 Mdot
.916 .47039 Mdot
.916 .47114 Mdot
.916 .47126 Mdot
.916 .47175 Mdot
.916 .47247 Mdot
.916 .47286 Mdot
.916 .47343 Mdot
.916 .47365 Mdot
.916 .47391 Mdot
.916 .47416 Mdot
.916 .47458 Mdot
.916 .4748 Mdot
.916 .47489 Mdot
.916 .47534 Mdot
.916 .47552 Mdot
.916 .47673 Mdot
.916 .47694 Mdot
.916 .47702 Mdot
.916 .4771 Mdot
.916 .47713 Mdot
.916 .47727 Mdot
.916 .47736 Mdot
.916 .47738 Mdot
.916 .47744 Mdot
.916 .47747 Mdot
.916 .47748 Mdot
.916 .47756 Mdot
.916 .4776 Mdot
.916 .47763 Mdot
.916 .4777 Mdot
.916 .47773 Mdot
.916 .47784 Mdot
.916 .47802 Mdot
.916 .47815 Mdot
.916 .47817 Mdot
.916 .47819 Mdot
.916 .47826 Mdot
.916 .47829 Mdot
.916 .4784 Mdot
.916 .47846 Mdot
.916 .47859 Mdot
.916 .47868 Mdot
.916 .47909 Mdot
.916 .47914 Mdot
.916 .47925 Mdot
.916 .47926 Mdot
.916 .4793 Mdot
.916 .47946 Mdot
.916 .47958 Mdot
.916 .47968 Mdot
.916 .47986 Mdot
.916 .47992 Mdot
.916 .48002 Mdot
.916 .48028 Mdot
.916 .48042 Mdot
.916 .48052 Mdot
.916 .48054 Mdot
.916 .48054 Mdot
.916 .48062 Mdot
.916 .48085 Mdot
.916 .48111 Mdot
.916 .48118 Mdot
.916 .48134 Mdot
.916 .48136 Mdot
.916 .4815 Mdot
.916 .4815 Mdot
.916 .48164 Mdot
.916 .48166 Mdot
.916 .48171 Mdot
.916 .48182 Mdot
.916 .48189 Mdot
.916 .48189 Mdot
.916 .48228 Mdot
.916 .48236 Mdot
.916 .48243 Mdot
.916 .48247 Mdot
.916 .48251 Mdot
.916 .48272 Mdot
.916 .48282 Mdot
.916 .48284 Mdot
.916 .48289 Mdot
.916 .48291 Mdot
.916 .48321 Mdot
.916 .48353 Mdot
.916 .48368 Mdot
.916 .48378 Mdot
.916 .48379 Mdot
.916 .48398 Mdot
.916 .484 Mdot
.916 .48437 Mdot
.916 .48437 Mdot
.916 .4844 Mdot
.916 .48444 Mdot
.916 .4846 Mdot
.916 .48462 Mdot
.916 .48466 Mdot
.916 .4847 Mdot
.916 .48471 Mdot
.916 .48471 Mdot
.916 .48474 Mdot
.916 .48486 Mdot
.916 .48488 Mdot
.916 .48492 Mdot
.916 .48495 Mdot
.916 .48498 Mdot
.916 .48498 Mdot
.916 .48499 Mdot
.916 .48502 Mdot
.916 .48506 Mdot
.916 .48509 Mdot
.916 .4851 Mdot
.916 .48511 Mdot
.916 .48512 Mdot
.916 .48513 Mdot
.916 .48515 Mdot
.916 .48516 Mdot
.916 .48518 Mdot
.916 .48518 Mdot
.916 .4852 Mdot
.916 .48524 Mdot
.916 .48524 Mdot
.916 .49655 Mdot
.916 .50634 Mdot
.916 .50853 Mdot
.916 .51602 Mdot
.916 .51639 Mdot
.916 .52133 Mdot
.916 .52366 Mdot
.916 .52366 Mdot
.916 .52366 Mdot
.916 .52366 Mdot
.916 .52366 Mdot
.916 .52366 Mdot
.916 .52366 Mdot
.916 .52366 Mdot
.916 .52366 Mdot
.916 .52366 Mdot
.916 .52366 Mdot
.916 .52366 Mdot
.916 .52367 Mdot
.916 .52367 Mdot
.916 .52367 Mdot
.916 .52367 Mdot
.916 .52367 Mdot
.916 .52367 Mdot
.916 .52367 Mdot
.916 .52367 Mdot
.916 .52368 Mdot
.916 .52368 Mdot
.916 .52368 Mdot
.916 .52368 Mdot
.916 .52368 Mdot
.916 .52368 Mdot
.916 .52369 Mdot
.916 .52369 Mdot
.916 .52369 Mdot
.916 .5237 Mdot
.916 .5237 Mdot
.916 .5237 Mdot
.916 .52372 Mdot
.916 .52372 Mdot
.916 .52372 Mdot
.916 .52373 Mdot
.916 .52373 Mdot
.916 .52374 Mdot
.916 .52375 Mdot
.916 .52377 Mdot
.916 .52377 Mdot
.916 .52377 Mdot
.916 .52377 Mdot
.916 .52377 Mdot
.916 .52378 Mdot
.916 .52379 Mdot
.916 .52379 Mdot
.916 .52379 Mdot
.916 .52379 Mdot
.916 .52381 Mdot
.916 .52381 Mdot
.916 .52382 Mdot
.916 .52382 Mdot
.916 .52382 Mdot
.916 .52382 Mdot
.916 .52383 Mdot
.916 .52383 Mdot
.916 .52384 Mdot
.916 .52384 Mdot
.916 .52384 Mdot
.916 .52385 Mdot
.916 .52386 Mdot
.916 .52387 Mdot
.916 .52387 Mdot
.916 .52387 Mdot
.916 .52387 Mdot
.916 .52388 Mdot
.916 .52388 Mdot
.916 .5239 Mdot
.916 .5239 Mdot
.916 .5239 Mdot
.916 .52391 Mdot
.916 .52391 Mdot
.916 .52392 Mdot
.916 .52392 Mdot
.916 .52393 Mdot
.916 .52393 Mdot
.916 .52393 Mdot
.916 .52394 Mdot
.916 .52394 Mdot
.916 .52396 Mdot
.916 .52396 Mdot
.916 .52397 Mdot
.916 .52397 Mdot
.916 .52397 Mdot
.916 .52398 Mdot
.916 .52398 Mdot
.916 .52398 Mdot
.916 .52398 Mdot
.916 .52399 Mdot
.916 .52399 Mdot
.916 .524 Mdot
.916 .524 Mdot
.916 .524 Mdot
.916 .524 Mdot
.916 .52401 Mdot
.916 .52401 Mdot
.916 .52401 Mdot
.916 .52401 Mdot
.916 .52401 Mdot
.916 .52402 Mdot
.916 .52402 Mdot
.916 .52403 Mdot
.916 .52403 Mdot
.916 .52403 Mdot
.916 .52403 Mdot
.916 .52404 Mdot
.916 .5241 Mdot
.916 .52411 Mdot
.916 .52413 Mdot
.916 .52413 Mdot
.916 .52414 Mdot
.916 .52416 Mdot
.916 .52417 Mdot
.916 .52418 Mdot
.916 .52419 Mdot
.916 .52421 Mdot
.916 .52423 Mdot
.916 .52426 Mdot
.916 .52428 Mdot
.916 .52429 Mdot
.916 .52432 Mdot
.916 .52434 Mdot
.916 .52434 Mdot
.916 .52434 Mdot
.916 .52434 Mdot
.916 .52434 Mdot
.916 .52437 Mdot
.916 .52438 Mdot
.916 .52439 Mdot
.916 .52442 Mdot
.916 .52442 Mdot
.916 .52443 Mdot
.916 .52443 Mdot
.916 .52455 Mdot
.916 .52458 Mdot
.916 .5246 Mdot
.916 .52461 Mdot
.916 .52461 Mdot
.916 .52463 Mdot
.916 .52464 Mdot
.916 .52466 Mdot
.916 .52469 Mdot
.916 .52475 Mdot
.916 .52475 Mdot
.916 .52477 Mdot
.916 .52477 Mdot
.916 .52479 Mdot
.916 .5248 Mdot
.916 .52481 Mdot
.916 .52481 Mdot
.916 .52482 Mdot
.916 .52482 Mdot
.916 .52482 Mdot
.916 .52483 Mdot
.916 .52486 Mdot
.916 .52487 Mdot
.916 .52489 Mdot
.916 .52492 Mdot
.916 .52494 Mdot
.916 .52495 Mdot
.916 .52495 Mdot
.916 .52497 Mdot
.916 .525 Mdot
.916 .52507 Mdot
.916 .52515 Mdot
.916 .52522 Mdot
.916 .52526 Mdot
.916 .52531 Mdot
.916 .52533 Mdot
.916 .5254 Mdot
.916 .52542 Mdot
.916 .52546 Mdot
.916 .52553 Mdot
.916 .52554 Mdot
.916 .52555 Mdot
.916 .52557 Mdot
.916 .52561 Mdot
.916 .52563 Mdot
.916 .52563 Mdot
.916 .52564 Mdot
.916 .52565 Mdot
.916 .52567 Mdot
.916 .52569 Mdot
.916 .52573 Mdot
.916 .52577 Mdot
.916 .52584 Mdot
.916 .52588 Mdot
.916 .5259 Mdot
.916 .52599 Mdot
.916 .52608 Mdot
.916 .52612 Mdot
.916 .52628 Mdot
.916 .52631 Mdot
.916 .52642 Mdot
.916 .52653 Mdot
.916 .5267 Mdot
.916 .52672 Mdot
.916 .52686 Mdot
.916 .52715 Mdot
.916 .52725 Mdot
.916 .52736 Mdot
.916 .52784 Mdot
.916 .52793 Mdot
.916 .52812 Mdot
.916 .52814 Mdot
.916 .52818 Mdot
.916 .52819 Mdot
.916 .5282 Mdot
.916 .52835 Mdot
.916 .52872 Mdot
.916 .5289 Mdot
.916 .5289 Mdot
.916 .52896 Mdot
.916 .5291 Mdot
.916 .52949 Mdot
.916 .53003 Mdot
.916 .53028 Mdot
.916 .53028 Mdot
.916 .53048 Mdot
.916 .53052 Mdot
.916 .53079 Mdot
.916 .53109 Mdot
.916 .53133 Mdot
.916 .53152 Mdot
.916 .53154 Mdot
.916 .5318 Mdot
.916 .53243 Mdot
.916 .53267 Mdot
.916 .53295 Mdot
.916 .5331 Mdot
.916 .53318 Mdot
.916 .5333 Mdot
.916 .53333 Mdot
.916 .53651 Mdot
.916 .53896 Mdot
.916 .54073 Mdot
.916 .54435 Mdot
.916 .54547 Mdot
.916 .5457 Mdot
.916 .54574 Mdot
.916 .54608 Mdot
.916 .54698 Mdot
.916 .54856 Mdot
.916 .54958 Mdot
.916 .55152 Mdot
.916 .5522 Mdot
.916 .5527 Mdot
.916 .55297 Mdot
.916 .55301 Mdot
.916 .55308 Mdot
.916 .55337 Mdot
.916 .55343 Mdot
.916 .55356 Mdot
.916 .5536 Mdot
.916 .55389 Mdot
.916 .55401 Mdot
.918 .24915 Mdot
.918 .24934 Mdot
.918 .31809 Mdot
.918 .31892 Mdot
.918 .46248 Mdot
.918 .46339 Mdot
.918 .52477 Mdot
.918 .52481 Mdot
.92 .11855 Mdot
.92 .11866 Mdot
.92 .11869 Mdot
.92 .11871 Mdot
.92 .11879 Mdot
.92 .11889 Mdot
.92 .11894 Mdot
.92 .11913 Mdot
.92 .11933 Mdot
.92 .11934 Mdot
.92 .11958 Mdot
.92 .12002 Mdot
.92 .12015 Mdot
.92 .12033 Mdot
.92 .12057 Mdot
.92 .12084 Mdot
.92 .12086 Mdot
.92 .12138 Mdot
.92 .12178 Mdot
.92 .12183 Mdot
.92 .1222 Mdot
.92 .12223 Mdot
.92 .1227 Mdot
.92 .12352 Mdot
.92 .12392 Mdot
.92 .12406 Mdot
.92 .12415 Mdot
.92 .12461 Mdot
.92 .12501 Mdot
.92 .1253 Mdot
.92 .12556 Mdot
.92 .12558 Mdot
.92 .1256 Mdot
.92 .12571 Mdot
.92 .12583 Mdot
.92 .12655 Mdot
.92 .12779 Mdot
.92 .1283 Mdot
.92 .12896 Mdot
.92 .1293 Mdot
.92 .13017 Mdot
.92 .13093 Mdot
.92 .13107 Mdot
.92 .13243 Mdot
.92 .13529 Mdot
.92 .13623 Mdot
.92 .13672 Mdot
.92 .1368 Mdot
.92 .1373 Mdot
.92 .13754 Mdot
.92 .13759 Mdot
.92 .1376 Mdot
.92 .13779 Mdot
.92 .14372 Mdot
.92 .14482 Mdot
.92 .14676 Mdot
.92 .15041 Mdot
.92 .15044 Mdot
.92 .15095 Mdot
.92 .15209 Mdot
.92 .15443 Mdot
.92 .15624 Mdot
.92 .16386 Mdot
.92 .16393 Mdot
.92 .16421 Mdot
.92 .16549 Mdot
.92 .16868 Mdot
.92 .17394 Mdot
.92 .1744 Mdot
.92 .17455 Mdot
.92 .17467 Mdot
.92 .17499 Mdot
.92 .17548 Mdot
.92 .17567 Mdot
.92 .17654 Mdot
.92 .17746 Mdot
.92 .17748 Mdot
.92 .17797 Mdot
.92 .17861 Mdot
.92 .17869 Mdot
.92 .18056 Mdot
.92 .18063 Mdot
.92 .18123 Mdot
.92 .18202 Mdot
.92 .18205 Mdot
.92 .18321 Mdot
.92 .18328 Mdot
.92 .18444 Mdot
.92 .18454 Mdot
.92 .187 Mdot
.92 .1889 Mdot
.92 .18913 Mdot
.92 .1909 Mdot
.92 .19106 Mdot
.92 .19294 Mdot
.92 .1933 Mdot
.92 .19336 Mdot
.92 .19357 Mdot
.92 .19434 Mdot
.92 .19581 Mdot
.92 .19729 Mdot
.92 .1974 Mdot
.92 .19776 Mdot
.92 .19819 Mdot
.92 .19923 Mdot
.92 .19991 Mdot
.92 .20019 Mdot
.92 .20037 Mdot
.92 .20061 Mdot
.92 .20064 Mdot
.92 .20262 Mdot
.92 .20332 Mdot
.92 .20419 Mdot
.92 .20461 Mdot
.92 .20474 Mdot
.92 .20499 Mdot
.92 .20544 Mdot
.92 .20574 Mdot
.92 .20583 Mdot
.92 .20598 Mdot
.92 .20603 Mdot
.92 .20732 Mdot
.92 .2074 Mdot
.92 .20753 Mdot
.92 .20803 Mdot
.92 .20863 Mdot
.92 .2092 Mdot
.92 .20967 Mdot
.92 .21222 Mdot
.92 .21252 Mdot
.92 .21448 Mdot
.92 .21456 Mdot
.92 .21469 Mdot
.92 .21472 Mdot
.92 .21748 Mdot
.92 .21838 Mdot
.92 .21843 Mdot
.92 .21893 Mdot
.92 .2192 Mdot
.92 .21928 Mdot
.92 .21967 Mdot
.92 .22057 Mdot
.92 .22097 Mdot
.92 .2212 Mdot
.92 .22179 Mdot
.92 .22261 Mdot
.92 .22368 Mdot
.92 .22431 Mdot
.92 .22555 Mdot
.92 .22601 Mdot
.92 .22689 Mdot
.92 .22755 Mdot
.92 .22775 Mdot
.92 .22786 Mdot
.92 .2283 Mdot
.92 .2284 Mdot
.92 .22903 Mdot
.92 .22935 Mdot
.92 .22938 Mdot
.92 .22952 Mdot
.92 .22968 Mdot
.92 .22983 Mdot
.92 .23 Mdot
.92 .23006 Mdot
.92 .23015 Mdot
.92 .23039 Mdot
.92 .23039 Mdot
.92 .2307 Mdot
.92 .23073 Mdot
.92 .23116 Mdot
.92 .23136 Mdot
.92 .23161 Mdot
.92 .23198 Mdot
.92 .2322 Mdot
.92 .23236 Mdot
.92 .23302 Mdot
.92 .23306 Mdot
.92 .23419 Mdot
.92 .23465 Mdot
.92 .23467 Mdot
.92 .23487 Mdot
.92 .23494 Mdot
.92 .2351 Mdot
.92 .23515 Mdot
.92 .23532 Mdot
.92 .23545 Mdot
.92 .23548 Mdot
.92 .23564 Mdot
.92 .23564 Mdot
.92 .23564 Mdot
.92 .2361 Mdot
.92 .23614 Mdot
.92 .23619 Mdot
.92 .23631 Mdot
.92 .23667 Mdot
.92 .23684 Mdot
.92 .23694 Mdot
.92 .23705 Mdot
.92 .23711 Mdot
.92 .2372 Mdot
.92 .23729 Mdot
.92 .23768 Mdot
.92 .23811 Mdot
.92 .23818 Mdot
.92 .2383 Mdot
.92 .23837 Mdot
.92 .23871 Mdot
.92 .23881 Mdot
.92 .23888 Mdot
.92 .23913 Mdot
.92 .2392 Mdot
.92 .23927 Mdot
.92 .23948 Mdot
.92 .23948 Mdot
.92 .23967 Mdot
.92 .23991 Mdot
.92 .24006 Mdot
.92 .24013 Mdot
.92 .2402 Mdot
.92 .24027 Mdot
.92 .2404 Mdot
.92 .2408 Mdot
.92 .24083 Mdot
.92 .24083 Mdot
.92 .24087 Mdot
.92 .24099 Mdot
.92 .24101 Mdot
.92 .24118 Mdot
.92 .24123 Mdot
.92 .24159 Mdot
.92 .24159 Mdot
.92 .2416 Mdot
.92 .24164 Mdot
.92 .24166 Mdot
.92 .24167 Mdot
.92 .2417 Mdot
.92 .24172 Mdot
.92 .24173 Mdot
.92 .24173 Mdot
.92 .24177 Mdot
.92 .24187 Mdot
.92 .24195 Mdot
.92 .24203 Mdot
.92 .24208 Mdot
.92 .24209 Mdot
.92 .24214 Mdot
.92 .24222 Mdot
.92 .24225 Mdot
.92 .2423 Mdot
.92 .24232 Mdot
.92 .24234 Mdot
.92 .24234 Mdot
.92 .24254 Mdot
.92 .24269 Mdot
.92 .24271 Mdot
.92 .24275 Mdot
.92 .24283 Mdot
.92 .24284 Mdot
.92 .24297 Mdot
.92 .2431 Mdot
.92 .24315 Mdot
.92 .24315 Mdot
.92 .2432 Mdot
.92 .24324 Mdot
.92 .24329 Mdot
.92 .24333 Mdot
.92 .24352 Mdot
.92 .24358 Mdot
.92 .24359 Mdot
.92 .24361 Mdot
.92 .24377 Mdot
.92 .24382 Mdot
.92 .2439 Mdot
.92 .24393 Mdot
.92 .24394 Mdot
.92 .24396 Mdot
.92 .24397 Mdot
.92 .24404 Mdot
.92 .24408 Mdot
.92 .24412 Mdot
.92 .24417 Mdot
.92 .24418 Mdot
.92 .24419 Mdot
.92 .2442 Mdot
.92 .24422 Mdot
.92 .24424 Mdot
.92 .24425 Mdot
.92 .24427 Mdot
.92 .24427 Mdot
.92 .24428 Mdot
.92 .24431 Mdot
.92 .24431 Mdot
.92 .24433 Mdot
.92 .24435 Mdot
.92 .24436 Mdot
.92 .24436 Mdot
.92 .24436 Mdot
.92 .24436 Mdot
.92 .24437 Mdot
.92 .25174 Mdot
.92 .2519 Mdot
.92 .25573 Mdot
.92 .25803 Mdot
.92 .26023 Mdot
.92 .2619 Mdot
.92 .26258 Mdot
.92 .26293 Mdot
.92 .26326 Mdot
.92 .26365 Mdot
.92 .26532 Mdot
.92 .26644 Mdot
.92 .26668 Mdot
.92 .26671 Mdot
.92 .26762 Mdot
.92 .26885 Mdot
.92 .27557 Mdot
.92 .27603 Mdot
.92 .27613 Mdot
.92 .27908 Mdot
.92 .27976 Mdot
.92 .29361 Mdot
.92 .2973 Mdot
.92 .29799 Mdot
.92 .30455 Mdot
.92 .30534 Mdot
.92 .30541 Mdot
.92 .30824 Mdot
.92 .31095 Mdot
.92 .3141 Mdot
.92 .31532 Mdot
.92 .31532 Mdot
.92 .31532 Mdot
.92 .31536 Mdot
.92 .31538 Mdot
.92 .3154 Mdot
.92 .31542 Mdot
.92 .31552 Mdot
.92 .3156 Mdot
.92 .31562 Mdot
.92 .31567 Mdot
.92 .31569 Mdot
.92 .31597 Mdot
.92 .31598 Mdot
.92 .31601 Mdot
.92 .31608 Mdot
.92 .31616 Mdot
.92 .31626 Mdot
.92 .3163 Mdot
.92 .3163 Mdot
.92 .31637 Mdot
.92 .31667 Mdot
.92 .31668 Mdot
.92 .31702 Mdot
.92 .3171 Mdot
.92 .31733 Mdot
.92 .31756 Mdot
.92 .31764 Mdot
.92 .31765 Mdot
.92 .31775 Mdot
.92 .31791 Mdot
.92 .31798 Mdot
.92 .31799 Mdot
.92 .31895 Mdot
.92 .3191 Mdot
.92 .31927 Mdot
.92 .31929 Mdot
.92 .32056 Mdot
.92 .3207 Mdot
.92 .32073 Mdot
.92 .32088 Mdot
.92 .3213 Mdot
.92 .32153 Mdot
.92 .32176 Mdot
.92 .32183 Mdot
.92 .32224 Mdot
.92 .3226 Mdot
.92 .32386 Mdot
.92 .3244 Mdot
.92 .32447 Mdot
.92 .32447 Mdot
.92 .32453 Mdot
.92 .32466 Mdot
.92 .32477 Mdot
.92 .32483 Mdot
.92 .32594 Mdot
.92 .32692 Mdot
.92 .32723 Mdot
.92 .32808 Mdot
.92 .32874 Mdot
.92 .32956 Mdot
.92 .32974 Mdot
.92 .33044 Mdot
.92 .33055 Mdot
.92 .33194 Mdot
.92 .33256 Mdot
.92 .33268 Mdot
.92 .33282 Mdot
.92 .33302 Mdot
.92 .33315 Mdot
.92 .33391 Mdot
.92 .33442 Mdot
.92 .33448 Mdot
.92 .33452 Mdot
.92 .33453 Mdot
.92 .33455 Mdot
.92 .3346 Mdot
.92 .33466 Mdot
.92 .33467 Mdot
.92 .33476 Mdot
.92 .33481 Mdot
.92 .33486 Mdot
.92 .33503 Mdot
.92 .33518 Mdot
.92 .33519 Mdot
.92 .33558 Mdot
.92 .33565 Mdot
.92 .3357 Mdot
.92 .33584 Mdot
.92 .33598 Mdot
.92 .33599 Mdot
.92 .33612 Mdot
.92 .33624 Mdot
.92 .33628 Mdot
.92 .33643 Mdot
.92 .33658 Mdot
.92 .33676 Mdot
.92 .3369 Mdot
.92 .33693 Mdot
.92 .33703 Mdot
.92 .33724 Mdot
.92 .3373 Mdot
.92 .33774 Mdot
.92 .33797 Mdot
.92 .33804 Mdot
.92 .33829 Mdot
.92 .3383 Mdot
.92 .33861 Mdot
.92 .33886 Mdot
.92 .33942 Mdot
.92 .33992 Mdot
.92 .34 Mdot
.92 .34007 Mdot
.92 .34015 Mdot
.92 .34023 Mdot
.92 .34032 Mdot
.92 .34052 Mdot
.92 .34089 Mdot
.92 .3409 Mdot
.92 .34137 Mdot
.92 .3414 Mdot
.92 .34165 Mdot
.92 .34181 Mdot
.92 .34199 Mdot
.92 .34216 Mdot
.92 .34225 Mdot
.92 .34242 Mdot
.92 .34244 Mdot
.92 .3428 Mdot
.92 .34299 Mdot
.92 .34314 Mdot
.92 .34351 Mdot
.92 .34374 Mdot
.92 .34382 Mdot
.92 .34384 Mdot
.92 .3439 Mdot
.92 .34391 Mdot
.92 .34393 Mdot
.92 .34411 Mdot
.92 .34423 Mdot
.92 .34432 Mdot
.92 .34458 Mdot
.92 .34492 Mdot
.92 .34501 Mdot
.92 .3453 Mdot
.92 .34542 Mdot
.92 .34545 Mdot
.92 .34562 Mdot
.92 .34569 Mdot
.92 .34583 Mdot
.92 .34583 Mdot
.92 .34588 Mdot
.92 .34598 Mdot
.92 .34612 Mdot
.92 .34686 Mdot
.92 .34778 Mdot
.92 .34988 Mdot
.92 .35005 Mdot
.92 .35061 Mdot
.92 .35149 Mdot
.92 .35231 Mdot
.92 .35304 Mdot
.92 .35312 Mdot
.92 .35408 Mdot
.92 .35421 Mdot
.92 .35588 Mdot
.92 .35632 Mdot
.92 .35885 Mdot
.92 .35907 Mdot
.92 .35912 Mdot
.92 .35913 Mdot
.92 .36052 Mdot
.92 .36133 Mdot
.92 .36166 Mdot
.92 .36166 Mdot
.92 .36243 Mdot
.92 .36286 Mdot
.92 .36311 Mdot
.92 .36456 Mdot
.92 .36461 Mdot
.92 .36498 Mdot
.92 .36754 Mdot
.92 .36867 Mdot
.92 .36869 Mdot
.92 .36881 Mdot
.92 .36895 Mdot
.92 .36915 Mdot
.92 .36943 Mdot
.92 .36951 Mdot
.92 .37021 Mdot
.92 .37052 Mdot
.92 .37081 Mdot
.92 .3711 Mdot
.92 .37151 Mdot
.92 .37176 Mdot
.92 .37216 Mdot
.92 .3728 Mdot
.92 .37313 Mdot
.92 .37314 Mdot
.92 .37381 Mdot
.92 .37416 Mdot
.92 .37445 Mdot
.92 .37458 Mdot
.92 .37525 Mdot
.92 .37643 Mdot
.92 .37688 Mdot
.92 .37731 Mdot
.92 .3784 Mdot
.92 .37868 Mdot
.92 .38002 Mdot
.92 .3807 Mdot
.92 .38099 Mdot
.92 .38158 Mdot
.92 .38163 Mdot
.92 .38168 Mdot
.92 .38194 Mdot
.92 .38236 Mdot
.92 .38308 Mdot
.92 .38332 Mdot
.92 .38367 Mdot
.92 .38463 Mdot
.92 .38465 Mdot
.92 .38475 Mdot
.92 .3848 Mdot
.92 .38481 Mdot
.92 .38905 Mdot
.92 .38994 Mdot
.92 .3921 Mdot
.92 .39217 Mdot
.92 .39311 Mdot
.92 .39312 Mdot
.92 .39341 Mdot
.92 .39417 Mdot
.92 .39418 Mdot
.92 .3944 Mdot
.92 .39522 Mdot
.92 .39584 Mdot
.92 .39595 Mdot
.92 .3967 Mdot
.92 .39672 Mdot
.92 .39673 Mdot
.92 .39692 Mdot
.92 .39811 Mdot
.92 .39868 Mdot
.92 .39889 Mdot
.92 .3991 Mdot
.92 .39934 Mdot
.92 .39987 Mdot
.92 .40159 Mdot
.92 .40165 Mdot
.92 .40244 Mdot
.92 .40253 Mdot
.92 .40254 Mdot
.92 .40291 Mdot
.92 .40331 Mdot
.92 .40345 Mdot
.92 .40374 Mdot
.92 .40415 Mdot
.92 .4046 Mdot
.92 .40587 Mdot
.92 .4065 Mdot
.92 .40857 Mdot
.92 .40891 Mdot
.92 .40948 Mdot
.92 .40986 Mdot
.92 .4115 Mdot
.92 .41203 Mdot
.92 .41237 Mdot
.92 .41282 Mdot
.92 .41357 Mdot
.92 .41394 Mdot
.92 .41408 Mdot
.92 .41429 Mdot
.92 .41529 Mdot
.92 .41529 Mdot
.92 .41603 Mdot
.92 .41624 Mdot
.92 .41745 Mdot
.92 .41779 Mdot
.92 .41817 Mdot
.92 .4185 Mdot
.92 .41887 Mdot
.92 .41923 Mdot
.92 .41962 Mdot
.92 .41988 Mdot
.92 .4213 Mdot
.92 .42183 Mdot
.92 .42199 Mdot
.92 .422 Mdot
.92 .42218 Mdot
.92 .4228 Mdot
.92 .42292 Mdot
.92 .42317 Mdot
.92 .42376 Mdot
.92 .42398 Mdot
.92 .42486 Mdot
.92 .4258 Mdot
.92 .42581 Mdot
.92 .42584 Mdot
.92 .42605 Mdot
.92 .42613 Mdot
.92 .42618 Mdot
.92 .42634 Mdot
.92 .42644 Mdot
.92 .42651 Mdot
.92 .42652 Mdot
.92 .42672 Mdot
.92 .42718 Mdot
.92 .42759 Mdot
.92 .42797 Mdot
.92 .42823 Mdot
.92 .42831 Mdot
.92 .42855 Mdot
.92 .42896 Mdot
.92 .4291 Mdot
.92 .42936 Mdot
.92 .42943 Mdot
.92 .42954 Mdot
.92 .42954 Mdot
.92 .43057 Mdot
.92 .43093 Mdot
.92 .43131 Mdot
.92 .43139 Mdot
.92 .4316 Mdot
.92 .43197 Mdot
.92 .43199 Mdot
.92 .43205 Mdot
.92 .43273 Mdot
.92 .43334 Mdot
.92 .43361 Mdot
.92 .43364 Mdot
.92 .43384 Mdot
.92 .43408 Mdot
.92 .43434 Mdot
.92 .4345 Mdot
.92 .43545 Mdot
.92 .43568 Mdot
.92 .43573 Mdot
.92 .43576 Mdot
.92 .43584 Mdot
.92 .4359 Mdot
.92 .43674 Mdot
.92 .43695 Mdot
.92 .43738 Mdot
.92 .4375 Mdot
.92 .43757 Mdot
.92 .43768 Mdot
.92 .43771 Mdot
.92 .43808 Mdot
.92 .43828 Mdot
.92 .43848 Mdot
.92 .43874 Mdot
.92 .43878 Mdot
.92 .43884 Mdot
.92 .4389 Mdot
.92 .43896 Mdot
.92 .43908 Mdot
.92 .43913 Mdot
.92 .43924 Mdot
.92 .43925 Mdot
.92 .43928 Mdot
.92 .43943 Mdot
.92 .43943 Mdot
.92 .43956 Mdot
.92 .43963 Mdot
.92 .43968 Mdot
.92 .43968 Mdot
.92 .43969 Mdot
.92 .4397 Mdot
.92 .43973 Mdot
.92 .44073 Mdot
.92 .44177 Mdot
.92 .44246 Mdot
.92 .44433 Mdot
.92 .44808 Mdot
.92 .45034 Mdot
.92 .45203 Mdot
.92 .45462 Mdot
.92 .4627 Mdot
.92 .46454 Mdot
.92 .4673 Mdot
.92 .46897 Mdot
.92 .47585 Mdot
.92 .47661 Mdot
.92 .47877 Mdot
.92 .48167 Mdot
.92 .48747 Mdot
.92 .48948 Mdot
.92 .4913 Mdot
.92 .49256 Mdot
.92 .49318 Mdot
.92 .49396 Mdot
.92 .4949 Mdot
.92 .49651 Mdot
.92 .49654 Mdot
.92 .49693 Mdot
.92 .50026 Mdot
.92 .5005 Mdot
.92 .50365 Mdot
.92 .50748 Mdot
.92 .50956 Mdot
.92 .5105 Mdot
.92 .51129 Mdot
.92 .51207 Mdot
.92 .51231 Mdot
.92 .51421 Mdot
.92 .5184 Mdot
.92 .51855 Mdot
.92 .51921 Mdot
.92 .51923 Mdot
.92 .51933 Mdot
.92 .5208 Mdot
.92 .52191 Mdot
.92 .52199 Mdot
.92 .52228 Mdot
.92 .52309 Mdot
.92 .52435 Mdot
.92 .52438 Mdot
.92 .52588 Mdot
.92 .52588 Mdot
.92 .52588 Mdot
.92 .52588 Mdot
.92 .52588 Mdot
.92 .52588 Mdot
.92 .52589 Mdot
.92 .52589 Mdot
.92 .52589 Mdot
.92 .5259 Mdot
.92 .5259 Mdot
.92 .5259 Mdot
.92 .52591 Mdot
.92 .52591 Mdot
.92 .52591 Mdot
.92 .52591 Mdot
.92 .52592 Mdot
.92 .52592 Mdot
.92 .52592 Mdot
.92 .52593 Mdot
.92 .52594 Mdot
.92 .52595 Mdot
.92 .52596 Mdot
.92 .52596 Mdot
.92 .52597 Mdot
.92 .52597 Mdot
.92 .52598 Mdot
.92 .52599 Mdot
.92 .526 Mdot
.92 .52603 Mdot
.92 .52604 Mdot
.92 .52604 Mdot
.92 .52605 Mdot
.92 .52609 Mdot
.92 .5261 Mdot
.92 .52611 Mdot
.92 .52612 Mdot
.92 .52613 Mdot
.92 .52613 Mdot
.92 .52614 Mdot
.92 .52616 Mdot
.92 .52619 Mdot
.92 .52619 Mdot
.92 .52621 Mdot
.92 .52622 Mdot
.92 .52622 Mdot
.92 .52625 Mdot
.92 .52629 Mdot
.92 .52629 Mdot
.92 .5263 Mdot
.92 .5263 Mdot
.92 .52631 Mdot
.92 .52631 Mdot
.92 .52633 Mdot
.92 .52634 Mdot
.92 .52634 Mdot
.92 .52635 Mdot
.92 .52637 Mdot
.92 .52639 Mdot
.92 .5264 Mdot
.92 .52641 Mdot
.92 .52641 Mdot
.92 .52642 Mdot
.92 .52642 Mdot
.92 .52643 Mdot
.92 .52643 Mdot
.92 .52644 Mdot
.92 .52644 Mdot
.92 .52644 Mdot
.92 .52651 Mdot
.92 .52652 Mdot
.92 .52656 Mdot
.92 .52656 Mdot
.92 .52659 Mdot
.92 .52659 Mdot
.92 .52659 Mdot
.92 .5266 Mdot
.92 .52668 Mdot
.92 .52671 Mdot
.92 .52672 Mdot
.92 .52674 Mdot
.92 .52675 Mdot
.92 .52678 Mdot
.92 .52683 Mdot
.92 .52687 Mdot
.92 .52687 Mdot
.92 .52691 Mdot
.92 .52692 Mdot
.92 .52694 Mdot
.92 .52699 Mdot
.92 .527 Mdot
.92 .52702 Mdot
.92 .52709 Mdot
.92 .5271 Mdot
.92 .52713 Mdot
.92 .52714 Mdot
.92 .52723 Mdot
.92 .5273 Mdot
.92 .52732 Mdot
.92 .52734 Mdot
.92 .52735 Mdot
.92 .52737 Mdot
.92 .52739 Mdot
.92 .52743 Mdot
.92 .5275 Mdot
.92 .52752 Mdot
.92 .52753 Mdot
.92 .52754 Mdot
.92 .52763 Mdot
.92 .52763 Mdot
.92 .52764 Mdot
.92 .52767 Mdot
.92 .52767 Mdot
.92 .5277 Mdot
.92 .52773 Mdot
.92 .52774 Mdot
.92 .52778 Mdot
.92 .52783 Mdot
.92 .52783 Mdot
.92 .52815 Mdot
.92 .52816 Mdot
.92 .52829 Mdot
.92 .52832 Mdot
.92 .52837 Mdot
.92 .52844 Mdot
.92 .52849 Mdot
.92 .52853 Mdot
.92 .52862 Mdot
.92 .52862 Mdot
.92 .52868 Mdot
.92 .52873 Mdot
.92 .52875 Mdot
.92 .52876 Mdot
.92 .5288 Mdot
.92 .52882 Mdot
.92 .52886 Mdot
.92 .52888 Mdot
.92 .52889 Mdot
.92 .52895 Mdot
.92 .52908 Mdot
.92 .5291 Mdot
.92 .52919 Mdot
.92 .52921 Mdot
.92 .52925 Mdot
.92 .52938 Mdot
.92 .52965 Mdot
.92 .53002 Mdot
.92 .53023 Mdot
.92 .5304 Mdot
.92 .53052 Mdot
.92 .53064 Mdot
.92 .53082 Mdot
.92 .5309 Mdot
.92 .53091 Mdot
.92 .53097 Mdot
.92 .53108 Mdot
.92 .53126 Mdot
.92 .53181 Mdot
.92 .53182 Mdot
.92 .53184 Mdot
.92 .53186 Mdot
.92 .53225 Mdot
.92 .53282 Mdot
.92 .53292 Mdot
.92 .53357 Mdot
.92 .5336 Mdot
.92 .53361 Mdot
.92 .53368 Mdot
.92 .53377 Mdot
.92 .53382 Mdot
.92 .53393 Mdot
.92 .5341 Mdot
.92 .53465 Mdot
.92 .53466 Mdot
.92 .53474 Mdot
.92 .53515 Mdot
.92 .53524 Mdot
.92 .53531 Mdot
.92 .53564 Mdot
.92 .53594 Mdot
.92 .5361 Mdot
.92 .53615 Mdot
.92 .53623 Mdot
.92 .53827 Mdot
.92 .53885 Mdot
.92 .53926 Mdot
.92 .53942 Mdot
.92 .54149 Mdot
.92 .54222 Mdot
.92 .54252 Mdot
.92 .54259 Mdot
.92 .54261 Mdot
.92 .54444 Mdot
.92 .54489 Mdot
.92 .54549 Mdot
.92 .54578 Mdot
.92 .54592 Mdot
.92 .54592 Mdot
.92 .54689 Mdot
.92 .54742 Mdot
.92 .54773 Mdot
.92 .54944 Mdot
.92 .5495 Mdot
.92 .5495 Mdot
.92 .54952 Mdot
.92 .54959 Mdot
.92 .54974 Mdot
.92 .54976 Mdot
.92 .54991 Mdot
.92 .5502 Mdot
.92 .55112 Mdot
.92 .55157 Mdot
.92 .55161 Mdot
.92 .55187 Mdot
.92 .55217 Mdot
.92 .55229 Mdot
.92 .55252 Mdot
.92 .5527 Mdot
.92 .55315 Mdot
.92 .55341 Mdot
.92 .55346 Mdot
.92 .5535 Mdot
.92 .55351 Mdot
.92 .55351 Mdot
.92 .55361 Mdot
.92 .55372 Mdot
.92 .55387 Mdot
.92 .55405 Mdot
.92 .55409 Mdot
.92 .55414 Mdot
.92 .5543 Mdot
.92 .55463 Mdot
.92 .55481 Mdot
.92 .55483 Mdot
.92 .55498 Mdot
.92 .555 Mdot
.92 .55517 Mdot
.92 .55539 Mdot
.92 .5554 Mdot
.92 .55551 Mdot
.92 .55562 Mdot
.92 .55569 Mdot
.92 .55575 Mdot
.92 .55594 Mdot
.92 .55605 Mdot
.92 .55606 Mdot
.92 .55615 Mdot
.92 .55623 Mdot
.92 .55625 Mdot
.92 .5563 Mdot
.92 .55633 Mdot
.92 .55635 Mdot
.92 .55636 Mdot
.92 .55641 Mdot
.922 .11636 Mdot
.922 .11637 Mdot
.922 .11637 Mdot
.922 .11641 Mdot
.922 .11641 Mdot
.922 .11649 Mdot
.922 .11654 Mdot
.922 .11658 Mdot
.922 .11691 Mdot
.922 .11709 Mdot
.922 .11732 Mdot
.922 .11736 Mdot
.922 .1175 Mdot
.922 .11853 Mdot
.922 .11863 Mdot
.922 .11883 Mdot
.922 .11884 Mdot
.922 .11906 Mdot
.922 .11911 Mdot
.922 .11941 Mdot
.922 .11965 Mdot
.922 .12012 Mdot
.922 .12238 Mdot
.922 .12253 Mdot
.922 .12344 Mdot
.922 .1236 Mdot
.922 .12408 Mdot
.922 .12412 Mdot
.922 .12433 Mdot
.922 .12579 Mdot
.922 .12795 Mdot
.922 .12849 Mdot
.922 .12851 Mdot
.922 .12888 Mdot
.922 .12923 Mdot
.922 .12971 Mdot
.922 .1298 Mdot
.922 .1299 Mdot
.922 .13027 Mdot
.922 .13028 Mdot
.922 .13054 Mdot
.922 .13058 Mdot
.922 .13059 Mdot
.922 .13338 Mdot
.922 .13451 Mdot
.922 .1346 Mdot
.922 .13462 Mdot
.922 .13479 Mdot
.922 .13522 Mdot
.922 .13524 Mdot
.922 .13572 Mdot
.922 .13585 Mdot
.922 .13586 Mdot
.922 .14017 Mdot
.922 .14219 Mdot
.922 .14556 Mdot
.922 .14603 Mdot
.922 .15644 Mdot
.922 .15921 Mdot
.922 .16464 Mdot
.922 .1647 Mdot
.922 .16471 Mdot
.922 .16486 Mdot
.922 .16488 Mdot
.922 .16519 Mdot
.922 .16542 Mdot
.922 .16559 Mdot
.922 .167 Mdot
.922 .16772 Mdot
.922 .1678 Mdot
.922 .16882 Mdot
.922 .16895 Mdot
.922 .16897 Mdot
.922 .16942 Mdot
.922 .16954 Mdot
.922 .16959 Mdot
.922 .17156 Mdot
.922 .17418 Mdot
.922 .17461 Mdot
.922 .17552 Mdot
.922 .1756 Mdot
.922 .17657 Mdot
.922 .17681 Mdot
.922 .17789 Mdot
.922 .17818 Mdot
.922 .17836 Mdot
.922 .17928 Mdot
.922 .18007 Mdot
.922 .18145 Mdot
.922 .183 Mdot
.922 .19089 Mdot
.922 .19171 Mdot
.922 .19218 Mdot
.922 .19254 Mdot
.922 .19286 Mdot
.922 .19292 Mdot
.922 .19406 Mdot
.922 .19438 Mdot
.922 .1973 Mdot
.922 .19809 Mdot
.922 .19903 Mdot
.922 .1994 Mdot
.922 .1999 Mdot
.922 .20002 Mdot
.922 .2003 Mdot
.922 .20044 Mdot
.922 .20061 Mdot
.922 .20166 Mdot
.922 .20199 Mdot
.922 .20229 Mdot
.922 .20409 Mdot
.922 .20466 Mdot
.922 .20673 Mdot
.922 .20686 Mdot
.922 .20694 Mdot
.922 .2079 Mdot
.922 .20846 Mdot
.922 .20883 Mdot
.922 .20888 Mdot
.922 .20898 Mdot
.922 .21311 Mdot
.922 .21436 Mdot
.922 .21474 Mdot
.922 .21613 Mdot
.922 .21655 Mdot
.922 .21728 Mdot
.922 .21766 Mdot
.922 .2185 Mdot
.922 .21861 Mdot
.922 .21875 Mdot
.922 .21885 Mdot
.922 .21952 Mdot
.922 .21963 Mdot
.922 .21964 Mdot
.922 .2197 Mdot
.922 .22098 Mdot
.922 .22101 Mdot
.922 .22115 Mdot
.922 .22166 Mdot
.922 .22191 Mdot
.922 .2221 Mdot
.922 .2222 Mdot
.922 .22239 Mdot
.922 .22249 Mdot
.922 .22264 Mdot
.922 .2227 Mdot
.922 .22302 Mdot
.922 .22305 Mdot
.922 .22361 Mdot
.922 .22389 Mdot
.922 .224 Mdot
.922 .22433 Mdot
.922 .22436 Mdot
.922 .22469 Mdot
.922 .22482 Mdot
.922 .22507 Mdot
.922 .22514 Mdot
.922 .2256 Mdot
.922 .22581 Mdot
.922 .22583 Mdot
.922 .22612 Mdot
.922 .22621 Mdot
.922 .22629 Mdot
.922 .22737 Mdot
.922 .2274 Mdot
.922 .22799 Mdot
.922 .22799 Mdot
.922 .228 Mdot
.922 .22803 Mdot
.922 .22806 Mdot
.922 .22808 Mdot
.922 .22808 Mdot
.922 .22816 Mdot
.922 .22838 Mdot
.922 .22838 Mdot
.922 .22843 Mdot
.922 .22844 Mdot
.922 .22852 Mdot
.922 .2288 Mdot
.922 .22895 Mdot
.922 .22898 Mdot
.922 .22905 Mdot
.922 .22918 Mdot
.922 .2295 Mdot
.922 .22958 Mdot
.922 .2301 Mdot
.922 .23043 Mdot
.922 .23045 Mdot
.922 .23062 Mdot
.922 .23064 Mdot
.922 .23086 Mdot
.922 .23091 Mdot
.922 .23098 Mdot
.922 .2312 Mdot
.922 .23127 Mdot
.922 .23134 Mdot
.922 .23139 Mdot
.922 .23161 Mdot
.922 .23167 Mdot
.922 .23167 Mdot
.922 .23171 Mdot
.922 .23213 Mdot
.922 .23223 Mdot
.922 .23227 Mdot
.922 .23255 Mdot
.922 .23258 Mdot
.922 .23259 Mdot
.922 .23263 Mdot
.922 .23266 Mdot
.922 .23269 Mdot
.922 .23269 Mdot
.922 .2327 Mdot
.922 .2329 Mdot
.922 .23293 Mdot
.922 .23313 Mdot
.922 .23321 Mdot
.922 .23363 Mdot
.922 .2337 Mdot
.922 .23392 Mdot
.922 .23439 Mdot
.922 .2346 Mdot
.922 .2347 Mdot
.922 .23473 Mdot
.922 .23484 Mdot
.922 .23561 Mdot
.922 .23568 Mdot
.922 .23596 Mdot
.922 .23602 Mdot
.922 .23604 Mdot
.922 .23609 Mdot
.922 .23631 Mdot
.922 .23663 Mdot
.922 .2367 Mdot
.922 .23711 Mdot
.922 .2372 Mdot
.922 .2374 Mdot
.922 .23757 Mdot
.922 .23757 Mdot
.922 .23763 Mdot
.922 .23763 Mdot
.922 .23764 Mdot
.922 .23766 Mdot
.922 .2377 Mdot
.922 .23772 Mdot
.922 .23772 Mdot
.922 .23773 Mdot
.922 .23773 Mdot
.922 .23773 Mdot
.922 .23781 Mdot
.922 .23785 Mdot
.922 .23789 Mdot
.922 .23789 Mdot
.922 .23792 Mdot
.922 .23794 Mdot
.922 .23801 Mdot
.922 .23802 Mdot
.922 .23803 Mdot
.922 .23803 Mdot
.922 .23806 Mdot
.922 .2381 Mdot
.922 .23835 Mdot
.922 .23847 Mdot
.922 .23849 Mdot
.922 .2385 Mdot
.922 .23851 Mdot
.922 .23855 Mdot
.922 .23857 Mdot
.922 .23859 Mdot
.922 .23859 Mdot
.922 .23859 Mdot
.922 .23864 Mdot
.922 .23868 Mdot
.922 .23876 Mdot
.922 .23876 Mdot
.922 .23882 Mdot
.922 .23896 Mdot
.922 .23898 Mdot
.922 .23898 Mdot
.922 .239 Mdot
.922 .23902 Mdot
.922 .23904 Mdot
.922 .23904 Mdot
.922 .23915 Mdot
.922 .23915 Mdot
.922 .23916 Mdot
.922 .2392 Mdot
.922 .23924 Mdot
.922 .23924 Mdot
.922 .23924 Mdot
.922 .23927 Mdot
.922 .23927 Mdot
.922 .23927 Mdot
.922 .23929 Mdot
.922 .2393 Mdot
.922 .23932 Mdot
.922 .23932 Mdot
.922 .23932 Mdot
.922 .23933 Mdot
.922 .23934 Mdot
.922 .23934 Mdot
.922 .23934 Mdot
.922 .23934 Mdot
.922 .23934 Mdot
.922 .24687 Mdot
.922 .25242 Mdot
.922 .25288 Mdot
.922 .25295 Mdot
.922 .25382 Mdot
.922 .25588 Mdot
.922 .25601 Mdot
.922 .25832 Mdot
.922 .25894 Mdot
.922 .25897 Mdot
.922 .27903 Mdot
.922 .2827 Mdot
.922 .28751 Mdot
.922 .28787 Mdot
.922 .30148 Mdot
.922 .30326 Mdot
.922 .30739 Mdot
.922 .31156 Mdot
.922 .31257 Mdot
.922 .31581 Mdot
.922 .31596 Mdot
.922 .31597 Mdot
.922 .31598 Mdot
.922 .31602 Mdot
.922 .31602 Mdot
.922 .31603 Mdot
.922 .31603 Mdot
.922 .31603 Mdot
.922 .31608 Mdot
.922 .31611 Mdot
.922 .31614 Mdot
.922 .31618 Mdot
.922 .31623 Mdot
.922 .31624 Mdot
.922 .31626 Mdot
.922 .31629 Mdot
.922 .31662 Mdot
.922 .31663 Mdot
.922 .31668 Mdot
.922 .3167 Mdot
.922 .31672 Mdot
.922 .31672 Mdot
.922 .31677 Mdot
.922 .3169 Mdot
.922 .31696 Mdot
.922 .31723 Mdot
.922 .31725 Mdot
.922 .31744 Mdot
.922 .31755 Mdot
.922 .31764 Mdot
.922 .31792 Mdot
.922 .31794 Mdot
.922 .31796 Mdot
.922 .31799 Mdot
.922 .31803 Mdot
.922 .31806 Mdot
.922 .31814 Mdot
.922 .31856 Mdot
.922 .31865 Mdot
.922 .31916 Mdot
.922 .32133 Mdot
.922 .32167 Mdot
.922 .32283 Mdot
.922 .32293 Mdot
.922 .32299 Mdot
.922 .32304 Mdot
.922 .32336 Mdot
.922 .32379 Mdot
.922 .32405 Mdot
.922 .32413 Mdot
.922 .32434 Mdot
.922 .32477 Mdot
.922 .32486 Mdot
.922 .32488 Mdot
.922 .32496 Mdot
.922 .32509 Mdot
.922 .32533 Mdot
.922 .32535 Mdot
.922 .32551 Mdot
.922 .32552 Mdot
.922 .32567 Mdot
.922 .32573 Mdot
.922 .32639 Mdot
.922 .32728 Mdot
.922 .32729 Mdot
.922 .32766 Mdot
.922 .3279 Mdot
.922 .32815 Mdot
.922 .3282 Mdot
.922 .32909 Mdot
.922 .32918 Mdot
.922 .32928 Mdot
.922 .33055 Mdot
.922 .33067 Mdot
.922 .33155 Mdot
.922 .33184 Mdot
.922 .33338 Mdot
.922 .33339 Mdot
.922 .33353 Mdot
.922 .3338 Mdot
.922 .33394 Mdot
.922 .33408 Mdot
.922 .33415 Mdot
.922 .33416 Mdot
.922 .33427 Mdot
.922 .33433 Mdot
.922 .33441 Mdot
.922 .33449 Mdot
.922 .33456 Mdot
.922 .33525 Mdot
.922 .33573 Mdot
.922 .33614 Mdot
.922 .33615 Mdot
.922 .33643 Mdot
.922 .33644 Mdot
.922 .3366 Mdot
.922 .33662 Mdot
.922 .33679 Mdot
.922 .3371 Mdot
.922 .33715 Mdot
.922 .33768 Mdot
.922 .3387 Mdot
.922 .33876 Mdot
.922 .33902 Mdot
.922 .33916 Mdot
.922 .33932 Mdot
.922 .3394 Mdot
.922 .33965 Mdot
.922 .34013 Mdot
.922 .34022 Mdot
.922 .34022 Mdot
.922 .34031 Mdot
.922 .34064 Mdot
.922 .34075 Mdot
.922 .3412 Mdot
.922 .34139 Mdot
.922 .34141 Mdot
.922 .3416 Mdot
.922 .34168 Mdot
.922 .34168 Mdot
.922 .34214 Mdot
.922 .34225 Mdot
.922 .34272 Mdot
.922 .34285 Mdot
.922 .34289 Mdot
.922 .34293 Mdot
.922 .34293 Mdot
.922 .34316 Mdot
.922 .34321 Mdot
.922 .34345 Mdot
.922 .34348 Mdot
.922 .34365 Mdot
.922 .34375 Mdot
.922 .34379 Mdot
.922 .34382 Mdot
.922 .34398 Mdot
.922 .34437 Mdot
.922 .3445 Mdot
.922 .34468 Mdot
.922 .34479 Mdot
.922 .34512 Mdot
.922 .34513 Mdot
.922 .34514 Mdot
.922 .34516 Mdot
.922 .34517 Mdot
.922 .34527 Mdot
.922 .34528 Mdot
.922 .34532 Mdot
.922 .34545 Mdot
.922 .34547 Mdot
.922 .3456 Mdot
.922 .34569 Mdot
.922 .34571 Mdot
.922 .3458 Mdot
.922 .34585 Mdot
.922 .34611 Mdot
.922 .34612 Mdot
.922 .34626 Mdot
.922 .34633 Mdot
.922 .34643 Mdot
.922 .34644 Mdot
.922 .34645 Mdot
.922 .34645 Mdot
.922 .34653 Mdot
.922 .34653 Mdot
.922 .34654 Mdot
.922 .34655 Mdot
.922 .34656 Mdot
.922 .34656 Mdot
.922 .34656 Mdot
.922 .34672 Mdot
.922 .34701 Mdot
.922 .34713 Mdot
.922 .34718 Mdot
.922 .34826 Mdot
.922 .34921 Mdot
.922 .34958 Mdot
.922 .35068 Mdot
.922 .35078 Mdot
.922 .35193 Mdot
.922 .35238 Mdot
.922 .35323 Mdot
.922 .35348 Mdot
.922 .35511 Mdot
.922 .35588 Mdot
.922 .35596 Mdot
.922 .35701 Mdot
.922 .35735 Mdot
.922 .35766 Mdot
.922 .36173 Mdot
.922 .36183 Mdot
.922 .36414 Mdot
.922 .36414 Mdot
.922 .36417 Mdot
.922 .36431 Mdot
.922 .36442 Mdot
.922 .36447 Mdot
.922 .36447 Mdot
.922 .36482 Mdot
.922 .36566 Mdot
.922 .36566 Mdot
.922 .36588 Mdot
.922 .36591 Mdot
.922 .36622 Mdot
.922 .36736 Mdot
.922 .36797 Mdot
.922 .36808 Mdot
.922 .36837 Mdot
.922 .36889 Mdot
.922 .37022 Mdot
.922 .37054 Mdot
.922 .37269 Mdot
.922 .37408 Mdot
.922 .37419 Mdot
.922 .37489 Mdot
.922 .37499 Mdot
.922 .37595 Mdot
.922 .37613 Mdot
.922 .37644 Mdot
.922 .37739 Mdot
.922 .37768 Mdot
.922 .37799 Mdot
.922 .3782 Mdot
.922 .37919 Mdot
.922 .37942 Mdot
.922 .37943 Mdot
.922 .37962 Mdot
.922 .38146 Mdot
.922 .3819 Mdot
.922 .3821 Mdot
.922 .38333 Mdot
.922 .38348 Mdot
.922 .38348 Mdot
.922 .38367 Mdot
.922 .3838 Mdot
.922 .38394 Mdot
.922 .38394 Mdot
.922 .384 Mdot
.922 .38489 Mdot
.922 .38504 Mdot
.922 .38595 Mdot
.922 .38628 Mdot
.922 .38821 Mdot
.922 .38853 Mdot
.922 .38954 Mdot
.922 .39168 Mdot
.922 .39269 Mdot
.922 .39313 Mdot
.922 .39325 Mdot
.922 .39377 Mdot
.922 .39742 Mdot
.922 .39772 Mdot
.922 .39906 Mdot
.922 .39937 Mdot
.922 .39945 Mdot
.922 .3997 Mdot
.922 .40075 Mdot
.922 .40225 Mdot
.922 .40259 Mdot
.922 .40459 Mdot
.922 .40501 Mdot
.922 .40596 Mdot
.922 .40681 Mdot
.922 .40682 Mdot
.922 .4071 Mdot
.922 .4071 Mdot
.922 .40716 Mdot
.922 .40726 Mdot
.922 .40741 Mdot
.922 .40752 Mdot
.922 .40753 Mdot
.922 .40756 Mdot
.922 .40757 Mdot
.922 .40759 Mdot
.922 .40795 Mdot
.922 .40815 Mdot
.922 .40835 Mdot
.922 .40837 Mdot
.922 .40853 Mdot
.922 .40861 Mdot
.922 .40895 Mdot
.922 .40898 Mdot
.922 .40902 Mdot
.922 .40904 Mdot
.922 .40919 Mdot
.922 .40938 Mdot
.922 .41061 Mdot
.922 .41119 Mdot
.922 .41128 Mdot
.922 .41134 Mdot
.922 .4114 Mdot
.922 .41159 Mdot
.922 .41171 Mdot
.922 .41178 Mdot
.922 .41179 Mdot
.922 .41179 Mdot
.922 .41203 Mdot
.922 .41224 Mdot
.922 .41262 Mdot
.922 .41264 Mdot
.922 .41289 Mdot
.922 .41363 Mdot
.922 .41371 Mdot
.922 .41372 Mdot
.922 .41382 Mdot
.922 .41389 Mdot
.922 .41398 Mdot
.922 .41398 Mdot
.922 .41453 Mdot
.922 .41454 Mdot
.922 .41459 Mdot
.922 .41479 Mdot
.922 .41497 Mdot
.922 .41499 Mdot
.922 .41501 Mdot
.922 .41513 Mdot
.922 .41514 Mdot
.922 .41514 Mdot
.922 .41525 Mdot
.922 .41527 Mdot
.922 .41537 Mdot
.922 .41539 Mdot
.922 .41541 Mdot
.922 .41543 Mdot
.922 .41546 Mdot
.922 .41547 Mdot
.922 .41549 Mdot
.922 .41549 Mdot
.922 .4155 Mdot
.922 .43558 Mdot
.922 .43559 Mdot
.922 .43563 Mdot
.922 .43572 Mdot
.922 .43578 Mdot
.922 .43591 Mdot
.922 .43604 Mdot
.922 .43612 Mdot
.922 .43622 Mdot
.922 .4367 Mdot
.922 .43684 Mdot
.922 .43735 Mdot
.922 .43738 Mdot
.922 .43744 Mdot
.922 .43805 Mdot
.922 .43814 Mdot
.922 .43823 Mdot
.922 .43915 Mdot
.922 .44014 Mdot
.922 .44042 Mdot
.922 .44042 Mdot
.922 .44318 Mdot
.922 .44319 Mdot
.922 .44365 Mdot
.922 .44401 Mdot
.922 .44449 Mdot
.922 .44455 Mdot
.922 .44498 Mdot
.922 .44865 Mdot
.922 .44993 Mdot
.922 .45 Mdot
.922 .45191 Mdot
.922 .45298 Mdot
.922 .45318 Mdot
.922 .45416 Mdot
.922 .45417 Mdot
.922 .45421 Mdot
.922 .45455 Mdot
.922 .45516 Mdot
.922 .45609 Mdot
.922 .45642 Mdot
.922 .45671 Mdot
.922 .45711 Mdot
.922 .46 Mdot
.922 .46604 Mdot
.922 .46697 Mdot
.922 .46765 Mdot
.922 .46776 Mdot
.922 .46795 Mdot
.922 .46809 Mdot
.922 .46978 Mdot
.922 .47015 Mdot
.922 .47093 Mdot
.922 .471 Mdot
.922 .47195 Mdot
.922 .47291 Mdot
.922 .47465 Mdot
.922 .47474 Mdot
.922 .47478 Mdot
.922 .4749 Mdot
.922 .47496 Mdot
.922 .47548 Mdot
.922 .47619 Mdot
.922 .47669 Mdot
.922 .47694 Mdot
.922 .47697 Mdot
.922 .47825 Mdot
.922 .4783 Mdot
.922 .48007 Mdot
.922 .4822 Mdot
.922 .48228 Mdot
.922 .48255 Mdot
.922 .48651 Mdot
.922 .48663 Mdot
.922 .48852 Mdot
.922 .49567 Mdot
.922 .49623 Mdot
.922 .49732 Mdot
.922 .49879 Mdot
.922 .50504 Mdot
.922 .5059 Mdot
.922 .50836 Mdot
.922 .5085 Mdot
.922 .50923 Mdot
.922 .51022 Mdot
.922 .51051 Mdot
.922 .5117 Mdot
.922 .51675 Mdot
.922 .51786 Mdot
.922 .52699 Mdot
.922 .52699 Mdot
.922 .52699 Mdot
.922 .52699 Mdot
.922 .52699 Mdot
.922 .52699 Mdot
.922 .52699 Mdot
.922 .527 Mdot
.922 .527 Mdot
.922 .527 Mdot
.922 .527 Mdot
.922 .52701 Mdot
.922 .52701 Mdot
.922 .52701 Mdot
.922 .52701 Mdot
.922 .52701 Mdot
.922 .52701 Mdot
.922 .52702 Mdot
.922 .52703 Mdot
.922 .52703 Mdot
.922 .52703 Mdot
.922 .52705 Mdot
.922 .52705 Mdot
.922 .52706 Mdot
.922 .52706 Mdot
.922 .52706 Mdot
.922 .52706 Mdot
.922 .52707 Mdot
.922 .5271 Mdot
.922 .52711 Mdot
.922 .52711 Mdot
.922 .52712 Mdot
.922 .52713 Mdot
.922 .52714 Mdot
.922 .52714 Mdot
.922 .52714 Mdot
.922 .52714 Mdot
.922 .52715 Mdot
.922 .52716 Mdot
.922 .52716 Mdot
.922 .52716 Mdot
.922 .52717 Mdot
.922 .52719 Mdot
.922 .52724 Mdot
.922 .52725 Mdot
.922 .52725 Mdot
.922 .52725 Mdot
.922 .52726 Mdot
.922 .52726 Mdot
.922 .52727 Mdot
.922 .52727 Mdot
.922 .52728 Mdot
.922 .52728 Mdot
.922 .52729 Mdot
.922 .5273 Mdot
.922 .52731 Mdot
.922 .52731 Mdot
.922 .52731 Mdot
.922 .52732 Mdot
.922 .52732 Mdot
.922 .52732 Mdot
.922 .52733 Mdot
.922 .52733 Mdot
.922 .52733 Mdot
.922 .52733 Mdot
.922 .52734 Mdot
.922 .52735 Mdot
.922 .52738 Mdot
.922 .52742 Mdot
.922 .52744 Mdot
.922 .52752 Mdot
.922 .52753 Mdot
.922 .5276 Mdot
.922 .52764 Mdot
.922 .52765 Mdot
.922 .52765 Mdot
.922 .52767 Mdot
.922 .52772 Mdot
.922 .52774 Mdot
.922 .52789 Mdot
.922 .52791 Mdot
.922 .52792 Mdot
.922 .52794 Mdot
.922 .52798 Mdot
.922 .52807 Mdot
.922 .52812 Mdot
.922 .52813 Mdot
.922 .52822 Mdot
.922 .52823 Mdot
.922 .52832 Mdot
.922 .52832 Mdot
.922 .52833 Mdot
.922 .52833 Mdot
.922 .52834 Mdot
.922 .52834 Mdot
.922 .52835 Mdot
.922 .5284 Mdot
.922 .52841 Mdot
.922 .52843 Mdot
.922 .52851 Mdot
.922 .52852 Mdot
.922 .52852 Mdot
.922 .52853 Mdot
.922 .5286 Mdot
.922 .52862 Mdot
.922 .52866 Mdot
.922 .52867 Mdot
.922 .52868 Mdot
.922 .52873 Mdot
.922 .52873 Mdot
.922 .52876 Mdot
.922 .52877 Mdot
.922 .52884 Mdot
.922 .52894 Mdot
.922 .52902 Mdot
.922 .52904 Mdot
.922 .52906 Mdot
.922 .52909 Mdot
.922 .52916 Mdot
.922 .52917 Mdot
.922 .52918 Mdot
.922 .52918 Mdot
.922 .52922 Mdot
.922 .52924 Mdot
.922 .52924 Mdot
.922 .52924 Mdot
.922 .52925 Mdot
.922 .52925 Mdot
.922 .52925 Mdot
.922 .52925 Mdot
.922 .52937 Mdot
.922 .52938 Mdot
.922 .52959 Mdot
.922 .52961 Mdot
.922 .52968 Mdot
.922 .52969 Mdot
.922 .52973 Mdot
.922 .52982 Mdot
.922 .52984 Mdot
.922 .52988 Mdot
.922 .52991 Mdot
.922 .52998 Mdot
.922 .53005 Mdot
.922 .53007 Mdot
.922 .53013 Mdot
.922 .53024 Mdot
.922 .53024 Mdot
.922 .53031 Mdot
.922 .53032 Mdot
.922 .5304 Mdot
.922 .53042 Mdot
.922 .53046 Mdot
.922 .53051 Mdot
.922 .53061 Mdot
.922 .53064 Mdot
.922 .53065 Mdot
.922 .53092 Mdot
.922 .53092 Mdot
.922 .53094 Mdot
.922 .53107 Mdot
.922 .53109 Mdot
.922 .53112 Mdot
.922 .53114 Mdot
.922 .53131 Mdot
.922 .53138 Mdot
.922 .53153 Mdot
.922 .53161 Mdot
.922 .53189 Mdot
.922 .53197 Mdot
.922 .53222 Mdot
.922 .53305 Mdot
.922 .53308 Mdot
.922 .53315 Mdot
.922 .53326 Mdot
.922 .53345 Mdot
.922 .53347 Mdot
.922 .5335 Mdot
.922 .53392 Mdot
.922 .53403 Mdot
.922 .5344 Mdot
.922 .53446 Mdot
.922 .5348 Mdot
.922 .53486 Mdot
.922 .53488 Mdot
.922 .53498 Mdot
.922 .53506 Mdot
.922 .53602 Mdot
.922 .53608 Mdot
.922 .53632 Mdot
.922 .5364 Mdot
.922 .53657 Mdot
.922 .53674 Mdot
.922 .5384 Mdot
.922 .53904 Mdot
.922 .53941 Mdot
.922 .53951 Mdot
.922 .54091 Mdot
.922 .54137 Mdot
.922 .5414 Mdot
.922 .5415 Mdot
.922 .54179 Mdot
.922 .54379 Mdot
.922 .54447 Mdot
.922 .54717 Mdot
.922 .54729 Mdot
.922 .54823 Mdot
.922 .54882 Mdot
.922 .55011 Mdot
.922 .55011 Mdot
.922 .55015 Mdot
.922 .5503 Mdot
.922 .55031 Mdot
.922 .55044 Mdot
.922 .5505 Mdot
.922 .5505 Mdot
.922 .55053 Mdot
.922 .55089 Mdot
.922 .55181 Mdot
.922 .55182 Mdot
.922 .55183 Mdot
.922 .55192 Mdot
.922 .55192 Mdot
.922 .55205 Mdot
.922 .55208 Mdot
.922 .55211 Mdot
.922 .55228 Mdot
.922 .5524 Mdot
.922 .55253 Mdot
.922 .55254 Mdot
.922 .55273 Mdot
.922 .55352 Mdot
.922 .55407 Mdot
.922 .55416 Mdot
.922 .55417 Mdot
.922 .55436 Mdot
.922 .55442 Mdot
.922 .55479 Mdot
.922 .55485 Mdot
.922 .55581 Mdot
.922 .55601 Mdot
.922 .55612 Mdot
.922 .55626 Mdot
.922 .55628 Mdot
.922 .55638 Mdot
.922 .55639 Mdot
.922 .55648 Mdot
.922 .55652 Mdot
.922 .55701 Mdot
.922 .55708 Mdot
.922 .5571 Mdot
.922 .55721 Mdot
.922 .5573 Mdot
.922 .55746 Mdot
.922 .55748 Mdot
.922 .55751 Mdot
.922 .55755 Mdot
.922 .55755 Mdot
.922 .55757 Mdot
.922 .55757 Mdot
.922 .55757 Mdot
.924 .11435 Mdot
.924 .11436 Mdot
.924 .11438 Mdot
.924 .1144 Mdot
.924 .1145 Mdot
.924 .11455 Mdot
.924 .11464 Mdot
.924 .11478 Mdot
.924 .11492 Mdot
.924 .11499 Mdot
.924 .11519 Mdot
.924 .11523 Mdot
.924 .11531 Mdot
.924 .11563 Mdot
.924 .116 Mdot
.924 .11624 Mdot
.924 .11779 Mdot
.924 .11782 Mdot
.924 .11812 Mdot
.924 .1183 Mdot
.924 .11836 Mdot
.924 .1186 Mdot
.924 .11885 Mdot
.924 .12051 Mdot
.924 .12102 Mdot
.924 .12173 Mdot
.924 .1219 Mdot
.924 .12277 Mdot
.924 .12284 Mdot
.924 .12291 Mdot
.924 .12443 Mdot
.924 .12642 Mdot
.924 .12659 Mdot
.924 .12748 Mdot
.924 .12758 Mdot
.924 .12784 Mdot
.924 .12821 Mdot
.924 .12888 Mdot
.924 .12987 Mdot
.924 .13151 Mdot
.924 .13234 Mdot
.924 .13246 Mdot
.924 .13332 Mdot
.924 .13435 Mdot
.924 .1347 Mdot
.924 .13542 Mdot
.924 .13589 Mdot
.924 .13658 Mdot
.924 .13907 Mdot
.924 .14079 Mdot
.924 .14333 Mdot
.924 .14392 Mdot
.924 .14504 Mdot
.924 .14512 Mdot
.924 .14672 Mdot
.924 .14891 Mdot
.924 .14914 Mdot
.924 .14933 Mdot
.924 .14955 Mdot
.924 .14967 Mdot
.924 .1499 Mdot
.924 .15047 Mdot
.924 .15177 Mdot
.924 .1523 Mdot
.924 .15315 Mdot
.924 .15353 Mdot
.924 .15385 Mdot
.924 .15389 Mdot
.924 .15415 Mdot
.924 .15528 Mdot
.924 .15607 Mdot
.924 .15661 Mdot
.924 .15662 Mdot
.924 .15674 Mdot
.924 .15681 Mdot
.924 .1569 Mdot
.924 .15711 Mdot
.924 .1572 Mdot
.924 .1574 Mdot
.924 .15758 Mdot
.924 .15779 Mdot
.924 .15834 Mdot
.924 .15837 Mdot
.924 .15876 Mdot
.924 .15884 Mdot
.924 .15892 Mdot
.924 .15898 Mdot
.924 .15923 Mdot
.924 .15952 Mdot
.924 .16004 Mdot
.924 .1602 Mdot
.924 .16052 Mdot
.924 .16165 Mdot
.924 .16169 Mdot
.924 .16188 Mdot
.924 .16191 Mdot
.924 .16264 Mdot
.924 .16343 Mdot
.924 .16391 Mdot
.924 .16421 Mdot
.924 .16445 Mdot
.924 .16737 Mdot
.924 .16779 Mdot
.924 .16842 Mdot
.924 .17041 Mdot
.924 .17121 Mdot
.924 .17136 Mdot
.924 .17206 Mdot
.924 .17255 Mdot
.924 .1727 Mdot
.924 .17337 Mdot
.924 .17351 Mdot
.924 .17369 Mdot
.924 .17378 Mdot
.924 .17405 Mdot
.924 .17443 Mdot
.924 .17482 Mdot
.924 .17599 Mdot
.924 .17603 Mdot
.924 .17743 Mdot
.924 .17762 Mdot
.924 .17902 Mdot
.924 .17982 Mdot
.924 .1829 Mdot
.924 .18308 Mdot
.924 .18362 Mdot
.924 .18474 Mdot
.924 .18485 Mdot
.924 .1851 Mdot
.924 .18527 Mdot
.924 .18541 Mdot
.924 .18602 Mdot
.924 .18637 Mdot
.924 .18697 Mdot
.924 .18702 Mdot
.924 .1877 Mdot
.924 .18882 Mdot
.924 .18886 Mdot
.924 .18922 Mdot
.924 .18941 Mdot
.924 .18942 Mdot
.924 .18988 Mdot
.924 .19015 Mdot
.924 .19021 Mdot
.924 .19027 Mdot
.924 .19067 Mdot
.924 .19082 Mdot
.924 .19088 Mdot
.924 .19095 Mdot
.924 .19099 Mdot
.924 .19119 Mdot
.924 .19134 Mdot
.924 .19134 Mdot
.924 .19145 Mdot
.924 .19145 Mdot
.924 .1932 Mdot
.924 .19413 Mdot
.924 .19442 Mdot
.924 .19478 Mdot
.924 .19502 Mdot
.924 .19508 Mdot
.924 .19509 Mdot
.924 .19639 Mdot
.924 .19708 Mdot
.924 .19717 Mdot
.924 .19753 Mdot
.924 .19806 Mdot
.924 .19862 Mdot
.924 .19902 Mdot
.924 .19949 Mdot
.924 .20165 Mdot
.924 .20255 Mdot
.924 .20354 Mdot
.924 .2041 Mdot
.924 .20432 Mdot
.924 .20451 Mdot
.924 .20463 Mdot
.924 .20497 Mdot
.924 .20516 Mdot
.924 .20541 Mdot
.924 .20728 Mdot
.924 .20766 Mdot
.924 .20781 Mdot
.924 .20816 Mdot
.924 .20855 Mdot
.924 .20964 Mdot
.924 .20976 Mdot
.924 .21023 Mdot
.924 .21074 Mdot
.924 .2111 Mdot
.924 .21125 Mdot
.924 .21233 Mdot
.924 .21242 Mdot
.924 .21251 Mdot
.924 .21259 Mdot
.924 .21277 Mdot
.924 .2128 Mdot
.924 .21306 Mdot
.924 .21331 Mdot
.924 .21362 Mdot
.924 .21367 Mdot
.924 .21388 Mdot
.924 .2144 Mdot
.924 .21445 Mdot
.924 .21513 Mdot
.924 .21519 Mdot
.924 .21626 Mdot
.924 .21687 Mdot
.924 .21698 Mdot
.924 .21772 Mdot
.924 .21776 Mdot
.924 .21778 Mdot
.924 .21826 Mdot
.924 .21876 Mdot
.924 .21949 Mdot
.924 .21959 Mdot
.924 .21986 Mdot
.924 .22014 Mdot
.924 .22048 Mdot
.924 .2206 Mdot
.924 .22083 Mdot
.924 .2213 Mdot
.924 .22133 Mdot
.924 .22138 Mdot
.924 .22142 Mdot
.924 .22143 Mdot
.924 .22155 Mdot
.924 .22184 Mdot
.924 .22193 Mdot
.924 .22215 Mdot
.924 .22253 Mdot
.924 .22298 Mdot
.924 .22332 Mdot
.924 .22357 Mdot
.924 .22361 Mdot
.924 .22378 Mdot
.924 .22435 Mdot
.924 .22437 Mdot
.924 .22451 Mdot
.924 .22479 Mdot
.924 .22483 Mdot
.924 .22507 Mdot
.924 .22531 Mdot
.924 .22535 Mdot
.924 .22542 Mdot
.924 .22549 Mdot
.924 .2256 Mdot
.924 .22575 Mdot
.924 .22589 Mdot
.924 .22615 Mdot
.924 .2263 Mdot
.924 .22639 Mdot
.924 .22644 Mdot
.924 .22655 Mdot
.924 .22679 Mdot
.924 .22692 Mdot
.924 .22701 Mdot
.924 .22711 Mdot
.924 .22726 Mdot
.924 .22764 Mdot
.924 .22774 Mdot
.924 .2278 Mdot
.924 .22781 Mdot
.924 .22787 Mdot
.924 .22799 Mdot
.924 .22816 Mdot
.924 .22846 Mdot
.924 .22862 Mdot
.924 .22884 Mdot
.924 .2289 Mdot
.924 .22914 Mdot
.924 .22921 Mdot
.924 .22963 Mdot
.924 .22979 Mdot
.924 .22993 Mdot
.924 .22994 Mdot
.924 .23005 Mdot
.924 .23011 Mdot
.924 .23019 Mdot
.924 .23026 Mdot
.924 .23051 Mdot
.924 .23052 Mdot
.924 .23068 Mdot
.924 .2307 Mdot
.924 .23107 Mdot
.924 .23118 Mdot
.924 .23136 Mdot
.924 .23168 Mdot
.924 .23168 Mdot
.924 .23173 Mdot
.924 .23175 Mdot
.924 .23179 Mdot
.924 .23212 Mdot
.924 .23213 Mdot
.924 .23221 Mdot
.924 .23221 Mdot
.924 .23246 Mdot
.924 .23253 Mdot
.924 .2326 Mdot
.924 .23287 Mdot
.924 .23291 Mdot
.924 .23296 Mdot
.924 .23305 Mdot
.924 .23322 Mdot
.924 .23325 Mdot
.924 .23337 Mdot
.924 .23338 Mdot
.924 .23338 Mdot
.924 .23339 Mdot
.924 .23339 Mdot
.924 .23341 Mdot
.924 .23343 Mdot
.924 .23344 Mdot
.924 .23346 Mdot
.924 .23348 Mdot
.924 .23349 Mdot
.924 .2335 Mdot
.924 .23351 Mdot
.924 .23354 Mdot
.924 .23359 Mdot
.924 .23361 Mdot
.924 .23363 Mdot
.924 .23364 Mdot
.924 .23369 Mdot
.924 .23369 Mdot
.924 .23371 Mdot
.924 .23374 Mdot
.924 .23374 Mdot
.924 .23382 Mdot
.924 .23383 Mdot
.924 .23391 Mdot
.924 .23392 Mdot
.924 .23393 Mdot
.924 .23394 Mdot
.924 .23395 Mdot
.924 .23401 Mdot
.924 .23411 Mdot
.924 .23415 Mdot
.924 .23415 Mdot
.924 .23415 Mdot
.924 .23417 Mdot
.924 .23418 Mdot
.924 .23419 Mdot
.924 .23421 Mdot
.924 .23421 Mdot
.924 .23421 Mdot
.924 .23422 Mdot
.924 .23423 Mdot
.924 .23424 Mdot
.924 .23424 Mdot
.924 .23425 Mdot
.924 .23425 Mdot
.924 .23803 Mdot
.924 .24219 Mdot
.924 .24281 Mdot
.924 .24707 Mdot
.924 .25215 Mdot
.924 .25279 Mdot
.924 .25386 Mdot
.924 .2574 Mdot
.924 .25966 Mdot
.924 .26299 Mdot
.924 .27466 Mdot
.924 .28238 Mdot
.924 .29323 Mdot
.924 .29564 Mdot
.924 .30008 Mdot
.924 .30041 Mdot
.924 .30599 Mdot
.924 .30645 Mdot
.924 .31411 Mdot
.924 .31488 Mdot
.924 .31552 Mdot
.924 .31623 Mdot
.924 .31661 Mdot
.924 .31661 Mdot
.924 .31662 Mdot
.924 .31662 Mdot
.924 .31664 Mdot
.924 .31666 Mdot
.924 .31667 Mdot
.924 .31672 Mdot
.924 .31672 Mdot
.924 .31676 Mdot
.924 .31682 Mdot
.924 .31692 Mdot
.924 .31736 Mdot
.924 .31754 Mdot
.924 .31776 Mdot
.924 .31783 Mdot
.924 .31786 Mdot
.924 .31808 Mdot
.924 .3181 Mdot
.924 .31835 Mdot
.924 .31836 Mdot
.924 .31874 Mdot
.924 .31913 Mdot
.924 .31915 Mdot
.924 .31926 Mdot
.924 .31938 Mdot
.924 .31941 Mdot
.924 .31949 Mdot
.924 .31984 Mdot
.924 .32006 Mdot
.924 .32039 Mdot
.924 .3208 Mdot
.924 .32098 Mdot
.924 .32127 Mdot
.924 .32128 Mdot
.924 .32135 Mdot
.924 .32159 Mdot
.924 .32188 Mdot
.924 .32196 Mdot
.924 .32226 Mdot
.924 .32232 Mdot
.924 .32237 Mdot
.924 .32249 Mdot
.924 .32262 Mdot
.924 .32273 Mdot
.924 .32299 Mdot
.924 .32302 Mdot
.924 .32303 Mdot
.924 .32328 Mdot
.924 .32342 Mdot
.924 .3238 Mdot
.924 .3243 Mdot
.924 .32438 Mdot
.924 .32452 Mdot
.924 .32473 Mdot
.924 .32533 Mdot
.924 .32534 Mdot
.924 .32546 Mdot
.924 .32547 Mdot
.924 .32561 Mdot
.924 .32565 Mdot
.924 .32569 Mdot
.924 .32589 Mdot
.924 .32595 Mdot
.924 .32603 Mdot
.924 .32611 Mdot
.924 .3263 Mdot
.924 .3268 Mdot
.924 .32683 Mdot
.924 .32688 Mdot
.924 .32692 Mdot
.924 .32696 Mdot
.924 .32704 Mdot
.924 .3273 Mdot
.924 .32785 Mdot
.924 .3279 Mdot
.924 .32791 Mdot
.924 .32816 Mdot
.924 .32863 Mdot
.924 .32865 Mdot
.924 .32869 Mdot
.924 .32876 Mdot
.924 .32915 Mdot
.924 .32941 Mdot
.924 .33016 Mdot
.924 .33046 Mdot
.924 .33068 Mdot
.924 .33108 Mdot
.924 .33115 Mdot
.924 .33196 Mdot
.924 .33209 Mdot
.924 .33237 Mdot
.924 .33242 Mdot
.924 .33245 Mdot
.924 .3325 Mdot
.924 .33299 Mdot
.924 .33324 Mdot
.924 .33343 Mdot
.924 .33365 Mdot
.924 .33366 Mdot
.924 .33385 Mdot
.924 .33399 Mdot
.924 .33414 Mdot
.924 .33487 Mdot
.924 .33498 Mdot
.924 .335 Mdot
.924 .33524 Mdot
.924 .33539 Mdot
.924 .33557 Mdot
.924 .33561 Mdot
.924 .33598 Mdot
.924 .33616 Mdot
.924 .33633 Mdot
.924 .33654 Mdot
.924 .33656 Mdot
.924 .33675 Mdot
.924 .33688 Mdot
.924 .33701 Mdot
.924 .33728 Mdot
.924 .33775 Mdot
.924 .33827 Mdot
.924 .33832 Mdot
.924 .33851 Mdot
.924 .33899 Mdot
.924 .33911 Mdot
.924 .33924 Mdot
.924 .33934 Mdot
.924 .33942 Mdot
.924 .33975 Mdot
.924 .33976 Mdot
.924 .34021 Mdot
.924 .34031 Mdot
.924 .34041 Mdot
.924 .34099 Mdot
.924 .34116 Mdot
.924 .34121 Mdot
.924 .34121 Mdot
.924 .34166 Mdot
.924 .34178 Mdot
.924 .34187 Mdot
.924 .342 Mdot
.924 .34215 Mdot
.924 .34217 Mdot
.924 .34252 Mdot
.924 .34266 Mdot
.924 .34284 Mdot
.924 .34309 Mdot
.924 .34314 Mdot
.924 .34336 Mdot
.924 .34339 Mdot
.924 .3434 Mdot
.924 .34366 Mdot
.924 .34408 Mdot
.924 .34411 Mdot
.924 .34415 Mdot
.924 .34417 Mdot
.924 .34435 Mdot
.924 .34491 Mdot
.924 .34506 Mdot
.924 .34531 Mdot
.924 .34534 Mdot
.924 .34551 Mdot
.924 .34554 Mdot
.924 .34559 Mdot
.924 .34571 Mdot
.924 .34576 Mdot
.924 .34581 Mdot
.924 .34592 Mdot
.924 .346 Mdot
.924 .34635 Mdot
.924 .34642 Mdot
.924 .34664 Mdot
.924 .3469 Mdot
.924 .34693 Mdot
.924 .34694 Mdot
.924 .34696 Mdot
.924 .34708 Mdot
.924 .34714 Mdot
.924 .34717 Mdot
.924 .34725 Mdot
.924 .34803 Mdot
.924 .34886 Mdot
.924 .34898 Mdot
.924 .34956 Mdot
.924 .35147 Mdot
.924 .35155 Mdot
.924 .35202 Mdot
.924 .353 Mdot
.924 .35314 Mdot
.924 .35399 Mdot
.924 .35428 Mdot
.924 .35483 Mdot
.924 .35496 Mdot
.924 .35523 Mdot
.924 .35546 Mdot
.924 .35585 Mdot
.924 .35641 Mdot
.924 .35693 Mdot
.924 .35788 Mdot
.924 .35843 Mdot
.924 .35874 Mdot
.924 .35893 Mdot
.924 .35934 Mdot
.924 .36027 Mdot
.924 .36076 Mdot
.924 .36109 Mdot
.924 .36148 Mdot
.924 .36204 Mdot
.924 .36353 Mdot
.924 .3639 Mdot
.924 .36414 Mdot
.924 .36417 Mdot
.924 .36441 Mdot
.924 .3649 Mdot
.924 .36554 Mdot
.924 .36597 Mdot
.924 .36677 Mdot
.924 .36741 Mdot
.924 .36829 Mdot
.924 .36855 Mdot
.924 .36949 Mdot
.924 .36981 Mdot
.924 .37153 Mdot
.924 .37221 Mdot
.924 .37275 Mdot
.924 .37281 Mdot
.924 .37327 Mdot
.924 .37354 Mdot
.924 .37388 Mdot
.924 .37416 Mdot
.924 .37521 Mdot
.924 .37527 Mdot
.924 .37592 Mdot
.924 .37605 Mdot
.924 .37761 Mdot
.924 .37808 Mdot
.924 .37887 Mdot
.924 .38027 Mdot
.924 .38029 Mdot
.924 .38048 Mdot
.924 .38058 Mdot
.924 .38075 Mdot
.924 .3822 Mdot
.924 .38226 Mdot
.924 .38259 Mdot
.924 .38261 Mdot
.924 .38373 Mdot
.924 .38401 Mdot
.924 .38436 Mdot
.924 .38554 Mdot
.924 .38574 Mdot
.924 .38595 Mdot
.924 .38638 Mdot
.924 .38712 Mdot
.924 .38728 Mdot
.924 .3878 Mdot
.924 .38786 Mdot
.924 .38788 Mdot
.924 .3879 Mdot
.924 .38793 Mdot
.924 .388 Mdot
.924 .38809 Mdot
.924 .38816 Mdot
.924 .38823 Mdot
.924 .38833 Mdot
.924 .38837 Mdot
.924 .38841 Mdot
.924 .38845 Mdot
.924 .38858 Mdot
.924 .38883 Mdot
.924 .38892 Mdot
.924 .38899 Mdot
.924 .38904 Mdot
.924 .38927 Mdot
.924 .38927 Mdot
.924 .38937 Mdot
.924 .3895 Mdot
.924 .38953 Mdot
.924 .38988 Mdot
.924 .38994 Mdot
.924 .39027 Mdot
.924 .39032 Mdot
.924 .39039 Mdot
.924 .39045 Mdot
.924 .39048 Mdot
.924 .39076 Mdot
.924 .3912 Mdot
.924 .39138 Mdot
.924 .39139 Mdot
.924 .3914 Mdot
.924 .39148 Mdot
.924 .39153 Mdot
.924 .39158 Mdot
.924 .39167 Mdot
.924 .39167 Mdot
.924 .3917 Mdot
.924 .39171 Mdot
.924 .39177 Mdot
.924 .39183 Mdot
.924 .39183 Mdot
.924 .39186 Mdot
.924 .39187 Mdot
.924 .40992 Mdot
.924 .43059 Mdot
.924 .4337 Mdot
.924 .45513 Mdot
.924 .46436 Mdot
.924 .4798 Mdot
.924 .48279 Mdot
.924 .48771 Mdot
.924 .50318 Mdot
.924 .51226 Mdot
.924 .52438 Mdot
.924 .5281 Mdot
.924 .5281 Mdot
.924 .5281 Mdot
.924 .5281 Mdot
.924 .52811 Mdot
.924 .52811 Mdot
.924 .52811 Mdot
.924 .52811 Mdot
.924 .52811 Mdot
.924 .52811 Mdot
.924 .52812 Mdot
.924 .52812 Mdot
.924 .52812 Mdot
.924 .52812 Mdot
.924 .52812 Mdot
.924 .52813 Mdot
.924 .52815 Mdot
.924 .52816 Mdot
.924 .52816 Mdot
.924 .52817 Mdot
.924 .52817 Mdot
.924 .52817 Mdot
.924 .52819 Mdot
.924 .52819 Mdot
.924 .5282 Mdot
.924 .5282 Mdot
.924 .52821 Mdot
.924 .52821 Mdot
.924 .52821 Mdot
.924 .52822 Mdot
.924 .52823 Mdot
.924 .52823 Mdot
.924 .52823 Mdot
.924 .52824 Mdot
.924 .52825 Mdot
.924 .52825 Mdot
.924 .52825 Mdot
.924 .52826 Mdot
.924 .52826 Mdot
.924 .52826 Mdot
.924 .52827 Mdot
.924 .52827 Mdot
.924 .52827 Mdot
.924 .52827 Mdot
.924 .52827 Mdot
.924 .52828 Mdot
.924 .52828 Mdot
.924 .5283 Mdot
.924 .52831 Mdot
.924 .52834 Mdot
.924 .52836 Mdot
.924 .52837 Mdot
.924 .52838 Mdot
.924 .52843 Mdot
.924 .52845 Mdot
.924 .52846 Mdot
.924 .52851 Mdot
.924 .52851 Mdot
.924 .52852 Mdot
.924 .52853 Mdot
.924 .52859 Mdot
.924 .5286 Mdot
.924 .5286 Mdot
.924 .52861 Mdot
.924 .52861 Mdot
.924 .52868 Mdot
.924 .52871 Mdot
.924 .52873 Mdot
.924 .52881 Mdot
.924 .52881 Mdot
.924 .52884 Mdot
.924 .52885 Mdot
.924 .5289 Mdot
.924 .52891 Mdot
.924 .52892 Mdot
.924 .52894 Mdot
.924 .52896 Mdot
.924 .52896 Mdot
.924 .52902 Mdot
.924 .5291 Mdot
.924 .52912 Mdot
.924 .52916 Mdot
.924 .52918 Mdot
.924 .52922 Mdot
.924 .52925 Mdot
.924 .52931 Mdot
.924 .52935 Mdot
.924 .52937 Mdot
.924 .52938 Mdot
.924 .52938 Mdot
.924 .5294 Mdot
.924 .52941 Mdot
.924 .52949 Mdot
.924 .52952 Mdot
.924 .52954 Mdot
.924 .52956 Mdot
.924 .52958 Mdot
.924 .52963 Mdot
.924 .52965 Mdot
.924 .52966 Mdot
.924 .52968 Mdot
.924 .52971 Mdot
.924 .52976 Mdot
.924 .52979 Mdot
.924 .52982 Mdot
.924 .52984 Mdot
.924 .52986 Mdot
.924 .52987 Mdot
.924 .52988 Mdot
.924 .52992 Mdot
.924 .52998 Mdot
.924 .53004 Mdot
.924 .53006 Mdot
.924 .53007 Mdot
.924 .53018 Mdot
.924 .53022 Mdot
.924 .53022 Mdot
.924 .53027 Mdot
.924 .53034 Mdot
.924 .53043 Mdot
.924 .5305 Mdot
.924 .53055 Mdot
.924 .53057 Mdot
.924 .53062 Mdot
.924 .53065 Mdot
.924 .53066 Mdot
.924 .53067 Mdot
.924 .53067 Mdot
.924 .53077 Mdot
.924 .53081 Mdot
.924 .53084 Mdot
.924 .5309 Mdot
.924 .53096 Mdot
.924 .53103 Mdot
.924 .53118 Mdot
.924 .53137 Mdot
.924 .53138 Mdot
.924 .53153 Mdot
.924 .53155 Mdot
.924 .53168 Mdot
.924 .53189 Mdot
.924 .5319 Mdot
.924 .53204 Mdot
.924 .53204 Mdot
.924 .53215 Mdot
.924 .53219 Mdot
.924 .5322 Mdot
.924 .53231 Mdot
.924 .53237 Mdot
.924 .53237 Mdot
.924 .53241 Mdot
.924 .53242 Mdot
.924 .53246 Mdot
.924 .53267 Mdot
.924 .5327 Mdot
.924 .53278 Mdot
.924 .53288 Mdot
.924 .53297 Mdot
.924 .533 Mdot
.924 .53322 Mdot
.924 .5333 Mdot
.924 .53336 Mdot
.924 .53339 Mdot
.924 .53347 Mdot
.924 .53385 Mdot
.924 .5339 Mdot
.924 .53394 Mdot
.924 .53401 Mdot
.924 .53403 Mdot
.924 .53407 Mdot
.924 .53411 Mdot
.924 .53423 Mdot
.924 .53461 Mdot
.924 .53505 Mdot
.924 .53514 Mdot
.924 .53522 Mdot
.924 .53534 Mdot
.924 .53545 Mdot
.924 .53552 Mdot
.924 .53554 Mdot
.924 .53568 Mdot
.924 .53595 Mdot
.924 .53596 Mdot
.924 .53615 Mdot
.924 .53634 Mdot
.924 .5367 Mdot
.924 .5367 Mdot
.924 .53673 Mdot
.924 .53673 Mdot
.924 .53676 Mdot
.924 .5368 Mdot
.924 .53681 Mdot
.924 .53682 Mdot
.924 .53683 Mdot
.924 .53686 Mdot
.924 .53695 Mdot
.924 .53697 Mdot
.924 .53703 Mdot
.924 .53713 Mdot
.924 .53717 Mdot
.924 .53724 Mdot
.924 .53725 Mdot
.924 .53749 Mdot
.924 .53763 Mdot
.924 .53764 Mdot
.924 .53777 Mdot
.924 .53797 Mdot
.924 .538 Mdot
.924 .53804 Mdot
.924 .53809 Mdot
.924 .53811 Mdot
.924 .53847 Mdot
.924 .53851 Mdot
.924 .53917 Mdot
.924 .53934 Mdot
.924 .53965 Mdot
.924 .53969 Mdot
.924 .53999 Mdot
.924 .54035 Mdot
.924 .54043 Mdot
.924 .54051 Mdot
.924 .54058 Mdot
.924 .54077 Mdot
.924 .54088 Mdot
.924 .54125 Mdot
.924 .5417 Mdot
.924 .54185 Mdot
.924 .54194 Mdot
.924 .54268 Mdot
.924 .54275 Mdot
.924 .54304 Mdot
.924 .54322 Mdot
.924 .54327 Mdot
.924 .54328 Mdot
.924 .54379 Mdot
.924 .54392 Mdot
.924 .54396 Mdot
.924 .54398 Mdot
.924 .54408 Mdot
.924 .54427 Mdot
.924 .54438 Mdot
.924 .54443 Mdot
.924 .54464 Mdot
.924 .54484 Mdot
.924 .54512 Mdot
.924 .54518 Mdot
.924 .5452 Mdot
.924 .54527 Mdot
.924 .54537 Mdot
.924 .54559 Mdot
.924 .54573 Mdot
.924 .54588 Mdot
.924 .54606 Mdot
.924 .54621 Mdot
.924 .54627 Mdot
.924 .5463 Mdot
.924 .54636 Mdot
.924 .54641 Mdot
.924 .54647 Mdot
.924 .54706 Mdot
.924 .54749 Mdot
.924 .54752 Mdot
.924 .54783 Mdot
.924 .54799 Mdot
.924 .54872 Mdot
.924 .54922 Mdot
.924 .54997 Mdot
.924 .55018 Mdot
.924 .55033 Mdot
.924 .55056 Mdot
.924 .55067 Mdot
.924 .551 Mdot
.924 .55127 Mdot
.924 .55131 Mdot
.924 .55159 Mdot
.924 .55214 Mdot
.924 .55249 Mdot
.924 .55272 Mdot
.924 .55285 Mdot
.924 .55295 Mdot
.924 .55299 Mdot
.924 .55331 Mdot
.924 .55338 Mdot
.924 .55413 Mdot
.924 .55473 Mdot
.924 .55476 Mdot
.924 .55479 Mdot
.924 .55515 Mdot
.924 .55522 Mdot
.924 .55552 Mdot
.924 .55574 Mdot
.924 .55648 Mdot
.924 .5566 Mdot
.924 .55671 Mdot
.924 .55673 Mdot
.924 .55682 Mdot
.924 .55696 Mdot
.924 .55698 Mdot
.924 .55775 Mdot
.924 .55787 Mdot
.924 .55807 Mdot
.924 .55824 Mdot
.924 .55828 Mdot
.924 .5583 Mdot
.924 .55841 Mdot
.924 .55845 Mdot
.924 .55852 Mdot
.924 .5586 Mdot
.924 .55865 Mdot
.924 .55868 Mdot
.924 .55874 Mdot
.924 .55875 Mdot
.924 .55876 Mdot
.924 .55876 Mdot
.926 .11267 Mdot
.926 .11343 Mdot
.926 .11354 Mdot
.926 .11498 Mdot
.926 .11536 Mdot
.926 .11571 Mdot
.926 .11572 Mdot
.926 .11572 Mdot
.926 .11572 Mdot
.926 .11573 Mdot
.926 .11574 Mdot
.926 .11574 Mdot
.926 .11575 Mdot
.926 .11576 Mdot
.926 .11576 Mdot
.926 .1158 Mdot
.926 .11587 Mdot
.926 .11592 Mdot
.926 .11602 Mdot
.926 .11608 Mdot
.926 .11611 Mdot
.926 .11623 Mdot
.926 .11624 Mdot
.926 .11628 Mdot
.926 .11632 Mdot
.926 .11639 Mdot
.926 .11642 Mdot
.926 .11682 Mdot
.926 .11684 Mdot
.926 .11694 Mdot
.926 .11694 Mdot
.926 .11724 Mdot
.926 .11726 Mdot
.926 .11735 Mdot
.926 .11739 Mdot
.926 .11745 Mdot
.926 .11763 Mdot
.926 .11776 Mdot
.926 .11784 Mdot
.926 .11787 Mdot
.926 .11797 Mdot
.926 .11833 Mdot
.926 .11849 Mdot
.926 .11859 Mdot
.926 .11894 Mdot
.926 .11911 Mdot
.926 .11916 Mdot
.926 .11966 Mdot
.926 .1199 Mdot
.926 .12008 Mdot
.926 .12061 Mdot
.926 .12214 Mdot
.926 .12295 Mdot
.926 .12363 Mdot
.926 .12503 Mdot
.926 .12544 Mdot
.926 .12966 Mdot
.926 .12975 Mdot
.926 .13188 Mdot
.926 .13504 Mdot
.926 .13597 Mdot
.926 .13686 Mdot
.926 .13751 Mdot
.926 .14031 Mdot
.926 .14108 Mdot
.926 .14598 Mdot
.926 .14942 Mdot
.926 .15028 Mdot
.926 .15323 Mdot
.926 .15367 Mdot
.926 .15435 Mdot
.926 .15948 Mdot
.926 .16108 Mdot
.926 .16251 Mdot
.926 .16256 Mdot
.926 .16257 Mdot
.926 .16259 Mdot
.926 .1626 Mdot
.926 .16264 Mdot
.926 .16266 Mdot
.926 .1627 Mdot
.926 .16274 Mdot
.926 .16275 Mdot
.926 .16291 Mdot
.926 .1632 Mdot
.926 .16341 Mdot
.926 .16385 Mdot
.926 .1641 Mdot
.926 .16424 Mdot
.926 .16458 Mdot
.926 .16474 Mdot
.926 .16478 Mdot
.926 .16496 Mdot
.926 .16511 Mdot
.926 .16545 Mdot
.926 .16557 Mdot
.926 .16729 Mdot
.926 .16737 Mdot
.926 .16779 Mdot
.926 .16783 Mdot
.926 .16914 Mdot
.926 .16921 Mdot
.926 .16961 Mdot
.926 .1698 Mdot
.926 .17003 Mdot
.926 .1707 Mdot
.926 .17086 Mdot
.926 .17113 Mdot
.926 .17142 Mdot
.926 .17178 Mdot
.926 .17192 Mdot
.926 .17237 Mdot
.926 .17396 Mdot
.926 .17464 Mdot
.926 .1747 Mdot
.926 .17477 Mdot
.926 .17481 Mdot
.926 .17515 Mdot
.926 .1766 Mdot
.926 .17671 Mdot
.926 .1775 Mdot
.926 .17776 Mdot
.926 .17897 Mdot
.926 .17915 Mdot
.926 .17972 Mdot
.926 .17983 Mdot
.926 .17997 Mdot
.926 .18003 Mdot
.926 .18005 Mdot
.926 .18114 Mdot
.926 .18162 Mdot
.926 .1819 Mdot
.926 .182 Mdot
.926 .18203 Mdot
.926 .18437 Mdot
.926 .18443 Mdot
.926 .1845 Mdot
.926 .18458 Mdot
.926 .18475 Mdot
.926 .18544 Mdot
.926 .1858 Mdot
.926 .18709 Mdot
.926 .1876 Mdot
.926 .18822 Mdot
.926 .18877 Mdot
.926 .1888 Mdot
.926 .18895 Mdot
.926 .18923 Mdot
.926 .19175 Mdot
.926 .19191 Mdot
.926 .19227 Mdot
.926 .19278 Mdot
.926 .19321 Mdot
.926 .19329 Mdot
.926 .19456 Mdot
.926 .19526 Mdot
.926 .19568 Mdot
.926 .19581 Mdot
.926 .1973 Mdot
.926 .19805 Mdot
.926 .19836 Mdot
.926 .19899 Mdot
.926 .19962 Mdot
.926 .19984 Mdot
.926 .20015 Mdot
.926 .20164 Mdot
.926 .20222 Mdot
.926 .2033 Mdot
.926 .20361 Mdot
.926 .20455 Mdot
.926 .20509 Mdot
.926 .20594 Mdot
.926 .20604 Mdot
.926 .20606 Mdot
.926 .20664 Mdot
.926 .20694 Mdot
.926 .20697 Mdot
.926 .20743 Mdot
.926 .2075 Mdot
.926 .20795 Mdot
.926 .208 Mdot
.926 .20848 Mdot
.926 .20859 Mdot
.926 .20863 Mdot
.926 .20876 Mdot
.926 .20916 Mdot
.926 .20996 Mdot
.926 .21037 Mdot
.926 .21103 Mdot
.926 .21109 Mdot
.926 .21131 Mdot
.926 .21132 Mdot
.926 .21155 Mdot
.926 .21181 Mdot
.926 .21183 Mdot
.926 .21184 Mdot
.926 .21194 Mdot
.926 .21198 Mdot
.926 .21202 Mdot
.926 .21215 Mdot
.926 .21227 Mdot
.926 .2123 Mdot
.926 .21233 Mdot
.926 .21263 Mdot
.926 .21268 Mdot
.926 .21269 Mdot
.926 .21273 Mdot
.926 .21276 Mdot
.926 .21279 Mdot
.926 .21286 Mdot
.926 .21318 Mdot
.926 .21346 Mdot
.926 .21356 Mdot
.926 .21408 Mdot
.926 .21408 Mdot
.926 .21417 Mdot
.926 .21431 Mdot
.926 .21471 Mdot
.926 .21483 Mdot
.926 .21485 Mdot
.926 .21506 Mdot
.926 .21551 Mdot
.926 .21551 Mdot
.926 .21577 Mdot
.926 .21593 Mdot
.926 .21604 Mdot
.926 .21605 Mdot
.926 .2164 Mdot
.926 .21652 Mdot
.926 .21683 Mdot
.926 .21686 Mdot
.926 .21694 Mdot
.926 .21702 Mdot
.926 .21726 Mdot
.926 .21729 Mdot
.926 .21739 Mdot
.926 .21743 Mdot
.926 .2175 Mdot
.926 .21769 Mdot
.926 .21779 Mdot
.926 .21783 Mdot
.926 .21789 Mdot
.926 .21806 Mdot
.926 .21808 Mdot
.926 .2181 Mdot
.926 .21816 Mdot
.926 .21819 Mdot
.926 .21825 Mdot
.926 .21835 Mdot
.926 .21847 Mdot
.926 .21867 Mdot
.926 .21903 Mdot
.926 .21914 Mdot
.926 .21944 Mdot
.926 .21944 Mdot
.926 .21972 Mdot
.926 .21993 Mdot
.926 .22009 Mdot
.926 .22017 Mdot
.926 .22025 Mdot
.926 .22032 Mdot
.926 .22033 Mdot
.926 .22048 Mdot
.926 .22093 Mdot
.926 .22106 Mdot
.926 .22107 Mdot
.926 .22114 Mdot
.926 .2215 Mdot
.926 .22168 Mdot
.926 .22172 Mdot
.926 .22183 Mdot
.926 .22204 Mdot
.926 .22212 Mdot
.926 .22232 Mdot
.926 .22247 Mdot
.926 .2225 Mdot
.926 .2226 Mdot
.926 .2226 Mdot
.926 .22277 Mdot
.926 .22281 Mdot
.926 .22286 Mdot
.926 .22291 Mdot
.926 .22302 Mdot
.926 .22307 Mdot
.926 .22319 Mdot
.926 .22321 Mdot
.926 .22327 Mdot
.926 .22331 Mdot
.926 .22343 Mdot
.926 .22353 Mdot
.926 .22362 Mdot
.926 .22426 Mdot
.926 .22442 Mdot
.926 .22445 Mdot
.926 .22451 Mdot
.926 .22464 Mdot
.926 .22476 Mdot
.926 .2249 Mdot
.926 .22491 Mdot
.926 .22511 Mdot
.926 .22512 Mdot
.926 .22529 Mdot
.926 .22531 Mdot
.926 .2256 Mdot
.926 .22583 Mdot
.926 .22611 Mdot
.926 .22636 Mdot
.926 .22655 Mdot
.926 .22682 Mdot
.926 .22687 Mdot
.926 .22704 Mdot
.926 .22708 Mdot
.926 .22714 Mdot
.926 .2272 Mdot
.926 .22741 Mdot
.926 .22757 Mdot
.926 .22758 Mdot
.926 .22792 Mdot
.926 .22796 Mdot
.926 .22809 Mdot
.926 .22815 Mdot
.926 .22824 Mdot
.926 .2284 Mdot
.926 .22847 Mdot
.926 .22849 Mdot
.926 .22852 Mdot
.926 .22858 Mdot
.926 .22859 Mdot
.926 .22861 Mdot
.926 .22866 Mdot
.926 .22867 Mdot
.926 .22869 Mdot
.926 .22874 Mdot
.926 .22876 Mdot
.926 .22876 Mdot
.926 .22877 Mdot
.926 .22879 Mdot
.926 .22882 Mdot
.926 .22883 Mdot
.926 .22884 Mdot
.926 .22885 Mdot
.926 .22885 Mdot
.926 .2289 Mdot
.926 .2289 Mdot
.926 .22892 Mdot
.926 .22892 Mdot
.926 .22899 Mdot
.926 .22899 Mdot
.926 .22901 Mdot
.926 .22901 Mdot
.926 .22902 Mdot
.926 .22902 Mdot
.926 .22904 Mdot
.926 .22905 Mdot
.926 .22906 Mdot
.926 .22908 Mdot
.926 .22909 Mdot
.926 .2291 Mdot
.926 .22911 Mdot
.926 .22911 Mdot
.926 .22911 Mdot
.926 .22911 Mdot
.926 .22912 Mdot
.926 .22912 Mdot
.926 .22912 Mdot
.926 .22912 Mdot
.926 .22912 Mdot
.926 .22912 Mdot
.926 .22919 Mdot
.926 .22968 Mdot
.926 .24038 Mdot
.926 .25604 Mdot
.926 .26059 Mdot
.926 .26485 Mdot
.926 .26793 Mdot
.926 .28081 Mdot
.926 .28423 Mdot
.926 .28803 Mdot
.926 .3043 Mdot
.926 .31648 Mdot
.926 .31727 Mdot
.926 .31728 Mdot
.926 .31732 Mdot
.926 .3174 Mdot
.926 .31743 Mdot
.926 .31758 Mdot
.926 .31762 Mdot
.926 .31766 Mdot
.926 .31766 Mdot
.926 .31789 Mdot
.926 .31803 Mdot
.926 .31804 Mdot
.926 .31815 Mdot
.926 .31828 Mdot
.926 .3183 Mdot
.926 .31832 Mdot
.926 .31842 Mdot
.926 .3186 Mdot
.926 .31863 Mdot
.926 .31878 Mdot
.926 .31896 Mdot
.926 .31905 Mdot
.926 .31907 Mdot
.926 .31918 Mdot
.926 .31918 Mdot
.926 .3192 Mdot
.926 .3194 Mdot
.926 .3195 Mdot
.926 .31996 Mdot
.926 .32023 Mdot
.926 .32064 Mdot
.926 .32125 Mdot
.926 .32137 Mdot
.926 .32138 Mdot
.926 .32145 Mdot
.926 .3217 Mdot
.926 .32172 Mdot
.926 .32177 Mdot
.926 .322 Mdot
.926 .32233 Mdot
.926 .32236 Mdot
.926 .32237 Mdot
.926 .32248 Mdot
.926 .3225 Mdot
.926 .32256 Mdot
.926 .32261 Mdot
.926 .32278 Mdot
.926 .32294 Mdot
.926 .32299 Mdot
.926 .32303 Mdot
.926 .32345 Mdot
.926 .32352 Mdot
.926 .32354 Mdot
.926 .32359 Mdot
.926 .32364 Mdot
.926 .32368 Mdot
.926 .32379 Mdot
.926 .32384 Mdot
.926 .32393 Mdot
.926 .32427 Mdot
.926 .32442 Mdot
.926 .32471 Mdot
.926 .32487 Mdot
.926 .32501 Mdot
.926 .32545 Mdot
.926 .32563 Mdot
.926 .32572 Mdot
.926 .32573 Mdot
.926 .32587 Mdot
.926 .32611 Mdot
.926 .32683 Mdot
.926 .32704 Mdot
.926 .32709 Mdot
.926 .32747 Mdot
.926 .32774 Mdot
.926 .32832 Mdot
.926 .32832 Mdot
.926 .32882 Mdot
.926 .32884 Mdot
.926 .32887 Mdot
.926 .32916 Mdot
.926 .3292 Mdot
.926 .32938 Mdot
.926 .32939 Mdot
.926 .32941 Mdot
.926 .32944 Mdot
.926 .33012 Mdot
.926 .33016 Mdot
.926 .33039 Mdot
.926 .33059 Mdot
.926 .33098 Mdot
.926 .33105 Mdot
.926 .33111 Mdot
.926 .33129 Mdot
.926 .33146 Mdot
.926 .33167 Mdot
.926 .332 Mdot
.926 .33207 Mdot
.926 .33229 Mdot
.926 .33238 Mdot
.926 .33255 Mdot
.926 .33298 Mdot
.926 .33321 Mdot
.926 .33331 Mdot
.926 .33342 Mdot
.926 .33344 Mdot
.926 .33386 Mdot
.926 .3339 Mdot
.926 .3339 Mdot
.926 .33394 Mdot
.926 .33409 Mdot
.926 .33417 Mdot
.926 .33431 Mdot
.926 .33456 Mdot
.926 .33482 Mdot
.926 .33485 Mdot
.926 .33504 Mdot
.926 .33516 Mdot
.926 .33525 Mdot
.926 .33533 Mdot
.926 .33535 Mdot
.926 .33626 Mdot
.926 .33652 Mdot
.926 .33732 Mdot
.926 .33733 Mdot
.926 .33804 Mdot
.926 .33836 Mdot
.926 .3384 Mdot
.926 .33853 Mdot
.926 .33862 Mdot
.926 .33887 Mdot
.926 .33905 Mdot
.926 .33927 Mdot
.926 .33946 Mdot
.926 .33949 Mdot
.926 .33969 Mdot
.926 .33972 Mdot
.926 .34012 Mdot
.926 .34075 Mdot
.926 .34078 Mdot
.926 .34084 Mdot
.926 .34085 Mdot
.926 .34101 Mdot
.926 .34113 Mdot
.926 .34142 Mdot
.926 .34177 Mdot
.926 .3418 Mdot
.926 .34181 Mdot
.926 .34197 Mdot
.926 .34203 Mdot
.926 .34225 Mdot
.926 .34308 Mdot
.926 .34311 Mdot
.926 .34323 Mdot
.926 .34349 Mdot
.926 .34362 Mdot
.926 .34375 Mdot
.926 .34408 Mdot
.926 .34423 Mdot
.926 .34428 Mdot
.926 .34433 Mdot
.926 .34472 Mdot
.926 .34475 Mdot
.926 .3448 Mdot
.926 .34481 Mdot
.926 .34483 Mdot
.926 .34484 Mdot
.926 .34488 Mdot
.926 .34491 Mdot
.926 .34494 Mdot
.926 .34496 Mdot
.926 .34498 Mdot
.926 .34499 Mdot
.926 .34515 Mdot
.926 .34542 Mdot
.926 .34554 Mdot
.926 .34556 Mdot
.926 .3456 Mdot
.926 .34579 Mdot
.926 .34581 Mdot
.926 .34586 Mdot
.926 .34591 Mdot
.926 .34597 Mdot
.926 .34605 Mdot
.926 .34614 Mdot
.926 .34617 Mdot
.926 .34627 Mdot
.926 .34636 Mdot
.926 .34644 Mdot
.926 .34644 Mdot
.926 .34652 Mdot
.926 .34663 Mdot
.926 .34665 Mdot
.926 .34677 Mdot
.926 .34686 Mdot
.926 .34698 Mdot
.926 .34705 Mdot
.926 .34712 Mdot
.926 .34712 Mdot
.926 .34723 Mdot
.926 .34728 Mdot
.926 .34741 Mdot
.926 .34745 Mdot
.926 .34747 Mdot
.926 .34759 Mdot
.926 .34768 Mdot
.926 .34776 Mdot
.926 .34778 Mdot
.926 .34778 Mdot
.926 .3478 Mdot
.926 .3478 Mdot
.926 .34789 Mdot
.926 .3479 Mdot
.926 .34792 Mdot
.926 .34795 Mdot
.926 .34796 Mdot
.926 .34797 Mdot
.926 .34799 Mdot
.926 .348 Mdot
.926 .34832 Mdot
.926 .34842 Mdot
.926 .34859 Mdot
.926 .34873 Mdot
.926 .34912 Mdot
.926 .34944 Mdot
.926 .34973 Mdot
.926 .35191 Mdot
.926 .35243 Mdot
.926 .35256 Mdot
.926 .35276 Mdot
.926 .35322 Mdot
.926 .35363 Mdot
.926 .35412 Mdot
.926 .35415 Mdot
.926 .35486 Mdot
.926 .35489 Mdot
.926 .35548 Mdot
.926 .35556 Mdot
.926 .35662 Mdot
.926 .35846 Mdot
.926 .3594 Mdot
.926 .3601 Mdot
.926 .36114 Mdot
.926 .36131 Mdot
.926 .36196 Mdot
.926 .36212 Mdot
.926 .36233 Mdot
.926 .36256 Mdot
.926 .36339 Mdot
.926 .364 Mdot
.926 .36402 Mdot
.926 .36537 Mdot
.926 .36551 Mdot
.926 .36603 Mdot
.926 .36629 Mdot
.926 .36662 Mdot
.926 .36729 Mdot
.926 .36754 Mdot
.926 .36763 Mdot
.926 .36775 Mdot
.926 .368 Mdot
.926 .36803 Mdot
.926 .36812 Mdot
.926 .3683 Mdot
.926 .36836 Mdot
.926 .36845 Mdot
.926 .36865 Mdot
.926 .36871 Mdot
.926 .36873 Mdot
.926 .36878 Mdot
.926 .36886 Mdot
.926 .36897 Mdot
.926 .36901 Mdot
.926 .36903 Mdot
.926 .36909 Mdot
.926 .3691 Mdot
.926 .36929 Mdot
.926 .3693 Mdot
.926 .36937 Mdot
.926 .36938 Mdot
.926 .36965 Mdot
.926 .36967 Mdot
.926 .36973 Mdot
.926 .36976 Mdot
.926 .36979 Mdot
.926 .36979 Mdot
.926 .36988 Mdot
.926 .36991 Mdot
.926 .36995 Mdot
.926 .37003 Mdot
.926 .37007 Mdot
.926 .37012 Mdot
.926 .37015 Mdot
.926 .37015 Mdot
.926 .37016 Mdot
.926 .37017 Mdot
.926 .37017 Mdot
.926 .37018 Mdot
.926 .37018 Mdot
.926 .37019 Mdot
.926 .37019 Mdot
.926 .3702 Mdot
.926 .37048 Mdot
.926 .3725 Mdot
.926 .4032 Mdot
.926 .42238 Mdot
.926 .49679 Mdot
.926 .49842 Mdot
.926 .5169 Mdot
.926 .52921 Mdot
.926 .52921 Mdot
.926 .52921 Mdot
.926 .52921 Mdot
.926 .52921 Mdot
.926 .52921 Mdot
.926 .52921 Mdot
.926 .52921 Mdot
.926 .52922 Mdot
.926 .52922 Mdot
.926 .52922 Mdot
.926 .52922 Mdot
.926 .52922 Mdot
.926 .52923 Mdot
.926 .52923 Mdot
.926 .52923 Mdot
.926 .52923 Mdot
.926 .52923 Mdot
.926 .52923 Mdot
.926 .52924 Mdot
.926 .52924 Mdot
.926 .52924 Mdot
.926 .52925 Mdot
.926 .52925 Mdot
.926 .52926 Mdot
.926 .52926 Mdot
.926 .52927 Mdot
.926 .52927 Mdot
.926 .52927 Mdot
.926 .52927 Mdot
.926 .52927 Mdot
.926 .52928 Mdot
.926 .52928 Mdot
.926 .52928 Mdot
.926 .52929 Mdot
.926 .52929 Mdot
.926 .5293 Mdot
.926 .5293 Mdot
.926 .52931 Mdot
.926 .52931 Mdot
.926 .52932 Mdot
.926 .52932 Mdot
.926 .52933 Mdot
.926 .52934 Mdot
.926 .52934 Mdot
.926 .52936 Mdot
.926 .52939 Mdot
.926 .5294 Mdot
.926 .52942 Mdot
.926 .52944 Mdot
.926 .52945 Mdot
.926 .52952 Mdot
.926 .52952 Mdot
.926 .52955 Mdot
.926 .52959 Mdot
.926 .52961 Mdot
.926 .52962 Mdot
.926 .52963 Mdot
.926 .52966 Mdot
.926 .52967 Mdot
.926 .52972 Mdot
.926 .52976 Mdot
.926 .52981 Mdot
.926 .52987 Mdot
.926 .52991 Mdot
.926 .52997 Mdot
.926 .52997 Mdot
.926 .53001 Mdot
.926 .53001 Mdot
.926 .53005 Mdot
.926 .53005 Mdot
.926 .53008 Mdot
.926 .5301 Mdot
.926 .53013 Mdot
.926 .53014 Mdot
.926 .53014 Mdot
.926 .53017 Mdot
.926 .5303 Mdot
.926 .53032 Mdot
.926 .53034 Mdot
.926 .53036 Mdot
.926 .53037 Mdot
.926 .53038 Mdot
.926 .53039 Mdot
.926 .53041 Mdot
.926 .53042 Mdot
.926 .53044 Mdot
.926 .53045 Mdot
.926 .53046 Mdot
.926 .53047 Mdot
.926 .5305 Mdot
.926 .5305 Mdot
.926 .53052 Mdot
.926 .53053 Mdot
.926 .53056 Mdot
.926 .5306 Mdot
.926 .53061 Mdot
.926 .53066 Mdot
.926 .53068 Mdot
.926 .53069 Mdot
.926 .53072 Mdot
.926 .53079 Mdot
.926 .53081 Mdot
.926 .53081 Mdot
.926 .53083 Mdot
.926 .53093 Mdot
.926 .53095 Mdot
.926 .53096 Mdot
.926 .53097 Mdot
.926 .53099 Mdot
.926 .531 Mdot
.926 .53103 Mdot
.926 .53108 Mdot
.926 .53113 Mdot
.926 .53113 Mdot
.926 .53119 Mdot
.926 .53121 Mdot
.926 .53128 Mdot
.926 .53132 Mdot
.926 .53135 Mdot
.926 .53137 Mdot
.926 .53138 Mdot
.926 .53138 Mdot
.926 .5314 Mdot
.926 .5314 Mdot
.926 .5314 Mdot
.926 .53144 Mdot
.926 .53145 Mdot
.926 .53146 Mdot
.926 .53148 Mdot
.926 .53152 Mdot
.926 .53153 Mdot
.926 .53154 Mdot
.926 .53156 Mdot
.926 .53156 Mdot
.926 .53161 Mdot
.926 .53163 Mdot
.926 .53164 Mdot
.926 .53165 Mdot
.926 .53171 Mdot
.926 .53173 Mdot
.926 .5318 Mdot
.926 .53181 Mdot
.926 .53183 Mdot
.926 .53186 Mdot
.926 .53191 Mdot
.926 .53191 Mdot
.926 .532 Mdot
.926 .53204 Mdot
.926 .53205 Mdot
.926 .53207 Mdot
.926 .53215 Mdot
.926 .53218 Mdot
.926 .5322 Mdot
.926 .5322 Mdot
.926 .5323 Mdot
.926 .53232 Mdot
.926 .53238 Mdot
.926 .53244 Mdot
.926 .53245 Mdot
.926 .53246 Mdot
.926 .53247 Mdot
.926 .53247 Mdot
.926 .53248 Mdot
.926 .53248 Mdot
.926 .53255 Mdot
.926 .53255 Mdot
.926 .53256 Mdot
.926 .53258 Mdot
.926 .53261 Mdot
.926 .53261 Mdot
.926 .53262 Mdot
.926 .53264 Mdot
.926 .53264 Mdot
.926 .53265 Mdot
.926 .5327 Mdot
.926 .53275 Mdot
.926 .53275 Mdot
.926 .53279 Mdot
.926 .5328 Mdot
.926 .53294 Mdot
.926 .53302 Mdot
.926 .53318 Mdot
.926 .53326 Mdot
.926 .53328 Mdot
.926 .53329 Mdot
.926 .53331 Mdot
.926 .53341 Mdot
.926 .53351 Mdot
.926 .53353 Mdot
.926 .53362 Mdot
.926 .53362 Mdot
.926 .53368 Mdot
.926 .5338 Mdot
.926 .5338 Mdot
.926 .53399 Mdot
.926 .5341 Mdot
.926 .53429 Mdot
.926 .53436 Mdot
.926 .53458 Mdot
.926 .53469 Mdot
.926 .53499 Mdot
.926 .53506 Mdot
.926 .5351 Mdot
.926 .53536 Mdot
.926 .53542 Mdot
.926 .53558 Mdot
.926 .53588 Mdot
.926 .536 Mdot
.926 .53614 Mdot
.926 .5364 Mdot
.926 .53642 Mdot
.926 .53651 Mdot
.926 .53661 Mdot
.926 .53669 Mdot
.926 .53724 Mdot
.926 .5373 Mdot
.926 .53734 Mdot
.926 .53734 Mdot
.926 .53746 Mdot
.926 .53759 Mdot
.926 .53769 Mdot
.926 .53797 Mdot
.926 .53804 Mdot
.926 .53819 Mdot
.926 .53822 Mdot
.926 .53826 Mdot
.926 .53827 Mdot
.926 .53877 Mdot
.926 .5388 Mdot
.926 .53886 Mdot
.926 .53919 Mdot
.926 .53921 Mdot
.926 .53924 Mdot
.926 .53927 Mdot
.926 .53939 Mdot
.926 .53943 Mdot
.926 .53995 Mdot
.926 .54034 Mdot
.926 .54035 Mdot
.926 .54038 Mdot
.926 .54116 Mdot
.926 .54126 Mdot
.926 .54266 Mdot
.926 .54514 Mdot
.926 .54641 Mdot
.926 .54734 Mdot
.926 .54871 Mdot
.926 .54893 Mdot
.926 .54977 Mdot
.926 .54996 Mdot
.926 .55024 Mdot
.926 .55053 Mdot
.926 .55155 Mdot
.926 .55227 Mdot
.926 .5523 Mdot
.926 .55383 Mdot
.926 .55399 Mdot
.926 .55454 Mdot
.926 .55481 Mdot
.926 .55514 Mdot
.926 .55579 Mdot
.926 .55602 Mdot
.926 .55611 Mdot
.926 .55621 Mdot
.926 .55644 Mdot
.926 .55646 Mdot
.926 .55654 Mdot
.926 .5567 Mdot
.926 .55675 Mdot
.926 .55683 Mdot
.926 .557 Mdot
.926 .55705 Mdot
.926 .55706 Mdot
.926 .5571 Mdot
.926 .55716 Mdot
.926 .55725 Mdot
.926 .55728 Mdot
.926 .5573 Mdot
.926 .55735 Mdot
.926 .55735 Mdot
.926 .5575 Mdot
.926 .55751 Mdot
.926 .55755 Mdot
.926 .55756 Mdot
.926 .55777 Mdot
.926 .55778 Mdot
.926 .55782 Mdot
.926 .55784 Mdot
.926 .55786 Mdot
.926 .55787 Mdot
.926 .55793 Mdot
.926 .55794 Mdot
.926 .55798 Mdot
.926 .55803 Mdot
.926 .55806 Mdot
.926 .55809 Mdot
.926 .55811 Mdot
.926 .55811 Mdot
.926 .55812 Mdot
.926 .55812 Mdot
.926 .55813 Mdot
.926 .55813 Mdot
.926 .55813 Mdot
.926 .55813 Mdot
.926 .55814 Mdot
.926 .55814 Mdot
.926 .55832 Mdot
.926 .55853 Mdot
.926 .55936 Mdot
.926 .55943 Mdot
.926 .5599 Mdot
.928 .175 Mdot
.928 .1751 Mdot
.928 .17642 Mdot
.928 .1774 Mdot
.928 .17743 Mdot
.928 .17756 Mdot
.928 .17794 Mdot
.928 .17809 Mdot
.928 .17811 Mdot
.928 .17867 Mdot
.928 .17875 Mdot
.928 .17881 Mdot
.928 .17927 Mdot
.928 .17974 Mdot
.928 .17996 Mdot
.928 .18018 Mdot
.928 .18024 Mdot
.928 .18104 Mdot
.928 .18124 Mdot
.928 .18147 Mdot
.928 .18147 Mdot
.928 .18152 Mdot
.928 .18154 Mdot
.928 .18157 Mdot
.928 .18157 Mdot
.928 .1816 Mdot
.928 .18184 Mdot
.928 .18192 Mdot
.928 .18221 Mdot
.928 .18221 Mdot
.928 .18231 Mdot
.928 .18236 Mdot
.928 .1824 Mdot
.928 .18278 Mdot
.928 .18285 Mdot
.928 .18309 Mdot
.928 .18333 Mdot
.928 .18349 Mdot
.928 .18409 Mdot
.928 .18608 Mdot
.928 .18705 Mdot
.928 .18723 Mdot
.928 .18786 Mdot
.928 .18854 Mdot
.928 .18859 Mdot
.928 .18859 Mdot
.928 .1886 Mdot
.928 .1886 Mdot
.928 .18863 Mdot
.928 .18864 Mdot
.928 .18866 Mdot
.928 .18866 Mdot
.928 .18866 Mdot
.928 .18867 Mdot
.928 .18867 Mdot
.928 .18871 Mdot
.928 .18879 Mdot
.928 .18881 Mdot
.928 .18888 Mdot
.928 .18892 Mdot
.928 .18893 Mdot
.928 .18899 Mdot
.928 .18904 Mdot
.928 .18905 Mdot
.928 .18905 Mdot
.928 .18943 Mdot
.928 .18957 Mdot
.928 .18965 Mdot
.928 .18974 Mdot
.928 .18979 Mdot
.928 .18989 Mdot
.928 .18991 Mdot
.928 .19 Mdot
.928 .19017 Mdot
.928 .19072 Mdot
.928 .19079 Mdot
.928 .19116 Mdot
.928 .1912 Mdot
.928 .19129 Mdot
.928 .19133 Mdot
.928 .1915 Mdot
.928 .19193 Mdot
.928 .19206 Mdot
.928 .19215 Mdot
.928 .19309 Mdot
.928 .19315 Mdot
.928 .19325 Mdot
.928 .19331 Mdot
.928 .19368 Mdot
.928 .19382 Mdot
.928 .19383 Mdot
.928 .19408 Mdot
.928 .19416 Mdot
.928 .1942 Mdot
.928 .19443 Mdot
.928 .19475 Mdot
.928 .19486 Mdot
.928 .19492 Mdot
.928 .19501 Mdot
.928 .19501 Mdot
.928 .19506 Mdot
.928 .19517 Mdot
.928 .19558 Mdot
.928 .1956 Mdot
.928 .19566 Mdot
.928 .19606 Mdot
.928 .19622 Mdot
.928 .19665 Mdot
.928 .19693 Mdot
.928 .19732 Mdot
.928 .19763 Mdot
.928 .19808 Mdot
.928 .1984 Mdot
.928 .19876 Mdot
.928 .19898 Mdot
.928 .19911 Mdot
.928 .19922 Mdot
.928 .19956 Mdot
.928 .19971 Mdot
.928 .19994 Mdot
.928 .20044 Mdot
.928 .20054 Mdot
.928 .20064 Mdot
.928 .20103 Mdot
.928 .2012 Mdot
.928 .20141 Mdot
.928 .20143 Mdot
.928 .202 Mdot
.928 .20224 Mdot
.928 .20263 Mdot
.928 .20286 Mdot
.928 .20298 Mdot
.928 .20388 Mdot
.928 .20402 Mdot
.928 .20446 Mdot
.928 .20506 Mdot
.928 .2052 Mdot
.928 .2053 Mdot
.928 .20533 Mdot
.928 .20545 Mdot
.928 .20577 Mdot
.928 .206 Mdot
.928 .20623 Mdot
.928 .20683 Mdot
.928 .20721 Mdot
.928 .20735 Mdot
.928 .20755 Mdot
.928 .20766 Mdot
.928 .20816 Mdot
.928 .20825 Mdot
.928 .20826 Mdot
.928 .20851 Mdot
.928 .20856 Mdot
.928 .2087 Mdot
.928 .20876 Mdot
.928 .20877 Mdot
.928 .20879 Mdot
.928 .209 Mdot
.928 .20946 Mdot
.928 .20949 Mdot
.928 .20984 Mdot
.928 .20999 Mdot
.928 .21031 Mdot
.928 .21057 Mdot
.928 .21087 Mdot
.928 .21111 Mdot
.928 .21114 Mdot
.928 .21127 Mdot
.928 .21131 Mdot
.928 .21193 Mdot
.928 .21219 Mdot
.928 .21222 Mdot
.928 .21251 Mdot
.928 .21263 Mdot
.928 .21285 Mdot
.928 .21289 Mdot
.928 .21301 Mdot
.928 .21306 Mdot
.928 .21311 Mdot
.928 .21318 Mdot
.928 .21345 Mdot
.928 .21381 Mdot
.928 .21401 Mdot
.928 .21446 Mdot
.928 .21487 Mdot
.928 .21493 Mdot
.928 .21531 Mdot
.928 .21572 Mdot
.928 .21574 Mdot
.928 .21592 Mdot
.928 .21621 Mdot
.928 .21623 Mdot
.928 .21624 Mdot
.928 .21625 Mdot
.928 .21641 Mdot
.928 .21648 Mdot
.928 .21656 Mdot
.928 .2168 Mdot
.928 .21698 Mdot
.928 .21699 Mdot
.928 .21727 Mdot
.928 .21731 Mdot
.928 .21743 Mdot
.928 .21795 Mdot
.928 .21806 Mdot
.928 .21807 Mdot
.928 .21811 Mdot
.928 .21828 Mdot
.928 .21875 Mdot
.928 .21885 Mdot
.928 .21934 Mdot
.928 .21934 Mdot
.928 .21943 Mdot
.928 .2195 Mdot
.928 .21971 Mdot
.928 .21973 Mdot
.928 .21976 Mdot
.928 .21981 Mdot
.928 .21987 Mdot
.928 .2199 Mdot
.928 .22043 Mdot
.928 .22057 Mdot
.928 .22062 Mdot
.928 .22064 Mdot
.928 .22066 Mdot
.928 .22077 Mdot
.928 .22077 Mdot
.928 .2209 Mdot
.928 .22096 Mdot
.928 .22098 Mdot
.928 .22115 Mdot
.928 .22116 Mdot
.928 .22124 Mdot
.928 .22132 Mdot
.928 .22145 Mdot
.928 .2215 Mdot
.928 .22161 Mdot
.928 .22163 Mdot
.928 .22176 Mdot
.928 .22201 Mdot
.928 .22205 Mdot
.928 .22205 Mdot
.928 .2221 Mdot
.928 .22218 Mdot
.928 .22219 Mdot
.928 .22229 Mdot
.928 .22236 Mdot
.928 .22239 Mdot
.928 .22243 Mdot
.928 .22243 Mdot
.928 .22252 Mdot
.928 .22254 Mdot
.928 .22262 Mdot
.928 .22269 Mdot
.928 .2227 Mdot
.928 .22271 Mdot
.928 .22271 Mdot
.928 .22274 Mdot
.928 .22291 Mdot
.928 .22292 Mdot
.928 .22295 Mdot
.928 .22295 Mdot
.928 .22296 Mdot
.928 .22297 Mdot
.928 .22301 Mdot
.928 .22304 Mdot
.928 .22311 Mdot
.928 .22312 Mdot
.928 .22314 Mdot
.928 .22316 Mdot
.928 .22318 Mdot
.928 .22321 Mdot
.928 .22324 Mdot
.928 .22326 Mdot
.928 .22331 Mdot
.928 .22336 Mdot
.928 .22337 Mdot
.928 .22338 Mdot
.928 .22342 Mdot
.928 .22345 Mdot
.928 .22349 Mdot
.928 .22351 Mdot
.928 .22354 Mdot
.928 .22357 Mdot
.928 .22357 Mdot
.928 .22359 Mdot
.928 .2236 Mdot
.928 .22361 Mdot
.928 .22361 Mdot
.928 .22365 Mdot
.928 .22365 Mdot
.928 .22366 Mdot
.928 .22367 Mdot
.928 .22367 Mdot
.928 .2237 Mdot
.928 .22371 Mdot
.928 .22377 Mdot
.928 .22378 Mdot
.928 .2238 Mdot
.928 .22381 Mdot
.928 .22381 Mdot
.928 .22382 Mdot
.928 .22382 Mdot
.928 .22384 Mdot
.928 .22384 Mdot
.928 .22387 Mdot
.928 .22389 Mdot
.928 .22389 Mdot
.928 .22389 Mdot
.928 .2239 Mdot
.928 .22391 Mdot
.928 .22393 Mdot
.928 .22393 Mdot
.928 .22393 Mdot
.928 .22394 Mdot
.928 .22394 Mdot
.928 .22394 Mdot
.928 .22394 Mdot
.928 .22395 Mdot
.928 .22395 Mdot
.928 .22395 Mdot
.928 .22395 Mdot
.928 .22395 Mdot
.928 .22395 Mdot
.928 .22396 Mdot
.928 .22396 Mdot
.928 .22396 Mdot
.928 .22396 Mdot
.928 .22396 Mdot
.928 .22396 Mdot
.928 .22396 Mdot
.928 .22396 Mdot
.928 .22396 Mdot
.928 .31792 Mdot
.928 .31792 Mdot
.928 .31793 Mdot
.928 .31796 Mdot
.928 .31796 Mdot
.928 .31798 Mdot
.928 .31801 Mdot
.928 .31805 Mdot
.928 .31808 Mdot
.928 .31808 Mdot
.928 .3181 Mdot
.928 .3181 Mdot
.928 .31813 Mdot
.928 .31813 Mdot
.928 .31822 Mdot
.928 .3183 Mdot
.928 .3183 Mdot
.928 .3183 Mdot
.928 .31837 Mdot
.928 .31838 Mdot
.928 .31843 Mdot
.928 .31858 Mdot
.928 .31863 Mdot
.928 .31863 Mdot
.928 .31867 Mdot
.928 .31882 Mdot
.928 .31889 Mdot
.928 .31891 Mdot
.928 .31901 Mdot
.928 .31902 Mdot
.928 .31908 Mdot
.928 .31911 Mdot
.928 .3193 Mdot
.928 .31936 Mdot
.928 .3194 Mdot
.928 .31944 Mdot
.928 .31945 Mdot
.928 .31946 Mdot
.928 .31958 Mdot
.928 .31964 Mdot
.928 .31968 Mdot
.928 .31978 Mdot
.928 .31982 Mdot
.928 .31983 Mdot
.928 .31984 Mdot
.928 .31986 Mdot
.928 .32002 Mdot
.928 .32004 Mdot
.928 .32037 Mdot
.928 .32042 Mdot
.928 .32045 Mdot
.928 .32061 Mdot
.928 .32078 Mdot
.928 .32092 Mdot
.928 .32092 Mdot
.928 .32116 Mdot
.928 .32125 Mdot
.928 .32152 Mdot
.928 .32153 Mdot
.928 .32168 Mdot
.928 .32186 Mdot
.928 .32205 Mdot
.928 .32211 Mdot
.928 .32212 Mdot
.928 .32213 Mdot
.928 .32216 Mdot
.928 .32233 Mdot
.928 .32238 Mdot
.928 .32252 Mdot
.928 .32263 Mdot
.928 .32268 Mdot
.928 .32269 Mdot
.928 .32277 Mdot
.928 .32283 Mdot
.928 .32294 Mdot
.928 .32316 Mdot
.928 .32328 Mdot
.928 .3235 Mdot
.928 .32351 Mdot
.928 .32355 Mdot
.928 .32356 Mdot
.928 .32364 Mdot
.928 .32391 Mdot
.928 .32392 Mdot
.928 .32395 Mdot
.928 .32407 Mdot
.928 .32413 Mdot
.928 .32445 Mdot
.928 .32449 Mdot
.928 .3245 Mdot
.928 .32455 Mdot
.928 .32467 Mdot
.928 .32469 Mdot
.928 .32473 Mdot
.928 .32476 Mdot
.928 .32483 Mdot
.928 .32494 Mdot
.928 .32537 Mdot
.928 .32583 Mdot
.928 .32593 Mdot
.928 .32595 Mdot
.928 .32609 Mdot
.928 .32628 Mdot
.928 .32661 Mdot
.928 .32683 Mdot
.928 .32688 Mdot
.928 .32698 Mdot
.928 .32704 Mdot
.928 .32706 Mdot
.928 .3275 Mdot
.928 .32758 Mdot
.928 .32779 Mdot
.928 .3279 Mdot
.928 .32829 Mdot
.928 .3285 Mdot
.928 .32861 Mdot
.928 .32862 Mdot
.928 .32865 Mdot
.928 .32877 Mdot
.928 .32883 Mdot
.928 .32896 Mdot
.928 .32905 Mdot
.928 .32924 Mdot
.928 .32941 Mdot
.928 .32946 Mdot
.928 .32974 Mdot
.928 .32974 Mdot
.928 .32976 Mdot
.928 .32982 Mdot
.928 .32982 Mdot
.928 .32989 Mdot
.928 .32991 Mdot
.928 .32996 Mdot
.928 .33005 Mdot
.928 .33008 Mdot
.928 .33018 Mdot
.928 .33024 Mdot
.928 .33025 Mdot
.928 .33025 Mdot
.928 .33025 Mdot
.928 .33025 Mdot
.928 .33028 Mdot
.928 .33029 Mdot
.928 .33033 Mdot
.928 .33033 Mdot
.928 .33034 Mdot
.928 .33035 Mdot
.928 .3304 Mdot
.928 .33041 Mdot
.928 .33044 Mdot
.928 .33047 Mdot
.928 .33049 Mdot
.928 .33083 Mdot
.928 .33098 Mdot
.928 .33116 Mdot
.928 .33132 Mdot
.928 .33165 Mdot
.928 .33207 Mdot
.928 .33207 Mdot
.928 .33216 Mdot
.928 .33241 Mdot
.928 .33271 Mdot
.928 .33279 Mdot
.928 .33307 Mdot
.928 .33372 Mdot
.928 .33429 Mdot
.928 .33455 Mdot
.928 .33456 Mdot
.928 .33466 Mdot
.928 .33508 Mdot
.928 .33624 Mdot
.928 .33639 Mdot
.928 .33649 Mdot
.928 .33718 Mdot
.928 .33739 Mdot
.928 .33771 Mdot
.928 .33776 Mdot
.928 .33776 Mdot
.928 .33798 Mdot
.928 .33802 Mdot
.928 .33811 Mdot
.928 .33818 Mdot
.928 .3386 Mdot
.928 .33864 Mdot
.928 .3387 Mdot
.928 .33872 Mdot
.928 .33877 Mdot
.928 .33883 Mdot
.928 .33884 Mdot
.928 .33886 Mdot
.928 .33899 Mdot
.928 .33916 Mdot
.928 .3392 Mdot
.928 .33925 Mdot
.928 .3393 Mdot
.928 .3396 Mdot
.928 .33964 Mdot
.928 .33964 Mdot
.928 .33967 Mdot
.928 .33969 Mdot
.928 .33975 Mdot
.928 .33976 Mdot
.928 .34005 Mdot
.928 .34029 Mdot
.928 .34069 Mdot
.928 .3411 Mdot
.928 .34124 Mdot
.928 .34125 Mdot
.928 .34129 Mdot
.928 .34131 Mdot
.928 .34134 Mdot
.928 .34157 Mdot
.928 .34166 Mdot
.928 .34167 Mdot
.928 .34182 Mdot
.928 .34202 Mdot
.928 .34221 Mdot
.928 .34227 Mdot
.928 .34235 Mdot
.928 .34275 Mdot
.928 .34278 Mdot
.928 .34285 Mdot
.928 .34292 Mdot
.928 .343 Mdot
.928 .34302 Mdot
.928 .34326 Mdot
.928 .34359 Mdot
.928 .3436 Mdot
.928 .34364 Mdot
.928 .34376 Mdot
.928 .34379 Mdot
.928 .34411 Mdot
.928 .34414 Mdot
.928 .34418 Mdot
.928 .34426 Mdot
.928 .3443 Mdot
.928 .34456 Mdot
.928 .3452 Mdot
.928 .34534 Mdot
.928 .34544 Mdot
.928 .34546 Mdot
.928 .34561 Mdot
.928 .34586 Mdot
.928 .34587 Mdot
.928 .34618 Mdot
.928 .34628 Mdot
.928 .34636 Mdot
.928 .34641 Mdot
.928 .34651 Mdot
.928 .34662 Mdot
.928 .34663 Mdot
.928 .34692 Mdot
.928 .34698 Mdot
.928 .34724 Mdot
.928 .34744 Mdot
.928 .34749 Mdot
.928 .3475 Mdot
.928 .34752 Mdot
.928 .34762 Mdot
.928 .34815 Mdot
.928 .3482 Mdot
.928 .34827 Mdot
.928 .3483 Mdot
.928 .3483 Mdot
.928 .34836 Mdot
.928 .34849 Mdot
.928 .34858 Mdot
.928 .34881 Mdot
.928 .34883 Mdot
.928 .34888 Mdot
.928 .34896 Mdot
.928 .34901 Mdot
.928 .34914 Mdot
.928 .34922 Mdot
.928 .3493 Mdot
.928 .34944 Mdot
.928 .34961 Mdot
.928 .34963 Mdot
.928 .34968 Mdot
.928 .34981 Mdot
.928 .3499 Mdot
.928 .35004 Mdot
.928 .35009 Mdot
.928 .35021 Mdot
.928 .3503 Mdot
.928 .3503 Mdot
.928 .35038 Mdot
.928 .35041 Mdot
.928 .35043 Mdot
.928 .35044 Mdot
.928 .35056 Mdot
.928 .35057 Mdot
.928 .35059 Mdot
.928 .35064 Mdot
.928 .35064 Mdot
.928 .35074 Mdot
.928 .35077 Mdot
.928 .35097 Mdot
.928 .35099 Mdot
.928 .35107 Mdot
.928 .3511 Mdot
.928 .35111 Mdot
.928 .35113 Mdot
.928 .35114 Mdot
.928 .3512 Mdot
.928 .35122 Mdot
.928 .35132 Mdot
.928 .35136 Mdot
.928 .35137 Mdot
.928 .35139 Mdot
.928 .35141 Mdot
.928 .35143 Mdot
.928 .35152 Mdot
.928 .35152 Mdot
.928 .35152 Mdot
.928 .35153 Mdot
.928 .35154 Mdot
.928 .35155 Mdot
.928 .35155 Mdot
.928 .35156 Mdot
.928 .35156 Mdot
.928 .35157 Mdot
.928 .35158 Mdot
.928 .35159 Mdot
.928 .35159 Mdot
.928 .35159 Mdot
.928 .35159 Mdot
.928 .35159 Mdot
.928 .3516 Mdot
.928 .3516 Mdot
.928 .3516 Mdot
.928 .3516 Mdot
.928 .3516 Mdot
.928 .35161 Mdot
.928 .53032 Mdot
.928 .53032 Mdot
.928 .53032 Mdot
.928 .53032 Mdot
.928 .53032 Mdot
.928 .53032 Mdot
.928 .53033 Mdot
.928 .53033 Mdot
.928 .53033 Mdot
.928 .53033 Mdot
.928 .53033 Mdot
.928 .53033 Mdot
.928 .53033 Mdot
.928 .53033 Mdot
.928 .53033 Mdot
.928 .53033 Mdot
.928 .53033 Mdot
.928 .53033 Mdot
.928 .53033 Mdot
.928 .53033 Mdot
.928 .53033 Mdot
.928 .53033 Mdot
.928 .53033 Mdot
.928 .53034 Mdot
.928 .53034 Mdot
.928 .53034 Mdot
.928 .53034 Mdot
.928 .53034 Mdot
.928 .53035 Mdot
.928 .53035 Mdot
.928 .53035 Mdot
.928 .53035 Mdot
.928 .53035 Mdot
.928 .53035 Mdot
.928 .53036 Mdot
.928 .53036 Mdot
.928 .53036 Mdot
.928 .53037 Mdot
.928 .53038 Mdot
.928 .53038 Mdot
.928 .53038 Mdot
.928 .53038 Mdot
.928 .53039 Mdot
.928 .53039 Mdot
.928 .53039 Mdot
.928 .53039 Mdot
.928 .53039 Mdot
.928 .5304 Mdot
.928 .5304 Mdot
.928 .5304 Mdot
.928 .53041 Mdot
.928 .53041 Mdot
.928 .53042 Mdot
.928 .53043 Mdot
.928 .53043 Mdot
.928 .53044 Mdot
.928 .53044 Mdot
.928 .53044 Mdot
.928 .53045 Mdot
.928 .53046 Mdot
.928 .53047 Mdot
.928 .53047 Mdot
.928 .53048 Mdot
.928 .53048 Mdot
.928 .53049 Mdot
.928 .53049 Mdot
.928 .53049 Mdot
.928 .53051 Mdot
.928 .53051 Mdot
.928 .53052 Mdot
.928 .53052 Mdot
.928 .53052 Mdot
.928 .53052 Mdot
.928 .53053 Mdot
.928 .53053 Mdot
.928 .53056 Mdot
.928 .53057 Mdot
.928 .53057 Mdot
.928 .53057 Mdot
.928 .53058 Mdot
.928 .53059 Mdot
.928 .5306 Mdot
.928 .53061 Mdot
.928 .53063 Mdot
.928 .53063 Mdot
.928 .53063 Mdot
.928 .53064 Mdot
.928 .53066 Mdot
.928 .53067 Mdot
.928 .53068 Mdot
.928 .53069 Mdot
.928 .5307 Mdot
.928 .5307 Mdot
.928 .53071 Mdot
.928 .53076 Mdot
.928 .53078 Mdot
.928 .53079 Mdot
.928 .53081 Mdot
.928 .53082 Mdot
.928 .53085 Mdot
.928 .53086 Mdot
.928 .53088 Mdot
.928 .53088 Mdot
.928 .53091 Mdot
.928 .53092 Mdot
.928 .53093 Mdot
.928 .53095 Mdot
.928 .53096 Mdot
.928 .53098 Mdot
.928 .53098 Mdot
.928 .53098 Mdot
.928 .53099 Mdot
.928 .53102 Mdot
.928 .53113 Mdot
.928 .53113 Mdot
.928 .53115 Mdot
.928 .53115 Mdot
.928 .53116 Mdot
.928 .53117 Mdot
.928 .53121 Mdot
.928 .53122 Mdot
.928 .53124 Mdot
.928 .53124 Mdot
.928 .53133 Mdot
.928 .53135 Mdot
.928 .53145 Mdot
.928 .53148 Mdot
.928 .53149 Mdot
.928 .53149 Mdot
.928 .53151 Mdot
.928 .53162 Mdot
.928 .53164 Mdot
.928 .53165 Mdot
.928 .5317 Mdot
.928 .5317 Mdot
.928 .53174 Mdot
.928 .53179 Mdot
.928 .5318 Mdot
.928 .53182 Mdot
.928 .53185 Mdot
.928 .53185 Mdot
.928 .53186 Mdot
.928 .53186 Mdot
.928 .53192 Mdot
.928 .53195 Mdot
.928 .53196 Mdot
.928 .53204 Mdot
.928 .53211 Mdot
.928 .53212 Mdot
.928 .53221 Mdot
.928 .5323 Mdot
.928 .53233 Mdot
.928 .53241 Mdot
.928 .53246 Mdot
.928 .53247 Mdot
.928 .53248 Mdot
.928 .53249 Mdot
.928 .53252 Mdot
.928 .53253 Mdot
.928 .53257 Mdot
.928 .53259 Mdot
.928 .53265 Mdot
.928 .53266 Mdot
.928 .53271 Mdot
.928 .53283 Mdot
.928 .53284 Mdot
.928 .53287 Mdot
.928 .53287 Mdot
.928 .53292 Mdot
.928 .53298 Mdot
.928 .53303 Mdot
.928 .5331 Mdot
.928 .53313 Mdot
.928 .5332 Mdot
.928 .5332 Mdot
.928 .53329 Mdot
.928 .53334 Mdot
.928 .53334 Mdot
.928 .53334 Mdot
.928 .53335 Mdot
.928 .53338 Mdot
.928 .53339 Mdot
.928 .53344 Mdot
.928 .53344 Mdot
.928 .53346 Mdot
.928 .53356 Mdot
.928 .53358 Mdot
.928 .53362 Mdot
.928 .53365 Mdot
.928 .53373 Mdot
.928 .53385 Mdot
.928 .5339 Mdot
.928 .53394 Mdot
.928 .53401 Mdot
.928 .53403 Mdot
.928 .53404 Mdot
.928 .53406 Mdot
.928 .53408 Mdot
.928 .5342 Mdot
.928 .53429 Mdot
.928 .53432 Mdot
.928 .5345 Mdot
.928 .53453 Mdot
.928 .53457 Mdot
.928 .53465 Mdot
.928 .5347 Mdot
.928 .53482 Mdot
.928 .53482 Mdot
.928 .53486 Mdot
.928 .5349 Mdot
.928 .53498 Mdot
.928 .535 Mdot
.928 .53502 Mdot
.928 .53512 Mdot
.928 .53517 Mdot
.928 .5352 Mdot
.928 .53526 Mdot
.928 .53529 Mdot
.928 .53531 Mdot
.928 .53536 Mdot
.928 .53543 Mdot
.928 .5355 Mdot
.928 .53559 Mdot
.928 .53565 Mdot
.928 .53573 Mdot
.928 .53579 Mdot
.928 .53588 Mdot
.928 .53591 Mdot
.928 .53599 Mdot
.928 .53601 Mdot
.928 .53601 Mdot
.928 .53609 Mdot
.928 .53612 Mdot
.928 .53613 Mdot
.928 .53613 Mdot
.928 .53614 Mdot
.928 .53616 Mdot
.928 .53618 Mdot
.928 .53625 Mdot
.928 .53629 Mdot
.928 .5363 Mdot
.928 .53632 Mdot
.928 .53637 Mdot
.928 .53637 Mdot
.928 .5364 Mdot
.928 .53648 Mdot
.928 .53649 Mdot
.928 .53651 Mdot
.928 .53652 Mdot
.928 .53672 Mdot
.928 .53673 Mdot
.928 .53676 Mdot
.928 .53685 Mdot
.928 .53689 Mdot
.928 .53689 Mdot
.928 .53691 Mdot
.928 .53692 Mdot
.928 .537 Mdot
.928 .53701 Mdot
.928 .53713 Mdot
.928 .53716 Mdot
.928 .53718 Mdot
.928 .53719 Mdot
.928 .53721 Mdot
.928 .53722 Mdot
.928 .53724 Mdot
.928 .53725 Mdot
.928 .53728 Mdot
.928 .53736 Mdot
.928 .53736 Mdot
.928 .53736 Mdot
.928 .53737 Mdot
.928 .53739 Mdot
.928 .53739 Mdot
.928 .5374 Mdot
.928 .53741 Mdot
.928 .53741 Mdot
.928 .53741 Mdot
.928 .53743 Mdot
.928 .53744 Mdot
.928 .53744 Mdot
.928 .53744 Mdot
.928 .53744 Mdot
.928 .53744 Mdot
.928 .53745 Mdot
.928 .53745 Mdot
.928 .53745 Mdot
.928 .53746 Mdot
.928 .53746 Mdot
.928 .53746 Mdot
.928 .53747 Mdot
.928 .53761 Mdot
.928 .53774 Mdot
.928 .53778 Mdot
.928 .53799 Mdot
.928 .53841 Mdot
.928 .53853 Mdot
.928 .53857 Mdot
.928 .53862 Mdot
.928 .53867 Mdot
.928 .53869 Mdot
.928 .53877 Mdot
.928 .53878 Mdot
.928 .53879 Mdot
.928 .53881 Mdot
.928 .53881 Mdot
.928 .53887 Mdot
.928 .53889 Mdot
.928 .53894 Mdot
.928 .53895 Mdot
.928 .53895 Mdot
.928 .53895 Mdot
.928 .53895 Mdot
.928 .53897 Mdot
.928 .53897 Mdot
.928 .53902 Mdot
.928 .53906 Mdot
.928 .53923 Mdot
.928 .53925 Mdot
.928 .53929 Mdot
.928 .53934 Mdot
.928 .53944 Mdot
.928 .53954 Mdot
.928 .53955 Mdot
.928 .53957 Mdot
.928 .53969 Mdot
.928 .5397 Mdot
.928 .53973 Mdot
.928 .53981 Mdot
.928 .53984 Mdot
.928 .53985 Mdot
.928 .54006 Mdot
.928 .54035 Mdot
.928 .54037 Mdot
.93 .17156 Mdot
.93 .17158 Mdot
.93 .1726 Mdot
.93 .1727 Mdot
.93 .17339 Mdot
.93 .17341 Mdot
.93 .17511 Mdot
.93 .17578 Mdot
.93 .17585 Mdot
.93 .17602 Mdot
.93 .17738 Mdot
.93 .17875 Mdot
.93 .1788 Mdot
.93 .17917 Mdot
.93 .1792 Mdot
.93 .1799 Mdot
.93 .18009 Mdot
.93 .18011 Mdot
.93 .18071 Mdot
.93 .18144 Mdot
.93 .18164 Mdot
.93 .18176 Mdot
.93 .18216 Mdot
.93 .18273 Mdot
.93 .18287 Mdot
.93 .1832 Mdot
.93 .18368 Mdot
.93 .18414 Mdot
.93 .18417 Mdot
.93 .18434 Mdot
.93 .18452 Mdot
.93 .18585 Mdot
.93 .18633 Mdot
.93 .18786 Mdot
.93 .18826 Mdot
.93 .18848 Mdot
.93 .18853 Mdot
.93 .18885 Mdot
.93 .18886 Mdot
.93 .18897 Mdot
.93 .1895 Mdot
.93 .18967 Mdot
.93 .19038 Mdot
.93 .19065 Mdot
.93 .19086 Mdot
.93 .19101 Mdot
.93 .19224 Mdot
.93 .19224 Mdot
.93 .19243 Mdot
.93 .19255 Mdot
.93 .19256 Mdot
.93 .19259 Mdot
.93 .19269 Mdot
.93 .19278 Mdot
.93 .19312 Mdot
.93 .19324 Mdot
.93 .19352 Mdot
.93 .194 Mdot
.93 .19409 Mdot
.93 .19435 Mdot
.93 .19488 Mdot
.93 .19492 Mdot
.93 .19517 Mdot
.93 .19574 Mdot
.93 .19588 Mdot
.93 .19631 Mdot
.93 .19644 Mdot
.93 .19644 Mdot
.93 .19644 Mdot
.93 .19648 Mdot
.93 .19654 Mdot
.93 .19655 Mdot
.93 .1966 Mdot
.93 .19661 Mdot
.93 .19662 Mdot
.93 .19669 Mdot
.93 .19675 Mdot
.93 .19676 Mdot
.93 .19676 Mdot
.93 .19679 Mdot
.93 .19691 Mdot
.93 .19692 Mdot
.93 .19697 Mdot
.93 .19702 Mdot
.93 .19707 Mdot
.93 .1971 Mdot
.93 .1971 Mdot
.93 .19722 Mdot
.93 .19751 Mdot
.93 .1976 Mdot
.93 .19787 Mdot
.93 .19818 Mdot
.93 .19831 Mdot
.93 .19833 Mdot
.93 .19849 Mdot
.93 .19868 Mdot
.93 .19872 Mdot
.93 .19873 Mdot
.93 .19877 Mdot
.93 .19901 Mdot
.93 .19902 Mdot
.93 .19924 Mdot
.93 .19929 Mdot
.93 .19947 Mdot
.93 .19952 Mdot
.93 .19964 Mdot
.93 .20009 Mdot
.93 .20037 Mdot
.93 .20052 Mdot
.93 .20053 Mdot
.93 .20064 Mdot
.93 .20088 Mdot
.93 .20094 Mdot
.93 .2012 Mdot
.93 .20169 Mdot
.93 .20171 Mdot
.93 .20188 Mdot
.93 .20192 Mdot
.93 .20195 Mdot
.93 .20223 Mdot
.93 .20245 Mdot
.93 .20262 Mdot
.93 .20266 Mdot
.93 .20276 Mdot
.93 .20312 Mdot
.93 .20325 Mdot
.93 .20343 Mdot
.93 .20359 Mdot
.93 .20361 Mdot
.93 .2039 Mdot
.93 .20411 Mdot
.93 .20416 Mdot
.93 .20423 Mdot
.93 .20424 Mdot
.93 .20434 Mdot
.93 .20443 Mdot
.93 .2046 Mdot
.93 .20486 Mdot
.93 .20495 Mdot
.93 .20508 Mdot
.93 .20562 Mdot
.93 .20564 Mdot
.93 .20575 Mdot
.93 .20582 Mdot
.93 .20654 Mdot
.93 .20706 Mdot
.93 .20738 Mdot
.93 .20754 Mdot
.93 .20765 Mdot
.93 .20785 Mdot
.93 .20794 Mdot
.93 .20802 Mdot
.93 .20809 Mdot
.93 .20818 Mdot
.93 .20834 Mdot
.93 .20835 Mdot
.93 .20915 Mdot
.93 .2092 Mdot
.93 .20951 Mdot
.93 .20968 Mdot
.93 .21001 Mdot
.93 .21007 Mdot
.93 .21021 Mdot
.93 .21026 Mdot
.93 .21027 Mdot
.93 .2104 Mdot
.93 .2104 Mdot
.93 .21095 Mdot
.93 .21098 Mdot
.93 .21103 Mdot
.93 .21117 Mdot
.93 .2112 Mdot
.93 .2112 Mdot
.93 .21133 Mdot
.93 .21165 Mdot
.93 .21168 Mdot
.93 .2122 Mdot
.93 .2123 Mdot
.93 .2123 Mdot
.93 .21232 Mdot
.93 .21239 Mdot
.93 .21239 Mdot
.93 .21242 Mdot
.93 .21251 Mdot
.93 .21253 Mdot
.93 .21258 Mdot
.93 .21262 Mdot
.93 .21265 Mdot
.93 .21281 Mdot
.93 .21286 Mdot
.93 .21292 Mdot
.93 .21294 Mdot
.93 .21296 Mdot
.93 .21299 Mdot
.93 .21302 Mdot
.93 .21307 Mdot
.93 .21307 Mdot
.93 .21309 Mdot
.93 .21312 Mdot
.93 .21316 Mdot
.93 .21319 Mdot
.93 .21321 Mdot
.93 .21322 Mdot
.93 .21323 Mdot
.93 .21324 Mdot
.93 .21324 Mdot
.93 .21325 Mdot
.93 .21325 Mdot
.93 .21325 Mdot
.93 .21326 Mdot
.93 .21326 Mdot
.93 .21326 Mdot
.93 .21326 Mdot
.93 .21327 Mdot
.93 .21327 Mdot
.93 .21328 Mdot
.93 .21328 Mdot
.93 .21328 Mdot
.93 .21336 Mdot
.93 .2135 Mdot
.93 .21352 Mdot
.93 .21361 Mdot
.93 .21362 Mdot
.93 .21365 Mdot
.93 .21366 Mdot
.93 .21367 Mdot
.93 .21369 Mdot
.93 .2137 Mdot
.93 .2137 Mdot
.93 .21383 Mdot
.93 .21388 Mdot
.93 .21401 Mdot
.93 .21404 Mdot
.93 .21404 Mdot
.93 .2141 Mdot
.93 .21422 Mdot
.93 .21437 Mdot
.93 .21438 Mdot
.93 .2144 Mdot
.93 .21451 Mdot
.93 .21461 Mdot
.93 .2147 Mdot
.93 .21477 Mdot
.93 .21477 Mdot
.93 .21501 Mdot
.93 .21517 Mdot
.93 .21529 Mdot
.93 .21554 Mdot
.93 .21554 Mdot
.93 .2157 Mdot
.93 .21574 Mdot
.93 .21584 Mdot
.93 .21612 Mdot
.93 .21612 Mdot
.93 .2162 Mdot
.93 .21655 Mdot
.93 .21659 Mdot
.93 .2166 Mdot
.93 .21665 Mdot
.93 .21672 Mdot
.93 .21674 Mdot
.93 .21692 Mdot
.93 .21713 Mdot
.93 .21717 Mdot
.93 .21719 Mdot
.93 .21723 Mdot
.93 .21729 Mdot
.93 .21731 Mdot
.93 .21731 Mdot
.93 .21744 Mdot
.93 .21746 Mdot
.93 .21746 Mdot
.93 .21755 Mdot
.93 .21757 Mdot
.93 .21761 Mdot
.93 .21763 Mdot
.93 .21767 Mdot
.93 .21768 Mdot
.93 .21776 Mdot
.93 .21778 Mdot
.93 .2178 Mdot
.93 .21783 Mdot
.93 .2179 Mdot
.93 .21791 Mdot
.93 .21798 Mdot
.93 .21803 Mdot
.93 .21806 Mdot
.93 .21807 Mdot
.93 .21815 Mdot
.93 .21824 Mdot
.93 .21828 Mdot
.93 .21833 Mdot
.93 .21834 Mdot
.93 .21835 Mdot
.93 .21837 Mdot
.93 .21843 Mdot
.93 .21844 Mdot
.93 .21846 Mdot
.93 .21852 Mdot
.93 .2186 Mdot
.93 .2186 Mdot
.93 .21861 Mdot
.93 .21861 Mdot
.93 .21861 Mdot
.93 .21862 Mdot
.93 .21863 Mdot
.93 .21863 Mdot
.93 .21864 Mdot
.93 .21864 Mdot
.93 .21866 Mdot
.93 .21867 Mdot
.93 .21868 Mdot
.93 .21869 Mdot
.93 .21869 Mdot
.93 .2187 Mdot
.93 .2187 Mdot
.93 .2187 Mdot
.93 .2187 Mdot
.93 .21871 Mdot
.93 .21871 Mdot
.93 .21871 Mdot
.93 .21872 Mdot
.93 .21872 Mdot
.93 .21872 Mdot
.93 .21872 Mdot
.93 .21872 Mdot
.93 .21872 Mdot
.93 .21872 Mdot
.93 .21872 Mdot
.93 .21872 Mdot
.93 .21872 Mdot
.93 .21872 Mdot
.93 .21877 Mdot
.93 .31858 Mdot
.93 .31858 Mdot
.93 .31858 Mdot
.93 .31858 Mdot
.93 .31858 Mdot
.93 .31859 Mdot
.93 .31859 Mdot
.93 .31859 Mdot
.93 .31859 Mdot
.93 .3186 Mdot
.93 .3186 Mdot
.93 .31861 Mdot
.93 .31863 Mdot
.93 .31864 Mdot
.93 .31866 Mdot
.93 .31866 Mdot
.93 .31867 Mdot
.93 .31868 Mdot
.93 .31869 Mdot
.93 .31871 Mdot
.93 .31874 Mdot
.93 .3188 Mdot
.93 .31881 Mdot
.93 .31882 Mdot
.93 .31883 Mdot
.93 .31884 Mdot
.93 .31886 Mdot
.93 .31887 Mdot
.93 .31887 Mdot
.93 .31889 Mdot
.93 .31903 Mdot
.93 .31912 Mdot
.93 .31914 Mdot
.93 .31916 Mdot
.93 .31924 Mdot
.93 .31928 Mdot
.93 .31929 Mdot
.93 .31936 Mdot
.93 .3194 Mdot
.93 .31949 Mdot
.93 .31957 Mdot
.93 .31966 Mdot
.93 .31972 Mdot
.93 .31972 Mdot
.93 .31979 Mdot
.93 .31981 Mdot
.93 .31984 Mdot
.93 .31991 Mdot
.93 .31992 Mdot
.93 .31994 Mdot
.93 .31996 Mdot
.93 .32001 Mdot
.93 .32007 Mdot
.93 .32007 Mdot
.93 .32008 Mdot
.93 .32017 Mdot
.93 .32018 Mdot
.93 .32023 Mdot
.93 .32025 Mdot
.93 .32026 Mdot
.93 .32029 Mdot
.93 .32042 Mdot
.93 .32052 Mdot
.93 .32053 Mdot
.93 .32062 Mdot
.93 .32081 Mdot
.93 .32085 Mdot
.93 .32085 Mdot
.93 .32105 Mdot
.93 .32112 Mdot
.93 .32112 Mdot
.93 .32128 Mdot
.93 .32135 Mdot
.93 .32144 Mdot
.93 .32144 Mdot
.93 .32147 Mdot
.93 .32151 Mdot
.93 .32155 Mdot
.93 .32159 Mdot
.93 .3216 Mdot
.93 .3216 Mdot
.93 .32166 Mdot
.93 .3217 Mdot
.93 .32172 Mdot
.93 .32172 Mdot
.93 .32174 Mdot
.93 .32178 Mdot
.93 .3218 Mdot
.93 .32185 Mdot
.93 .32185 Mdot
.93 .32186 Mdot
.93 .32186 Mdot
.93 .32186 Mdot
.93 .32191 Mdot
.93 .32192 Mdot
.93 .32197 Mdot
.93 .322 Mdot
.93 .322 Mdot
.93 .322 Mdot
.93 .322 Mdot
.93 .32201 Mdot
.93 .32211 Mdot
.93 .32251 Mdot
.93 .3226 Mdot
.93 .32264 Mdot
.93 .32264 Mdot
.93 .32271 Mdot
.93 .32287 Mdot
.93 .3229 Mdot
.93 .3229 Mdot
.93 .32306 Mdot
.93 .32319 Mdot
.93 .32344 Mdot
.93 .32346 Mdot
.93 .32348 Mdot
.93 .3235 Mdot
.93 .32403 Mdot
.93 .32419 Mdot
.93 .3243 Mdot
.93 .32432 Mdot
.93 .32432 Mdot
.93 .32435 Mdot
.93 .32439 Mdot
.93 .32445 Mdot
.93 .32445 Mdot
.93 .32449 Mdot
.93 .32462 Mdot
.93 .32465 Mdot
.93 .32472 Mdot
.93 .32478 Mdot
.93 .32482 Mdot
.93 .32492 Mdot
.93 .32505 Mdot
.93 .32513 Mdot
.93 .32521 Mdot
.93 .32523 Mdot
.93 .32524 Mdot
.93 .32527 Mdot
.93 .32532 Mdot
.93 .32536 Mdot
.93 .32537 Mdot
.93 .32544 Mdot
.93 .32545 Mdot
.93 .32547 Mdot
.93 .32552 Mdot
.93 .32558 Mdot
.93 .32563 Mdot
.93 .32565 Mdot
.93 .32568 Mdot
.93 .32568 Mdot
.93 .32571 Mdot
.93 .32571 Mdot
.93 .32571 Mdot
.93 .32571 Mdot
.93 .32572 Mdot
.93 .32573 Mdot
.93 .32574 Mdot
.93 .32574 Mdot
.93 .32574 Mdot
.93 .32575 Mdot
.93 .32575 Mdot
.93 .32576 Mdot
.93 .32577 Mdot
.93 .32577 Mdot
.93 .32577 Mdot
.93 .32586 Mdot
.93 .32588 Mdot
.93 .32598 Mdot
.93 .32602 Mdot
.93 .32602 Mdot
.93 .32611 Mdot
.93 .32615 Mdot
.93 .32617 Mdot
.93 .32629 Mdot
.93 .3263 Mdot
.93 .32636 Mdot
.93 .32637 Mdot
.93 .32639 Mdot
.93 .32639 Mdot
.93 .32639 Mdot
.93 .32641 Mdot
.93 .32644 Mdot
.93 .32644 Mdot
.93 .32665 Mdot
.93 .32673 Mdot
.93 .32695 Mdot
.93 .327 Mdot
.93 .32701 Mdot
.93 .3271 Mdot
.93 .32732 Mdot
.93 .32757 Mdot
.93 .32759 Mdot
.93 .32762 Mdot
.93 .32762 Mdot
.93 .32781 Mdot
.93 .32789 Mdot
.93 .32799 Mdot
.93 .32809 Mdot
.93 .32816 Mdot
.93 .32828 Mdot
.93 .32829 Mdot
.93 .32834 Mdot
.93 .32869 Mdot
.93 .32872 Mdot
.93 .32902 Mdot
.93 .32925 Mdot
.93 .32961 Mdot
.93 .32973 Mdot
.93 .32975 Mdot
.93 .32983 Mdot
.93 .33005 Mdot
.93 .33014 Mdot
.93 .33034 Mdot
.93 .33052 Mdot
.93 .33066 Mdot
.93 .33069 Mdot
.93 .3309 Mdot
.93 .33091 Mdot
.93 .33106 Mdot
.93 .33111 Mdot
.93 .33117 Mdot
.93 .33147 Mdot
.93 .33182 Mdot
.93 .3319 Mdot
.93 .33192 Mdot
.93 .332 Mdot
.93 .33202 Mdot
.93 .33217 Mdot
.93 .33223 Mdot
.93 .33261 Mdot
.93 .33307 Mdot
.93 .33317 Mdot
.93 .3332 Mdot
.93 .33329 Mdot
.93 .33344 Mdot
.93 .33348 Mdot
.93 .33349 Mdot
.93 .33378 Mdot
.93 .33381 Mdot
.93 .33383 Mdot
.93 .33403 Mdot
.93 .33406 Mdot
.93 .33407 Mdot
.93 .33418 Mdot
.93 .33422 Mdot
.93 .33431 Mdot
.93 .33433 Mdot
.93 .33452 Mdot
.93 .33458 Mdot
.93 .33461 Mdot
.93 .33469 Mdot
.93 .33471 Mdot
.93 .33486 Mdot
.93 .33487 Mdot
.93 .33503 Mdot
.93 .33515 Mdot
.93 .33523 Mdot
.93 .33526 Mdot
.93 .33546 Mdot
.93 .33566 Mdot
.93 .33575 Mdot
.93 .33588 Mdot
.93 .3359 Mdot
.93 .33594 Mdot
.93 .33599 Mdot
.93 .33614 Mdot
.93 .33617 Mdot
.93 .33621 Mdot
.93 .33636 Mdot
.93 .33652 Mdot
.93 .33654 Mdot
.93 .33655 Mdot
.93 .33657 Mdot
.93 .33657 Mdot
.93 .33658 Mdot
.93 .33661 Mdot
.93 .33662 Mdot
.93 .33664 Mdot
.93 .33665 Mdot
.93 .33666 Mdot
.93 .33671 Mdot
.93 .33672 Mdot
.93 .33675 Mdot
.93 .33676 Mdot
.93 .33677 Mdot
.93 .33678 Mdot
.93 .33679 Mdot
.93 .33679 Mdot
.93 .3368 Mdot
.93 .33681 Mdot
.93 .33682 Mdot
.93 .33684 Mdot
.93 .33684 Mdot
.93 .33684 Mdot
.93 .33685 Mdot
.93 .33685 Mdot
.93 .33685 Mdot
.93 .33685 Mdot
.93 .33686 Mdot
.93 .33686 Mdot
.93 .33686 Mdot
.93 .33686 Mdot
.93 .33686 Mdot
.93 .33686 Mdot
.93 .33698 Mdot
.93 .33698 Mdot
.93 .33701 Mdot
.93 .33763 Mdot
.93 .33826 Mdot
.93 .33869 Mdot
.93 .33886 Mdot
.93 .33959 Mdot
.93 .3401 Mdot
.93 .34024 Mdot
.93 .3405 Mdot
.93 .34138 Mdot
.93 .34209 Mdot
.93 .34212 Mdot
.93 .34234 Mdot
.93 .34313 Mdot
.93 .34316 Mdot
.93 .34357 Mdot
.93 .34362 Mdot
.93 .34502 Mdot
.93 .34626 Mdot
.93 .34641 Mdot
.93 .34646 Mdot
.93 .34699 Mdot
.93 .34813 Mdot
.93 .34814 Mdot
.93 .34851 Mdot
.93 .34856 Mdot
.93 .34898 Mdot
.93 .34899 Mdot
.93 .53144 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53145 Mdot
.93 .53146 Mdot
.93 .53146 Mdot
.93 .53146 Mdot
.93 .53146 Mdot
.93 .53146 Mdot
.93 .53146 Mdot
.93 .53147 Mdot
.93 .53147 Mdot
.93 .53147 Mdot
.93 .53147 Mdot
.93 .53147 Mdot
.93 .53147 Mdot
.93 .53147 Mdot
.93 .53149 Mdot
.93 .5315 Mdot
.93 .5315 Mdot
.93 .5315 Mdot
.93 .53152 Mdot
.93 .53152 Mdot
.93 .53152 Mdot
.93 .53152 Mdot
.93 .53154 Mdot
.93 .53154 Mdot
.93 .53156 Mdot
.93 .53158 Mdot
.93 .53158 Mdot
.93 .53158 Mdot
.93 .53159 Mdot
.93 .53161 Mdot
.93 .53161 Mdot
.93 .53162 Mdot
.93 .53163 Mdot
.93 .53163 Mdot
.93 .53164 Mdot
.93 .53165 Mdot
.93 .53166 Mdot
.93 .53166 Mdot
.93 .53167 Mdot
.93 .53168 Mdot
.93 .53168 Mdot
.93 .5317 Mdot
.93 .5317 Mdot
.93 .5317 Mdot
.93 .53173 Mdot
.93 .53173 Mdot
.93 .53173 Mdot
.93 .53174 Mdot
.93 .53175 Mdot
.93 .53175 Mdot
.93 .53176 Mdot
.93 .5318 Mdot
.93 .53184 Mdot
.93 .53184 Mdot
.93 .53186 Mdot
.93 .53187 Mdot
.93 .53187 Mdot
.93 .53188 Mdot
.93 .53195 Mdot
.93 .53196 Mdot
.93 .53196 Mdot
.93 .53202 Mdot
.93 .53204 Mdot
.93 .53205 Mdot
.93 .53208 Mdot
.93 .53208 Mdot
.93 .53213 Mdot
.93 .53215 Mdot
.93 .53218 Mdot
.93 .53223 Mdot
.93 .53223 Mdot
.93 .53224 Mdot
.93 .53226 Mdot
.93 .53228 Mdot
.93 .5323 Mdot
.93 .53231 Mdot
.93 .53231 Mdot
.93 .53234 Mdot
.93 .53236 Mdot
.93 .53237 Mdot
.93 .53237 Mdot
.93 .53238 Mdot
.93 .53241 Mdot
.93 .53242 Mdot
.93 .53244 Mdot
.93 .53244 Mdot
.93 .53244 Mdot
.93 .53245 Mdot
.93 .53245 Mdot
.93 .53245 Mdot
.93 .53246 Mdot
.93 .53246 Mdot
.93 .53248 Mdot
.93 .53248 Mdot
.93 .53251 Mdot
.93 .53253 Mdot
.93 .53253 Mdot
.93 .53253 Mdot
.93 .53253 Mdot
.93 .53253 Mdot
.93 .53253 Mdot
.93 .53253 Mdot
.93 .53253 Mdot
.93 .53253 Mdot
.93 .53253 Mdot
.93 .53253 Mdot
.93 .53253 Mdot
.93 .53253 Mdot
.93 .53253 Mdot
.93 .53254 Mdot
.93 .53254 Mdot
.93 .53254 Mdot
.93 .53254 Mdot
.93 .53255 Mdot
.93 .53256 Mdot
.93 .53256 Mdot
.93 .53257 Mdot
.93 .53257 Mdot
.93 .53258 Mdot
.93 .53258 Mdot
.93 .53259 Mdot
.93 .53259 Mdot
.93 .5326 Mdot
.93 .53261 Mdot
.93 .53262 Mdot
.93 .53265 Mdot
.93 .53266 Mdot
.93 .53266 Mdot
.93 .53267 Mdot
.93 .53268 Mdot
.93 .5327 Mdot
.93 .5327 Mdot
.93 .5327 Mdot
.93 .53272 Mdot
.93 .53272 Mdot
.93 .53272 Mdot
.93 .53274 Mdot
.93 .53284 Mdot
.93 .53285 Mdot
.93 .53291 Mdot
.93 .53294 Mdot
.93 .53294 Mdot
.93 .53294 Mdot
.93 .53297 Mdot
.93 .53298 Mdot
.93 .53299 Mdot
.93 .5331 Mdot
.93 .5331 Mdot
.93 .53312 Mdot
.93 .53313 Mdot
.93 .53314 Mdot
.93 .53316 Mdot
.93 .53318 Mdot
.93 .53324 Mdot
.93 .53328 Mdot
.93 .53334 Mdot
.93 .53335 Mdot
.93 .53351 Mdot
.93 .53351 Mdot
.93 .53354 Mdot
.93 .53356 Mdot
.93 .53357 Mdot
.93 .53359 Mdot
.93 .53361 Mdot
.93 .53365 Mdot
.93 .53367 Mdot
.93 .5337 Mdot
.93 .53376 Mdot
.93 .53387 Mdot
.93 .53401 Mdot
.93 .53403 Mdot
.93 .53405 Mdot
.93 .53405 Mdot
.93 .53416 Mdot
.93 .53419 Mdot
.93 .53421 Mdot
.93 .53426 Mdot
.93 .53429 Mdot
.93 .53431 Mdot
.93 .53433 Mdot
.93 .53433 Mdot
.93 .53435 Mdot
.93 .53436 Mdot
.93 .5344 Mdot
.93 .53446 Mdot
.93 .53446 Mdot
.93 .53449 Mdot
.93 .53453 Mdot
.93 .53456 Mdot
.93 .53463 Mdot
.93 .53465 Mdot
.93 .53466 Mdot
.93 .53469 Mdot
.93 .53474 Mdot
.93 .53479 Mdot
.93 .5348 Mdot
.93 .53481 Mdot
.93 .53484 Mdot
.93 .53484 Mdot
.93 .53495 Mdot
.93 .535 Mdot
.93 .53501 Mdot
.93 .53506 Mdot
.93 .53508 Mdot
.93 .53508 Mdot
.93 .53511 Mdot
.93 .53517 Mdot
.93 .53526 Mdot
.93 .53529 Mdot
.93 .5353 Mdot
.93 .53533 Mdot
.93 .53534 Mdot
.93 .53539 Mdot
.93 .53539 Mdot
.93 .53544 Mdot
.93 .53544 Mdot
.93 .53545 Mdot
.93 .53546 Mdot
.93 .5355 Mdot
.93 .53553 Mdot
.93 .53553 Mdot
.93 .53556 Mdot
.93 .53562 Mdot
.93 .53568 Mdot
.93 .53569 Mdot
.93 .53575 Mdot
.93 .53578 Mdot
.93 .53578 Mdot
.93 .53578 Mdot
.93 .53579 Mdot
.93 .5358 Mdot
.93 .53581 Mdot
.93 .53582 Mdot
.93 .53584 Mdot
.93 .53585 Mdot
.93 .53585 Mdot
.93 .53585 Mdot
.93 .53586 Mdot
.93 .53587 Mdot
.93 .53588 Mdot
.93 .53588 Mdot
.93 .53588 Mdot
.93 .53589 Mdot
.93 .53589 Mdot
.93 .5359 Mdot
.93 .53591 Mdot
.93 .53591 Mdot
.93 .53591 Mdot
.93 .53594 Mdot
.93 .53603 Mdot
.93 .53606 Mdot
.93 .53617 Mdot
.93 .53622 Mdot
.93 .53623 Mdot
.93 .53634 Mdot
.93 .5364 Mdot
.93 .53641 Mdot
.93 .53651 Mdot
.93 .53657 Mdot
.93 .53659 Mdot
.93 .53667 Mdot
.93 .53668 Mdot
.93 .5367 Mdot
.93 .53671 Mdot
.93 .53671 Mdot
.93 .53674 Mdot
.93 .53678 Mdot
.93 .53678 Mdot
.93 .53703 Mdot
.93 .53706 Mdot
.93 .53711 Mdot
.93 .53716 Mdot
.93 .53731 Mdot
.93 .53735 Mdot
.93 .53746 Mdot
.93 .53748 Mdot
.93 .53748 Mdot
.93 .53755 Mdot
.93 .53756 Mdot
.93 .53761 Mdot
.93 .53769 Mdot
.93 .53801 Mdot
.93 .53811 Mdot
.93 .53839 Mdot
.93 .53843 Mdot
.93 .53847 Mdot
.93 .53847 Mdot
.93 .53857 Mdot
.93 .53867 Mdot
.93 .53874 Mdot
.93 .53877 Mdot
.93 .5389 Mdot
.93 .53898 Mdot
.93 .53901 Mdot
.93 .53905 Mdot
.93 .53921 Mdot
.93 .53934 Mdot
.93 .53934 Mdot
.93 .53938 Mdot
.93 .53953 Mdot
.93 .53954 Mdot
.93 .53962 Mdot
.93 .53963 Mdot
.93 .53993 Mdot
.93 .54023 Mdot
.93 .54026 Mdot
.93 .54028 Mdot
.93 .54043 Mdot
.93 .5408 Mdot
.93 .54081 Mdot
.93 .54096 Mdot
.93 .54098 Mdot
.93 .54121 Mdot
.93 .54122 Mdot
.932 .16564 Mdot
.932 .16614 Mdot
.932 .16635 Mdot
.932 .16674 Mdot
.932 .16696 Mdot
.932 .16791 Mdot
.932 .16825 Mdot
.932 .16858 Mdot
.932 .16877 Mdot
.932 .1689 Mdot
.932 .17338 Mdot
.932 .17338 Mdot
.932 .17341 Mdot
.932 .17353 Mdot
.932 .17375 Mdot
.932 .17457 Mdot
.932 .17501 Mdot
.932 .17581 Mdot
.932 .17587 Mdot
.932 .17605 Mdot
.932 .17619 Mdot
.932 .17734 Mdot
.932 .17808 Mdot
.932 .17831 Mdot
.932 .17907 Mdot
.932 .17932 Mdot
.932 .17955 Mdot
.932 .1797 Mdot
.932 .17993 Mdot
.932 .18009 Mdot
.932 .18048 Mdot
.932 .18077 Mdot
.932 .18091 Mdot
.932 .18287 Mdot
.932 .18306 Mdot
.932 .18332 Mdot
.932 .18357 Mdot
.932 .18381 Mdot
.932 .18404 Mdot
.932 .18405 Mdot
.932 .18449 Mdot
.932 .18479 Mdot
.932 .18487 Mdot
.932 .18496 Mdot
.932 .18534 Mdot
.932 .18536 Mdot
.932 .1854 Mdot
.932 .18549 Mdot
.932 .1856 Mdot
.932 .186 Mdot
.932 .18608 Mdot
.932 .18627 Mdot
.932 .18628 Mdot
.932 .18633 Mdot
.932 .18634 Mdot
.932 .18641 Mdot
.932 .18647 Mdot
.932 .18671 Mdot
.932 .18685 Mdot
.932 .18691 Mdot
.932 .18695 Mdot
.932 .18749 Mdot
.932 .18782 Mdot
.932 .18803 Mdot
.932 .1881 Mdot
.932 .18811 Mdot
.932 .18817 Mdot
.932 .18825 Mdot
.932 .18826 Mdot
.932 .18828 Mdot
.932 .18832 Mdot
.932 .18838 Mdot
.932 .18843 Mdot
.932 .18845 Mdot
.932 .18848 Mdot
.932 .18851 Mdot
.932 .18853 Mdot
.932 .18877 Mdot
.932 .18878 Mdot
.932 .18886 Mdot
.932 .18887 Mdot
.932 .1889 Mdot
.932 .18891 Mdot
.932 .18896 Mdot
.932 .18904 Mdot
.932 .18907 Mdot
.932 .18915 Mdot
.932 .18926 Mdot
.932 .1893 Mdot
.932 .1893 Mdot
.932 .18943 Mdot
.932 .18951 Mdot
.932 .18955 Mdot
.932 .18955 Mdot
.932 .18955 Mdot
.932 .19 Mdot
.932 .19003 Mdot
.932 .19006 Mdot
.932 .19019 Mdot
.932 .19027 Mdot
.932 .19034 Mdot
.932 .19041 Mdot
.932 .19045 Mdot
.932 .19057 Mdot
.932 .19065 Mdot
.932 .19114 Mdot
.932 .1913 Mdot
.932 .19142 Mdot
.932 .19178 Mdot
.932 .19192 Mdot
.932 .19221 Mdot
.932 .19235 Mdot
.932 .19245 Mdot
.932 .19246 Mdot
.932 .19252 Mdot
.932 .19253 Mdot
.932 .19261 Mdot
.932 .19266 Mdot
.932 .19273 Mdot
.932 .19288 Mdot
.932 .19293 Mdot
.932 .19351 Mdot
.932 .19352 Mdot
.932 .19357 Mdot
.932 .19359 Mdot
.932 .19369 Mdot
.932 .19392 Mdot
.932 .19404 Mdot
.932 .19452 Mdot
.932 .19467 Mdot
.932 .1949 Mdot
.932 .19496 Mdot
.932 .195 Mdot
.932 .19549 Mdot
.932 .19558 Mdot
.932 .19583 Mdot
.932 .19595 Mdot
.932 .19598 Mdot
.932 .19602 Mdot
.932 .19603 Mdot
.932 .1963 Mdot
.932 .19634 Mdot
.932 .19659 Mdot
.932 .19666 Mdot
.932 .19667 Mdot
.932 .19685 Mdot
.932 .19725 Mdot
.932 .19729 Mdot
.932 .19731 Mdot
.932 .19768 Mdot
.932 .19768 Mdot
.932 .19772 Mdot
.932 .19804 Mdot
.932 .19819 Mdot
.932 .19895 Mdot
.932 .19907 Mdot
.932 .19919 Mdot
.932 .19924 Mdot
.932 .1994 Mdot
.932 .19958 Mdot
.932 .19964 Mdot
.932 .19989 Mdot
.932 .19989 Mdot
.932 .19997 Mdot
.932 .20005 Mdot
.932 .20009 Mdot
.932 .2001 Mdot
.932 .20015 Mdot
.932 .20033 Mdot
.932 .20044 Mdot
.932 .20044 Mdot
.932 .20051 Mdot
.932 .20054 Mdot
.932 .20065 Mdot
.932 .20068 Mdot
.932 .20113 Mdot
.932 .20138 Mdot
.932 .20147 Mdot
.932 .20165 Mdot
.932 .20168 Mdot
.932 .20177 Mdot
.932 .20214 Mdot
.932 .20215 Mdot
.932 .20237 Mdot
.932 .20242 Mdot
.932 .20243 Mdot
.932 .20252 Mdot
.932 .20253 Mdot
.932 .20263 Mdot
.932 .20287 Mdot
.932 .20296 Mdot
.932 .20309 Mdot
.932 .2032 Mdot
.932 .20391 Mdot
.932 .20394 Mdot
.932 .20431 Mdot
.932 .20434 Mdot
.932 .20447 Mdot
.932 .20458 Mdot
.932 .20464 Mdot
.932 .20485 Mdot
.932 .20491 Mdot
.932 .20517 Mdot
.932 .20526 Mdot
.932 .20532 Mdot
.932 .20532 Mdot
.932 .20553 Mdot
.932 .20554 Mdot
.932 .20561 Mdot
.932 .20564 Mdot
.932 .20601 Mdot
.932 .20615 Mdot
.932 .20639 Mdot
.932 .20662 Mdot
.932 .20664 Mdot
.932 .20711 Mdot
.932 .20712 Mdot
.932 .20733 Mdot
.932 .20734 Mdot
.932 .20772 Mdot
.932 .20777 Mdot
.932 .20789 Mdot
.932 .20802 Mdot
.932 .20806 Mdot
.932 .20812 Mdot
.932 .20818 Mdot
.932 .20818 Mdot
.932 .20823 Mdot
.932 .20828 Mdot
.932 .20858 Mdot
.932 .20873 Mdot
.932 .20907 Mdot
.932 .20907 Mdot
.932 .20914 Mdot
.932 .20917 Mdot
.932 .2095 Mdot
.932 .20956 Mdot
.932 .20971 Mdot
.932 .20971 Mdot
.932 .20975 Mdot
.932 .20981 Mdot
.932 .21 Mdot
.932 .21035 Mdot
.932 .21039 Mdot
.932 .21057 Mdot
.932 .21059 Mdot
.932 .21061 Mdot
.932 .2109 Mdot
.932 .21106 Mdot
.932 .21108 Mdot
.932 .21113 Mdot
.932 .2112 Mdot
.932 .2112 Mdot
.932 .21122 Mdot
.932 .21122 Mdot
.932 .21123 Mdot
.932 .21127 Mdot
.932 .21134 Mdot
.932 .21136 Mdot
.932 .2114 Mdot
.932 .21142 Mdot
.932 .21155 Mdot
.932 .21158 Mdot
.932 .21166 Mdot
.932 .21168 Mdot
.932 .21173 Mdot
.932 .21176 Mdot
.932 .21179 Mdot
.932 .21181 Mdot
.932 .21197 Mdot
.932 .21202 Mdot
.932 .21202 Mdot
.932 .21208 Mdot
.932 .21209 Mdot
.932 .21215 Mdot
.932 .21217 Mdot
.932 .21218 Mdot
.932 .21222 Mdot
.932 .21226 Mdot
.932 .21227 Mdot
.932 .21229 Mdot
.932 .21233 Mdot
.932 .2124 Mdot
.932 .2124 Mdot
.932 .21244 Mdot
.932 .21246 Mdot
.932 .21252 Mdot
.932 .21254 Mdot
.932 .21257 Mdot
.932 .21258 Mdot
.932 .21258 Mdot
.932 .21269 Mdot
.932 .21272 Mdot
.932 .21275 Mdot
.932 .21279 Mdot
.932 .21284 Mdot
.932 .21285 Mdot
.932 .21287 Mdot
.932 .21292 Mdot
.932 .21293 Mdot
.932 .21295 Mdot
.932 .21296 Mdot
.932 .21297 Mdot
.932 .21297 Mdot
.932 .21299 Mdot
.932 .21299 Mdot
.932 .213 Mdot
.932 .21304 Mdot
.932 .21304 Mdot
.932 .21304 Mdot
.932 .21305 Mdot
.932 .21306 Mdot
.932 .21307 Mdot
.932 .21309 Mdot
.932 .2131 Mdot
.932 .2131 Mdot
.932 .21311 Mdot
.932 .21311 Mdot
.932 .21311 Mdot
.932 .21312 Mdot
.932 .21313 Mdot
.932 .21313 Mdot
.932 .21315 Mdot
.932 .21315 Mdot
.932 .21316 Mdot
.932 .21316 Mdot
.932 .21317 Mdot
.932 .21317 Mdot
.932 .21318 Mdot
.932 .21318 Mdot
.932 .21318 Mdot
.932 .2132 Mdot
.932 .2132 Mdot
.932 .31923 Mdot
.932 .31923 Mdot
.932 .31925 Mdot
.932 .31925 Mdot
.932 .31925 Mdot
.932 .31926 Mdot
.932 .31927 Mdot
.932 .31927 Mdot
.932 .31928 Mdot
.932 .31928 Mdot
.932 .31929 Mdot
.932 .31932 Mdot
.932 .31932 Mdot
.932 .31933 Mdot
.932 .31933 Mdot
.932 .31933 Mdot
.932 .31935 Mdot
.932 .31935 Mdot
.932 .31936 Mdot
.932 .31938 Mdot
.932 .3194 Mdot
.932 .31941 Mdot
.932 .31941 Mdot
.932 .31941 Mdot
.932 .31941 Mdot
.932 .31946 Mdot
.932 .31947 Mdot
.932 .31949 Mdot
.932 .31949 Mdot
.932 .3195 Mdot
.932 .31953 Mdot
.932 .31954 Mdot
.932 .31959 Mdot
.932 .31961 Mdot
.932 .31962 Mdot
.932 .31966 Mdot
.932 .3197 Mdot
.932 .31975 Mdot
.932 .31984 Mdot
.932 .31985 Mdot
.932 .31988 Mdot
.932 .31989 Mdot
.932 .31994 Mdot
.932 .31995 Mdot
.932 .31998 Mdot
.932 .31998 Mdot
.932 .32003 Mdot
.932 .32008 Mdot
.932 .32008 Mdot
.932 .32011 Mdot
.932 .32014 Mdot
.932 .32014 Mdot
.932 .32016 Mdot
.932 .32019 Mdot
.932 .3202 Mdot
.932 .3202 Mdot
.932 .32024 Mdot
.932 .32024 Mdot
.932 .32037 Mdot
.932 .32041 Mdot
.932 .32042 Mdot
.932 .32045 Mdot
.932 .32051 Mdot
.932 .32053 Mdot
.932 .3206 Mdot
.932 .32061 Mdot
.932 .32063 Mdot
.932 .32064 Mdot
.932 .32068 Mdot
.932 .3207 Mdot
.932 .32072 Mdot
.932 .32072 Mdot
.932 .32075 Mdot
.932 .32078 Mdot
.932 .32079 Mdot
.932 .32101 Mdot
.932 .32113 Mdot
.932 .32128 Mdot
.932 .32138 Mdot
.932 .3214 Mdot
.932 .3214 Mdot
.932 .32146 Mdot
.932 .32148 Mdot
.932 .32162 Mdot
.932 .32165 Mdot
.932 .32165 Mdot
.932 .32177 Mdot
.932 .32183 Mdot
.932 .32193 Mdot
.932 .32195 Mdot
.932 .32197 Mdot
.932 .32197 Mdot
.932 .32199 Mdot
.932 .32201 Mdot
.932 .32207 Mdot
.932 .32225 Mdot
.932 .32231 Mdot
.932 .32246 Mdot
.932 .32247 Mdot
.932 .32254 Mdot
.932 .32261 Mdot
.932 .32265 Mdot
.932 .32275 Mdot
.932 .32279 Mdot
.932 .32284 Mdot
.932 .32286 Mdot
.932 .32289 Mdot
.932 .32303 Mdot
.932 .32304 Mdot
.932 .32307 Mdot
.932 .32311 Mdot
.932 .32321 Mdot
.932 .32322 Mdot
.932 .3234 Mdot
.932 .32342 Mdot
.932 .32346 Mdot
.932 .32348 Mdot
.932 .32353 Mdot
.932 .32356 Mdot
.932 .32356 Mdot
.932 .32358 Mdot
.932 .32359 Mdot
.932 .3236 Mdot
.932 .32365 Mdot
.932 .32374 Mdot
.932 .32376 Mdot
.932 .32381 Mdot
.932 .32383 Mdot
.932 .32399 Mdot
.932 .32402 Mdot
.932 .32404 Mdot
.932 .32406 Mdot
.932 .32412 Mdot
.932 .32414 Mdot
.932 .32416 Mdot
.932 .32422 Mdot
.932 .32426 Mdot
.932 .3243 Mdot
.932 .32433 Mdot
.932 .32435 Mdot
.932 .32451 Mdot
.932 .32454 Mdot
.932 .3246 Mdot
.932 .32461 Mdot
.932 .32469 Mdot
.932 .3247 Mdot
.932 .32478 Mdot
.932 .32481 Mdot
.932 .32483 Mdot
.932 .32487 Mdot
.932 .32493 Mdot
.932 .32494 Mdot
.932 .32497 Mdot
.932 .32502 Mdot
.932 .32503 Mdot
.932 .32513 Mdot
.932 .32513 Mdot
.932 .32514 Mdot
.932 .32519 Mdot
.932 .32521 Mdot
.932 .3253 Mdot
.932 .32532 Mdot
.932 .32536 Mdot
.932 .32538 Mdot
.932 .32539 Mdot
.932 .3254 Mdot
.932 .32551 Mdot
.932 .32553 Mdot
.932 .32555 Mdot
.932 .32558 Mdot
.932 .32558 Mdot
.932 .3256 Mdot
.932 .32562 Mdot
.932 .3257 Mdot
.932 .32576 Mdot
.932 .32578 Mdot
.932 .32581 Mdot
.932 .32589 Mdot
.932 .3259 Mdot
.932 .32593 Mdot
.932 .32594 Mdot
.932 .32595 Mdot
.932 .32597 Mdot
.932 .32599 Mdot
.932 .32599 Mdot
.932 .326 Mdot
.932 .32607 Mdot
.932 .32607 Mdot
.932 .32607 Mdot
.932 .32608 Mdot
.932 .32609 Mdot
.932 .32612 Mdot
.932 .32614 Mdot
.932 .32615 Mdot
.932 .32615 Mdot
.932 .32617 Mdot
.932 .32617 Mdot
.932 .32618 Mdot
.932 .32618 Mdot
.932 .3262 Mdot
.932 .3262 Mdot
.932 .32624 Mdot
.932 .32624 Mdot
.932 .32624 Mdot
.932 .32625 Mdot
.932 .32625 Mdot
.932 .32626 Mdot
.932 .32627 Mdot
.932 .32628 Mdot
.932 .32628 Mdot
.932 .32628 Mdot
.932 .3263 Mdot
.932 .3263 Mdot
.932 .32632 Mdot
.932 .32649 Mdot
.932 .32657 Mdot
.932 .32662 Mdot
.932 .32672 Mdot
.932 .32673 Mdot
.932 .32681 Mdot
.932 .32682 Mdot
.932 .32693 Mdot
.932 .3271 Mdot
.932 .32745 Mdot
.932 .32761 Mdot
.932 .32806 Mdot
.932 .3282 Mdot
.932 .3284 Mdot
.932 .32902 Mdot
.932 .32913 Mdot
.932 .32927 Mdot
.932 .32932 Mdot
.932 .32941 Mdot
.932 .32951 Mdot
.932 .32961 Mdot
.932 .32977 Mdot
.932 .32982 Mdot
.932 .32986 Mdot
.932 .33044 Mdot
.932 .33044 Mdot
.932 .33044 Mdot
.932 .33049 Mdot
.932 .3306 Mdot
.932 .33076 Mdot
.932 .33077 Mdot
.932 .33081 Mdot
.932 .33097 Mdot
.932 .33107 Mdot
.932 .3311 Mdot
.932 .33121 Mdot
.932 .33128 Mdot
.932 .3313 Mdot
.932 .33133 Mdot
.932 .33135 Mdot
.932 .33145 Mdot
.932 .33147 Mdot
.932 .33178 Mdot
.932 .33182 Mdot
.932 .33186 Mdot
.932 .33189 Mdot
.932 .33193 Mdot
.932 .33199 Mdot
.932 .33207 Mdot
.932 .33213 Mdot
.932 .33214 Mdot
.932 .33216 Mdot
.932 .33222 Mdot
.932 .33228 Mdot
.932 .33236 Mdot
.932 .33236 Mdot
.932 .33246 Mdot
.932 .33275 Mdot
.932 .33318 Mdot
.932 .33392 Mdot
.932 .33398 Mdot
.932 .33405 Mdot
.932 .33424 Mdot
.932 .33456 Mdot
.932 .33465 Mdot
.932 .33475 Mdot
.932 .33476 Mdot
.932 .33482 Mdot
.932 .33484 Mdot
.932 .33509 Mdot
.932 .3352 Mdot
.932 .33574 Mdot
.932 .3359 Mdot
.932 .33601 Mdot
.932 .33608 Mdot
.932 .33609 Mdot
.932 .33661 Mdot
.932 .33674 Mdot
.932 .33683 Mdot
.932 .33725 Mdot
.932 .33783 Mdot
.932 .33784 Mdot
.932 .33815 Mdot
.932 .33847 Mdot
.932 .33879 Mdot
.932 .33913 Mdot
.932 .33939 Mdot
.932 .34184 Mdot
.932 .34202 Mdot
.932 .34236 Mdot
.932 .34282 Mdot
.932 .34301 Mdot
.932 .34328 Mdot
.932 .34345 Mdot
.932 .34371 Mdot
.932 .34398 Mdot
.932 .3448 Mdot
.932 .34504 Mdot
.932 .34577 Mdot
.932 .34683 Mdot
.932 .34695 Mdot
.932 .3471 Mdot
.932 .34715 Mdot
.932 .34778 Mdot
.932 .3481 Mdot
.932 .34865 Mdot
.932 .34877 Mdot
.932 .34884 Mdot
.932 .34886 Mdot
.932 .34887 Mdot
.932 .3493 Mdot
.932 .34954 Mdot
.932 .34963 Mdot
.932 .34977 Mdot
.932 .34985 Mdot
.932 .35007 Mdot
.932 .35011 Mdot
.932 .35014 Mdot
.932 .35015 Mdot
.932 .35016 Mdot
.932 .53263 Mdot
.932 .53263 Mdot
.932 .53263 Mdot
.932 .53263 Mdot
.932 .53263 Mdot
.932 .53263 Mdot
.932 .53263 Mdot
.932 .53263 Mdot
.932 .53263 Mdot
.932 .53263 Mdot
.932 .53264 Mdot
.932 .53264 Mdot
.932 .53264 Mdot
.932 .53264 Mdot
.932 .53264 Mdot
.932 .53264 Mdot
.932 .53264 Mdot
.932 .53265 Mdot
.932 .53265 Mdot
.932 .53265 Mdot
.932 .53265 Mdot
.932 .53265 Mdot
.932 .53266 Mdot
.932 .53266 Mdot
.932 .53266 Mdot
.932 .53266 Mdot
.932 .53267 Mdot
.932 .53267 Mdot
.932 .53267 Mdot
.932 .53267 Mdot
.932 .53267 Mdot
.932 .53267 Mdot
.932 .53268 Mdot
.932 .53268 Mdot
.932 .53268 Mdot
.932 .53269 Mdot
.932 .5327 Mdot
.932 .5327 Mdot
.932 .53271 Mdot
.932 .53272 Mdot
.932 .53272 Mdot
.932 .53273 Mdot
.932 .53275 Mdot
.932 .53275 Mdot
.932 .53275 Mdot
.932 .53276 Mdot
.932 .53276 Mdot
.932 .53277 Mdot
.932 .53278 Mdot
.932 .53278 Mdot
.932 .53278 Mdot
.932 .5328 Mdot
.932 .53281 Mdot
.932 .53281 Mdot
.932 .53281 Mdot
.932 .53282 Mdot
.932 .53283 Mdot
.932 .53283 Mdot
.932 .53283 Mdot
.932 .53284 Mdot
.932 .53285 Mdot
.932 .53285 Mdot
.932 .53286 Mdot
.932 .53286 Mdot
.932 .53287 Mdot
.932 .5329 Mdot
.932 .5329 Mdot
.932 .53291 Mdot
.932 .53292 Mdot
.932 .53293 Mdot
.932 .53293 Mdot
.932 .53295 Mdot
.932 .53295 Mdot
.932 .53298 Mdot
.932 .53298 Mdot
.932 .53299 Mdot
.932 .53299 Mdot
.932 .53301 Mdot
.932 .53302 Mdot
.932 .53302 Mdot
.932 .53302 Mdot
.932 .53302 Mdot
.932 .53302 Mdot
.932 .53304 Mdot
.932 .53305 Mdot
.932 .53305 Mdot
.932 .53308 Mdot
.932 .53314 Mdot
.932 .53314 Mdot
.932 .53315 Mdot
.932 .53318 Mdot
.932 .53319 Mdot
.932 .53326 Mdot
.932 .5333 Mdot
.932 .53331 Mdot
.932 .53332 Mdot
.932 .53332 Mdot
.932 .53335 Mdot
.932 .53336 Mdot
.932 .53343 Mdot
.932 .53343 Mdot
.932 .53345 Mdot
.932 .53345 Mdot
.932 .53351 Mdot
.932 .53354 Mdot
.932 .5336 Mdot
.932 .53361 Mdot
.932 .53362 Mdot
.932 .53362 Mdot
.932 .53364 Mdot
.932 .53365 Mdot
.932 .53366 Mdot
.932 .53368 Mdot
.932 .53371 Mdot
.932 .53372 Mdot
.932 .53379 Mdot
.932 .53379 Mdot
.932 .53384 Mdot
.932 .53384 Mdot
.932 .53393 Mdot
.932 .53394 Mdot
.932 .53398 Mdot
.932 .53403 Mdot
.932 .53406 Mdot
.932 .53413 Mdot
.932 .53414 Mdot
.932 .53415 Mdot
.932 .53415 Mdot
.932 .5342 Mdot
.932 .5342 Mdot
.932 .53421 Mdot
.932 .53423 Mdot
.932 .53428 Mdot
.932 .53429 Mdot
.932 .53433 Mdot
.932 .53434 Mdot
.932 .53437 Mdot
.932 .53439 Mdot
.932 .5344 Mdot
.932 .53447 Mdot
.932 .53448 Mdot
.932 .53462 Mdot
.932 .53465 Mdot
.932 .53467 Mdot
.932 .53469 Mdot
.932 .53474 Mdot
.932 .53476 Mdot
.932 .53476 Mdot
.932 .53478 Mdot
.932 .53478 Mdot
.932 .53479 Mdot
.932 .53483 Mdot
.932 .53484 Mdot
.932 .53491 Mdot
.932 .53493 Mdot
.932 .53494 Mdot
.932 .53497 Mdot
.932 .53499 Mdot
.932 .53504 Mdot
.932 .53513 Mdot
.932 .53514 Mdot
.932 .53516 Mdot
.932 .53517 Mdot
.932 .53518 Mdot
.932 .53518 Mdot
.932 .5352 Mdot
.932 .53524 Mdot
.932 .53525 Mdot
.932 .53525 Mdot
.932 .53526 Mdot
.932 .53527 Mdot
.932 .53529 Mdot
.932 .53529 Mdot
.932 .53534 Mdot
.932 .53535 Mdot
.932 .53539 Mdot
.932 .53542 Mdot
.932 .53543 Mdot
.932 .53546 Mdot
.932 .53548 Mdot
.932 .53564 Mdot
.932 .53567 Mdot
.932 .53573 Mdot
.932 .53574 Mdot
.932 .53574 Mdot
.932 .53581 Mdot
.932 .53582 Mdot
.932 .53583 Mdot
.932 .53591 Mdot
.932 .53595 Mdot
.932 .53595 Mdot
.932 .53596 Mdot
.932 .53601 Mdot
.932 .53602 Mdot
.932 .53608 Mdot
.932 .53608 Mdot
.932 .53609 Mdot
.932 .53609 Mdot
.932 .53612 Mdot
.932 .53617 Mdot
.932 .53619 Mdot
.932 .53629 Mdot
.932 .5363 Mdot
.932 .53631 Mdot
.932 .53636 Mdot
.932 .53639 Mdot
.932 .53648 Mdot
.932 .53651 Mdot
.932 .53656 Mdot
.932 .53658 Mdot
.932 .53658 Mdot
.932 .53659 Mdot
.932 .53659 Mdot
.932 .53671 Mdot
.932 .53672 Mdot
.932 .53675 Mdot
.932 .53677 Mdot
.932 .53678 Mdot
.932 .5368 Mdot
.932 .5368 Mdot
.932 .53681 Mdot
.932 .53681 Mdot
.932 .53683 Mdot
.932 .53686 Mdot
.932 .53692 Mdot
.932 .53695 Mdot
.932 .53703 Mdot
.932 .53705 Mdot
.932 .53708 Mdot
.932 .53718 Mdot
.932 .5372 Mdot
.932 .53723 Mdot
.932 .53723 Mdot
.932 .53725 Mdot
.932 .53726 Mdot
.932 .53728 Mdot
.932 .53731 Mdot
.932 .53731 Mdot
.932 .53732 Mdot
.932 .53741 Mdot
.932 .53741 Mdot
.932 .53741 Mdot
.932 .53742 Mdot
.932 .53744 Mdot
.932 .53746 Mdot
.932 .53747 Mdot
.932 .53747 Mdot
.932 .5375 Mdot
.932 .53751 Mdot
.932 .53752 Mdot
.932 .53754 Mdot
.932 .53755 Mdot
.932 .53755 Mdot
.932 .53755 Mdot
.932 .53756 Mdot
.932 .53757 Mdot
.932 .53758 Mdot
.932 .53763 Mdot
.932 .53763 Mdot
.932 .53764 Mdot
.932 .53764 Mdot
.932 .53765 Mdot
.932 .53766 Mdot
.932 .53767 Mdot
.932 .53768 Mdot
.932 .53768 Mdot
.932 .53769 Mdot
.932 .5377 Mdot
.932 .53772 Mdot
.932 .53772 Mdot
.932 .53773 Mdot
.932 .53778 Mdot
.932 .53784 Mdot
.932 .53796 Mdot
.932 .53797 Mdot
.932 .53798 Mdot
.932 .53801 Mdot
.932 .53806 Mdot
.932 .53807 Mdot
.932 .53809 Mdot
.932 .53809 Mdot
.932 .5381 Mdot
.932 .5381 Mdot
.932 .53814 Mdot
.932 .53816 Mdot
.932 .53824 Mdot
.932 .53827 Mdot
.932 .53828 Mdot
.932 .53829 Mdot
.932 .5383 Mdot
.932 .53838 Mdot
.932 .5384 Mdot
.932 .53841 Mdot
.932 .53848 Mdot
.932 .53857 Mdot
.932 .53857 Mdot
.932 .53862 Mdot
.932 .53867 Mdot
.932 .53873 Mdot
.932 .53878 Mdot
.932 .53882 Mdot
.932 .53924 Mdot
.932 .53927 Mdot
.932 .53933 Mdot
.932 .53942 Mdot
.932 .53945 Mdot
.932 .5395 Mdot
.932 .53953 Mdot
.932 .53958 Mdot
.932 .53964 Mdot
.932 .5398 Mdot
.932 .53985 Mdot
.932 .54001 Mdot
.932 .54027 Mdot
.932 .5403 Mdot
.932 .54034 Mdot
.932 .54035 Mdot
.932 .54052 Mdot
.932 .54062 Mdot
.932 .5408 Mdot
.932 .54085 Mdot
.932 .54088 Mdot
.932 .54089 Mdot
.932 .54089 Mdot
.932 .54189 Mdot
.932 .54192 Mdot
.932 .54197 Mdot
.932 .54204 Mdot
.932 .54212 Mdot
.932 .54234 Mdot
.932 .54239 Mdot
.932 .54248 Mdot
.932 .54253 Mdot
.932 .54264 Mdot
.934 .20651 Mdot
.934 .32045 Mdot
.934 .53404 Mdot
.936 .16934 Mdot
.936 .35159 Mdot
.936 .54194 Mdot
.938 .15404 Mdot
.938 .15599 Mdot
.938 .15639 Mdot
.938 .1585 Mdot
.938 .15901 Mdot
.938 .15947 Mdot
.938 .15964 Mdot
.938 .15983 Mdot
.938 .16081 Mdot
.938 .16107 Mdot
.938 .16113 Mdot
.938 .16116 Mdot
.938 .16117 Mdot
.938 .16118 Mdot
.938 .16121 Mdot
.938 .16125 Mdot
.938 .16129 Mdot
.938 .16144 Mdot
.938 .16149 Mdot
.938 .16152 Mdot
.938 .16152 Mdot
.938 .16154 Mdot
.938 .16163 Mdot
.938 .16166 Mdot
.938 .16169 Mdot
.938 .16172 Mdot
.938 .16182 Mdot
.938 .16192 Mdot
.938 .1621 Mdot
.938 .16215 Mdot
.938 .16227 Mdot
.938 .16251 Mdot
.938 .16263 Mdot
.938 .16269 Mdot
.938 .16296 Mdot
.938 .16312 Mdot
.938 .16318 Mdot
.938 .1632 Mdot
.938 .16326 Mdot
.938 .16335 Mdot
.938 .16367 Mdot
.938 .164 Mdot
.938 .16409 Mdot
.938 .1641 Mdot
.938 .16416 Mdot
.938 .16433 Mdot
.938 .1646 Mdot
.938 .1649 Mdot
.938 .16508 Mdot
.938 .16519 Mdot
.938 .1652 Mdot
.938 .16543 Mdot
.938 .16563 Mdot
.938 .16572 Mdot
.938 .16597 Mdot
.938 .16609 Mdot
.938 .1662 Mdot
.938 .16657 Mdot
.938 .16662 Mdot
.938 .16665 Mdot
.938 .16666 Mdot
.938 .1667 Mdot
.938 .1668 Mdot
.938 .16696 Mdot
.938 .16725 Mdot
.938 .16735 Mdot
.938 .16754 Mdot
.938 .16764 Mdot
.938 .16794 Mdot
.938 .16797 Mdot
.938 .16801 Mdot
.938 .16833 Mdot
.938 .16841 Mdot
.938 .16851 Mdot
.938 .16865 Mdot
.938 .16912 Mdot
.938 .16934 Mdot
.938 .16943 Mdot
.938 .16996 Mdot
.938 .17006 Mdot
.938 .17019 Mdot
.938 .17023 Mdot
.938 .17026 Mdot
.938 .1703 Mdot
.938 .17067 Mdot
.938 .17098 Mdot
.938 .17107 Mdot
.938 .17187 Mdot
.938 .17193 Mdot
.938 .17196 Mdot
.938 .1723 Mdot
.938 .17239 Mdot
.938 .17262 Mdot
.938 .17266 Mdot
.938 .17281 Mdot
.938 .17285 Mdot
.938 .173 Mdot
.938 .17305 Mdot
.938 .17308 Mdot
.938 .17325 Mdot
.938 .17339 Mdot
.938 .17352 Mdot
.938 .17365 Mdot
.938 .17389 Mdot
.938 .17396 Mdot
.938 .17424 Mdot
.938 .17496 Mdot
.938 .17506 Mdot
.938 .17516 Mdot
.938 .17601 Mdot
.938 .17609 Mdot
.938 .17618 Mdot
.938 .17644 Mdot
.938 .17658 Mdot
.938 .17673 Mdot
.938 .17686 Mdot
.938 .17701 Mdot
.938 .17724 Mdot
.938 .17729 Mdot
.938 .17806 Mdot
.938 .17812 Mdot
.938 .17825 Mdot
.938 .17842 Mdot
.938 .17857 Mdot
.938 .17863 Mdot
.938 .1787 Mdot
.938 .17878 Mdot
.938 .17879 Mdot
.938 .17887 Mdot
.938 .17892 Mdot
.938 .17914 Mdot
.938 .17937 Mdot
.938 .17937 Mdot
.938 .17945 Mdot
.938 .17952 Mdot
.938 .17982 Mdot
.938 .17991 Mdot
.938 .18017 Mdot
.938 .18031 Mdot
.938 .18048 Mdot
.938 .1808 Mdot
.938 .18085 Mdot
.938 .18089 Mdot
.938 .18094 Mdot
.938 .18095 Mdot
.938 .18095 Mdot
.938 .18096 Mdot
.938 .18097 Mdot
.938 .18099 Mdot
.938 .18109 Mdot
.938 .1811 Mdot
.938 .18116 Mdot
.938 .18117 Mdot
.938 .18126 Mdot
.938 .18141 Mdot
.938 .18143 Mdot
.938 .18144 Mdot
.938 .18151 Mdot
.938 .18163 Mdot
.938 .18168 Mdot
.938 .18178 Mdot
.938 .18178 Mdot
.938 .18178 Mdot
.938 .18186 Mdot
.938 .18195 Mdot
.938 .18216 Mdot
.938 .18237 Mdot
.938 .18248 Mdot
.938 .18265 Mdot
.938 .18268 Mdot
.938 .1827 Mdot
.938 .18274 Mdot
.938 .1828 Mdot
.938 .18293 Mdot
.938 .18311 Mdot
.938 .18325 Mdot
.938 .18331 Mdot
.938 .18331 Mdot
.938 .18333 Mdot
.938 .18339 Mdot
.938 .18347 Mdot
.938 .18354 Mdot
.938 .18358 Mdot
.938 .18376 Mdot
.938 .18393 Mdot
.938 .18394 Mdot
.938 .18406 Mdot
.938 .18408 Mdot
.938 .18418 Mdot
.938 .18468 Mdot
.938 .1847 Mdot
.938 .18482 Mdot
.938 .18492 Mdot
.938 .18507 Mdot
.938 .18524 Mdot
.938 .18524 Mdot
.938 .18536 Mdot
.938 .18542 Mdot
.938 .18545 Mdot
.938 .18556 Mdot
.938 .18587 Mdot
.938 .186 Mdot
.938 .18611 Mdot
.938 .18625 Mdot
.938 .18647 Mdot
.938 .18666 Mdot
.938 .18669 Mdot
.938 .18669 Mdot
.938 .18688 Mdot
.938 .18691 Mdot
.938 .187 Mdot
.938 .18717 Mdot
.938 .18718 Mdot
.938 .18725 Mdot
.938 .18729 Mdot
.938 .18738 Mdot
.938 .18742 Mdot
.938 .18746 Mdot
.938 .18748 Mdot
.938 .18751 Mdot
.938 .18753 Mdot
.938 .1876 Mdot
.938 .18768 Mdot
.938 .1877 Mdot
.938 .18781 Mdot
.938 .18784 Mdot
.938 .18788 Mdot
.938 .18798 Mdot
.938 .188 Mdot
.938 .18812 Mdot
.938 .18813 Mdot
.938 .1882 Mdot
.938 .18827 Mdot
.938 .18836 Mdot
.938 .1884 Mdot
.938 .18841 Mdot
.938 .18845 Mdot
.938 .18845 Mdot
.938 .18846 Mdot
.938 .18848 Mdot
.938 .18848 Mdot
.938 .18849 Mdot
.938 .18849 Mdot
.938 .18878 Mdot
.938 .18881 Mdot
.938 .18882 Mdot
.938 .18963 Mdot
.938 .18964 Mdot
.938 .18969 Mdot
.938 .18993 Mdot
.938 .19009 Mdot
.938 .19013 Mdot
.938 .19017 Mdot
.938 .19024 Mdot
.938 .191 Mdot
.938 .19112 Mdot
.938 .19114 Mdot
.938 .19121 Mdot
.938 .19127 Mdot
.938 .1915 Mdot
.938 .19177 Mdot
.938 .19235 Mdot
.938 .19276 Mdot
.938 .19296 Mdot
.938 .19329 Mdot
.938 .19349 Mdot
.938 .19369 Mdot
.938 .19387 Mdot
.938 .1942 Mdot
.938 .19431 Mdot
.938 .19433 Mdot
.938 .19445 Mdot
.938 .19457 Mdot
.938 .1946 Mdot
.938 .19461 Mdot
.938 .19463 Mdot
.938 .19464 Mdot
.938 .19471 Mdot
.938 .19497 Mdot
.938 .19499 Mdot
.938 .19513 Mdot
.938 .19515 Mdot
.938 .19526 Mdot
.938 .19537 Mdot
.938 .19551 Mdot
.938 .19558 Mdot
.938 .19565 Mdot
.938 .19572 Mdot
.938 .19576 Mdot
.938 .19578 Mdot
.938 .19579 Mdot
.938 .19593 Mdot
.938 .19609 Mdot
.938 .1961 Mdot
.938 .1962 Mdot
.938 .19629 Mdot
.938 .19643 Mdot
.938 .19647 Mdot
.938 .19648 Mdot
.938 .19649 Mdot
.938 .19649 Mdot
.938 .19663 Mdot
.938 .19665 Mdot
.938 .19679 Mdot
.938 .19679 Mdot
.938 .19698 Mdot
.938 .19713 Mdot
.938 .19719 Mdot
.938 .19722 Mdot
.938 .19742 Mdot
.938 .19755 Mdot
.938 .19756 Mdot
.938 .19775 Mdot
.938 .19778 Mdot
.938 .19779 Mdot
.938 .19783 Mdot
.938 .19785 Mdot
.938 .19788 Mdot
.938 .19793 Mdot
.938 .19794 Mdot
.938 .19798 Mdot
.938 .19803 Mdot
.938 .19803 Mdot
.938 .19808 Mdot
.938 .19811 Mdot
.938 .19813 Mdot
.938 .19815 Mdot
.938 .19815 Mdot
.938 .19815 Mdot
.938 .19816 Mdot
.938 .19816 Mdot
.938 .19816 Mdot
.938 .19816 Mdot
.938 .32327 Mdot
.938 .32327 Mdot
.938 .32327 Mdot
.938 .32327 Mdot
.938 .32328 Mdot
.938 .32328 Mdot
.938 .32328 Mdot
.938 .32329 Mdot
.938 .32331 Mdot
.938 .32333 Mdot
.938 .32336 Mdot
.938 .32337 Mdot
.938 .3234 Mdot
.938 .32343 Mdot
.938 .32344 Mdot
.938 .32347 Mdot
.938 .3235 Mdot
.938 .32352 Mdot
.938 .32354 Mdot
.938 .32355 Mdot
.938 .32358 Mdot
.938 .32372 Mdot
.938 .32373 Mdot
.938 .32382 Mdot
.938 .32398 Mdot
.938 .32401 Mdot
.938 .32406 Mdot
.938 .32418 Mdot
.938 .32434 Mdot
.938 .32435 Mdot
.938 .32446 Mdot
.938 .32448 Mdot
.938 .3246 Mdot
.938 .32461 Mdot
.938 .32461 Mdot
.938 .32462 Mdot
.938 .32465 Mdot
.938 .32478 Mdot
.938 .32486 Mdot
.938 .32495 Mdot
.938 .32496 Mdot
.938 .32511 Mdot
.938 .32524 Mdot
.938 .32525 Mdot
.938 .32526 Mdot
.938 .32531 Mdot
.938 .32537 Mdot
.938 .32544 Mdot
.938 .32551 Mdot
.938 .32565 Mdot
.938 .32575 Mdot
.938 .32586 Mdot
.938 .32588 Mdot
.938 .32602 Mdot
.938 .32604 Mdot
.938 .3263 Mdot
.938 .32638 Mdot
.938 .32639 Mdot
.938 .32641 Mdot
.938 .32642 Mdot
.938 .32645 Mdot
.938 .32658 Mdot
.938 .32671 Mdot
.938 .32672 Mdot
.938 .32685 Mdot
.938 .3272 Mdot
.938 .3274 Mdot
.938 .32762 Mdot
.938 .32784 Mdot
.938 .32822 Mdot
.938 .32845 Mdot
.938 .32894 Mdot
.938 .32964 Mdot
.938 .32997 Mdot
.938 .33027 Mdot
.938 .33034 Mdot
.938 .33043 Mdot
.938 .33045 Mdot
.938 .33059 Mdot
.938 .33156 Mdot
.938 .33166 Mdot
.938 .33172 Mdot
.938 .33177 Mdot
.938 .33197 Mdot
.938 .33229 Mdot
.938 .33235 Mdot
.938 .33237 Mdot
.938 .33344 Mdot
.938 .33345 Mdot
.938 .3335 Mdot
.938 .33388 Mdot
.938 .33389 Mdot
.938 .3339 Mdot
.938 .3339 Mdot
.938 .3339 Mdot
.938 .33393 Mdot
.938 .33394 Mdot
.938 .33394 Mdot
.938 .33399 Mdot
.938 .33401 Mdot
.938 .33406 Mdot
.938 .33418 Mdot
.938 .33427 Mdot
.938 .33437 Mdot
.938 .33438 Mdot
.938 .33454 Mdot
.938 .33456 Mdot
.938 .33471 Mdot
.938 .33476 Mdot
.938 .3348 Mdot
.938 .33494 Mdot
.938 .33497 Mdot
.938 .33508 Mdot
.938 .33518 Mdot
.938 .33521 Mdot
.938 .33525 Mdot
.938 .33527 Mdot
.938 .33532 Mdot
.938 .33538 Mdot
.938 .33551 Mdot
.938 .33556 Mdot
.938 .33566 Mdot
.938 .33567 Mdot
.938 .33591 Mdot
.938 .33602 Mdot
.938 .33607 Mdot
.938 .33632 Mdot
.938 .33633 Mdot
.938 .33637 Mdot
.938 .33663 Mdot
.938 .33693 Mdot
.938 .33712 Mdot
.938 .33727 Mdot
.938 .33745 Mdot
.938 .33787 Mdot
.938 .33802 Mdot
.938 .33806 Mdot
.938 .33813 Mdot
.938 .3383 Mdot
.938 .3383 Mdot
.938 .3385 Mdot
.938 .33854 Mdot
.938 .33864 Mdot
.938 .33873 Mdot
.938 .33887 Mdot
.938 .33904 Mdot
.938 .33906 Mdot
.938 .33937 Mdot
.938 .33974 Mdot
.938 .33987 Mdot
.938 .33989 Mdot
.938 .34006 Mdot
.938 .34007 Mdot
.938 .3403 Mdot
.938 .34054 Mdot
.938 .34058 Mdot
.938 .34069 Mdot
.938 .34079 Mdot
.938 .34086 Mdot
.938 .34089 Mdot
.938 .34089 Mdot
.938 .34097 Mdot
.938 .34115 Mdot
.938 .34139 Mdot
.938 .34156 Mdot
.938 .34165 Mdot
.938 .3417 Mdot
.938 .34171 Mdot
.938 .34176 Mdot
.938 .34198 Mdot
.938 .34212 Mdot
.938 .34239 Mdot
.938 .34266 Mdot
.938 .34277 Mdot
.938 .34287 Mdot
.938 .34287 Mdot
.938 .34288 Mdot
.938 .34299 Mdot
.938 .34306 Mdot
.938 .34322 Mdot
.938 .3433 Mdot
.938 .34331 Mdot
.938 .34334 Mdot
.938 .34345 Mdot
.938 .34353 Mdot
.938 .34364 Mdot
.938 .34365 Mdot
.938 .34372 Mdot
.938 .34373 Mdot
.938 .34385 Mdot
.938 .34388 Mdot
.938 .34389 Mdot
.938 .3439 Mdot
.938 .34391 Mdot
.938 .34392 Mdot
.938 .34397 Mdot
.938 .34403 Mdot
.938 .34409 Mdot
.938 .34431 Mdot
.938 .34447 Mdot
.938 .34468 Mdot
.938 .34484 Mdot
.938 .34505 Mdot
.938 .34514 Mdot
.938 .34525 Mdot
.938 .34532 Mdot
.938 .34559 Mdot
.938 .34561 Mdot
.938 .34567 Mdot
.938 .34576 Mdot
.938 .34577 Mdot
.938 .34602 Mdot
.938 .34626 Mdot
.938 .34632 Mdot
.938 .34641 Mdot
.938 .34642 Mdot
.938 .3465 Mdot
.938 .34658 Mdot
.938 .34664 Mdot
.938 .3468 Mdot
.938 .34699 Mdot
.938 .347 Mdot
.938 .34712 Mdot
.938 .34718 Mdot
.938 .34734 Mdot
.938 .34742 Mdot
.938 .34747 Mdot
.938 .34748 Mdot
.938 .3475 Mdot
.938 .34753 Mdot
.938 .34758 Mdot
.938 .34763 Mdot
.938 .34782 Mdot
.938 .34787 Mdot
.938 .34791 Mdot
.938 .34791 Mdot
.938 .34794 Mdot
.938 .34795 Mdot
.938 .348 Mdot
.938 .34804 Mdot
.938 .34808 Mdot
.938 .34811 Mdot
.938 .34815 Mdot
.938 .34823 Mdot
.938 .34827 Mdot
.938 .34836 Mdot
.938 .34838 Mdot
.938 .34849 Mdot
.938 .34859 Mdot
.938 .34862 Mdot
.938 .34864 Mdot
.938 .34874 Mdot
.938 .34877 Mdot
.938 .34897 Mdot
.938 .34902 Mdot
.938 .34906 Mdot
.938 .34912 Mdot
.938 .34915 Mdot
.938 .34921 Mdot
.938 .34948 Mdot
.938 .34963 Mdot
.938 .34969 Mdot
.938 .34971 Mdot
.938 .34976 Mdot
.938 .34981 Mdot
.938 .34984 Mdot
.938 .34989 Mdot
.938 .34997 Mdot
.938 .35012 Mdot
.938 .35039 Mdot
.938 .35046 Mdot
.938 .35047 Mdot
.938 .35048 Mdot
.938 .35051 Mdot
.938 .35064 Mdot
.938 .35066 Mdot
.938 .35071 Mdot
.938 .35083 Mdot
.938 .35085 Mdot
.938 .35093 Mdot
.938 .35101 Mdot
.938 .35103 Mdot
.938 .35109 Mdot
.938 .35115 Mdot
.938 .35118 Mdot
.938 .3512 Mdot
.938 .35121 Mdot
.938 .35122 Mdot
.938 .35123 Mdot
.938 .3513 Mdot
.938 .35132 Mdot
.938 .35135 Mdot
.938 .3514 Mdot
.938 .35142 Mdot
.938 .35146 Mdot
.938 .3515 Mdot
.938 .35153 Mdot
.938 .35156 Mdot
.938 .35162 Mdot
.938 .35168 Mdot
.938 .35171 Mdot
.938 .35172 Mdot
.938 .35172 Mdot
.938 .35174 Mdot
.938 .35187 Mdot
.938 .35189 Mdot
.938 .3519 Mdot
.938 .35191 Mdot
.938 .35192 Mdot
.938 .35195 Mdot
.938 .35201 Mdot
.938 .35202 Mdot
.938 .35204 Mdot
.938 .35209 Mdot
.938 .35211 Mdot
.938 .35212 Mdot
.938 .35216 Mdot
.938 .35218 Mdot
.938 .3522 Mdot
.938 .3522 Mdot
.938 .35221 Mdot
.938 .35222 Mdot
.938 .35223 Mdot
.938 .35224 Mdot
.938 .35224 Mdot
.938 .35224 Mdot
.938 .35225 Mdot
.938 .35228 Mdot
.938 .35229 Mdot
.938 .3523 Mdot
.938 .3523 Mdot
.938 .35231 Mdot
.938 .35231 Mdot
.938 .35232 Mdot
.938 .53588 Mdot
.938 .53588 Mdot
.938 .53588 Mdot
.938 .53588 Mdot
.938 .53588 Mdot
.938 .53588 Mdot
.938 .53588 Mdot
.938 .53589 Mdot
.938 .53589 Mdot
.938 .5359 Mdot
.938 .53591 Mdot
.938 .53591 Mdot
.938 .53592 Mdot
.938 .53592 Mdot
.938 .53593 Mdot
.938 .53594 Mdot
.938 .53594 Mdot
.938 .53595 Mdot
.938 .53596 Mdot
.938 .53596 Mdot
.938 .53597 Mdot
.938 .536 Mdot
.938 .53601 Mdot
.938 .53603 Mdot
.938 .53607 Mdot
.938 .53608 Mdot
.938 .53609 Mdot
.938 .53612 Mdot
.938 .53616 Mdot
.938 .53616 Mdot
.938 .53619 Mdot
.938 .53619 Mdot
.938 .53622 Mdot
.938 .53622 Mdot
.938 .53622 Mdot
.938 .53622 Mdot
.938 .53623 Mdot
.938 .53626 Mdot
.938 .53628 Mdot
.938 .5363 Mdot
.938 .5363 Mdot
.938 .53633 Mdot
.938 .53636 Mdot
.938 .53636 Mdot
.938 .53637 Mdot
.938 .53638 Mdot
.938 .53639 Mdot
.938 .53641 Mdot
.938 .53642 Mdot
.938 .53645 Mdot
.938 .53647 Mdot
.938 .53649 Mdot
.938 .5365 Mdot
.938 .53653 Mdot
.938 .53653 Mdot
.938 .53658 Mdot
.938 .5366 Mdot
.938 .5366 Mdot
.938 .5366 Mdot
.938 .53661 Mdot
.938 .53661 Mdot
.938 .53664 Mdot
.938 .53666 Mdot
.938 .53666 Mdot
.938 .53669 Mdot
.938 .53675 Mdot
.938 .53679 Mdot
.938 .53683 Mdot
.938 .53687 Mdot
.938 .53694 Mdot
.938 .53698 Mdot
.938 .53707 Mdot
.938 .53712 Mdot
.938 .53719 Mdot
.938 .53724 Mdot
.938 .53729 Mdot
.938 .5373 Mdot
.938 .53732 Mdot
.938 .53732 Mdot
.938 .53735 Mdot
.938 .5375 Mdot
.938 .53752 Mdot
.938 .53753 Mdot
.938 .53753 Mdot
.938 .53757 Mdot
.938 .53762 Mdot
.938 .53763 Mdot
.938 .53763 Mdot
.938 .5378 Mdot
.938 .5378 Mdot
.938 .53781 Mdot
.938 .53787 Mdot
.938 .53787 Mdot
.938 .53787 Mdot
.938 .53787 Mdot
.938 .53787 Mdot
.938 .53788 Mdot
.938 .53788 Mdot
.938 .53788 Mdot
.938 .53789 Mdot
.938 .5379 Mdot
.938 .53791 Mdot
.938 .53793 Mdot
.938 .53794 Mdot
.938 .53794 Mdot
.938 .53797 Mdot
.938 .53797 Mdot
.938 .53799 Mdot
.938 .538 Mdot
.938 .53801 Mdot
.938 .53803 Mdot
.938 .53804 Mdot
.938 .53805 Mdot
.938 .53807 Mdot
.938 .53807 Mdot
.938 .53808 Mdot
.938 .53808 Mdot
.938 .53809 Mdot
.938 .5381 Mdot
.938 .53812 Mdot
.938 .53813 Mdot
.938 .53814 Mdot
.938 .53814 Mdot
.938 .53818 Mdot
.938 .5382 Mdot
.938 .5382 Mdot
.938 .53824 Mdot
.938 .53824 Mdot
.938 .53825 Mdot
.938 .53829 Mdot
.938 .53834 Mdot
.938 .53837 Mdot
.938 .53839 Mdot
.938 .53842 Mdot
.938 .53848 Mdot
.938 .53851 Mdot
.938 .53851 Mdot
.938 .53852 Mdot
.938 .53855 Mdot
.938 .53855 Mdot
.938 .53859 Mdot
.938 .53862 Mdot
.938 .53864 Mdot
.938 .53866 Mdot
.938 .53867 Mdot
.938 .53877 Mdot
.938 .53879 Mdot
.938 .5388 Mdot
.938 .53882 Mdot
.938 .53883 Mdot
.938 .53886 Mdot
.938 .5389 Mdot
.938 .53891 Mdot
.938 .53892 Mdot
.938 .53894 Mdot
.938 .53895 Mdot
.938 .53896 Mdot
.938 .53896 Mdot
.938 .53897 Mdot
.938 .539 Mdot
.938 .53904 Mdot
.938 .53906 Mdot
.938 .53908 Mdot
.938 .53909 Mdot
.938 .53909 Mdot
.938 .5391 Mdot
.938 .53913 Mdot
.938 .53916 Mdot
.938 .5392 Mdot
.938 .53925 Mdot
.938 .53927 Mdot
.938 .53928 Mdot
.938 .53928 Mdot
.938 .53928 Mdot
.938 .5393 Mdot
.938 .53931 Mdot
.938 .53934 Mdot
.938 .53936 Mdot
.938 .53936 Mdot
.938 .53936 Mdot
.938 .5394 Mdot
.938 .53941 Mdot
.938 .53942 Mdot
.938 .53943 Mdot
.938 .53943 Mdot
.938 .53945 Mdot
.938 .53946 Mdot
.938 .53946 Mdot
.938 .53946 Mdot
.938 .53946 Mdot
.938 .53946 Mdot
.938 .53947 Mdot
.938 .53948 Mdot
.938 .53949 Mdot
.938 .53956 Mdot
.938 .5396 Mdot
.938 .53963 Mdot
.938 .53968 Mdot
.938 .5397 Mdot
.938 .53977 Mdot
.938 .53978 Mdot
.938 .5398 Mdot
.938 .5398 Mdot
.938 .53985 Mdot
.938 .5399 Mdot
.938 .53991 Mdot
.938 .53993 Mdot
.938 .53993 Mdot
.938 .53995 Mdot
.938 .53996 Mdot
.938 .53997 Mdot
.938 .54001 Mdot
.938 .54004 Mdot
.938 .54007 Mdot
.938 .54008 Mdot
.938 .54025 Mdot
.938 .54026 Mdot
.938 .54031 Mdot
.938 .54035 Mdot
.938 .54038 Mdot
.938 .54041 Mdot
.938 .54044 Mdot
.938 .54049 Mdot
.938 .54051 Mdot
.938 .54053 Mdot
.938 .54072 Mdot
.938 .54074 Mdot
.938 .54076 Mdot
.938 .54092 Mdot
.938 .54098 Mdot
.938 .541 Mdot
.938 .54105 Mdot
.938 .54108 Mdot
.938 .54111 Mdot
.938 .54114 Mdot
.938 .54118 Mdot
.938 .54119 Mdot
.938 .5412 Mdot
.938 .54123 Mdot
.938 .54124 Mdot
.938 .54127 Mdot
.938 .54128 Mdot
.938 .54133 Mdot
.938 .54135 Mdot
.938 .54143 Mdot
.938 .54144 Mdot
.938 .54145 Mdot
.938 .54163 Mdot
.938 .54165 Mdot
.938 .54172 Mdot
.938 .5418 Mdot
.938 .54181 Mdot
.938 .54182 Mdot
.938 .54183 Mdot
.938 .54186 Mdot
.938 .54188 Mdot
.938 .542 Mdot
.938 .54202 Mdot
.938 .54207 Mdot
.938 .54218 Mdot
.938 .54221 Mdot
.938 .54223 Mdot
.938 .54225 Mdot
.938 .54232 Mdot
.938 .54233 Mdot
.938 .54234 Mdot
.938 .54241 Mdot
.938 .54243 Mdot
.938 .54247 Mdot
.938 .5425 Mdot
.938 .54256 Mdot
.938 .5426 Mdot
.938 .54262 Mdot
.938 .54263 Mdot
.938 .54263 Mdot
.938 .54264 Mdot
.938 .54265 Mdot
.938 .54274 Mdot
.938 .54276 Mdot
.938 .54279 Mdot
.938 .54285 Mdot
.938 .54287 Mdot
.938 .54292 Mdot
.938 .54297 Mdot
.938 .54297 Mdot
.938 .543 Mdot
.938 .54304 Mdot
.938 .54311 Mdot
.938 .54317 Mdot
.938 .54321 Mdot
.938 .54323 Mdot
.938 .54323 Mdot
.938 .54325 Mdot
.938 .54333 Mdot
.938 .5434 Mdot
.938 .54343 Mdot
.938 .54344 Mdot
.938 .54344 Mdot
.938 .54346 Mdot
.938 .5435 Mdot
.938 .54356 Mdot
.938 .54358 Mdot
.938 .5436 Mdot
.938 .54366 Mdot
.938 .54369 Mdot
.938 .5437 Mdot
.938 .54374 Mdot
.938 .54377 Mdot
.938 .54379 Mdot
.938 .5438 Mdot
.938 .54381 Mdot
.938 .54381 Mdot
.938 .54383 Mdot
.938 .54384 Mdot
.938 .54384 Mdot
.938 .54385 Mdot
.938 .54386 Mdot
.938 .54389 Mdot
.938 .5439 Mdot
.938 .54391 Mdot
.938 .54392 Mdot
.938 .54392 Mdot
.938 .54392 Mdot
.938 .54393 Mdot
.938 .54395 Mdot
.938 .54401 Mdot
.938 .54425 Mdot
.938 .54429 Mdot
.938 .54433 Mdot
.938 .54444 Mdot
.938 .54457 Mdot
.938 .54509 Mdot
.938 .54519 Mdot
.938 .54568 Mdot
.94 .15327 Mdot
.94 .16899 Mdot
.94 .33258 Mdot
.94 .35304 Mdot
.94 .54217 Mdot
.94 .54595 Mdot
.942 .14585 Mdot
.942 .1459 Mdot
.942 .14595 Mdot
.942 .1463 Mdot
.942 .14642 Mdot
.942 .14667 Mdot
.942 .14668 Mdot
.942 .14675 Mdot
.942 .14679 Mdot
.942 .14698 Mdot
.942 .14699 Mdot
.942 .14749 Mdot
.942 .14785 Mdot
.942 .14898 Mdot
.942 .14909 Mdot
.942 .14915 Mdot
.942 .1496 Mdot
.942 .14981 Mdot
.942 .15003 Mdot
.942 .15003 Mdot
.942 .15007 Mdot
.942 .15033 Mdot
.942 .15092 Mdot
.942 .15115 Mdot
.942 .15174 Mdot
.942 .15178 Mdot
.942 .1531 Mdot
.942 .15337 Mdot
.942 .15461 Mdot
.942 .1551 Mdot
.942 .15525 Mdot
.942 .15633 Mdot
.942 .15673 Mdot
.942 .15688 Mdot
.942 .15714 Mdot
.942 .15729 Mdot
.942 .15731 Mdot
.942 .15734 Mdot
.942 .15735 Mdot
.942 .15737 Mdot
.942 .15762 Mdot
.942 .15763 Mdot
.942 .15773 Mdot
.942 .15776 Mdot
.942 .15781 Mdot
.942 .15783 Mdot
.942 .15812 Mdot
.942 .15847 Mdot
.942 .15873 Mdot
.942 .1591 Mdot
.942 .15998 Mdot
.942 .16016 Mdot
.942 .16078 Mdot
.942 .16102 Mdot
.942 .16123 Mdot
.942 .16174 Mdot
.942 .16188 Mdot
.942 .16206 Mdot
.942 .16239 Mdot
.942 .16242 Mdot
.942 .16279 Mdot
.942 .16313 Mdot
.942 .1633 Mdot
.942 .16344 Mdot
.942 .1635 Mdot
.942 .16354 Mdot
.942 .16392 Mdot
.942 .16396 Mdot
.942 .16409 Mdot
.942 .16444 Mdot
.942 .16494 Mdot
.942 .16496 Mdot
.942 .16516 Mdot
.942 .16546 Mdot
.942 .16556 Mdot
.942 .16558 Mdot
.942 .16558 Mdot
.942 .16576 Mdot
.942 .16598 Mdot
.942 .16603 Mdot
.942 .16684 Mdot
.942 .16735 Mdot
.942 .16747 Mdot
.942 .16786 Mdot
.942 .1686 Mdot
.942 .16902 Mdot
.942 .16957 Mdot
.942 .17032 Mdot
.942 .17059 Mdot
.942 .17066 Mdot
.942 .17086 Mdot
.942 .17219 Mdot
.942 .1725 Mdot
.942 .17297 Mdot
.942 .17377 Mdot
.942 .17478 Mdot
.942 .17506 Mdot
.942 .17506 Mdot
.942 .17507 Mdot
.942 .17507 Mdot
.942 .17508 Mdot
.942 .17515 Mdot
.942 .17515 Mdot
.942 .17519 Mdot
.942 .1752 Mdot
.942 .17521 Mdot
.942 .17529 Mdot
.942 .17545 Mdot
.942 .17583 Mdot
.942 .17599 Mdot
.942 .17605 Mdot
.942 .1761 Mdot
.942 .17631 Mdot
.942 .17639 Mdot
.942 .1764 Mdot
.942 .17649 Mdot
.942 .17665 Mdot
.942 .17666 Mdot
.942 .17676 Mdot
.942 .17677 Mdot
.942 .17701 Mdot
.942 .17713 Mdot
.942 .17716 Mdot
.942 .17716 Mdot
.942 .1772 Mdot
.942 .17727 Mdot
.942 .17746 Mdot
.942 .17758 Mdot
.942 .1776 Mdot
.942 .17787 Mdot
.942 .17833 Mdot
.942 .17839 Mdot
.942 .1787 Mdot
.942 .17938 Mdot
.942 .17938 Mdot
.942 .17938 Mdot
.942 .17938 Mdot
.942 .17938 Mdot
.942 .1794 Mdot
.942 .1794 Mdot
.942 .17941 Mdot
.942 .17941 Mdot
.942 .17941 Mdot
.942 .17943 Mdot
.942 .17947 Mdot
.942 .17956 Mdot
.942 .17962 Mdot
.942 .17968 Mdot
.942 .1797 Mdot
.942 .1797 Mdot
.942 .17972 Mdot
.942 .17976 Mdot
.942 .17979 Mdot
.942 .17979 Mdot
.942 .17988 Mdot
.942 .17989 Mdot
.942 .17992 Mdot
.942 .17996 Mdot
.942 .17999 Mdot
.942 .18007 Mdot
.942 .18018 Mdot
.942 .1802 Mdot
.942 .18028 Mdot
.942 .18047 Mdot
.942 .18052 Mdot
.942 .1806 Mdot
.942 .1806 Mdot
.942 .1807 Mdot
.942 .18095 Mdot
.942 .18097 Mdot
.942 .18101 Mdot
.942 .18102 Mdot
.942 .18111 Mdot
.942 .18114 Mdot
.942 .18116 Mdot
.942 .18124 Mdot
.942 .18134 Mdot
.942 .18135 Mdot
.942 .18137 Mdot
.942 .1814 Mdot
.942 .18141 Mdot
.942 .18163 Mdot
.942 .1817 Mdot
.942 .18176 Mdot
.942 .1818 Mdot
.942 .1818 Mdot
.942 .18186 Mdot
.942 .18191 Mdot
.942 .182 Mdot
.942 .18204 Mdot
.942 .18207 Mdot
.942 .18216 Mdot
.942 .18231 Mdot
.942 .18232 Mdot
.942 .18247 Mdot
.942 .1825 Mdot
.942 .18252 Mdot
.942 .18257 Mdot
.942 .18264 Mdot
.942 .18265 Mdot
.942 .1827 Mdot
.942 .18284 Mdot
.942 .18288 Mdot
.942 .18312 Mdot
.942 .18323 Mdot
.942 .18324 Mdot
.942 .1833 Mdot
.942 .18337 Mdot
.942 .18341 Mdot
.942 .18354 Mdot
.942 .18356 Mdot
.942 .18359 Mdot
.942 .18362 Mdot
.942 .18377 Mdot
.942 .18387 Mdot
.942 .18389 Mdot
.942 .18399 Mdot
.942 .18403 Mdot
.942 .18406 Mdot
.942 .18418 Mdot
.942 .18419 Mdot
.942 .1842 Mdot
.942 .18427 Mdot
.942 .18441 Mdot
.942 .18443 Mdot
.942 .1845 Mdot
.942 .18452 Mdot
.942 .18455 Mdot
.942 .18456 Mdot
.942 .1846 Mdot
.942 .18462 Mdot
.942 .18465 Mdot
.942 .18484 Mdot
.942 .18487 Mdot
.942 .18495 Mdot
.942 .18503 Mdot
.942 .18511 Mdot
.942 .18514 Mdot
.942 .18517 Mdot
.942 .18523 Mdot
.942 .18525 Mdot
.942 .18525 Mdot
.942 .18527 Mdot
.942 .18528 Mdot
.942 .18534 Mdot
.942 .18542 Mdot
.942 .18547 Mdot
.942 .18552 Mdot
.942 .18561 Mdot
.942 .18566 Mdot
.942 .18569 Mdot
.942 .18571 Mdot
.942 .18574 Mdot
.942 .18581 Mdot
.942 .18584 Mdot
.942 .18586 Mdot
.942 .18588 Mdot
.942 .18591 Mdot
.942 .18601 Mdot
.942 .18603 Mdot
.942 .18604 Mdot
.942 .18613 Mdot
.942 .18636 Mdot
.942 .18642 Mdot
.942 .1865 Mdot
.942 .18654 Mdot
.942 .18656 Mdot
.942 .18661 Mdot
.942 .18662 Mdot
.942 .18665 Mdot
.942 .18668 Mdot
.942 .18672 Mdot
.942 .18679 Mdot
.942 .18681 Mdot
.942 .18682 Mdot
.942 .18683 Mdot
.942 .18685 Mdot
.942 .1869 Mdot
.942 .18692 Mdot
.942 .18693 Mdot
.942 .18698 Mdot
.942 .18709 Mdot
.942 .18711 Mdot
.942 .18711 Mdot
.942 .18715 Mdot
.942 .18718 Mdot
.942 .18719 Mdot
.942 .1872 Mdot
.942 .18723 Mdot
.942 .18729 Mdot
.942 .1873 Mdot
.942 .18735 Mdot
.942 .18743 Mdot
.942 .1875 Mdot
.942 .18751 Mdot
.942 .18754 Mdot
.942 .18756 Mdot
.942 .18757 Mdot
.942 .1876 Mdot
.942 .18765 Mdot
.942 .18767 Mdot
.942 .18772 Mdot
.942 .18772 Mdot
.942 .18774 Mdot
.942 .18775 Mdot
.942 .18775 Mdot
.942 .18776 Mdot
.942 .18782 Mdot
.942 .18784 Mdot
.942 .18784 Mdot
.942 .18786 Mdot
.942 .18787 Mdot
.942 .18793 Mdot
.942 .18793 Mdot
.942 .18795 Mdot
.942 .18797 Mdot
.942 .18798 Mdot
.942 .18802 Mdot
.942 .18803 Mdot
.942 .18803 Mdot
.942 .18803 Mdot
.942 .18804 Mdot
.942 .18806 Mdot
.942 .18809 Mdot
.942 .18809 Mdot
.942 .18809 Mdot
.942 .18809 Mdot
.942 .18809 Mdot
.942 .1881 Mdot
.942 .1881 Mdot
.942 .1881 Mdot
.942 .1881 Mdot
.942 .1881 Mdot
.942 .3088 Mdot
.942 .30902 Mdot
.942 .30921 Mdot
.942 .31055 Mdot
.942 .31101 Mdot
.942 .31194 Mdot
.942 .31198 Mdot
.942 .31223 Mdot
.942 .31241 Mdot
.942 .31309 Mdot
.942 .31312 Mdot
.942 .31496 Mdot
.942 .31625 Mdot
.942 .3202 Mdot
.942 .32058 Mdot
.942 .32076 Mdot
.942 .32227 Mdot
.942 .32297 Mdot
.942 .32366 Mdot
.942 .32367 Mdot
.942 .32379 Mdot
.942 .32463 Mdot
.942 .32648 Mdot
.942 .32719 Mdot
.942 .32894 Mdot
.942 .32907 Mdot
.942 .33278 Mdot
.942 .33353 Mdot
.942 .33577 Mdot
.942 .33577 Mdot
.942 .33577 Mdot
.942 .33577 Mdot
.942 .33577 Mdot
.942 .33578 Mdot
.942 .33578 Mdot
.942 .33578 Mdot
.942 .33578 Mdot
.942 .33579 Mdot
.942 .33582 Mdot
.942 .33586 Mdot
.942 .33586 Mdot
.942 .33586 Mdot
.942 .33587 Mdot
.942 .33588 Mdot
.942 .33594 Mdot
.942 .33595 Mdot
.942 .33597 Mdot
.942 .336 Mdot
.942 .33601 Mdot
.942 .33609 Mdot
.942 .3361 Mdot
.942 .33613 Mdot
.942 .33613 Mdot
.942 .33616 Mdot
.942 .33623 Mdot
.942 .33624 Mdot
.942 .33625 Mdot
.942 .33625 Mdot
.942 .33628 Mdot
.942 .33629 Mdot
.942 .33635 Mdot
.942 .33638 Mdot
.942 .33645 Mdot
.942 .33649 Mdot
.942 .3365 Mdot
.942 .33654 Mdot
.942 .33657 Mdot
.942 .33658 Mdot
.942 .33667 Mdot
.942 .33668 Mdot
.942 .33679 Mdot
.942 .33686 Mdot
.942 .33688 Mdot
.942 .33696 Mdot
.942 .337 Mdot
.942 .33701 Mdot
.942 .33703 Mdot
.942 .33707 Mdot
.942 .33712 Mdot
.942 .33713 Mdot
.942 .33715 Mdot
.942 .3373 Mdot
.942 .33737 Mdot
.942 .33738 Mdot
.942 .33741 Mdot
.942 .33747 Mdot
.942 .33751 Mdot
.942 .33752 Mdot
.942 .33753 Mdot
.942 .33755 Mdot
.942 .33766 Mdot
.942 .33771 Mdot
.942 .33775 Mdot
.942 .33779 Mdot
.942 .33781 Mdot
.942 .33785 Mdot
.942 .33787 Mdot
.942 .3379 Mdot
.942 .33796 Mdot
.942 .33807 Mdot
.942 .33815 Mdot
.942 .3382 Mdot
.942 .33847 Mdot
.942 .33858 Mdot
.942 .3386 Mdot
.942 .33863 Mdot
.942 .33877 Mdot
.942 .3388 Mdot
.942 .33884 Mdot
.942 .33886 Mdot
.942 .3389 Mdot
.942 .339 Mdot
.942 .33903 Mdot
.942 .33906 Mdot
.942 .3391 Mdot
.942 .33917 Mdot
.942 .3393 Mdot
.942 .33937 Mdot
.942 .33944 Mdot
.942 .33955 Mdot
.942 .33963 Mdot
.942 .33964 Mdot
.942 .33967 Mdot
.942 .33967 Mdot
.942 .33969 Mdot
.942 .33977 Mdot
.942 .33981 Mdot
.942 .33986 Mdot
.942 .33998 Mdot
.942 .34008 Mdot
.942 .34019 Mdot
.942 .34023 Mdot
.942 .34049 Mdot
.942 .34053 Mdot
.942 .34056 Mdot
.942 .34061 Mdot
.942 .34062 Mdot
.942 .34063 Mdot
.942 .34066 Mdot
.942 .34069 Mdot
.942 .34078 Mdot
.942 .34081 Mdot
.942 .341 Mdot
.942 .34109 Mdot
.942 .34111 Mdot
.942 .34113 Mdot
.942 .34128 Mdot
.942 .34132 Mdot
.942 .34138 Mdot
.942 .34147 Mdot
.942 .34151 Mdot
.942 .34154 Mdot
.942 .34167 Mdot
.942 .34178 Mdot
.942 .34187 Mdot
.942 .34191 Mdot
.942 .34195 Mdot
.942 .34197 Mdot
.942 .34215 Mdot
.942 .34221 Mdot
.942 .34229 Mdot
.942 .3423 Mdot
.942 .34237 Mdot
.942 .34239 Mdot
.942 .34253 Mdot
.942 .34261 Mdot
.942 .34263 Mdot
.942 .34269 Mdot
.942 .34272 Mdot
.942 .34276 Mdot
.942 .34285 Mdot
.942 .3429 Mdot
.942 .34309 Mdot
.942 .34315 Mdot
.942 .34316 Mdot
.942 .34324 Mdot
.942 .34325 Mdot
.942 .34326 Mdot
.942 .34332 Mdot
.942 .34335 Mdot
.942 .34339 Mdot
.942 .34345 Mdot
.942 .3435 Mdot
.942 .34358 Mdot
.942 .34359 Mdot
.942 .34359 Mdot
.942 .34363 Mdot
.942 .34379 Mdot
.942 .34391 Mdot
.942 .34394 Mdot
.942 .344 Mdot
.942 .34411 Mdot
.942 .34417 Mdot
.942 .34418 Mdot
.942 .34424 Mdot
.942 .34425 Mdot
.942 .34429 Mdot
.942 .34437 Mdot
.942 .34447 Mdot
.942 .34474 Mdot
.942 .34475 Mdot
.942 .34479 Mdot
.942 .34481 Mdot
.942 .34481 Mdot
.942 .34483 Mdot
.942 .34494 Mdot
.942 .34505 Mdot
.942 .34508 Mdot
.942 .34511 Mdot
.942 .34522 Mdot
.942 .34523 Mdot
.942 .34524 Mdot
.942 .34528 Mdot
.942 .34531 Mdot
.942 .34561 Mdot
.942 .34573 Mdot
.942 .34574 Mdot
.942 .34583 Mdot
.942 .34587 Mdot
.942 .34589 Mdot
.942 .34612 Mdot
.942 .34621 Mdot
.942 .34623 Mdot
.942 .34637 Mdot
.942 .34646 Mdot
.942 .34649 Mdot
.942 .34655 Mdot
.942 .34658 Mdot
.942 .34659 Mdot
.942 .34669 Mdot
.942 .34669 Mdot
.942 .34673 Mdot
.942 .34677 Mdot
.942 .3468 Mdot
.942 .3468 Mdot
.942 .34682 Mdot
.942 .3469 Mdot
.942 .34696 Mdot
.942 .34706 Mdot
.942 .34711 Mdot
.942 .34713 Mdot
.942 .34713 Mdot
.942 .34713 Mdot
.942 .34714 Mdot
.942 .34714 Mdot
.942 .34716 Mdot
.942 .34717 Mdot
.942 .34717 Mdot
.942 .34717 Mdot
.942 .34717 Mdot
.942 .34724 Mdot
.942 .34751 Mdot
.942 .34792 Mdot
.942 .34826 Mdot
.942 .34832 Mdot
.942 .34839 Mdot
.942 .3487 Mdot
.942 .3488 Mdot
.942 .34898 Mdot
.942 .34907 Mdot
.942 .34909 Mdot
.942 .34921 Mdot
.942 .3494 Mdot
.942 .34941 Mdot
.942 .34946 Mdot
.942 .3495 Mdot
.942 .3495 Mdot
.942 .34953 Mdot
.942 .3496 Mdot
.942 .34965 Mdot
.942 .34976 Mdot
.942 .34987 Mdot
.942 .34988 Mdot
.942 .34996 Mdot
.942 .34997 Mdot
.942 .34998 Mdot
.942 .35013 Mdot
.942 .35021 Mdot
.942 .35022 Mdot
.942 .35029 Mdot
.942 .35033 Mdot
.942 .35036 Mdot
.942 .35047 Mdot
.942 .35052 Mdot
.942 .35057 Mdot
.942 .3507 Mdot
.942 .35074 Mdot
.942 .35101 Mdot
.942 .35107 Mdot
.942 .35114 Mdot
.942 .35121 Mdot
.942 .35121 Mdot
.942 .35122 Mdot
.942 .35123 Mdot
.942 .35125 Mdot
.942 .35125 Mdot
.942 .3513 Mdot
.942 .35131 Mdot
.942 .35131 Mdot
.942 .35132 Mdot
.942 .35132 Mdot
.942 .35135 Mdot
.942 .35141 Mdot
.942 .35144 Mdot
.942 .35153 Mdot
.942 .35176 Mdot
.942 .35179 Mdot
.942 .35189 Mdot
.942 .35215 Mdot
.942 .35221 Mdot
.942 .35249 Mdot
.942 .3525 Mdot
.942 .35263 Mdot
.942 .35267 Mdot
.942 .3528 Mdot
.942 .35286 Mdot
.942 .35286 Mdot
.942 .35286 Mdot
.942 .35291 Mdot
.942 .35296 Mdot
.942 .35305 Mdot
.942 .35306 Mdot
.942 .35309 Mdot
.942 .3534 Mdot
.942 .35351 Mdot
.942 .35355 Mdot
.942 .35356 Mdot
.942 .35358 Mdot
.942 .35358 Mdot
.942 .35363 Mdot
.942 .35366 Mdot
.942 .35373 Mdot
.942 .35374 Mdot
.942 .35376 Mdot
.942 .5381 Mdot
.942 .5381 Mdot
.942 .5381 Mdot
.942 .5381 Mdot
.942 .5381 Mdot
.942 .5381 Mdot
.942 .5381 Mdot
.942 .5381 Mdot
.942 .5381 Mdot
.942 .53811 Mdot
.942 .53811 Mdot
.942 .53812 Mdot
.942 .53812 Mdot
.942 .53812 Mdot
.942 .53812 Mdot
.942 .53812 Mdot
.942 .53813 Mdot
.942 .53813 Mdot
.942 .53813 Mdot
.942 .53814 Mdot
.942 .53814 Mdot
.942 .53815 Mdot
.942 .53815 Mdot
.942 .53815 Mdot
.942 .53816 Mdot
.942 .53816 Mdot
.942 .53816 Mdot
.942 .53817 Mdot
.942 .53817 Mdot
.942 .53818 Mdot
.942 .53818 Mdot
.942 .53818 Mdot
.942 .53818 Mdot
.942 .53819 Mdot
.942 .5382 Mdot
.942 .53821 Mdot
.942 .53821 Mdot
.942 .53822 Mdot
.942 .53822 Mdot
.942 .53822 Mdot
.942 .53823 Mdot
.942 .53824 Mdot
.942 .53826 Mdot
.942 .53827 Mdot
.942 .53827 Mdot
.942 .53829 Mdot
.942 .53829 Mdot
.942 .53829 Mdot
.942 .5383 Mdot
.942 .5383 Mdot
.942 .53831 Mdot
.942 .53831 Mdot
.942 .53831 Mdot
.942 .53834 Mdot
.942 .53835 Mdot
.942 .53835 Mdot
.942 .53835 Mdot
.942 .53836 Mdot
.942 .53837 Mdot
.942 .53837 Mdot
.942 .53837 Mdot
.942 .53838 Mdot
.942 .53839 Mdot
.942 .5384 Mdot
.942 .53841 Mdot
.942 .53841 Mdot
.942 .53841 Mdot
.942 .53842 Mdot
.942 .53843 Mdot
.942 .53844 Mdot
.942 .53845 Mdot
.942 .53847 Mdot
.942 .53852 Mdot
.942 .53853 Mdot
.942 .53854 Mdot
.942 .53854 Mdot
.942 .53856 Mdot
.942 .53857 Mdot
.942 .53857 Mdot
.942 .53857 Mdot
.942 .53858 Mdot
.942 .5386 Mdot
.942 .5386 Mdot
.942 .53861 Mdot
.942 .53861 Mdot
.942 .53862 Mdot
.942 .53864 Mdot
.942 .53865 Mdot
.942 .53866 Mdot
.942 .53868 Mdot
.942 .53869 Mdot
.942 .5387 Mdot
.942 .5387 Mdot
.942 .5387 Mdot
.942 .5387 Mdot
.942 .53872 Mdot
.942 .53872 Mdot
.942 .53873 Mdot
.942 .53875 Mdot
.942 .53876 Mdot
.942 .53878 Mdot
.942 .53879 Mdot
.942 .53883 Mdot
.942 .53883 Mdot
.942 .53884 Mdot
.942 .53885 Mdot
.942 .53885 Mdot
.942 .53885 Mdot
.942 .53886 Mdot
.942 .53887 Mdot
.942 .53888 Mdot
.942 .53891 Mdot
.942 .53892 Mdot
.942 .53892 Mdot
.942 .53893 Mdot
.942 .53895 Mdot
.942 .53896 Mdot
.942 .53897 Mdot
.942 .53899 Mdot
.942 .53899 Mdot
.942 .53901 Mdot
.942 .53904 Mdot
.942 .53905 Mdot
.942 .53906 Mdot
.942 .53906 Mdot
.942 .53909 Mdot
.942 .5391 Mdot
.942 .53911 Mdot
.942 .53912 Mdot
.942 .53913 Mdot
.942 .53915 Mdot
.942 .5392 Mdot
.942 .53921 Mdot
.942 .53924 Mdot
.942 .53925 Mdot
.942 .53925 Mdot
.942 .53927 Mdot
.942 .53928 Mdot
.942 .53928 Mdot
.942 .53929 Mdot
.942 .53932 Mdot
.942 .53932 Mdot
.942 .53935 Mdot
.942 .53937 Mdot
.942 .53938 Mdot
.942 .53939 Mdot
.942 .53941 Mdot
.942 .53942 Mdot
.942 .53943 Mdot
.942 .53943 Mdot
.942 .53944 Mdot
.942 .53945 Mdot
.942 .53947 Mdot
.942 .53951 Mdot
.942 .53952 Mdot
.942 .53952 Mdot
.942 .53953 Mdot
.942 .53953 Mdot
.942 .53955 Mdot
.942 .53957 Mdot
.942 .53957 Mdot
.942 .53958 Mdot
.942 .5396 Mdot
.942 .5396 Mdot
.942 .53961 Mdot
.942 .53961 Mdot
.942 .53967 Mdot
.942 .53969 Mdot
.942 .53969 Mdot
.942 .5397 Mdot
.942 .53972 Mdot
.942 .53976 Mdot
.942 .53977 Mdot
.942 .53978 Mdot
.942 .5398 Mdot
.942 .53982 Mdot
.942 .53982 Mdot
.942 .53983 Mdot
.942 .53984 Mdot
.942 .53984 Mdot
.942 .53986 Mdot
.942 .53986 Mdot
.942 .53987 Mdot
.942 .53988 Mdot
.942 .53988 Mdot
.942 .53988 Mdot
.942 .53989 Mdot
.942 .5399 Mdot
.942 .53991 Mdot
.942 .53993 Mdot
.942 .53994 Mdot
.942 .53994 Mdot
.942 .53994 Mdot
.942 .53994 Mdot
.942 .53995 Mdot
.942 .53995 Mdot
.942 .53995 Mdot
.942 .53995 Mdot
.942 .53995 Mdot
.942 .53995 Mdot
.942 .53995 Mdot
.942 .5401 Mdot
.942 .54016 Mdot
.942 .54018 Mdot
.942 .54028 Mdot
.942 .54033 Mdot
.942 .54034 Mdot
.942 .54037 Mdot
.942 .54041 Mdot
.942 .54042 Mdot
.942 .54043 Mdot
.942 .54043 Mdot
.942 .54044 Mdot
.942 .54046 Mdot
.942 .54052 Mdot
.942 .54052 Mdot
.942 .54054 Mdot
.942 .54054 Mdot
.942 .54058 Mdot
.942 .5406 Mdot
.942 .5406 Mdot
.942 .54062 Mdot
.942 .54066 Mdot
.942 .54067 Mdot
.942 .54069 Mdot
.942 .54072 Mdot
.942 .5408 Mdot
.942 .54084 Mdot
.942 .54086 Mdot
.942 .54086 Mdot
.942 .54086 Mdot
.942 .54087 Mdot
.942 .54087 Mdot
.942 .54089 Mdot
.942 .54089 Mdot
.942 .54089 Mdot
.942 .54089 Mdot
.942 .54089 Mdot
.942 .54095 Mdot
.942 .54118 Mdot
.942 .54135 Mdot
.942 .54146 Mdot
.942 .54153 Mdot
.942 .54183 Mdot
.942 .54187 Mdot
.942 .54189 Mdot
.942 .54195 Mdot
.942 .54212 Mdot
.942 .54224 Mdot
.942 .54234 Mdot
.942 .54251 Mdot
.942 .5426 Mdot
.942 .54262 Mdot
.942 .54274 Mdot
.942 .54293 Mdot
.942 .54294 Mdot
.942 .54299 Mdot
.942 .54303 Mdot
.942 .54303 Mdot
.942 .54304 Mdot
.942 .54306 Mdot
.942 .54313 Mdot
.942 .54318 Mdot
.942 .54318 Mdot
.942 .5433 Mdot
.942 .54338 Mdot
.942 .54341 Mdot
.942 .54342 Mdot
.942 .54351 Mdot
.942 .54352 Mdot
.942 .54353 Mdot
.942 .54357 Mdot
.942 .54361 Mdot
.942 .54369 Mdot
.942 .54377 Mdot
.942 .54378 Mdot
.942 .54386 Mdot
.942 .5439 Mdot
.942 .54394 Mdot
.942 .54406 Mdot
.942 .54411 Mdot
.942 .54416 Mdot
.942 .54431 Mdot
.942 .54436 Mdot
.942 .54457 Mdot
.942 .54466 Mdot
.942 .54472 Mdot
.942 .54481 Mdot
.942 .54488 Mdot
.942 .54489 Mdot
.942 .5449 Mdot
.942 .54491 Mdot
.942 .54493 Mdot
.942 .54493 Mdot
.942 .54499 Mdot
.942 .545 Mdot
.942 .545 Mdot
.942 .54501 Mdot
.942 .54501 Mdot
.942 .54505 Mdot
.942 .54511 Mdot
.942 .54515 Mdot
.942 .54525 Mdot
.942 .54552 Mdot
.942 .54556 Mdot
.942 .54568 Mdot
.942 .546 Mdot
.942 .54607 Mdot
.942 .5464 Mdot
.942 .54642 Mdot
.942 .54657 Mdot
.942 .54663 Mdot
.942 .54678 Mdot
.942 .54685 Mdot
.942 .54686 Mdot
.942 .54686 Mdot
.942 .54692 Mdot
.942 .54698 Mdot
.942 .5471 Mdot
.942 .54711 Mdot
.942 .54714 Mdot
.942 .54744 Mdot
.942 .54754 Mdot
.942 .54768 Mdot
.942 .54768 Mdot
.942 .54773 Mdot
.942 .54774 Mdot
.942 .54776 Mdot
.942 .54776 Mdot
.942 .54783 Mdot
.942 .54786 Mdot
.942 .54796 Mdot
.942 .54797 Mdot
.942 .54799 Mdot
.944 .10708 Mdot
.944 .10708 Mdot
.944 .10708 Mdot
.944 .10708 Mdot
.944 .10708 Mdot
.944 .10709 Mdot
.944 .10709 Mdot
.944 .10709 Mdot
.944 .10709 Mdot
.944 .1071 Mdot
.944 .1071 Mdot
.944 .1071 Mdot
.944 .10711 Mdot
.944 .10711 Mdot
.944 .10713 Mdot
.944 .10713 Mdot
.944 .10714 Mdot
.944 .10715 Mdot
.944 .10715 Mdot
.944 .10715 Mdot
.944 .10715 Mdot
.944 .10715 Mdot
.944 .10715 Mdot
.944 .10715 Mdot
.944 .10722 Mdot
.944 .10792 Mdot
.944 .10793 Mdot
.944 .10811 Mdot
.944 .10849 Mdot
.944 .10852 Mdot
.944 .10856 Mdot
.944 .10887 Mdot
.944 .10905 Mdot
.944 .10929 Mdot
.944 .10995 Mdot
.944 .1111 Mdot
.944 .11126 Mdot
.944 .11211 Mdot
.944 .1137 Mdot
.944 .11481 Mdot
.944 .11641 Mdot
.944 .11777 Mdot
.944 .11901 Mdot
.944 .12033 Mdot
.944 .12038 Mdot
.944 .12039 Mdot
.944 .1204 Mdot
.944 .12066 Mdot
.944 .12144 Mdot
.944 .12264 Mdot
.944 .12361 Mdot
.944 .12399 Mdot
.944 .13027 Mdot
.944 .13348 Mdot
.944 .13348 Mdot
.944 .13348 Mdot
.944 .13348 Mdot
.944 .13348 Mdot
.944 .13348 Mdot
.944 .13349 Mdot
.944 .1335 Mdot
.944 .1335 Mdot
.944 .13351 Mdot
.944 .13354 Mdot
.944 .13354 Mdot
.944 .13356 Mdot
.944 .13356 Mdot
.944 .13362 Mdot
.944 .13363 Mdot
.944 .13364 Mdot
.944 .13367 Mdot
.944 .13368 Mdot
.944 .13368 Mdot
.944 .13369 Mdot
.944 .13369 Mdot
.944 .13369 Mdot
.944 .13369 Mdot
.944 .13377 Mdot
.944 .1339 Mdot
.944 .13606 Mdot
.944 .13611 Mdot
.944 .13668 Mdot
.944 .13791 Mdot
.944 .13801 Mdot
.944 .13812 Mdot
.944 .13897 Mdot
.944 .13899 Mdot
.944 .13901 Mdot
.944 .13904 Mdot
.944 .13909 Mdot
.944 .1391 Mdot
.944 .13911 Mdot
.944 .13915 Mdot
.944 .13922 Mdot
.944 .13922 Mdot
.944 .13944 Mdot
.944 .13956 Mdot
.944 .13964 Mdot
.944 .13967 Mdot
.944 .13972 Mdot
.944 .13973 Mdot
.944 .13976 Mdot
.944 .13991 Mdot
.944 .14005 Mdot
.944 .14009 Mdot
.944 .14025 Mdot
.944 .14056 Mdot
.944 .14057 Mdot
.944 .14081 Mdot
.944 .14106 Mdot
.944 .14157 Mdot
.944 .14157 Mdot
.944 .14178 Mdot
.944 .14179 Mdot
.944 .1419 Mdot
.944 .14201 Mdot
.944 .14215 Mdot
.944 .14236 Mdot
.944 .14239 Mdot
.944 .14252 Mdot
.944 .14272 Mdot
.944 .14285 Mdot
.944 .14302 Mdot
.944 .14314 Mdot
.944 .14325 Mdot
.944 .14336 Mdot
.944 .14337 Mdot
.944 .14337 Mdot
.944 .14337 Mdot
.944 .14339 Mdot
.944 .14345 Mdot
.944 .14354 Mdot
.944 .14361 Mdot
.944 .14364 Mdot
.944 .14427 Mdot
.944 .14459 Mdot
.944 .14465 Mdot
.944 .14468 Mdot
.944 .14483 Mdot
.944 .14499 Mdot
.944 .14528 Mdot
.944 .14551 Mdot
.944 .14566 Mdot
.944 .14577 Mdot
.944 .14582 Mdot
.944 .14623 Mdot
.944 .14637 Mdot
.944 .14644 Mdot
.944 .1466 Mdot
.944 .14687 Mdot
.944 .14698 Mdot
.944 .14728 Mdot
.944 .14756 Mdot
.944 .14758 Mdot
.944 .14797 Mdot
.944 .14798 Mdot
.944 .14798 Mdot
.944 .14801 Mdot
.944 .14809 Mdot
.944 .14832 Mdot
.944 .14839 Mdot
.944 .14849 Mdot
.944 .14922 Mdot
.944 .14936 Mdot
.944 .1494 Mdot
.944 .14949 Mdot
.944 .14954 Mdot
.944 .15011 Mdot
.944 .15046 Mdot
.944 .15077 Mdot
.944 .15102 Mdot
.944 .15129 Mdot
.944 .15146 Mdot
.944 .15163 Mdot
.944 .15225 Mdot
.944 .15238 Mdot
.944 .15266 Mdot
.944 .15266 Mdot
.944 .15281 Mdot
.944 .15328 Mdot
.944 .15356 Mdot
.944 .15386 Mdot
.944 .15392 Mdot
.944 .154 Mdot
.944 .15416 Mdot
.944 .15455 Mdot
.944 .15462 Mdot
.944 .15562 Mdot
.944 .15577 Mdot
.944 .15618 Mdot
.944 .15647 Mdot
.944 .15667 Mdot
.944 .15668 Mdot
.944 .15672 Mdot
.944 .15682 Mdot
.944 .15703 Mdot
.944 .15726 Mdot
.944 .15751 Mdot
.944 .15779 Mdot
.944 .15826 Mdot
.944 .15828 Mdot
.944 .15832 Mdot
.944 .1584 Mdot
.944 .15841 Mdot
.944 .15846 Mdot
.944 .15869 Mdot
.944 .15919 Mdot
.944 .15925 Mdot
.944 .15954 Mdot
.944 .15997 Mdot
.944 .16025 Mdot
.944 .16049 Mdot
.944 .16103 Mdot
.944 .16145 Mdot
.944 .16159 Mdot
.944 .16202 Mdot
.944 .16313 Mdot
.944 .16349 Mdot
.944 .16353 Mdot
.944 .16428 Mdot
.944 .16454 Mdot
.944 .16462 Mdot
.944 .16491 Mdot
.944 .16543 Mdot
.944 .16547 Mdot
.944 .16552 Mdot
.944 .16574 Mdot
.944 .16579 Mdot
.944 .1659 Mdot
.944 .16602 Mdot
.944 .16712 Mdot
.944 .16744 Mdot
.944 .16745 Mdot
.944 .1675 Mdot
.944 .16775 Mdot
.944 .16827 Mdot
.944 .16828 Mdot
.944 .16831 Mdot
.944 .16843 Mdot
.944 .1685 Mdot
.944 .16866 Mdot
.944 .16945 Mdot
.944 .16997 Mdot
.944 .17042 Mdot
.944 .17051 Mdot
.944 .17078 Mdot
.944 .17091 Mdot
.944 .17131 Mdot
.944 .17163 Mdot
.944 .17193 Mdot
.944 .17194 Mdot
.944 .17206 Mdot
.944 .17217 Mdot
.944 .17235 Mdot
.944 .17252 Mdot
.944 .17282 Mdot
.944 .17289 Mdot
.944 .17341 Mdot
.944 .17358 Mdot
.944 .17378 Mdot
.944 .17392 Mdot
.944 .17397 Mdot
.944 .17414 Mdot
.944 .17427 Mdot
.944 .17436 Mdot
.944 .17449 Mdot
.944 .1745 Mdot
.944 .17453 Mdot
.944 .17462 Mdot
.944 .17465 Mdot
.944 .17487 Mdot
.944 .17495 Mdot
.944 .17523 Mdot
.944 .17546 Mdot
.944 .17572 Mdot
.944 .17575 Mdot
.944 .17583 Mdot
.944 .17583 Mdot
.944 .17586 Mdot
.944 .17614 Mdot
.944 .17615 Mdot
.944 .17617 Mdot
.944 .17621 Mdot
.944 .17631 Mdot
.944 .17658 Mdot
.944 .17678 Mdot
.944 .17683 Mdot
.944 .17687 Mdot
.944 .17697 Mdot
.944 .17724 Mdot
.944 .17731 Mdot
.944 .17744 Mdot
.944 .17761 Mdot
.944 .17866 Mdot
.944 .17892 Mdot
.944 .17893 Mdot
.944 .17898 Mdot
.944 .1793 Mdot
.944 .17937 Mdot
.944 .17949 Mdot
.944 .1795 Mdot
.944 .1795 Mdot
.944 .17958 Mdot
.944 .18011 Mdot
.944 .18021 Mdot
.944 .18036 Mdot
.944 .18039 Mdot
.944 .18042 Mdot
.944 .18046 Mdot
.944 .18058 Mdot
.944 .1806 Mdot
.944 .18073 Mdot
.944 .18082 Mdot
.944 .18086 Mdot
.944 .18097 Mdot
.944 .18101 Mdot
.944 .18101 Mdot
.944 .18104 Mdot
.944 .18113 Mdot
.944 .1812 Mdot
.944 .18134 Mdot
.944 .18137 Mdot
.944 .18147 Mdot
.944 .18169 Mdot
.944 .18183 Mdot
.944 .18222 Mdot
.944 .18244 Mdot
.944 .18252 Mdot
.944 .18254 Mdot
.944 .18284 Mdot
.944 .18286 Mdot
.944 .18287 Mdot
.944 .18289 Mdot
.944 .18293 Mdot
.944 .18294 Mdot
.944 .183 Mdot
.944 .18304 Mdot
.944 .18305 Mdot
.944 .18311 Mdot
.944 .18312 Mdot
.944 .18314 Mdot
.944 .18645 Mdot
.944 .18669 Mdot
.944 .18675 Mdot
.944 .18678 Mdot
.944 .188 Mdot
.944 .19179 Mdot
.944 .19765 Mdot
.944 .20249 Mdot
.944 .20438 Mdot
.944 .23649 Mdot
.944 .25291 Mdot
.944 .25291 Mdot
.944 .25291 Mdot
.944 .25291 Mdot
.944 .25291 Mdot
.944 .25293 Mdot
.944 .25298 Mdot
.944 .253 Mdot
.944 .25301 Mdot
.944 .25308 Mdot
.944 .25322 Mdot
.944 .25322 Mdot
.944 .2533 Mdot
.944 .25334 Mdot
.944 .25364 Mdot
.944 .25367 Mdot
.944 .25371 Mdot
.944 .25385 Mdot
.944 .25391 Mdot
.944 .25394 Mdot
.944 .25396 Mdot
.944 .25398 Mdot
.944 .25398 Mdot
.944 .25399 Mdot
.944 .25437 Mdot
.944 .25502 Mdot
.944 .2658 Mdot
.944 .26603 Mdot
.944 .26882 Mdot
.944 .27476 Mdot
.944 .27524 Mdot
.944 .27578 Mdot
.944 .27979 Mdot
.944 .2799 Mdot
.944 .28 Mdot
.944 .28012 Mdot
.944 .28034 Mdot
.944 .28042 Mdot
.944 .28044 Mdot
.944 .28064 Mdot
.944 .28099 Mdot
.944 .28099 Mdot
.944 .282 Mdot
.944 .28253 Mdot
.944 .28291 Mdot
.944 .28307 Mdot
.944 .2833 Mdot
.944 .28334 Mdot
.944 .28347 Mdot
.944 .28415 Mdot
.944 .28482 Mdot
.944 .28501 Mdot
.944 .28572 Mdot
.944 .28713 Mdot
.944 .28717 Mdot
.944 .28827 Mdot
.944 .28938 Mdot
.944 .29164 Mdot
.944 .29167 Mdot
.944 .2926 Mdot
.944 .29264 Mdot
.944 .29309 Mdot
.944 .29357 Mdot
.944 .29421 Mdot
.944 .29511 Mdot
.944 .29523 Mdot
.944 .29578 Mdot
.944 .29667 Mdot
.944 .29722 Mdot
.944 .29792 Mdot
.944 .29847 Mdot
.944 .29893 Mdot
.944 .29939 Mdot
.944 .29941 Mdot
.944 .29941 Mdot
.944 .29942 Mdot
.944 .2995 Mdot
.944 .29976 Mdot
.944 .30014 Mdot
.944 .30044 Mdot
.944 .30055 Mdot
.944 .30316 Mdot
.944 .30445 Mdot
.944 .30468 Mdot
.944 .30481 Mdot
.944 .30544 Mdot
.944 .30607 Mdot
.944 .30721 Mdot
.944 .30813 Mdot
.944 .3087 Mdot
.944 .30915 Mdot
.944 .30933 Mdot
.944 .3109 Mdot
.944 .31143 Mdot
.944 .31172 Mdot
.944 .3123 Mdot
.944 .31334 Mdot
.944 .31372 Mdot
.944 .31483 Mdot
.944 .31585 Mdot
.944 .31593 Mdot
.944 .31735 Mdot
.944 .31736 Mdot
.944 .31737 Mdot
.944 .31747 Mdot
.944 .31774 Mdot
.944 .31858 Mdot
.944 .31881 Mdot
.944 .31914 Mdot
.944 .32164 Mdot
.944 .32214 Mdot
.944 .32224 Mdot
.944 .32257 Mdot
.944 .32272 Mdot
.944 .32318 Mdot
.944 .32326 Mdot
.944 .3246 Mdot
.944 .32562 Mdot
.944 .3257 Mdot
.944 .32668 Mdot
.944 .32745 Mdot
.944 .32826 Mdot
.944 .32879 Mdot
.944 .32929 Mdot
.944 .3311 Mdot
.944 .33145 Mdot
.944 .33163 Mdot
.944 .33226 Mdot
.944 .33226 Mdot
.944 .33266 Mdot
.944 .33396 Mdot
.944 .3347 Mdot
.944 .33478 Mdot
.944 .33549 Mdot
.944 .33564 Mdot
.944 .33585 Mdot
.944 .33623 Mdot
.944 .33659 Mdot
.944 .33721 Mdot
.944 .3374 Mdot
.944 .33826 Mdot
.944 .33831 Mdot
.944 .33839 Mdot
.944 .33872 Mdot
.944 .3397 Mdot
.944 .33976 Mdot
.944 .34008 Mdot
.944 .341 Mdot
.944 .34162 Mdot
.944 .34204 Mdot
.944 .34207 Mdot
.944 .34214 Mdot
.944 .34235 Mdot
.944 .34278 Mdot
.944 .34321 Mdot
.944 .34323 Mdot
.944 .34323 Mdot
.944 .34325 Mdot
.944 .34332 Mdot
.944 .34334 Mdot
.944 .34339 Mdot
.944 .34347 Mdot
.944 .34348 Mdot
.944 .34354 Mdot
.944 .34357 Mdot
.944 .34358 Mdot
.944 .3436 Mdot
.944 .34373 Mdot
.944 .34399 Mdot
.944 .34403 Mdot
.944 .34412 Mdot
.944 .34427 Mdot
.944 .3444 Mdot
.944 .3449 Mdot
.944 .34508 Mdot
.944 .34512 Mdot
.944 .34515 Mdot
.944 .34523 Mdot
.944 .34536 Mdot
.944 .34537 Mdot
.944 .34538 Mdot
.944 .34548 Mdot
.944 .34549 Mdot
.944 .34553 Mdot
.944 .34562 Mdot
.944 .3457 Mdot
.944 .34579 Mdot
.944 .34589 Mdot
.944 .3459 Mdot
.944 .34594 Mdot
.944 .34594 Mdot
.944 .34598 Mdot
.944 .34612 Mdot
.944 .34617 Mdot
.944 .34628 Mdot
.944 .34644 Mdot
.944 .34646 Mdot
.944 .3466 Mdot
.944 .34666 Mdot
.944 .34669 Mdot
.944 .34673 Mdot
.944 .34673 Mdot
.944 .34681 Mdot
.944 .34691 Mdot
.944 .34702 Mdot
.944 .34728 Mdot
.944 .34764 Mdot
.944 .34773 Mdot
.944 .34774 Mdot
.944 .34774 Mdot
.944 .34788 Mdot
.944 .34794 Mdot
.944 .34796 Mdot
.944 .34832 Mdot
.944 .34835 Mdot
.944 .34838 Mdot
.944 .34839 Mdot
.944 .34844 Mdot
.944 .34846 Mdot
.944 .34847 Mdot
.944 .3486 Mdot
.944 .34867 Mdot
.944 .34869 Mdot
.944 .34875 Mdot
.944 .34894 Mdot
.944 .34929 Mdot
.944 .34943 Mdot
.944 .34977 Mdot
.944 .34994 Mdot
.944 .34995 Mdot
.944 .35007 Mdot
.944 .35012 Mdot
.944 .35013 Mdot
.944 .35013 Mdot
.944 .35034 Mdot
.944 .35039 Mdot
.944 .35049 Mdot
.944 .35051 Mdot
.944 .35052 Mdot
.944 .35057 Mdot
.944 .35064 Mdot
.944 .35076 Mdot
.944 .351 Mdot
.944 .35109 Mdot
.944 .35112 Mdot
.944 .35114 Mdot
.944 .35115 Mdot
.944 .35139 Mdot
.944 .35142 Mdot
.944 .35142 Mdot
.944 .35148 Mdot
.944 .35151 Mdot
.944 .35172 Mdot
.944 .35178 Mdot
.944 .35191 Mdot
.944 .35198 Mdot
.944 .35211 Mdot
.944 .35212 Mdot
.944 .35214 Mdot
.944 .35215 Mdot
.944 .35218 Mdot
.944 .35234 Mdot
.944 .35236 Mdot
.944 .35243 Mdot
.944 .35244 Mdot
.944 .35245 Mdot
.944 .35245 Mdot
.944 .35245 Mdot
.944 .35254 Mdot
.944 .35261 Mdot
.944 .3527 Mdot
.944 .35276 Mdot
.944 .35281 Mdot
.944 .35284 Mdot
.944 .35293 Mdot
.944 .35294 Mdot
.944 .35296 Mdot
.944 .353 Mdot
.944 .35305 Mdot
.944 .35315 Mdot
.944 .35318 Mdot
.944 .35319 Mdot
.944 .3532 Mdot
.944 .35327 Mdot
.944 .35341 Mdot
.944 .35343 Mdot
.944 .35345 Mdot
.944 .35347 Mdot
.944 .35347 Mdot
.944 .35347 Mdot
.944 .35347 Mdot
.944 .35347 Mdot
.944 .3535 Mdot
.944 .35352 Mdot
.944 .35355 Mdot
.944 .35362 Mdot
.944 .35366 Mdot
.944 .35369 Mdot
.944 .3537 Mdot
.944 .35374 Mdot
.944 .35378 Mdot
.944 .3538 Mdot
.944 .35383 Mdot
.944 .35387 Mdot
.944 .35388 Mdot
.944 .35399 Mdot
.944 .3541 Mdot
.944 .35421 Mdot
.944 .35422 Mdot
.944 .35425 Mdot
.944 .35429 Mdot
.944 .35429 Mdot
.944 .35431 Mdot
.944 .35431 Mdot
.944 .35433 Mdot
.944 .35436 Mdot
.944 .35441 Mdot
.944 .35444 Mdot
.944 .35444 Mdot
.944 .35444 Mdot
.944 .35445 Mdot
.944 .35446 Mdot
.944 .35446 Mdot
.944 .35447 Mdot
.944 .41083 Mdot
.944 .46951 Mdot
.944 .49348 Mdot
.944 .49348 Mdot
.944 .49348 Mdot
.944 .49349 Mdot
.944 .49351 Mdot
.944 .49358 Mdot
.944 .49382 Mdot
.944 .49393 Mdot
.944 .49396 Mdot
.944 .49428 Mdot
.944 .49496 Mdot
.944 .49496 Mdot
.944 .49533 Mdot
.944 .49551 Mdot
.944 .49694 Mdot
.944 .49709 Mdot
.944 .49727 Mdot
.944 .49793 Mdot
.944 .49819 Mdot
.944 .49833 Mdot
.944 .49844 Mdot
.944 .49853 Mdot
.944 .49853 Mdot
.944 .49854 Mdot
.944 .50032 Mdot
.944 .50326 Mdot
.944 .53922 Mdot
.944 .53923 Mdot
.944 .53923 Mdot
.944 .53924 Mdot
.944 .53924 Mdot
.944 .53925 Mdot
.944 .53926 Mdot
.944 .53927 Mdot
.944 .53928 Mdot
.944 .53928 Mdot
.944 .53928 Mdot
.944 .53928 Mdot
.944 .53935 Mdot
.944 .53935 Mdot
.944 .53937 Mdot
.944 .53942 Mdot
.944 .5395 Mdot
.944 .53953 Mdot
.944 .53958 Mdot
.944 .5396 Mdot
.944 .53961 Mdot
.944 .53963 Mdot
.944 .53965 Mdot
.944 .53967 Mdot
.944 .53968 Mdot
.944 .53968 Mdot
.944 .53968 Mdot
.944 .53971 Mdot
.944 .53972 Mdot
.944 .53974 Mdot
.944 .53976 Mdot
.944 .53977 Mdot
.944 .53979 Mdot
.944 .5398 Mdot
.944 .53981 Mdot
.944 .53981 Mdot
.944 .53987 Mdot
.944 .53998 Mdot
.944 .54 Mdot
.944 .54 Mdot
.944 .54 Mdot
.944 .54003 Mdot
.944 .54004 Mdot
.944 .54011 Mdot
.944 .54012 Mdot
.944 .54013 Mdot
.944 .54018 Mdot
.944 .54041 Mdot
.944 .54045 Mdot
.944 .54047 Mdot
.944 .54049 Mdot
.944 .54055 Mdot
.944 .54057 Mdot
.944 .54058 Mdot
.944 .54059 Mdot
.944 .54063 Mdot
.944 .54069 Mdot
.944 .54071 Mdot
.944 .54072 Mdot
.944 .54073 Mdot
.944 .54073 Mdot
.944 .54079 Mdot
.944 .5408 Mdot
.944 .5408 Mdot
.944 .54081 Mdot
.944 .54082 Mdot
.944 .54088 Mdot
.944 .54093 Mdot
.944 .54099 Mdot
.944 .54101 Mdot
.944 .54106 Mdot
.944 .54106 Mdot
.944 .54109 Mdot
.944 .54109 Mdot
.944 .54112 Mdot
.944 .54114 Mdot
.944 .54117 Mdot
.944 .54121 Mdot
.944 .54122 Mdot
.944 .54125 Mdot
.944 .54129 Mdot
.944 .54133 Mdot
.944 .54145 Mdot
.944 .54146 Mdot
.944 .54153 Mdot
.944 .54157 Mdot
.944 .54161 Mdot
.944 .54163 Mdot
.944 .54166 Mdot
.944 .54166 Mdot
.944 .54173 Mdot
.944 .5418 Mdot
.944 .54189 Mdot
.944 .54192 Mdot
.944 .54198 Mdot
.944 .542 Mdot
.944 .5421 Mdot
.944 .54222 Mdot
.944 .5424 Mdot
.944 .54243 Mdot
.944 .54248 Mdot
.944 .54249 Mdot
.944 .54249 Mdot
.944 .54261 Mdot
.944 .54266 Mdot
.944 .54267 Mdot
.944 .54268 Mdot
.944 .54275 Mdot
.944 .543 Mdot
.944 .54303 Mdot
.944 .54306 Mdot
.944 .54307 Mdot
.944 .54312 Mdot
.944 .54313 Mdot
.944 .54314 Mdot
.944 .54326 Mdot
.944 .54333 Mdot
.944 .54335 Mdot
.944 .54341 Mdot
.944 .54359 Mdot
.944 .5436 Mdot
.944 .54368 Mdot
.944 .54394 Mdot
.944 .54408 Mdot
.944 .54418 Mdot
.944 .54431 Mdot
.944 .54437 Mdot
.944 .54443 Mdot
.944 .54454 Mdot
.944 .54461 Mdot
.944 .54462 Mdot
.944 .54474 Mdot
.944 .5448 Mdot
.944 .54481 Mdot
.944 .54482 Mdot
.944 .54484 Mdot
.944 .54485 Mdot
.944 .54485 Mdot
.944 .54496 Mdot
.944 .54503 Mdot
.944 .5451 Mdot
.944 .5452 Mdot
.944 .54523 Mdot
.944 .54524 Mdot
.944 .54524 Mdot
.944 .54529 Mdot
.944 .54536 Mdot
.944 .54547 Mdot
.944 .5455 Mdot
.944 .54575 Mdot
.944 .54577 Mdot
.944 .54587 Mdot
.944 .54591 Mdot
.944 .54593 Mdot
.944 .54595 Mdot
.944 .54602 Mdot
.944 .54609 Mdot
.944 .54622 Mdot
.944 .54625 Mdot
.944 .54625 Mdot
.944 .54633 Mdot
.944 .54636 Mdot
.944 .54652 Mdot
.944 .54656 Mdot
.944 .54661 Mdot
.944 .54668 Mdot
.944 .54682 Mdot
.944 .54692 Mdot
.944 .54707 Mdot
.944 .54708 Mdot
.944 .54711 Mdot
.944 .54711 Mdot
.944 .54715 Mdot
.944 .54735 Mdot
.944 .54737 Mdot
.944 .54739 Mdot
.944 .54746 Mdot
.944 .54748 Mdot
.944 .54748 Mdot
.944 .54748 Mdot
.944 .54749 Mdot
.944 .5476 Mdot
.944 .54767 Mdot
.944 .54778 Mdot
.944 .54786 Mdot
.944 .5479 Mdot
.944 .54792 Mdot
.944 .54796 Mdot
.944 .54807 Mdot
.944 .54808 Mdot
.944 .54812 Mdot
.944 .54816 Mdot
.944 .54822 Mdot
.944 .5483 Mdot
.944 .54835 Mdot
.944 .54839 Mdot
.944 .5484 Mdot
.944 .54841 Mdot
.944 .5485 Mdot
.944 .54868 Mdot
.944 .54869 Mdot
.944 .54871 Mdot
.944 .54873 Mdot
.944 .54875 Mdot
.944 .54876 Mdot
.944 .54876 Mdot
.944 .54876 Mdot
.944 .54876 Mdot
.944 .54879 Mdot
.944 .54882 Mdot
.944 .54886 Mdot
.944 .54894 Mdot
.944 .549 Mdot
.944 .54904 Mdot
.944 .54905 Mdot
.944 .54911 Mdot
.944 .54915 Mdot
.944 .54918 Mdot
.944 .54921 Mdot
.944 .54921 Mdot
.944 .54927 Mdot
.944 .54928 Mdot
.944 .54942 Mdot
.944 .5495 Mdot
.944 .54957 Mdot
.944 .54966 Mdot
.944 .54971 Mdot
.944 .54972 Mdot
.944 .54976 Mdot
.944 .54982 Mdot
.944 .54982 Mdot
.944 .54983 Mdot
.944 .54984 Mdot
.944 .54987 Mdot
.944 .5499 Mdot
.944 .54997 Mdot
.944 .54997 Mdot
.944 .55 Mdot
.944 .55 Mdot
.944 .55001 Mdot
.944 .55002 Mdot
.944 .55003 Mdot
.944 .55004 Mdot
.944 .55004 Mdot
.944 .55168 Mdot
.944 .55286 Mdot
.944 .55524 Mdot
.944 .5554 Mdot
.944 .55581 Mdot
.944 .55633 Mdot
.944 .55668 Mdot
.944 .5568 Mdot
.944 .5568 Mdot
.944 .55681 Mdot
.944 .55683 Mdot
.944 .55746 Mdot
.944 .55809 Mdot
.944 .55882 Mdot
.944 .55975 Mdot
.944 .56046 Mdot
.944 .56159 Mdot
.944 .56227 Mdot
.944 .56241 Mdot
.944 .56349 Mdot
.944 .56422 Mdot
.944 .56451 Mdot
.944 .56474 Mdot
.944 .56518 Mdot
.944 .56523 Mdot
.944 .56527 Mdot
.944 .56588 Mdot
.944 .56621 Mdot
.944 .56624 Mdot
.944 .56819 Mdot
.944 .56896 Mdot
.944 .56952 Mdot
.944 .56958 Mdot
.944 .56958 Mdot
.944 .5696 Mdot
.944 .56964 Mdot
.944 .5697 Mdot
.944 .56981 Mdot
.944 .56985 Mdot
.944 .56986 Mdot
.944 .56994 Mdot
.944 .57008 Mdot
.944 .57008 Mdot
.944 .57018 Mdot
.944 .57037 Mdot
.944 .57039 Mdot
.944 .57041 Mdot
.944 .57048 Mdot
.944 .5705 Mdot
.944 .57052 Mdot
.944 .57053 Mdot
.944 .57054 Mdot
.944 .57054 Mdot
.944 .57054 Mdot
.946 .15566 Mdot
.946 .15573 Mdot
.946 .15587 Mdot
.946 .1559 Mdot
.946 .17828 Mdot
.946 .1783 Mdot
.946 .17833 Mdot
.946 .17834 Mdot
.946 .34053 Mdot
.946 .34069 Mdot
.946 .34101 Mdot
.946 .34107 Mdot
.946 .34973 Mdot
.946 .34973 Mdot
.946 .34977 Mdot
.946 .34978 Mdot
.946 .54033 Mdot
.946 .54033 Mdot
.946 .54033 Mdot
.946 .54034 Mdot
.946 .54551 Mdot
.946 .54551 Mdot
.946 .54555 Mdot
.946 .54557 Mdot
.948 .10748 Mdot
.948 .10749 Mdot
.948 .10749 Mdot
.948 .1075 Mdot
.948 .10753 Mdot
.948 .10757 Mdot
.948 .10759 Mdot
.948 .10767 Mdot
.948 .10773 Mdot
.948 .10773 Mdot
.948 .10774 Mdot
.948 .10778 Mdot
.948 .1078 Mdot
.948 .10782 Mdot
.948 .10784 Mdot
.948 .10786 Mdot
.948 .10791 Mdot
.948 .10796 Mdot
.948 .10797 Mdot
.948 .10805 Mdot
.948 .10807 Mdot
.948 .10808 Mdot
.948 .10811 Mdot
.948 .10819 Mdot
.948 .10821 Mdot
.948 .10821 Mdot
.948 .10824 Mdot
.948 .10824 Mdot
.948 .10825 Mdot
.948 .10828 Mdot
.948 .10866 Mdot
.948 .10867 Mdot
.948 .10878 Mdot
.948 .10879 Mdot
.948 .1089 Mdot
.948 .10946 Mdot
.948 .10954 Mdot
.948 .10982 Mdot
.948 .11079 Mdot
.948 .11125 Mdot
.948 .11142 Mdot
.948 .11147 Mdot
.948 .1116 Mdot
.948 .11183 Mdot
.948 .1123 Mdot
.948 .11325 Mdot
.948 .11389 Mdot
.948 .11393 Mdot
.948 .1143 Mdot
.948 .11475 Mdot
.948 .11518 Mdot
.948 .11555 Mdot
.948 .11557 Mdot
.948 .11634 Mdot
.948 .11643 Mdot
.948 .11718 Mdot
.948 .11735 Mdot
.948 .118 Mdot
.948 .1185 Mdot
.948 .11961 Mdot
.948 .11994 Mdot
.948 .12026 Mdot
.948 .12071 Mdot
.948 .12095 Mdot
.948 .12201 Mdot
.948 .12366 Mdot
.948 .12394 Mdot
.948 .12617 Mdot
.948 .12663 Mdot
.948 .12696 Mdot
.948 .12696 Mdot
.948 .12697 Mdot
.948 .12718 Mdot
.948 .1272 Mdot
.948 .12722 Mdot
.948 .12724 Mdot
.948 .12725 Mdot
.948 .12728 Mdot
.948 .12739 Mdot
.948 .1275 Mdot
.948 .12762 Mdot
.948 .12769 Mdot
.948 .12771 Mdot
.948 .12782 Mdot
.948 .12804 Mdot
.948 .12819 Mdot
.948 .12819 Mdot
.948 .12908 Mdot
.948 .12926 Mdot
.948 .12931 Mdot
.948 .12955 Mdot
.948 .12964 Mdot
.948 .13011 Mdot
.948 .13038 Mdot
.948 .13049 Mdot
.948 .13057 Mdot
.948 .13057 Mdot
.948 .1306 Mdot
.948 .13068 Mdot
.948 .1307 Mdot
.948 .13077 Mdot
.948 .13081 Mdot
.948 .13128 Mdot
.948 .1314 Mdot
.948 .13145 Mdot
.948 .1315 Mdot
.948 .13161 Mdot
.948 .13163 Mdot
.948 .13166 Mdot
.948 .13172 Mdot
.948 .13172 Mdot
.948 .13178 Mdot
.948 .1318 Mdot
.948 .13186 Mdot
.948 .13202 Mdot
.948 .13213 Mdot
.948 .13235 Mdot
.948 .13275 Mdot
.948 .13312 Mdot
.948 .13313 Mdot
.948 .13321 Mdot
.948 .1337 Mdot
.948 .13411 Mdot
.948 .13411 Mdot
.948 .13434 Mdot
.948 .1344 Mdot
.948 .1347 Mdot
.948 .13497 Mdot
.948 .13509 Mdot
.948 .13521 Mdot
.948 .13522 Mdot
.948 .13524 Mdot
.948 .13526 Mdot
.948 .13536 Mdot
.948 .1355 Mdot
.948 .13554 Mdot
.948 .13579 Mdot
.948 .13598 Mdot
.948 .136 Mdot
.948 .13601 Mdot
.948 .13613 Mdot
.948 .13613 Mdot
.948 .13621 Mdot
.948 .13625 Mdot
.948 .13632 Mdot
.948 .13641 Mdot
.948 .13655 Mdot
.948 .13662 Mdot
.948 .13665 Mdot
.948 .1367 Mdot
.948 .13672 Mdot
.948 .13675 Mdot
.948 .13687 Mdot
.948 .13694 Mdot
.948 .13699 Mdot
.948 .13706 Mdot
.948 .1371 Mdot
.948 .1372 Mdot
.948 .13732 Mdot
.948 .13737 Mdot
.948 .13746 Mdot
.948 .13751 Mdot
.948 .13751 Mdot
.948 .1376 Mdot
.948 .13763 Mdot
.948 .13765 Mdot
.948 .13774 Mdot
.948 .13806 Mdot
.948 .13851 Mdot
.948 .13864 Mdot
.948 .13868 Mdot
.948 .13899 Mdot
.948 .13901 Mdot
.948 .13937 Mdot
.948 .13942 Mdot
.948 .13978 Mdot
.948 .14028 Mdot
.948 .14051 Mdot
.948 .14051 Mdot
.948 .14075 Mdot
.948 .14097 Mdot
.948 .14136 Mdot
.948 .1415 Mdot
.948 .14164 Mdot
.948 .14169 Mdot
.948 .14196 Mdot
.948 .14196 Mdot
.948 .14215 Mdot
.948 .14247 Mdot
.948 .1425 Mdot
.948 .14282 Mdot
.948 .14287 Mdot
.948 .14292 Mdot
.948 .14309 Mdot
.948 .14347 Mdot
.948 .14349 Mdot
.948 .14369 Mdot
.948 .14394 Mdot
.948 .14442 Mdot
.948 .14571 Mdot
.948 .14579 Mdot
.948 .14617 Mdot
.948 .1464 Mdot
.948 .14741 Mdot
.948 .1477 Mdot
.948 .14808 Mdot
.948 .14841 Mdot
.948 .14873 Mdot
.948 .14876 Mdot
.948 .14892 Mdot
.948 .14927 Mdot
.948 .14936 Mdot
.948 .14938 Mdot
.948 .14946 Mdot
.948 .14975 Mdot
.948 .1502 Mdot
.948 .15026 Mdot
.948 .15028 Mdot
.948 .15082 Mdot
.948 .15086 Mdot
.948 .15107 Mdot
.948 .1515 Mdot
.948 .15192 Mdot
.948 .15209 Mdot
.948 .15215 Mdot
.948 .15221 Mdot
.948 .15224 Mdot
.948 .15234 Mdot
.948 .1524 Mdot
.948 .15259 Mdot
.948 .15311 Mdot
.948 .15363 Mdot
.948 .1542 Mdot
.948 .15429 Mdot
.948 .15452 Mdot
.948 .15478 Mdot
.948 .1548 Mdot
.948 .15514 Mdot
.948 .15546 Mdot
.948 .1558 Mdot
.948 .15581 Mdot
.948 .15582 Mdot
.948 .1568 Mdot
.948 .15699 Mdot
.948 .15782 Mdot
.948 .15816 Mdot
.948 .15821 Mdot
.948 .15838 Mdot
.948 .15854 Mdot
.948 .15875 Mdot
.948 .15899 Mdot
.948 .159 Mdot
.948 .15901 Mdot
.948 .15902 Mdot
.948 .15906 Mdot
.948 .15915 Mdot
.948 .15922 Mdot
.948 .15972 Mdot
.948 .15976 Mdot
.948 .15991 Mdot
.948 .16009 Mdot
.948 .16012 Mdot
.948 .16013 Mdot
.948 .16015 Mdot
.948 .1602 Mdot
.948 .16027 Mdot
.948 .16066 Mdot
.948 .16188 Mdot
.948 .16195 Mdot
.948 .16202 Mdot
.948 .16213 Mdot
.948 .16219 Mdot
.948 .16238 Mdot
.948 .16281 Mdot
.948 .16285 Mdot
.948 .16296 Mdot
.948 .16376 Mdot
.948 .1638 Mdot
.948 .16398 Mdot
.948 .16407 Mdot
.948 .1642 Mdot
.948 .16501 Mdot
.948 .16531 Mdot
.948 .16536 Mdot
.948 .16541 Mdot
.948 .16543 Mdot
.948 .16595 Mdot
.948 .16687 Mdot
.948 .16789 Mdot
.948 .16877 Mdot
.948 .16881 Mdot
.948 .16918 Mdot
.948 .16994 Mdot
.948 .16998 Mdot
.948 .17003 Mdot
.948 .17008 Mdot
.948 .17032 Mdot
.948 .17046 Mdot
.948 .17061 Mdot
.948 .17071 Mdot
.948 .17085 Mdot
.948 .17107 Mdot
.948 .17201 Mdot
.948 .17205 Mdot
.948 .17225 Mdot
.948 .17252 Mdot
.948 .17273 Mdot
.948 .17277 Mdot
.948 .17282 Mdot
.948 .17287 Mdot
.948 .17312 Mdot
.948 .17318 Mdot
.948 .17327 Mdot
.948 .17328 Mdot
.948 .17329 Mdot
.948 .17332 Mdot
.948 .17335 Mdot
.948 .17336 Mdot
.948 .17338 Mdot
.948 .17346 Mdot
.948 .1735 Mdot
.948 .1736 Mdot
.948 .17429 Mdot
.948 .17622 Mdot
.948 .17853 Mdot
.948 .18371 Mdot
.948 .18514 Mdot
.948 .18532 Mdot
.948 .18684 Mdot
.948 .18719 Mdot
.948 .18901 Mdot
.948 .19016 Mdot
.948 .19274 Mdot
.948 .19456 Mdot
.948 .19535 Mdot
.948 .19671 Mdot
.948 .19709 Mdot
.948 .20354 Mdot
.948 .20494 Mdot
.948 .20785 Mdot
.948 .21631 Mdot
.948 .21864 Mdot
.948 .2191 Mdot
.948 .22035 Mdot
.948 .22036 Mdot
.948 .22038 Mdot
.948 .22147 Mdot
.948 .22157 Mdot
.948 .22171 Mdot
.948 .22178 Mdot
.948 .22183 Mdot
.948 .22201 Mdot
.948 .22258 Mdot
.948 .22311 Mdot
.948 .22373 Mdot
.948 .22413 Mdot
.948 .22422 Mdot
.948 .22481 Mdot
.948 .22595 Mdot
.948 .22669 Mdot
.948 .22672 Mdot
.948 .23132 Mdot
.948 .23225 Mdot
.948 .23251 Mdot
.948 .23372 Mdot
.948 .23422 Mdot
.948 .23664 Mdot
.948 .23804 Mdot
.948 .23861 Mdot
.948 .23898 Mdot
.948 .23902 Mdot
.948 .23917 Mdot
.948 .23955 Mdot
.948 .23969 Mdot
.948 .24003 Mdot
.948 .24023 Mdot
.948 .24265 Mdot
.948 .24331 Mdot
.948 .24353 Mdot
.948 .2438 Mdot
.948 .24434 Mdot
.948 .24447 Mdot
.948 .2446 Mdot
.948 .24493 Mdot
.948 .24494 Mdot
.948 .24523 Mdot
.948 .24534 Mdot
.948 .24562 Mdot
.948 .24645 Mdot
.948 .24645 Mdot
.948 .24701 Mdot
.948 .24816 Mdot
.948 .25022 Mdot
.948 .25207 Mdot
.948 .25217 Mdot
.948 .25255 Mdot
.948 .25292 Mdot
.948 .25368 Mdot
.948 .25503 Mdot
.948 .25709 Mdot
.948 .25713 Mdot
.948 .25829 Mdot
.948 .2586 Mdot
.948 .26008 Mdot
.948 .26146 Mdot
.948 .26206 Mdot
.948 .26266 Mdot
.948 .26269 Mdot
.948 .26281 Mdot
.948 .26292 Mdot
.948 .26337 Mdot
.948 .26406 Mdot
.948 .2643 Mdot
.948 .26555 Mdot
.948 .26649 Mdot
.948 .26654 Mdot
.948 .2666 Mdot
.948 .26722 Mdot
.948 .26723 Mdot
.948 .26763 Mdot
.948 .26781 Mdot
.948 .26816 Mdot
.948 .26859 Mdot
.948 .26895 Mdot
.948 .26928 Mdot
.948 .26962 Mdot
.948 .26975 Mdot
.948 .26999 Mdot
.948 .2701 Mdot
.948 .27025 Mdot
.948 .27082 Mdot
.948 .2712 Mdot
.948 .27143 Mdot
.948 .27178 Mdot
.948 .27197 Mdot
.948 .27246 Mdot
.948 .27302 Mdot
.948 .27327 Mdot
.948 .27372 Mdot
.948 .27395 Mdot
.948 .27395 Mdot
.948 .27439 Mdot
.948 .27451 Mdot
.948 .27463 Mdot
.948 .27507 Mdot
.948 .27617 Mdot
.948 .27661 Mdot
.948 .27876 Mdot
.948 .27936 Mdot
.948 .27956 Mdot
.948 .28103 Mdot
.948 .28112 Mdot
.948 .28222 Mdot
.948 .2828 Mdot
.948 .28301 Mdot
.948 .28469 Mdot
.948 .28698 Mdot
.948 .28804 Mdot
.948 .28806 Mdot
.948 .28913 Mdot
.948 .29014 Mdot
.948 .2919 Mdot
.948 .29252 Mdot
.948 .29315 Mdot
.948 .29334 Mdot
.948 .29453 Mdot
.948 .29454 Mdot
.948 .29539 Mdot
.948 .29677 Mdot
.948 .29692 Mdot
.948 .2983 Mdot
.948 .2985 Mdot
.948 .29872 Mdot
.948 .29945 Mdot
.948 .29975 Mdot
.948 .30104 Mdot
.948 .30112 Mdot
.948 .30198 Mdot
.948 .30302 Mdot
.948 .30387 Mdot
.948 .30458 Mdot
.948 .30498 Mdot
.948 .31016 Mdot
.948 .31046 Mdot
.948 .31193 Mdot
.948 .31282 Mdot
.948 .31658 Mdot
.948 .31764 Mdot
.948 .31899 Mdot
.948 .32018 Mdot
.948 .32129 Mdot
.948 .3214 Mdot
.948 .32195 Mdot
.948 .32311 Mdot
.948 .32343 Mdot
.948 .32349 Mdot
.948 .32377 Mdot
.948 .32446 Mdot
.948 .32447 Mdot
.948 .32448 Mdot
.948 .32456 Mdot
.948 .32457 Mdot
.948 .32473 Mdot
.948 .32474 Mdot
.948 .32474 Mdot
.948 .32493 Mdot
.948 .32551 Mdot
.948 .32558 Mdot
.948 .32576 Mdot
.948 .32618 Mdot
.948 .32639 Mdot
.948 .32644 Mdot
.948 .32672 Mdot
.948 .32739 Mdot
.948 .32771 Mdot
.948 .32806 Mdot
.948 .32814 Mdot
.948 .32827 Mdot
.948 .32886 Mdot
.948 .32887 Mdot
.948 .32893 Mdot
.948 .32898 Mdot
.948 .32947 Mdot
.948 .32978 Mdot
.948 .33022 Mdot
.948 .33148 Mdot
.948 .33183 Mdot
.948 .33196 Mdot
.948 .33202 Mdot
.948 .33216 Mdot
.948 .33231 Mdot
.948 .33241 Mdot
.948 .33269 Mdot
.948 .33286 Mdot
.948 .33342 Mdot
.948 .33485 Mdot
.948 .33494 Mdot
.948 .33506 Mdot
.948 .33578 Mdot
.948 .33623 Mdot
.948 .33658 Mdot
.948 .33743 Mdot
.948 .33771 Mdot
.948 .33794 Mdot
.948 .3385 Mdot
.948 .33906 Mdot
.948 .33915 Mdot
.948 .3392 Mdot
.948 .33955 Mdot
.948 .3397 Mdot
.948 .34001 Mdot
.948 .34075 Mdot
.948 .34153 Mdot
.948 .34155 Mdot
.948 .34159 Mdot
.948 .34164 Mdot
.948 .34189 Mdot
.948 .34287 Mdot
.948 .3437 Mdot
.948 .34383 Mdot
.948 .34407 Mdot
.948 .34409 Mdot
.948 .34571 Mdot
.948 .34635 Mdot
.948 .34643 Mdot
.948 .34674 Mdot
.948 .34702 Mdot
.948 .34738 Mdot
.948 .34749 Mdot
.948 .34754 Mdot
.948 .34759 Mdot
.948 .34779 Mdot
.948 .34781 Mdot
.948 .34783 Mdot
.948 .34785 Mdot
.948 .34792 Mdot
.948 .34807 Mdot
.948 .34817 Mdot
.948 .34896 Mdot
.948 .34897 Mdot
.948 .34904 Mdot
.948 .34926 Mdot
.948 .34952 Mdot
.948 .34957 Mdot
.948 .34959 Mdot
.948 .34962 Mdot
.948 .34969 Mdot
.948 .3498 Mdot
.948 .35012 Mdot
.948 .35023 Mdot
.948 .35034 Mdot
.948 .35079 Mdot
.948 .35109 Mdot
.948 .35151 Mdot
.948 .35174 Mdot
.948 .35188 Mdot
.948 .3519 Mdot
.948 .35198 Mdot
.948 .35206 Mdot
.948 .35218 Mdot
.948 .35225 Mdot
.948 .35234 Mdot
.948 .35245 Mdot
.948 .35245 Mdot
.948 .35251 Mdot
.948 .3529 Mdot
.948 .35293 Mdot
.948 .35304 Mdot
.948 .35334 Mdot
.948 .35378 Mdot
.948 .35381 Mdot
.948 .35395 Mdot
.948 .35402 Mdot
.948 .35402 Mdot
.948 .35413 Mdot
.948 .35427 Mdot
.948 .35437 Mdot
.948 .35447 Mdot
.948 .35453 Mdot
.948 .35456 Mdot
.948 .3546 Mdot
.948 .35461 Mdot
.948 .35462 Mdot
.948 .35463 Mdot
.948 .35465 Mdot
.948 .35466 Mdot
.948 .35466 Mdot
.948 .35469 Mdot
.948 .3547 Mdot
.948 .35471 Mdot
.948 .35475 Mdot
.948 .35487 Mdot
.948 .35488 Mdot
.948 .3549 Mdot
.948 .3549 Mdot
.948 .35492 Mdot
.948 .35493 Mdot
.948 .35493 Mdot
.948 .35495 Mdot
.948 .35505 Mdot
.948 .35518 Mdot
.948 .3552 Mdot
.948 .35527 Mdot
.948 .35528 Mdot
.948 .35557 Mdot
.948 .35557 Mdot
.948 .35561 Mdot
.948 .35567 Mdot
.948 .3557 Mdot
.948 .35571 Mdot
.948 .35573 Mdot
.948 .35576 Mdot
.948 .35579 Mdot
.948 .35582 Mdot
.948 .35583 Mdot
.948 .35584 Mdot
.948 .35585 Mdot
.948 .35585 Mdot
.948 .35591 Mdot
.948 .35591 Mdot
.948 .35591 Mdot
.948 .35601 Mdot
.948 .35808 Mdot
.948 .35944 Mdot
.948 .35978 Mdot
.948 .36185 Mdot
.948 .36603 Mdot
.948 .36886 Mdot
.948 .36897 Mdot
.948 .37226 Mdot
.948 .37621 Mdot
.948 .38365 Mdot
.948 .3867 Mdot
.948 .38815 Mdot
.948 .39235 Mdot
.948 .39352 Mdot
.948 .39561 Mdot
.948 .3991 Mdot
.948 .39914 Mdot
.948 .3999 Mdot
.948 .4015 Mdot
.948 .4081 Mdot
.948 .40908 Mdot
.948 .41326 Mdot
.948 .42021 Mdot
.948 .42306 Mdot
.948 .42327 Mdot
.948 .42498 Mdot
.948 .42515 Mdot
.948 .4259 Mdot
.948 .42786 Mdot
.948 .42856 Mdot
.948 .43032 Mdot
.948 .4313 Mdot
.948 .44378 Mdot
.948 .44717 Mdot
.948 .44835 Mdot
.948 .44972 Mdot
.948 .45318 Mdot
.948 .45386 Mdot
.948 .45556 Mdot
.948 .45564 Mdot
.948 .45712 Mdot
.948 .4577 Mdot
.948 .45902 Mdot
.948 .45914 Mdot
.948 .46339 Mdot
.948 .4634 Mdot
.948 .46628 Mdot
.948 .47212 Mdot
.948 .48023 Mdot
.948 .48245 Mdot
.948 .48509 Mdot
.948 .49153 Mdot
.948 .49199 Mdot
.948 .49382 Mdot
.948 .49559 Mdot
.948 .49914 Mdot
.948 .5054 Mdot
.948 .51454 Mdot
.948 .51471 Mdot
.948 .51569 Mdot
.948 .51961 Mdot
.948 .52089 Mdot
.948 .52237 Mdot
.948 .52543 Mdot
.948 .52557 Mdot
.948 .52684 Mdot
.948 .53214 Mdot
.948 .53434 Mdot
.948 .53649 Mdot
.948 .53657 Mdot
.948 .537 Mdot
.948 .53738 Mdot
.948 .53852 Mdot
.948 .53895 Mdot
.948 .54128 Mdot
.948 .54144 Mdot
.948 .54146 Mdot
.948 .54147 Mdot
.948 .54148 Mdot
.948 .54149 Mdot
.948 .54149 Mdot
.948 .5415 Mdot
.948 .5415 Mdot
.948 .54151 Mdot
.948 .54153 Mdot
.948 .54154 Mdot
.948 .5416 Mdot
.948 .54161 Mdot
.948 .54162 Mdot
.948 .54163 Mdot
.948 .54174 Mdot
.948 .54178 Mdot
.948 .54179 Mdot
.948 .542 Mdot
.948 .54205 Mdot
.948 .54208 Mdot
.948 .5421 Mdot
.948 .54214 Mdot
.948 .54217 Mdot
.948 .54223 Mdot
.948 .54223 Mdot
.948 .54225 Mdot
.948 .54226 Mdot
.948 .54252 Mdot
.948 .54272 Mdot
.948 .54296 Mdot
.948 .54317 Mdot
.948 .54329 Mdot
.948 .54332 Mdot
.948 .54339 Mdot
.948 .54358 Mdot
.948 .54361 Mdot
.948 .54363 Mdot
.948 .54367 Mdot
.948 .54387 Mdot
.948 .5439 Mdot
.948 .5439 Mdot
.948 .54401 Mdot
.948 .54405 Mdot
.948 .54409 Mdot
.948 .54412 Mdot
.948 .54442 Mdot
.948 .54451 Mdot
.948 .54453 Mdot
.948 .54454 Mdot
.948 .54454 Mdot
.948 .54455 Mdot
.948 .5446 Mdot
.948 .54463 Mdot
.948 .54464 Mdot
.948 .54477 Mdot
.948 .54478 Mdot
.948 .5448 Mdot
.948 .54481 Mdot
.948 .54482 Mdot
.948 .54482 Mdot
.948 .54482 Mdot
.948 .54488 Mdot
.948 .54501 Mdot
.948 .54502 Mdot
.948 .54511 Mdot
.948 .54531 Mdot
.948 .54536 Mdot
.948 .5456 Mdot
.948 .54561 Mdot
.948 .54569 Mdot
.948 .54577 Mdot
.948 .54586 Mdot
.948 .54586 Mdot
.948 .54593 Mdot
.948 .54599 Mdot
.948 .54601 Mdot
.948 .54616 Mdot
.948 .54629 Mdot
.948 .54642 Mdot
.948 .54647 Mdot
.948 .54649 Mdot
.948 .54651 Mdot
.948 .54652 Mdot
.948 .54653 Mdot
.948 .54659 Mdot
.948 .5467 Mdot
.948 .54681 Mdot
.948 .54687 Mdot
.948 .54688 Mdot
.948 .54702 Mdot
.948 .54704 Mdot
.948 .54716 Mdot
.948 .54724 Mdot
.948 .54727 Mdot
.948 .54729 Mdot
.948 .54742 Mdot
.948 .54752 Mdot
.948 .54771 Mdot
.948 .54779 Mdot
.948 .54813 Mdot
.948 .54823 Mdot
.948 .54825 Mdot
.948 .54862 Mdot
.948 .54875 Mdot
.948 .54882 Mdot
.948 .54888 Mdot
.948 .54888 Mdot
.948 .54899 Mdot
.948 .54905 Mdot
.948 .54907 Mdot
.948 .54916 Mdot
.948 .54917 Mdot
.948 .54926 Mdot
.948 .54932 Mdot
.948 .54941 Mdot
.948 .54945 Mdot
.948 .54949 Mdot
.948 .54961 Mdot
.948 .54967 Mdot
.948 .54974 Mdot
.948 .54974 Mdot
.948 .54981 Mdot
.948 .55029 Mdot
.948 .5503 Mdot
.948 .55034 Mdot
.948 .55048 Mdot
.948 .55069 Mdot
.948 .55071 Mdot
.948 .55082 Mdot
.948 .55085 Mdot
.948 .5509 Mdot
.948 .55092 Mdot
.948 .55093 Mdot
.948 .55108 Mdot
.948 .55141 Mdot
.948 .55145 Mdot
.948 .55154 Mdot
.948 .55163 Mdot
.948 .55165 Mdot
.948 .55173 Mdot
.948 .55173 Mdot
.948 .55187 Mdot
.948 .55203 Mdot
.948 .55205 Mdot
.948 .55206 Mdot
.948 .55218 Mdot
.948 .55232 Mdot
.948 .55239 Mdot
.948 .55243 Mdot
.948 .55248 Mdot
.948 .5525 Mdot
.948 .55251 Mdot
.948 .55253 Mdot
.948 .55253 Mdot
.948 .55255 Mdot
.948 .55256 Mdot
.948 .55257 Mdot
.948 .55261 Mdot
.948 .55262 Mdot
.948 .55264 Mdot
.948 .55268 Mdot
.948 .55285 Mdot
.948 .55286 Mdot
.948 .55288 Mdot
.948 .55289 Mdot
.948 .55292 Mdot
.948 .55293 Mdot
.948 .55293 Mdot
.948 .55296 Mdot
.948 .55299 Mdot
.948 .55309 Mdot
.948 .55326 Mdot
.948 .55329 Mdot
.948 .55338 Mdot
.948 .55339 Mdot
.948 .55346 Mdot
.948 .55379 Mdot
.948 .55379 Mdot
.948 .55384 Mdot
.948 .55392 Mdot
.948 .55397 Mdot
.948 .55397 Mdot
.948 .554 Mdot
.948 .55405 Mdot
.948 .55408 Mdot
.948 .55413 Mdot
.948 .55414 Mdot
.948 .55414 Mdot
.948 .55415 Mdot
.948 .55416 Mdot
.948 .55417 Mdot
.948 .55425 Mdot
.948 .55425 Mdot
.948 .55425 Mdot
.948 .55438 Mdot
.948 .55455 Mdot
.948 .55545 Mdot
.948 .55557 Mdot
.948 .55627 Mdot
.948 .55675 Mdot
.948 .55686 Mdot
.948 .55707 Mdot
.948 .55723 Mdot
.948 .55739 Mdot
.948 .55794 Mdot
.948 .5582 Mdot
.948 .55854 Mdot
.948 .55863 Mdot
.948 .55905 Mdot
.948 .5591 Mdot
.948 .55955 Mdot
.948 .55956 Mdot
.948 .55979 Mdot
.948 .56005 Mdot
.948 .56034 Mdot
.948 .56059 Mdot
.948 .56062 Mdot
.948 .56106 Mdot
.948 .56176 Mdot
.948 .56214 Mdot
.948 .56234 Mdot
.948 .56244 Mdot
.948 .56249 Mdot
.948 .56264 Mdot
.948 .56306 Mdot
.948 .56407 Mdot
.948 .5644 Mdot
.948 .5645 Mdot
.948 .56526 Mdot
.948 .56542 Mdot
.948 .56544 Mdot
.948 .56561 Mdot
.948 .56562 Mdot
.948 .56631 Mdot
.948 .56648 Mdot
.948 .56666 Mdot
.948 .56681 Mdot
.948 .56702 Mdot
.948 .56728 Mdot
.948 .56736 Mdot
.948 .56747 Mdot
.948 .56768 Mdot
.948 .56832 Mdot
.948 .5687 Mdot
.948 .5692 Mdot
.948 .56993 Mdot
.948 .57005 Mdot
.948 .57014 Mdot
.948 .57072 Mdot
.948 .5712 Mdot
.948 .57144 Mdot
.948 .57145 Mdot
.948 .57161 Mdot
.948 .57174 Mdot
.948 .57203 Mdot
.948 .5722 Mdot
.948 .57245 Mdot
.948 .57249 Mdot
.948 .57278 Mdot
.948 .57278 Mdot
.948 .57285 Mdot
.948 .57286 Mdot
.948 .57288 Mdot
.95 .10767 Mdot
.95 .10767 Mdot
.95 .10768 Mdot
.95 .10774 Mdot
.95 .10775 Mdot
.95 .10777 Mdot
.95 .10783 Mdot
.95 .10784 Mdot
.95 .10787 Mdot
.95 .10789 Mdot
.95 .10791 Mdot
.95 .10793 Mdot
.95 .10799 Mdot
.95 .108 Mdot
.95 .10801 Mdot
.95 .10801 Mdot
.95 .10803 Mdot
.95 .10804 Mdot
.95 .10808 Mdot
.95 .10814 Mdot
.95 .10814 Mdot
.95 .10815 Mdot
.95 .10817 Mdot
.95 .10821 Mdot
.95 .10823 Mdot
.95 .10827 Mdot
.95 .10828 Mdot
.95 .10833 Mdot
.95 .10835 Mdot
.95 .10835 Mdot
.95 .10835 Mdot
.95 .10837 Mdot
.95 .10838 Mdot
.95 .10841 Mdot
.95 .10843 Mdot
.95 .10857 Mdot
.95 .1086 Mdot
.95 .10862 Mdot
.95 .10869 Mdot
.95 .10876 Mdot
.95 .10883 Mdot
.95 .10888 Mdot
.95 .10892 Mdot
.95 .10897 Mdot
.95 .10898 Mdot
.95 .109 Mdot
.95 .10901 Mdot
.95 .10903 Mdot
.95 .10904 Mdot
.95 .10905 Mdot
.95 .10908 Mdot
.95 .10926 Mdot
.95 .10941 Mdot
.95 .10963 Mdot
.95 .10963 Mdot
.95 .10978 Mdot
.95 .11015 Mdot
.95 .11016 Mdot
.95 .11049 Mdot
.95 .11146 Mdot
.95 .11151 Mdot
.95 .11188 Mdot
.95 .11221 Mdot
.95 .11303 Mdot
.95 .11304 Mdot
.95 .11354 Mdot
.95 .11367 Mdot
.95 .11482 Mdot
.95 .1159 Mdot
.95 .1166 Mdot
.95 .11723 Mdot
.95 .12064 Mdot
.95 .12107 Mdot
.95 .12127 Mdot
.95 .12145 Mdot
.95 .12202 Mdot
.95 .12202 Mdot
.95 .12202 Mdot
.95 .12202 Mdot
.95 .12202 Mdot
.95 .12202 Mdot
.95 .12202 Mdot
.95 .12202 Mdot
.95 .12202 Mdot
.95 .12203 Mdot
.95 .12203 Mdot
.95 .12203 Mdot
.95 .12204 Mdot
.95 .12206 Mdot
.95 .12208 Mdot
.95 .12218 Mdot
.95 .12236 Mdot
.95 .12237 Mdot
.95 .12256 Mdot
.95 .12269 Mdot
.95 .12278 Mdot
.95 .12305 Mdot
.95 .12313 Mdot
.95 .12316 Mdot
.95 .12319 Mdot
.95 .12334 Mdot
.95 .12354 Mdot
.95 .12386 Mdot
.95 .1243 Mdot
.95 .12576 Mdot
.95 .12587 Mdot
.95 .12596 Mdot
.95 .12625 Mdot
.95 .12743 Mdot
.95 .12761 Mdot
.95 .1281 Mdot
.95 .12886 Mdot
.95 .12887 Mdot
.95 .12908 Mdot
.95 .12964 Mdot
.95 .1297 Mdot
.95 .13008 Mdot
.95 .13134 Mdot
.95 .13146 Mdot
.95 .13155 Mdot
.95 .13181 Mdot
.95 .13184 Mdot
.95 .13187 Mdot
.95 .13188 Mdot
.95 .13189 Mdot
.95 .13194 Mdot
.95 .13196 Mdot
.95 .13197 Mdot
.95 .13198 Mdot
.95 .13203 Mdot
.95 .13207 Mdot
.95 .13208 Mdot
.95 .1322 Mdot
.95 .13225 Mdot
.95 .13227 Mdot
.95 .13243 Mdot
.95 .13244 Mdot
.95 .13292 Mdot
.95 .13293 Mdot
.95 .13313 Mdot
.95 .13348 Mdot
.95 .13349 Mdot
.95 .13357 Mdot
.95 .13365 Mdot
.95 .1339 Mdot
.95 .13423 Mdot
.95 .13424 Mdot
.95 .13481 Mdot
.95 .13483 Mdot
.95 .135 Mdot
.95 .13506 Mdot
.95 .13537 Mdot
.95 .13542 Mdot
.95 .13599 Mdot
.95 .13603 Mdot
.95 .13606 Mdot
.95 .13606 Mdot
.95 .13608 Mdot
.95 .13628 Mdot
.95 .13631 Mdot
.95 .13638 Mdot
.95 .13638 Mdot
.95 .13655 Mdot
.95 .13658 Mdot
.95 .13668 Mdot
.95 .13675 Mdot
.95 .13676 Mdot
.95 .1368 Mdot
.95 .13689 Mdot
.95 .13702 Mdot
.95 .13706 Mdot
.95 .1371 Mdot
.95 .13713 Mdot
.95 .13713 Mdot
.95 .13718 Mdot
.95 .13722 Mdot
.95 .13737 Mdot
.95 .13743 Mdot
.95 .13754 Mdot
.95 .13755 Mdot
.95 .13757 Mdot
.95 .13764 Mdot
.95 .13777 Mdot
.95 .13786 Mdot
.95 .13798 Mdot
.95 .13802 Mdot
.95 .13815 Mdot
.95 .13817 Mdot
.95 .13823 Mdot
.95 .13823 Mdot
.95 .13824 Mdot
.95 .13829 Mdot
.95 .13833 Mdot
.95 .13833 Mdot
.95 .13843 Mdot
.95 .13848 Mdot
.95 .13849 Mdot
.95 .13894 Mdot
.95 .13906 Mdot
.95 .13907 Mdot
.95 .13913 Mdot
.95 .13934 Mdot
.95 .13959 Mdot
.95 .13968 Mdot
.95 .1398 Mdot
.95 .13992 Mdot
.95 .13999 Mdot
.95 .14007 Mdot
.95 .14013 Mdot
.95 .14015 Mdot
.95 .14018 Mdot
.95 .1403 Mdot
.95 .14032 Mdot
.95 .14037 Mdot
.95 .14038 Mdot
.95 .14043 Mdot
.95 .14049 Mdot
.95 .14053 Mdot
.95 .14055 Mdot
.95 .14064 Mdot
.95 .14126 Mdot
.95 .14153 Mdot
.95 .14178 Mdot
.95 .14231 Mdot
.95 .14254 Mdot
.95 .14254 Mdot
.95 .14265 Mdot
.95 .14307 Mdot
.95 .14353 Mdot
.95 .14391 Mdot
.95 .144 Mdot
.95 .14409 Mdot
.95 .14414 Mdot
.95 .14436 Mdot
.95 .14439 Mdot
.95 .14444 Mdot
.95 .14558 Mdot
.95 .1456 Mdot
.95 .14592 Mdot
.95 .14599 Mdot
.95 .14617 Mdot
.95 .14654 Mdot
.95 .14687 Mdot
.95 .14696 Mdot
.95 .14745 Mdot
.95 .14749 Mdot
.95 .14837 Mdot
.95 .14895 Mdot
.95 .14899 Mdot
.95 .14916 Mdot
.95 .14932 Mdot
.95 .14967 Mdot
.95 .15058 Mdot
.95 .15066 Mdot
.95 .15076 Mdot
.95 .15125 Mdot
.95 .15126 Mdot
.95 .15145 Mdot
.95 .15156 Mdot
.95 .15166 Mdot
.95 .15173 Mdot
.95 .15201 Mdot
.95 .15216 Mdot
.95 .15228 Mdot
.95 .15235 Mdot
.95 .15236 Mdot
.95 .15244 Mdot
.95 .15256 Mdot
.95 .15271 Mdot
.95 .15274 Mdot
.95 .15309 Mdot
.95 .1531 Mdot
.95 .15314 Mdot
.95 .15357 Mdot
.95 .15364 Mdot
.95 .15421 Mdot
.95 .15467 Mdot
.95 .15478 Mdot
.95 .15524 Mdot
.95 .15527 Mdot
.95 .15598 Mdot
.95 .15634 Mdot
.95 .15639 Mdot
.95 .15674 Mdot
.95 .15721 Mdot
.95 .15727 Mdot
.95 .15747 Mdot
.95 .15767 Mdot
.95 .15779 Mdot
.95 .1579 Mdot
.95 .15863 Mdot
.95 .15902 Mdot
.95 .15966 Mdot
.95 .15981 Mdot
.95 .1599 Mdot
.95 .15997 Mdot
.95 .16006 Mdot
.95 .16033 Mdot
.95 .16038 Mdot
.95 .16039 Mdot
.95 .16049 Mdot
.95 .16121 Mdot
.95 .16148 Mdot
.95 .16181 Mdot
.95 .16219 Mdot
.95 .16253 Mdot
.95 .16255 Mdot
.95 .16284 Mdot
.95 .16363 Mdot
.95 .16383 Mdot
.95 .1639 Mdot
.95 .16435 Mdot
.95 .16504 Mdot
.95 .16509 Mdot
.95 .16624 Mdot
.95 .16648 Mdot
.95 .16665 Mdot
.95 .16684 Mdot
.95 .16691 Mdot
.95 .1672 Mdot
.95 .1673 Mdot
.95 .16748 Mdot
.95 .16778 Mdot
.95 .16816 Mdot
.95 .16858 Mdot
.95 .16869 Mdot
.95 .16874 Mdot
.95 .16875 Mdot
.95 .16877 Mdot
.95 .16882 Mdot
.95 .16884 Mdot
.95 .16887 Mdot
.95 .16887 Mdot
.95 .16888 Mdot
.95 .16894 Mdot
.95 .16895 Mdot
.95 .16896 Mdot
.95 .17026 Mdot
.95 .17127 Mdot
.95 .17308 Mdot
.95 .18902 Mdot
.95 .19111 Mdot
.95 .19206 Mdot
.95 .19298 Mdot
.95 .19574 Mdot
.95 .19574 Mdot
.95 .19574 Mdot
.95 .19575 Mdot
.95 .19575 Mdot
.95 .19576 Mdot
.95 .19577 Mdot
.95 .19577 Mdot
.95 .19578 Mdot
.95 .1958 Mdot
.95 .19581 Mdot
.95 .19581 Mdot
.95 .19585 Mdot
.95 .19594 Mdot
.95 .19605 Mdot
.95 .1962 Mdot
.95 .19655 Mdot
.95 .19745 Mdot
.95 .19748 Mdot
.95 .19843 Mdot
.95 .1991 Mdot
.95 .19954 Mdot
.95 .20089 Mdot
.95 .20129 Mdot
.95 .20141 Mdot
.95 .20156 Mdot
.95 .20214 Mdot
.95 .20234 Mdot
.95 .20334 Mdot
.95 .20495 Mdot
.95 .20719 Mdot
.95 .2146 Mdot
.95 .2152 Mdot
.95 .21565 Mdot
.95 .21715 Mdot
.95 .2177 Mdot
.95 .21994 Mdot
.95 .22322 Mdot
.95 .22415 Mdot
.95 .22666 Mdot
.95 .2306 Mdot
.95 .23067 Mdot
.95 .23177 Mdot
.95 .23467 Mdot
.95 .23496 Mdot
.95 .23693 Mdot
.95 .24344 Mdot
.95 .24405 Mdot
.95 .24456 Mdot
.95 .24587 Mdot
.95 .24605 Mdot
.95 .24621 Mdot
.95 .24623 Mdot
.95 .24626 Mdot
.95 .24653 Mdot
.95 .24663 Mdot
.95 .24669 Mdot
.95 .24674 Mdot
.95 .24701 Mdot
.95 .2472 Mdot
.95 .24728 Mdot
.95 .24789 Mdot
.95 .24815 Mdot
.95 .24824 Mdot
.95 .24907 Mdot
.95 .24912 Mdot
.95 .25156 Mdot
.95 .25163 Mdot
.95 .25266 Mdot
.95 .25442 Mdot
.95 .25449 Mdot
.95 .25487 Mdot
.95 .25528 Mdot
.95 .25656 Mdot
.95 .25821 Mdot
.95 .25828 Mdot
.95 .26115 Mdot
.95 .26127 Mdot
.95 .2621 Mdot
.95 .26243 Mdot
.95 .26395 Mdot
.95 .26421 Mdot
.95 .26706 Mdot
.95 .26725 Mdot
.95 .26741 Mdot
.95 .26742 Mdot
.95 .26747 Mdot
.95 .26847 Mdot
.95 .26866 Mdot
.95 .26896 Mdot
.95 .26899 Mdot
.95 .26983 Mdot
.95 .26998 Mdot
.95 .27046 Mdot
.95 .27081 Mdot
.95 .27085 Mdot
.95 .27102 Mdot
.95 .27146 Mdot
.95 .27211 Mdot
.95 .2723 Mdot
.95 .27253 Mdot
.95 .27263 Mdot
.95 .27263 Mdot
.95 .2729 Mdot
.95 .27308 Mdot
.95 .27382 Mdot
.95 .27411 Mdot
.95 .27464 Mdot
.95 .2747 Mdot
.95 .27479 Mdot
.95 .27511 Mdot
.95 .27575 Mdot
.95 .27617 Mdot
.95 .27676 Mdot
.95 .27695 Mdot
.95 .27757 Mdot
.95 .27768 Mdot
.95 .27789 Mdot
.95 .27794 Mdot
.95 .27797 Mdot
.95 .27803 Mdot
.95 .27824 Mdot
.95 .27844 Mdot
.95 .27846 Mdot
.95 .27894 Mdot
.95 .27918 Mdot
.95 .27923 Mdot
.95 .27927 Mdot
.95 .28134 Mdot
.95 .28192 Mdot
.95 .28195 Mdot
.95 .28225 Mdot
.95 .28321 Mdot
.95 .28438 Mdot
.95 .28481 Mdot
.95 .28538 Mdot
.95 .28594 Mdot
.95 .28626 Mdot
.95 .28661 Mdot
.95 .28688 Mdot
.95 .28697 Mdot
.95 .28713 Mdot
.95 .28768 Mdot
.95 .28774 Mdot
.95 .28799 Mdot
.95 .28806 Mdot
.95 .28829 Mdot
.95 .28854 Mdot
.95 .2887 Mdot
.95 .28882 Mdot
.95 .28924 Mdot
.95 .29204 Mdot
.95 .29322 Mdot
.95 .29434 Mdot
.95 .29668 Mdot
.95 .29766 Mdot
.95 .29768 Mdot
.95 .29813 Mdot
.95 .29997 Mdot
.95 .30191 Mdot
.95 .30352 Mdot
.95 .30385 Mdot
.95 .30425 Mdot
.95 .30447 Mdot
.95 .30534 Mdot
.95 .30549 Mdot
.95 .30568 Mdot
.95 .31027 Mdot
.95 .31033 Mdot
.95 .31035 Mdot
.95 .31158 Mdot
.95 .31186 Mdot
.95 .31255 Mdot
.95 .31396 Mdot
.95 .3152 Mdot
.95 .31556 Mdot
.95 .31737 Mdot
.95 .31753 Mdot
.95 .32068 Mdot
.95 .3227 Mdot
.95 .32282 Mdot
.95 .32341 Mdot
.95 .32396 Mdot
.95 .32512 Mdot
.95 .32513 Mdot
.95 .32513 Mdot
.95 .32522 Mdot
.95 .32525 Mdot
.95 .3253 Mdot
.95 .32545 Mdot
.95 .3255 Mdot
.95 .32554 Mdot
.95 .32568 Mdot
.95 .32588 Mdot
.95 .32602 Mdot
.95 .32633 Mdot
.95 .32659 Mdot
.95 .32703 Mdot
.95 .3277 Mdot
.95 .32774 Mdot
.95 .32776 Mdot
.95 .32805 Mdot
.95 .32825 Mdot
.95 .32832 Mdot
.95 .3285 Mdot
.95 .32851 Mdot
.95 .32861 Mdot
.95 .32883 Mdot
.95 .32889 Mdot
.95 .32897 Mdot
.95 .32907 Mdot
.95 .32916 Mdot
.95 .32919 Mdot
.95 .32919 Mdot
.95 .3292 Mdot
.95 .32922 Mdot
.95 .32923 Mdot
.95 .32923 Mdot
.95 .32924 Mdot
.95 .32925 Mdot
.95 .32925 Mdot
.95 .32925 Mdot
.95 .32926 Mdot
.95 .32926 Mdot
.95 .32926 Mdot
.95 .32932 Mdot
.95 .32952 Mdot
.95 .33013 Mdot
.95 .33017 Mdot
.95 .33023 Mdot
.95 .33074 Mdot
.95 .33091 Mdot
.95 .33107 Mdot
.95 .33137 Mdot
.95 .33152 Mdot
.95 .33158 Mdot
.95 .33184 Mdot
.95 .33215 Mdot
.95 .33222 Mdot
.95 .33241 Mdot
.95 .33283 Mdot
.95 .33319 Mdot
.95 .33332 Mdot
.95 .33338 Mdot
.95 .33342 Mdot
.95 .33365 Mdot
.95 .33383 Mdot
.95 .33398 Mdot
.95 .3344 Mdot
.95 .33449 Mdot
.95 .33451 Mdot
.95 .33471 Mdot
.95 .33509 Mdot
.95 .33547 Mdot
.95 .3355 Mdot
.95 .33559 Mdot
.95 .33559 Mdot
.95 .33562 Mdot
.95 .33584 Mdot
.95 .33674 Mdot
.95 .33677 Mdot
.95 .33694 Mdot
.95 .33725 Mdot
.95 .33842 Mdot
.95 .33957 Mdot
.95 .33982 Mdot
.95 .33983 Mdot
.95 .33997 Mdot
.95 .3401 Mdot
.95 .34093 Mdot
.95 .34095 Mdot
.95 .34101 Mdot
.95 .34122 Mdot
.95 .34126 Mdot
.95 .34161 Mdot
.95 .34228 Mdot
.95 .34262 Mdot
.95 .34342 Mdot
.95 .34351 Mdot
.95 .34427 Mdot
.95 .34522 Mdot
.95 .34534 Mdot
.95 .34573 Mdot
.95 .34613 Mdot
.95 .34636 Mdot
.95 .34657 Mdot
.95 .34706 Mdot
.95 .34785 Mdot
.95 .34788 Mdot
.95 .34817 Mdot
.95 .34855 Mdot
.95 .34958 Mdot
.95 .34981 Mdot
.95 .34995 Mdot
.95 .35006 Mdot
.95 .3502 Mdot
.95 .35059 Mdot
.95 .35067 Mdot
.95 .35068 Mdot
.95 .35082 Mdot
.95 .35179 Mdot
.95 .35213 Mdot
.95 .35253 Mdot
.95 .35262 Mdot
.95 .35296 Mdot
.95 .35333 Mdot
.95 .35335 Mdot
.95 .35364 Mdot
.95 .35427 Mdot
.95 .35438 Mdot
.95 .35454 Mdot
.95 .35461 Mdot
.95 .35495 Mdot
.95 .35543 Mdot
.95 .35545 Mdot
.95 .35549 Mdot
.95 .35605 Mdot
.95 .35615 Mdot
.95 .35621 Mdot
.95 .35627 Mdot
.95 .35628 Mdot
.95 .3563 Mdot
.95 .35639 Mdot
.95 .35642 Mdot
.95 .35646 Mdot
.95 .35652 Mdot
.95 .35652 Mdot
.95 .35658 Mdot
.95 .35661 Mdot
.95 .35662 Mdot
.95 .35663 Mdot
.95 .35663 Mdot
.95 .35663 Mdot
.95 .35663 Mdot
.95 .35663 Mdot
.95 .35663 Mdot
.95 .35663 Mdot
.95 .35663 Mdot
.95 .35663 Mdot
.95 .35663 Mdot
.95 .35664 Mdot
.95 .35664 Mdot
.95 .35664 Mdot
.95 .35709 Mdot
.95 .36026 Mdot
.95 .3695 Mdot
.95 .38577 Mdot
.95 .38607 Mdot
.95 .39095 Mdot
.95 .40447 Mdot
.95 .40586 Mdot
.95 .41553 Mdot
.95 .4482 Mdot
.95 .4488 Mdot
.95 .45194 Mdot
.95 .45456 Mdot
.95 .46134 Mdot
.95 .46229 Mdot
.95 .46311 Mdot
.95 .46318 Mdot
.95 .46338 Mdot
.95 .46473 Mdot
.95 .46528 Mdot
.95 .46556 Mdot
.95 .46583 Mdot
.95 .46722 Mdot
.95 .46821 Mdot
.95 .46861 Mdot
.95 .47172 Mdot
.95 .47302 Mdot
.95 .4735 Mdot
.95 .47769 Mdot
.95 .47795 Mdot
.95 .49004 Mdot
.95 .49038 Mdot
.95 .49535 Mdot
.95 .49696 Mdot
.95 .50349 Mdot
.95 .50361 Mdot
.95 .50397 Mdot
.95 .50572 Mdot
.95 .50758 Mdot
.95 .51325 Mdot
.95 .52035 Mdot
.95 .52064 Mdot
.95 .53206 Mdot
.95 .5325 Mdot
.95 .53556 Mdot
.95 .53675 Mdot
.95 .54203 Mdot
.95 .54255 Mdot
.95 .54255 Mdot
.95 .54256 Mdot
.95 .54257 Mdot
.95 .54257 Mdot
.95 .54257 Mdot
.95 .54258 Mdot
.95 .54258 Mdot
.95 .5426 Mdot
.95 .5426 Mdot
.95 .5426 Mdot
.95 .54261 Mdot
.95 .54264 Mdot
.95 .54273 Mdot
.95 .54282 Mdot
.95 .54289 Mdot
.95 .54293 Mdot
.95 .54302 Mdot
.95 .54304 Mdot
.95 .54308 Mdot
.95 .54312 Mdot
.95 .54318 Mdot
.95 .54344 Mdot
.95 .54345 Mdot
.95 .54362 Mdot
.95 .54372 Mdot
.95 .54374 Mdot
.95 .54378 Mdot
.95 .54397 Mdot
.95 .54404 Mdot
.95 .54412 Mdot
.95 .54421 Mdot
.95 .54429 Mdot
.95 .54436 Mdot
.95 .54453 Mdot
.95 .54455 Mdot
.95 .54456 Mdot
.95 .54457 Mdot
.95 .54463 Mdot
.95 .54466 Mdot
.95 .54467 Mdot
.95 .5447 Mdot
.95 .54473 Mdot
.95 .54489 Mdot
.95 .54498 Mdot
.95 .54516 Mdot
.95 .54522 Mdot
.95 .54527 Mdot
.95 .54533 Mdot
.95 .54545 Mdot
.95 .54554 Mdot
.95 .54555 Mdot
.95 .54564 Mdot
.95 .54594 Mdot
.95 .54597 Mdot
.95 .54608 Mdot
.95 .54623 Mdot
.95 .54624 Mdot
.95 .54636 Mdot
.95 .54636 Mdot
.95 .54637 Mdot
.95 .54646 Mdot
.95 .54647 Mdot
.95 .5465 Mdot
.95 .54654 Mdot
.95 .54656 Mdot
.95 .54656 Mdot
.95 .54658 Mdot
.95 .54661 Mdot
.95 .54672 Mdot
.95 .54674 Mdot
.95 .54676 Mdot
.95 .54679 Mdot
.95 .54684 Mdot
.95 .54684 Mdot
.95 .547 Mdot
.95 .54702 Mdot
.95 .54726 Mdot
.95 .54744 Mdot
.95 .54745 Mdot
.95 .54761 Mdot
.95 .54784 Mdot
.95 .54785 Mdot
.95 .54799 Mdot
.95 .54801 Mdot
.95 .5481 Mdot
.95 .54821 Mdot
.95 .54825 Mdot
.95 .54827 Mdot
.95 .54836 Mdot
.95 .54869 Mdot
.95 .54877 Mdot
.95 .54878 Mdot
.95 .54881 Mdot
.95 .54883 Mdot
.95 .54894 Mdot
.95 .5492 Mdot
.95 .54929 Mdot
.95 .54952 Mdot
.95 .54986 Mdot
.95 .54992 Mdot
.95 .54995 Mdot
.95 .54999 Mdot
.95 .55007 Mdot
.95 .55025 Mdot
.95 .55043 Mdot
.95 .55048 Mdot
.95 .55053 Mdot
.95 .55075 Mdot
.95 .55088 Mdot
.95 .55096 Mdot
.95 .55108 Mdot
.95 .55119 Mdot
.95 .55121 Mdot
.95 .55139 Mdot
.95 .5514 Mdot
.95 .5515 Mdot
.95 .55152 Mdot
.95 .55158 Mdot
.95 .55158 Mdot
.95 .55177 Mdot
.95 .55177 Mdot
.95 .55188 Mdot
.95 .55197 Mdot
.95 .55199 Mdot
.95 .55202 Mdot
.95 .55202 Mdot
.95 .55214 Mdot
.95 .5522 Mdot
.95 .55221 Mdot
.95 .55237 Mdot
.95 .55237 Mdot
.95 .55243 Mdot
.95 .55243 Mdot
.95 .55245 Mdot
.95 .55249 Mdot
.95 .5525 Mdot
.95 .55251 Mdot
.95 .55253 Mdot
.95 .55253 Mdot
.95 .55253 Mdot
.95 .55254 Mdot
.95 .55256 Mdot
.95 .55256 Mdot
.95 .55256 Mdot
.95 .55257 Mdot
.95 .55258 Mdot
.95 .55267 Mdot
.95 .55271 Mdot
.95 .55275 Mdot
.95 .55319 Mdot
.95 .55333 Mdot
.95 .55335 Mdot
.95 .55355 Mdot
.95 .55362 Mdot
.95 .55363 Mdot
.95 .55391 Mdot
.95 .55409 Mdot
.95 .55416 Mdot
.95 .55461 Mdot
.95 .55473 Mdot
.95 .55476 Mdot
.95 .55481 Mdot
.95 .55539 Mdot
.95 .55558 Mdot
.95 .55571 Mdot
.95 .5558 Mdot
.95 .55586 Mdot
.95 .55588 Mdot
.95 .55589 Mdot
.95 .55592 Mdot
.95 .55604 Mdot
.95 .55608 Mdot
.95 .55613 Mdot
.95 .55622 Mdot
.95 .55622 Mdot
.95 .5563 Mdot
.95 .55635 Mdot
.95 .55636 Mdot
.95 .55636 Mdot
.95 .55637 Mdot
.95 .55637 Mdot
.95 .55637 Mdot
.95 .55637 Mdot
.95 .55637 Mdot
.95 .55637 Mdot
.95 .55637 Mdot
.95 .55637 Mdot
.95 .55637 Mdot
.95 .55637 Mdot
.95 .55637 Mdot
.95 .55637 Mdot
.95 .55663 Mdot
.95 .55671 Mdot
.95 .5568 Mdot
.95 .557 Mdot
.95 .55872 Mdot
.95 .55907 Mdot
.95 .55948 Mdot
.95 .56014 Mdot
.95 .56091 Mdot
.95 .561 Mdot
.95 .56136 Mdot
.95 .56136 Mdot
.95 .562 Mdot
.95 .56227 Mdot
.95 .56259 Mdot
.95 .56263 Mdot
.95 .56356 Mdot
.95 .56392 Mdot
.95 .56393 Mdot
.95 .56435 Mdot
.95 .56453 Mdot
.95 .56454 Mdot
.95 .56482 Mdot
.95 .56502 Mdot
.95 .56533 Mdot
.95 .56536 Mdot
.95 .56657 Mdot
.95 .56683 Mdot
.95 .56784 Mdot
.95 .56793 Mdot
.95 .56806 Mdot
.95 .5681 Mdot
.95 .5685 Mdot
.95 .56935 Mdot
.95 .56935 Mdot
.95 .56986 Mdot
.95 .57054 Mdot
.95 .57074 Mdot
.95 .57136 Mdot
.95 .57146 Mdot
.95 .57166 Mdot
.95 .5717 Mdot
.95 .57173 Mdot
.95 .57173 Mdot
.95 .57178 Mdot
.95 .57182 Mdot
.95 .57196 Mdot
.95 .57211 Mdot
.95 .57213 Mdot
.95 .57214 Mdot
.95 .5722 Mdot
.95 .57231 Mdot
.95 .57247 Mdot
.95 .5725 Mdot
.95 .57261 Mdot
.95 .57266 Mdot
.95 .57267 Mdot
.95 .5727 Mdot
.95 .57273 Mdot
.95 .5728 Mdot
.95 .57284 Mdot
.95 .57313 Mdot
.95 .57321 Mdot
.95 .57325 Mdot
.95 .57337 Mdot
.95 .57351 Mdot
.95 .57363 Mdot
.95 .57374 Mdot
.95 .57381 Mdot
.95 .5739 Mdot
.95 .5739 Mdot
.95 .57394 Mdot
.95 .57397 Mdot
.95 .57401 Mdot
.95 .57407 Mdot
.952 .10787 Mdot
.952 .10787 Mdot
.952 .10788 Mdot
.952 .1079 Mdot
.952 .10791 Mdot
.952 .10792 Mdot
.952 .10793 Mdot
.952 .10796 Mdot
.952 .10803 Mdot
.952 .10809 Mdot
.952 .10819 Mdot
.952 .1082 Mdot
.952 .10824 Mdot
.952 .10827 Mdot
.952 .10827 Mdot
.952 .10832 Mdot
.952 .10836 Mdot
.952 .10837 Mdot
.952 .10837 Mdot
.952 .1084 Mdot
.952 .10843 Mdot
.952 .10845 Mdot
.952 .10845 Mdot
.952 .10846 Mdot
.952 .10852 Mdot
.952 .10856 Mdot
.952 .10864 Mdot
.952 .10868 Mdot
.952 .10868 Mdot
.952 .10873 Mdot
.952 .10877 Mdot
.952 .10879 Mdot
.952 .10885 Mdot
.952 .10887 Mdot
.952 .10888 Mdot
.952 .1089 Mdot
.952 .10893 Mdot
.952 .10901 Mdot
.952 .10904 Mdot
.952 .10913 Mdot
.952 .10916 Mdot
.952 .1092 Mdot
.952 .10925 Mdot
.952 .10929 Mdot
.952 .1093 Mdot
.952 .10936 Mdot
.952 .10939 Mdot
.952 .10939 Mdot
.952 .10941 Mdot
.952 .10948 Mdot
.952 .10949 Mdot
.952 .1095 Mdot
.952 .10952 Mdot
.952 .10953 Mdot
.952 .10955 Mdot
.952 .10955 Mdot
.952 .10959 Mdot
.952 .10962 Mdot
.952 .10962 Mdot
.952 .10966 Mdot
.952 .10973 Mdot
.952 .10981 Mdot
.952 .10981 Mdot
.952 .10982 Mdot
.952 .10985 Mdot
.952 .10985 Mdot
.952 .10988 Mdot
.952 .10995 Mdot
.952 .10996 Mdot
.952 .11003 Mdot
.952 .11005 Mdot
.952 .11005 Mdot
.952 .11006 Mdot
.952 .11011 Mdot
.952 .11026 Mdot
.952 .11035 Mdot
.952 .11073 Mdot
.952 .11077 Mdot
.952 .11094 Mdot
.952 .1111 Mdot
.952 .11125 Mdot
.952 .11136 Mdot
.952 .11191 Mdot
.952 .11211 Mdot
.952 .11213 Mdot
.952 .11299 Mdot
.952 .11304 Mdot
.952 .11315 Mdot
.952 .11427 Mdot
.952 .11428 Mdot
.952 .11585 Mdot
.952 .11649 Mdot
.952 .11771 Mdot
.952 .11797 Mdot
.952 .11807 Mdot
.952 .11843 Mdot
.952 .11844 Mdot
.952 .11867 Mdot
.952 .1196 Mdot
.952 .1197 Mdot
.952 .11986 Mdot
.952 .11997 Mdot
.952 .12113 Mdot
.952 .1212 Mdot
.952 .12125 Mdot
.952 .1213 Mdot
.952 .12236 Mdot
.952 .12237 Mdot
.952 .12243 Mdot
.952 .12246 Mdot
.952 .12266 Mdot
.952 .12267 Mdot
.952 .12272 Mdot
.952 .12272 Mdot
.952 .12299 Mdot
.952 .12309 Mdot
.952 .12311 Mdot
.952 .1233 Mdot
.952 .12342 Mdot
.952 .12348 Mdot
.952 .12351 Mdot
.952 .12427 Mdot
.952 .12431 Mdot
.952 .12445 Mdot
.952 .12522 Mdot
.952 .12546 Mdot
.952 .12584 Mdot
.952 .1262 Mdot
.952 .12651 Mdot
.952 .12653 Mdot
.952 .12699 Mdot
.952 .12798 Mdot
.952 .12872 Mdot
.952 .12902 Mdot
.952 .12983 Mdot
.952 .12989 Mdot
.952 .12997 Mdot
.952 .12998 Mdot
.952 .13014 Mdot
.952 .13025 Mdot
.952 .1303 Mdot
.952 .13069 Mdot
.952 .13083 Mdot
.952 .13108 Mdot
.952 .13122 Mdot
.952 .13126 Mdot
.952 .13147 Mdot
.952 .13155 Mdot
.952 .13184 Mdot
.952 .13193 Mdot
.952 .13213 Mdot
.952 .13256 Mdot
.952 .13316 Mdot
.952 .13336 Mdot
.952 .13406 Mdot
.952 .13488 Mdot
.952 .13495 Mdot
.952 .13598 Mdot
.952 .13614 Mdot
.952 .13642 Mdot
.952 .13651 Mdot
.952 .13658 Mdot
.952 .13675 Mdot
.952 .13676 Mdot
.952 .13683 Mdot
.952 .13693 Mdot
.952 .13693 Mdot
.952 .13696 Mdot
.952 .13703 Mdot
.952 .13704 Mdot
.952 .13706 Mdot
.952 .13711 Mdot
.952 .13712 Mdot
.952 .13716 Mdot
.952 .13723 Mdot
.952 .13746 Mdot
.952 .13765 Mdot
.952 .13787 Mdot
.952 .13789 Mdot
.952 .13796 Mdot
.952 .13798 Mdot
.952 .13801 Mdot
.952 .13811 Mdot
.952 .13813 Mdot
.952 .13822 Mdot
.952 .13823 Mdot
.952 .13838 Mdot
.952 .13843 Mdot
.952 .13845 Mdot
.952 .13851 Mdot
.952 .13852 Mdot
.952 .13856 Mdot
.952 .13857 Mdot
.952 .13858 Mdot
.952 .13866 Mdot
.952 .13874 Mdot
.952 .13881 Mdot
.952 .13881 Mdot
.952 .13885 Mdot
.952 .13904 Mdot
.952 .13918 Mdot
.952 .13921 Mdot
.952 .13937 Mdot
.952 .13944 Mdot
.952 .13956 Mdot
.952 .13958 Mdot
.952 .13974 Mdot
.952 .13987 Mdot
.952 .13991 Mdot
.952 .13994 Mdot
.952 .13996 Mdot
.952 .14014 Mdot
.952 .1402 Mdot
.952 .14025 Mdot
.952 .1403 Mdot
.952 .14042 Mdot
.952 .14067 Mdot
.952 .14069 Mdot
.952 .14073 Mdot
.952 .14077 Mdot
.952 .1408 Mdot
.952 .1411 Mdot
.952 .1412 Mdot
.952 .14133 Mdot
.952 .14135 Mdot
.952 .14149 Mdot
.952 .14151 Mdot
.952 .14163 Mdot
.952 .14168 Mdot
.952 .14187 Mdot
.952 .14198 Mdot
.952 .14199 Mdot
.952 .14206 Mdot
.952 .14217 Mdot
.952 .14227 Mdot
.952 .14233 Mdot
.952 .14236 Mdot
.952 .14244 Mdot
.952 .14245 Mdot
.952 .14253 Mdot
.952 .14255 Mdot
.952 .14266 Mdot
.952 .14266 Mdot
.952 .14278 Mdot
.952 .14278 Mdot
.952 .14293 Mdot
.952 .14317 Mdot
.952 .14328 Mdot
.952 .1433 Mdot
.952 .14335 Mdot
.952 .14337 Mdot
.952 .14345 Mdot
.952 .14345 Mdot
.952 .14347 Mdot
.952 .14348 Mdot
.952 .14357 Mdot
.952 .14358 Mdot
.952 .14358 Mdot
.952 .14359 Mdot
.952 .1437 Mdot
.952 .14382 Mdot
.952 .14393 Mdot
.952 .14398 Mdot
.952 .14415 Mdot
.952 .14421 Mdot
.952 .14423 Mdot
.952 .14429 Mdot
.952 .1443 Mdot
.952 .14432 Mdot
.952 .14436 Mdot
.952 .14442 Mdot
.952 .14448 Mdot
.952 .14464 Mdot
.952 .14475 Mdot
.952 .14477 Mdot
.952 .14505 Mdot
.952 .14509 Mdot
.952 .14511 Mdot
.952 .14519 Mdot
.952 .14536 Mdot
.952 .14584 Mdot
.952 .14598 Mdot
.952 .14619 Mdot
.952 .14622 Mdot
.952 .14629 Mdot
.952 .14632 Mdot
.952 .14667 Mdot
.952 .14673 Mdot
.952 .14674 Mdot
.952 .14687 Mdot
.952 .14725 Mdot
.952 .14732 Mdot
.952 .14732 Mdot
.952 .1475 Mdot
.952 .14777 Mdot
.952 .14793 Mdot
.952 .14808 Mdot
.952 .14831 Mdot
.952 .14849 Mdot
.952 .14849 Mdot
.952 .14864 Mdot
.952 .14864 Mdot
.952 .14904 Mdot
.952 .14999 Mdot
.952 .15093 Mdot
.952 .15114 Mdot
.952 .15172 Mdot
.952 .15192 Mdot
.952 .15199 Mdot
.952 .15323 Mdot
.952 .15363 Mdot
.952 .15444 Mdot
.952 .15481 Mdot
.952 .15532 Mdot
.952 .15537 Mdot
.952 .15554 Mdot
.952 .15598 Mdot
.952 .15612 Mdot
.952 .1576 Mdot
.952 .15781 Mdot
.952 .15858 Mdot
.952 .15861 Mdot
.952 .1587 Mdot
.952 .15878 Mdot
.952 .15888 Mdot
.952 .15912 Mdot
.952 .15913 Mdot
.952 .15929 Mdot
.952 .16011 Mdot
.952 .16036 Mdot
.952 .16038 Mdot
.952 .16058 Mdot
.952 .16059 Mdot
.952 .16059 Mdot
.952 .16144 Mdot
.952 .1616 Mdot
.952 .16174 Mdot
.952 .16183 Mdot
.952 .16186 Mdot
.952 .16203 Mdot
.952 .16207 Mdot
.952 .16235 Mdot
.952 .16283 Mdot
.952 .16306 Mdot
.952 .1633 Mdot
.952 .16338 Mdot
.952 .16364 Mdot
.952 .16371 Mdot
.952 .16399 Mdot
.952 .16403 Mdot
.952 .16408 Mdot
.952 .16416 Mdot
.952 .16416 Mdot
.952 .1642 Mdot
.952 .16434 Mdot
.952 .16435 Mdot
.952 .16444 Mdot
.952 .16445 Mdot
.952 .16447 Mdot
.952 .16448 Mdot
.952 .16728 Mdot
.952 .17012 Mdot
.952 .17557 Mdot
.952 .17679 Mdot
.952 .17726 Mdot
.952 .17891 Mdot
.952 .17895 Mdot
.952 .18003 Mdot
.952 .18439 Mdot
.952 .18487 Mdot
.952 .18565 Mdot
.952 .18615 Mdot
.952 .19175 Mdot
.952 .19191 Mdot
.952 .1921 Mdot
.952 .19236 Mdot
.952 .19261 Mdot
.952 .19785 Mdot
.952 .19787 Mdot
.952 .19819 Mdot
.952 .19831 Mdot
.952 .19869 Mdot
.952 .19933 Mdot
.952 .19935 Mdot
.952 .19961 Mdot
.952 .19962 Mdot
.952 .20098 Mdot
.952 .20148 Mdot
.952 .20157 Mdot
.952 .20253 Mdot
.952 .20312 Mdot
.952 .20344 Mdot
.952 .20358 Mdot
.952 .2074 Mdot
.952 .20765 Mdot
.952 .20834 Mdot
.952 .21227 Mdot
.952 .21348 Mdot
.952 .21544 Mdot
.952 .21729 Mdot
.952 .21888 Mdot
.952 .21899 Mdot
.952 .22136 Mdot
.952 .22649 Mdot
.952 .23032 Mdot
.952 .23192 Mdot
.952 .23612 Mdot
.952 .23643 Mdot
.952 .23684 Mdot
.952 .23688 Mdot
.952 .23772 Mdot
.952 .23828 Mdot
.952 .23854 Mdot
.952 .24059 Mdot
.952 .24128 Mdot
.952 .24259 Mdot
.952 .2433 Mdot
.952 .24353 Mdot
.952 .2446 Mdot
.952 .24504 Mdot
.952 .24649 Mdot
.952 .24699 Mdot
.952 .248 Mdot
.952 .25023 Mdot
.952 .25331 Mdot
.952 .25431 Mdot
.952 .25787 Mdot
.952 .26201 Mdot
.952 .26239 Mdot
.952 .26753 Mdot
.952 .26833 Mdot
.952 .26973 Mdot
.952 .27017 Mdot
.952 .27052 Mdot
.952 .27133 Mdot
.952 .2714 Mdot
.952 .27171 Mdot
.952 .27222 Mdot
.952 .27222 Mdot
.952 .27235 Mdot
.952 .27271 Mdot
.952 .27274 Mdot
.952 .27285 Mdot
.952 .27311 Mdot
.952 .27316 Mdot
.952 .27336 Mdot
.952 .27367 Mdot
.952 .27479 Mdot
.952 .27571 Mdot
.952 .27677 Mdot
.952 .27687 Mdot
.952 .27721 Mdot
.952 .27733 Mdot
.952 .27745 Mdot
.952 .27793 Mdot
.952 .27802 Mdot
.952 .27849 Mdot
.952 .27852 Mdot
.952 .27924 Mdot
.952 .27948 Mdot
.952 .27957 Mdot
.952 .27986 Mdot
.952 .27992 Mdot
.952 .2801 Mdot
.952 .28015 Mdot
.952 .28018 Mdot
.952 .28057 Mdot
.952 .28096 Mdot
.952 .28129 Mdot
.952 .2813 Mdot
.952 .28145 Mdot
.952 .28163 Mdot
.952 .28303 Mdot
.952 .28317 Mdot
.952 .28394 Mdot
.952 .28425 Mdot
.952 .28484 Mdot
.952 .28493 Mdot
.952 .28564 Mdot
.952 .28628 Mdot
.952 .28644 Mdot
.952 .28657 Mdot
.952 .28668 Mdot
.952 .28749 Mdot
.952 .28778 Mdot
.952 .288 Mdot
.952 .28825 Mdot
.952 .28881 Mdot
.952 .28994 Mdot
.952 .29003 Mdot
.952 .29021 Mdot
.952 .29039 Mdot
.952 .29054 Mdot
.952 .29187 Mdot
.952 .29234 Mdot
.952 .29293 Mdot
.952 .293 Mdot
.952 .29362 Mdot
.952 .29374 Mdot
.952 .29427 Mdot
.952 .29447 Mdot
.952 .29533 Mdot
.952 .2958 Mdot
.952 .29586 Mdot
.952 .29619 Mdot
.952 .29664 Mdot
.952 .29711 Mdot
.952 .29734 Mdot
.952 .29748 Mdot
.952 .29785 Mdot
.952 .29788 Mdot
.952 .29823 Mdot
.952 .2983 Mdot
.952 .29879 Mdot
.952 .2988 Mdot
.952 .2993 Mdot
.952 .29933 Mdot
.952 .29996 Mdot
.952 .30096 Mdot
.952 .30145 Mdot
.952 .30155 Mdot
.952 .30173 Mdot
.952 .30182 Mdot
.952 .30215 Mdot
.952 .30219 Mdot
.952 .30225 Mdot
.952 .30228 Mdot
.952 .30268 Mdot
.952 .30271 Mdot
.952 .30273 Mdot
.952 .30274 Mdot
.952 .30321 Mdot
.952 .30371 Mdot
.952 .30417 Mdot
.952 .30438 Mdot
.952 .3051 Mdot
.952 .30536 Mdot
.952 .30544 Mdot
.952 .30567 Mdot
.952 .30572 Mdot
.952 .3058 Mdot
.952 .30595 Mdot
.952 .30623 Mdot
.952 .30648 Mdot
.952 .30713 Mdot
.952 .30755 Mdot
.952 .30766 Mdot
.952 .30876 Mdot
.952 .30895 Mdot
.952 .30901 Mdot
.952 .30932 Mdot
.952 .31003 Mdot
.952 .3119 Mdot
.952 .31246 Mdot
.952 .31328 Mdot
.952 .31336 Mdot
.952 .31367 Mdot
.952 .31375 Mdot
.952 .31508 Mdot
.952 .31533 Mdot
.952 .31535 Mdot
.952 .31586 Mdot
.952 .31725 Mdot
.952 .31753 Mdot
.952 .31754 Mdot
.952 .31818 Mdot
.952 .31918 Mdot
.952 .31973 Mdot
.952 .32028 Mdot
.952 .3211 Mdot
.952 .32174 Mdot
.952 .32175 Mdot
.952 .32225 Mdot
.952 .32225 Mdot
.952 .32366 Mdot
.952 .32577 Mdot
.952 .32577 Mdot
.952 .32579 Mdot
.952 .32579 Mdot
.952 .32587 Mdot
.952 .3261 Mdot
.952 .32613 Mdot
.952 .32619 Mdot
.952 .3263 Mdot
.952 .32636 Mdot
.952 .32679 Mdot
.952 .32682 Mdot
.952 .32694 Mdot
.952 .32694 Mdot
.952 .32695 Mdot
.952 .3271 Mdot
.952 .32711 Mdot
.952 .3274 Mdot
.952 .32751 Mdot
.952 .32768 Mdot
.952 .32777 Mdot
.952 .32786 Mdot
.952 .32809 Mdot
.952 .3281 Mdot
.952 .32877 Mdot
.952 .32978 Mdot
.952 .32983 Mdot
.952 .33046 Mdot
.952 .33106 Mdot
.952 .33161 Mdot
.952 .33221 Mdot
.952 .33244 Mdot
.952 .33245 Mdot
.952 .33264 Mdot
.952 .33268 Mdot
.952 .33283 Mdot
.952 .33302 Mdot
.952 .33332 Mdot
.952 .33345 Mdot
.952 .33358 Mdot
.952 .33362 Mdot
.952 .33394 Mdot
.952 .33417 Mdot
.952 .33436 Mdot
.952 .33559 Mdot
.952 .33651 Mdot
.952 .337 Mdot
.952 .3376 Mdot
.952 .33967 Mdot
.952 .34031 Mdot
.952 .34059 Mdot
.952 .34098 Mdot
.952 .3418 Mdot
.952 .34187 Mdot
.952 .34192 Mdot
.952 .34232 Mdot
.952 .34257 Mdot
.952 .34263 Mdot
.952 .34333 Mdot
.952 .34363 Mdot
.952 .34364 Mdot
.952 .3443 Mdot
.952 .34489 Mdot
.952 .34514 Mdot
.952 .34518 Mdot
.952 .34669 Mdot
.952 .34708 Mdot
.952 .3485 Mdot
.952 .34855 Mdot
.952 .3487 Mdot
.952 .34885 Mdot
.952 .34899 Mdot
.952 .34901 Mdot
.952 .34942 Mdot
.952 .34944 Mdot
.952 .3497 Mdot
.952 .34988 Mdot
.952 .34993 Mdot
.952 .35097 Mdot
.952 .35118 Mdot
.952 .35122 Mdot
.952 .35134 Mdot
.952 .35137 Mdot
.952 .35164 Mdot
.952 .35166 Mdot
.952 .35166 Mdot
.952 .35187 Mdot
.952 .35278 Mdot
.952 .35296 Mdot
.952 .35298 Mdot
.952 .35315 Mdot
.952 .35326 Mdot
.952 .3533 Mdot
.952 .3534 Mdot
.952 .3535 Mdot
.952 .35353 Mdot
.952 .35385 Mdot
.952 .35435 Mdot
.952 .35449 Mdot
.952 .35458 Mdot
.952 .3548 Mdot
.952 .35487 Mdot
.952 .3551 Mdot
.952 .35516 Mdot
.952 .3554 Mdot
.952 .3554 Mdot
.952 .35542 Mdot
.952 .35546 Mdot
.952 .35552 Mdot
.952 .35553 Mdot
.952 .35556 Mdot
.952 .35566 Mdot
.952 .35567 Mdot
.952 .35573 Mdot
.952 .35574 Mdot
.952 .35576 Mdot
.952 .35576 Mdot
.952 .35713 Mdot
.952 .35727 Mdot
.952 .36019 Mdot
.952 .36958 Mdot
.952 .38533 Mdot
.952 .39242 Mdot
.952 .40372 Mdot
.952 .40393 Mdot
.952 .41049 Mdot
.952 .41233 Mdot
.952 .4139 Mdot
.952 .41594 Mdot
.952 .41612 Mdot
.952 .4203 Mdot
.952 .42312 Mdot
.952 .42447 Mdot
.952 .42452 Mdot
.952 .43493 Mdot
.952 .43847 Mdot
.952 .44529 Mdot
.952 .44601 Mdot
.952 .44698 Mdot
.952 .44894 Mdot
.952 .45015 Mdot
.952 .45569 Mdot
.952 .45756 Mdot
.952 .458 Mdot
.952 .46551 Mdot
.952 .46567 Mdot
.952 .46807 Mdot
.952 .47326 Mdot
.952 .47509 Mdot
.952 .48449 Mdot
.952 .49945 Mdot
.952 .50416 Mdot
.952 .50698 Mdot
.952 .50794 Mdot
.952 .51997 Mdot
.952 .53632 Mdot
.952 .5377 Mdot
.952 .54366 Mdot
.952 .54366 Mdot
.952 .54367 Mdot
.952 .54367 Mdot
.952 .54369 Mdot
.952 .54369 Mdot
.952 .54372 Mdot
.952 .54373 Mdot
.952 .54373 Mdot
.952 .54375 Mdot
.952 .54376 Mdot
.952 .54377 Mdot
.952 .54384 Mdot
.952 .54385 Mdot
.952 .54392 Mdot
.952 .54394 Mdot
.952 .54399 Mdot
.952 .54405 Mdot
.952 .54416 Mdot
.952 .54423 Mdot
.952 .54424 Mdot
.952 .54428 Mdot
.952 .54428 Mdot
.952 .54431 Mdot
.952 .54434 Mdot
.952 .54438 Mdot
.952 .54458 Mdot
.952 .54463 Mdot
.952 .54464 Mdot
.952 .5447 Mdot
.952 .5449 Mdot
.952 .54493 Mdot
.952 .54494 Mdot
.952 .545 Mdot
.952 .54502 Mdot
.952 .54504 Mdot
.952 .54506 Mdot
.952 .54507 Mdot
.952 .54526 Mdot
.952 .54531 Mdot
.952 .54568 Mdot
.952 .54588 Mdot
.952 .546 Mdot
.952 .5461 Mdot
.952 .5463 Mdot
.952 .54641 Mdot
.952 .5468 Mdot
.952 .547 Mdot
.952 .54725 Mdot
.952 .54761 Mdot
.952 .54765 Mdot
.952 .54765 Mdot
.952 .5477 Mdot
.952 .5478 Mdot
.952 .54784 Mdot
.952 .54797 Mdot
.952 .54797 Mdot
.952 .54799 Mdot
.952 .54813 Mdot
.952 .54814 Mdot
.952 .54824 Mdot
.952 .54825 Mdot
.952 .54827 Mdot
.952 .54827 Mdot
.952 .54833 Mdot
.952 .54837 Mdot
.952 .54855 Mdot
.952 .54858 Mdot
.952 .54858 Mdot
.952 .54867 Mdot
.952 .54868 Mdot
.952 .54871 Mdot
.952 .54877 Mdot
.952 .54879 Mdot
.952 .54882 Mdot
.952 .54885 Mdot
.952 .54894 Mdot
.952 .54901 Mdot
.952 .54901 Mdot
.952 .54904 Mdot
.952 .54907 Mdot
.952 .54907 Mdot
.952 .54909 Mdot
.952 .54909 Mdot
.952 .54927 Mdot
.952 .54941 Mdot
.952 .54961 Mdot
.952 .54966 Mdot
.952 .54982 Mdot
.952 .54983 Mdot
.952 .54985 Mdot
.952 .55006 Mdot
.952 .55008 Mdot
.952 .55024 Mdot
.952 .55029 Mdot
.952 .55048 Mdot
.952 .5505 Mdot
.952 .55052 Mdot
.952 .55053 Mdot
.952 .55062 Mdot
.952 .55066 Mdot
.952 .55069 Mdot
.952 .5507 Mdot
.952 .55092 Mdot
.952 .55096 Mdot
.952 .55102 Mdot
.952 .55104 Mdot
.952 .55105 Mdot
.952 .5511 Mdot
.952 .55112 Mdot
.952 .55115 Mdot
.952 .55124 Mdot
.952 .55129 Mdot
.952 .55162 Mdot
.952 .55165 Mdot
.952 .55191 Mdot
.952 .55214 Mdot
.952 .55221 Mdot
.952 .55241 Mdot
.952 .55256 Mdot
.952 .55263 Mdot
.952 .55266 Mdot
.952 .55276 Mdot
.952 .55279 Mdot
.952 .55286 Mdot
.952 .55287 Mdot
.952 .55292 Mdot
.952 .55301 Mdot
.952 .55306 Mdot
.952 .5532 Mdot
.952 .55322 Mdot
.952 .55325 Mdot
.952 .55331 Mdot
.952 .55331 Mdot
.952 .55334 Mdot
.952 .55336 Mdot
.952 .55366 Mdot
.952 .55377 Mdot
.952 .55404 Mdot
.952 .55442 Mdot
.952 .5546 Mdot
.952 .55461 Mdot
.952 .55473 Mdot
.952 .55487 Mdot
.952 .55502 Mdot
.952 .55511 Mdot
.952 .55543 Mdot
.952 .55549 Mdot
.952 .55551 Mdot
.952 .55582 Mdot
.952 .55583 Mdot
.952 .55586 Mdot
.952 .55591 Mdot
.952 .55599 Mdot
.952 .556 Mdot
.952 .55605 Mdot
.952 .55616 Mdot
.952 .55616 Mdot
.952 .55619 Mdot
.952 .55619 Mdot
.952 .55628 Mdot
.952 .55629 Mdot
.952 .55632 Mdot
.952 .55632 Mdot
.952 .5568 Mdot
.952 .55682 Mdot
.952 .55685 Mdot
.952 .55688 Mdot
.952 .55743 Mdot
.952 .55748 Mdot
.952 .55756 Mdot
.952 .55761 Mdot
.952 .55807 Mdot
.952 .55819 Mdot
.952 .5582 Mdot
.952 .55839 Mdot
.952 .55844 Mdot
.952 .55858 Mdot
.952 .55926 Mdot
.952 .55964 Mdot
.952 .56064 Mdot
.952 .56064 Mdot
.952 .56143 Mdot
.952 .56152 Mdot
.952 .56155 Mdot
.952 .56223 Mdot
.952 .56225 Mdot
.952 .56242 Mdot
.952 .56291 Mdot
.952 .56301 Mdot
.952 .56316 Mdot
.952 .56331 Mdot
.952 .56348 Mdot
.952 .56352 Mdot
.952 .56392 Mdot
.952 .56402 Mdot
.952 .5642 Mdot
.952 .56451 Mdot
.952 .56493 Mdot
.952 .56493 Mdot
.952 .56512 Mdot
.952 .56517 Mdot
.952 .56571 Mdot
.952 .56583 Mdot
.952 .56589 Mdot
.952 .56609 Mdot
.952 .56612 Mdot
.952 .5662 Mdot
.952 .56654 Mdot
.952 .56663 Mdot
.952 .56679 Mdot
.952 .56697 Mdot
.952 .56725 Mdot
.952 .5675 Mdot
.952 .56783 Mdot
.952 .56807 Mdot
.952 .56868 Mdot
.952 .56882 Mdot
.952 .56922 Mdot
.952 .56951 Mdot
.952 .56958 Mdot
.952 .57021 Mdot
.952 .57046 Mdot
.952 .57068 Mdot
.952 .57171 Mdot
.952 .57183 Mdot
.952 .57193 Mdot
.952 .57206 Mdot
.952 .57218 Mdot
.952 .57222 Mdot
.952 .5723 Mdot
.952 .57236 Mdot
.952 .57242 Mdot
.952 .57244 Mdot
.952 .57286 Mdot
.952 .57295 Mdot
.952 .57296 Mdot
.952 .5733 Mdot
.952 .57334 Mdot
.952 .57336 Mdot
.952 .57367 Mdot
.952 .57383 Mdot
.952 .57388 Mdot
.952 .57395 Mdot
.952 .57403 Mdot
.952 .57409 Mdot
.952 .57411 Mdot
.952 .57426 Mdot
.952 .5743 Mdot
.952 .57439 Mdot
.952 .57442 Mdot
.952 .57443 Mdot
.952 .57452 Mdot
.952 .57457 Mdot
.952 .57462 Mdot
.952 .57462 Mdot
.952 .57468 Mdot
.952 .57478 Mdot
.952 .5749 Mdot
.952 .5749 Mdot
.952 .57491 Mdot
.952 .57495 Mdot
.952 .575 Mdot
.952 .57509 Mdot
.952 .57511 Mdot
.952 .5752 Mdot
.952 .57523 Mdot
.952 .57524 Mdot
.952 .57525 Mdot
.954 .10806 Mdot
.954 .10807 Mdot
.954 .10807 Mdot
.954 .10808 Mdot
.954 .10808 Mdot
.954 .10808 Mdot
.954 .10808 Mdot
.954 .1081 Mdot
.954 .1081 Mdot
.954 .1081 Mdot
.954 .1081 Mdot
.954 .10816 Mdot
.954 .10822 Mdot
.954 .10828 Mdot
.954 .10831 Mdot
.954 .10838 Mdot
.954 .10838 Mdot
.954 .10845 Mdot
.954 .10845 Mdot
.954 .10845 Mdot
.954 .10845 Mdot
.954 .10846 Mdot
.954 .10848 Mdot
.954 .1085 Mdot
.954 .10855 Mdot
.954 .10859 Mdot
.954 .10865 Mdot
.954 .10873 Mdot
.954 .10892 Mdot
.954 .10896 Mdot
.954 .10901 Mdot
.954 .10901 Mdot
.954 .10903 Mdot
.954 .10905 Mdot
.954 .10911 Mdot
.954 .10911 Mdot
.954 .10911 Mdot
.954 .10914 Mdot
.954 .10916 Mdot
.954 .10918 Mdot
.954 .10927 Mdot
.954 .10928 Mdot
.954 .10928 Mdot
.954 .10928 Mdot
.954 .10929 Mdot
.954 .10929 Mdot
.954 .10935 Mdot
.954 .10939 Mdot
.954 .10952 Mdot
.954 .10963 Mdot
.954 .1097 Mdot
.954 .10978 Mdot
.954 .1099 Mdot
.954 .11008 Mdot
.954 .11023 Mdot
.954 .11026 Mdot
.954 .11027 Mdot
.954 .11033 Mdot
.954 .11058 Mdot
.954 .11063 Mdot
.954 .11072 Mdot
.954 .11078 Mdot
.954 .1109 Mdot
.954 .11092 Mdot
.954 .11092 Mdot
.954 .11097 Mdot
.954 .111 Mdot
.954 .11106 Mdot
.954 .11107 Mdot
.954 .11108 Mdot
.954 .1111 Mdot
.954 .11112 Mdot
.954 .11116 Mdot
.954 .11116 Mdot
.954 .11119 Mdot
.954 .11119 Mdot
.954 .11119 Mdot
.954 .11119 Mdot
.954 .1112 Mdot
.954 .1112 Mdot
.954 .1112 Mdot
.954 .1112 Mdot
.954 .11125 Mdot
.954 .11207 Mdot
.954 .1121 Mdot
.954 .11217 Mdot
.954 .11376 Mdot
.954 .11381 Mdot
.954 .11457 Mdot
.954 .11465 Mdot
.954 .11474 Mdot
.954 .11548 Mdot
.954 .11598 Mdot
.954 .11773 Mdot
.954 .118 Mdot
.954 .12009 Mdot
.954 .12064 Mdot
.954 .12074 Mdot
.954 .12113 Mdot
.954 .12215 Mdot
.954 .12219 Mdot
.954 .1229 Mdot
.954 .12335 Mdot
.954 .12358 Mdot
.954 .12396 Mdot
.954 .12444 Mdot
.954 .12563 Mdot
.954 .12602 Mdot
.954 .12658 Mdot
.954 .12668 Mdot
.954 .12671 Mdot
.954 .1269 Mdot
.954 .12762 Mdot
.954 .12818 Mdot
.954 .12986 Mdot
.954 .13003 Mdot
.954 .13032 Mdot
.954 .13051 Mdot
.954 .1306 Mdot
.954 .13087 Mdot
.954 .13259 Mdot
.954 .13285 Mdot
.954 .13352 Mdot
.954 .13383 Mdot
.954 .13387 Mdot
.954 .13391 Mdot
.954 .13401 Mdot
.954 .13418 Mdot
.954 .13451 Mdot
.954 .1346 Mdot
.954 .13485 Mdot
.954 .13488 Mdot
.954 .13494 Mdot
.954 .13505 Mdot
.954 .13522 Mdot
.954 .13535 Mdot
.954 .13547 Mdot
.954 .13552 Mdot
.954 .13557 Mdot
.954 .13574 Mdot
.954 .13579 Mdot
.954 .13586 Mdot
.954 .13603 Mdot
.954 .13635 Mdot
.954 .13646 Mdot
.954 .13666 Mdot
.954 .13668 Mdot
.954 .13675 Mdot
.954 .13701 Mdot
.954 .13705 Mdot
.954 .13718 Mdot
.954 .13732 Mdot
.954 .13753 Mdot
.954 .13778 Mdot
.954 .1378 Mdot
.954 .13782 Mdot
.954 .13783 Mdot
.954 .13784 Mdot
.954 .13786 Mdot
.954 .13786 Mdot
.954 .13787 Mdot
.954 .13789 Mdot
.954 .13792 Mdot
.954 .13793 Mdot
.954 .13793 Mdot
.954 .13793 Mdot
.954 .13806 Mdot
.954 .13812 Mdot
.954 .13833 Mdot
.954 .13851 Mdot
.954 .1386 Mdot
.954 .13883 Mdot
.954 .13884 Mdot
.954 .13888 Mdot
.954 .13898 Mdot
.954 .13905 Mdot
.954 .13906 Mdot
.954 .13907 Mdot
.954 .13909 Mdot
.954 .13909 Mdot
.954 .1391 Mdot
.954 .13918 Mdot
.954 .13925 Mdot
.954 .1394 Mdot
.954 .13954 Mdot
.954 .13956 Mdot
.954 .13961 Mdot
.954 .13961 Mdot
.954 .13976 Mdot
.954 .13985 Mdot
.954 .13999 Mdot
.954 .14003 Mdot
.954 .14004 Mdot
.954 .14051 Mdot
.954 .14064 Mdot
.954 .14079 Mdot
.954 .14083 Mdot
.954 .14094 Mdot
.954 .14096 Mdot
.954 .14101 Mdot
.954 .14109 Mdot
.954 .14121 Mdot
.954 .1413 Mdot
.954 .1413 Mdot
.954 .14131 Mdot
.954 .14133 Mdot
.954 .14136 Mdot
.954 .1414 Mdot
.954 .14145 Mdot
.954 .14153 Mdot
.954 .14185 Mdot
.954 .14186 Mdot
.954 .14187 Mdot
.954 .14188 Mdot
.954 .1419 Mdot
.954 .14192 Mdot
.954 .14212 Mdot
.954 .14217 Mdot
.954 .14226 Mdot
.954 .14256 Mdot
.954 .14268 Mdot
.954 .1427 Mdot
.954 .14309 Mdot
.954 .14331 Mdot
.954 .14334 Mdot
.954 .14358 Mdot
.954 .14361 Mdot
.954 .14369 Mdot
.954 .1438 Mdot
.954 .14383 Mdot
.954 .14403 Mdot
.954 .1441 Mdot
.954 .14458 Mdot
.954 .14466 Mdot
.954 .14473 Mdot
.954 .14488 Mdot
.954 .14501 Mdot
.954 .14519 Mdot
.954 .14521 Mdot
.954 .14523 Mdot
.954 .1453 Mdot
.954 .14532 Mdot
.954 .14533 Mdot
.954 .14556 Mdot
.954 .14568 Mdot
.954 .14582 Mdot
.954 .14595 Mdot
.954 .14647 Mdot
.954 .1465 Mdot
.954 .14651 Mdot
.954 .14664 Mdot
.954 .14667 Mdot
.954 .14692 Mdot
.954 .14699 Mdot
.954 .14705 Mdot
.954 .14719 Mdot
.954 .14762 Mdot
.954 .14763 Mdot
.954 .14763 Mdot
.954 .1477 Mdot
.954 .14772 Mdot
.954 .1479 Mdot
.954 .148 Mdot
.954 .14818 Mdot
.954 .14823 Mdot
.954 .14825 Mdot
.954 .14828 Mdot
.954 .14837 Mdot
.954 .14843 Mdot
.954 .14845 Mdot
.954 .1486 Mdot
.954 .1486 Mdot
.954 .14867 Mdot
.954 .1487 Mdot
.954 .1487 Mdot
.954 .14871 Mdot
.954 .14872 Mdot
.954 .14874 Mdot
.954 .14874 Mdot
.954 .14874 Mdot
.954 .14875 Mdot
.954 .14892 Mdot
.954 .14894 Mdot
.954 .14911 Mdot
.954 .14948 Mdot
.954 .14966 Mdot
.954 .14983 Mdot
.954 .14992 Mdot
.954 .14993 Mdot
.954 .14995 Mdot
.954 .14999 Mdot
.954 .15 Mdot
.954 .1503 Mdot
.954 .1509 Mdot
.954 .15096 Mdot
.954 .15107 Mdot
.954 .15116 Mdot
.954 .15123 Mdot
.954 .15169 Mdot
.954 .152 Mdot
.954 .15205 Mdot
.954 .15206 Mdot
.954 .15211 Mdot
.954 .15212 Mdot
.954 .15214 Mdot
.954 .1523 Mdot
.954 .15233 Mdot
.954 .15235 Mdot
.954 .15243 Mdot
.954 .15246 Mdot
.954 .15253 Mdot
.954 .15261 Mdot
.954 .15284 Mdot
.954 .15306 Mdot
.954 .15349 Mdot
.954 .15353 Mdot
.954 .15363 Mdot
.954 .15404 Mdot
.954 .1543 Mdot
.954 .15495 Mdot
.954 .15514 Mdot
.954 .15523 Mdot
.954 .15525 Mdot
.954 .15532 Mdot
.954 .15568 Mdot
.954 .15587 Mdot
.954 .15635 Mdot
.954 .15659 Mdot
.954 .15678 Mdot
.954 .15712 Mdot
.954 .15713 Mdot
.954 .15716 Mdot
.954 .15733 Mdot
.954 .15733 Mdot
.954 .15741 Mdot
.954 .15771 Mdot
.954 .1579 Mdot
.954 .15803 Mdot
.954 .15809 Mdot
.954 .15819 Mdot
.954 .15821 Mdot
.954 .15829 Mdot
.954 .15833 Mdot
.954 .15835 Mdot
.954 .15873 Mdot
.954 .15876 Mdot
.954 .15895 Mdot
.954 .15912 Mdot
.954 .15929 Mdot
.954 .15933 Mdot
.954 .15944 Mdot
.954 .15947 Mdot
.954 .15953 Mdot
.954 .15953 Mdot
.954 .15956 Mdot
.954 .15958 Mdot
.954 .15964 Mdot
.954 .15972 Mdot
.954 .15973 Mdot
.954 .15974 Mdot
.954 .15979 Mdot
.954 .15982 Mdot
.954 .15984 Mdot
.954 .15998 Mdot
.954 .16001 Mdot
.954 .16003 Mdot
.954 .1601 Mdot
.954 .16214 Mdot
.954 .16246 Mdot
.954 .16282 Mdot
.954 .166 Mdot
.954 .16817 Mdot
.954 .17035 Mdot
.954 .17602 Mdot
.954 .17726 Mdot
.954 .17898 Mdot
.954 .18454 Mdot
.954 .1868 Mdot
.954 .18709 Mdot
.954 .18977 Mdot
.954 .19023 Mdot
.954 .19215 Mdot
.954 .19718 Mdot
.954 .19735 Mdot
.954 .20089 Mdot
.954 .20317 Mdot
.954 .20433 Mdot
.954 .20624 Mdot
.954 .20871 Mdot
.954 .2096 Mdot
.954 .21476 Mdot
.954 .21678 Mdot
.954 .21905 Mdot
.954 .2197 Mdot
.954 .22022 Mdot
.954 .22039 Mdot
.954 .22134 Mdot
.954 .2251 Mdot
.954 .22797 Mdot
.954 .23673 Mdot
.954 .23759 Mdot
.954 .23914 Mdot
.954 .24009 Mdot
.954 .24056 Mdot
.954 .242 Mdot
.954 .25089 Mdot
.954 .25222 Mdot
.954 .25296 Mdot
.954 .25562 Mdot
.954 .25724 Mdot
.954 .25745 Mdot
.954 .25763 Mdot
.954 .25813 Mdot
.954 .25903 Mdot
.954 .26067 Mdot
.954 .26115 Mdot
.954 .26239 Mdot
.954 .26253 Mdot
.954 .26286 Mdot
.954 .26341 Mdot
.954 .26426 Mdot
.954 .26489 Mdot
.954 .26553 Mdot
.954 .26579 Mdot
.954 .26601 Mdot
.954 .26686 Mdot
.954 .26713 Mdot
.954 .26749 Mdot
.954 .26829 Mdot
.954 .26989 Mdot
.954 .27046 Mdot
.954 .27141 Mdot
.954 .27152 Mdot
.954 .27178 Mdot
.954 .27187 Mdot
.954 .27314 Mdot
.954 .27334 Mdot
.954 .27396 Mdot
.954 .27468 Mdot
.954 .27571 Mdot
.954 .27691 Mdot
.954 .277 Mdot
.954 .27709 Mdot
.954 .27713 Mdot
.954 .27717 Mdot
.954 .27729 Mdot
.954 .27729 Mdot
.954 .27734 Mdot
.954 .27742 Mdot
.954 .2776 Mdot
.954 .27761 Mdot
.954 .27762 Mdot
.954 .27763 Mdot
.954 .27827 Mdot
.954 .27855 Mdot
.954 .27955 Mdot
.954 .28043 Mdot
.954 .28087 Mdot
.954 .28196 Mdot
.954 .282 Mdot
.954 .28204 Mdot
.954 .28217 Mdot
.954 .28265 Mdot
.954 .283 Mdot
.954 .28305 Mdot
.954 .28306 Mdot
.954 .28318 Mdot
.954 .28319 Mdot
.954 .28323 Mdot
.954 .2836 Mdot
.954 .28393 Mdot
.954 .28463 Mdot
.954 .28527 Mdot
.954 .28539 Mdot
.954 .2856 Mdot
.954 .28562 Mdot
.954 .2857 Mdot
.954 .2863 Mdot
.954 .28673 Mdot
.954 .2874 Mdot
.954 .28757 Mdot
.954 .28764 Mdot
.954 .28979 Mdot
.954 .2898 Mdot
.954 .29039 Mdot
.954 .29108 Mdot
.954 .29127 Mdot
.954 .29186 Mdot
.954 .29208 Mdot
.954 .29243 Mdot
.954 .29298 Mdot
.954 .29339 Mdot
.954 .29339 Mdot
.954 .2934 Mdot
.954 .29352 Mdot
.954 .29362 Mdot
.954 .29382 Mdot
.954 .29405 Mdot
.954 .2944 Mdot
.954 .29584 Mdot
.954 .29586 Mdot
.954 .29592 Mdot
.954 .29597 Mdot
.954 .29606 Mdot
.954 .29614 Mdot
.954 .29702 Mdot
.954 .29726 Mdot
.954 .29763 Mdot
.954 .29894 Mdot
.954 .29949 Mdot
.954 .29954 Mdot
.954 .30125 Mdot
.954 .3022 Mdot
.954 .3023 Mdot
.954 .30331 Mdot
.954 .30345 Mdot
.954 .30379 Mdot
.954 .30426 Mdot
.954 .30438 Mdot
.954 .30523 Mdot
.954 .3055 Mdot
.954 .30747 Mdot
.954 .30783 Mdot
.954 .30809 Mdot
.954 .30869 Mdot
.954 .30924 Mdot
.954 .30996 Mdot
.954 .31003 Mdot
.954 .3101 Mdot
.954 .31041 Mdot
.954 .31045 Mdot
.954 .31051 Mdot
.954 .31143 Mdot
.954 .31191 Mdot
.954 .31245 Mdot
.954 .31295 Mdot
.954 .31497 Mdot
.954 .31509 Mdot
.954 .31513 Mdot
.954 .31562 Mdot
.954 .31574 Mdot
.954 .31669 Mdot
.954 .31694 Mdot
.954 .31715 Mdot
.954 .31768 Mdot
.954 .31928 Mdot
.954 .3193 Mdot
.954 .31931 Mdot
.954 .31949 Mdot
.954 .31956 Mdot
.954 .31963 Mdot
.954 .32029 Mdot
.954 .32065 Mdot
.954 .32128 Mdot
.954 .32145 Mdot
.954 .32154 Mdot
.954 .32165 Mdot
.954 .32194 Mdot
.954 .32217 Mdot
.954 .32224 Mdot
.954 .32277 Mdot
.954 .32278 Mdot
.954 .32301 Mdot
.954 .32311 Mdot
.954 .32313 Mdot
.954 .32317 Mdot
.954 .32317 Mdot
.954 .32324 Mdot
.954 .32325 Mdot
.954 .32326 Mdot
.954 .32328 Mdot
.954 .3239 Mdot
.954 .32393 Mdot
.954 .32453 Mdot
.954 .32578 Mdot
.954 .32639 Mdot
.954 .32644 Mdot
.954 .32644 Mdot
.954 .32689 Mdot
.954 .32694 Mdot
.954 .327 Mdot
.954 .32725 Mdot
.954 .32727 Mdot
.954 .32736 Mdot
.954 .32746 Mdot
.954 .32751 Mdot
.954 .32834 Mdot
.954 .3285 Mdot
.954 .32911 Mdot
.954 .32916 Mdot
.954 .3293 Mdot
.954 .3304 Mdot
.954 .33057 Mdot
.954 .33093 Mdot
.954 .33118 Mdot
.954 .3314 Mdot
.954 .33241 Mdot
.954 .3328 Mdot
.954 .33371 Mdot
.954 .33386 Mdot
.954 .33389 Mdot
.954 .33403 Mdot
.954 .33407 Mdot
.954 .33414 Mdot
.954 .33454 Mdot
.954 .3346 Mdot
.954 .33467 Mdot
.954 .33472 Mdot
.954 .33497 Mdot
.954 .33506 Mdot
.954 .33526 Mdot
.954 .33548 Mdot
.954 .33612 Mdot
.954 .33636 Mdot
.954 .33673 Mdot
.954 .33699 Mdot
.954 .3376 Mdot
.954 .3379 Mdot
.954 .33801 Mdot
.954 .33825 Mdot
.954 .33828 Mdot
.954 .33934 Mdot
.954 .34001 Mdot
.954 .34049 Mdot
.954 .34125 Mdot
.954 .34162 Mdot
.954 .34166 Mdot
.954 .34207 Mdot
.954 .34229 Mdot
.954 .34233 Mdot
.954 .3425 Mdot
.954 .34334 Mdot
.954 .34377 Mdot
.954 .34479 Mdot
.954 .34483 Mdot
.954 .34534 Mdot
.954 .34573 Mdot
.954 .34602 Mdot
.954 .34643 Mdot
.954 .34646 Mdot
.954 .34652 Mdot
.954 .34685 Mdot
.954 .34686 Mdot
.954 .34701 Mdot
.954 .3476 Mdot
.954 .34778 Mdot
.954 .34795 Mdot
.954 .3482 Mdot
.954 .34832 Mdot
.954 .34849 Mdot
.954 .34853 Mdot
.954 .34867 Mdot
.954 .34875 Mdot
.954 .34879 Mdot
.954 .34923 Mdot
.954 .34947 Mdot
.954 .34951 Mdot
.954 .34971 Mdot
.954 .34984 Mdot
.954 .35012 Mdot
.954 .35014 Mdot
.954 .3504 Mdot
.954 .35047 Mdot
.954 .35064 Mdot
.954 .35069 Mdot
.954 .35078 Mdot
.954 .35079 Mdot
.954 .35084 Mdot
.954 .35087 Mdot
.954 .35096 Mdot
.954 .35109 Mdot
.954 .3511 Mdot
.954 .35112 Mdot
.954 .35119 Mdot
.954 .35124 Mdot
.954 .35127 Mdot
.954 .35148 Mdot
.954 .35153 Mdot
.954 .35156 Mdot
.954 .35157 Mdot
.954 .35167 Mdot
.954 .35185 Mdot
.954 .35252 Mdot
.954 .35367 Mdot
.954 .35433 Mdot
.954 .35467 Mdot
.954 .35482 Mdot
.954 .35505 Mdot
.954 .35578 Mdot
.954 .35738 Mdot
.954 .35795 Mdot
.954 .35799 Mdot
.954 .35802 Mdot
.954 .3584 Mdot
.954 .36511 Mdot
.954 .36703 Mdot
.954 .3762 Mdot
.954 .38675 Mdot
.954 .4057 Mdot
.954 .41621 Mdot
.954 .42052 Mdot
.954 .42427 Mdot
.954 .42839 Mdot
.954 .43323 Mdot
.954 .43567 Mdot
.954 .44313 Mdot
.954 .44649 Mdot
.954 .48875 Mdot
.954 .49526 Mdot
.954 .49883 Mdot
.954 .49973 Mdot
.954 .51118 Mdot
.954 .51834 Mdot
.954 .51923 Mdot
.954 .52001 Mdot
.954 .52213 Mdot
.954 .52586 Mdot
.954 .5324 Mdot
.954 .53424 Mdot
.954 .53883 Mdot
.954 .5393 Mdot
.954 .54048 Mdot
.954 .54239 Mdot
.954 .54477 Mdot
.954 .54479 Mdot
.954 .5448 Mdot
.954 .5448 Mdot
.954 .54484 Mdot
.954 .54484 Mdot
.954 .54485 Mdot
.954 .54486 Mdot
.954 .54486 Mdot
.954 .54486 Mdot
.954 .54488 Mdot
.954 .5449 Mdot
.954 .5449 Mdot
.954 .54491 Mdot
.954 .54491 Mdot
.954 .54493 Mdot
.954 .54493 Mdot
.954 .54496 Mdot
.954 .54497 Mdot
.954 .54501 Mdot
.954 .5451 Mdot
.954 .5452 Mdot
.954 .5452 Mdot
.954 .54521 Mdot
.954 .54523 Mdot
.954 .54524 Mdot
.954 .54526 Mdot
.954 .54528 Mdot
.954 .54531 Mdot
.954 .54536 Mdot
.954 .54543 Mdot
.954 .54545 Mdot
.954 .54545 Mdot
.954 .54549 Mdot
.954 .5455 Mdot
.954 .5455 Mdot
.954 .54559 Mdot
.954 .54563 Mdot
.954 .54569 Mdot
.954 .54581 Mdot
.954 .54586 Mdot
.954 .54595 Mdot
.954 .54597 Mdot
.954 .54597 Mdot
.954 .546 Mdot
.954 .54604 Mdot
.954 .54621 Mdot
.954 .54627 Mdot
.954 .54638 Mdot
.954 .5464 Mdot
.954 .54641 Mdot
.954 .54652 Mdot
.954 .54658 Mdot
.954 .54664 Mdot
.954 .54666 Mdot
.954 .54668 Mdot
.954 .54671 Mdot
.954 .54671 Mdot
.954 .54672 Mdot
.954 .54677 Mdot
.954 .54677 Mdot
.954 .54678 Mdot
.954 .5468 Mdot
.954 .54688 Mdot
.954 .547 Mdot
.954 .54702 Mdot
.954 .54704 Mdot
.954 .54707 Mdot
.954 .54708 Mdot
.954 .54724 Mdot
.954 .54732 Mdot
.954 .54733 Mdot
.954 .54733 Mdot
.954 .54734 Mdot
.954 .54734 Mdot
.954 .54737 Mdot
.954 .54741 Mdot
.954 .54746 Mdot
.954 .54756 Mdot
.954 .54761 Mdot
.954 .54768 Mdot
.954 .54774 Mdot
.954 .54781 Mdot
.954 .54796 Mdot
.954 .54796 Mdot
.954 .54812 Mdot
.954 .54815 Mdot
.954 .54822 Mdot
.954 .54826 Mdot
.954 .54827 Mdot
.954 .54842 Mdot
.954 .54845 Mdot
.954 .54849 Mdot
.954 .5486 Mdot
.954 .54862 Mdot
.954 .54863 Mdot
.954 .54868 Mdot
.954 .54872 Mdot
.954 .54876 Mdot
.954 .5488 Mdot
.954 .54894 Mdot
.954 .54901 Mdot
.954 .54902 Mdot
.954 .54905 Mdot
.954 .54908 Mdot
.954 .54915 Mdot
.954 .54934 Mdot
.954 .54938 Mdot
.954 .54949 Mdot
.954 .54973 Mdot
.954 .54973 Mdot
.954 .54977 Mdot
.954 .54988 Mdot
.954 .54998 Mdot
.954 .55012 Mdot
.954 .55012 Mdot
.954 .55017 Mdot
.954 .55025 Mdot
.954 .55025 Mdot
.954 .55026 Mdot
.954 .55041 Mdot
.954 .55044 Mdot
.954 .55047 Mdot
.954 .55072 Mdot
.954 .5508 Mdot
.954 .5508 Mdot
.954 .55088 Mdot
.954 .55095 Mdot
.954 .55099 Mdot
.954 .55103 Mdot
.954 .55105 Mdot
.954 .55113 Mdot
.954 .55115 Mdot
.954 .55116 Mdot
.954 .55122 Mdot
.954 .55125 Mdot
.954 .55136 Mdot
.954 .55141 Mdot
.954 .55143 Mdot
.954 .55145 Mdot
.954 .5515 Mdot
.954 .55152 Mdot
.954 .55153 Mdot
.954 .55157 Mdot
.954 .55162 Mdot
.954 .55167 Mdot
.954 .55171 Mdot
.954 .55173 Mdot
.954 .55174 Mdot
.954 .55182 Mdot
.954 .55185 Mdot
.954 .55195 Mdot
.954 .55201 Mdot
.954 .55204 Mdot
.954 .55206 Mdot
.954 .55207 Mdot
.954 .55218 Mdot
.954 .5524 Mdot
.954 .55249 Mdot
.954 .55308 Mdot
.954 .55318 Mdot
.954 .55321 Mdot
.954 .55327 Mdot
.954 .55338 Mdot
.954 .55344 Mdot
.954 .55406 Mdot
.954 .55427 Mdot
.954 .55454 Mdot
.954 .55462 Mdot
.954 .55463 Mdot
.954 .55467 Mdot
.954 .55489 Mdot
.954 .55505 Mdot
.954 .55553 Mdot
.954 .55573 Mdot
.954 .55589 Mdot
.954 .55599 Mdot
.954 .55619 Mdot
.954 .5565 Mdot
.954 .55651 Mdot
.954 .55698 Mdot
.954 .55717 Mdot
.954 .55721 Mdot
.954 .55748 Mdot
.954 .55854 Mdot
.954 .55869 Mdot
.954 .55969 Mdot
.954 .55999 Mdot
.954 .56047 Mdot
.954 .56053 Mdot
.954 .56058 Mdot
.954 .56111 Mdot
.954 .56114 Mdot
.954 .56237 Mdot
.954 .56244 Mdot
.954 .56246 Mdot
.954 .5632 Mdot
.954 .56447 Mdot
.954 .5647 Mdot
.954 .56497 Mdot
.954 .56522 Mdot
.954 .56541 Mdot
.954 .56547 Mdot
.954 .56578 Mdot
.954 .56586 Mdot
.954 .56693 Mdot
.954 .56703 Mdot
.954 .56715 Mdot
.954 .56721 Mdot
.954 .56728 Mdot
.954 .5673 Mdot
.954 .56776 Mdot
.954 .5681 Mdot
.954 .56908 Mdot
.954 .56913 Mdot
.954 .56948 Mdot
.954 .56975 Mdot
.954 .56983 Mdot
.954 .56998 Mdot
.954 .57009 Mdot
.954 .57022 Mdot
.954 .57023 Mdot
.954 .57024 Mdot
.954 .57025 Mdot
.954 .57069 Mdot
.954 .57128 Mdot
.954 .57164 Mdot
.954 .57165 Mdot
.954 .57187 Mdot
.954 .5719 Mdot
.954 .57244 Mdot
.954 .57261 Mdot
.954 .57304 Mdot
.954 .57314 Mdot
.954 .57322 Mdot
.954 .57324 Mdot
.954 .57327 Mdot
.954 .57331 Mdot
.954 .57343 Mdot
.954 .57343 Mdot
.954 .57349 Mdot
.954 .57356 Mdot
.954 .57373 Mdot
.954 .57373 Mdot
.954 .57374 Mdot
.954 .57374 Mdot
.954 .57375 Mdot
.954 .57376 Mdot
.954 .57433 Mdot
.954 .57456 Mdot
.954 .57521 Mdot
.954 .57525 Mdot
.954 .57525 Mdot
.954 .57534 Mdot
.954 .57567 Mdot
.954 .57573 Mdot
.954 .57585 Mdot
.954 .57592 Mdot
.954 .57607 Mdot
.954 .57609 Mdot
.954 .5761 Mdot
.954 .57616 Mdot
.954 .57619 Mdot
.954 .57626 Mdot
.954 .57627 Mdot
.954 .57628 Mdot
.954 .57631 Mdot
.954 .57633 Mdot
.954 .57638 Mdot
.954 .57638 Mdot
.954 .57641 Mdot
.954 .57641 Mdot
.954 .57642 Mdot
.954 .57642 Mdot
.954 .57642 Mdot
.954 .57642 Mdot
.954 .57643 Mdot
.954 .57643 Mdot
.956 .10826 Mdot
.956 .10826 Mdot
.956 .10827 Mdot
.956 .10828 Mdot
.956 .10838 Mdot
.956 .10862 Mdot
.956 .1089 Mdot
.956 .10908 Mdot
.956 .10925 Mdot
.956 .10946 Mdot
.956 .10948 Mdot
.956 .10954 Mdot
.956 .10955 Mdot
.956 .10989 Mdot
.956 .1099 Mdot
.956 .11009 Mdot
.956 .11013 Mdot
.956 .1114 Mdot
.956 .1115 Mdot
.956 .11171 Mdot
.956 .11173 Mdot
.956 .1119 Mdot
.956 .1119 Mdot
.956 .11191 Mdot
.956 .11192 Mdot
.956 .11224 Mdot
.956 .11224 Mdot
.956 .11232 Mdot
.956 .11232 Mdot
.956 .11233 Mdot
.956 .11235 Mdot
.956 .11236 Mdot
.956 .11238 Mdot
.956 .11243 Mdot
.956 .11246 Mdot
.956 .11247 Mdot
.956 .11248 Mdot
.956 .11274 Mdot
.956 .11286 Mdot
.956 .11335 Mdot
.956 .1134 Mdot
.956 .11352 Mdot
.956 .11357 Mdot
.956 .11377 Mdot
.956 .11394 Mdot
.956 .11418 Mdot
.956 .11467 Mdot
.956 .11476 Mdot
.956 .11499 Mdot
.956 .1152 Mdot
.956 .11523 Mdot
.956 .11529 Mdot
.956 .1155 Mdot
.956 .11559 Mdot
.956 .1169 Mdot
.956 .11707 Mdot
.956 .1173 Mdot
.956 .1177 Mdot
.956 .118 Mdot
.956 .11918 Mdot
.956 .12064 Mdot
.956 .12145 Mdot
.956 .12234 Mdot
.956 .12294 Mdot
.956 .12304 Mdot
.956 .1238 Mdot
.956 .12488 Mdot
.956 .12506 Mdot
.956 .12516 Mdot
.956 .1261 Mdot
.956 .12896 Mdot
.956 .12912 Mdot
.956 .12938 Mdot
.956 .12939 Mdot
.956 .12946 Mdot
.956 .1295 Mdot
.956 .12962 Mdot
.956 .13014 Mdot
.956 .13072 Mdot
.956 .13083 Mdot
.956 .13173 Mdot
.956 .13185 Mdot
.956 .13198 Mdot
.956 .13203 Mdot
.956 .1321 Mdot
.956 .13249 Mdot
.956 .13306 Mdot
.956 .13342 Mdot
.956 .13464 Mdot
.956 .13695 Mdot
.956 .13697 Mdot
.956 .13758 Mdot
.956 .13778 Mdot
.956 .13825 Mdot
.956 .13834 Mdot
.956 .13843 Mdot
.956 .13871 Mdot
.956 .13872 Mdot
.956 .13875 Mdot
.956 .13879 Mdot
.956 .13891 Mdot
.956 .13911 Mdot
.956 .13921 Mdot
.956 .13942 Mdot
.956 .13942 Mdot
.956 .13991 Mdot
.956 .14051 Mdot
.956 .14065 Mdot
.956 .14065 Mdot
.956 .14077 Mdot
.956 .14085 Mdot
.956 .1411 Mdot
.956 .14128 Mdot
.956 .14142 Mdot
.956 .14145 Mdot
.956 .14203 Mdot
.956 .14221 Mdot
.956 .14232 Mdot
.956 .14236 Mdot
.956 .14265 Mdot
.956 .14268 Mdot
.956 .14268 Mdot
.956 .14274 Mdot
.956 .14275 Mdot
.956 .14282 Mdot
.956 .14288 Mdot
.956 .14305 Mdot
.956 .14307 Mdot
.956 .14309 Mdot
.956 .1431 Mdot
.956 .14327 Mdot
.956 .14331 Mdot
.956 .14334 Mdot
.956 .14361 Mdot
.956 .14367 Mdot
.956 .14375 Mdot
.956 .1438 Mdot
.956 .14386 Mdot
.956 .14397 Mdot
.956 .14426 Mdot
.956 .14428 Mdot
.956 .14429 Mdot
.956 .14438 Mdot
.956 .14497 Mdot
.956 .1451 Mdot
.956 .14511 Mdot
.956 .14524 Mdot
.956 .1458 Mdot
.956 .14582 Mdot
.956 .14635 Mdot
.956 .14645 Mdot
.956 .14679 Mdot
.956 .14715 Mdot
.956 .14721 Mdot
.956 .14721 Mdot
.956 .14751 Mdot
.956 .14765 Mdot
.956 .14791 Mdot
.956 .1482 Mdot
.956 .14872 Mdot
.956 .14876 Mdot
.956 .14881 Mdot
.956 .14891 Mdot
.956 .14896 Mdot
.956 .14905 Mdot
.956 .14927 Mdot
.956 .14977 Mdot
.956 .14993 Mdot
.956 .15017 Mdot
.956 .15081 Mdot
.956 .15094 Mdot
.956 .15104 Mdot
.956 .15122 Mdot
.956 .1514 Mdot
.956 .15146 Mdot
.956 .15159 Mdot
.956 .15168 Mdot
.956 .15169 Mdot
.956 .15173 Mdot
.956 .15175 Mdot
.956 .15187 Mdot
.956 .15187 Mdot
.956 .15187 Mdot
.956 .15189 Mdot
.956 .15191 Mdot
.956 .15191 Mdot
.956 .15192 Mdot
.956 .15193 Mdot
.956 .15196 Mdot
.956 .15197 Mdot
.956 .15197 Mdot
.956 .15198 Mdot
.956 .15201 Mdot
.956 .1521 Mdot
.956 .15217 Mdot
.956 .15227 Mdot
.956 .15231 Mdot
.956 .15231 Mdot
.956 .15231 Mdot
.956 .15235 Mdot
.956 .15236 Mdot
.956 .15239 Mdot
.956 .15243 Mdot
.956 .15249 Mdot
.956 .15249 Mdot
.956 .15252 Mdot
.956 .15264 Mdot
.956 .15276 Mdot
.956 .15282 Mdot
.956 .15285 Mdot
.956 .15288 Mdot
.956 .15293 Mdot
.956 .153 Mdot
.956 .153 Mdot
.956 .15301 Mdot
.956 .15303 Mdot
.956 .15303 Mdot
.956 .15309 Mdot
.956 .15311 Mdot
.956 .15313 Mdot
.956 .1532 Mdot
.956 .1532 Mdot
.956 .15325 Mdot
.956 .15329 Mdot
.956 .15329 Mdot
.956 .15332 Mdot
.956 .15333 Mdot
.956 .15333 Mdot
.956 .15337 Mdot
.956 .15337 Mdot
.956 .15338 Mdot
.956 .15339 Mdot
.956 .15342 Mdot
.956 .15345 Mdot
.956 .15354 Mdot
.956 .15355 Mdot
.956 .15356 Mdot
.956 .15358 Mdot
.956 .1536 Mdot
.956 .15363 Mdot
.956 .15368 Mdot
.956 .15374 Mdot
.956 .15377 Mdot
.956 .15379 Mdot
.956 .15384 Mdot
.956 .15389 Mdot
.956 .15389 Mdot
.956 .15389 Mdot
.956 .15391 Mdot
.956 .15391 Mdot
.956 .15392 Mdot
.956 .15395 Mdot
.956 .15395 Mdot
.956 .15397 Mdot
.956 .15399 Mdot
.956 .15404 Mdot
.956 .15407 Mdot
.956 .15408 Mdot
.956 .15411 Mdot
.956 .15413 Mdot
.956 .15418 Mdot
.956 .15419 Mdot
.956 .15419 Mdot
.956 .15423 Mdot
.956 .15425 Mdot
.956 .15432 Mdot
.956 .1544 Mdot
.956 .15442 Mdot
.956 .15452 Mdot
.956 .15454 Mdot
.956 .15458 Mdot
.956 .15468 Mdot
.956 .15473 Mdot
.956 .15474 Mdot
.956 .15477 Mdot
.956 .15478 Mdot
.956 .15485 Mdot
.956 .15487 Mdot
.956 .15488 Mdot
.956 .1549 Mdot
.956 .15496 Mdot
.956 .15506 Mdot
.956 .15511 Mdot
.956 .15513 Mdot
.956 .15518 Mdot
.956 .15522 Mdot
.956 .15527 Mdot
.956 .15528 Mdot
.956 .15529 Mdot
.956 .15533 Mdot
.956 .15534 Mdot
.956 .15535 Mdot
.956 .15538 Mdot
.956 .15538 Mdot
.956 .15544 Mdot
.956 .15546 Mdot
.956 .15548 Mdot
.956 .15548 Mdot
.956 .15553 Mdot
.956 .15554 Mdot
.956 .15556 Mdot
.956 .15557 Mdot
.956 .15557 Mdot
.956 .15559 Mdot
.956 .1556 Mdot
.956 .1556 Mdot
.956 .15562 Mdot
.956 .15562 Mdot
.956 .15565 Mdot
.956 .15566 Mdot
.956 .15568 Mdot
.956 .15571 Mdot
.956 .15574 Mdot
.956 .15576 Mdot
.956 .15578 Mdot
.956 .15579 Mdot
.956 .15579 Mdot
.956 .1558 Mdot
.956 .15582 Mdot
.956 .15584 Mdot
.956 .15586 Mdot
.956 .15587 Mdot
.956 .15587 Mdot
.956 .15587 Mdot
.956 .15587 Mdot
.956 .15588 Mdot
.956 .15588 Mdot
.956 .15588 Mdot
.956 .15589 Mdot
.956 .15589 Mdot
.956 .15589 Mdot
.956 .15589 Mdot
.956 .15642 Mdot
.956 .1574 Mdot
.956 .15761 Mdot
.956 .15809 Mdot
.956 .15828 Mdot
.956 .15839 Mdot
.956 .1591 Mdot
.956 .15983 Mdot
.956 .16082 Mdot
.956 .16286 Mdot
.956 .16325 Mdot
.956 .1642 Mdot
.956 .1651 Mdot
.956 .16526 Mdot
.956 .16549 Mdot
.956 .16639 Mdot
.956 .16682 Mdot
.956 .17257 Mdot
.956 .17334 Mdot
.956 .17438 Mdot
.956 .17622 Mdot
.956 .17761 Mdot
.956 .1831 Mdot
.956 .18728 Mdot
.956 .19014 Mdot
.956 .19159 Mdot
.956 .19411 Mdot
.956 .19851 Mdot
.956 .20148 Mdot
.956 .20199 Mdot
.956 .20582 Mdot
.956 .21134 Mdot
.956 .21225 Mdot
.956 .21277 Mdot
.956 .21765 Mdot
.956 .23252 Mdot
.956 .23334 Mdot
.956 .23469 Mdot
.956 .23473 Mdot
.956 .2351 Mdot
.956 .23531 Mdot
.956 .23594 Mdot
.956 .23866 Mdot
.956 .24167 Mdot
.956 .24223 Mdot
.956 .24692 Mdot
.956 .24753 Mdot
.956 .2482 Mdot
.956 .24846 Mdot
.956 .24883 Mdot
.956 .25084 Mdot
.956 .25377 Mdot
.956 .25563 Mdot
.956 .26184 Mdot
.956 .26392 Mdot
.956 .27338 Mdot
.956 .27349 Mdot
.956 .27648 Mdot
.956 .27747 Mdot
.956 .27974 Mdot
.956 .28016 Mdot
.956 .28061 Mdot
.956 .28194 Mdot
.956 .28199 Mdot
.956 .28214 Mdot
.956 .28229 Mdot
.956 .28287 Mdot
.956 .28384 Mdot
.956 .28429 Mdot
.956 .28531 Mdot
.956 .28531 Mdot
.956 .28757 Mdot
.956 .29036 Mdot
.956 .291 Mdot
.956 .29101 Mdot
.956 .29157 Mdot
.956 .29193 Mdot
.956 .29304 Mdot
.956 .29388 Mdot
.956 .29451 Mdot
.956 .29462 Mdot
.956 .29724 Mdot
.956 .29801 Mdot
.956 .29848 Mdot
.956 .29867 Mdot
.956 .29996 Mdot
.956 .30008 Mdot
.956 .30008 Mdot
.956 .30034 Mdot
.956 .30035 Mdot
.956 .30066 Mdot
.956 .30093 Mdot
.956 .30165 Mdot
.956 .30175 Mdot
.956 .30185 Mdot
.956 .30189 Mdot
.956 .3026 Mdot
.956 .30277 Mdot
.956 .30293 Mdot
.956 .30404 Mdot
.956 .30433 Mdot
.956 .30463 Mdot
.956 .30486 Mdot
.956 .30511 Mdot
.956 .30555 Mdot
.956 .30678 Mdot
.956 .30686 Mdot
.956 .30688 Mdot
.956 .30729 Mdot
.956 .30969 Mdot
.956 .31023 Mdot
.956 .31027 Mdot
.956 .31076 Mdot
.956 .31302 Mdot
.956 .31306 Mdot
.956 .31514 Mdot
.956 .31553 Mdot
.956 .31604 Mdot
.956 .31681 Mdot
.956 .31817 Mdot
.956 .31839 Mdot
.956 .31839 Mdot
.956 .31949 Mdot
.956 .32002 Mdot
.956 .32095 Mdot
.956 .32201 Mdot
.956 .32382 Mdot
.956 .32399 Mdot
.956 .32415 Mdot
.956 .32451 Mdot
.956 .32468 Mdot
.956 .32498 Mdot
.956 .32574 Mdot
.956 .32729 Mdot
.956 .3274 Mdot
.956 .32741 Mdot
.956 .32744 Mdot
.956 .32793 Mdot
.956 .32871 Mdot
.956 .32894 Mdot
.956 .33078 Mdot
.956 .33117 Mdot
.956 .33139 Mdot
.956 .33148 Mdot
.956 .33169 Mdot
.956 .33205 Mdot
.956 .33259 Mdot
.956 .33278 Mdot
.956 .33291 Mdot
.956 .33293 Mdot
.956 .33317 Mdot
.956 .33344 Mdot
.956 .33348 Mdot
.956 .33359 Mdot
.956 .33364 Mdot
.956 .33367 Mdot
.956 .334 Mdot
.956 .334 Mdot
.956 .33402 Mdot
.956 .33405 Mdot
.956 .33411 Mdot
.956 .33411 Mdot
.956 .33416 Mdot
.956 .33417 Mdot
.956 .33427 Mdot
.956 .33429 Mdot
.956 .3343 Mdot
.956 .33432 Mdot
.956 .33443 Mdot
.956 .33467 Mdot
.956 .33487 Mdot
.956 .33506 Mdot
.956 .33517 Mdot
.956 .33528 Mdot
.956 .3353 Mdot
.956 .3353 Mdot
.956 .33539 Mdot
.956 .33544 Mdot
.956 .33552 Mdot
.956 .33562 Mdot
.956 .3358 Mdot
.956 .33581 Mdot
.956 .33588 Mdot
.956 .33591 Mdot
.956 .33623 Mdot
.956 .33657 Mdot
.956 .33674 Mdot
.956 .33682 Mdot
.956 .3369 Mdot
.956 .33704 Mdot
.956 .33723 Mdot
.956 .33725 Mdot
.956 .33727 Mdot
.956 .33732 Mdot
.956 .33732 Mdot
.956 .33749 Mdot
.956 .33754 Mdot
.956 .33759 Mdot
.956 .33778 Mdot
.956 .33779 Mdot
.956 .33779 Mdot
.956 .33792 Mdot
.956 .33802 Mdot
.956 .33803 Mdot
.956 .33812 Mdot
.956 .33814 Mdot
.956 .33815 Mdot
.956 .33824 Mdot
.956 .33826 Mdot
.956 .33829 Mdot
.956 .3383 Mdot
.956 .33839 Mdot
.956 .33847 Mdot
.956 .33871 Mdot
.956 .33874 Mdot
.956 .33875 Mdot
.956 .33881 Mdot
.956 .33886 Mdot
.956 .339 Mdot
.956 .33908 Mdot
.956 .33924 Mdot
.956 .33933 Mdot
.956 .33936 Mdot
.956 .3395 Mdot
.956 .33962 Mdot
.956 .33964 Mdot
.956 .33964 Mdot
.956 .33968 Mdot
.956 .33969 Mdot
.956 .33971 Mdot
.956 .33978 Mdot
.956 .33979 Mdot
.956 .33984 Mdot
.956 .3399 Mdot
.956 .34002 Mdot
.956 .34009 Mdot
.956 .34012 Mdot
.956 .34019 Mdot
.956 .34026 Mdot
.956 .34039 Mdot
.956 .3404 Mdot
.956 .34041 Mdot
.956 .3405 Mdot
.956 .34055 Mdot
.956 .34066 Mdot
.956 .34073 Mdot
.956 .34095 Mdot
.956 .341 Mdot
.956 .34125 Mdot
.956 .34129 Mdot
.956 .34138 Mdot
.956 .34163 Mdot
.956 .34168 Mdot
.956 .34177 Mdot
.956 .34178 Mdot
.956 .34186 Mdot
.956 .34189 Mdot
.956 .34206 Mdot
.956 .34211 Mdot
.956 .34212 Mdot
.956 .34219 Mdot
.956 .34232 Mdot
.956 .34256 Mdot
.956 .34268 Mdot
.956 .34273 Mdot
.956 .34285 Mdot
.956 .34286 Mdot
.956 .34296 Mdot
.956 .34308 Mdot
.956 .34309 Mdot
.956 .34312 Mdot
.956 .3432 Mdot
.956 .34321 Mdot
.956 .34323 Mdot
.956 .34326 Mdot
.956 .34329 Mdot
.956 .34332 Mdot
.956 .34334 Mdot
.956 .34347 Mdot
.956 .3435 Mdot
.956 .34355 Mdot
.956 .34356 Mdot
.956 .34367 Mdot
.956 .3437 Mdot
.956 .34374 Mdot
.956 .34377 Mdot
.956 .34377 Mdot
.956 .34381 Mdot
.956 .34383 Mdot
.956 .34384 Mdot
.956 .34387 Mdot
.956 .34388 Mdot
.956 .34396 Mdot
.956 .34398 Mdot
.956 .34403 Mdot
.956 .34409 Mdot
.956 .34416 Mdot
.956 .34421 Mdot
.956 .34424 Mdot
.956 .34427 Mdot
.956 .34427 Mdot
.956 .34429 Mdot
.956 .34435 Mdot
.956 .34438 Mdot
.956 .34442 Mdot
.956 .34444 Mdot
.956 .34445 Mdot
.956 .34445 Mdot
.956 .34445 Mdot
.956 .34447 Mdot
.956 .34447 Mdot
.956 .34448 Mdot
.956 .34449 Mdot
.956 .34449 Mdot
.956 .3445 Mdot
.956 .3445 Mdot
.956 .34566 Mdot
.956 .34743 Mdot
.956 .34769 Mdot
.956 .348 Mdot
.956 .34811 Mdot
.956 .34901 Mdot
.956 .34936 Mdot
.956 .34956 Mdot
.956 .34975 Mdot
.956 .3508 Mdot
.956 .35177 Mdot
.956 .35196 Mdot
.956 .352 Mdot
.956 .35339 Mdot
.956 .35403 Mdot
.956 .35535 Mdot
.956 .35581 Mdot
.956 .35619 Mdot
.956 .35682 Mdot
.956 .35687 Mdot
.956 .35699 Mdot
.956 .35725 Mdot
.956 .35749 Mdot
.956 .35762 Mdot
.956 .35771 Mdot
.956 .35781 Mdot
.956 .35784 Mdot
.956 .3579 Mdot
.956 .35827 Mdot
.956 .35843 Mdot
.956 .35879 Mdot
.956 .39479 Mdot
.956 .39677 Mdot
.956 .40058 Mdot
.956 .40704 Mdot
.956 .40722 Mdot
.956 .40901 Mdot
.956 .41007 Mdot
.956 .41316 Mdot
.956 .42677 Mdot
.956 .44231 Mdot
.956 .44521 Mdot
.956 .46327 Mdot
.956 .46963 Mdot
.956 .47274 Mdot
.956 .47618 Mdot
.956 .47753 Mdot
.956 .47919 Mdot
.956 .47938 Mdot
.956 .48454 Mdot
.956 .4895 Mdot
.956 .49342 Mdot
.956 .4943 Mdot
.956 .50368 Mdot
.956 .51227 Mdot
.956 .52381 Mdot
.956 .53792 Mdot
.956 .53881 Mdot
.956 .54526 Mdot
.956 .54575 Mdot
.956 .54588 Mdot
.956 .54588 Mdot
.956 .54588 Mdot
.956 .54588 Mdot
.956 .54588 Mdot
.956 .54588 Mdot
.956 .54588 Mdot
.956 .54589 Mdot
.956 .54589 Mdot
.956 .54589 Mdot
.956 .54589 Mdot
.956 .54589 Mdot
.956 .54589 Mdot
.956 .5459 Mdot
.956 .5459 Mdot
.956 .54591 Mdot
.956 .54591 Mdot
.956 .54591 Mdot
.956 .54591 Mdot
.956 .54592 Mdot
.956 .54593 Mdot
.956 .54593 Mdot
.956 .54594 Mdot
.956 .54594 Mdot
.956 .54595 Mdot
.956 .54595 Mdot
.956 .54595 Mdot
.956 .54596 Mdot
.956 .54596 Mdot
.956 .54596 Mdot
.956 .54596 Mdot
.956 .54596 Mdot
.956 .54597 Mdot
.956 .54597 Mdot
.956 .54598 Mdot
.956 .54598 Mdot
.956 .54599 Mdot
.956 .54601 Mdot
.956 .54601 Mdot
.956 .54602 Mdot
.956 .54602 Mdot
.956 .54602 Mdot
.956 .54603 Mdot
.956 .54603 Mdot
.956 .54604 Mdot
.956 .54605 Mdot
.956 .54606 Mdot
.956 .54607 Mdot
.956 .54608 Mdot
.956 .54609 Mdot
.956 .54613 Mdot
.956 .54614 Mdot
.956 .54614 Mdot
.956 .54614 Mdot
.956 .54616 Mdot
.956 .54616 Mdot
.956 .54617 Mdot
.956 .54617 Mdot
.956 .54619 Mdot
.956 .54621 Mdot
.956 .54622 Mdot
.956 .54623 Mdot
.956 .54625 Mdot
.956 .54626 Mdot
.956 .54628 Mdot
.956 .5463 Mdot
.956 .5463 Mdot
.956 .54631 Mdot
.956 .54631 Mdot
.956 .54631 Mdot
.956 .54633 Mdot
.956 .54633 Mdot
.956 .54634 Mdot
.956 .54634 Mdot
.956 .54635 Mdot
.956 .54636 Mdot
.956 .54637 Mdot
.956 .54637 Mdot
.956 .54637 Mdot
.956 .54638 Mdot
.956 .54638 Mdot
.956 .54639 Mdot
.956 .54639 Mdot
.956 .54641 Mdot
.956 .54642 Mdot
.956 .54644 Mdot
.956 .54645 Mdot
.956 .54646 Mdot
.956 .54647 Mdot
.956 .54647 Mdot
.956 .54648 Mdot
.956 .54652 Mdot
.956 .54652 Mdot
.956 .54652 Mdot
.956 .54652 Mdot
.956 .54653 Mdot
.956 .54654 Mdot
.956 .54655 Mdot
.956 .54656 Mdot
.956 .54656 Mdot
.956 .54658 Mdot
.956 .54659 Mdot
.956 .54659 Mdot
.956 .54661 Mdot
.956 .54661 Mdot
.956 .54661 Mdot
.956 .54663 Mdot
.956 .54665 Mdot
.956 .54665 Mdot
.956 .54666 Mdot
.956 .54668 Mdot
.956 .54671 Mdot
.956 .54674 Mdot
.956 .54675 Mdot
.956 .54675 Mdot
.956 .54676 Mdot
.956 .54677 Mdot
.956 .54678 Mdot
.956 .54678 Mdot
.956 .54679 Mdot
.956 .54679 Mdot
.956 .54679 Mdot
.956 .5468 Mdot
.956 .54683 Mdot
.956 .54685 Mdot
.956 .54687 Mdot
.956 .54688 Mdot
.956 .54688 Mdot
.956 .54688 Mdot
.956 .54688 Mdot
.956 .54689 Mdot
.956 .54689 Mdot
.956 .5469 Mdot
.956 .5469 Mdot
.956 .5469 Mdot
.956 .54691 Mdot
.956 .54691 Mdot
.956 .54691 Mdot
.956 .54698 Mdot
.956 .54701 Mdot
.956 .54703 Mdot
.956 .54708 Mdot
.956 .54718 Mdot
.956 .54742 Mdot
.956 .54759 Mdot
.956 .54765 Mdot
.956 .54767 Mdot
.956 .54769 Mdot
.956 .54771 Mdot
.956 .54773 Mdot
.956 .54774 Mdot
.956 .54788 Mdot
.956 .54796 Mdot
.956 .54803 Mdot
.956 .54807 Mdot
.956 .54815 Mdot
.956 .54815 Mdot
.956 .54816 Mdot
.956 .54826 Mdot
.956 .54836 Mdot
.956 .54838 Mdot
.956 .54853 Mdot
.956 .54853 Mdot
.956 .54869 Mdot
.956 .54873 Mdot
.956 .54893 Mdot
.956 .54897 Mdot
.956 .54905 Mdot
.956 .54908 Mdot
.956 .5491 Mdot
.956 .54911 Mdot
.956 .54913 Mdot
.956 .54915 Mdot
.956 .54923 Mdot
.956 .54924 Mdot
.956 .54925 Mdot
.956 .5493 Mdot
.956 .5493 Mdot
.956 .54936 Mdot
.956 .5494 Mdot
.956 .54942 Mdot
.956 .54942 Mdot
.956 .54943 Mdot
.956 .54951 Mdot
.956 .54952 Mdot
.956 .54956 Mdot
.956 .54979 Mdot
.956 .54983 Mdot
.956 .54988 Mdot
.956 .54998 Mdot
.956 .55001 Mdot
.956 .55001 Mdot
.956 .55006 Mdot
.956 .55038 Mdot
.956 .55038 Mdot
.956 .55045 Mdot
.956 .55054 Mdot
.956 .55068 Mdot
.956 .55071 Mdot
.956 .55074 Mdot
.956 .55088 Mdot
.956 .55095 Mdot
.956 .55114 Mdot
.956 .55115 Mdot
.956 .55189 Mdot
.956 .55229 Mdot
.956 .55241 Mdot
.956 .55261 Mdot
.956 .55274 Mdot
.956 .55276 Mdot
.956 .55278 Mdot
.956 .55283 Mdot
.956 .55287 Mdot
.956 .55318 Mdot
.956 .55322 Mdot
.956 .55343 Mdot
.956 .55361 Mdot
.956 .55366 Mdot
.956 .55367 Mdot
.956 .5537 Mdot
.956 .5537 Mdot
.956 .5538 Mdot
.956 .55385 Mdot
.956 .55495 Mdot
.956 .55533 Mdot
.956 .55537 Mdot
.956 .55544 Mdot
.956 .5559 Mdot
.956 .55622 Mdot
.956 .55627 Mdot
.956 .55653 Mdot
.956 .55693 Mdot
.956 .55732 Mdot
.956 .55804 Mdot
.956 .55866 Mdot
.956 .55882 Mdot
.956 .55904 Mdot
.956 .55918 Mdot
.956 .55927 Mdot
.956 .56005 Mdot
.956 .56011 Mdot
.956 .56025 Mdot
.956 .56028 Mdot
.956 .56031 Mdot
.956 .56044 Mdot
.956 .56059 Mdot
.956 .56065 Mdot
.956 .56099 Mdot
.956 .56115 Mdot
.956 .56128 Mdot
.956 .56143 Mdot
.956 .56146 Mdot
.956 .56155 Mdot
.956 .56159 Mdot
.956 .56197 Mdot
.956 .56207 Mdot
.956 .56229 Mdot
.956 .56239 Mdot
.956 .56242 Mdot
.956 .56277 Mdot
.956 .56277 Mdot
.956 .56278 Mdot
.956 .56294 Mdot
.956 .56471 Mdot
.956 .56497 Mdot
.956 .56562 Mdot
.956 .56665 Mdot
.956 .56933 Mdot
.956 .56952 Mdot
.956 .56998 Mdot
.956 .57011 Mdot
.956 .57085 Mdot
.956 .5718 Mdot
.956 .57296 Mdot
.956 .57331 Mdot
.956 .57373 Mdot
.956 .57385 Mdot
.956 .57386 Mdot
.956 .57443 Mdot
.956 .57478 Mdot
.956 .57642 Mdot
.956 .57654 Mdot
.956 .57677 Mdot
.956 .57699 Mdot
.956 .57736 Mdot
.956 .57736 Mdot
.956 .57743 Mdot
.956 .57745 Mdot
.956 .57748 Mdot
.956 .5775 Mdot
.956 .57755 Mdot
.956 .57758 Mdot
.956 .5776 Mdot
.958 .10846 Mdot
.958 .10846 Mdot
.958 .10853 Mdot
.958 .10857 Mdot
.958 .10857 Mdot
.958 .10858 Mdot
.958 .10859 Mdot
.958 .1086 Mdot
.958 .10864 Mdot
.958 .10869 Mdot
.958 .1089 Mdot
.958 .10891 Mdot
.958 .10895 Mdot
.958 .10896 Mdot
.958 .10898 Mdot
.958 .10911 Mdot
.958 .10917 Mdot
.958 .10928 Mdot
.958 .10932 Mdot
.958 .10933 Mdot
.958 .10934 Mdot
.958 .10937 Mdot
.958 .1096 Mdot
.958 .1097 Mdot
.958 .10978 Mdot
.958 .10978 Mdot
.958 .11001 Mdot
.958 .11018 Mdot
.958 .1102 Mdot
.958 .11024 Mdot
.958 .11024 Mdot
.958 .11034 Mdot
.958 .11045 Mdot
.958 .1106 Mdot
.958 .11063 Mdot
.958 .11081 Mdot
.958 .11085 Mdot
.958 .11089 Mdot
.958 .11089 Mdot
.958 .1109 Mdot
.958 .11092 Mdot
.958 .11103 Mdot
.958 .1111 Mdot
.958 .11127 Mdot
.958 .11127 Mdot
.958 .11134 Mdot
.958 .11136 Mdot
.958 .11143 Mdot
.958 .11147 Mdot
.958 .11152 Mdot
.958 .11162 Mdot
.958 .1117 Mdot
.958 .11176 Mdot
.958 .11191 Mdot
.958 .11203 Mdot
.958 .11204 Mdot
.958 .11205 Mdot
.958 .11205 Mdot
.958 .11212 Mdot
.958 .11225 Mdot
.958 .11228 Mdot
.958 .11229 Mdot
.958 .11229 Mdot
.958 .11232 Mdot
.958 .11244 Mdot
.958 .11247 Mdot
.958 .11255 Mdot
.958 .11276 Mdot
.958 .11284 Mdot
.958 .11305 Mdot
.958 .11306 Mdot
.958 .11307 Mdot
.958 .11308 Mdot
.958 .11309 Mdot
.958 .11309 Mdot
.958 .11337 Mdot
.958 .11338 Mdot
.958 .11348 Mdot
.958 .11358 Mdot
.958 .11362 Mdot
.958 .11368 Mdot
.958 .11556 Mdot
.958 .11573 Mdot
.958 .11632 Mdot
.958 .11723 Mdot
.958 .11811 Mdot
.958 .11826 Mdot
.958 .11908 Mdot
.958 .11974 Mdot
.958 .11988 Mdot
.958 .1207 Mdot
.958 .12082 Mdot
.958 .12113 Mdot
.958 .12114 Mdot
.958 .12119 Mdot
.958 .12126 Mdot
.958 .1213 Mdot
.958 .12137 Mdot
.958 .12177 Mdot
.958 .12227 Mdot
.958 .1224 Mdot
.958 .12248 Mdot
.958 .12262 Mdot
.958 .12296 Mdot
.958 .12301 Mdot
.958 .1234 Mdot
.958 .12344 Mdot
.958 .12346 Mdot
.958 .12365 Mdot
.958 .12374 Mdot
.958 .12419 Mdot
.958 .12424 Mdot
.958 .1244 Mdot
.958 .12515 Mdot
.958 .12547 Mdot
.958 .126 Mdot
.958 .12609 Mdot
.958 .12617 Mdot
.958 .12626 Mdot
.958 .12645 Mdot
.958 .12658 Mdot
.958 .12666 Mdot
.958 .12667 Mdot
.958 .1268 Mdot
.958 .1268 Mdot
.958 .12703 Mdot
.958 .12755 Mdot
.958 .12756 Mdot
.958 .12759 Mdot
.958 .12766 Mdot
.958 .12773 Mdot
.958 .12773 Mdot
.958 .12802 Mdot
.958 .12846 Mdot
.958 .12851 Mdot
.958 .12884 Mdot
.958 .12924 Mdot
.958 .12934 Mdot
.958 .12936 Mdot
.958 .12944 Mdot
.958 .12957 Mdot
.958 .12982 Mdot
.958 .12987 Mdot
.958 .13003 Mdot
.958 .13022 Mdot
.958 .13076 Mdot
.958 .13099 Mdot
.958 .13115 Mdot
.958 .13167 Mdot
.958 .13294 Mdot
.958 .13313 Mdot
.958 .13374 Mdot
.958 .13384 Mdot
.958 .13393 Mdot
.958 .13399 Mdot
.958 .13449 Mdot
.958 .13505 Mdot
.958 .13512 Mdot
.958 .13528 Mdot
.958 .13558 Mdot
.958 .13614 Mdot
.958 .13646 Mdot
.958 .13659 Mdot
.958 .13675 Mdot
.958 .13689 Mdot
.958 .13706 Mdot
.958 .13717 Mdot
.958 .13719 Mdot
.958 .13725 Mdot
.958 .13728 Mdot
.958 .13769 Mdot
.958 .13789 Mdot
.958 .13797 Mdot
.958 .13805 Mdot
.958 .13813 Mdot
.958 .13825 Mdot
.958 .13838 Mdot
.958 .13844 Mdot
.958 .13926 Mdot
.958 .13931 Mdot
.958 .13962 Mdot
.958 .13963 Mdot
.958 .13986 Mdot
.958 .13992 Mdot
.958 .13999 Mdot
.958 .14001 Mdot
.958 .14002 Mdot
.958 .14006 Mdot
.958 .14011 Mdot
.958 .14014 Mdot
.958 .14025 Mdot
.958 .14039 Mdot
.958 .1404 Mdot
.958 .14041 Mdot
.958 .14058 Mdot
.958 .14062 Mdot
.958 .14097 Mdot
.958 .14102 Mdot
.958 .14104 Mdot
.958 .14112 Mdot
.958 .14114 Mdot
.958 .14127 Mdot
.958 .14131 Mdot
.958 .14134 Mdot
.958 .14138 Mdot
.958 .14156 Mdot
.958 .14177 Mdot
.958 .14182 Mdot
.958 .14202 Mdot
.958 .14217 Mdot
.958 .1423 Mdot
.958 .1423 Mdot
.958 .14235 Mdot
.958 .14239 Mdot
.958 .14248 Mdot
.958 .14248 Mdot
.958 .14253 Mdot
.958 .14257 Mdot
.958 .1426 Mdot
.958 .14264 Mdot
.958 .14272 Mdot
.958 .14276 Mdot
.958 .14276 Mdot
.958 .14293 Mdot
.958 .14316 Mdot
.958 .14324 Mdot
.958 .14333 Mdot
.958 .14351 Mdot
.958 .14357 Mdot
.958 .14388 Mdot
.958 .14413 Mdot
.958 .14413 Mdot
.958 .14414 Mdot
.958 .14495 Mdot
.958 .14495 Mdot
.958 .14521 Mdot
.958 .14538 Mdot
.958 .14556 Mdot
.958 .14564 Mdot
.958 .14579 Mdot
.958 .14579 Mdot
.958 .14613 Mdot
.958 .14614 Mdot
.958 .14633 Mdot
.958 .14635 Mdot
.958 .14637 Mdot
.958 .14643 Mdot
.958 .14649 Mdot
.958 .14652 Mdot
.958 .14654 Mdot
.958 .14672 Mdot
.958 .14709 Mdot
.958 .14711 Mdot
.958 .14715 Mdot
.958 .14719 Mdot
.958 .14725 Mdot
.958 .14734 Mdot
.958 .14758 Mdot
.958 .1477 Mdot
.958 .14772 Mdot
.958 .14773 Mdot
.958 .14784 Mdot
.958 .148 Mdot
.958 .14815 Mdot
.958 .14817 Mdot
.958 .14819 Mdot
.958 .14827 Mdot
.958 .14863 Mdot
.958 .14867 Mdot
.958 .14889 Mdot
.958 .1489 Mdot
.958 .14894 Mdot
.958 .14898 Mdot
.958 .14898 Mdot
.958 .14899 Mdot
.958 .14906 Mdot
.958 .14943 Mdot
.958 .14949 Mdot
.958 .14955 Mdot
.958 .14956 Mdot
.958 .14956 Mdot
.958 .14962 Mdot
.958 .14968 Mdot
.958 .14977 Mdot
.958 .14983 Mdot
.958 .14991 Mdot
.958 .15014 Mdot
.958 .15019 Mdot
.958 .15023 Mdot
.958 .15031 Mdot
.958 .15032 Mdot
.958 .15032 Mdot
.958 .15036 Mdot
.958 .1504 Mdot
.958 .15052 Mdot
.958 .15059 Mdot
.958 .15085 Mdot
.958 .15086 Mdot
.958 .15089 Mdot
.958 .15096 Mdot
.958 .15102 Mdot
.958 .15112 Mdot
.958 .15118 Mdot
.958 .15119 Mdot
.958 .1512 Mdot
.958 .15124 Mdot
.958 .15129 Mdot
.958 .15131 Mdot
.958 .1514 Mdot
.958 .15142 Mdot
.958 .15144 Mdot
.958 .15154 Mdot
.958 .15155 Mdot
.958 .15166 Mdot
.958 .15172 Mdot
.958 .15176 Mdot
.958 .15178 Mdot
.958 .15178 Mdot
.958 .15182 Mdot
.958 .15182 Mdot
.958 .152 Mdot
.958 .15245 Mdot
.958 .15249 Mdot
.958 .15255 Mdot
.958 .15255 Mdot
.958 .1528 Mdot
.958 .15333 Mdot
.958 .15344 Mdot
.958 .15347 Mdot
.958 .15349 Mdot
.958 .15359 Mdot
.958 .15407 Mdot
.958 .15418 Mdot
.958 .15451 Mdot
.958 .15534 Mdot
.958 .15564 Mdot
.958 .15649 Mdot
.958 .15651 Mdot
.958 .15656 Mdot
.958 .15659 Mdot
.958 .15664 Mdot
.958 .15664 Mdot
.958 .15778 Mdot
.958 .1578 Mdot
.958 .15822 Mdot
.958 .15863 Mdot
.958 .1588 Mdot
.958 .15904 Mdot
.958 .16699 Mdot
.958 .16773 Mdot
.958 .17031 Mdot
.958 .17442 Mdot
.958 .17844 Mdot
.958 .17917 Mdot
.958 .18293 Mdot
.958 .18301 Mdot
.958 .18612 Mdot
.958 .18684 Mdot
.958 .19061 Mdot
.958 .1908 Mdot
.958 .19138 Mdot
.958 .19286 Mdot
.958 .19295 Mdot
.958 .1932 Mdot
.958 .19351 Mdot
.958 .19373 Mdot
.958 .19406 Mdot
.958 .19602 Mdot
.958 .19851 Mdot
.958 .1992 Mdot
.958 .19956 Mdot
.958 .20029 Mdot
.958 .20199 Mdot
.958 .20223 Mdot
.958 .20424 Mdot
.958 .20442 Mdot
.958 .20451 Mdot
.958 .20546 Mdot
.958 .20596 Mdot
.958 .20824 Mdot
.958 .20846 Mdot
.958 .20933 Mdot
.958 .21316 Mdot
.958 .21481 Mdot
.958 .21631 Mdot
.958 .21752 Mdot
.958 .21803 Mdot
.958 .21841 Mdot
.958 .21887 Mdot
.958 .21989 Mdot
.958 .22054 Mdot
.958 .22096 Mdot
.958 .22102 Mdot
.958 .22167 Mdot
.958 .22169 Mdot
.958 .2229 Mdot
.958 .22561 Mdot
.958 .22566 Mdot
.958 .22582 Mdot
.958 .22616 Mdot
.958 .22656 Mdot
.958 .22656 Mdot
.958 .22803 Mdot
.958 .23034 Mdot
.958 .23062 Mdot
.958 .23235 Mdot
.958 .23441 Mdot
.958 .23492 Mdot
.958 .23505 Mdot
.958 .23547 Mdot
.958 .23613 Mdot
.958 .23747 Mdot
.958 .23769 Mdot
.958 .23855 Mdot
.958 .23957 Mdot
.958 .24195 Mdot
.958 .24198 Mdot
.958 .24236 Mdot
.958 .24357 Mdot
.958 .2444 Mdot
.958 .24709 Mdot
.958 .24841 Mdot
.958 .25368 Mdot
.958 .25463 Mdot
.958 .25779 Mdot
.958 .25827 Mdot
.958 .25877 Mdot
.958 .25907 Mdot
.958 .25907 Mdot
.958 .26162 Mdot
.958 .26444 Mdot
.958 .26479 Mdot
.958 .26562 Mdot
.958 .26715 Mdot
.958 .26949 Mdot
.958 .26992 Mdot
.958 .2715 Mdot
.958 .27217 Mdot
.958 .27295 Mdot
.958 .27363 Mdot
.958 .27449 Mdot
.958 .27503 Mdot
.958 .27511 Mdot
.958 .27543 Mdot
.958 .27557 Mdot
.958 .27754 Mdot
.958 .27855 Mdot
.958 .27893 Mdot
.958 .27934 Mdot
.958 .27968 Mdot
.958 .28029 Mdot
.958 .28092 Mdot
.958 .28119 Mdot
.958 .2851 Mdot
.958 .28532 Mdot
.958 .28682 Mdot
.958 .28683 Mdot
.958 .28794 Mdot
.958 .2882 Mdot
.958 .28854 Mdot
.958 .28864 Mdot
.958 .28867 Mdot
.958 .28887 Mdot
.958 .28911 Mdot
.958 .2892 Mdot
.958 .28972 Mdot
.958 .29037 Mdot
.958 .29041 Mdot
.958 .29048 Mdot
.958 .29125 Mdot
.958 .29147 Mdot
.958 .29304 Mdot
.958 .29325 Mdot
.958 .29337 Mdot
.958 .29373 Mdot
.958 .29384 Mdot
.958 .29443 Mdot
.958 .29459 Mdot
.958 .29474 Mdot
.958 .2949 Mdot
.958 .29573 Mdot
.958 .29667 Mdot
.958 .29688 Mdot
.958 .29776 Mdot
.958 .29844 Mdot
.958 .29899 Mdot
.958 .29899 Mdot
.958 .29923 Mdot
.958 .2994 Mdot
.958 .29978 Mdot
.958 .29981 Mdot
.958 .30002 Mdot
.958 .30019 Mdot
.958 .30031 Mdot
.958 .3005 Mdot
.958 .30086 Mdot
.958 .301 Mdot
.958 .30101 Mdot
.958 .30176 Mdot
.958 .30275 Mdot
.958 .30309 Mdot
.958 .30348 Mdot
.958 .30423 Mdot
.958 .30448 Mdot
.958 .30579 Mdot
.958 .30684 Mdot
.958 .30687 Mdot
.958 .30687 Mdot
.958 .31021 Mdot
.958 .31023 Mdot
.958 .31128 Mdot
.958 .31196 Mdot
.958 .31266 Mdot
.958 .31298 Mdot
.958 .31359 Mdot
.958 .3136 Mdot
.958 .31493 Mdot
.958 .31494 Mdot
.958 .3157 Mdot
.958 .31577 Mdot
.958 .31584 Mdot
.958 .31606 Mdot
.958 .31631 Mdot
.958 .31642 Mdot
.958 .31648 Mdot
.958 .31717 Mdot
.958 .31857 Mdot
.958 .31866 Mdot
.958 .3188 Mdot
.958 .31895 Mdot
.958 .31916 Mdot
.958 .31953 Mdot
.958 .3204 Mdot
.958 .32084 Mdot
.958 .3209 Mdot
.958 .32094 Mdot
.958 .32135 Mdot
.958 .32194 Mdot
.958 .32247 Mdot
.958 .32253 Mdot
.958 .32261 Mdot
.958 .3229 Mdot
.958 .32416 Mdot
.958 .32432 Mdot
.958 .32506 Mdot
.958 .32511 Mdot
.958 .32526 Mdot
.958 .32537 Mdot
.958 .3254 Mdot
.958 .32543 Mdot
.958 .32567 Mdot
.958 .32691 Mdot
.958 .32713 Mdot
.958 .32734 Mdot
.958 .32734 Mdot
.958 .32737 Mdot
.958 .32755 Mdot
.958 .32772 Mdot
.958 .32772 Mdot
.958 .32774 Mdot
.958 .32776 Mdot
.958 .32776 Mdot
.958 .32777 Mdot
.958 .32789 Mdot
.958 .32795 Mdot
.958 .32795 Mdot
.958 .32803 Mdot
.958 .32807 Mdot
.958 .3281 Mdot
.958 .32811 Mdot
.958 .32826 Mdot
.958 .32852 Mdot
.958 .32857 Mdot
.958 .32895 Mdot
.958 .32916 Mdot
.958 .32927 Mdot
.958 .3293 Mdot
.958 .32932 Mdot
.958 .32944 Mdot
.958 .32947 Mdot
.958 .32957 Mdot
.958 .3296 Mdot
.958 .32982 Mdot
.958 .32986 Mdot
.958 .32987 Mdot
.958 .33 Mdot
.958 .33011 Mdot
.958 .33018 Mdot
.958 .33052 Mdot
.958 .33072 Mdot
.958 .33154 Mdot
.958 .33157 Mdot
.958 .33164 Mdot
.958 .33168 Mdot
.958 .33191 Mdot
.958 .33207 Mdot
.958 .33239 Mdot
.958 .33258 Mdot
.958 .33261 Mdot
.958 .33264 Mdot
.958 .33277 Mdot
.958 .33293 Mdot
.958 .33297 Mdot
.958 .33327 Mdot
.958 .33331 Mdot
.958 .33335 Mdot
.958 .33338 Mdot
.958 .33365 Mdot
.958 .33367 Mdot
.958 .33371 Mdot
.958 .33402 Mdot
.958 .33404 Mdot
.958 .33421 Mdot
.958 .33427 Mdot
.958 .33434 Mdot
.958 .3344 Mdot
.958 .33441 Mdot
.958 .33451 Mdot
.958 .33453 Mdot
.958 .33463 Mdot
.958 .33492 Mdot
.958 .33493 Mdot
.958 .33503 Mdot
.958 .33506 Mdot
.958 .33636 Mdot
.958 .3364 Mdot
.958 .33648 Mdot
.958 .33665 Mdot
.958 .33666 Mdot
.958 .3367 Mdot
.958 .33685 Mdot
.958 .33736 Mdot
.958 .33759 Mdot
.958 .3378 Mdot
.958 .33784 Mdot
.958 .33883 Mdot
.958 .33911 Mdot
.958 .33919 Mdot
.958 .33925 Mdot
.958 .33952 Mdot
.958 .34077 Mdot
.958 .34083 Mdot
.958 .34107 Mdot
.958 .3419 Mdot
.958 .34205 Mdot
.958 .34217 Mdot
.958 .34298 Mdot
.958 .34302 Mdot
.958 .34357 Mdot
.958 .34392 Mdot
.958 .34398 Mdot
.958 .34463 Mdot
.958 .3448 Mdot
.958 .34576 Mdot
.958 .34651 Mdot
.958 .34655 Mdot
.958 .34666 Mdot
.958 .34673 Mdot
.958 .34683 Mdot
.958 .34683 Mdot
.958 .34694 Mdot
.958 .34825 Mdot
.958 .34836 Mdot
.958 .34912 Mdot
.958 .34916 Mdot
.958 .34969 Mdot
.958 .34994 Mdot
.958 .35069 Mdot
.958 .35098 Mdot
.958 .35129 Mdot
.958 .3514 Mdot
.958 .35156 Mdot
.958 .35279 Mdot
.958 .35299 Mdot
.958 .35306 Mdot
.958 .35386 Mdot
.958 .35432 Mdot
.958 .35495 Mdot
.958 .35501 Mdot
.958 .35603 Mdot
.958 .35751 Mdot
.958 .35829 Mdot
.958 .3589 Mdot
.958 .3592 Mdot
.958 .35939 Mdot
.958 .35939 Mdot
.958 .36845 Mdot
.958 .36865 Mdot
.958 .36925 Mdot
.958 .37054 Mdot
.958 .37206 Mdot
.958 .37208 Mdot
.958 .37211 Mdot
.958 .37795 Mdot
.958 .38774 Mdot
.958 .38899 Mdot
.958 .39403 Mdot
.958 .3968 Mdot
.958 .39856 Mdot
.958 .40651 Mdot
.958 .40898 Mdot
.958 .40959 Mdot
.958 .41165 Mdot
.958 .4149 Mdot
.958 .41491 Mdot
.958 .4205 Mdot
.958 .42161 Mdot
.958 .42273 Mdot
.958 .42612 Mdot
.958 .42711 Mdot
.958 .43229 Mdot
.958 .44465 Mdot
.958 .44482 Mdot
.958 .44677 Mdot
.958 .45311 Mdot
.958 .45506 Mdot
.958 .45512 Mdot
.958 .45744 Mdot
.958 .47144 Mdot
.958 .47205 Mdot
.958 .4782 Mdot
.958 .48259 Mdot
.958 .48566 Mdot
.958 .49788 Mdot
.958 .50429 Mdot
.958 .50871 Mdot
.958 .5228 Mdot
.958 .52487 Mdot
.958 .52693 Mdot
.958 .52817 Mdot
.958 .52818 Mdot
.958 .53309 Mdot
.958 .53819 Mdot
.958 .53979 Mdot
.958 .54699 Mdot
.958 .54699 Mdot
.958 .547 Mdot
.958 .547 Mdot
.958 .54701 Mdot
.958 .54702 Mdot
.958 .54704 Mdot
.958 .54706 Mdot
.958 .54707 Mdot
.958 .54709 Mdot
.958 .5471 Mdot
.958 .54713 Mdot
.958 .54713 Mdot
.958 .54715 Mdot
.958 .54716 Mdot
.958 .54716 Mdot
.958 .54718 Mdot
.958 .5472 Mdot
.958 .54722 Mdot
.958 .54725 Mdot
.958 .54725 Mdot
.958 .54732 Mdot
.958 .54737 Mdot
.958 .54738 Mdot
.958 .54739 Mdot
.958 .54739 Mdot
.958 .54741 Mdot
.958 .54744 Mdot
.958 .54753 Mdot
.958 .54756 Mdot
.958 .54757 Mdot
.958 .54759 Mdot
.958 .54761 Mdot
.958 .54762 Mdot
.958 .54772 Mdot
.958 .54774 Mdot
.958 .54774 Mdot
.958 .54775 Mdot
.958 .54777 Mdot
.958 .54777 Mdot
.958 .54784 Mdot
.958 .54808 Mdot
.958 .54808 Mdot
.958 .54809 Mdot
.958 .54812 Mdot
.958 .54819 Mdot
.958 .54821 Mdot
.958 .54824 Mdot
.958 .54825 Mdot
.958 .54836 Mdot
.958 .54841 Mdot
.958 .54842 Mdot
.958 .54844 Mdot
.958 .54845 Mdot
.958 .54846 Mdot
.958 .54846 Mdot
.958 .54852 Mdot
.958 .54873 Mdot
.958 .54878 Mdot
.958 .54885 Mdot
.958 .54908 Mdot
.958 .54924 Mdot
.958 .54931 Mdot
.958 .54933 Mdot
.958 .54936 Mdot
.958 .54942 Mdot
.958 .54947 Mdot
.958 .54947 Mdot
.958 .54951 Mdot
.958 .54955 Mdot
.958 .54955 Mdot
.958 .54959 Mdot
.958 .54961 Mdot
.958 .54961 Mdot
.958 .54964 Mdot
.958 .54982 Mdot
.958 .54989 Mdot
.958 .54998 Mdot
.958 .54998 Mdot
.958 .55 Mdot
.958 .5501 Mdot
.958 .55011 Mdot
.958 .55017 Mdot
.958 .55017 Mdot
.958 .55025 Mdot
.958 .55031 Mdot
.958 .5505 Mdot
.958 .55051 Mdot
.958 .55076 Mdot
.958 .55078 Mdot
.958 .55082 Mdot
.958 .55086 Mdot
.958 .55088 Mdot
.958 .55091 Mdot
.958 .55093 Mdot
.958 .55099 Mdot
.958 .55112 Mdot
.958 .55113 Mdot
.958 .55115 Mdot
.958 .55116 Mdot
.958 .55119 Mdot
.958 .55124 Mdot
.958 .55129 Mdot
.958 .55134 Mdot
.958 .55138 Mdot
.958 .55148 Mdot
.958 .55162 Mdot
.958 .55166 Mdot
.958 .55176 Mdot
.958 .55181 Mdot
.958 .55183 Mdot
.958 .55202 Mdot
.958 .55218 Mdot
.958 .5522 Mdot
.958 .55223 Mdot
.958 .55227 Mdot
.958 .55247 Mdot
.958 .55253 Mdot
.958 .55297 Mdot
.958 .55315 Mdot
.958 .55321 Mdot
.958 .55329 Mdot
.958 .55348 Mdot
.958 .55355 Mdot
.958 .55361 Mdot
.958 .55363 Mdot
.958 .55372 Mdot
.958 .55377 Mdot
.958 .5538 Mdot
.958 .55381 Mdot
.958 .55384 Mdot
.958 .55399 Mdot
.958 .55411 Mdot
.958 .55413 Mdot
.958 .5543 Mdot
.958 .5544 Mdot
.958 .5544 Mdot
.958 .55443 Mdot
.958 .55446 Mdot
.958 .55447 Mdot
.958 .55447 Mdot
.958 .55467 Mdot
.958 .55477 Mdot
.958 .55477 Mdot
.958 .55482 Mdot
.958 .55482 Mdot
.958 .55485 Mdot
.958 .5549 Mdot
.958 .55498 Mdot
.958 .55501 Mdot
.958 .55504 Mdot
.958 .55508 Mdot
.958 .55529 Mdot
.958 .55543 Mdot
.958 .55574 Mdot
.958 .55581 Mdot
.958 .55582 Mdot
.958 .55602 Mdot
.958 .55606 Mdot
.958 .55614 Mdot
.958 .55615 Mdot
.958 .55616 Mdot
.958 .55634 Mdot
.958 .55636 Mdot
.958 .55651 Mdot
.958 .55657 Mdot
.958 .5566 Mdot
.958 .55667 Mdot
.958 .55689 Mdot
.958 .55708 Mdot
.958 .55711 Mdot
.958 .55713 Mdot
.958 .55716 Mdot
.958 .55718 Mdot
.958 .55719 Mdot
.958 .55734 Mdot
.958 .55739 Mdot
.958 .55779 Mdot
.958 .55787 Mdot
.958 .5582 Mdot
.958 .55863 Mdot
.958 .55872 Mdot
.958 .5592 Mdot
.958 .55974 Mdot
.958 .5601 Mdot
.958 .56021 Mdot
.958 .56158 Mdot
.958 .56216 Mdot
.958 .56249 Mdot
.958 .56262 Mdot
.958 .56263 Mdot
.958 .56283 Mdot
.958 .56324 Mdot
.958 .56333 Mdot
.958 .56339 Mdot
.958 .56352 Mdot
.958 .56359 Mdot
.958 .56376 Mdot
.958 .564 Mdot
.958 .56409 Mdot
.958 .56429 Mdot
.958 .56433 Mdot
.958 .56451 Mdot
.958 .56477 Mdot
.958 .56477 Mdot
.958 .56486 Mdot
.958 .56509 Mdot
.958 .56543 Mdot
.958 .56543 Mdot
.958 .56617 Mdot
.958 .56619 Mdot
.958 .56698 Mdot
.958 .56711 Mdot
.958 .56828 Mdot
.958 .56829 Mdot
.958 .56855 Mdot
.958 .56975 Mdot
.958 .56977 Mdot
.958 .5708 Mdot
.958 .57091 Mdot
.958 .57099 Mdot
.958 .57117 Mdot
.958 .57137 Mdot
.958 .57206 Mdot
.958 .57219 Mdot
.958 .57227 Mdot
.958 .57259 Mdot
.958 .57273 Mdot
.958 .57296 Mdot
.958 .57305 Mdot
.958 .57316 Mdot
.958 .5736 Mdot
.958 .57379 Mdot
.958 .57459 Mdot
.958 .57479 Mdot
.958 .5755 Mdot
.958 .57556 Mdot
.958 .57556 Mdot
.958 .57559 Mdot
.958 .57573 Mdot
.958 .57602 Mdot
.958 .57614 Mdot
.958 .57623 Mdot
.958 .57653 Mdot
.958 .5766 Mdot
.958 .57677 Mdot
.958 .5769 Mdot
.958 .57692 Mdot
.958 .57693 Mdot
.958 .577 Mdot
.958 .57715 Mdot
.958 .57719 Mdot
.958 .57722 Mdot
.958 .57738 Mdot
.958 .57747 Mdot
.958 .57769 Mdot
.958 .57798 Mdot
.958 .57798 Mdot
.958 .57799 Mdot
.958 .578 Mdot
.958 .57801 Mdot
.958 .57801 Mdot
.958 .57829 Mdot
.958 .5783 Mdot
.958 .57839 Mdot
.958 .57853 Mdot
.958 .57859 Mdot
.96 .10865 Mdot
.96 .10865 Mdot
.96 .10869 Mdot
.96 .1087 Mdot
.96 .10871 Mdot
.96 .10871 Mdot
.96 .10873 Mdot
.96 .10873 Mdot
.96 .10877 Mdot
.96 .10878 Mdot
.96 .10892 Mdot
.96 .10903 Mdot
.96 .10912 Mdot
.96 .10912 Mdot
.96 .10912 Mdot
.96 .10913 Mdot
.96 .10918 Mdot
.96 .10918 Mdot
.96 .10921 Mdot
.96 .10922 Mdot
.96 .10924 Mdot
.96 .10928 Mdot
.96 .10929 Mdot
.96 .10934 Mdot
.96 .10939 Mdot
.96 .10941 Mdot
.96 .10944 Mdot
.96 .10945 Mdot
.96 .10977 Mdot
.96 .10983 Mdot
.96 .10985 Mdot
.96 .10993 Mdot
.96 .10996 Mdot
.96 .10999 Mdot
.96 .11006 Mdot
.96 .11015 Mdot
.96 .11022 Mdot
.96 .11023 Mdot
.96 .11024 Mdot
.96 .11024 Mdot
.96 .1103 Mdot
.96 .11045 Mdot
.96 .11045 Mdot
.96 .11047 Mdot
.96 .11049 Mdot
.96 .11058 Mdot
.96 .11059 Mdot
.96 .11062 Mdot
.96 .11065 Mdot
.96 .11065 Mdot
.96 .1108 Mdot
.96 .1108 Mdot
.96 .11089 Mdot
.96 .11098 Mdot
.96 .1111 Mdot
.96 .11115 Mdot
.96 .11121 Mdot
.96 .11125 Mdot
.96 .11143 Mdot
.96 .11146 Mdot
.96 .11152 Mdot
.96 .11164 Mdot
.96 .11171 Mdot
.96 .11173 Mdot
.96 .11181 Mdot
.96 .11184 Mdot
.96 .11199 Mdot
.96 .11206 Mdot
.96 .1121 Mdot
.96 .11265 Mdot
.96 .11277 Mdot
.96 .11299 Mdot
.96 .11328 Mdot
.96 .11338 Mdot
.96 .11363 Mdot
.96 .1139 Mdot
.96 .11402 Mdot
.96 .11416 Mdot
.96 .11427 Mdot
.96 .11444 Mdot
.96 .11454 Mdot
.96 .11458 Mdot
.96 .11469 Mdot
.96 .1147 Mdot
.96 .11475 Mdot
.96 .11479 Mdot
.96 .11484 Mdot
.96 .11498 Mdot
.96 .11505 Mdot
.96 .11534 Mdot
.96 .11537 Mdot
.96 .1158 Mdot
.96 .11585 Mdot
.96 .11587 Mdot
.96 .11597 Mdot
.96 .11623 Mdot
.96 .11639 Mdot
.96 .11688 Mdot
.96 .11697 Mdot
.96 .11715 Mdot
.96 .11864 Mdot
.96 .11883 Mdot
.96 .119 Mdot
.96 .119 Mdot
.96 .11911 Mdot
.96 .11924 Mdot
.96 .11936 Mdot
.96 .11949 Mdot
.96 .11953 Mdot
.96 .11958 Mdot
.96 .12009 Mdot
.96 .12036 Mdot
.96 .121 Mdot
.96 .12113 Mdot
.96 .12139 Mdot
.96 .12139 Mdot
.96 .12143 Mdot
.96 .12144 Mdot
.96 .12169 Mdot
.96 .1217 Mdot
.96 .12201 Mdot
.96 .12219 Mdot
.96 .12225 Mdot
.96 .1223 Mdot
.96 .12232 Mdot
.96 .12239 Mdot
.96 .12248 Mdot
.96 .12294 Mdot
.96 .12339 Mdot
.96 .12346 Mdot
.96 .12399 Mdot
.96 .124 Mdot
.96 .1243 Mdot
.96 .12435 Mdot
.96 .12447 Mdot
.96 .12451 Mdot
.96 .12575 Mdot
.96 .12607 Mdot
.96 .12614 Mdot
.96 .12639 Mdot
.96 .1266 Mdot
.96 .1267 Mdot
.96 .12713 Mdot
.96 .12764 Mdot
.96 .12801 Mdot
.96 .12859 Mdot
.96 .12863 Mdot
.96 .12869 Mdot
.96 .12878 Mdot
.96 .1289 Mdot
.96 .12946 Mdot
.96 .12965 Mdot
.96 .12984 Mdot
.96 .13096 Mdot
.96 .13107 Mdot
.96 .13165 Mdot
.96 .13229 Mdot
.96 .13252 Mdot
.96 .13287 Mdot
.96 .13297 Mdot
.96 .13388 Mdot
.96 .13419 Mdot
.96 .13422 Mdot
.96 .13423 Mdot
.96 .13434 Mdot
.96 .13471 Mdot
.96 .13476 Mdot
.96 .13497 Mdot
.96 .13509 Mdot
.96 .1352 Mdot
.96 .13546 Mdot
.96 .13577 Mdot
.96 .13595 Mdot
.96 .13659 Mdot
.96 .13688 Mdot
.96 .13708 Mdot
.96 .1374 Mdot
.96 .1374 Mdot
.96 .13779 Mdot
.96 .13796 Mdot
.96 .13815 Mdot
.96 .1382 Mdot
.96 .13822 Mdot
.96 .13827 Mdot
.96 .13942 Mdot
.96 .13949 Mdot
.96 .13982 Mdot
.96 .14026 Mdot
.96 .14039 Mdot
.96 .14044 Mdot
.96 .14053 Mdot
.96 .14054 Mdot
.96 .14067 Mdot
.96 .14068 Mdot
.96 .14072 Mdot
.96 .14073 Mdot
.96 .1408 Mdot
.96 .1408 Mdot
.96 .14093 Mdot
.96 .14096 Mdot
.96 .14133 Mdot
.96 .14145 Mdot
.96 .14149 Mdot
.96 .14153 Mdot
.96 .14168 Mdot
.96 .1418 Mdot
.96 .14182 Mdot
.96 .14189 Mdot
.96 .14204 Mdot
.96 .14211 Mdot
.96 .14212 Mdot
.96 .14213 Mdot
.96 .14215 Mdot
.96 .14217 Mdot
.96 .14232 Mdot
.96 .14234 Mdot
.96 .14237 Mdot
.96 .14243 Mdot
.96 .14246 Mdot
.96 .14246 Mdot
.96 .14249 Mdot
.96 .1425 Mdot
.96 .14255 Mdot
.96 .14266 Mdot
.96 .14271 Mdot
.96 .14273 Mdot
.96 .14283 Mdot
.96 .14288 Mdot
.96 .14304 Mdot
.96 .14314 Mdot
.96 .14322 Mdot
.96 .14322 Mdot
.96 .14323 Mdot
.96 .14324 Mdot
.96 .14326 Mdot
.96 .14328 Mdot
.96 .14333 Mdot
.96 .14336 Mdot
.96 .14359 Mdot
.96 .14359 Mdot
.96 .14376 Mdot
.96 .14398 Mdot
.96 .14398 Mdot
.96 .14402 Mdot
.96 .14415 Mdot
.96 .14424 Mdot
.96 .14437 Mdot
.96 .14438 Mdot
.96 .1446 Mdot
.96 .14466 Mdot
.96 .14467 Mdot
.96 .14482 Mdot
.96 .14486 Mdot
.96 .14495 Mdot
.96 .14502 Mdot
.96 .14507 Mdot
.96 .14515 Mdot
.96 .14517 Mdot
.96 .14529 Mdot
.96 .14538 Mdot
.96 .14541 Mdot
.96 .14554 Mdot
.96 .14561 Mdot
.96 .14564 Mdot
.96 .14575 Mdot
.96 .1458 Mdot
.96 .14585 Mdot
.96 .14592 Mdot
.96 .14599 Mdot
.96 .146 Mdot
.96 .14604 Mdot
.96 .14605 Mdot
.96 .14625 Mdot
.96 .14628 Mdot
.96 .14632 Mdot
.96 .14635 Mdot
.96 .14643 Mdot
.96 .14651 Mdot
.96 .14669 Mdot
.96 .14678 Mdot
.96 .1468 Mdot
.96 .14681 Mdot
.96 .14682 Mdot
.96 .14688 Mdot
.96 .14688 Mdot
.96 .14693 Mdot
.96 .14697 Mdot
.96 .14698 Mdot
.96 .14699 Mdot
.96 .14708 Mdot
.96 .14716 Mdot
.96 .14717 Mdot
.96 .14731 Mdot
.96 .14732 Mdot
.96 .14733 Mdot
.96 .14742 Mdot
.96 .14744 Mdot
.96 .14745 Mdot
.96 .14753 Mdot
.96 .14755 Mdot
.96 .14756 Mdot
.96 .1476 Mdot
.96 .14766 Mdot
.96 .14779 Mdot
.96 .14781 Mdot
.96 .14782 Mdot
.96 .14783 Mdot
.96 .14786 Mdot
.96 .14788 Mdot
.96 .14791 Mdot
.96 .14791 Mdot
.96 .14792 Mdot
.96 .14792 Mdot
.96 .14792 Mdot
.96 .14792 Mdot
.96 .1481 Mdot
.96 .14812 Mdot
.96 .14843 Mdot
.96 .14878 Mdot
.96 .1492 Mdot
.96 .1494 Mdot
.96 .14964 Mdot
.96 .14976 Mdot
.96 .15044 Mdot
.96 .15056 Mdot
.96 .15079 Mdot
.96 .15124 Mdot
.96 .15153 Mdot
.96 .15158 Mdot
.96 .15189 Mdot
.96 .15202 Mdot
.96 .15259 Mdot
.96 .15289 Mdot
.96 .15302 Mdot
.96 .15519 Mdot
.96 .15566 Mdot
.96 .15567 Mdot
.96 .15653 Mdot
.96 .1577 Mdot
.96 .15812 Mdot
.96 .15913 Mdot
.96 .15957 Mdot
.96 .16027 Mdot
.96 .16076 Mdot
.96 .16133 Mdot
.96 .16181 Mdot
.96 .1625 Mdot
.96 .16293 Mdot
.96 .16309 Mdot
.96 .16356 Mdot
.96 .16359 Mdot
.96 .1638 Mdot
.96 .16398 Mdot
.96 .16422 Mdot
.96 .16479 Mdot
.96 .16511 Mdot
.96 .16634 Mdot
.96 .16647 Mdot
.96 .16657 Mdot
.96 .16835 Mdot
.96 .16858 Mdot
.96 .16867 Mdot
.96 .16912 Mdot
.96 .17025 Mdot
.96 .17098 Mdot
.96 .17318 Mdot
.96 .17358 Mdot
.96 .17439 Mdot
.96 .18128 Mdot
.96 .18218 Mdot
.96 .18295 Mdot
.96 .18298 Mdot
.96 .18349 Mdot
.96 .18413 Mdot
.96 .18469 Mdot
.96 .1853 Mdot
.96 .18551 Mdot
.96 .18574 Mdot
.96 .1882 Mdot
.96 .18951 Mdot
.96 .19023 Mdot
.96 .1926 Mdot
.96 .19324 Mdot
.96 .19453 Mdot
.96 .19455 Mdot
.96 .19476 Mdot
.96 .19479 Mdot
.96 .19603 Mdot
.96 .19608 Mdot
.96 .1976 Mdot
.96 .19853 Mdot
.96 .19881 Mdot
.96 .19907 Mdot
.96 .19919 Mdot
.96 .19952 Mdot
.96 .19997 Mdot
.96 .20144 Mdot
.96 .20195 Mdot
.96 .2023 Mdot
.96 .20274 Mdot
.96 .20457 Mdot
.96 .2047 Mdot
.96 .20491 Mdot
.96 .20759 Mdot
.96 .20764 Mdot
.96 .20918 Mdot
.96 .20946 Mdot
.96 .21005 Mdot
.96 .21028 Mdot
.96 .21669 Mdot
.96 .21833 Mdot
.96 .21868 Mdot
.96 .21998 Mdot
.96 .22109 Mdot
.96 .22161 Mdot
.96 .22386 Mdot
.96 .22651 Mdot
.96 .22844 Mdot
.96 .23148 Mdot
.96 .23167 Mdot
.96 .23202 Mdot
.96 .23247 Mdot
.96 .2331 Mdot
.96 .23604 Mdot
.96 .23701 Mdot
.96 .23788 Mdot
.96 .23803 Mdot
.96 .24389 Mdot
.96 .24443 Mdot
.96 .2475 Mdot
.96 .25081 Mdot
.96 .25199 Mdot
.96 .25383 Mdot
.96 .2543 Mdot
.96 .25902 Mdot
.96 .26062 Mdot
.96 .26076 Mdot
.96 .26078 Mdot
.96 .26137 Mdot
.96 .26324 Mdot
.96 .26352 Mdot
.96 .26458 Mdot
.96 .26461 Mdot
.96 .26519 Mdot
.96 .26572 Mdot
.96 .26703 Mdot
.96 .26863 Mdot
.96 .26949 Mdot
.96 .27269 Mdot
.96 .27413 Mdot
.96 .2751 Mdot
.96 .27669 Mdot
.96 .27671 Mdot
.96 .27858 Mdot
.96 .27945 Mdot
.96 .28036 Mdot
.96 .28059 Mdot
.96 .28069 Mdot
.96 .28091 Mdot
.96 .28644 Mdot
.96 .28674 Mdot
.96 .28829 Mdot
.96 .29038 Mdot
.96 .29097 Mdot
.96 .2912 Mdot
.96 .2916 Mdot
.96 .29167 Mdot
.96 .29226 Mdot
.96 .29231 Mdot
.96 .29248 Mdot
.96 .29254 Mdot
.96 .29284 Mdot
.96 .29284 Mdot
.96 .29345 Mdot
.96 .29356 Mdot
.96 .29528 Mdot
.96 .2958 Mdot
.96 .29598 Mdot
.96 .29618 Mdot
.96 .29682 Mdot
.96 .29736 Mdot
.96 .29747 Mdot
.96 .29776 Mdot
.96 .29844 Mdot
.96 .29875 Mdot
.96 .29881 Mdot
.96 .29885 Mdot
.96 .29893 Mdot
.96 .29901 Mdot
.96 .29968 Mdot
.96 .29977 Mdot
.96 .29991 Mdot
.96 .30016 Mdot
.96 .3003 Mdot
.96 .30031 Mdot
.96 .30043 Mdot
.96 .30047 Mdot
.96 .30068 Mdot
.96 .30117 Mdot
.96 .30138 Mdot
.96 .3015 Mdot
.96 .30193 Mdot
.96 .30213 Mdot
.96 .30284 Mdot
.96 .30324 Mdot
.96 .30359 Mdot
.96 .30362 Mdot
.96 .30363 Mdot
.96 .30367 Mdot
.96 .30379 Mdot
.96 .30387 Mdot
.96 .30408 Mdot
.96 .3042 Mdot
.96 .30506 Mdot
.96 .30518 Mdot
.96 .30519 Mdot
.96 .30588 Mdot
.96 .30682 Mdot
.96 .30682 Mdot
.96 .307 Mdot
.96 .30756 Mdot
.96 .3079 Mdot
.96 .30845 Mdot
.96 .30849 Mdot
.96 .30942 Mdot
.96 .30963 Mdot
.96 .30971 Mdot
.96 .3103 Mdot
.96 .31046 Mdot
.96 .31048 Mdot
.96 .31084 Mdot
.96 .31113 Mdot
.96 .31131 Mdot
.96 .31164 Mdot
.96 .31173 Mdot
.96 .31222 Mdot
.96 .31259 Mdot
.96 .31319 Mdot
.96 .3135 Mdot
.96 .31361 Mdot
.96 .31403 Mdot
.96 .31423 Mdot
.96 .31445 Mdot
.96 .31473 Mdot
.96 .31499 Mdot
.96 .31505 Mdot
.96 .3152 Mdot
.96 .31522 Mdot
.96 .31602 Mdot
.96 .31612 Mdot
.96 .31629 Mdot
.96 .3164 Mdot
.96 .31669 Mdot
.96 .317 Mdot
.96 .31769 Mdot
.96 .31803 Mdot
.96 .31811 Mdot
.96 .31815 Mdot
.96 .3182 Mdot
.96 .31841 Mdot
.96 .31843 Mdot
.96 .31859 Mdot
.96 .31877 Mdot
.96 .31879 Mdot
.96 .31884 Mdot
.96 .31916 Mdot
.96 .31949 Mdot
.96 .31951 Mdot
.96 .32002 Mdot
.96 .32008 Mdot
.96 .32012 Mdot
.96 .32044 Mdot
.96 .3205 Mdot
.96 .32056 Mdot
.96 .32086 Mdot
.96 .32091 Mdot
.96 .32095 Mdot
.96 .32111 Mdot
.96 .32134 Mdot
.96 .32182 Mdot
.96 .32186 Mdot
.96 .32193 Mdot
.96 .32195 Mdot
.96 .32205 Mdot
.96 .32213 Mdot
.96 .32223 Mdot
.96 .32224 Mdot
.96 .32227 Mdot
.96 .32229 Mdot
.96 .32229 Mdot
.96 .32229 Mdot
.96 .32293 Mdot
.96 .32298 Mdot
.96 .32412 Mdot
.96 .32533 Mdot
.96 .32681 Mdot
.96 .32748 Mdot
.96 .32828 Mdot
.96 .3284 Mdot
.96 .32843 Mdot
.96 .32845 Mdot
.96 .32845 Mdot
.96 .32847 Mdot
.96 .32848 Mdot
.96 .32853 Mdot
.96 .32861 Mdot
.96 .32869 Mdot
.96 .32876 Mdot
.96 .3292 Mdot
.96 .32938 Mdot
.96 .32953 Mdot
.96 .32956 Mdot
.96 .32962 Mdot
.96 .32982 Mdot
.96 .32989 Mdot
.96 .33006 Mdot
.96 .33025 Mdot
.96 .33071 Mdot
.96 .33092 Mdot
.96 .33093 Mdot
.96 .33096 Mdot
.96 .33129 Mdot
.96 .33151 Mdot
.96 .33154 Mdot
.96 .33178 Mdot
.96 .33203 Mdot
.96 .33225 Mdot
.96 .3323 Mdot
.96 .33344 Mdot
.96 .33353 Mdot
.96 .33357 Mdot
.96 .33378 Mdot
.96 .33381 Mdot
.96 .33431 Mdot
.96 .33447 Mdot
.96 .33525 Mdot
.96 .33541 Mdot
.96 .3358 Mdot
.96 .33601 Mdot
.96 .33745 Mdot
.96 .33822 Mdot
.96 .33828 Mdot
.96 .33864 Mdot
.96 .33902 Mdot
.96 .33998 Mdot
.96 .34177 Mdot
.96 .34235 Mdot
.96 .34424 Mdot
.96 .3452 Mdot
.96 .34536 Mdot
.96 .34537 Mdot
.96 .34552 Mdot
.96 .34581 Mdot
.96 .34625 Mdot
.96 .34666 Mdot
.96 .34713 Mdot
.96 .34715 Mdot
.96 .34729 Mdot
.96 .34743 Mdot
.96 .3483 Mdot
.96 .34899 Mdot
.96 .34902 Mdot
.96 .34967 Mdot
.96 .35005 Mdot
.96 .35047 Mdot
.96 .35066 Mdot
.96 .35121 Mdot
.96 .35225 Mdot
.96 .35296 Mdot
.96 .35389 Mdot
.96 .35404 Mdot
.96 .35473 Mdot
.96 .35547 Mdot
.96 .35548 Mdot
.96 .35566 Mdot
.96 .35593 Mdot
.96 .35607 Mdot
.96 .35686 Mdot
.96 .35731 Mdot
.96 .35746 Mdot
.96 .35789 Mdot
.96 .35791 Mdot
.96 .3581 Mdot
.96 .35825 Mdot
.96 .35825 Mdot
.96 .35844 Mdot
.96 .35878 Mdot
.96 .35885 Mdot
.96 .35902 Mdot
.96 .35905 Mdot
.96 .35969 Mdot
.96 .35974 Mdot
.96 .35978 Mdot
.96 .35995 Mdot
.96 .36007 Mdot
.96 .36012 Mdot
.96 .3602 Mdot
.96 .36022 Mdot
.96 .36023 Mdot
.96 .36023 Mdot
.96 .36287 Mdot
.96 .37264 Mdot
.96 .38041 Mdot
.96 .38676 Mdot
.96 .39362 Mdot
.96 .39449 Mdot
.96 .39609 Mdot
.96 .39814 Mdot
.96 .40107 Mdot
.96 .4033 Mdot
.96 .40682 Mdot
.96 .41529 Mdot
.96 .42012 Mdot
.96 .42455 Mdot
.96 .42529 Mdot
.96 .42892 Mdot
.96 .45403 Mdot
.96 .45573 Mdot
.96 .45852 Mdot
.96 .47451 Mdot
.96 .49134 Mdot
.96 .49717 Mdot
.96 .49739 Mdot
.96 .50599 Mdot
.96 .50823 Mdot
.96 .514 Mdot
.96 .52388 Mdot
.96 .52904 Mdot
.96 .53544 Mdot
.96 .53583 Mdot
.96 .53598 Mdot
.96 .53608 Mdot
.96 .53835 Mdot
.96 .54347 Mdot
.96 .54512 Mdot
.96 .54608 Mdot
.96 .5481 Mdot
.96 .5481 Mdot
.96 .5481 Mdot
.96 .54811 Mdot
.96 .54811 Mdot
.96 .54811 Mdot
.96 .54812 Mdot
.96 .54812 Mdot
.96 .54813 Mdot
.96 .54813 Mdot
.96 .54814 Mdot
.96 .54814 Mdot
.96 .54818 Mdot
.96 .54819 Mdot
.96 .54821 Mdot
.96 .54823 Mdot
.96 .54824 Mdot
.96 .54827 Mdot
.96 .54831 Mdot
.96 .54831 Mdot
.96 .54834 Mdot
.96 .54836 Mdot
.96 .54836 Mdot
.96 .54838 Mdot
.96 .54839 Mdot
.96 .54841 Mdot
.96 .54842 Mdot
.96 .54844 Mdot
.96 .54849 Mdot
.96 .54851 Mdot
.96 .54853 Mdot
.96 .54854 Mdot
.96 .54856 Mdot
.96 .54865 Mdot
.96 .54867 Mdot
.96 .54869 Mdot
.96 .54873 Mdot
.96 .54874 Mdot
.96 .54876 Mdot
.96 .5488 Mdot
.96 .54883 Mdot
.96 .54887 Mdot
.96 .54891 Mdot
.96 .54895 Mdot
.96 .54896 Mdot
.96 .549 Mdot
.96 .54909 Mdot
.96 .54913 Mdot
.96 .54915 Mdot
.96 .54919 Mdot
.96 .5492 Mdot
.96 .5492 Mdot
.96 .54926 Mdot
.96 .54931 Mdot
.96 .54931 Mdot
.96 .54938 Mdot
.96 .54939 Mdot
.96 .5494 Mdot
.96 .54941 Mdot
.96 .54942 Mdot
.96 .54942 Mdot
.96 .54953 Mdot
.96 .54956 Mdot
.96 .54963 Mdot
.96 .54963 Mdot
.96 .54964 Mdot
.96 .54966 Mdot
.96 .54973 Mdot
.96 .54976 Mdot
.96 .5498 Mdot
.96 .54982 Mdot
.96 .54987 Mdot
.96 .54991 Mdot
.96 .54992 Mdot
.96 .54997 Mdot
.96 .55023 Mdot
.96 .55025 Mdot
.96 .55029 Mdot
.96 .55042 Mdot
.96 .55052 Mdot
.96 .55054 Mdot
.96 .55089 Mdot
.96 .55091 Mdot
.96 .55091 Mdot
.96 .55093 Mdot
.96 .55099 Mdot
.96 .55104 Mdot
.96 .55116 Mdot
.96 .55116 Mdot
.96 .55127 Mdot
.96 .55133 Mdot
.96 .55142 Mdot
.96 .55163 Mdot
.96 .55168 Mdot
.96 .55178 Mdot
.96 .55187 Mdot
.96 .5519 Mdot
.96 .55194 Mdot
.96 .55201 Mdot
.96 .55203 Mdot
.96 .55215 Mdot
.96 .55219 Mdot
.96 .55219 Mdot
.96 .5522 Mdot
.96 .5523 Mdot
.96 .55261 Mdot
.96 .55264 Mdot
.96 .55276 Mdot
.96 .55284 Mdot
.96 .55306 Mdot
.96 .55327 Mdot
.96 .55331 Mdot
.96 .55371 Mdot
.96 .55378 Mdot
.96 .55385 Mdot
.96 .55405 Mdot
.96 .5541 Mdot
.96 .55413 Mdot
.96 .55416 Mdot
.96 .55417 Mdot
.96 .55439 Mdot
.96 .55453 Mdot
.96 .55473 Mdot
.96 .5549 Mdot
.96 .55493 Mdot
.96 .55502 Mdot
.96 .55512 Mdot
.96 .55515 Mdot
.96 .55527 Mdot
.96 .55579 Mdot
.96 .55581 Mdot
.96 .55585 Mdot
.96 .55588 Mdot
.96 .55601 Mdot
.96 .55601 Mdot
.96 .55624 Mdot
.96 .55627 Mdot
.96 .55646 Mdot
.96 .55667 Mdot
.96 .55671 Mdot
.96 .55674 Mdot
.96 .55675 Mdot
.96 .55678 Mdot
.96 .5568 Mdot
.96 .55689 Mdot
.96 .55703 Mdot
.96 .55703 Mdot
.96 .55715 Mdot
.96 .55715 Mdot
.96 .55717 Mdot
.96 .55717 Mdot
.96 .5573 Mdot
.96 .55736 Mdot
.96 .55767 Mdot
.96 .5578 Mdot
.96 .55806 Mdot
.96 .55808 Mdot
.96 .5581 Mdot
.96 .55817 Mdot
.96 .55823 Mdot
.96 .5583 Mdot
.96 .55835 Mdot
.96 .55836 Mdot
.96 .55844 Mdot
.96 .55854 Mdot
.96 .55937 Mdot
.96 .55947 Mdot
.96 .55953 Mdot
.96 .55982 Mdot
.96 .55992 Mdot
.96 .56008 Mdot
.96 .56014 Mdot
.96 .56016 Mdot
.96 .56019 Mdot
.96 .56047 Mdot
.96 .56049 Mdot
.96 .56068 Mdot
.96 .56073 Mdot
.96 .5611 Mdot
.96 .56122 Mdot
.96 .5613 Mdot
.96 .56149 Mdot
.96 .5622 Mdot
.96 .56238 Mdot
.96 .56249 Mdot
.96 .56301 Mdot
.96 .56308 Mdot
.96 .56322 Mdot
.96 .56325 Mdot
.96 .56354 Mdot
.96 .56363 Mdot
.96 .56382 Mdot
.96 .56386 Mdot
.96 .56411 Mdot
.96 .56422 Mdot
.96 .56432 Mdot
.96 .56433 Mdot
.96 .56451 Mdot
.96 .56458 Mdot
.96 .56459 Mdot
.96 .56474 Mdot
.96 .56476 Mdot
.96 .56496 Mdot
.96 .56507 Mdot
.96 .56516 Mdot
.96 .5653 Mdot
.96 .5654 Mdot
.96 .56545 Mdot
.96 .5655 Mdot
.96 .56563 Mdot
.96 .56633 Mdot
.96 .5664 Mdot
.96 .56646 Mdot
.96 .56656 Mdot
.96 .56667 Mdot
.96 .5667 Mdot
.96 .56677 Mdot
.96 .56683 Mdot
.96 .56685 Mdot
.96 .56691 Mdot
.96 .56693 Mdot
.96 .56704 Mdot
.96 .56706 Mdot
.96 .56707 Mdot
.96 .56708 Mdot
.96 .56733 Mdot
.96 .56825 Mdot
.96 .56865 Mdot
.96 .56879 Mdot
.96 .5693 Mdot
.96 .56951 Mdot
.96 .57035 Mdot
.96 .57043 Mdot
.96 .5706 Mdot
.96 .5706 Mdot
.96 .57084 Mdot
.96 .5715 Mdot
.96 .57289 Mdot
.96 .57354 Mdot
.96 .57366 Mdot
.96 .57432 Mdot
.96 .57434 Mdot
.96 .57434 Mdot
.96 .57466 Mdot
.96 .57473 Mdot
.96 .5749 Mdot
.96 .57496 Mdot
.96 .57556 Mdot
.96 .57563 Mdot
.96 .57601 Mdot
.96 .57623 Mdot
.96 .57632 Mdot
.96 .57633 Mdot
.96 .57676 Mdot
.96 .578 Mdot
.96 .5781 Mdot
.96 .57834 Mdot
.96 .57872 Mdot
.96 .57919 Mdot
.96 .57923 Mdot
.96 .57933 Mdot
.96 .57933 Mdot
.96 .57938 Mdot
.96 .57942 Mdot
.96 .57947 Mdot
.962 .10885 Mdot
.962 .10885 Mdot
.962 .10885 Mdot
.962 .10885 Mdot
.962 .10885 Mdot
.962 .10885 Mdot
.962 .10885 Mdot
.962 .10886 Mdot
.962 .10886 Mdot
.962 .10886 Mdot
.962 .10886 Mdot
.962 .10886 Mdot
.962 .10886 Mdot
.962 .10886 Mdot
.962 .10886 Mdot
.962 .10887 Mdot
.962 .10887 Mdot
.962 .10888 Mdot
.962 .10888 Mdot
.962 .10888 Mdot
.962 .10888 Mdot
.962 .10889 Mdot
.962 .10889 Mdot
.962 .10889 Mdot
.962 .10889 Mdot
.962 .1089 Mdot
.962 .1089 Mdot
.962 .1089 Mdot
.962 .1089 Mdot
.962 .1089 Mdot
.962 .1089 Mdot
.962 .1089 Mdot
.962 .10891 Mdot
.962 .10891 Mdot
.962 .10891 Mdot
.962 .10892 Mdot
.962 .10892 Mdot
.962 .10893 Mdot
.962 .10894 Mdot
.962 .10894 Mdot
.962 .10894 Mdot
.962 .10896 Mdot
.962 .10897 Mdot
.962 .10897 Mdot
.962 .10897 Mdot
.962 .10897 Mdot
.962 .10897 Mdot
.962 .10898 Mdot
.962 .10899 Mdot
.962 .10899 Mdot
.962 .109 Mdot
.962 .109 Mdot
.962 .109 Mdot
.962 .109 Mdot
.962 .109 Mdot
.962 .10901 Mdot
.962 .10902 Mdot
.962 .10902 Mdot
.962 .10902 Mdot
.962 .10902 Mdot
.962 .10903 Mdot
.962 .10903 Mdot
.962 .10903 Mdot
.962 .10904 Mdot
.962 .10904 Mdot
.962 .10904 Mdot
.962 .10905 Mdot
.962 .10905 Mdot
.962 .10907 Mdot
.962 .10909 Mdot
.962 .10913 Mdot
.962 .10913 Mdot
.962 .10914 Mdot
.962 .10915 Mdot
.962 .10917 Mdot
.962 .10918 Mdot
.962 .10919 Mdot
.962 .10922 Mdot
.962 .10925 Mdot
.962 .10926 Mdot
.962 .10926 Mdot
.962 .1093 Mdot
.962 .10932 Mdot
.962 .10933 Mdot
.962 .10935 Mdot
.962 .10939 Mdot
.962 .10942 Mdot
.962 .10946 Mdot
.962 .10956 Mdot
.962 .10958 Mdot
.962 .10967 Mdot
.962 .10974 Mdot
.962 .10977 Mdot
.962 .10981 Mdot
.962 .10984 Mdot
.962 .1099 Mdot
.962 .11004 Mdot
.962 .11006 Mdot
.962 .11014 Mdot
.962 .11019 Mdot
.962 .11029 Mdot
.962 .11034 Mdot
.962 .11037 Mdot
.962 .11043 Mdot
.962 .11054 Mdot
.962 .11086 Mdot
.962 .1109 Mdot
.962 .11097 Mdot
.962 .11101 Mdot
.962 .11113 Mdot
.962 .11125 Mdot
.962 .11131 Mdot
.962 .1114 Mdot
.962 .11147 Mdot
.962 .11147 Mdot
.962 .11164 Mdot
.962 .11168 Mdot
.962 .11173 Mdot
.962 .11183 Mdot
.962 .11222 Mdot
.962 .11259 Mdot
.962 .11264 Mdot
.962 .11265 Mdot
.962 .11279 Mdot
.962 .11285 Mdot
.962 .11293 Mdot
.962 .11331 Mdot
.962 .11336 Mdot
.962 .11339 Mdot
.962 .11365 Mdot
.962 .11373 Mdot
.962 .11401 Mdot
.962 .11422 Mdot
.962 .11455 Mdot
.962 .11511 Mdot
.962 .11537 Mdot
.962 .11539 Mdot
.962 .11541 Mdot
.962 .11543 Mdot
.962 .1158 Mdot
.962 .11643 Mdot
.962 .11651 Mdot
.962 .11656 Mdot
.962 .11662 Mdot
.962 .11683 Mdot
.962 .11696 Mdot
.962 .11698 Mdot
.962 .11702 Mdot
.962 .11715 Mdot
.962 .11718 Mdot
.962 .11755 Mdot
.962 .11758 Mdot
.962 .1178 Mdot
.962 .11807 Mdot
.962 .11807 Mdot
.962 .11817 Mdot
.962 .11895 Mdot
.962 .11906 Mdot
.962 .11915 Mdot
.962 .1193 Mdot
.962 .11987 Mdot
.962 .11994 Mdot
.962 .12034 Mdot
.962 .12034 Mdot
.962 .12039 Mdot
.962 .12052 Mdot
.962 .12208 Mdot
.962 .12225 Mdot
.962 .12229 Mdot
.962 .12237 Mdot
.962 .12249 Mdot
.962 .12285 Mdot
.962 .12303 Mdot
.962 .12365 Mdot
.962 .12401 Mdot
.962 .12417 Mdot
.962 .12422 Mdot
.962 .12448 Mdot
.962 .12479 Mdot
.962 .12479 Mdot
.962 .12524 Mdot
.962 .12543 Mdot
.962 .12548 Mdot
.962 .12559 Mdot
.962 .12574 Mdot
.962 .12578 Mdot
.962 .12617 Mdot
.962 .12657 Mdot
.962 .12681 Mdot
.962 .12844 Mdot
.962 .12853 Mdot
.962 .12861 Mdot
.962 .12886 Mdot
.962 .12919 Mdot
.962 .12944 Mdot
.962 .12946 Mdot
.962 .12968 Mdot
.962 .13016 Mdot
.962 .13035 Mdot
.962 .13045 Mdot
.962 .13084 Mdot
.962 .13111 Mdot
.962 .13116 Mdot
.962 .13191 Mdot
.962 .13197 Mdot
.962 .1323 Mdot
.962 .13246 Mdot
.962 .13361 Mdot
.962 .13413 Mdot
.962 .13413 Mdot
.962 .13461 Mdot
.962 .13465 Mdot
.962 .13496 Mdot
.962 .13503 Mdot
.962 .13547 Mdot
.962 .13574 Mdot
.962 .13577 Mdot
.962 .13692 Mdot
.962 .13793 Mdot
.962 .13849 Mdot
.962 .13853 Mdot
.962 .13861 Mdot
.962 .1396 Mdot
.962 .14033 Mdot
.962 .14058 Mdot
.962 .14062 Mdot
.962 .14071 Mdot
.962 .14078 Mdot
.962 .14092 Mdot
.962 .14107 Mdot
.962 .14145 Mdot
.962 .14145 Mdot
.962 .14146 Mdot
.962 .14146 Mdot
.962 .14146 Mdot
.962 .14146 Mdot
.962 .14148 Mdot
.962 .14148 Mdot
.962 .14149 Mdot
.962 .14149 Mdot
.962 .14149 Mdot
.962 .14149 Mdot
.962 .14151 Mdot
.962 .14151 Mdot
.962 .14151 Mdot
.962 .14151 Mdot
.962 .14154 Mdot
.962 .14155 Mdot
.962 .14156 Mdot
.962 .14157 Mdot
.962 .14158 Mdot
.962 .14158 Mdot
.962 .1416 Mdot
.962 .1416 Mdot
.962 .1416 Mdot
.962 .14161 Mdot
.962 .14162 Mdot
.962 .14163 Mdot
.962 .14163 Mdot
.962 .14165 Mdot
.962 .14165 Mdot
.962 .14165 Mdot
.962 .14165 Mdot
.962 .14166 Mdot
.962 .14166 Mdot
.962 .14167 Mdot
.962 .14169 Mdot
.962 .14171 Mdot
.962 .14175 Mdot
.962 .14176 Mdot
.962 .14176 Mdot
.962 .14179 Mdot
.962 .14179 Mdot
.962 .14184 Mdot
.962 .14187 Mdot
.962 .14188 Mdot
.962 .14188 Mdot
.962 .14188 Mdot
.962 .14188 Mdot
.962 .14191 Mdot
.962 .14194 Mdot
.962 .14195 Mdot
.962 .14196 Mdot
.962 .14197 Mdot
.962 .14198 Mdot
.962 .14198 Mdot
.962 .14199 Mdot
.962 .14201 Mdot
.962 .14203 Mdot
.962 .14204 Mdot
.962 .14205 Mdot
.962 .14205 Mdot
.962 .14206 Mdot
.962 .14207 Mdot
.962 .14208 Mdot
.962 .14209 Mdot
.962 .14211 Mdot
.962 .14211 Mdot
.962 .14211 Mdot
.962 .14214 Mdot
.962 .14214 Mdot
.962 .14223 Mdot
.962 .14229 Mdot
.962 .1423 Mdot
.962 .14237 Mdot
.962 .14241 Mdot
.962 .14243 Mdot
.962 .14244 Mdot
.962 .14249 Mdot
.962 .14256 Mdot
.962 .14257 Mdot
.962 .14263 Mdot
.962 .14273 Mdot
.962 .14285 Mdot
.962 .14285 Mdot
.962 .14288 Mdot
.962 .14288 Mdot
.962 .14295 Mdot
.962 .14299 Mdot
.962 .143 Mdot
.962 .14306 Mdot
.962 .14311 Mdot
.962 .14317 Mdot
.962 .14321 Mdot
.962 .14332 Mdot
.962 .14344 Mdot
.962 .14358 Mdot
.962 .14361 Mdot
.962 .14371 Mdot
.962 .14371 Mdot
.962 .1439 Mdot
.962 .14405 Mdot
.962 .14408 Mdot
.962 .14411 Mdot
.962 .14411 Mdot
.962 .14416 Mdot
.962 .14417 Mdot
.962 .14418 Mdot
.962 .14419 Mdot
.962 .14419 Mdot
.962 .14428 Mdot
.962 .14453 Mdot
.962 .14463 Mdot
.962 .14478 Mdot
.962 .14489 Mdot
.962 .1451 Mdot
.962 .14563 Mdot
.962 .14568 Mdot
.962 .14595 Mdot
.962 .14614 Mdot
.962 .1465 Mdot
.962 .14669 Mdot
.962 .14681 Mdot
.962 .14701 Mdot
.962 .1474 Mdot
.962 .14796 Mdot
.962 .1486 Mdot
.962 .14874 Mdot
.962 .14901 Mdot
.962 .14916 Mdot
.962 .14959 Mdot
.962 .15006 Mdot
.962 .15026 Mdot
.962 .15064 Mdot
.962 .15087 Mdot
.962 .15089 Mdot
.962 .15153 Mdot
.962 .15167 Mdot
.962 .15188 Mdot
.962 .15221 Mdot
.962 .15226 Mdot
.962 .15379 Mdot
.962 .15503 Mdot
.962 .15525 Mdot
.962 .15545 Mdot
.962 .15547 Mdot
.962 .15605 Mdot
.962 .15629 Mdot
.962 .15661 Mdot
.962 .15812 Mdot
.962 .15832 Mdot
.962 .15847 Mdot
.962 .15953 Mdot
.962 .15987 Mdot
.962 .16101 Mdot
.962 .16187 Mdot
.962 .16327 Mdot
.962 .16566 Mdot
.962 .16682 Mdot
.962 .1669 Mdot
.962 .16696 Mdot
.962 .16707 Mdot
.962 .16869 Mdot
.962 .17146 Mdot
.962 .17182 Mdot
.962 .17205 Mdot
.962 .17232 Mdot
.962 .17327 Mdot
.962 .17384 Mdot
.962 .17395 Mdot
.962 .17414 Mdot
.962 .1747 Mdot
.962 .17487 Mdot
.962 .17569 Mdot
.962 .17656 Mdot
.962 .17669 Mdot
.962 .17771 Mdot
.962 .17894 Mdot
.962 .17895 Mdot
.962 .17943 Mdot
.962 .18309 Mdot
.962 .18361 Mdot
.962 .18402 Mdot
.962 .18476 Mdot
.962 .1875 Mdot
.962 .18784 Mdot
.962 .18975 Mdot
.962 .18977 Mdot
.962 .18999 Mdot
.962 .19062 Mdot
.962 .19575 Mdot
.962 .19622 Mdot
.962 .19835 Mdot
.962 .19922 Mdot
.962 .19941 Mdot
.962 .19982 Mdot
.962 .20039 Mdot
.962 .2022 Mdot
.962 .20313 Mdot
.962 .20627 Mdot
.962 .20809 Mdot
.962 .20895 Mdot
.962 .2092 Mdot
.962 .21054 Mdot
.962 .21212 Mdot
.962 .21214 Mdot
.962 .21446 Mdot
.962 .21545 Mdot
.962 .21567 Mdot
.962 .21624 Mdot
.962 .21703 Mdot
.962 .21723 Mdot
.962 .21928 Mdot
.962 .22137 Mdot
.962 .22262 Mdot
.962 .23112 Mdot
.962 .23163 Mdot
.962 .23204 Mdot
.962 .23333 Mdot
.962 .23509 Mdot
.962 .23638 Mdot
.962 .23649 Mdot
.962 .23763 Mdot
.962 .24017 Mdot
.962 .24115 Mdot
.962 .24171 Mdot
.962 .24372 Mdot
.962 .24514 Mdot
.962 .24538 Mdot
.962 .24932 Mdot
.962 .24962 Mdot
.962 .25133 Mdot
.962 .25192 Mdot
.962 .25219 Mdot
.962 .25814 Mdot
.962 .26079 Mdot
.962 .26082 Mdot
.962 .26326 Mdot
.962 .26347 Mdot
.962 .26505 Mdot
.962 .26537 Mdot
.962 .2676 Mdot
.962 .269 Mdot
.962 .26912 Mdot
.962 .27488 Mdot
.962 .27983 Mdot
.962 .28255 Mdot
.962 .28272 Mdot
.962 .28314 Mdot
.962 .28783 Mdot
.962 .29125 Mdot
.962 .29239 Mdot
.962 .29259 Mdot
.962 .293 Mdot
.962 .29333 Mdot
.962 .29397 Mdot
.962 .29466 Mdot
.962 .2964 Mdot
.962 .2964 Mdot
.962 .29643 Mdot
.962 .29643 Mdot
.962 .29643 Mdot
.962 .29644 Mdot
.962 .29651 Mdot
.962 .29652 Mdot
.962 .29655 Mdot
.962 .29655 Mdot
.962 .29657 Mdot
.962 .29658 Mdot
.962 .29667 Mdot
.962 .29667 Mdot
.962 .29667 Mdot
.962 .29667 Mdot
.962 .29679 Mdot
.962 .29684 Mdot
.962 .29689 Mdot
.962 .29692 Mdot
.962 .29699 Mdot
.962 .29699 Mdot
.962 .29704 Mdot
.962 .29707 Mdot
.962 .29709 Mdot
.962 .29711 Mdot
.962 .29715 Mdot
.962 .29719 Mdot
.962 .29721 Mdot
.962 .29728 Mdot
.962 .29728 Mdot
.962 .29729 Mdot
.962 .29729 Mdot
.962 .29735 Mdot
.962 .29736 Mdot
.962 .29737 Mdot
.962 .29749 Mdot
.962 .29757 Mdot
.962 .29773 Mdot
.962 .2978 Mdot
.962 .2978 Mdot
.962 .2979 Mdot
.962 .29794 Mdot
.962 .29814 Mdot
.962 .29828 Mdot
.962 .2983 Mdot
.962 .29831 Mdot
.962 .29833 Mdot
.962 .29833 Mdot
.962 .29847 Mdot
.962 .2986 Mdot
.962 .29864 Mdot
.962 .29867 Mdot
.962 .29871 Mdot
.962 .29877 Mdot
.962 .29879 Mdot
.962 .2988 Mdot
.962 .29892 Mdot
.962 .29897 Mdot
.962 .29906 Mdot
.962 .29907 Mdot
.962 .29908 Mdot
.962 .29911 Mdot
.962 .29916 Mdot
.962 .29921 Mdot
.962 .29927 Mdot
.962 .29934 Mdot
.962 .29934 Mdot
.962 .29936 Mdot
.962 .29946 Mdot
.962 .29948 Mdot
.962 .29986 Mdot
.962 .30015 Mdot
.962 .30021 Mdot
.962 .30049 Mdot
.962 .3006 Mdot
.962 .30065 Mdot
.962 .30076 Mdot
.962 .30081 Mdot
.962 .30101 Mdot
.962 .30134 Mdot
.962 .3014 Mdot
.962 .30163 Mdot
.962 .30207 Mdot
.962 .30258 Mdot
.962 .30262 Mdot
.962 .30271 Mdot
.962 .30275 Mdot
.962 .30302 Mdot
.962 .30322 Mdot
.962 .30327 Mdot
.962 .30353 Mdot
.962 .30371 Mdot
.962 .304 Mdot
.962 .30415 Mdot
.962 .30463 Mdot
.962 .30514 Mdot
.962 .30573 Mdot
.962 .30587 Mdot
.962 .30629 Mdot
.962 .30631 Mdot
.962 .30712 Mdot
.962 .30775 Mdot
.962 .30786 Mdot
.962 .30797 Mdot
.962 .30797 Mdot
.962 .30821 Mdot
.962 .30822 Mdot
.962 .30826 Mdot
.962 .30832 Mdot
.962 .30833 Mdot
.962 .30871 Mdot
.962 .30974 Mdot
.962 .31016 Mdot
.962 .31077 Mdot
.962 .3112 Mdot
.962 .31206 Mdot
.962 .31418 Mdot
.962 .31439 Mdot
.962 .31548 Mdot
.962 .31621 Mdot
.962 .3176 Mdot
.962 .31831 Mdot
.962 .31877 Mdot
.962 .31954 Mdot
.962 .32102 Mdot
.962 .32305 Mdot
.962 .32535 Mdot
.962 .32584 Mdot
.962 .32677 Mdot
.962 .32731 Mdot
.962 .32877 Mdot
.962 .32906 Mdot
.962 .32906 Mdot
.962 .3292 Mdot
.962 .32952 Mdot
.962 .32983 Mdot
.962 .33012 Mdot
.962 .33033 Mdot
.962 .33035 Mdot
.962 .33046 Mdot
.962 .33051 Mdot
.962 .331 Mdot
.962 .33103 Mdot
.962 .33116 Mdot
.962 .33139 Mdot
.962 .3322 Mdot
.962 .33273 Mdot
.962 .33278 Mdot
.962 .33294 Mdot
.962 .33301 Mdot
.962 .33322 Mdot
.962 .33328 Mdot
.962 .33461 Mdot
.962 .33472 Mdot
.962 .33474 Mdot
.962 .33499 Mdot
.962 .33542 Mdot
.962 .33603 Mdot
.962 .33701 Mdot
.962 .33709 Mdot
.962 .33716 Mdot
.962 .3385 Mdot
.962 .33918 Mdot
.962 .34 Mdot
.962 .34031 Mdot
.962 .34033 Mdot
.962 .34039 Mdot
.962 .34084 Mdot
.962 .34142 Mdot
.962 .34205 Mdot
.962 .34286 Mdot
.962 .34296 Mdot
.962 .34343 Mdot
.962 .34379 Mdot
.962 .34401 Mdot
.962 .34425 Mdot
.962 .34454 Mdot
.962 .34507 Mdot
.962 .34555 Mdot
.962 .34559 Mdot
.962 .34692 Mdot
.962 .34725 Mdot
.962 .34745 Mdot
.962 .34815 Mdot
.962 .34828 Mdot
.962 .3483 Mdot
.962 .34883 Mdot
.962 .34941 Mdot
.962 .34953 Mdot
.962 .35117 Mdot
.962 .35153 Mdot
.962 .35181 Mdot
.962 .35189 Mdot
.962 .35361 Mdot
.962 .35388 Mdot
.962 .35414 Mdot
.962 .35416 Mdot
.962 .35472 Mdot
.962 .35473 Mdot
.962 .35544 Mdot
.962 .35578 Mdot
.962 .35581 Mdot
.962 .35606 Mdot
.962 .35652 Mdot
.962 .35686 Mdot
.962 .35706 Mdot
.962 .35718 Mdot
.962 .35796 Mdot
.962 .35834 Mdot
.962 .35861 Mdot
.962 .35874 Mdot
.962 .35884 Mdot
.962 .35896 Mdot
.962 .35914 Mdot
.962 .35921 Mdot
.962 .35926 Mdot
.962 .35934 Mdot
.962 .35943 Mdot
.962 .35968 Mdot
.962 .36008 Mdot
.962 .36009 Mdot
.962 .36018 Mdot
.962 .3603 Mdot
.962 .36039 Mdot
.962 .36052 Mdot
.962 .36059 Mdot
.962 .36062 Mdot
.962 .36063 Mdot
.962 .36067 Mdot
.962 .36095 Mdot
.962 .39275 Mdot
.962 .39506 Mdot
.962 .39693 Mdot
.962 .40299 Mdot
.962 .40964 Mdot
.962 .41147 Mdot
.962 .41781 Mdot
.962 .41839 Mdot
.962 .42414 Mdot
.962 .43714 Mdot
.962 .43869 Mdot
.962 .44173 Mdot
.962 .44224 Mdot
.962 .4452 Mdot
.962 .45573 Mdot
.962 .46316 Mdot
.962 .46445 Mdot
.962 .47486 Mdot
.962 .48429 Mdot
.962 .48482 Mdot
.962 .48633 Mdot
.962 .49488 Mdot
.962 .49783 Mdot
.962 .49915 Mdot
.962 .51646 Mdot
.962 .52645 Mdot
.962 .5372 Mdot
.962 .5373 Mdot
.962 .54149 Mdot
.962 .54632 Mdot
.962 .54704 Mdot
.962 .54817 Mdot
.962 .54922 Mdot
.962 .54922 Mdot
.962 .54922 Mdot
.962 .54922 Mdot
.962 .54922 Mdot
.962 .54924 Mdot
.962 .54924 Mdot
.962 .54925 Mdot
.962 .54926 Mdot
.962 .54935 Mdot
.962 .54935 Mdot
.962 .54938 Mdot
.962 .5495 Mdot
.962 .54956 Mdot
.962 .54957 Mdot
.962 .54959 Mdot
.962 .54974 Mdot
.962 .54976 Mdot
.962 .54984 Mdot
.962 .54991 Mdot
.962 .55001 Mdot
.962 .55012 Mdot
.962 .55017 Mdot
.962 .55021 Mdot
.962 .55023 Mdot
.962 .55026 Mdot
.962 .55027 Mdot
.962 .55035 Mdot
.962 .55057 Mdot
.962 .55087 Mdot
.962 .55089 Mdot
.962 .5509 Mdot
.962 .55108 Mdot
.962 .55139 Mdot
.962 .55176 Mdot
.962 .55177 Mdot
.962 .55186 Mdot
.962 .55201 Mdot
.962 .55203 Mdot
.962 .55213 Mdot
.962 .55214 Mdot
.962 .5523 Mdot
.962 .5523 Mdot
.962 .55247 Mdot
.962 .55287 Mdot
.962 .55292 Mdot
.962 .55304 Mdot
.962 .55306 Mdot
.962 .55332 Mdot
.962 .55334 Mdot
.962 .55344 Mdot
.962 .55357 Mdot
.962 .55361 Mdot
.962 .55368 Mdot
.962 .55386 Mdot
.962 .55394 Mdot
.962 .55394 Mdot
.962 .55403 Mdot
.962 .55416 Mdot
.962 .55425 Mdot
.962 .55428 Mdot
.962 .55432 Mdot
.962 .55494 Mdot
.962 .55504 Mdot
.962 .5552 Mdot
.962 .55536 Mdot
.962 .55537 Mdot
.962 .55544 Mdot
.962 .55548 Mdot
.962 .5555 Mdot
.962 .55558 Mdot
.962 .55576 Mdot
.962 .55577 Mdot
.962 .5559 Mdot
.962 .55601 Mdot
.962 .55603 Mdot
.962 .5561 Mdot
.962 .55625 Mdot
.962 .55652 Mdot
.962 .55661 Mdot
.962 .55677 Mdot
.962 .55682 Mdot
.962 .55686 Mdot
.962 .55688 Mdot
.962 .55695 Mdot
.962 .5577 Mdot
.962 .55776 Mdot
.962 .55778 Mdot
.962 .55779 Mdot
.962 .55798 Mdot
.962 .55802 Mdot
.962 .55831 Mdot
.962 .55839 Mdot
.962 .55844 Mdot
.962 .55849 Mdot
.962 .55892 Mdot
.962 .55897 Mdot
.962 .55897 Mdot
.962 .55912 Mdot
.962 .55925 Mdot
.962 .55926 Mdot
.962 .55948 Mdot
.962 .5595 Mdot
.962 .55981 Mdot
.962 .55985 Mdot
.962 .55988 Mdot
.962 .55993 Mdot
.962 .56058 Mdot
.962 .56059 Mdot
.962 .5606 Mdot
.962 .56078 Mdot
.962 .56117 Mdot
.962 .56141 Mdot
.962 .56156 Mdot
.962 .56177 Mdot
.962 .56183 Mdot
.962 .56204 Mdot
.962 .56207 Mdot
.962 .56211 Mdot
.962 .56242 Mdot
.962 .56249 Mdot
.962 .56254 Mdot
.962 .56267 Mdot
.962 .56271 Mdot
.962 .56305 Mdot
.962 .56343 Mdot
.962 .56353 Mdot
.962 .56359 Mdot
.962 .56381 Mdot
.962 .56387 Mdot
.962 .56398 Mdot
.962 .56404 Mdot
.962 .56436 Mdot
.962 .56445 Mdot
.962 .56491 Mdot
.962 .56506 Mdot
.962 .56519 Mdot
.962 .56526 Mdot
.962 .56541 Mdot
.962 .56549 Mdot
.962 .56561 Mdot
.962 .56563 Mdot
.962 .56598 Mdot
.962 .56603 Mdot
.962 .56611 Mdot
.962 .56616 Mdot
.962 .5663 Mdot
.962 .56647 Mdot
.962 .56651 Mdot
.962 .56672 Mdot
.962 .56681 Mdot
.962 .56689 Mdot
.962 .56699 Mdot
.962 .56704 Mdot
.962 .56707 Mdot
.962 .56712 Mdot
.962 .56722 Mdot
.962 .56724 Mdot
.962 .56724 Mdot
.962 .56734 Mdot
.962 .56743 Mdot
.962 .56747 Mdot
.962 .56749 Mdot
.962 .56756 Mdot
.962 .5676 Mdot
.962 .56761 Mdot
.962 .56763 Mdot
.962 .56775 Mdot
.962 .56782 Mdot
.962 .56799 Mdot
.962 .568 Mdot
.962 .56802 Mdot
.962 .56803 Mdot
.962 .56803 Mdot
.962 .56812 Mdot
.962 .56816 Mdot
.962 .56817 Mdot
.962 .56821 Mdot
.962 .56827 Mdot
.962 .56832 Mdot
.962 .56845 Mdot
.962 .56845 Mdot
.962 .56863 Mdot
.962 .56863 Mdot
.962 .56864 Mdot
.962 .56867 Mdot
.962 .56867 Mdot
.962 .5687 Mdot
.962 .56872 Mdot
.962 .56876 Mdot
.962 .56878 Mdot
.962 .56883 Mdot
.962 .56889 Mdot
.962 .56917 Mdot
.962 .56921 Mdot
.962 .56922 Mdot
.962 .56936 Mdot
.962 .56936 Mdot
.962 .56945 Mdot
.962 .56967 Mdot
.962 .56978 Mdot
.962 .56993 Mdot
.962 .56996 Mdot
.962 .56997 Mdot
.962 .57005 Mdot
.962 .57005 Mdot
.962 .57005 Mdot
.962 .57006 Mdot
.962 .57015 Mdot
.962 .57018 Mdot
.962 .57024 Mdot
.962 .57028 Mdot
.962 .57032 Mdot
.962 .57034 Mdot
.962 .57037 Mdot
.962 .57044 Mdot
.962 .57045 Mdot
.962 .57054 Mdot
.962 .57058 Mdot
.962 .57065 Mdot
.962 .57071 Mdot
.962 .57086 Mdot
.962 .57086 Mdot
.962 .57087 Mdot
.962 .57087 Mdot
.962 .57098 Mdot
.962 .571 Mdot
.962 .57102 Mdot
.962 .57102 Mdot
.962 .57106 Mdot
.962 .57108 Mdot
.962 .57116 Mdot
.962 .57118 Mdot
.962 .57118 Mdot
.962 .57119 Mdot
.962 .57122 Mdot
.962 .57122 Mdot
.962 .57341 Mdot
.962 .57424 Mdot
.962 .57497 Mdot
.962 .57518 Mdot
.962 .57533 Mdot
.962 .57578 Mdot
.962 .57599 Mdot
.962 .57714 Mdot
.962 .5798 Mdot
.962 .58012 Mdot
.962 .58098 Mdot
.962 .58108 Mdot
.962 .5811 Mdot
.962 .58113 Mdot
.964 .10904 Mdot
.964 .10904 Mdot
.964 .10904 Mdot
.964 .10904 Mdot
.964 .10904 Mdot
.964 .10904 Mdot
.964 .10904 Mdot
.964 .10904 Mdot
.964 .10904 Mdot
.964 .10905 Mdot
.964 .10905 Mdot
.964 .10906 Mdot
.964 .10906 Mdot
.964 .10907 Mdot
.964 .10908 Mdot
.964 .10908 Mdot
.964 .1091 Mdot
.964 .1091 Mdot
.964 .1091 Mdot
.964 .10911 Mdot
.964 .10911 Mdot
.964 .10914 Mdot
.964 .10914 Mdot
.964 .10915 Mdot
.964 .10916 Mdot
.964 .10917 Mdot
.964 .10921 Mdot
.964 .10921 Mdot
.964 .10922 Mdot
.964 .10924 Mdot
.964 .10924 Mdot
.964 .10926 Mdot
.964 .10926 Mdot
.964 .10927 Mdot
.964 .10927 Mdot
.964 .10927 Mdot
.964 .10932 Mdot
.964 .10934 Mdot
.964 .10937 Mdot
.964 .10939 Mdot
.964 .10942 Mdot
.964 .10955 Mdot
.964 .10965 Mdot
.964 .10978 Mdot
.964 .10987 Mdot
.964 .11003 Mdot
.964 .11005 Mdot
.964 .1101 Mdot
.964 .1101 Mdot
.964 .1101 Mdot
.964 .1101 Mdot
.964 .1101 Mdot
.964 .11011 Mdot
.964 .11011 Mdot
.964 .11011 Mdot
.964 .11011 Mdot
.964 .11017 Mdot
.964 .11017 Mdot
.964 .11033 Mdot
.964 .11034 Mdot
.964 .11042 Mdot
.964 .11047 Mdot
.964 .1105 Mdot
.964 .11056 Mdot
.964 .11063 Mdot
.964 .11081 Mdot
.964 .11082 Mdot
.964 .11088 Mdot
.964 .11092 Mdot
.964 .11096 Mdot
.964 .11098 Mdot
.964 .11099 Mdot
.964 .11101 Mdot
.964 .11105 Mdot
.964 .11106 Mdot
.964 .11108 Mdot
.964 .11112 Mdot
.964 .11138 Mdot
.964 .11139 Mdot
.964 .11143 Mdot
.964 .11169 Mdot
.964 .11173 Mdot
.964 .11178 Mdot
.964 .11181 Mdot
.964 .11184 Mdot
.964 .11193 Mdot
.964 .11197 Mdot
.964 .11205 Mdot
.964 .11209 Mdot
.964 .11217 Mdot
.964 .1122 Mdot
.964 .11222 Mdot
.964 .11222 Mdot
.964 .11226 Mdot
.964 .11231 Mdot
.964 .11231 Mdot
.964 .11248 Mdot
.964 .11275 Mdot
.964 .11287 Mdot
.964 .11292 Mdot
.964 .11298 Mdot
.964 .11312 Mdot
.964 .11334 Mdot
.964 .11339 Mdot
.964 .1136 Mdot
.964 .11382 Mdot
.964 .11383 Mdot
.964 .11393 Mdot
.964 .11397 Mdot
.964 .11399 Mdot
.964 .11399 Mdot
.964 .11402 Mdot
.964 .11419 Mdot
.964 .1143 Mdot
.964 .11441 Mdot
.964 .11443 Mdot
.964 .11445 Mdot
.964 .11451 Mdot
.964 .11453 Mdot
.964 .11458 Mdot
.964 .11459 Mdot
.964 .11464 Mdot
.964 .1147 Mdot
.964 .11474 Mdot
.964 .11483 Mdot
.964 .11484 Mdot
.964 .11486 Mdot
.964 .11489 Mdot
.964 .11489 Mdot
.964 .11489 Mdot
.964 .11493 Mdot
.964 .11507 Mdot
.964 .11513 Mdot
.964 .11542 Mdot
.964 .11545 Mdot
.964 .11554 Mdot
.964 .11561 Mdot
.964 .11574 Mdot
.964 .11574 Mdot
.964 .11589 Mdot
.964 .116 Mdot
.964 .11637 Mdot
.964 .11638 Mdot
.964 .11649 Mdot
.964 .1165 Mdot
.964 .11674 Mdot
.964 .11676 Mdot
.964 .11676 Mdot
.964 .11685 Mdot
.964 .1169 Mdot
.964 .11694 Mdot
.964 .11727 Mdot
.964 .11742 Mdot
.964 .11745 Mdot
.964 .11762 Mdot
.964 .11771 Mdot
.964 .11773 Mdot
.964 .11779 Mdot
.964 .11786 Mdot
.964 .118 Mdot
.964 .11809 Mdot
.964 .11811 Mdot
.964 .11818 Mdot
.964 .11821 Mdot
.964 .11822 Mdot
.964 .11824 Mdot
.964 .11836 Mdot
.964 .11846 Mdot
.964 .11851 Mdot
.964 .11868 Mdot
.964 .1187 Mdot
.964 .11871 Mdot
.964 .11872 Mdot
.964 .11875 Mdot
.964 .11887 Mdot
.964 .11974 Mdot
.964 .12046 Mdot
.964 .12055 Mdot
.964 .12094 Mdot
.964 .12109 Mdot
.964 .12119 Mdot
.964 .12132 Mdot
.964 .12136 Mdot
.964 .12197 Mdot
.964 .12201 Mdot
.964 .12211 Mdot
.964 .12236 Mdot
.964 .12271 Mdot
.964 .12278 Mdot
.964 .12396 Mdot
.964 .12451 Mdot
.964 .12479 Mdot
.964 .12507 Mdot
.964 .12532 Mdot
.964 .12629 Mdot
.964 .12683 Mdot
.964 .12737 Mdot
.964 .12804 Mdot
.964 .12819 Mdot
.964 .12841 Mdot
.964 .12855 Mdot
.964 .12993 Mdot
.964 .12997 Mdot
.964 .13008 Mdot
.964 .13121 Mdot
.964 .13189 Mdot
.964 .13216 Mdot
.964 .13253 Mdot
.964 .13268 Mdot
.964 .13374 Mdot
.964 .13468 Mdot
.964 .13496 Mdot
.964 .13514 Mdot
.964 .13539 Mdot
.964 .13574 Mdot
.964 .1367 Mdot
.964 .13683 Mdot
.964 .13728 Mdot
.964 .1373 Mdot
.964 .13743 Mdot
.964 .13804 Mdot
.964 .1381 Mdot
.964 .13825 Mdot
.964 .13844 Mdot
.964 .13844 Mdot
.964 .13846 Mdot
.964 .13898 Mdot
.964 .13906 Mdot
.964 .13912 Mdot
.964 .13925 Mdot
.964 .13936 Mdot
.964 .13951 Mdot
.964 .13953 Mdot
.964 .13956 Mdot
.964 .13975 Mdot
.964 .13978 Mdot
.964 .13985 Mdot
.964 .13989 Mdot
.964 .14002 Mdot
.964 .14004 Mdot
.964 .14005 Mdot
.964 .14007 Mdot
.964 .14008 Mdot
.964 .14008 Mdot
.964 .14014 Mdot
.964 .14016 Mdot
.964 .14021 Mdot
.964 .14021 Mdot
.964 .14022 Mdot
.964 .14043 Mdot
.964 .14044 Mdot
.964 .14048 Mdot
.964 .14054 Mdot
.964 .14057 Mdot
.964 .14058 Mdot
.964 .1406 Mdot
.964 .14062 Mdot
.964 .14065 Mdot
.964 .1407 Mdot
.964 .14238 Mdot
.964 .14238 Mdot
.964 .14238 Mdot
.964 .14238 Mdot
.964 .14238 Mdot
.964 .14238 Mdot
.964 .14238 Mdot
.964 .14238 Mdot
.964 .14239 Mdot
.964 .1424 Mdot
.964 .1424 Mdot
.964 .14244 Mdot
.964 .14244 Mdot
.964 .14248 Mdot
.964 .1425 Mdot
.964 .14251 Mdot
.964 .14257 Mdot
.964 .14258 Mdot
.964 .14259 Mdot
.964 .1426 Mdot
.964 .14261 Mdot
.964 .14272 Mdot
.964 .14273 Mdot
.964 .14275 Mdot
.964 .14278 Mdot
.964 .14282 Mdot
.964 .14295 Mdot
.964 .14298 Mdot
.964 .14298 Mdot
.964 .14306 Mdot
.964 .14307 Mdot
.964 .14312 Mdot
.964 .14312 Mdot
.964 .14317 Mdot
.964 .14318 Mdot
.964 .14318 Mdot
.964 .14335 Mdot
.964 .14341 Mdot
.964 .1435 Mdot
.964 .1436 Mdot
.964 .1437 Mdot
.964 .14399 Mdot
.964 .14416 Mdot
.964 .1445 Mdot
.964 .14495 Mdot
.964 .14526 Mdot
.964 .14584 Mdot
.964 .14593 Mdot
.964 .14608 Mdot
.964 .14609 Mdot
.964 .14609 Mdot
.964 .14609 Mdot
.964 .14612 Mdot
.964 .14613 Mdot
.964 .14614 Mdot
.964 .14614 Mdot
.964 .14615 Mdot
.964 .14634 Mdot
.964 .14635 Mdot
.964 .14694 Mdot
.964 .14695 Mdot
.964 .14727 Mdot
.964 .14745 Mdot
.964 .14753 Mdot
.964 .14779 Mdot
.964 .14802 Mdot
.964 .14868 Mdot
.964 .14873 Mdot
.964 .14897 Mdot
.964 .14909 Mdot
.964 .14926 Mdot
.964 .14931 Mdot
.964 .14936 Mdot
.964 .14945 Mdot
.964 .14958 Mdot
.964 .14962 Mdot
.964 .1497 Mdot
.964 .14986 Mdot
.964 .15081 Mdot
.964 .15087 Mdot
.964 .15101 Mdot
.964 .15201 Mdot
.964 .15215 Mdot
.964 .15236 Mdot
.964 .15246 Mdot
.964 .1526 Mdot
.964 .15292 Mdot
.964 .1531 Mdot
.964 .15339 Mdot
.964 .15357 Mdot
.964 .15386 Mdot
.964 .15398 Mdot
.964 .15406 Mdot
.964 .15407 Mdot
.964 .15424 Mdot
.964 .15442 Mdot
.964 .15443 Mdot
.964 .15508 Mdot
.964 .15617 Mdot
.964 .15666 Mdot
.964 .15686 Mdot
.964 .15709 Mdot
.964 .15767 Mdot
.964 .15855 Mdot
.964 .15874 Mdot
.964 .15961 Mdot
.964 .16054 Mdot
.964 .16056 Mdot
.964 .16099 Mdot
.964 .16115 Mdot
.964 .16123 Mdot
.964 .16124 Mdot
.964 .16137 Mdot
.964 .16207 Mdot
.964 .16255 Mdot
.964 .16301 Mdot
.964 .16308 Mdot
.964 .16318 Mdot
.964 .16342 Mdot
.964 .1635 Mdot
.964 .16372 Mdot
.964 .16376 Mdot
.964 .16398 Mdot
.964 .16422 Mdot
.964 .16439 Mdot
.964 .16479 Mdot
.964 .16484 Mdot
.964 .1649 Mdot
.964 .16503 Mdot
.964 .16505 Mdot
.964 .16505 Mdot
.964 .16522 Mdot
.964 .16581 Mdot
.964 .16608 Mdot
.964 .16732 Mdot
.964 .16746 Mdot
.964 .16785 Mdot
.964 .16814 Mdot
.964 .16873 Mdot
.964 .16874 Mdot
.964 .16939 Mdot
.964 .16987 Mdot
.964 .17153 Mdot
.964 .17156 Mdot
.964 .17204 Mdot
.964 .17212 Mdot
.964 .17317 Mdot
.964 .17327 Mdot
.964 .17329 Mdot
.964 .17369 Mdot
.964 .17393 Mdot
.964 .17407 Mdot
.964 .17559 Mdot
.964 .17629 Mdot
.964 .17643 Mdot
.964 .17719 Mdot
.964 .17762 Mdot
.964 .17773 Mdot
.964 .17799 Mdot
.964 .17831 Mdot
.964 .17897 Mdot
.964 .17936 Mdot
.964 .17948 Mdot
.964 .17981 Mdot
.964 .17994 Mdot
.964 .17997 Mdot
.964 .18007 Mdot
.964 .18063 Mdot
.964 .18113 Mdot
.964 .18134 Mdot
.964 .18215 Mdot
.964 .18226 Mdot
.964 .18228 Mdot
.964 .18246 Mdot
.964 .18305 Mdot
.964 .18723 Mdot
.964 .1907 Mdot
.964 .19117 Mdot
.964 .19307 Mdot
.964 .19383 Mdot
.964 .19428 Mdot
.964 .19483 Mdot
.964 .19493 Mdot
.964 .19516 Mdot
.964 .19818 Mdot
.964 .19836 Mdot
.964 .19889 Mdot
.964 .20013 Mdot
.964 .20189 Mdot
.964 .20227 Mdot
.964 .20828 Mdot
.964 .2111 Mdot
.964 .21254 Mdot
.964 .21399 Mdot
.964 .21526 Mdot
.964 .22033 Mdot
.964 .22133 Mdot
.964 .22314 Mdot
.964 .22597 Mdot
.964 .22951 Mdot
.964 .23028 Mdot
.964 .23145 Mdot
.964 .23215 Mdot
.964 .23942 Mdot
.964 .23962 Mdot
.964 .24021 Mdot
.964 .24614 Mdot
.964 .24969 Mdot
.964 .25112 Mdot
.964 .25306 Mdot
.964 .25382 Mdot
.964 .25931 Mdot
.964 .26411 Mdot
.964 .26556 Mdot
.964 .26649 Mdot
.964 .26773 Mdot
.964 .2695 Mdot
.964 .2743 Mdot
.964 .27495 Mdot
.964 .27717 Mdot
.964 .27729 Mdot
.964 .27791 Mdot
.964 .28093 Mdot
.964 .2812 Mdot
.964 .28192 Mdot
.964 .28285 Mdot
.964 .28288 Mdot
.964 .28297 Mdot
.964 .28547 Mdot
.964 .28583 Mdot
.964 .28611 Mdot
.964 .28677 Mdot
.964 .28728 Mdot
.964 .28797 Mdot
.964 .28809 Mdot
.964 .2882 Mdot
.964 .28913 Mdot
.964 .28926 Mdot
.964 .28957 Mdot
.964 .28978 Mdot
.964 .29037 Mdot
.964 .2905 Mdot
.964 .29054 Mdot
.964 .2906 Mdot
.964 .29065 Mdot
.964 .29066 Mdot
.964 .29094 Mdot
.964 .29106 Mdot
.964 .29126 Mdot
.964 .29126 Mdot
.964 .29132 Mdot
.964 .29228 Mdot
.964 .29234 Mdot
.964 .29251 Mdot
.964 .29279 Mdot
.964 .29297 Mdot
.964 .29301 Mdot
.964 .29308 Mdot
.964 .29319 Mdot
.964 .29332 Mdot
.964 .29353 Mdot
.964 .30114 Mdot
.964 .30114 Mdot
.964 .30114 Mdot
.964 .30114 Mdot
.964 .30115 Mdot
.964 .30115 Mdot
.964 .30116 Mdot
.964 .30116 Mdot
.964 .30116 Mdot
.964 .30123 Mdot
.964 .30123 Mdot
.964 .30141 Mdot
.964 .30142 Mdot
.964 .30159 Mdot
.964 .30166 Mdot
.964 .30172 Mdot
.964 .30196 Mdot
.964 .30204 Mdot
.964 .30205 Mdot
.964 .30212 Mdot
.964 .30214 Mdot
.964 .30264 Mdot
.964 .30266 Mdot
.964 .30275 Mdot
.964 .3029 Mdot
.964 .30309 Mdot
.964 .30362 Mdot
.964 .30375 Mdot
.964 .30378 Mdot
.964 .30412 Mdot
.964 .30415 Mdot
.964 .30437 Mdot
.964 .30438 Mdot
.964 .3046 Mdot
.964 .30462 Mdot
.964 .30462 Mdot
.964 .30537 Mdot
.964 .30562 Mdot
.964 .30603 Mdot
.964 .30645 Mdot
.964 .30687 Mdot
.964 .30808 Mdot
.964 .30879 Mdot
.964 .31022 Mdot
.964 .31206 Mdot
.964 .31332 Mdot
.964 .31565 Mdot
.964 .316 Mdot
.964 .31661 Mdot
.964 .31663 Mdot
.964 .31665 Mdot
.964 .31665 Mdot
.964 .31674 Mdot
.964 .31677 Mdot
.964 .31684 Mdot
.964 .31684 Mdot
.964 .31686 Mdot
.964 .31763 Mdot
.964 .31767 Mdot
.964 .31992 Mdot
.964 .31997 Mdot
.964 .32114 Mdot
.964 .32184 Mdot
.964 .32214 Mdot
.964 .32307 Mdot
.964 .32391 Mdot
.964 .32628 Mdot
.964 .32644 Mdot
.964 .32728 Mdot
.964 .32773 Mdot
.964 .32831 Mdot
.964 .32846 Mdot
.964 .32864 Mdot
.964 .32893 Mdot
.964 .32937 Mdot
.964 .32952 Mdot
.964 .3298 Mdot
.964 .32984 Mdot
.964 .32993 Mdot
.964 .33034 Mdot
.964 .33061 Mdot
.964 .3313 Mdot
.964 .33132 Mdot
.964 .33168 Mdot
.964 .33181 Mdot
.964 .33342 Mdot
.964 .33354 Mdot
.964 .33358 Mdot
.964 .33404 Mdot
.964 .33405 Mdot
.964 .33448 Mdot
.964 .33472 Mdot
.964 .33481 Mdot
.964 .33541 Mdot
.964 .33591 Mdot
.964 .33599 Mdot
.964 .33678 Mdot
.964 .3371 Mdot
.964 .3375 Mdot
.964 .33811 Mdot
.964 .33832 Mdot
.964 .33841 Mdot
.964 .33881 Mdot
.964 .33913 Mdot
.964 .33972 Mdot
.964 .33975 Mdot
.964 .34021 Mdot
.964 .3407 Mdot
.964 .34101 Mdot
.964 .34135 Mdot
.964 .34151 Mdot
.964 .34229 Mdot
.964 .3426 Mdot
.964 .3428 Mdot
.964 .34283 Mdot
.964 .34326 Mdot
.964 .34372 Mdot
.964 .34374 Mdot
.964 .34388 Mdot
.964 .34449 Mdot
.964 .34535 Mdot
.964 .34788 Mdot
.964 .34896 Mdot
.964 .34938 Mdot
.964 .34985 Mdot
.964 .35029 Mdot
.964 .35102 Mdot
.964 .35107 Mdot
.964 .35132 Mdot
.964 .35134 Mdot
.964 .35149 Mdot
.964 .35253 Mdot
.964 .35264 Mdot
.964 .3528 Mdot
.964 .35298 Mdot
.964 .35307 Mdot
.964 .35343 Mdot
.964 .3538 Mdot
.964 .35411 Mdot
.964 .35423 Mdot
.964 .35426 Mdot
.964 .35443 Mdot
.964 .35444 Mdot
.964 .35482 Mdot
.964 .35495 Mdot
.964 .3554 Mdot
.964 .35583 Mdot
.964 .35587 Mdot
.964 .35604 Mdot
.964 .35613 Mdot
.964 .35646 Mdot
.964 .35647 Mdot
.964 .35668 Mdot
.964 .35675 Mdot
.964 .35678 Mdot
.964 .3568 Mdot
.964 .35686 Mdot
.964 .35695 Mdot
.964 .35729 Mdot
.964 .3578 Mdot
.964 .35802 Mdot
.964 .35814 Mdot
.964 .35834 Mdot
.964 .35875 Mdot
.964 .35881 Mdot
.964 .35887 Mdot
.964 .35897 Mdot
.964 .35919 Mdot
.964 .35927 Mdot
.964 .35946 Mdot
.964 .3595 Mdot
.964 .35968 Mdot
.964 .35968 Mdot
.964 .35987 Mdot
.964 .3599 Mdot
.964 .36 Mdot
.964 .36 Mdot
.964 .36015 Mdot
.964 .36028 Mdot
.964 .36031 Mdot
.964 .36035 Mdot
.964 .36039 Mdot
.964 .3604 Mdot
.964 .36044 Mdot
.964 .36045 Mdot
.964 .36045 Mdot
.964 .36046 Mdot
.964 .36056 Mdot
.964 .36088 Mdot
.964 .36098 Mdot
.964 .36101 Mdot
.964 .36102 Mdot
.964 .36121 Mdot
.964 .36121 Mdot
.964 .36133 Mdot
.964 .36146 Mdot
.964 .36149 Mdot
.964 .36157 Mdot
.964 .36162 Mdot
.964 .36162 Mdot
.964 .36166 Mdot
.964 .36167 Mdot
.964 .36167 Mdot
.964 .36185 Mdot
.964 .36373 Mdot
.964 .36743 Mdot
.964 .37204 Mdot
.964 .38645 Mdot
.964 .38982 Mdot
.964 .39503 Mdot
.964 .39825 Mdot
.964 .43413 Mdot
.964 .43517 Mdot
.964 .43827 Mdot
.964 .46936 Mdot
.964 .48766 Mdot
.964 .49487 Mdot
.964 .50438 Mdot
.964 .50801 Mdot
.964 .53237 Mdot
.964 .53756 Mdot
.964 .54935 Mdot
.964 .55031 Mdot
.964 .55033 Mdot
.964 .55033 Mdot
.964 .55034 Mdot
.964 .55035 Mdot
.964 .55035 Mdot
.964 .55036 Mdot
.964 .55038 Mdot
.964 .55039 Mdot
.964 .55039 Mdot
.964 .55046 Mdot
.964 .55046 Mdot
.964 .55046 Mdot
.964 .55047 Mdot
.964 .55048 Mdot
.964 .5505 Mdot
.964 .5505 Mdot
.964 .5505 Mdot
.964 .55051 Mdot
.964 .55051 Mdot
.964 .55052 Mdot
.964 .55056 Mdot
.964 .55057 Mdot
.964 .55059 Mdot
.964 .5506 Mdot
.964 .55066 Mdot
.964 .55066 Mdot
.964 .55067 Mdot
.964 .55072 Mdot
.964 .55075 Mdot
.964 .55079 Mdot
.964 .55081 Mdot
.964 .55083 Mdot
.964 .55099 Mdot
.964 .551 Mdot
.964 .551 Mdot
.964 .55106 Mdot
.964 .55111 Mdot
.964 .55112 Mdot
.964 .55132 Mdot
.964 .55136 Mdot
.964 .55136 Mdot
.964 .55151 Mdot
.964 .55155 Mdot
.964 .55186 Mdot
.964 .55197 Mdot
.964 .55205 Mdot
.964 .55211 Mdot
.964 .5522 Mdot
.964 .55251 Mdot
.964 .55288 Mdot
.964 .55293 Mdot
.964 .55305 Mdot
.964 .55315 Mdot
.964 .55339 Mdot
.964 .5538 Mdot
.964 .55384 Mdot
.964 .55385 Mdot
.964 .55436 Mdot
.964 .55442 Mdot
.964 .5545 Mdot
.964 .55456 Mdot
.964 .55482 Mdot
.964 .55503 Mdot
.964 .55524 Mdot
.964 .55564 Mdot
.964 .55574 Mdot
.964 .55586 Mdot
.964 .55598 Mdot
.964 .55621 Mdot
.964 .55674 Mdot
.964 .55677 Mdot
.964 .55693 Mdot
.964 .55704 Mdot
.964 .55709 Mdot
.964 .55711 Mdot
.964 .55739 Mdot
.964 .55742 Mdot
.964 .55748 Mdot
.964 .55752 Mdot
.964 .5576 Mdot
.964 .55779 Mdot
.964 .55784 Mdot
.964 .5582 Mdot
.964 .55865 Mdot
.964 .55872 Mdot
.964 .55876 Mdot
.964 .55887 Mdot
.964 .55901 Mdot
.964 .55903 Mdot
.964 .55913 Mdot
.964 .55921 Mdot
.964 .55925 Mdot
.964 .55935 Mdot
.964 .55944 Mdot
.964 .55955 Mdot
.964 .55977 Mdot
.964 .55985 Mdot
.964 .55987 Mdot
.964 .56001 Mdot
.964 .56002 Mdot
.964 .56009 Mdot
.964 .56009 Mdot
.964 .5605 Mdot
.964 .56063 Mdot
.964 .56069 Mdot
.964 .56091 Mdot
.964 .56107 Mdot
.964 .56107 Mdot
.964 .56108 Mdot
.964 .56111 Mdot
.964 .56111 Mdot
.964 .56133 Mdot
.964 .56135 Mdot
.964 .56139 Mdot
.964 .5614 Mdot
.964 .56142 Mdot
.964 .56171 Mdot
.964 .56175 Mdot
.964 .56186 Mdot
.964 .56204 Mdot
.964 .56221 Mdot
.964 .56225 Mdot
.964 .56243 Mdot
.964 .56264 Mdot
.964 .56316 Mdot
.964 .56325 Mdot
.964 .5633 Mdot
.964 .56342 Mdot
.964 .56354 Mdot
.964 .56362 Mdot
.964 .56366 Mdot
.964 .56374 Mdot
.964 .56378 Mdot
.964 .56411 Mdot
.964 .56412 Mdot
.964 .56442 Mdot
.964 .56447 Mdot
.964 .5645 Mdot
.964 .56451 Mdot
.964 .56455 Mdot
.964 .56458 Mdot
.964 .5646 Mdot
.964 .56462 Mdot
.964 .56467 Mdot
.964 .56472 Mdot
.964 .5648 Mdot
.964 .56482 Mdot
.964 .56506 Mdot
.964 .56515 Mdot
.964 .56524 Mdot
.964 .56528 Mdot
.964 .56548 Mdot
.964 .56549 Mdot
.964 .56575 Mdot
.964 .56575 Mdot
.964 .56584 Mdot
.964 .56584 Mdot
.964 .56584 Mdot
.964 .56585 Mdot
.964 .56586 Mdot
.964 .56587 Mdot
.964 .56587 Mdot
.964 .56587 Mdot
.964 .56587 Mdot
.964 .56595 Mdot
.964 .56599 Mdot
.964 .56629 Mdot
.964 .56647 Mdot
.964 .56674 Mdot
.964 .56732 Mdot
.964 .5674 Mdot
.964 .56749 Mdot
.964 .56763 Mdot
.964 .56794 Mdot
.964 .56804 Mdot
.964 .56831 Mdot
.964 .56836 Mdot
.964 .56861 Mdot
.964 .56862 Mdot
.964 .56888 Mdot
.964 .56892 Mdot
.964 .56906 Mdot
.964 .56906 Mdot
.964 .56927 Mdot
.964 .56945 Mdot
.964 .56949 Mdot
.964 .56955 Mdot
.964 .5696 Mdot
.964 .56961 Mdot
.964 .56967 Mdot
.964 .56969 Mdot
.964 .56969 Mdot
.964 .56969 Mdot
.964 .56983 Mdot
.964 .57027 Mdot
.964 .57041 Mdot
.964 .57045 Mdot
.964 .57046 Mdot
.964 .57071 Mdot
.964 .57072 Mdot
.964 .57088 Mdot
.964 .57105 Mdot
.964 .5711 Mdot
.964 .57121 Mdot
.964 .57127 Mdot
.964 .57127 Mdot
.964 .57133 Mdot
.964 .57134 Mdot
.964 .57134 Mdot
.964 .57158 Mdot
.964 .57222 Mdot
.964 .574 Mdot
.964 .57547 Mdot
.964 .57591 Mdot
.964 .57614 Mdot
.964 .57629 Mdot
.964 .57641 Mdot
.964 .57644 Mdot
.964 .57649 Mdot
.964 .57654 Mdot
.964 .57673 Mdot
.964 .57703 Mdot
.964 .57721 Mdot
.964 .57727 Mdot
.964 .57813 Mdot
.964 .57823 Mdot
.964 .57829 Mdot
.964 .57829 Mdot
.964 .57848 Mdot
.964 .57859 Mdot
.964 .57885 Mdot
.964 .57886 Mdot
.964 .57891 Mdot
.964 .57896 Mdot
.964 .579 Mdot
.964 .5791 Mdot
.964 .57917 Mdot
.964 .57929 Mdot
.964 .5796 Mdot
.964 .57977 Mdot
.964 .57988 Mdot
.964 .58001 Mdot
.964 .58011 Mdot
.964 .58074 Mdot
.964 .58082 Mdot
.964 .58089 Mdot
.964 .58128 Mdot
.964 .58151 Mdot
.964 .58153 Mdot
.964 .58181 Mdot
.964 .58183 Mdot
.964 .58191 Mdot
.964 .58193 Mdot
.964 .58202 Mdot
.964 .58214 Mdot
.964 .58229 Mdot
.964 .58229 Mdot
.964 .5823 Mdot
.966 .10924 Mdot
.966 .10924 Mdot
.966 .10924 Mdot
.966 .10924 Mdot
.966 .10924 Mdot
.966 .10925 Mdot
.966 .10925 Mdot
.966 .10925 Mdot
.966 .10925 Mdot
.966 .10928 Mdot
.966 .10928 Mdot
.966 .10928 Mdot
.966 .1093 Mdot
.966 .10931 Mdot
.966 .10931 Mdot
.966 .10932 Mdot
.966 .10934 Mdot
.966 .10935 Mdot
.966 .10937 Mdot
.966 .10939 Mdot
.966 .10943 Mdot
.966 .10944 Mdot
.966 .10944 Mdot
.966 .10946 Mdot
.966 .10951 Mdot
.966 .10953 Mdot
.966 .10963 Mdot
.966 .10965 Mdot
.966 .10966 Mdot
.966 .1097 Mdot
.966 .10971 Mdot
.966 .10972 Mdot
.966 .10972 Mdot
.966 .10978 Mdot
.966 .10978 Mdot
.966 .10988 Mdot
.966 .1099 Mdot
.966 .10991 Mdot
.966 .10992 Mdot
.966 .10994 Mdot
.966 .10997 Mdot
.966 .10998 Mdot
.966 .10999 Mdot
.966 .11003 Mdot
.966 .11005 Mdot
.966 .11006 Mdot
.966 .11008 Mdot
.966 .11009 Mdot
.966 .1101 Mdot
.966 .11011 Mdot
.966 .11018 Mdot
.966 .1102 Mdot
.966 .11021 Mdot
.966 .11023 Mdot
.966 .11024 Mdot
.966 .11025 Mdot
.966 .11027 Mdot
.966 .11027 Mdot
.966 .11028 Mdot
.966 .11029 Mdot
.966 .1103 Mdot
.966 .1103 Mdot
.966 .1103 Mdot
.966 .11031 Mdot
.966 .11031 Mdot
.966 .11031 Mdot
.966 .11031 Mdot
.966 .11055 Mdot
.966 .11062 Mdot
.966 .1108 Mdot
.966 .11082 Mdot
.966 .11091 Mdot
.966 .11111 Mdot
.966 .11118 Mdot
.966 .11122 Mdot
.966 .11126 Mdot
.966 .1114 Mdot
.966 .1114 Mdot
.966 .11196 Mdot
.966 .11206 Mdot
.966 .1121 Mdot
.966 .11216 Mdot
.966 .11218 Mdot
.966 .11271 Mdot
.966 .1128 Mdot
.966 .11314 Mdot
.966 .11328 Mdot
.966 .11336 Mdot
.966 .11365 Mdot
.966 .11391 Mdot
.966 .11399 Mdot
.966 .11414 Mdot
.966 .11415 Mdot
.966 .11428 Mdot
.966 .1143 Mdot
.966 .11484 Mdot
.966 .11491 Mdot
.966 .11496 Mdot
.966 .11521 Mdot
.966 .11548 Mdot
.966 .11555 Mdot
.966 .11562 Mdot
.966 .11565 Mdot
.966 .11577 Mdot
.966 .11578 Mdot
.966 .11582 Mdot
.966 .11587 Mdot
.966 .11592 Mdot
.966 .116 Mdot
.966 .11601 Mdot
.966 .11605 Mdot
.966 .11607 Mdot
.966 .1161 Mdot
.966 .1162 Mdot
.966 .11622 Mdot
.966 .11623 Mdot
.966 .11625 Mdot
.966 .11632 Mdot
.966 .11633 Mdot
.966 .11634 Mdot
.966 .11636 Mdot
.966 .11639 Mdot
.966 .11641 Mdot
.966 .11657 Mdot
.966 .11682 Mdot
.966 .11696 Mdot
.966 .11698 Mdot
.966 .11698 Mdot
.966 .11703 Mdot
.966 .11703 Mdot
.966 .11704 Mdot
.966 .11709 Mdot
.966 .11709 Mdot
.966 .11709 Mdot
.966 .11717 Mdot
.966 .11722 Mdot
.966 .11724 Mdot
.966 .11746 Mdot
.966 .11757 Mdot
.966 .11759 Mdot
.966 .11766 Mdot
.966 .11789 Mdot
.966 .11799 Mdot
.966 .11808 Mdot
.966 .11846 Mdot
.966 .11846 Mdot
.966 .11847 Mdot
.966 .11852 Mdot
.966 .11889 Mdot
.966 .11896 Mdot
.966 .11903 Mdot
.966 .11907 Mdot
.966 .11927 Mdot
.966 .11934 Mdot
.966 .11954 Mdot
.966 .11976 Mdot
.966 .11981 Mdot
.966 .11986 Mdot
.966 .12017 Mdot
.966 .1204 Mdot
.966 .12051 Mdot
.966 .12061 Mdot
.966 .12078 Mdot
.966 .12078 Mdot
.966 .12095 Mdot
.966 .12147 Mdot
.966 .12207 Mdot
.966 .12242 Mdot
.966 .12251 Mdot
.966 .12253 Mdot
.966 .12303 Mdot
.966 .12305 Mdot
.966 .12311 Mdot
.966 .12312 Mdot
.966 .12361 Mdot
.966 .12422 Mdot
.966 .12438 Mdot
.966 .12471 Mdot
.966 .12512 Mdot
.966 .12528 Mdot
.966 .12538 Mdot
.966 .1256 Mdot
.966 .12584 Mdot
.966 .12599 Mdot
.966 .12607 Mdot
.966 .12742 Mdot
.966 .12777 Mdot
.966 .12807 Mdot
.966 .12814 Mdot
.966 .12849 Mdot
.966 .1288 Mdot
.966 .12962 Mdot
.966 .13034 Mdot
.966 .13038 Mdot
.966 .131 Mdot
.966 .13133 Mdot
.966 .13144 Mdot
.966 .13147 Mdot
.966 .1315 Mdot
.966 .13247 Mdot
.966 .13314 Mdot
.966 .13327 Mdot
.966 .13346 Mdot
.966 .134 Mdot
.966 .13402 Mdot
.966 .13455 Mdot
.966 .13498 Mdot
.966 .135 Mdot
.966 .13502 Mdot
.966 .13502 Mdot
.966 .1351 Mdot
.966 .13512 Mdot
.966 .13514 Mdot
.966 .13523 Mdot
.966 .13528 Mdot
.966 .13536 Mdot
.966 .13537 Mdot
.966 .13544 Mdot
.966 .1355 Mdot
.966 .1355 Mdot
.966 .13562 Mdot
.966 .13568 Mdot
.966 .13568 Mdot
.966 .1357 Mdot
.966 .13586 Mdot
.966 .13598 Mdot
.966 .136 Mdot
.966 .13608 Mdot
.966 .13618 Mdot
.966 .13622 Mdot
.966 .13631 Mdot
.966 .13636 Mdot
.966 .13639 Mdot
.966 .1366 Mdot
.966 .13662 Mdot
.966 .13667 Mdot
.966 .13669 Mdot
.966 .13674 Mdot
.966 .13679 Mdot
.966 .13683 Mdot
.966 .13692 Mdot
.966 .13697 Mdot
.966 .13701 Mdot
.966 .13702 Mdot
.966 .13709 Mdot
.966 .13712 Mdot
.966 .13715 Mdot
.966 .13722 Mdot
.966 .13725 Mdot
.966 .13726 Mdot
.966 .13727 Mdot
.966 .13727 Mdot
.966 .13728 Mdot
.966 .13729 Mdot
.966 .13729 Mdot
.966 .13883 Mdot
.966 .14332 Mdot
.966 .14333 Mdot
.966 .14333 Mdot
.966 .14334 Mdot
.966 .14335 Mdot
.966 .14336 Mdot
.966 .14337 Mdot
.966 .14337 Mdot
.966 .14338 Mdot
.966 .14346 Mdot
.966 .14347 Mdot
.966 .14347 Mdot
.966 .14353 Mdot
.966 .14356 Mdot
.966 .14357 Mdot
.966 .14362 Mdot
.966 .14368 Mdot
.966 .14372 Mdot
.966 .14377 Mdot
.966 .14387 Mdot
.966 .144 Mdot
.966 .14403 Mdot
.966 .14404 Mdot
.966 .1441 Mdot
.966 .14426 Mdot
.966 .14433 Mdot
.966 .14469 Mdot
.966 .14478 Mdot
.966 .14494 Mdot
.966 .14499 Mdot
.966 .145 Mdot
.966 .145 Mdot
.966 .14522 Mdot
.966 .14524 Mdot
.966 .1456 Mdot
.966 .14565 Mdot
.966 .14569 Mdot
.966 .14571 Mdot
.966 .14581 Mdot
.966 .14591 Mdot
.966 .14595 Mdot
.966 .14597 Mdot
.966 .14612 Mdot
.966 .14618 Mdot
.966 .14622 Mdot
.966 .1463 Mdot
.966 .14633 Mdot
.966 .14639 Mdot
.966 .14641 Mdot
.966 .14665 Mdot
.966 .14674 Mdot
.966 .14677 Mdot
.966 .14685 Mdot
.966 .14688 Mdot
.966 .14691 Mdot
.966 .147 Mdot
.966 .147 Mdot
.966 .14701 Mdot
.966 .14706 Mdot
.966 .14708 Mdot
.966 .14709 Mdot
.966 .14711 Mdot
.966 .14711 Mdot
.966 .14713 Mdot
.966 .14713 Mdot
.966 .14713 Mdot
.966 .148 Mdot
.966 .14828 Mdot
.966 .14892 Mdot
.966 .149 Mdot
.966 .14936 Mdot
.966 .15011 Mdot
.966 .15036 Mdot
.966 .15049 Mdot
.966 .15067 Mdot
.966 .15118 Mdot
.966 .15118 Mdot
.966 .15333 Mdot
.966 .15375 Mdot
.966 .1539 Mdot
.966 .15411 Mdot
.966 .15419 Mdot
.966 .15629 Mdot
.966 .15668 Mdot
.966 .15803 Mdot
.966 .1586 Mdot
.966 .15895 Mdot
.966 .16013 Mdot
.966 .16118 Mdot
.966 .16152 Mdot
.966 .16219 Mdot
.966 .16222 Mdot
.966 .16275 Mdot
.966 .16282 Mdot
.966 .16512 Mdot
.966 .16543 Mdot
.966 .16566 Mdot
.966 .16673 Mdot
.966 .16791 Mdot
.966 .1682 Mdot
.966 .1685 Mdot
.966 .16865 Mdot
.966 .1692 Mdot
.966 .16924 Mdot
.966 .16941 Mdot
.966 .16964 Mdot
.966 .16987 Mdot
.966 .1702 Mdot
.966 .17026 Mdot
.966 .17044 Mdot
.966 .17049 Mdot
.966 .17065 Mdot
.966 .17107 Mdot
.966 .17116 Mdot
.966 .1712 Mdot
.966 .1713 Mdot
.966 .17164 Mdot
.966 .17166 Mdot
.966 .17171 Mdot
.966 .17183 Mdot
.966 .17194 Mdot
.966 .17202 Mdot
.966 .17276 Mdot
.966 .17389 Mdot
.966 .17451 Mdot
.966 .1746 Mdot
.966 .17463 Mdot
.966 .17482 Mdot
.966 .17483 Mdot
.966 .17485 Mdot
.966 .1751 Mdot
.966 .17511 Mdot
.966 .17512 Mdot
.966 .17545 Mdot
.966 .17571 Mdot
.966 .17579 Mdot
.966 .17679 Mdot
.966 .17732 Mdot
.966 .17741 Mdot
.966 .17772 Mdot
.966 .17793 Mdot
.966 .17877 Mdot
.966 .17924 Mdot
.966 .17924 Mdot
.966 .1797 Mdot
.966 .18145 Mdot
.966 .18146 Mdot
.966 .18151 Mdot
.966 .18173 Mdot
.966 .18349 Mdot
.966 .18382 Mdot
.966 .18415 Mdot
.966 .18434 Mdot
.966 .18532 Mdot
.966 .18565 Mdot
.966 .1866 Mdot
.966 .18766 Mdot
.966 .18791 Mdot
.966 .18813 Mdot
.966 .18968 Mdot
.966 .19077 Mdot
.966 .19134 Mdot
.966 .19181 Mdot
.966 .19266 Mdot
.966 .19267 Mdot
.966 .19348 Mdot
.966 .19607 Mdot
.966 .19908 Mdot
.966 .20081 Mdot
.966 .20126 Mdot
.966 .20139 Mdot
.966 .2039 Mdot
.966 .20403 Mdot
.966 .20432 Mdot
.966 .20438 Mdot
.966 .20685 Mdot
.966 .21 Mdot
.966 .21082 Mdot
.966 .21255 Mdot
.966 .21467 Mdot
.966 .2155 Mdot
.966 .216 Mdot
.966 .21715 Mdot
.966 .21839 Mdot
.966 .21921 Mdot
.966 .21961 Mdot
.966 .22002 Mdot
.966 .22592 Mdot
.966 .22665 Mdot
.966 .22851 Mdot
.966 .23012 Mdot
.966 .23046 Mdot
.966 .2323 Mdot
.966 .23396 Mdot
.966 .23675 Mdot
.966 .23825 Mdot
.966 .24205 Mdot
.966 .24224 Mdot
.966 .24555 Mdot
.966 .24727 Mdot
.966 .24783 Mdot
.966 .248 Mdot
.966 .24813 Mdot
.966 .25322 Mdot
.966 .25671 Mdot
.966 .25738 Mdot
.966 .25837 Mdot
.966 .25886 Mdot
.966 .26118 Mdot
.966 .26125 Mdot
.966 .26397 Mdot
.966 .26616 Mdot
.966 .2663 Mdot
.966 .26639 Mdot
.966 .2664 Mdot
.966 .26679 Mdot
.966 .26687 Mdot
.966 .26698 Mdot
.966 .26746 Mdot
.966 .26769 Mdot
.966 .26812 Mdot
.966 .26817 Mdot
.966 .26851 Mdot
.966 .2688 Mdot
.966 .26884 Mdot
.966 .26942 Mdot
.966 .26971 Mdot
.966 .26974 Mdot
.966 .26984 Mdot
.966 .27063 Mdot
.966 .27123 Mdot
.966 .27137 Mdot
.966 .27177 Mdot
.966 .27224 Mdot
.966 .27243 Mdot
.966 .2729 Mdot
.966 .27317 Mdot
.966 .27329 Mdot
.966 .27398 Mdot
.966 .27438 Mdot
.966 .27445 Mdot
.966 .27469 Mdot
.966 .27479 Mdot
.966 .27506 Mdot
.966 .2753 Mdot
.966 .27552 Mdot
.966 .27596 Mdot
.966 .27618 Mdot
.966 .27639 Mdot
.966 .27644 Mdot
.966 .2768 Mdot
.966 .27694 Mdot
.966 .27707 Mdot
.966 .27745 Mdot
.966 .27759 Mdot
.966 .27763 Mdot
.966 .27768 Mdot
.966 .27768 Mdot
.966 .27774 Mdot
.966 .27779 Mdot
.966 .27781 Mdot
.966 .28531 Mdot
.966 .30585 Mdot
.966 .30587 Mdot
.966 .30589 Mdot
.966 .30592 Mdot
.966 .30596 Mdot
.966 .30599 Mdot
.966 .30607 Mdot
.966 .30607 Mdot
.966 .30608 Mdot
.966 .30643 Mdot
.966 .30647 Mdot
.966 .3065 Mdot
.966 .30673 Mdot
.966 .30688 Mdot
.966 .30692 Mdot
.966 .30714 Mdot
.966 .3074 Mdot
.966 .30754 Mdot
.966 .30775 Mdot
.966 .30777 Mdot
.966 .30817 Mdot
.966 .30873 Mdot
.966 .30888 Mdot
.966 .30891 Mdot
.966 .30917 Mdot
.966 .30984 Mdot
.966 .31013 Mdot
.966 .31162 Mdot
.966 .31199 Mdot
.966 .31265 Mdot
.966 .31286 Mdot
.966 .31288 Mdot
.966 .31289 Mdot
.966 .31378 Mdot
.966 .31385 Mdot
.966 .3153 Mdot
.966 .31552 Mdot
.966 .31566 Mdot
.966 .31577 Mdot
.966 .31616 Mdot
.966 .31653 Mdot
.966 .3167 Mdot
.966 .31677 Mdot
.966 .31739 Mdot
.966 .31763 Mdot
.966 .31779 Mdot
.966 .31807 Mdot
.966 .31818 Mdot
.966 .31842 Mdot
.966 .31852 Mdot
.966 .31944 Mdot
.966 .31978 Mdot
.966 .31988 Mdot
.966 .32021 Mdot
.966 .32031 Mdot
.966 .32043 Mdot
.966 .32078 Mdot
.966 .32078 Mdot
.966 .32083 Mdot
.966 .32101 Mdot
.966 .32108 Mdot
.966 .32112 Mdot
.966 .32118 Mdot
.966 .32121 Mdot
.966 .32126 Mdot
.966 .32126 Mdot
.966 .32127 Mdot
.966 .32451 Mdot
.966 .32549 Mdot
.966 .32776 Mdot
.966 .32805 Mdot
.966 .32929 Mdot
.966 .33034 Mdot
.966 .33034 Mdot
.966 .33036 Mdot
.966 .33037 Mdot
.966 .33074 Mdot
.966 .33078 Mdot
.966 .33095 Mdot
.966 .33109 Mdot
.966 .3318 Mdot
.966 .33186 Mdot
.966 .3326 Mdot
.966 .33261 Mdot
.966 .33306 Mdot
.966 .33347 Mdot
.966 .33355 Mdot
.966 .33363 Mdot
.966 .33424 Mdot
.966 .33438 Mdot
.966 .33523 Mdot
.966 .33524 Mdot
.966 .33667 Mdot
.966 .33697 Mdot
.966 .33793 Mdot
.966 .33794 Mdot
.966 .33899 Mdot
.966 .33915 Mdot
.966 .33959 Mdot
.966 .33974 Mdot
.966 .34023 Mdot
.966 .34033 Mdot
.966 .34154 Mdot
.966 .34178 Mdot
.966 .34186 Mdot
.966 .34267 Mdot
.966 .34289 Mdot
.966 .34306 Mdot
.966 .34361 Mdot
.966 .3438 Mdot
.966 .34391 Mdot
.966 .34421 Mdot
.966 .34456 Mdot
.966 .34545 Mdot
.966 .34605 Mdot
.966 .34738 Mdot
.966 .34786 Mdot
.966 .34847 Mdot
.966 .34884 Mdot
.966 .34922 Mdot
.966 .34948 Mdot
.966 .34969 Mdot
.966 .34993 Mdot
.966 .35039 Mdot
.966 .35061 Mdot
.966 .35135 Mdot
.966 .35152 Mdot
.966 .35171 Mdot
.966 .35239 Mdot
.966 .35274 Mdot
.966 .35287 Mdot
.966 .35302 Mdot
.966 .35308 Mdot
.966 .3531 Mdot
.966 .35345 Mdot
.966 .35405 Mdot
.966 .35518 Mdot
.966 .35526 Mdot
.966 .3558 Mdot
.966 .3558 Mdot
.966 .35595 Mdot
.966 .35623 Mdot
.966 .35633 Mdot
.966 .35693 Mdot
.966 .35725 Mdot
.966 .35743 Mdot
.966 .35747 Mdot
.966 .35778 Mdot
.966 .35786 Mdot
.966 .35787 Mdot
.966 .35839 Mdot
.966 .35865 Mdot
.966 .35869 Mdot
.966 .35889 Mdot
.966 .35926 Mdot
.966 .35929 Mdot
.966 .35934 Mdot
.966 .35937 Mdot
.966 .35958 Mdot
.966 .35985 Mdot
.966 .35985 Mdot
.966 .35986 Mdot
.966 .36005 Mdot
.966 .36007 Mdot
.966 .36008 Mdot
.966 .36023 Mdot
.966 .36024 Mdot
.966 .36031 Mdot
.966 .36074 Mdot
.966 .36121 Mdot
.966 .3614 Mdot
.966 .3614 Mdot
.966 .36152 Mdot
.966 .36175 Mdot
.966 .36178 Mdot
.966 .36182 Mdot
.966 .36187 Mdot
.966 .36189 Mdot
.966 .3619 Mdot
.966 .362 Mdot
.966 .36201 Mdot
.966 .36204 Mdot
.966 .36206 Mdot
.966 .36208 Mdot
.966 .3622 Mdot
.966 .36223 Mdot
.966 .36224 Mdot
.966 .36228 Mdot
.966 .36229 Mdot
.966 .3623 Mdot
.966 .36234 Mdot
.966 .36234 Mdot
.966 .36236 Mdot
.966 .36237 Mdot
.966 .36238 Mdot
.966 .36238 Mdot
.966 .36239 Mdot
.966 .36239 Mdot
.966 .3726 Mdot
.966 .37541 Mdot
.966 .38295 Mdot
.966 .38887 Mdot
.966 .38986 Mdot
.966 .3914 Mdot
.966 .39973 Mdot
.966 .40662 Mdot
.966 .40762 Mdot
.966 .42137 Mdot
.966 .4251 Mdot
.966 .42897 Mdot
.966 .44877 Mdot
.966 .44977 Mdot
.966 .46717 Mdot
.966 .47621 Mdot
.966 .47909 Mdot
.966 .48 Mdot
.966 .48063 Mdot
.966 .49645 Mdot
.966 .50137 Mdot
.966 .50617 Mdot
.966 .52233 Mdot
.966 .5253 Mdot
.966 .52952 Mdot
.966 .53158 Mdot
.966 .53271 Mdot
.966 .54087 Mdot
.966 .54115 Mdot
.966 .55096 Mdot
.966 .55144 Mdot
.966 .55144 Mdot
.966 .55144 Mdot
.966 .55145 Mdot
.966 .55145 Mdot
.966 .55145 Mdot
.966 .55145 Mdot
.966 .55146 Mdot
.966 .55148 Mdot
.966 .55149 Mdot
.966 .5515 Mdot
.966 .55153 Mdot
.966 .55153 Mdot
.966 .55154 Mdot
.966 .55156 Mdot
.966 .55158 Mdot
.966 .5516 Mdot
.966 .55161 Mdot
.966 .55163 Mdot
.966 .55164 Mdot
.966 .55165 Mdot
.966 .55166 Mdot
.966 .55173 Mdot
.966 .55174 Mdot
.966 .55175 Mdot
.966 .55178 Mdot
.966 .55179 Mdot
.966 .55182 Mdot
.966 .55185 Mdot
.966 .55186 Mdot
.966 .5519 Mdot
.966 .55195 Mdot
.966 .55196 Mdot
.966 .55196 Mdot
.966 .55198 Mdot
.966 .55201 Mdot
.966 .55202 Mdot
.966 .55203 Mdot
.966 .55206 Mdot
.966 .55206 Mdot
.966 .55209 Mdot
.966 .5521 Mdot
.966 .55213 Mdot
.966 .55214 Mdot
.966 .55215 Mdot
.966 .55217 Mdot
.966 .55217 Mdot
.966 .55218 Mdot
.966 .55219 Mdot
.966 .55233 Mdot
.966 .5525 Mdot
.966 .55251 Mdot
.966 .55269 Mdot
.966 .55276 Mdot
.966 .5528 Mdot
.966 .55303 Mdot
.966 .55337 Mdot
.966 .55338 Mdot
.966 .55339 Mdot
.966 .55343 Mdot
.966 .55355 Mdot
.966 .55378 Mdot
.966 .55379 Mdot
.966 .55405 Mdot
.966 .55436 Mdot
.966 .55448 Mdot
.966 .55461 Mdot
.966 .55463 Mdot
.966 .55475 Mdot
.966 .55489 Mdot
.966 .55543 Mdot
.966 .55546 Mdot
.966 .55552 Mdot
.966 .55562 Mdot
.966 .55571 Mdot
.966 .55575 Mdot
.966 .55582 Mdot
.966 .55599 Mdot
.966 .55613 Mdot
.966 .5562 Mdot
.966 .55647 Mdot
.966 .55668 Mdot
.966 .55669 Mdot
.966 .55672 Mdot
.966 .55673 Mdot
.966 .55695 Mdot
.966 .55696 Mdot
.966 .557 Mdot
.966 .55716 Mdot
.966 .55745 Mdot
.966 .5577 Mdot
.966 .55778 Mdot
.966 .55778 Mdot
.966 .55787 Mdot
.966 .55797 Mdot
.966 .55825 Mdot
.966 .55827 Mdot
.966 .55841 Mdot
.966 .55852 Mdot
.966 .55856 Mdot
.966 .55866 Mdot
.966 .55869 Mdot
.966 .55872 Mdot
.966 .55876 Mdot
.966 .55896 Mdot
.966 .55899 Mdot
.966 .55899 Mdot
.966 .559 Mdot
.966 .5592 Mdot
.966 .55926 Mdot
.966 .55932 Mdot
.966 .55945 Mdot
.966 .55949 Mdot
.966 .5595 Mdot
.966 .55957 Mdot
.966 .55978 Mdot
.966 .55982 Mdot
.966 .55982 Mdot
.966 .55985 Mdot
.966 .55986 Mdot
.966 .5601 Mdot
.966 .5602 Mdot
.966 .56021 Mdot
.966 .56025 Mdot
.966 .56025 Mdot
.966 .56026 Mdot
.966 .56031 Mdot
.966 .56032 Mdot
.966 .56033 Mdot
.966 .5604 Mdot
.966 .56042 Mdot
.966 .56043 Mdot
.966 .56047 Mdot
.966 .56051 Mdot
.966 .56055 Mdot
.966 .56058 Mdot
.966 .56061 Mdot
.966 .56061 Mdot
.966 .5607 Mdot
.966 .56072 Mdot
.966 .56117 Mdot
.966 .56167 Mdot
.966 .56177 Mdot
.966 .56177 Mdot
.966 .56196 Mdot
.966 .5624 Mdot
.966 .56349 Mdot
.966 .56356 Mdot
.966 .5636 Mdot
.966 .56371 Mdot
.966 .56433 Mdot
.966 .56433 Mdot
.966 .56455 Mdot
.966 .56459 Mdot
.966 .56494 Mdot
.966 .56507 Mdot
.966 .56535 Mdot
.966 .56546 Mdot
.966 .56585 Mdot
.966 .56591 Mdot
.966 .56635 Mdot
.966 .56661 Mdot
.966 .56666 Mdot
.966 .56689 Mdot
.966 .5671 Mdot
.966 .56722 Mdot
.966 .56722 Mdot
.966 .56761 Mdot
.966 .56767 Mdot
.966 .5679 Mdot
.966 .56795 Mdot
.966 .56825 Mdot
.966 .56832 Mdot
.966 .56838 Mdot
.966 .56866 Mdot
.966 .56918 Mdot
.966 .56923 Mdot
.966 .56929 Mdot
.966 .56933 Mdot
.966 .56963 Mdot
.966 .56971 Mdot
.966 .57001 Mdot
.966 .57001 Mdot
.966 .57002 Mdot
.966 .57029 Mdot
.966 .57031 Mdot
.966 .57033 Mdot
.966 .57052 Mdot
.966 .57055 Mdot
.966 .57064 Mdot
.966 .57102 Mdot
.966 .57123 Mdot
.966 .57131 Mdot
.966 .57188 Mdot
.966 .57213 Mdot
.966 .57213 Mdot
.966 .57213 Mdot
.966 .57229 Mdot
.966 .57259 Mdot
.966 .57263 Mdot
.966 .5727 Mdot
.966 .57276 Mdot
.966 .57278 Mdot
.966 .57279 Mdot
.966 .57293 Mdot
.966 .57295 Mdot
.966 .57299 Mdot
.966 .57301 Mdot
.966 .57305 Mdot
.966 .57306 Mdot
.966 .57319 Mdot
.966 .57324 Mdot
.966 .57326 Mdot
.966 .5733 Mdot
.966 .57332 Mdot
.966 .57333 Mdot
.966 .57338 Mdot
.966 .57339 Mdot
.966 .57341 Mdot
.966 .57342 Mdot
.966 .57343 Mdot
.966 .57344 Mdot
.966 .57344 Mdot
.966 .57345 Mdot
.966 .57345 Mdot
.966 .57428 Mdot
.966 .57476 Mdot
.966 .57497 Mdot
.966 .57613 Mdot
.966 .57676 Mdot
.966 .57687 Mdot
.966 .57723 Mdot
.966 .57737 Mdot
.966 .57776 Mdot
.966 .57809 Mdot
.966 .57839 Mdot
.966 .57889 Mdot
.966 .57896 Mdot
.966 .57923 Mdot
.966 .57947 Mdot
.966 .57953 Mdot
.966 .57994 Mdot
.966 .5801 Mdot
.966 .58024 Mdot
.966 .58062 Mdot
.966 .58075 Mdot
.966 .58079 Mdot
.966 .58084 Mdot
.966 .58084 Mdot
.966 .5809 Mdot
.966 .58095 Mdot
.966 .58096 Mdot
.966 .58293 Mdot
.966 .58324 Mdot
.966 .58349 Mdot
.968 .10943 Mdot
.968 .10944 Mdot
.968 .10945 Mdot
.968 .10946 Mdot
.968 .10946 Mdot
.968 .10949 Mdot
.968 .1095 Mdot
.968 .1095 Mdot
.968 .10951 Mdot
.968 .10952 Mdot
.968 .10953 Mdot
.968 .10957 Mdot
.968 .10958 Mdot
.968 .10963 Mdot
.968 .10969 Mdot
.968 .10972 Mdot
.968 .10974 Mdot
.968 .10975 Mdot
.968 .10975 Mdot
.968 .10978 Mdot
.968 .10982 Mdot
.968 .10985 Mdot
.968 .10987 Mdot
.968 .1099 Mdot
.968 .10998 Mdot
.968 .11006 Mdot
.968 .11006 Mdot
.968 .11009 Mdot
.968 .11027 Mdot
.968 .11033 Mdot
.968 .11034 Mdot
.968 .11041 Mdot
.968 .11044 Mdot
.968 .11051 Mdot
.968 .11055 Mdot
.968 .1106 Mdot
.968 .11066 Mdot
.968 .11079 Mdot
.968 .11083 Mdot
.968 .11085 Mdot
.968 .11094 Mdot
.968 .11094 Mdot
.968 .11095 Mdot
.968 .11103 Mdot
.968 .11115 Mdot
.968 .11117 Mdot
.968 .1113 Mdot
.968 .11133 Mdot
.968 .11134 Mdot
.968 .11136 Mdot
.968 .11137 Mdot
.968 .11138 Mdot
.968 .11141 Mdot
.968 .11161 Mdot
.968 .11168 Mdot
.968 .11184 Mdot
.968 .11186 Mdot
.968 .11189 Mdot
.968 .11207 Mdot
.968 .1125 Mdot
.968 .11276 Mdot
.968 .11311 Mdot
.968 .1132 Mdot
.968 .11352 Mdot
.968 .11368 Mdot
.968 .1138 Mdot
.968 .11386 Mdot
.968 .11408 Mdot
.968 .11415 Mdot
.968 .11451 Mdot
.968 .11501 Mdot
.968 .11506 Mdot
.968 .11552 Mdot
.968 .1157 Mdot
.968 .11584 Mdot
.968 .11628 Mdot
.968 .1163 Mdot
.968 .11656 Mdot
.968 .11657 Mdot
.968 .11659 Mdot
.968 .11676 Mdot
.968 .11677 Mdot
.968 .11681 Mdot
.968 .11707 Mdot
.968 .1171 Mdot
.968 .11712 Mdot
.968 .11716 Mdot
.968 .11753 Mdot
.968 .11754 Mdot
.968 .11761 Mdot
.968 .11763 Mdot
.968 .11767 Mdot
.968 .11782 Mdot
.968 .11788 Mdot
.968 .11789 Mdot
.968 .11803 Mdot
.968 .11849 Mdot
.968 .11852 Mdot
.968 .11864 Mdot
.968 .11868 Mdot
.968 .11885 Mdot
.968 .1189 Mdot
.968 .11903 Mdot
.968 .1191 Mdot
.968 .11913 Mdot
.968 .11918 Mdot
.968 .12004 Mdot
.968 .12009 Mdot
.968 .1208 Mdot
.968 .12087 Mdot
.968 .12093 Mdot
.968 .12109 Mdot
.968 .12123 Mdot
.968 .12135 Mdot
.968 .12151 Mdot
.968 .12175 Mdot
.968 .12186 Mdot
.968 .1219 Mdot
.968 .12197 Mdot
.968 .12207 Mdot
.968 .12219 Mdot
.968 .1222 Mdot
.968 .12237 Mdot
.968 .12239 Mdot
.968 .12244 Mdot
.968 .12268 Mdot
.968 .12302 Mdot
.968 .12303 Mdot
.968 .12304 Mdot
.968 .12314 Mdot
.968 .12336 Mdot
.968 .12342 Mdot
.968 .12385 Mdot
.968 .1239 Mdot
.968 .12393 Mdot
.968 .124 Mdot
.968 .12403 Mdot
.968 .12406 Mdot
.968 .12413 Mdot
.968 .12415 Mdot
.968 .12426 Mdot
.968 .12472 Mdot
.968 .12473 Mdot
.968 .12476 Mdot
.968 .12477 Mdot
.968 .12494 Mdot
.968 .12511 Mdot
.968 .12563 Mdot
.968 .12563 Mdot
.968 .12569 Mdot
.968 .12575 Mdot
.968 .12587 Mdot
.968 .1259 Mdot
.968 .12599 Mdot
.968 .12606 Mdot
.968 .12628 Mdot
.968 .12635 Mdot
.968 .12651 Mdot
.968 .12652 Mdot
.968 .12669 Mdot
.968 .12737 Mdot
.968 .12757 Mdot
.968 .1279 Mdot
.968 .12821 Mdot
.968 .12831 Mdot
.968 .12843 Mdot
.968 .12845 Mdot
.968 .12859 Mdot
.968 .12873 Mdot
.968 .12877 Mdot
.968 .12913 Mdot
.968 .12948 Mdot
.968 .12949 Mdot
.968 .12981 Mdot
.968 .12986 Mdot
.968 .13002 Mdot
.968 .13014 Mdot
.968 .13025 Mdot
.968 .13033 Mdot
.968 .13064 Mdot
.968 .1309 Mdot
.968 .13098 Mdot
.968 .13099 Mdot
.968 .13157 Mdot
.968 .13157 Mdot
.968 .13161 Mdot
.968 .13165 Mdot
.968 .13194 Mdot
.968 .13206 Mdot
.968 .13207 Mdot
.968 .13214 Mdot
.968 .13216 Mdot
.968 .13238 Mdot
.968 .13243 Mdot
.968 .13249 Mdot
.968 .13254 Mdot
.968 .13258 Mdot
.968 .13264 Mdot
.968 .13266 Mdot
.968 .13291 Mdot
.968 .13299 Mdot
.968 .13313 Mdot
.968 .13322 Mdot
.968 .13329 Mdot
.968 .13337 Mdot
.968 .1335 Mdot
.968 .13354 Mdot
.968 .1336 Mdot
.968 .13366 Mdot
.968 .13367 Mdot
.968 .13373 Mdot
.968 .13374 Mdot
.968 .13376 Mdot
.968 .13377 Mdot
.968 .13388 Mdot
.968 .13392 Mdot
.968 .13394 Mdot
.968 .13395 Mdot
.968 .13401 Mdot
.968 .13404 Mdot
.968 .13412 Mdot
.968 .13413 Mdot
.968 .13413 Mdot
.968 .13413 Mdot
.968 .13962 Mdot
.968 .14427 Mdot
.968 .14431 Mdot
.968 .14432 Mdot
.968 .14437 Mdot
.968 .14438 Mdot
.968 .14448 Mdot
.968 .1445 Mdot
.968 .14451 Mdot
.968 .14455 Mdot
.968 .14458 Mdot
.968 .1446 Mdot
.968 .14475 Mdot
.968 .1448 Mdot
.968 .14496 Mdot
.968 .14517 Mdot
.968 .1453 Mdot
.968 .14535 Mdot
.968 .14538 Mdot
.968 .14539 Mdot
.968 .14545 Mdot
.968 .1455 Mdot
.968 .14565 Mdot
.968 .14575 Mdot
.968 .14582 Mdot
.968 .14593 Mdot
.968 .14621 Mdot
.968 .14649 Mdot
.968 .14651 Mdot
.968 .1466 Mdot
.968 .14725 Mdot
.968 .14749 Mdot
.968 .14752 Mdot
.968 .14778 Mdot
.968 .14789 Mdot
.968 .14815 Mdot
.968 .14829 Mdot
.968 .14848 Mdot
.968 .14869 Mdot
.968 .14917 Mdot
.968 .14931 Mdot
.968 .14938 Mdot
.968 .14973 Mdot
.968 .14973 Mdot
.968 .14978 Mdot
.968 .15007 Mdot
.968 .15051 Mdot
.968 .1506 Mdot
.968 .15109 Mdot
.968 .15119 Mdot
.968 .15125 Mdot
.968 .1513 Mdot
.968 .15134 Mdot
.968 .15139 Mdot
.968 .15151 Mdot
.968 .15228 Mdot
.968 .15256 Mdot
.968 .15316 Mdot
.968 .15325 Mdot
.968 .15334 Mdot
.968 .15406 Mdot
.968 .15573 Mdot
.968 .15575 Mdot
.968 .15575 Mdot
.968 .1563 Mdot
.968 .15681 Mdot
.968 .15709 Mdot
.968 .15822 Mdot
.968 .15856 Mdot
.968 .15989 Mdot
.968 .16056 Mdot
.968 .16106 Mdot
.968 .16128 Mdot
.968 .16221 Mdot
.968 .16252 Mdot
.968 .16265 Mdot
.968 .16405 Mdot
.968 .16587 Mdot
.968 .16618 Mdot
.968 .16638 Mdot
.968 .16841 Mdot
.968 .16919 Mdot
.968 .16983 Mdot
.968 .17099 Mdot
.968 .17163 Mdot
.968 .17177 Mdot
.968 .17187 Mdot
.968 .17304 Mdot
.968 .17309 Mdot
.968 .17317 Mdot
.968 .17369 Mdot
.968 .17392 Mdot
.968 .17399 Mdot
.968 .17414 Mdot
.968 .17536 Mdot
.968 .17547 Mdot
.968 .17556 Mdot
.968 .17575 Mdot
.968 .17649 Mdot
.968 .17747 Mdot
.968 .17751 Mdot
.968 .17781 Mdot
.968 .17794 Mdot
.968 .17811 Mdot
.968 .17879 Mdot
.968 .17908 Mdot
.968 .17912 Mdot
.968 .17976 Mdot
.968 .18194 Mdot
.968 .18211 Mdot
.968 .18267 Mdot
.968 .18284 Mdot
.968 .18366 Mdot
.968 .18388 Mdot
.968 .1845 Mdot
.968 .18484 Mdot
.968 .18498 Mdot
.968 .18523 Mdot
.968 .18553 Mdot
.968 .18718 Mdot
.968 .18812 Mdot
.968 .1894 Mdot
.968 .18961 Mdot
.968 .19081 Mdot
.968 .19105 Mdot
.968 .19313 Mdot
.968 .19348 Mdot
.968 .19378 Mdot
.968 .19454 Mdot
.968 .19522 Mdot
.968 .19584 Mdot
.968 .19662 Mdot
.968 .19766 Mdot
.968 .19782 Mdot
.968 .19838 Mdot
.968 .19859 Mdot
.968 .19894 Mdot
.968 .19898 Mdot
.968 .19943 Mdot
.968 .20006 Mdot
.968 .20011 Mdot
.968 .20093 Mdot
.968 .20107 Mdot
.968 .20133 Mdot
.968 .20251 Mdot
.968 .20425 Mdot
.968 .2043 Mdot
.968 .20437 Mdot
.968 .20486 Mdot
.968 .20489 Mdot
.968 .20599 Mdot
.968 .20627 Mdot
.968 .2085 Mdot
.968 .20874 Mdot
.968 .20889 Mdot
.968 .20925 Mdot
.968 .2094 Mdot
.968 .20958 Mdot
.968 .20993 Mdot
.968 .21006 Mdot
.968 .21059 Mdot
.968 .21097 Mdot
.968 .213 Mdot
.968 .21305 Mdot
.968 .2132 Mdot
.968 .21325 Mdot
.968 .214 Mdot
.968 .21413 Mdot
.968 .21503 Mdot
.968 .21595 Mdot
.968 .21771 Mdot
.968 .21772 Mdot
.968 .21802 Mdot
.968 .21834 Mdot
.968 .219 Mdot
.968 .21914 Mdot
.968 .21959 Mdot
.968 .21995 Mdot
.968 .22112 Mdot
.968 .22148 Mdot
.968 .2223 Mdot
.968 .2224 Mdot
.968 .22326 Mdot
.968 .22687 Mdot
.968 .22792 Mdot
.968 .22963 Mdot
.968 .23115 Mdot
.968 .23126 Mdot
.968 .23181 Mdot
.968 .23244 Mdot
.968 .23252 Mdot
.968 .23329 Mdot
.968 .234 Mdot
.968 .23424 Mdot
.968 .23612 Mdot
.968 .238 Mdot
.968 .23804 Mdot
.968 .23975 Mdot
.968 .24 Mdot
.968 .24014 Mdot
.968 .24084 Mdot
.968 .24149 Mdot
.968 .24207 Mdot
.968 .24249 Mdot
.968 .24408 Mdot
.968 .24549 Mdot
.968 .2459 Mdot
.968 .24593 Mdot
.968 .24744 Mdot
.968 .24812 Mdot
.968 .24899 Mdot
.968 .24899 Mdot
.968 .24918 Mdot
.968 .2494 Mdot
.968 .25094 Mdot
.968 .25157 Mdot
.968 .25163 Mdot
.968 .25197 Mdot
.968 .25208 Mdot
.968 .25323 Mdot
.968 .25349 Mdot
.968 .25381 Mdot
.968 .2541 Mdot
.968 .2543 Mdot
.968 .25462 Mdot
.968 .25473 Mdot
.968 .25602 Mdot
.968 .25645 Mdot
.968 .25662 Mdot
.968 .25715 Mdot
.968 .25764 Mdot
.968 .25799 Mdot
.968 .25839 Mdot
.968 .25908 Mdot
.968 .25917 Mdot
.968 .25931 Mdot
.968 .2596 Mdot
.968 .25989 Mdot
.968 .25995 Mdot
.968 .26029 Mdot
.968 .2603 Mdot
.968 .26044 Mdot
.968 .26049 Mdot
.968 .26107 Mdot
.968 .26123 Mdot
.968 .26135 Mdot
.968 .26138 Mdot
.968 .26169 Mdot
.968 .26189 Mdot
.968 .26226 Mdot
.968 .26231 Mdot
.968 .26235 Mdot
.968 .26235 Mdot
.968 .27113 Mdot
.968 .27505 Mdot
.968 .28463 Mdot
.968 .28962 Mdot
.968 .3105 Mdot
.968 .31065 Mdot
.968 .3107 Mdot
.968 .31092 Mdot
.968 .31094 Mdot
.968 .31135 Mdot
.968 .31147 Mdot
.968 .31148 Mdot
.968 .31155 Mdot
.968 .31166 Mdot
.968 .31177 Mdot
.968 .31186 Mdot
.968 .31247 Mdot
.968 .31269 Mdot
.968 .31333 Mdot
.968 .31356 Mdot
.968 .3142 Mdot
.968 .31472 Mdot
.968 .31494 Mdot
.968 .31505 Mdot
.968 .3151 Mdot
.968 .31534 Mdot
.968 .31555 Mdot
.968 .31613 Mdot
.968 .31654 Mdot
.968 .31683 Mdot
.968 .31725 Mdot
.968 .31837 Mdot
.968 .31945 Mdot
.968 .31951 Mdot
.968 .31962 Mdot
.968 .31986 Mdot
.968 .32234 Mdot
.968 .32318 Mdot
.968 .32326 Mdot
.968 .32336 Mdot
.968 .32431 Mdot
.968 .32473 Mdot
.968 .32568 Mdot
.968 .32617 Mdot
.968 .32687 Mdot
.968 .32762 Mdot
.968 .32818 Mdot
.968 .32928 Mdot
.968 .32976 Mdot
.968 .33001 Mdot
.968 .33091 Mdot
.968 .33101 Mdot
.968 .33101 Mdot
.968 .33102 Mdot
.968 .33108 Mdot
.968 .33109 Mdot
.968 .3311 Mdot
.968 .3312 Mdot
.968 .33121 Mdot
.968 .33138 Mdot
.968 .33138 Mdot
.968 .33142 Mdot
.968 .33148 Mdot
.968 .33151 Mdot
.968 .33156 Mdot
.968 .33175 Mdot
.968 .33193 Mdot
.968 .33196 Mdot
.968 .3323 Mdot
.968 .33232 Mdot
.968 .33258 Mdot
.968 .3326 Mdot
.968 .33278 Mdot
.968 .33284 Mdot
.968 .33292 Mdot
.968 .33297 Mdot
.968 .33298 Mdot
.968 .33309 Mdot
.968 .33327 Mdot
.968 .33339 Mdot
.968 .3334 Mdot
.968 .3334 Mdot
.968 .33352 Mdot
.968 .33354 Mdot
.968 .33371 Mdot
.968 .33377 Mdot
.968 .33405 Mdot
.968 .33406 Mdot
.968 .33419 Mdot
.968 .3344 Mdot
.968 .33476 Mdot
.968 .33513 Mdot
.968 .33521 Mdot
.968 .33561 Mdot
.968 .33574 Mdot
.968 .33593 Mdot
.968 .33611 Mdot
.968 .33628 Mdot
.968 .33639 Mdot
.968 .33645 Mdot
.968 .33656 Mdot
.968 .33673 Mdot
.968 .33693 Mdot
.968 .3373 Mdot
.968 .3373 Mdot
.968 .33764 Mdot
.968 .33802 Mdot
.968 .33805 Mdot
.968 .33811 Mdot
.968 .33835 Mdot
.968 .33843 Mdot
.968 .33922 Mdot
.968 .33969 Mdot
.968 .33992 Mdot
.968 .34004 Mdot
.968 .34064 Mdot
.968 .34065 Mdot
.968 .34095 Mdot
.968 .34159 Mdot
.968 .34173 Mdot
.968 .34197 Mdot
.968 .34224 Mdot
.968 .34256 Mdot
.968 .34265 Mdot
.968 .34283 Mdot
.968 .34346 Mdot
.968 .34356 Mdot
.968 .34374 Mdot
.968 .34417 Mdot
.968 .3446 Mdot
.968 .34592 Mdot
.968 .34745 Mdot
.968 .34748 Mdot
.968 .34822 Mdot
.968 .34825 Mdot
.968 .34828 Mdot
.968 .34831 Mdot
.968 .34833 Mdot
.968 .34867 Mdot
.968 .34902 Mdot
.968 .34903 Mdot
.968 .34921 Mdot
.968 .34956 Mdot
.968 .34969 Mdot
.968 .35054 Mdot
.968 .35065 Mdot
.968 .35076 Mdot
.968 .35085 Mdot
.968 .35114 Mdot
.968 .35125 Mdot
.968 .35128 Mdot
.968 .35153 Mdot
.968 .35196 Mdot
.968 .35219 Mdot
.968 .35237 Mdot
.968 .35265 Mdot
.968 .35294 Mdot
.968 .35316 Mdot
.968 .35334 Mdot
.968 .35337 Mdot
.968 .35345 Mdot
.968 .35406 Mdot
.968 .35458 Mdot
.968 .35559 Mdot
.968 .35589 Mdot
.968 .35595 Mdot
.968 .35606 Mdot
.968 .35629 Mdot
.968 .35664 Mdot
.968 .35668 Mdot
.968 .35682 Mdot
.968 .35701 Mdot
.968 .35727 Mdot
.968 .35729 Mdot
.968 .35776 Mdot
.968 .35792 Mdot
.968 .35794 Mdot
.968 .35798 Mdot
.968 .35808 Mdot
.968 .35826 Mdot
.968 .35839 Mdot
.968 .35843 Mdot
.968 .35861 Mdot
.968 .35939 Mdot
.968 .35939 Mdot
.968 .35973 Mdot
.968 .35987 Mdot
.968 .36004 Mdot
.968 .36014 Mdot
.968 .3602 Mdot
.968 .36028 Mdot
.968 .36037 Mdot
.968 .36053 Mdot
.968 .36083 Mdot
.968 .36117 Mdot
.968 .36128 Mdot
.968 .36139 Mdot
.968 .36143 Mdot
.968 .36158 Mdot
.968 .36189 Mdot
.968 .36194 Mdot
.968 .36196 Mdot
.968 .36208 Mdot
.968 .3621 Mdot
.968 .36232 Mdot
.968 .36235 Mdot
.968 .36249 Mdot
.968 .36252 Mdot
.968 .36254 Mdot
.968 .36256 Mdot
.968 .36257 Mdot
.968 .36258 Mdot
.968 .36262 Mdot
.968 .36283 Mdot
.968 .36291 Mdot
.968 .36306 Mdot
.968 .36309 Mdot
.968 .36311 Mdot
.968 .36371 Mdot
.968 .37703 Mdot
.968 .38129 Mdot
.968 .38852 Mdot
.968 .39061 Mdot
.968 .39146 Mdot
.968 .39526 Mdot
.968 .39575 Mdot
.968 .39828 Mdot
.968 .40119 Mdot
.968 .40159 Mdot
.968 .40521 Mdot
.968 .40859 Mdot
.968 .40977 Mdot
.968 .41903 Mdot
.968 .42855 Mdot
.968 .42875 Mdot
.968 .43759 Mdot
.968 .43802 Mdot
.968 .43892 Mdot
.968 .43966 Mdot
.968 .4433 Mdot
.968 .44673 Mdot
.968 .44976 Mdot
.968 .452 Mdot
.968 .46039 Mdot
.968 .46782 Mdot
.968 .46998 Mdot
.968 .47011 Mdot
.968 .47802 Mdot
.968 .48157 Mdot
.968 .48603 Mdot
.968 .48606 Mdot
.968 .48652 Mdot
.968 .48703 Mdot
.968 .48816 Mdot
.968 .49253 Mdot
.968 .49595 Mdot
.968 .49911 Mdot
.968 .49941 Mdot
.968 .50106 Mdot
.968 .50163 Mdot
.968 .50722 Mdot
.968 .50846 Mdot
.968 .50921 Mdot
.968 .51 Mdot
.968 .51139 Mdot
.968 .51232 Mdot
.968 .51385 Mdot
.968 .51433 Mdot
.968 .52028 Mdot
.968 .52223 Mdot
.968 .52301 Mdot
.968 .52534 Mdot
.968 .52583 Mdot
.968 .52745 Mdot
.968 .52758 Mdot
.968 .52897 Mdot
.968 .53067 Mdot
.968 .53357 Mdot
.968 .53394 Mdot
.968 .53453 Mdot
.968 .53572 Mdot
.968 .53688 Mdot
.968 .53714 Mdot
.968 .53848 Mdot
.968 .53853 Mdot
.968 .53908 Mdot
.968 .53927 Mdot
.968 .53961 Mdot
.968 .54154 Mdot
.968 .54215 Mdot
.968 .54261 Mdot
.968 .54275 Mdot
.968 .54392 Mdot
.968 .54467 Mdot
.968 .54602 Mdot
.968 .54622 Mdot
.968 .54636 Mdot
.968 .54636 Mdot
.968 .54909 Mdot
.968 .5508 Mdot
.968 .55255 Mdot
.968 .55255 Mdot
.968 .55255 Mdot
.968 .55255 Mdot
.968 .55258 Mdot
.968 .55259 Mdot
.968 .55261 Mdot
.968 .55261 Mdot
.968 .55262 Mdot
.968 .55263 Mdot
.968 .55267 Mdot
.968 .55267 Mdot
.968 .55268 Mdot
.968 .55268 Mdot
.968 .55271 Mdot
.968 .55271 Mdot
.968 .55273 Mdot
.968 .55275 Mdot
.968 .55276 Mdot
.968 .55281 Mdot
.968 .55283 Mdot
.968 .55286 Mdot
.968 .55289 Mdot
.968 .55294 Mdot
.968 .55296 Mdot
.968 .55305 Mdot
.968 .55306 Mdot
.968 .55308 Mdot
.968 .55309 Mdot
.968 .55311 Mdot
.968 .55313 Mdot
.968 .55315 Mdot
.968 .55323 Mdot
.968 .55323 Mdot
.968 .55326 Mdot
.968 .55326 Mdot
.968 .5533 Mdot
.968 .55341 Mdot
.968 .55342 Mdot
.968 .55343 Mdot
.968 .55343 Mdot
.968 .55364 Mdot
.968 .55364 Mdot
.968 .55367 Mdot
.968 .55377 Mdot
.968 .55388 Mdot
.968 .55391 Mdot
.968 .55395 Mdot
.968 .55399 Mdot
.968 .55405 Mdot
.968 .55407 Mdot
.968 .55419 Mdot
.968 .55419 Mdot
.968 .55432 Mdot
.968 .55446 Mdot
.968 .55448 Mdot
.968 .55453 Mdot
.968 .55458 Mdot
.968 .55459 Mdot
.968 .55463 Mdot
.968 .55467 Mdot
.968 .55479 Mdot
.968 .55492 Mdot
.968 .555 Mdot
.968 .55527 Mdot
.968 .55534 Mdot
.968 .55534 Mdot
.968 .55541 Mdot
.968 .55544 Mdot
.968 .55553 Mdot
.968 .55555 Mdot
.968 .55559 Mdot
.968 .5556 Mdot
.968 .55565 Mdot
.968 .55568 Mdot
.968 .5557 Mdot
.968 .5557 Mdot
.968 .55592 Mdot
.968 .55599 Mdot
.968 .55606 Mdot
.968 .55607 Mdot
.968 .55608 Mdot
.968 .55608 Mdot
.968 .55628 Mdot
.968 .55633 Mdot
.968 .55634 Mdot
.968 .55637 Mdot
.968 .55638 Mdot
.968 .5564 Mdot
.968 .55643 Mdot
.968 .55644 Mdot
.968 .55646 Mdot
.968 .55665 Mdot
.968 .55668 Mdot
.968 .55678 Mdot
.968 .55682 Mdot
.968 .55683 Mdot
.968 .55683 Mdot
.968 .55699 Mdot
.968 .5571 Mdot
.968 .55712 Mdot
.968 .55713 Mdot
.968 .55721 Mdot
.968 .55732 Mdot
.968 .55735 Mdot
.968 .55737 Mdot
.968 .55742 Mdot
.968 .55754 Mdot
.968 .55761 Mdot
.968 .55767 Mdot
.968 .55774 Mdot
.968 .55782 Mdot
.968 .55785 Mdot
.968 .55788 Mdot
.968 .55824 Mdot
.968 .55827 Mdot
.968 .55872 Mdot
.968 .55875 Mdot
.968 .55876 Mdot
.968 .5588 Mdot
.968 .55887 Mdot
.968 .55899 Mdot
.968 .55908 Mdot
.968 .5591 Mdot
.968 .55936 Mdot
.968 .55944 Mdot
.968 .55944 Mdot
.968 .55948 Mdot
.968 .55957 Mdot
.968 .55959 Mdot
.968 .5596 Mdot
.968 .55964 Mdot
.968 .55965 Mdot
.968 .55987 Mdot
.968 .5599 Mdot
.968 .55991 Mdot
.968 .55992 Mdot
.968 .56009 Mdot
.968 .56011 Mdot
.968 .56012 Mdot
.968 .56022 Mdot
.968 .56023 Mdot
.968 .56024 Mdot
.968 .56041 Mdot
.968 .56042 Mdot
.968 .56071 Mdot
.968 .5608 Mdot
.968 .56092 Mdot
.968 .56128 Mdot
.968 .56165 Mdot
.968 .56193 Mdot
.968 .56198 Mdot
.968 .56216 Mdot
.968 .5622 Mdot
.968 .5623 Mdot
.968 .56244 Mdot
.968 .56272 Mdot
.968 .56279 Mdot
.968 .56311 Mdot
.968 .5638 Mdot
.968 .56505 Mdot
.968 .56518 Mdot
.968 .5656 Mdot
.968 .56569 Mdot
.968 .56584 Mdot
.968 .56615 Mdot
.968 .56665 Mdot
.968 .5667 Mdot
.968 .56689 Mdot
.968 .56717 Mdot
.968 .56753 Mdot
.968 .56755 Mdot
.968 .56822 Mdot
.968 .56844 Mdot
.968 .56848 Mdot
.968 .56852 Mdot
.968 .56867 Mdot
.968 .56893 Mdot
.968 .56911 Mdot
.968 .56916 Mdot
.968 .56942 Mdot
.968 .5702 Mdot
.968 .5705 Mdot
.968 .57051 Mdot
.968 .57099 Mdot
.968 .57119 Mdot
.968 .57142 Mdot
.968 .57155 Mdot
.968 .57164 Mdot
.968 .57174 Mdot
.968 .57187 Mdot
.968 .57196 Mdot
.968 .5721 Mdot
.968 .5725 Mdot
.968 .57297 Mdot
.968 .57312 Mdot
.968 .57326 Mdot
.968 .57332 Mdot
.968 .57353 Mdot
.968 .57395 Mdot
.968 .57401 Mdot
.968 .57404 Mdot
.968 .57419 Mdot
.968 .57421 Mdot
.968 .57451 Mdot
.968 .57455 Mdot
.968 .57474 Mdot
.968 .57478 Mdot
.968 .5748 Mdot
.968 .57482 Mdot
.968 .57483 Mdot
.968 .57486 Mdot
.968 .5749 Mdot
.968 .57518 Mdot
.968 .57528 Mdot
.968 .57548 Mdot
.968 .57551 Mdot
.968 .57554 Mdot
.968 .57629 Mdot
.968 .57891 Mdot
.968 .58191 Mdot
.968 .58207 Mdot
.968 .58447 Mdot
.968 .58457 Mdot
.97 .10964 Mdot
.97 .10964 Mdot
.97 .10965 Mdot
.97 .10972 Mdot
.97 .10974 Mdot
.97 .10976 Mdot
.97 .10977 Mdot
.97 .10978 Mdot
.97 .10992 Mdot
.97 .10995 Mdot
.97 .10998 Mdot
.97 .11 Mdot
.97 .11002 Mdot
.97 .11005 Mdot
.97 .11011 Mdot
.97 .11019 Mdot
.97 .11026 Mdot
.97 .11043 Mdot
.97 .11051 Mdot
.97 .11055 Mdot
.97 .11057 Mdot
.97 .11097 Mdot
.97 .11109 Mdot
.97 .11109 Mdot
.97 .11111 Mdot
.97 .11112 Mdot
.97 .11118 Mdot
.97 .11123 Mdot
.97 .11124 Mdot
.97 .11136 Mdot
.97 .1114 Mdot
.97 .11148 Mdot
.97 .1116 Mdot
.97 .11165 Mdot
.97 .11169 Mdot
.97 .11194 Mdot
.97 .11197 Mdot
.97 .11199 Mdot
.97 .11203 Mdot
.97 .11203 Mdot
.97 .11215 Mdot
.97 .11222 Mdot
.97 .11226 Mdot
.97 .11227 Mdot
.97 .11227 Mdot
.97 .11228 Mdot
.97 .11229 Mdot
.97 .11237 Mdot
.97 .11244 Mdot
.97 .11264 Mdot
.97 .11344 Mdot
.97 .11345 Mdot
.97 .11354 Mdot
.97 .11363 Mdot
.97 .11386 Mdot
.97 .11388 Mdot
.97 .1139 Mdot
.97 .11407 Mdot
.97 .11421 Mdot
.97 .11463 Mdot
.97 .11519 Mdot
.97 .11541 Mdot
.97 .11574 Mdot
.97 .11647 Mdot
.97 .11659 Mdot
.97 .11659 Mdot
.97 .1166 Mdot
.97 .1166 Mdot
.97 .1166 Mdot
.97 .11661 Mdot
.97 .11664 Mdot
.97 .11668 Mdot
.97 .11669 Mdot
.97 .1167 Mdot
.97 .11671 Mdot
.97 .11682 Mdot
.97 .11688 Mdot
.97 .11689 Mdot
.97 .11693 Mdot
.97 .11695 Mdot
.97 .11715 Mdot
.97 .11716 Mdot
.97 .11721 Mdot
.97 .11727 Mdot
.97 .1173 Mdot
.97 .11738 Mdot
.97 .11742 Mdot
.97 .11752 Mdot
.97 .11801 Mdot
.97 .11826 Mdot
.97 .11826 Mdot
.97 .11835 Mdot
.97 .11879 Mdot
.97 .11906 Mdot
.97 .11907 Mdot
.97 .11915 Mdot
.97 .11919 Mdot
.97 .11921 Mdot
.97 .11934 Mdot
.97 .11946 Mdot
.97 .1195 Mdot
.97 .11955 Mdot
.97 .11963 Mdot
.97 .11965 Mdot
.97 .11978 Mdot
.97 .12 Mdot
.97 .12012 Mdot
.97 .12024 Mdot
.97 .12028 Mdot
.97 .12052 Mdot
.97 .12056 Mdot
.97 .12067 Mdot
.97 .12072 Mdot
.97 .12073 Mdot
.97 .12092 Mdot
.97 .12094 Mdot
.97 .12097 Mdot
.97 .1211 Mdot
.97 .12113 Mdot
.97 .1214 Mdot
.97 .1216 Mdot
.97 .12177 Mdot
.97 .12182 Mdot
.97 .12189 Mdot
.97 .12203 Mdot
.97 .12208 Mdot
.97 .12214 Mdot
.97 .12239 Mdot
.97 .12257 Mdot
.97 .12268 Mdot
.97 .12269 Mdot
.97 .1228 Mdot
.97 .1228 Mdot
.97 .12281 Mdot
.97 .12282 Mdot
.97 .12295 Mdot
.97 .1231 Mdot
.97 .12312 Mdot
.97 .12319 Mdot
.97 .12319 Mdot
.97 .1232 Mdot
.97 .12343 Mdot
.97 .12377 Mdot
.97 .12377 Mdot
.97 .12385 Mdot
.97 .12391 Mdot
.97 .12393 Mdot
.97 .12398 Mdot
.97 .12404 Mdot
.97 .12405 Mdot
.97 .12412 Mdot
.97 .12426 Mdot
.97 .12426 Mdot
.97 .12439 Mdot
.97 .12464 Mdot
.97 .12467 Mdot
.97 .12476 Mdot
.97 .12477 Mdot
.97 .12507 Mdot
.97 .12526 Mdot
.97 .12537 Mdot
.97 .12544 Mdot
.97 .126 Mdot
.97 .12601 Mdot
.97 .12617 Mdot
.97 .12642 Mdot
.97 .12648 Mdot
.97 .12655 Mdot
.97 .12655 Mdot
.97 .12655 Mdot
.97 .12694 Mdot
.97 .12726 Mdot
.97 .12727 Mdot
.97 .12735 Mdot
.97 .12736 Mdot
.97 .12738 Mdot
.97 .12745 Mdot
.97 .12752 Mdot
.97 .12768 Mdot
.97 .12784 Mdot
.97 .12795 Mdot
.97 .12796 Mdot
.97 .12802 Mdot
.97 .1281 Mdot
.97 .12825 Mdot
.97 .12832 Mdot
.97 .12849 Mdot
.97 .12874 Mdot
.97 .12881 Mdot
.97 .12906 Mdot
.97 .12907 Mdot
.97 .1292 Mdot
.97 .12926 Mdot
.97 .12939 Mdot
.97 .12945 Mdot
.97 .12947 Mdot
.97 .12952 Mdot
.97 .12955 Mdot
.97 .12963 Mdot
.97 .1298 Mdot
.97 .12989 Mdot
.97 .12991 Mdot
.97 .13005 Mdot
.97 .13007 Mdot
.97 .13025 Mdot
.97 .13034 Mdot
.97 .13035 Mdot
.97 .13037 Mdot
.97 .13039 Mdot
.97 .1304 Mdot
.97 .13047 Mdot
.97 .1305 Mdot
.97 .13052 Mdot
.97 .13054 Mdot
.97 .13064 Mdot
.97 .13069 Mdot
.97 .13071 Mdot
.97 .13073 Mdot
.97 .13073 Mdot
.97 .13085 Mdot
.97 .13089 Mdot
.97 .13094 Mdot
.97 .13096 Mdot
.97 .13097 Mdot
.97 .13099 Mdot
.97 .13099 Mdot
.97 .13099 Mdot
.97 .131 Mdot
.97 .13101 Mdot
.97 .13103 Mdot
.97 .13107 Mdot
.97 .13112 Mdot
.97 .13113 Mdot
.97 .13117 Mdot
.97 .14508 Mdot
.97 .14525 Mdot
.97 .14528 Mdot
.97 .14531 Mdot
.97 .14556 Mdot
.97 .14564 Mdot
.97 .14569 Mdot
.97 .14572 Mdot
.97 .14575 Mdot
.97 .14626 Mdot
.97 .14638 Mdot
.97 .1465 Mdot
.97 .14654 Mdot
.97 .14664 Mdot
.97 .14673 Mdot
.97 .14697 Mdot
.97 .14723 Mdot
.97 .14751 Mdot
.97 .1481 Mdot
.97 .14841 Mdot
.97 .14856 Mdot
.97 .14863 Mdot
.97 .15012 Mdot
.97 .15057 Mdot
.97 .15059 Mdot
.97 .15064 Mdot
.97 .1507 Mdot
.97 .15093 Mdot
.97 .15111 Mdot
.97 .15113 Mdot
.97 .15159 Mdot
.97 .15177 Mdot
.97 .15205 Mdot
.97 .15251 Mdot
.97 .15273 Mdot
.97 .15288 Mdot
.97 .15383 Mdot
.97 .15394 Mdot
.97 .15403 Mdot
.97 .15417 Mdot
.97 .1542 Mdot
.97 .15465 Mdot
.97 .15495 Mdot
.97 .15509 Mdot
.97 .15514 Mdot
.97 .15514 Mdot
.97 .15519 Mdot
.97 .15522 Mdot
.97 .15552 Mdot
.97 .15583 Mdot
.97 .1566 Mdot
.97 .15987 Mdot
.97 .15991 Mdot
.97 .16027 Mdot
.97 .16065 Mdot
.97 .16161 Mdot
.97 .16167 Mdot
.97 .16179 Mdot
.97 .16248 Mdot
.97 .16308 Mdot
.97 .16488 Mdot
.97 .16725 Mdot
.97 .16823 Mdot
.97 .16969 Mdot
.97 .17294 Mdot
.97 .1735 Mdot
.97 .17351 Mdot
.97 .17353 Mdot
.97 .17353 Mdot
.97 .17355 Mdot
.97 .1736 Mdot
.97 .17372 Mdot
.97 .1739 Mdot
.97 .17395 Mdot
.97 .17399 Mdot
.97 .17403 Mdot
.97 .17453 Mdot
.97 .17481 Mdot
.97 .17488 Mdot
.97 .17505 Mdot
.97 .17513 Mdot
.97 .17606 Mdot
.97 .17609 Mdot
.97 .1763 Mdot
.97 .17659 Mdot
.97 .17673 Mdot
.97 .17712 Mdot
.97 .17731 Mdot
.97 .17774 Mdot
.97 .18002 Mdot
.97 .18121 Mdot
.97 .18122 Mdot
.97 .18164 Mdot
.97 .18373 Mdot
.97 .18502 Mdot
.97 .18505 Mdot
.97 .18544 Mdot
.97 .18562 Mdot
.97 .18571 Mdot
.97 .18637 Mdot
.97 .18691 Mdot
.97 .18711 Mdot
.97 .18734 Mdot
.97 .18777 Mdot
.97 .18783 Mdot
.97 .18847 Mdot
.97 .18956 Mdot
.97 .19013 Mdot
.97 .19073 Mdot
.97 .1909 Mdot
.97 .1921 Mdot
.97 .19228 Mdot
.97 .19283 Mdot
.97 .1931 Mdot
.97 .19316 Mdot
.97 .19409 Mdot
.97 .19418 Mdot
.97 .19435 Mdot
.97 .19495 Mdot
.97 .19513 Mdot
.97 .19644 Mdot
.97 .19748 Mdot
.97 .19831 Mdot
.97 .19858 Mdot
.97 .19894 Mdot
.97 .19961 Mdot
.97 .19988 Mdot
.97 .20019 Mdot
.97 .20145 Mdot
.97 .20235 Mdot
.97 .20292 Mdot
.97 .20298 Mdot
.97 .20351 Mdot
.97 .20351 Mdot
.97 .20357 Mdot
.97 .20362 Mdot
.97 .20428 Mdot
.97 .20504 Mdot
.97 .20515 Mdot
.97 .20549 Mdot
.97 .2055 Mdot
.97 .20557 Mdot
.97 .20581 Mdot
.97 .20672 Mdot
.97 .20847 Mdot
.97 .20848 Mdot
.97 .2089 Mdot
.97 .20921 Mdot
.97 .20929 Mdot
.97 .20958 Mdot
.97 .20987 Mdot
.97 .20995 Mdot
.97 .21027 Mdot
.97 .21101 Mdot
.97 .21104 Mdot
.97 .21167 Mdot
.97 .213 Mdot
.97 .21312 Mdot
.97 .21363 Mdot
.97 .21367 Mdot
.97 .21523 Mdot
.97 .21621 Mdot
.97 .2168 Mdot
.97 .21714 Mdot
.97 .22007 Mdot
.97 .22016 Mdot
.97 .22098 Mdot
.97 .22229 Mdot
.97 .22259 Mdot
.97 .22297 Mdot
.97 .22297 Mdot
.97 .22299 Mdot
.97 .22502 Mdot
.97 .22668 Mdot
.97 .22678 Mdot
.97 .22718 Mdot
.97 .22721 Mdot
.97 .22736 Mdot
.97 .22771 Mdot
.97 .22809 Mdot
.97 .22894 Mdot
.97 .22976 Mdot
.97 .23034 Mdot
.97 .23041 Mdot
.97 .23071 Mdot
.97 .23114 Mdot
.97 .23191 Mdot
.97 .23229 Mdot
.97 .23319 Mdot
.97 .23454 Mdot
.97 .23491 Mdot
.97 .23621 Mdot
.97 .23626 Mdot
.97 .23696 Mdot
.97 .2373 Mdot
.97 .23795 Mdot
.97 .2383 Mdot
.97 .2384 Mdot
.97 .23866 Mdot
.97 .23881 Mdot
.97 .23922 Mdot
.97 .24016 Mdot
.97 .24061 Mdot
.97 .2407 Mdot
.97 .24147 Mdot
.97 .24157 Mdot
.97 .24251 Mdot
.97 .24298 Mdot
.97 .24305 Mdot
.97 .24313 Mdot
.97 .24328 Mdot
.97 .24329 Mdot
.97 .2437 Mdot
.97 .24384 Mdot
.97 .24397 Mdot
.97 .24406 Mdot
.97 .24456 Mdot
.97 .24484 Mdot
.97 .24495 Mdot
.97 .24504 Mdot
.97 .24508 Mdot
.97 .24515 Mdot
.97 .24566 Mdot
.97 .24589 Mdot
.97 .24618 Mdot
.97 .24627 Mdot
.97 .24632 Mdot
.97 .24641 Mdot
.97 .24643 Mdot
.97 .24644 Mdot
.97 .24646 Mdot
.97 .24653 Mdot
.97 .24663 Mdot
.97 .24686 Mdot
.97 .2471 Mdot
.97 .24718 Mdot
.97 .24738 Mdot
.97 .31444 Mdot
.97 .31517 Mdot
.97 .31529 Mdot
.97 .31539 Mdot
.97 .31642 Mdot
.97 .31672 Mdot
.97 .31692 Mdot
.97 .31717 Mdot
.97 .31917 Mdot
.97 .31967 Mdot
.97 .3201 Mdot
.97 .32028 Mdot
.97 .32065 Mdot
.97 .32095 Mdot
.97 .32102 Mdot
.97 .32191 Mdot
.97 .3229 Mdot
.97 .32396 Mdot
.97 .32614 Mdot
.97 .32726 Mdot
.97 .32781 Mdot
.97 .32805 Mdot
.97 .33165 Mdot
.97 .33165 Mdot
.97 .33165 Mdot
.97 .33165 Mdot
.97 .33166 Mdot
.97 .33167 Mdot
.97 .33168 Mdot
.97 .33169 Mdot
.97 .33169 Mdot
.97 .33174 Mdot
.97 .33177 Mdot
.97 .33179 Mdot
.97 .33179 Mdot
.97 .33188 Mdot
.97 .33188 Mdot
.97 .3319 Mdot
.97 .33193 Mdot
.97 .33194 Mdot
.97 .33197 Mdot
.97 .33199 Mdot
.97 .33203 Mdot
.97 .33233 Mdot
.97 .33255 Mdot
.97 .33271 Mdot
.97 .33285 Mdot
.97 .33289 Mdot
.97 .33315 Mdot
.97 .33326 Mdot
.97 .33331 Mdot
.97 .33333 Mdot
.97 .33341 Mdot
.97 .33342 Mdot
.97 .3335 Mdot
.97 .33369 Mdot
.97 .33376 Mdot
.97 .33381 Mdot
.97 .33402 Mdot
.97 .3341 Mdot
.97 .3342 Mdot
.97 .33433 Mdot
.97 .33437 Mdot
.97 .33462 Mdot
.97 .33466 Mdot
.97 .33468 Mdot
.97 .33474 Mdot
.97 .33484 Mdot
.97 .33503 Mdot
.97 .33507 Mdot
.97 .33522 Mdot
.97 .33567 Mdot
.97 .33576 Mdot
.97 .33592 Mdot
.97 .33596 Mdot
.97 .33634 Mdot
.97 .33635 Mdot
.97 .33642 Mdot
.97 .3365 Mdot
.97 .33659 Mdot
.97 .33669 Mdot
.97 .33676 Mdot
.97 .33733 Mdot
.97 .33752 Mdot
.97 .33762 Mdot
.97 .33782 Mdot
.97 .33823 Mdot
.97 .33837 Mdot
.97 .33868 Mdot
.97 .3387 Mdot
.97 .33875 Mdot
.97 .33889 Mdot
.97 .33892 Mdot
.97 .33908 Mdot
.97 .33916 Mdot
.97 .33922 Mdot
.97 .33951 Mdot
.97 .33973 Mdot
.97 .33974 Mdot
.97 .33975 Mdot
.97 .33979 Mdot
.97 .33997 Mdot
.97 .34023 Mdot
.97 .34056 Mdot
.97 .34119 Mdot
.97 .34151 Mdot
.97 .34161 Mdot
.97 .34173 Mdot
.97 .34253 Mdot
.97 .34267 Mdot
.97 .34302 Mdot
.97 .3433 Mdot
.97 .3438 Mdot
.97 .34397 Mdot
.97 .34422 Mdot
.97 .34454 Mdot
.97 .34469 Mdot
.97 .34475 Mdot
.97 .3448 Mdot
.97 .34513 Mdot
.97 .34519 Mdot
.97 .3452 Mdot
.97 .34546 Mdot
.97 .34569 Mdot
.97 .34577 Mdot
.97 .34601 Mdot
.97 .34634 Mdot
.97 .34638 Mdot
.97 .34671 Mdot
.97 .34678 Mdot
.97 .34698 Mdot
.97 .3471 Mdot
.97 .34743 Mdot
.97 .34755 Mdot
.97 .34755 Mdot
.97 .34759 Mdot
.97 .34768 Mdot
.97 .34774 Mdot
.97 .34775 Mdot
.97 .34825 Mdot
.97 .34847 Mdot
.97 .34862 Mdot
.97 .34868 Mdot
.97 .3488 Mdot
.97 .34906 Mdot
.97 .34918 Mdot
.97 .34929 Mdot
.97 .34943 Mdot
.97 .34945 Mdot
.97 .34951 Mdot
.97 .34961 Mdot
.97 .34965 Mdot
.97 .34966 Mdot
.97 .3502 Mdot
.97 .3509 Mdot
.97 .35096 Mdot
.97 .35144 Mdot
.97 .35236 Mdot
.97 .35256 Mdot
.97 .35422 Mdot
.97 .35426 Mdot
.97 .35442 Mdot
.97 .35466 Mdot
.97 .35479 Mdot
.97 .3548 Mdot
.97 .35481 Mdot
.97 .35611 Mdot
.97 .35629 Mdot
.97 .35697 Mdot
.97 .35702 Mdot
.97 .3571 Mdot
.97 .35757 Mdot
.97 .35812 Mdot
.97 .35887 Mdot
.97 .35931 Mdot
.97 .35939 Mdot
.97 .35946 Mdot
.97 .35949 Mdot
.97 .35961 Mdot
.97 .35987 Mdot
.97 .36001 Mdot
.97 .36027 Mdot
.97 .3604 Mdot
.97 .36046 Mdot
.97 .36049 Mdot
.97 .36102 Mdot
.97 .3612 Mdot
.97 .36127 Mdot
.97 .36133 Mdot
.97 .36147 Mdot
.97 .36152 Mdot
.97 .36173 Mdot
.97 .36208 Mdot
.97 .36211 Mdot
.97 .36213 Mdot
.97 .36216 Mdot
.97 .36217 Mdot
.97 .36228 Mdot
.97 .36235 Mdot
.97 .36239 Mdot
.97 .3624 Mdot
.97 .3624 Mdot
.97 .36241 Mdot
.97 .36242 Mdot
.97 .36249 Mdot
.97 .36274 Mdot
.97 .36344 Mdot
.97 .36345 Mdot
.97 .36352 Mdot
.97 .3636 Mdot
.97 .36379 Mdot
.97 .3638 Mdot
.97 .36396 Mdot
.97 .37068 Mdot
.97 .3715 Mdot
.97 .37444 Mdot
.97 .37687 Mdot
.97 .37704 Mdot
.97 .37743 Mdot
.97 .379 Mdot
.97 .37914 Mdot
.97 .37974 Mdot
.97 .37981 Mdot
.97 .38119 Mdot
.97 .38184 Mdot
.97 .38272 Mdot
.97 .38278 Mdot
.97 .38629 Mdot
.97 .38951 Mdot
.97 .38985 Mdot
.97 .39239 Mdot
.97 .39272 Mdot
.97 .39406 Mdot
.97 .39601 Mdot
.97 .39955 Mdot
.97 .40131 Mdot
.97 .40481 Mdot
.97 .40553 Mdot
.97 .41203 Mdot
.97 .413 Mdot
.97 .41387 Mdot
.97 .42031 Mdot
.97 .4206 Mdot
.97 .42412 Mdot
.97 .42582 Mdot
.97 .42917 Mdot
.97 .43076 Mdot
.97 .43098 Mdot
.97 .43148 Mdot
.97 .43222 Mdot
.97 .43284 Mdot
.97 .43362 Mdot
.97 .43574 Mdot
.97 .44062 Mdot
.97 .44299 Mdot
.97 .44345 Mdot
.97 .44751 Mdot
.97 .44806 Mdot
.97 .45299 Mdot
.97 .45549 Mdot
.97 .45583 Mdot
.97 .45625 Mdot
.97 .45707 Mdot
.97 .45712 Mdot
.97 .45931 Mdot
.97 .46002 Mdot
.97 .46072 Mdot
.97 .46122 Mdot
.97 .46382 Mdot
.97 .46531 Mdot
.97 .4659 Mdot
.97 .46609 Mdot
.97 .46638 Mdot
.97 .46657 Mdot
.97 .46696 Mdot
.97 .46966 Mdot
.97 .47067 Mdot
.97 .47086 Mdot
.97 .47237 Mdot
.97 .47284 Mdot
.97 .47311 Mdot
.97 .47358 Mdot
.97 .47368 Mdot
.97 .47374 Mdot
.97 .47384 Mdot
.97 .47423 Mdot
.97 .47477 Mdot
.97 .47579 Mdot
.97 .47594 Mdot
.97 .47719 Mdot
.97 .47765 Mdot
.97 .47869 Mdot
.97 .50869 Mdot
.97 .51214 Mdot
.97 .52811 Mdot
.97 .53561 Mdot
.97 .54927 Mdot
.97 .55366 Mdot
.97 .55367 Mdot
.97 .55368 Mdot
.97 .5537 Mdot
.97 .55371 Mdot
.97 .55372 Mdot
.97 .55372 Mdot
.97 .55373 Mdot
.97 .55373 Mdot
.97 .55373 Mdot
.97 .55373 Mdot
.97 .55374 Mdot
.97 .55374 Mdot
.97 .55376 Mdot
.97 .55378 Mdot
.97 .55382 Mdot
.97 .55382 Mdot
.97 .55383 Mdot
.97 .55384 Mdot
.97 .55385 Mdot
.97 .55389 Mdot
.97 .55389 Mdot
.97 .5539 Mdot
.97 .55391 Mdot
.97 .55394 Mdot
.97 .55394 Mdot
.97 .55395 Mdot
.97 .55396 Mdot
.97 .55396 Mdot
.97 .554 Mdot
.97 .55406 Mdot
.97 .55407 Mdot
.97 .55412 Mdot
.97 .55413 Mdot
.97 .55416 Mdot
.97 .55423 Mdot
.97 .55425 Mdot
.97 .55426 Mdot
.97 .55428 Mdot
.97 .55429 Mdot
.97 .55432 Mdot
.97 .55436 Mdot
.97 .55439 Mdot
.97 .55444 Mdot
.97 .55444 Mdot
.97 .55453 Mdot
.97 .55456 Mdot
.97 .55466 Mdot
.97 .55472 Mdot
.97 .55475 Mdot
.97 .55481 Mdot
.97 .55484 Mdot
.97 .55486 Mdot
.97 .55486 Mdot
.97 .55491 Mdot
.97 .55497 Mdot
.97 .55503 Mdot
.97 .55506 Mdot
.97 .55509 Mdot
.97 .5551 Mdot
.97 .5551 Mdot
.97 .55513 Mdot
.97 .55514 Mdot
.97 .55526 Mdot
.97 .55542 Mdot
.97 .55542 Mdot
.97 .55542 Mdot
.97 .55545 Mdot
.97 .55547 Mdot
.97 .55557 Mdot
.97 .55564 Mdot
.97 .55564 Mdot
.97 .55588 Mdot
.97 .5559 Mdot
.97 .55595 Mdot
.97 .55603 Mdot
.97 .55616 Mdot
.97 .55616 Mdot
.97 .5562 Mdot
.97 .55621 Mdot
.97 .55633 Mdot
.97 .55638 Mdot
.97 .55638 Mdot
.97 .55647 Mdot
.97 .55648 Mdot
.97 .55653 Mdot
.97 .55656 Mdot
.97 .5566 Mdot
.97 .55675 Mdot
.97 .55685 Mdot
.97 .55686 Mdot
.97 .55686 Mdot
.97 .55689 Mdot
.97 .5569 Mdot
.97 .55697 Mdot
.97 .55702 Mdot
.97 .55703 Mdot
.97 .55703 Mdot
.97 .55714 Mdot
.97 .55722 Mdot
.97 .55746 Mdot
.97 .55749 Mdot
.97 .55752 Mdot
.97 .5576 Mdot
.97 .5577 Mdot
.97 .55783 Mdot
.97 .55785 Mdot
.97 .5579 Mdot
.97 .55792 Mdot
.97 .55793 Mdot
.97 .55802 Mdot
.97 .55803 Mdot
.97 .55806 Mdot
.97 .55811 Mdot
.97 .55826 Mdot
.97 .55828 Mdot
.97 .5584 Mdot
.97 .55852 Mdot
.97 .55859 Mdot
.97 .55864 Mdot
.97 .55867 Mdot
.97 .55869 Mdot
.97 .55875 Mdot
.97 .55882 Mdot
.97 .55883 Mdot
.97 .55885 Mdot
.97 .5589 Mdot
.97 .5589 Mdot
.97 .55905 Mdot
.97 .55935 Mdot
.97 .55949 Mdot
.97 .55978 Mdot
.97 .55984 Mdot
.97 .55986 Mdot
.97 .55991 Mdot
.97 .55993 Mdot
.97 .55997 Mdot
.97 .56 Mdot
.97 .56 Mdot
.97 .56013 Mdot
.97 .56014 Mdot
.97 .56016 Mdot
.97 .56017 Mdot
.97 .56021 Mdot
.97 .56028 Mdot
.97 .56029 Mdot
.97 .56029 Mdot
.97 .5603 Mdot
.97 .56032 Mdot
.97 .56034 Mdot
.97 .56035 Mdot
.97 .56035 Mdot
.97 .56035 Mdot
.97 .56035 Mdot
.97 .56036 Mdot
.97 .56043 Mdot
.97 .56092 Mdot
.97 .56115 Mdot
.97 .56131 Mdot
.97 .56171 Mdot
.97 .56204 Mdot
.97 .56229 Mdot
.97 .56446 Mdot
.97 .5645 Mdot
.97 .56472 Mdot
.97 .56505 Mdot
.97 .56522 Mdot
.97 .56524 Mdot
.97 .56525 Mdot
.97 .56705 Mdot
.97 .56729 Mdot
.97 .56816 Mdot
.97 .56825 Mdot
.97 .56832 Mdot
.97 .56843 Mdot
.97 .569 Mdot
.97 .56909 Mdot
.97 .56988 Mdot
.97 .57092 Mdot
.97 .57154 Mdot
.97 .57166 Mdot
.97 .57176 Mdot
.97 .5718 Mdot
.97 .57196 Mdot
.97 .57233 Mdot
.97 .57252 Mdot
.97 .57289 Mdot
.97 .57307 Mdot
.97 .57315 Mdot
.97 .57319 Mdot
.97 .57391 Mdot
.97 .57417 Mdot
.97 .57426 Mdot
.97 .57435 Mdot
.97 .57453 Mdot
.97 .5746 Mdot
.97 .57488 Mdot
.97 .57534 Mdot
.97 .57538 Mdot
.97 .57541 Mdot
.97 .57546 Mdot
.97 .57547 Mdot
.97 .57562 Mdot
.97 .57571 Mdot
.97 .57576 Mdot
.97 .57577 Mdot
.97 .57577 Mdot
.97 .57579 Mdot
.97 .5758 Mdot
.97 .57589 Mdot
.97 .57599 Mdot
.97 .57622 Mdot
.97 .57712 Mdot
.97 .57713 Mdot
.97 .57722 Mdot
.97 .57732 Mdot
.97 .57755 Mdot
.97 .57757 Mdot
.97 .57776 Mdot
.97 .58144 Mdot
.97 .58151 Mdot
.97 .58252 Mdot
.97 .58317 Mdot
.97 .58428 Mdot
.97 .58432 Mdot
.97 .58437 Mdot
.97 .58476 Mdot
.97 .58476 Mdot
.97 .58484 Mdot
.97 .58553 Mdot
.97 .58565 Mdot
.97 .58569 Mdot
.97 .58578 Mdot
.972 .11508 Mdot
.972 .11508 Mdot
.972 .11508 Mdot
.972 .11508 Mdot
.972 .11508 Mdot
.972 .11508 Mdot
.972 .11509 Mdot
.972 .11509 Mdot
.972 .11509 Mdot
.972 .11509 Mdot
.972 .1151 Mdot
.972 .1151 Mdot
.972 .1151 Mdot
.972 .11511 Mdot
.972 .11511 Mdot
.972 .11511 Mdot
.972 .11511 Mdot
.972 .11513 Mdot
.972 .11513 Mdot
.972 .11513 Mdot
.972 .11513 Mdot
.972 .11514 Mdot
.972 .11514 Mdot
.972 .11514 Mdot
.972 .11516 Mdot
.972 .11518 Mdot
.972 .1152 Mdot
.972 .11521 Mdot
.972 .11522 Mdot
.972 .11522 Mdot
.972 .11523 Mdot
.972 .11528 Mdot
.972 .11529 Mdot
.972 .11529 Mdot
.972 .11529 Mdot
.972 .11531 Mdot
.972 .11531 Mdot
.972 .11532 Mdot
.972 .11533 Mdot
.972 .11535 Mdot
.972 .11535 Mdot
.972 .11536 Mdot
.972 .11536 Mdot
.972 .11536 Mdot
.972 .11538 Mdot
.972 .1154 Mdot
.972 .11541 Mdot
.972 .11542 Mdot
.972 .11544 Mdot
.972 .11547 Mdot
.972 .1155 Mdot
.972 .1155 Mdot
.972 .11553 Mdot
.972 .11553 Mdot
.972 .11554 Mdot
.972 .11554 Mdot
.972 .11556 Mdot
.972 .11556 Mdot
.972 .11556 Mdot
.972 .11558 Mdot
.972 .11558 Mdot
.972 .11558 Mdot
.972 .11559 Mdot
.972 .11559 Mdot
.972 .11559 Mdot
.972 .1156 Mdot
.972 .11561 Mdot
.972 .11561 Mdot
.972 .11561 Mdot
.972 .11561 Mdot
.972 .11566 Mdot
.972 .11571 Mdot
.972 .11571 Mdot
.972 .11571 Mdot
.972 .11574 Mdot
.972 .11574 Mdot
.972 .11575 Mdot
.972 .11576 Mdot
.972 .11576 Mdot
.972 .11577 Mdot
.972 .11578 Mdot
.972 .11579 Mdot
.972 .11579 Mdot
.972 .1158 Mdot
.972 .11581 Mdot
.972 .11581 Mdot
.972 .11581 Mdot
.972 .11582 Mdot
.972 .11582 Mdot
.972 .11582 Mdot
.972 .11582 Mdot
.972 .11582 Mdot
.972 .11583 Mdot
.972 .11583 Mdot
.972 .11583 Mdot
.972 .11583 Mdot
.972 .11586 Mdot
.972 .11587 Mdot
.972 .11587 Mdot
.972 .11587 Mdot
.972 .11588 Mdot
.972 .11588 Mdot
.972 .11588 Mdot
.972 .11588 Mdot
.972 .11589 Mdot
.972 .1159 Mdot
.972 .1159 Mdot
.972 .1159 Mdot
.972 .1159 Mdot
.972 .1159 Mdot
.972 .1159 Mdot
.972 .11591 Mdot
.972 .11591 Mdot
.972 .11592 Mdot
.972 .11592 Mdot
.972 .11592 Mdot
.972 .11592 Mdot
.972 .11593 Mdot
.972 .11593 Mdot
.972 .11593 Mdot
.972 .11593 Mdot
.972 .11593 Mdot
.972 .11593 Mdot
.972 .11593 Mdot
.972 .11593 Mdot
.972 .11594 Mdot
.972 .11594 Mdot
.972 .11594 Mdot
.972 .11595 Mdot
.972 .11595 Mdot
.972 .11595 Mdot
.972 .11595 Mdot
.972 .11595 Mdot
.972 .11596 Mdot
.972 .11596 Mdot
.972 .11596 Mdot
.972 .11596 Mdot
.972 .11597 Mdot
.972 .11597 Mdot
.972 .11597 Mdot
.972 .11597 Mdot
.972 .11597 Mdot
.972 .11597 Mdot
.972 .11597 Mdot
.972 .11597 Mdot
.972 .11597 Mdot
.972 .11598 Mdot
.972 .11598 Mdot
.972 .11598 Mdot
.972 .11598 Mdot
.972 .11598 Mdot
.972 .11599 Mdot
.972 .11599 Mdot
.972 .11599 Mdot
.972 .11601 Mdot
.972 .11601 Mdot
.972 .11601 Mdot
.972 .11601 Mdot
.972 .11601 Mdot
.972 .11601 Mdot
.972 .11601 Mdot
.972 .11601 Mdot
.972 .11601 Mdot
.972 .11601 Mdot
.972 .11602 Mdot
.972 .11602 Mdot
.972 .11602 Mdot
.972 .11603 Mdot
.972 .11603 Mdot
.972 .11603 Mdot
.972 .11604 Mdot
.972 .11604 Mdot
.972 .11604 Mdot
.972 .11605 Mdot
.972 .11605 Mdot
.972 .11605 Mdot
.972 .11606 Mdot
.972 .11606 Mdot
.972 .11607 Mdot
.972 .11609 Mdot
.972 .11611 Mdot
.972 .11611 Mdot
.972 .11611 Mdot
.972 .11611 Mdot
.972 .11611 Mdot
.972 .11612 Mdot
.972 .11612 Mdot
.972 .11612 Mdot
.972 .11612 Mdot
.972 .11613 Mdot
.972 .11613 Mdot
.972 .11613 Mdot
.972 .11613 Mdot
.972 .11613 Mdot
.972 .11614 Mdot
.972 .11614 Mdot
.972 .11614 Mdot
.972 .11614 Mdot
.972 .11616 Mdot
.972 .11616 Mdot
.972 .11617 Mdot
.972 .11618 Mdot
.972 .11619 Mdot
.972 .11619 Mdot
.972 .1162 Mdot
.972 .1162 Mdot
.972 .11621 Mdot
.972 .11621 Mdot
.972 .11621 Mdot
.972 .11621 Mdot
.972 .11621 Mdot
.972 .11622 Mdot
.972 .11623 Mdot
.972 .11623 Mdot
.972 .11623 Mdot
.972 .11624 Mdot
.972 .11624 Mdot
.972 .11624 Mdot
.972 .11626 Mdot
.972 .11626 Mdot
.972 .11626 Mdot
.972 .11626 Mdot
.972 .11627 Mdot
.972 .11627 Mdot
.972 .11628 Mdot
.972 .11629 Mdot
.972 .11629 Mdot
.972 .11629 Mdot
.972 .11629 Mdot
.972 .11629 Mdot
.972 .11629 Mdot
.972 .11629 Mdot
.972 .1163 Mdot
.972 .1163 Mdot
.972 .1163 Mdot
.972 .1163 Mdot
.972 .1163 Mdot
.972 .1163 Mdot
.972 .1163 Mdot
.972 .1163 Mdot
.972 .11631 Mdot
.972 .11631 Mdot
.972 .11631 Mdot
.972 .11631 Mdot
.972 .11631 Mdot
.972 .11631 Mdot
.972 .11631 Mdot
.972 .11631 Mdot
.972 .11631 Mdot
.972 .11631 Mdot
.972 .16711 Mdot
.972 .16711 Mdot
.972 .16711 Mdot
.972 .16711 Mdot
.972 .16712 Mdot
.972 .16713 Mdot
.972 .16715 Mdot
.972 .16716 Mdot
.972 .16717 Mdot
.972 .16717 Mdot
.972 .16721 Mdot
.972 .16721 Mdot
.972 .16722 Mdot
.972 .16724 Mdot
.972 .16724 Mdot
.972 .16725 Mdot
.972 .16726 Mdot
.972 .16731 Mdot
.972 .16733 Mdot
.972 .16733 Mdot
.972 .16733 Mdot
.972 .16735 Mdot
.972 .16737 Mdot
.972 .16739 Mdot
.972 .16745 Mdot
.972 .16756 Mdot
.972 .16763 Mdot
.972 .16768 Mdot
.972 .16771 Mdot
.972 .16773 Mdot
.972 .16775 Mdot
.972 .168 Mdot
.972 .16803 Mdot
.972 .16804 Mdot
.972 .16805 Mdot
.972 .1681 Mdot
.972 .16811 Mdot
.972 .16816 Mdot
.972 .16818 Mdot
.972 .1683 Mdot
.972 .16831 Mdot
.972 .16832 Mdot
.972 .16833 Mdot
.972 .16835 Mdot
.972 .16842 Mdot
.972 .1685 Mdot
.972 .16855 Mdot
.972 .1686 Mdot
.972 .16867 Mdot
.972 .1688 Mdot
.972 .16894 Mdot
.972 .16897 Mdot
.972 .16908 Mdot
.972 .16908 Mdot
.972 .16912 Mdot
.972 .16914 Mdot
.972 .16919 Mdot
.972 .16921 Mdot
.972 .16923 Mdot
.972 .16928 Mdot
.972 .16928 Mdot
.972 .1693 Mdot
.972 .16933 Mdot
.972 .16933 Mdot
.972 .16934 Mdot
.972 .1694 Mdot
.972 .16942 Mdot
.972 .16942 Mdot
.972 .16944 Mdot
.972 .16945 Mdot
.972 .16964 Mdot
.972 .16987 Mdot
.972 .16989 Mdot
.972 .16989 Mdot
.972 .16999 Mdot
.972 .16999 Mdot
.972 .17006 Mdot
.972 .17008 Mdot
.972 .1701 Mdot
.972 .17013 Mdot
.972 .17018 Mdot
.972 .17024 Mdot
.972 .17024 Mdot
.972 .17029 Mdot
.972 .1703 Mdot
.972 .17033 Mdot
.972 .17034 Mdot
.972 .17036 Mdot
.972 .17036 Mdot
.972 .17037 Mdot
.972 .17037 Mdot
.972 .17038 Mdot
.972 .1704 Mdot
.972 .17041 Mdot
.972 .17041 Mdot
.972 .17042 Mdot
.972 .17056 Mdot
.972 .17057 Mdot
.972 .17057 Mdot
.972 .1706 Mdot
.972 .17063 Mdot
.972 .17063 Mdot
.972 .17064 Mdot
.972 .17065 Mdot
.972 .17068 Mdot
.972 .17071 Mdot
.972 .17071 Mdot
.972 .17073 Mdot
.972 .17073 Mdot
.972 .17073 Mdot
.972 .17074 Mdot
.972 .17074 Mdot
.972 .17074 Mdot
.972 .17079 Mdot
.972 .17079 Mdot
.972 .17082 Mdot
.972 .17082 Mdot
.972 .17083 Mdot
.972 .17085 Mdot
.972 .17085 Mdot
.972 .17085 Mdot
.972 .17086 Mdot
.972 .17086 Mdot
.972 .17087 Mdot
.972 .17087 Mdot
.972 .17088 Mdot
.972 .17088 Mdot
.972 .1709 Mdot
.972 .17092 Mdot
.972 .17093 Mdot
.972 .17094 Mdot
.972 .17095 Mdot
.972 .17096 Mdot
.972 .17097 Mdot
.972 .17097 Mdot
.972 .17099 Mdot
.972 .17099 Mdot
.972 .17101 Mdot
.972 .17101 Mdot
.972 .17102 Mdot
.972 .17102 Mdot
.972 .17102 Mdot
.972 .17102 Mdot
.972 .17103 Mdot
.972 .17104 Mdot
.972 .17105 Mdot
.972 .17107 Mdot
.972 .17107 Mdot
.972 .17108 Mdot
.972 .17108 Mdot
.972 .17109 Mdot
.972 .17111 Mdot
.972 .17111 Mdot
.972 .17112 Mdot
.972 .17119 Mdot
.972 .17119 Mdot
.972 .1712 Mdot
.972 .1712 Mdot
.972 .17121 Mdot
.972 .17121 Mdot
.972 .17121 Mdot
.972 .17122 Mdot
.972 .17122 Mdot
.972 .17123 Mdot
.972 .17124 Mdot
.972 .17125 Mdot
.972 .17126 Mdot
.972 .17128 Mdot
.972 .17128 Mdot
.972 .17131 Mdot
.972 .17134 Mdot
.972 .17135 Mdot
.972 .17136 Mdot
.972 .17137 Mdot
.972 .1714 Mdot
.972 .17141 Mdot
.972 .17145 Mdot
.972 .17145 Mdot
.972 .17147 Mdot
.972 .17157 Mdot
.972 .17165 Mdot
.972 .17166 Mdot
.972 .17167 Mdot
.972 .17167 Mdot
.972 .17167 Mdot
.972 .1717 Mdot
.972 .17171 Mdot
.972 .17171 Mdot
.972 .17172 Mdot
.972 .17173 Mdot
.972 .17173 Mdot
.972 .17175 Mdot
.972 .17176 Mdot
.972 .17177 Mdot
.972 .17179 Mdot
.972 .1718 Mdot
.972 .17181 Mdot
.972 .17181 Mdot
.972 .17186 Mdot
.972 .17187 Mdot
.972 .17193 Mdot
.972 .17198 Mdot
.972 .17201 Mdot
.972 .17203 Mdot
.972 .17205 Mdot
.972 .17208 Mdot
.972 .17211 Mdot
.972 .17211 Mdot
.972 .17212 Mdot
.972 .17212 Mdot
.972 .17213 Mdot
.972 .17217 Mdot
.972 .17218 Mdot
.972 .1722 Mdot
.972 .1722 Mdot
.972 .17222 Mdot
.972 .17222 Mdot
.972 .17223 Mdot
.972 .17224 Mdot
.972 .17233 Mdot
.972 .17233 Mdot
.972 .17234 Mdot
.972 .17235 Mdot
.972 .17236 Mdot
.972 .17238 Mdot
.972 .1724 Mdot
.972 .17244 Mdot
.972 .17246 Mdot
.972 .17247 Mdot
.972 .17248 Mdot
.972 .17248 Mdot
.972 .17248 Mdot
.972 .17248 Mdot
.972 .17249 Mdot
.972 .17251 Mdot
.972 .17251 Mdot
.972 .17251 Mdot
.972 .17252 Mdot
.972 .17252 Mdot
.972 .17253 Mdot
.972 .17253 Mdot
.972 .17254 Mdot
.972 .17254 Mdot
.972 .17254 Mdot
.972 .17255 Mdot
.972 .17255 Mdot
.972 .17256 Mdot
.972 .17256 Mdot
.972 .17256 Mdot
.972 .17256 Mdot
.972 .17256 Mdot
.972 .36365 Mdot
.972 .36365 Mdot
.972 .36365 Mdot
.972 .36365 Mdot
.972 .36365 Mdot
.972 .36365 Mdot
.972 .36366 Mdot
.972 .36366 Mdot
.972 .36366 Mdot
.972 .36366 Mdot
.972 .36367 Mdot
.972 .36367 Mdot
.972 .36367 Mdot
.972 .36367 Mdot
.972 .36367 Mdot
.972 .36368 Mdot
.972 .36368 Mdot
.972 .36369 Mdot
.972 .36369 Mdot
.972 .36369 Mdot
.972 .36369 Mdot
.972 .36369 Mdot
.972 .36369 Mdot
.972 .3637 Mdot
.972 .36371 Mdot
.972 .36373 Mdot
.972 .36374 Mdot
.972 .36375 Mdot
.972 .36375 Mdot
.972 .36376 Mdot
.972 .36376 Mdot
.972 .3638 Mdot
.972 .36381 Mdot
.972 .36381 Mdot
.972 .36381 Mdot
.972 .36382 Mdot
.972 .36382 Mdot
.972 .36383 Mdot
.972 .36383 Mdot
.972 .36385 Mdot
.972 .36386 Mdot
.972 .36386 Mdot
.972 .36386 Mdot
.972 .36386 Mdot
.972 .36387 Mdot
.972 .36389 Mdot
.972 .3639 Mdot
.972 .3639 Mdot
.972 .36392 Mdot
.972 .36394 Mdot
.972 .36396 Mdot
.972 .36397 Mdot
.972 .36398 Mdot
.972 .36399 Mdot
.972 .36399 Mdot
.972 .36399 Mdot
.972 .364 Mdot
.972 .36401 Mdot
.972 .36401 Mdot
.972 .36402 Mdot
.972 .36402 Mdot
.972 .36402 Mdot
.972 .36403 Mdot
.972 .36403 Mdot
.972 .36403 Mdot
.972 .36404 Mdot
.972 .36404 Mdot
.972 .36404 Mdot
.972 .36404 Mdot
.972 .36405 Mdot
.972 .36408 Mdot
.972 .36411 Mdot
.972 .36412 Mdot
.972 .36412 Mdot
.972 .36414 Mdot
.972 .36414 Mdot
.972 .36415 Mdot
.972 .36415 Mdot
.972 .36415 Mdot
.972 .36416 Mdot
.972 .36417 Mdot
.972 .36418 Mdot
.972 .36418 Mdot
.972 .36418 Mdot
.972 .36419 Mdot
.972 .36419 Mdot
.972 .36419 Mdot
.972 .3642 Mdot
.972 .3642 Mdot
.972 .3642 Mdot
.972 .3642 Mdot
.972 .3642 Mdot
.972 .3642 Mdot
.972 .3642 Mdot
.972 .3642 Mdot
.972 .36421 Mdot
.972 .36423 Mdot
.972 .36423 Mdot
.972 .36423 Mdot
.972 .36424 Mdot
.972 .36424 Mdot
.972 .36424 Mdot
.972 .36424 Mdot
.972 .36424 Mdot
.972 .36425 Mdot
.972 .36425 Mdot
.972 .36425 Mdot
.972 .36426 Mdot
.972 .36426 Mdot
.972 .36426 Mdot
.972 .36426 Mdot
.972 .36426 Mdot
.972 .36426 Mdot
.972 .36427 Mdot
.972 .36427 Mdot
.972 .36427 Mdot
.972 .36427 Mdot
.972 .36427 Mdot
.972 .36428 Mdot
.972 .36428 Mdot
.972 .36428 Mdot
.972 .36428 Mdot
.972 .36428 Mdot
.972 .36428 Mdot
.972 .36428 Mdot
.972 .36428 Mdot
.972 .36428 Mdot
.972 .36428 Mdot
.972 .36429 Mdot
.972 .36429 Mdot
.972 .36429 Mdot
.972 .36429 Mdot
.972 .36429 Mdot
.972 .3643 Mdot
.972 .3643 Mdot
.972 .3643 Mdot
.972 .3643 Mdot
.972 .3643 Mdot
.972 .3643 Mdot
.972 .3643 Mdot
.972 .3643 Mdot
.972 .3643 Mdot
.972 .3643 Mdot
.972 .36431 Mdot
.972 .36431 Mdot
.972 .36431 Mdot
.972 .36431 Mdot
.972 .36431 Mdot
.972 .36431 Mdot
.972 .36431 Mdot
.972 .36432 Mdot
.972 .36432 Mdot
.972 .36432 Mdot
.972 .36432 Mdot
.972 .36433 Mdot
.972 .36433 Mdot
.972 .36433 Mdot
.972 .36433 Mdot
.972 .36434 Mdot
.972 .36434 Mdot
.972 .36434 Mdot
.972 .36434 Mdot
.972 .36434 Mdot
.972 .36434 Mdot
.972 .36434 Mdot
.972 .36434 Mdot
.972 .36434 Mdot
.972 .36435 Mdot
.972 .36435 Mdot
.972 .36435 Mdot
.972 .36436 Mdot
.972 .36436 Mdot
.972 .36436 Mdot
.972 .36436 Mdot
.972 .36437 Mdot
.972 .36437 Mdot
.972 .36437 Mdot
.972 .36437 Mdot
.972 .36438 Mdot
.972 .36439 Mdot
.972 .36441 Mdot
.972 .36441 Mdot
.972 .36441 Mdot
.972 .36441 Mdot
.972 .36441 Mdot
.972 .36442 Mdot
.972 .36442 Mdot
.972 .36442 Mdot
.972 .36442 Mdot
.972 .36442 Mdot
.972 .36442 Mdot
.972 .36442 Mdot
.972 .36442 Mdot
.972 .36443 Mdot
.972 .36443 Mdot
.972 .36443 Mdot
.972 .36443 Mdot
.972 .36443 Mdot
.972 .36444 Mdot
.972 .36444 Mdot
.972 .36445 Mdot
.972 .36446 Mdot
.972 .36446 Mdot
.972 .36447 Mdot
.972 .36447 Mdot
.972 .36448 Mdot
.972 .36448 Mdot
.972 .36448 Mdot
.972 .36448 Mdot
.972 .36448 Mdot
.972 .36448 Mdot
.972 .36449 Mdot
.972 .36449 Mdot
.972 .3645 Mdot
.972 .3645 Mdot
.972 .3645 Mdot
.972 .3645 Mdot
.972 .3645 Mdot
.972 .36452 Mdot
.972 .36452 Mdot
.972 .36452 Mdot
.972 .36452 Mdot
.972 .36452 Mdot
.972 .36452 Mdot
.972 .36453 Mdot
.972 .36453 Mdot
.972 .36454 Mdot
.972 .36454 Mdot
.972 .36454 Mdot
.972 .36454 Mdot
.972 .36454 Mdot
.972 .36454 Mdot
.972 .36454 Mdot
.972 .36454 Mdot
.972 .36455 Mdot
.972 .36455 Mdot
.972 .36455 Mdot
.972 .36455 Mdot
.972 .36455 Mdot
.972 .36455 Mdot
.972 .36455 Mdot
.972 .36455 Mdot
.972 .36455 Mdot
.972 .36455 Mdot
.972 .36455 Mdot
.972 .36455 Mdot
.972 .36455 Mdot
.972 .36455 Mdot
.972 .36455 Mdot
.972 .36455 Mdot
.972 .57854 Mdot
.972 .57854 Mdot
.972 .57854 Mdot
.972 .57854 Mdot
.972 .57855 Mdot
.972 .57855 Mdot
.972 .57855 Mdot
.972 .57855 Mdot
.972 .57856 Mdot
.972 .57856 Mdot
.972 .57856 Mdot
.972 .57857 Mdot
.972 .57857 Mdot
.972 .57857 Mdot
.972 .57857 Mdot
.972 .57857 Mdot
.972 .57858 Mdot
.972 .57859 Mdot
.972 .57859 Mdot
.972 .57859 Mdot
.972 .57859 Mdot
.972 .5786 Mdot
.972 .5786 Mdot
.972 .5786 Mdot
.972 .57862 Mdot
.972 .57864 Mdot
.972 .57866 Mdot
.972 .57867 Mdot
.972 .57867 Mdot
.972 .57868 Mdot
.972 .57868 Mdot
.972 .57873 Mdot
.972 .57874 Mdot
.972 .57874 Mdot
.972 .57874 Mdot
.972 .57875 Mdot
.972 .57876 Mdot
.972 .57877 Mdot
.972 .57877 Mdot
.972 .5788 Mdot
.972 .5788 Mdot
.972 .5788 Mdot
.972 .5788 Mdot
.972 .57881 Mdot
.972 .57882 Mdot
.972 .57884 Mdot
.972 .57885 Mdot
.972 .57886 Mdot
.972 .57887 Mdot
.972 .5789 Mdot
.972 .57893 Mdot
.972 .57894 Mdot
.972 .57896 Mdot
.972 .57896 Mdot
.972 .57897 Mdot
.972 .57897 Mdot
.972 .57898 Mdot
.972 .57899 Mdot
.972 .57899 Mdot
.972 .579 Mdot
.972 .579 Mdot
.972 .579 Mdot
.972 .57901 Mdot
.972 .57901 Mdot
.972 .57901 Mdot
.972 .57903 Mdot
.972 .57903 Mdot
.972 .57903 Mdot
.972 .57903 Mdot
.972 .57904 Mdot
.972 .57908 Mdot
.972 .57912 Mdot
.972 .57913 Mdot
.972 .57913 Mdot
.972 .57915 Mdot
.972 .57915 Mdot
.972 .57916 Mdot
.972 .57916 Mdot
.972 .57917 Mdot
.972 .57917 Mdot
.972 .57918 Mdot
.972 .5792 Mdot
.972 .5792 Mdot
.972 .57921 Mdot
.972 .57921 Mdot
.972 .57921 Mdot
.972 .57922 Mdot
.972 .57922 Mdot
.972 .57922 Mdot
.972 .57922 Mdot
.972 .57922 Mdot
.972 .57922 Mdot
.972 .57923 Mdot
.972 .57923 Mdot
.972 .57923 Mdot
.972 .57923 Mdot
.972 .57926 Mdot
.972 .57926 Mdot
.972 .57926 Mdot
.972 .57927 Mdot
.972 .57927 Mdot
.972 .57927 Mdot
.972 .57928 Mdot
.972 .57928 Mdot
.972 .57929 Mdot
.972 .57929 Mdot
.972 .57929 Mdot
.972 .57929 Mdot
.972 .57929 Mdot
.972 .57929 Mdot
.972 .5793 Mdot
.972 .5793 Mdot
.972 .5793 Mdot
.972 .57931 Mdot
.972 .57931 Mdot
.972 .57931 Mdot
.972 .57931 Mdot
.972 .57932 Mdot
.972 .57932 Mdot
.972 .57932 Mdot
.972 .57932 Mdot
.972 .57932 Mdot
.972 .57932 Mdot
.972 .57932 Mdot
.972 .57932 Mdot
.972 .57932 Mdot
.972 .57932 Mdot
.972 .57933 Mdot
.972 .57933 Mdot
.972 .57934 Mdot
.972 .57934 Mdot
.972 .57934 Mdot
.972 .57934 Mdot
.972 .57934 Mdot
.972 .57934 Mdot
.972 .57935 Mdot
.972 .57935 Mdot
.972 .57935 Mdot
.972 .57935 Mdot
.972 .57935 Mdot
.972 .57935 Mdot
.972 .57935 Mdot
.972 .57935 Mdot
.972 .57935 Mdot
.972 .57936 Mdot
.972 .57936 Mdot
.972 .57936 Mdot
.972 .57936 Mdot
.972 .57936 Mdot
.972 .57936 Mdot
.972 .57937 Mdot
.972 .57937 Mdot
.972 .57937 Mdot
.972 .57937 Mdot
.972 .57939 Mdot
.972 .57939 Mdot
.972 .57939 Mdot
.972 .57939 Mdot
.972 .57939 Mdot
.972 .57939 Mdot
.972 .57939 Mdot
.972 .57939 Mdot
.972 .57939 Mdot
.972 .57939 Mdot
.972 .5794 Mdot
.972 .5794 Mdot
.972 .5794 Mdot
.972 .5794 Mdot
.972 .5794 Mdot
.972 .57941 Mdot
.972 .57942 Mdot
.972 .57942 Mdot
.972 .57942 Mdot
.972 .57942 Mdot
.972 .57943 Mdot
.972 .57943 Mdot
.972 .57944 Mdot
.972 .57944 Mdot
.972 .57944 Mdot
.972 .57946 Mdot
.972 .57948 Mdot
.972 .57948 Mdot
.972 .57948 Mdot
.972 .57948 Mdot
.972 .57948 Mdot
.972 .57949 Mdot
.972 .57949 Mdot
.972 .57949 Mdot
.972 .57949 Mdot
.972 .57949 Mdot
.972 .57949 Mdot
.972 .5795 Mdot
.972 .5795 Mdot
.972 .5795 Mdot
.972 .5795 Mdot
.972 .57951 Mdot
.972 .57951 Mdot
.972 .57951 Mdot
.972 .57952 Mdot
.972 .57952 Mdot
.972 .57953 Mdot
.972 .57954 Mdot
.972 .57955 Mdot
.972 .57955 Mdot
.972 .57955 Mdot
.972 .57956 Mdot
.972 .57957 Mdot
.972 .57957 Mdot
.972 .57957 Mdot
.972 .57957 Mdot
.972 .57957 Mdot
.972 .57958 Mdot
.972 .57958 Mdot
.972 .57958 Mdot
.972 .57958 Mdot
.972 .57959 Mdot
.972 .57959 Mdot
.972 .57959 Mdot
.972 .57961 Mdot
.972 .57961 Mdot
.972 .57961 Mdot
.972 .57961 Mdot
.972 .57961 Mdot
.972 .57962 Mdot
.972 .57962 Mdot
.972 .57963 Mdot
.972 .57964 Mdot
.972 .57964 Mdot
.972 .57964 Mdot
.972 .57964 Mdot
.972 .57964 Mdot
.972 .57964 Mdot
.972 .57964 Mdot
.972 .57964 Mdot
.972 .57964 Mdot
.972 .57964 Mdot
.972 .57965 Mdot
.972 .57965 Mdot
.972 .57965 Mdot
.972 .57965 Mdot
.972 .57965 Mdot
.972 .57965 Mdot
.972 .57965 Mdot
.972 .57965 Mdot
.972 .57965 Mdot
.972 .57965 Mdot
.972 .57965 Mdot
.972 .57965 Mdot
.972 .57965 Mdot
.972 .57965 Mdot
.974 .11002 Mdot
.974 .11002 Mdot
.974 .11002 Mdot
.974 .11003 Mdot
.974 .11003 Mdot
.974 .11003 Mdot
.974 .11004 Mdot
.974 .11004 Mdot
.974 .11004 Mdot
.974 .11005 Mdot
.974 .11007 Mdot
.974 .11008 Mdot
.974 .11008 Mdot
.974 .11008 Mdot
.974 .11009 Mdot
.974 .11009 Mdot
.974 .1101 Mdot
.974 .11012 Mdot
.974 .11023 Mdot
.974 .11024 Mdot
.974 .11032 Mdot
.974 .11034 Mdot
.974 .11037 Mdot
.974 .11037 Mdot
.974 .11038 Mdot
.974 .11044 Mdot
.974 .11058 Mdot
.974 .11063 Mdot
.974 .11087 Mdot
.974 .11092 Mdot
.974 .11095 Mdot
.974 .11099 Mdot
.974 .11106 Mdot
.974 .11118 Mdot
.974 .11124 Mdot
.974 .11136 Mdot
.974 .11152 Mdot
.974 .11155 Mdot
.974 .11156 Mdot
.974 .11162 Mdot
.974 .11162 Mdot
.974 .11174 Mdot
.974 .11181 Mdot
.974 .11183 Mdot
.974 .11187 Mdot
.974 .11192 Mdot
.974 .11197 Mdot
.974 .112 Mdot
.974 .11203 Mdot
.974 .11206 Mdot
.974 .11208 Mdot
.974 .11209 Mdot
.974 .11209 Mdot
.974 .11252 Mdot
.974 .11265 Mdot
.974 .11284 Mdot
.974 .1129 Mdot
.974 .1132 Mdot
.974 .11354 Mdot
.974 .11378 Mdot
.974 .11391 Mdot
.974 .11397 Mdot
.974 .11399 Mdot
.974 .11406 Mdot
.974 .1141 Mdot
.974 .11418 Mdot
.974 .11428 Mdot
.974 .11429 Mdot
.974 .11429 Mdot
.974 .11433 Mdot
.974 .11434 Mdot
.974 .11438 Mdot
.974 .11438 Mdot
.974 .11442 Mdot
.974 .11444 Mdot
.974 .11444 Mdot
.974 .11456 Mdot
.974 .11462 Mdot
.974 .11467 Mdot
.974 .1147 Mdot
.974 .11478 Mdot
.974 .11484 Mdot
.974 .11507 Mdot
.974 .11516 Mdot
.974 .11527 Mdot
.974 .11537 Mdot
.974 .11542 Mdot
.974 .11546 Mdot
.974 .11551 Mdot
.974 .1156 Mdot
.974 .11583 Mdot
.974 .11591 Mdot
.974 .11597 Mdot
.974 .116 Mdot
.974 .11604 Mdot
.974 .11605 Mdot
.974 .11606 Mdot
.974 .11607 Mdot
.974 .11623 Mdot
.974 .1163 Mdot
.974 .11641 Mdot
.974 .11642 Mdot
.974 .11642 Mdot
.974 .11644 Mdot
.974 .11646 Mdot
.974 .11648 Mdot
.974 .11649 Mdot
.974 .1165 Mdot
.974 .1165 Mdot
.974 .11652 Mdot
.974 .11655 Mdot
.974 .11655 Mdot
.974 .11663 Mdot
.974 .11664 Mdot
.974 .11666 Mdot
.974 .11668 Mdot
.974 .11673 Mdot
.974 .11675 Mdot
.974 .11676 Mdot
.974 .11678 Mdot
.974 .1168 Mdot
.974 .11682 Mdot
.974 .11691 Mdot
.974 .11691 Mdot
.974 .11693 Mdot
.974 .11696 Mdot
.974 .11697 Mdot
.974 .11698 Mdot
.974 .11702 Mdot
.974 .11724 Mdot
.974 .1174 Mdot
.974 .11741 Mdot
.974 .11744 Mdot
.974 .11745 Mdot
.974 .1175 Mdot
.974 .11756 Mdot
.974 .11759 Mdot
.974 .1176 Mdot
.974 .11766 Mdot
.974 .11768 Mdot
.974 .11775 Mdot
.974 .11776 Mdot
.974 .11784 Mdot
.974 .11798 Mdot
.974 .118 Mdot
.974 .11805 Mdot
.974 .11805 Mdot
.974 .11814 Mdot
.974 .11815 Mdot
.974 .11816 Mdot
.974 .11818 Mdot
.974 .1182 Mdot
.974 .1182 Mdot
.974 .11822 Mdot
.974 .1183 Mdot
.974 .11835 Mdot
.974 .11835 Mdot
.974 .11838 Mdot
.974 .1185 Mdot
.974 .11865 Mdot
.974 .11867 Mdot
.974 .11868 Mdot
.974 .11869 Mdot
.974 .1187 Mdot
.974 .11877 Mdot
.974 .1188 Mdot
.974 .11891 Mdot
.974 .11892 Mdot
.974 .11893 Mdot
.974 .11894 Mdot
.974 .11896 Mdot
.974 .11896 Mdot
.974 .11897 Mdot
.974 .11897 Mdot
.974 .11913 Mdot
.974 .11927 Mdot
.974 .11939 Mdot
.974 .11958 Mdot
.974 .11974 Mdot
.974 .11974 Mdot
.974 .11975 Mdot
.974 .11979 Mdot
.974 .1198 Mdot
.974 .11985 Mdot
.974 .11997 Mdot
.974 .12004 Mdot
.974 .1201 Mdot
.974 .1201 Mdot
.974 .12014 Mdot
.974 .1205 Mdot
.974 .12058 Mdot
.974 .12061 Mdot
.974 .12079 Mdot
.974 .12081 Mdot
.974 .12083 Mdot
.974 .12083 Mdot
.974 .12094 Mdot
.974 .12122 Mdot
.974 .12124 Mdot
.974 .12148 Mdot
.974 .12152 Mdot
.974 .12154 Mdot
.974 .12158 Mdot
.974 .12174 Mdot
.974 .12181 Mdot
.974 .12212 Mdot
.974 .12231 Mdot
.974 .12231 Mdot
.974 .12238 Mdot
.974 .12257 Mdot
.974 .12273 Mdot
.974 .12276 Mdot
.974 .12285 Mdot
.974 .12285 Mdot
.974 .12287 Mdot
.974 .12289 Mdot
.974 .12301 Mdot
.974 .12305 Mdot
.974 .12329 Mdot
.974 .12384 Mdot
.974 .12386 Mdot
.974 .12399 Mdot
.974 .12401 Mdot
.974 .12424 Mdot
.974 .12429 Mdot
.974 .1246 Mdot
.974 .12461 Mdot
.974 .12462 Mdot
.974 .12473 Mdot
.974 .12485 Mdot
.974 .12491 Mdot
.974 .12493 Mdot
.974 .12493 Mdot
.974 .12503 Mdot
.974 .1251 Mdot
.974 .12511 Mdot
.974 .12514 Mdot
.974 .12515 Mdot
.974 .12519 Mdot
.974 .12528 Mdot
.974 .12529 Mdot
.974 .12548 Mdot
.974 .12564 Mdot
.974 .12577 Mdot
.974 .12581 Mdot
.974 .12583 Mdot
.974 .12585 Mdot
.974 .12586 Mdot
.974 .12587 Mdot
.974 .12588 Mdot
.974 .14717 Mdot
.974 .14717 Mdot
.974 .14718 Mdot
.974 .14719 Mdot
.974 .14722 Mdot
.974 .14722 Mdot
.974 .14723 Mdot
.974 .14723 Mdot
.974 .14723 Mdot
.974 .14729 Mdot
.974 .14734 Mdot
.974 .14737 Mdot
.974 .14737 Mdot
.974 .14738 Mdot
.974 .14742 Mdot
.974 .14744 Mdot
.974 .14746 Mdot
.974 .14755 Mdot
.974 .14792 Mdot
.974 .14797 Mdot
.974 .14827 Mdot
.974 .14835 Mdot
.974 .14846 Mdot
.974 .14846 Mdot
.974 .14847 Mdot
.974 .14872 Mdot
.974 .14922 Mdot
.974 .1494 Mdot
.974 .15031 Mdot
.974 .1505 Mdot
.974 .15061 Mdot
.974 .15077 Mdot
.974 .15104 Mdot
.974 .15149 Mdot
.974 .15171 Mdot
.974 .15216 Mdot
.974 .15279 Mdot
.974 .1529 Mdot
.974 .15293 Mdot
.974 .15315 Mdot
.974 .15317 Mdot
.974 .15364 Mdot
.974 .1539 Mdot
.974 .15398 Mdot
.974 .15416 Mdot
.974 .15433 Mdot
.974 .15452 Mdot
.974 .15464 Mdot
.974 .15478 Mdot
.974 .15488 Mdot
.974 .15498 Mdot
.974 .15498 Mdot
.974 .15501 Mdot
.974 .15671 Mdot
.974 .15723 Mdot
.974 .15798 Mdot
.974 .15823 Mdot
.974 .15946 Mdot
.974 .16088 Mdot
.974 .16188 Mdot
.974 .16242 Mdot
.974 .16265 Mdot
.974 .16275 Mdot
.974 .16306 Mdot
.974 .16323 Mdot
.974 .16353 Mdot
.974 .16398 Mdot
.974 .16401 Mdot
.974 .16403 Mdot
.974 .16417 Mdot
.974 .16423 Mdot
.974 .1644 Mdot
.974 .16441 Mdot
.974 .16457 Mdot
.974 .16465 Mdot
.974 .16466 Mdot
.974 .16516 Mdot
.974 .16545 Mdot
.974 .16567 Mdot
.974 .16578 Mdot
.974 .1661 Mdot
.974 .16639 Mdot
.974 .16737 Mdot
.974 .16776 Mdot
.974 .16825 Mdot
.974 .1687 Mdot
.974 .16893 Mdot
.974 .1691 Mdot
.974 .16931 Mdot
.974 .16969 Mdot
.974 .17074 Mdot
.974 .1711 Mdot
.974 .17136 Mdot
.974 .17151 Mdot
.974 .17168 Mdot
.974 .1717 Mdot
.974 .17177 Mdot
.974 .1718 Mdot
.974 .17253 Mdot
.974 .17282 Mdot
.974 .17333 Mdot
.974 .17338 Mdot
.974 .17338 Mdot
.974 .17345 Mdot
.974 .17356 Mdot
.974 .17365 Mdot
.974 .1737 Mdot
.974 .17375 Mdot
.974 .17376 Mdot
.974 .17384 Mdot
.974 .17396 Mdot
.974 .17398 Mdot
.974 .17433 Mdot
.974 .17436 Mdot
.974 .17448 Mdot
.974 .17456 Mdot
.974 .17479 Mdot
.974 .17486 Mdot
.974 .17494 Mdot
.974 .17499 Mdot
.974 .17509 Mdot
.974 .17519 Mdot
.974 .17559 Mdot
.974 .17561 Mdot
.974 .17572 Mdot
.974 .17582 Mdot
.974 .1759 Mdot
.974 .17592 Mdot
.974 .17611 Mdot
.974 .17715 Mdot
.974 .17787 Mdot
.974 .17792 Mdot
.974 .17803 Mdot
.974 .17812 Mdot
.974 .17833 Mdot
.974 .1786 Mdot
.974 .17873 Mdot
.974 .17879 Mdot
.974 .17906 Mdot
.974 .17916 Mdot
.974 .17949 Mdot
.974 .17956 Mdot
.974 .17991 Mdot
.974 .18057 Mdot
.974 .18067 Mdot
.974 .1809 Mdot
.974 .1809 Mdot
.974 .18132 Mdot
.974 .18139 Mdot
.974 .18141 Mdot
.974 .18153 Mdot
.974 .18159 Mdot
.974 .18163 Mdot
.974 .18168 Mdot
.974 .18209 Mdot
.974 .18234 Mdot
.974 .18234 Mdot
.974 .18245 Mdot
.974 .18303 Mdot
.974 .18373 Mdot
.974 .18383 Mdot
.974 .1839 Mdot
.974 .18392 Mdot
.974 .18398 Mdot
.974 .18434 Mdot
.974 .18446 Mdot
.974 .18499 Mdot
.974 .18506 Mdot
.974 .1851 Mdot
.974 .18513 Mdot
.974 .18525 Mdot
.974 .18525 Mdot
.974 .18529 Mdot
.974 .1853 Mdot
.974 .18606 Mdot
.974 .1867 Mdot
.974 .18732 Mdot
.974 .18824 Mdot
.974 .189 Mdot
.974 .189 Mdot
.974 .18904 Mdot
.974 .18923 Mdot
.974 .18932 Mdot
.974 .18956 Mdot
.974 .19011 Mdot
.974 .19049 Mdot
.974 .19076 Mdot
.974 .19077 Mdot
.974 .19094 Mdot
.974 .19274 Mdot
.974 .19313 Mdot
.974 .19327 Mdot
.974 .19417 Mdot
.974 .19429 Mdot
.974 .19435 Mdot
.974 .19438 Mdot
.974 .19492 Mdot
.974 .1963 Mdot
.974 .19641 Mdot
.974 .19763 Mdot
.974 .19784 Mdot
.974 .19792 Mdot
.974 .19811 Mdot
.974 .1989 Mdot
.974 .19928 Mdot
.974 .20084 Mdot
.974 .20178 Mdot
.974 .20182 Mdot
.974 .20214 Mdot
.974 .20312 Mdot
.974 .20395 Mdot
.974 .20409 Mdot
.974 .20457 Mdot
.974 .20457 Mdot
.974 .20464 Mdot
.974 .20474 Mdot
.974 .20536 Mdot
.974 .20557 Mdot
.974 .20672 Mdot
.974 .20681 Mdot
.974 .20963 Mdot
.974 .20973 Mdot
.974 .21042 Mdot
.974 .21055 Mdot
.974 .21172 Mdot
.974 .21197 Mdot
.974 .21359 Mdot
.974 .21365 Mdot
.974 .21372 Mdot
.974 .21426 Mdot
.974 .21492 Mdot
.974 .21523 Mdot
.974 .2153 Mdot
.974 .21531 Mdot
.974 .21582 Mdot
.974 .21619 Mdot
.974 .21627 Mdot
.974 .2164 Mdot
.974 .21646 Mdot
.974 .21668 Mdot
.974 .21715 Mdot
.974 .21717 Mdot
.974 .21822 Mdot
.974 .21905 Mdot
.974 .21971 Mdot
.974 .21994 Mdot
.974 .22002 Mdot
.974 .22013 Mdot
.974 .2202 Mdot
.974 .22026 Mdot
.974 .22028 Mdot
.974 .32397 Mdot
.974 .32398 Mdot
.974 .32401 Mdot
.974 .32405 Mdot
.974 .32414 Mdot
.974 .32415 Mdot
.974 .32417 Mdot
.974 .32417 Mdot
.974 .32417 Mdot
.974 .32443 Mdot
.974 .3246 Mdot
.974 .32473 Mdot
.974 .32473 Mdot
.974 .32473 Mdot
.974 .3249 Mdot
.974 .32498 Mdot
.974 .32506 Mdot
.974 .32539 Mdot
.974 .32675 Mdot
.974 .32694 Mdot
.974 .32806 Mdot
.974 .32834 Mdot
.974 .32873 Mdot
.974 .32873 Mdot
.974 .32875 Mdot
.974 .32965 Mdot
.974 .33142 Mdot
.974 .33202 Mdot
.974 .33295 Mdot
.974 .33296 Mdot
.974 .33298 Mdot
.974 .333 Mdot
.974 .333 Mdot
.974 .33301 Mdot
.974 .33303 Mdot
.974 .33314 Mdot
.974 .33315 Mdot
.974 .33321 Mdot
.974 .33322 Mdot
.974 .33323 Mdot
.974 .33356 Mdot
.974 .33364 Mdot
.974 .33369 Mdot
.974 .33436 Mdot
.974 .3346 Mdot
.974 .33511 Mdot
.974 .33515 Mdot
.974 .33529 Mdot
.974 .33536 Mdot
.974 .33552 Mdot
.974 .33571 Mdot
.974 .33574 Mdot
.974 .33583 Mdot
.974 .33607 Mdot
.974 .33656 Mdot
.974 .33656 Mdot
.974 .33657 Mdot
.974 .33667 Mdot
.974 .3367 Mdot
.974 .33744 Mdot
.974 .33805 Mdot
.974 .33816 Mdot
.974 .33851 Mdot
.974 .33862 Mdot
.974 .33865 Mdot
.974 .33873 Mdot
.974 .33886 Mdot
.974 .33886 Mdot
.974 .33952 Mdot
.974 .33988 Mdot
.974 .34005 Mdot
.974 .34052 Mdot
.974 .34088 Mdot
.974 .341 Mdot
.974 .34111 Mdot
.974 .34122 Mdot
.974 .34217 Mdot
.974 .34273 Mdot
.974 .3428 Mdot
.974 .34302 Mdot
.974 .34302 Mdot
.974 .34304 Mdot
.974 .34312 Mdot
.974 .3434 Mdot
.974 .34341 Mdot
.974 .34375 Mdot
.974 .3438 Mdot
.974 .34402 Mdot
.974 .34416 Mdot
.974 .34418 Mdot
.974 .34466 Mdot
.974 .34498 Mdot
.974 .34508 Mdot
.974 .3451 Mdot
.974 .34523 Mdot
.974 .34537 Mdot
.974 .34542 Mdot
.974 .34543 Mdot
.974 .34578 Mdot
.974 .34598 Mdot
.974 .34601 Mdot
.974 .34618 Mdot
.974 .34646 Mdot
.974 .34647 Mdot
.974 .34648 Mdot
.974 .3466 Mdot
.974 .34691 Mdot
.974 .3471 Mdot
.974 .34739 Mdot
.974 .34768 Mdot
.974 .34778 Mdot
.974 .34805 Mdot
.974 .34817 Mdot
.974 .34824 Mdot
.974 .34828 Mdot
.974 .34853 Mdot
.974 .34855 Mdot
.974 .34861 Mdot
.974 .34865 Mdot
.974 .34956 Mdot
.974 .35064 Mdot
.974 .35064 Mdot
.974 .35071 Mdot
.974 .35071 Mdot
.974 .35079 Mdot
.974 .35087 Mdot
.974 .35093 Mdot
.974 .35098 Mdot
.974 .35108 Mdot
.974 .35182 Mdot
.974 .35198 Mdot
.974 .35249 Mdot
.974 .35252 Mdot
.974 .35258 Mdot
.974 .3526 Mdot
.974 .3527 Mdot
.974 .35283 Mdot
.974 .35296 Mdot
.974 .35361 Mdot
.974 .3538 Mdot
.974 .35458 Mdot
.974 .35473 Mdot
.974 .35473 Mdot
.974 .3548 Mdot
.974 .35506 Mdot
.974 .3551 Mdot
.974 .35544 Mdot
.974 .35557 Mdot
.974 .35559 Mdot
.974 .35566 Mdot
.974 .35566 Mdot
.974 .35571 Mdot
.974 .3558 Mdot
.974 .35595 Mdot
.974 .35597 Mdot
.974 .35598 Mdot
.974 .35606 Mdot
.974 .35619 Mdot
.974 .35637 Mdot
.974 .35643 Mdot
.974 .3566 Mdot
.974 .3566 Mdot
.974 .35689 Mdot
.974 .35701 Mdot
.974 .35772 Mdot
.974 .35783 Mdot
.974 .35824 Mdot
.974 .35832 Mdot
.974 .35871 Mdot
.974 .35883 Mdot
.974 .35914 Mdot
.974 .35921 Mdot
.974 .35935 Mdot
.974 .35965 Mdot
.974 .35986 Mdot
.974 .35988 Mdot
.974 .35997 Mdot
.974 .36009 Mdot
.974 .36014 Mdot
.974 .36089 Mdot
.974 .36114 Mdot
.974 .36176 Mdot
.974 .36187 Mdot
.974 .36201 Mdot
.974 .36204 Mdot
.974 .36205 Mdot
.974 .36211 Mdot
.974 .36213 Mdot
.974 .36221 Mdot
.974 .3623 Mdot
.974 .36232 Mdot
.974 .36242 Mdot
.974 .36259 Mdot
.974 .36265 Mdot
.974 .36273 Mdot
.974 .36281 Mdot
.974 .36285 Mdot
.974 .36287 Mdot
.974 .36291 Mdot
.974 .36297 Mdot
.974 .36313 Mdot
.974 .36319 Mdot
.974 .36325 Mdot
.974 .36328 Mdot
.974 .36328 Mdot
.974 .36329 Mdot
.974 .3633 Mdot
.974 .36341 Mdot
.974 .36346 Mdot
.974 .36354 Mdot
.974 .36355 Mdot
.974 .36358 Mdot
.974 .36359 Mdot
.974 .36363 Mdot
.974 .36369 Mdot
.974 .36369 Mdot
.974 .36371 Mdot
.974 .36372 Mdot
.974 .36376 Mdot
.974 .36377 Mdot
.974 .36378 Mdot
.974 .36382 Mdot
.974 .36388 Mdot
.974 .36392 Mdot
.974 .36392 Mdot
.974 .36395 Mdot
.974 .36411 Mdot
.974 .36423 Mdot
.974 .36428 Mdot
.974 .36438 Mdot
.974 .3644 Mdot
.974 .36446 Mdot
.974 .36462 Mdot
.974 .36471 Mdot
.974 .36472 Mdot
.974 .36474 Mdot
.974 .36475 Mdot
.974 .36475 Mdot
.974 .36482 Mdot
.974 .36487 Mdot
.974 .36495 Mdot
.974 .36505 Mdot
.974 .36507 Mdot
.974 .36515 Mdot
.974 .36523 Mdot
.974 .36524 Mdot
.974 .36527 Mdot
.974 .36527 Mdot
.974 .36527 Mdot
.974 .36527 Mdot
.974 .55588 Mdot
.974 .55589 Mdot
.974 .55589 Mdot
.974 .5559 Mdot
.974 .55591 Mdot
.974 .55591 Mdot
.974 .55593 Mdot
.974 .55598 Mdot
.974 .55605 Mdot
.974 .55613 Mdot
.974 .55614 Mdot
.974 .55617 Mdot
.974 .55619 Mdot
.974 .5562 Mdot
.974 .55621 Mdot
.974 .55621 Mdot
.974 .55624 Mdot
.974 .55629 Mdot
.974 .55629 Mdot
.974 .55629 Mdot
.974 .55632 Mdot
.974 .55637 Mdot
.974 .55642 Mdot
.974 .55642 Mdot
.974 .55643 Mdot
.974 .55657 Mdot
.974 .55659 Mdot
.974 .55669 Mdot
.974 .5567 Mdot
.974 .55676 Mdot
.974 .55677 Mdot
.974 .55701 Mdot
.974 .55712 Mdot
.974 .55714 Mdot
.974 .5572 Mdot
.974 .55721 Mdot
.974 .55722 Mdot
.974 .55722 Mdot
.974 .55726 Mdot
.974 .55727 Mdot
.974 .55735 Mdot
.974 .55744 Mdot
.974 .55747 Mdot
.974 .55747 Mdot
.974 .55756 Mdot
.974 .55771 Mdot
.974 .55775 Mdot
.974 .55782 Mdot
.974 .55784 Mdot
.974 .55785 Mdot
.974 .55787 Mdot
.974 .55799 Mdot
.974 .558 Mdot
.974 .55814 Mdot
.974 .5582 Mdot
.974 .5582 Mdot
.974 .55821 Mdot
.974 .55822 Mdot
.974 .55831 Mdot
.974 .55832 Mdot
.974 .55837 Mdot
.974 .55856 Mdot
.974 .55857 Mdot
.974 .55858 Mdot
.974 .5586 Mdot
.974 .55865 Mdot
.974 .55871 Mdot
.974 .55873 Mdot
.974 .55874 Mdot
.974 .55876 Mdot
.974 .55877 Mdot
.974 .55877 Mdot
.974 .55885 Mdot
.974 .55895 Mdot
.974 .55902 Mdot
.974 .5591 Mdot
.974 .5592 Mdot
.974 .55921 Mdot
.974 .5593 Mdot
.974 .55934 Mdot
.974 .55935 Mdot
.974 .55935 Mdot
.974 .55954 Mdot
.974 .55954 Mdot
.974 .55962 Mdot
.974 .55966 Mdot
.974 .55972 Mdot
.974 .55972 Mdot
.974 .55976 Mdot
.974 .55984 Mdot
.974 .5599 Mdot
.974 .55999 Mdot
.974 .56 Mdot
.974 .56001 Mdot
.974 .56008 Mdot
.974 .5601 Mdot
.974 .56011 Mdot
.974 .56039 Mdot
.974 .5604 Mdot
.974 .56042 Mdot
.974 .56049 Mdot
.974 .56051 Mdot
.974 .56065 Mdot
.974 .56067 Mdot
.974 .56068 Mdot
.974 .56068 Mdot
.974 .56071 Mdot
.974 .56074 Mdot
.974 .56075 Mdot
.974 .56104 Mdot
.974 .56192 Mdot
.974 .56204 Mdot
.974 .56219 Mdot
.974 .56224 Mdot
.974 .56224 Mdot
.974 .56231 Mdot
.974 .56231 Mdot
.974 .5624 Mdot
.974 .5625 Mdot
.974 .56256 Mdot
.974 .56263 Mdot
.974 .56274 Mdot
.974 .56296 Mdot
.974 .56364 Mdot
.974 .56383 Mdot
.974 .56397 Mdot
.974 .56447 Mdot
.974 .56447 Mdot
.974 .5645 Mdot
.974 .56457 Mdot
.974 .56461 Mdot
.974 .56473 Mdot
.974 .5649 Mdot
.974 .56507 Mdot
.974 .56515 Mdot
.974 .56516 Mdot
.974 .5652 Mdot
.974 .56591 Mdot
.974 .56603 Mdot
.974 .56616 Mdot
.974 .56721 Mdot
.974 .56741 Mdot
.974 .56741 Mdot
.974 .5675 Mdot
.974 .56786 Mdot
.974 .56792 Mdot
.974 .56838 Mdot
.974 .56857 Mdot
.974 .5686 Mdot
.974 .56869 Mdot
.974 .56869 Mdot
.974 .56877 Mdot
.974 .56888 Mdot
.974 .5691 Mdot
.974 .56913 Mdot
.974 .56914 Mdot
.974 .56926 Mdot
.974 .56943 Mdot
.974 .56968 Mdot
.974 .56977 Mdot
.974 .57 Mdot
.974 .57001 Mdot
.974 .57042 Mdot
.974 .57059 Mdot
.974 .57159 Mdot
.974 .57175 Mdot
.974 .57233 Mdot
.974 .57245 Mdot
.974 .573 Mdot
.974 .57316 Mdot
.974 .5736 Mdot
.974 .5737 Mdot
.974 .5739 Mdot
.974 .57433 Mdot
.974 .57461 Mdot
.974 .57464 Mdot
.974 .57477 Mdot
.974 .57493 Mdot
.974 .57501 Mdot
.974 .57605 Mdot
.974 .5764 Mdot
.974 .57724 Mdot
.974 .57738 Mdot
.974 .57756 Mdot
.974 .57761 Mdot
.974 .57762 Mdot
.974 .5777 Mdot
.974 .57773 Mdot
.974 .57784 Mdot
.974 .57796 Mdot
.974 .57798 Mdot
.974 .57812 Mdot
.974 .57834 Mdot
.974 .57842 Mdot
.974 .57853 Mdot
.974 .57862 Mdot
.974 .57867 Mdot
.974 .57871 Mdot
.974 .57875 Mdot
.974 .57883 Mdot
.974 .57905 Mdot
.974 .57912 Mdot
.974 .5792 Mdot
.974 .57924 Mdot
.974 .57924 Mdot
.974 .57925 Mdot
.974 .57926 Mdot
.974 .5794 Mdot
.974 .57946 Mdot
.974 .57957 Mdot
.974 .57958 Mdot
.974 .57962 Mdot
.974 .57963 Mdot
.974 .57968 Mdot
.974 .57975 Mdot
.974 .57975 Mdot
.974 .57978 Mdot
.974 .57979 Mdot
.974 .57983 Mdot
.974 .57985 Mdot
.974 .57986 Mdot
.974 .57991 Mdot
.974 .57999 Mdot
.974 .58004 Mdot
.974 .58005 Mdot
.974 .58008 Mdot
.974 .58027 Mdot
.974 .58043 Mdot
.974 .58048 Mdot
.974 .58061 Mdot
.974 .58063 Mdot
.974 .5807 Mdot
.974 .58089 Mdot
.974 .581 Mdot
.974 .58102 Mdot
.974 .58104 Mdot
.974 .58105 Mdot
.974 .58106 Mdot
.974 .58113 Mdot
.974 .58119 Mdot
.974 .58129 Mdot
.974 .58141 Mdot
.974 .58143 Mdot
.974 .58153 Mdot
.974 .58162 Mdot
.974 .58163 Mdot
.974 .58166 Mdot
.974 .58166 Mdot
.974 .58167 Mdot
.974 .58167 Mdot
.976 .11022 Mdot
.976 .11022 Mdot
.976 .11024 Mdot
.976 .11025 Mdot
.976 .11026 Mdot
.976 .11026 Mdot
.976 .11027 Mdot
.976 .11028 Mdot
.976 .11028 Mdot
.976 .11029 Mdot
.976 .11029 Mdot
.976 .1103 Mdot
.976 .11031 Mdot
.976 .11034 Mdot
.976 .11034 Mdot
.976 .11037 Mdot
.976 .11043 Mdot
.976 .11051 Mdot
.976 .11053 Mdot
.976 .11053 Mdot
.976 .11053 Mdot
.976 .11054 Mdot
.976 .11058 Mdot
.976 .11064 Mdot
.976 .11066 Mdot
.976 .11067 Mdot
.976 .11068 Mdot
.976 .11074 Mdot
.976 .11076 Mdot
.976 .11076 Mdot
.976 .11077 Mdot
.976 .11077 Mdot
.976 .11081 Mdot
.976 .11082 Mdot
.976 .11083 Mdot
.976 .11084 Mdot
.976 .11087 Mdot
.976 .11091 Mdot
.976 .11091 Mdot
.976 .11091 Mdot
.976 .11104 Mdot
.976 .11109 Mdot
.976 .11116 Mdot
.976 .11118 Mdot
.976 .11123 Mdot
.976 .11123 Mdot
.976 .11138 Mdot
.976 .11144 Mdot
.976 .11149 Mdot
.976 .11151 Mdot
.976 .11154 Mdot
.976 .11174 Mdot
.976 .11185 Mdot
.976 .11189 Mdot
.976 .11221 Mdot
.976 .11225 Mdot
.976 .11225 Mdot
.976 .11233 Mdot
.976 .11236 Mdot
.976 .11237 Mdot
.976 .11247 Mdot
.976 .1125 Mdot
.976 .11254 Mdot
.976 .1126 Mdot
.976 .11264 Mdot
.976 .11274 Mdot
.976 .11277 Mdot
.976 .11279 Mdot
.976 .11284 Mdot
.976 .11288 Mdot
.976 .11291 Mdot
.976 .11298 Mdot
.976 .113 Mdot
.976 .11307 Mdot
.976 .11329 Mdot
.976 .11332 Mdot
.976 .11337 Mdot
.976 .11337 Mdot
.976 .11341 Mdot
.976 .11343 Mdot
.976 .11346 Mdot
.976 .1136 Mdot
.976 .11367 Mdot
.976 .1137 Mdot
.976 .11377 Mdot
.976 .11402 Mdot
.976 .1141 Mdot
.976 .11416 Mdot
.976 .11416 Mdot
.976 .11426 Mdot
.976 .11429 Mdot
.976 .11429 Mdot
.976 .11453 Mdot
.976 .11454 Mdot
.976 .11459 Mdot
.976 .11463 Mdot
.976 .11475 Mdot
.976 .11497 Mdot
.976 .1151 Mdot
.976 .11515 Mdot
.976 .11523 Mdot
.976 .11523 Mdot
.976 .11542 Mdot
.976 .11548 Mdot
.976 .11558 Mdot
.976 .11564 Mdot
.976 .11573 Mdot
.976 .11592 Mdot
.976 .11616 Mdot
.976 .11619 Mdot
.976 .1162 Mdot
.976 .11626 Mdot
.976 .11629 Mdot
.976 .11639 Mdot
.976 .11642 Mdot
.976 .11648 Mdot
.976 .11653 Mdot
.976 .11655 Mdot
.976 .11663 Mdot
.976 .11671 Mdot
.976 .11674 Mdot
.976 .11675 Mdot
.976 .1168 Mdot
.976 .11683 Mdot
.976 .11693 Mdot
.976 .11707 Mdot
.976 .11709 Mdot
.976 .1171 Mdot
.976 .11717 Mdot
.976 .11723 Mdot
.976 .11726 Mdot
.976 .11738 Mdot
.976 .11743 Mdot
.976 .11743 Mdot
.976 .11744 Mdot
.976 .11754 Mdot
.976 .11758 Mdot
.976 .11762 Mdot
.976 .1177 Mdot
.976 .11779 Mdot
.976 .11794 Mdot
.976 .11796 Mdot
.976 .11803 Mdot
.976 .11815 Mdot
.976 .11817 Mdot
.976 .11828 Mdot
.976 .11835 Mdot
.976 .11836 Mdot
.976 .11838 Mdot
.976 .11838 Mdot
.976 .11839 Mdot
.976 .1184 Mdot
.976 .11843 Mdot
.976 .1185 Mdot
.976 .11858 Mdot
.976 .1186 Mdot
.976 .11865 Mdot
.976 .11869 Mdot
.976 .1188 Mdot
.976 .11885 Mdot
.976 .11886 Mdot
.976 .1189 Mdot
.976 .11891 Mdot
.976 .11893 Mdot
.976 .11894 Mdot
.976 .11895 Mdot
.976 .11895 Mdot
.976 .11897 Mdot
.976 .119 Mdot
.976 .11901 Mdot
.976 .11904 Mdot
.976 .1191 Mdot
.976 .11911 Mdot
.976 .11912 Mdot
.976 .11915 Mdot
.976 .11915 Mdot
.976 .11919 Mdot
.976 .11922 Mdot
.976 .11925 Mdot
.976 .11941 Mdot
.976 .11947 Mdot
.976 .11956 Mdot
.976 .11961 Mdot
.976 .11972 Mdot
.976 .11986 Mdot
.976 .11991 Mdot
.976 .11997 Mdot
.976 .12003 Mdot
.976 .12004 Mdot
.976 .12008 Mdot
.976 .1201 Mdot
.976 .1201 Mdot
.976 .12022 Mdot
.976 .12025 Mdot
.976 .12026 Mdot
.976 .12028 Mdot
.976 .12032 Mdot
.976 .12036 Mdot
.976 .12043 Mdot
.976 .12044 Mdot
.976 .12044 Mdot
.976 .12058 Mdot
.976 .12088 Mdot
.976 .12093 Mdot
.976 .12105 Mdot
.976 .12114 Mdot
.976 .12141 Mdot
.976 .12144 Mdot
.976 .12145 Mdot
.976 .12145 Mdot
.976 .12151 Mdot
.976 .12153 Mdot
.976 .12155 Mdot
.976 .12165 Mdot
.976 .12166 Mdot
.976 .1217 Mdot
.976 .12171 Mdot
.976 .12172 Mdot
.976 .12176 Mdot
.976 .12177 Mdot
.976 .12177 Mdot
.976 .12179 Mdot
.976 .12181 Mdot
.976 .12181 Mdot
.976 .12198 Mdot
.976 .12216 Mdot
.976 .12217 Mdot
.976 .12219 Mdot
.976 .12242 Mdot
.976 .12244 Mdot
.976 .12251 Mdot
.976 .12252 Mdot
.976 .12266 Mdot
.976 .12287 Mdot
.976 .12294 Mdot
.976 .12295 Mdot
.976 .12302 Mdot
.976 .12313 Mdot
.976 .12315 Mdot
.976 .12322 Mdot
.976 .12324 Mdot
.976 .12333 Mdot
.976 .12341 Mdot
.976 .12349 Mdot
.976 .12352 Mdot
.976 .12352 Mdot
.976 .12352 Mdot
.976 .12354 Mdot
.976 .12354 Mdot
.976 .12355 Mdot
.976 .14816 Mdot
.976 .14817 Mdot
.976 .14823 Mdot
.976 .14827 Mdot
.976 .14832 Mdot
.976 .14833 Mdot
.976 .14837 Mdot
.976 .14838 Mdot
.976 .14841 Mdot
.976 .14841 Mdot
.976 .14842 Mdot
.976 .14847 Mdot
.976 .14851 Mdot
.976 .14861 Mdot
.976 .14863 Mdot
.976 .14871 Mdot
.976 .14896 Mdot
.976 .14924 Mdot
.976 .1493 Mdot
.976 .14931 Mdot
.976 .14932 Mdot
.976 .14935 Mdot
.976 .14951 Mdot
.976 .14972 Mdot
.976 .1498 Mdot
.976 .14983 Mdot
.976 .14986 Mdot
.976 .1501 Mdot
.976 .15017 Mdot
.976 .15017 Mdot
.976 .15022 Mdot
.976 .15023 Mdot
.976 .15036 Mdot
.976 .1504 Mdot
.976 .15044 Mdot
.976 .15048 Mdot
.976 .15058 Mdot
.976 .15072 Mdot
.976 .15074 Mdot
.976 .15075 Mdot
.976 .15125 Mdot
.976 .15142 Mdot
.976 .15167 Mdot
.976 .15175 Mdot
.976 .15193 Mdot
.976 .15196 Mdot
.976 .15252 Mdot
.976 .15277 Mdot
.976 .15296 Mdot
.976 .15302 Mdot
.976 .15315 Mdot
.976 .15393 Mdot
.976 .15434 Mdot
.976 .15452 Mdot
.976 .15578 Mdot
.976 .15593 Mdot
.976 .15594 Mdot
.976 .15622 Mdot
.976 .15635 Mdot
.976 .15642 Mdot
.976 .1568 Mdot
.976 .15692 Mdot
.976 .15707 Mdot
.976 .15733 Mdot
.976 .15748 Mdot
.976 .15788 Mdot
.976 .15801 Mdot
.976 .1581 Mdot
.976 .15829 Mdot
.976 .15846 Mdot
.976 .15857 Mdot
.976 .15887 Mdot
.976 .15894 Mdot
.976 .15922 Mdot
.976 .16014 Mdot
.976 .16025 Mdot
.976 .16045 Mdot
.976 .16046 Mdot
.976 .16063 Mdot
.976 .1607 Mdot
.976 .16085 Mdot
.976 .1614 Mdot
.976 .1617 Mdot
.976 .16186 Mdot
.976 .16215 Mdot
.976 .16319 Mdot
.976 .1635 Mdot
.976 .16376 Mdot
.976 .16379 Mdot
.976 .16419 Mdot
.976 .16432 Mdot
.976 .16433 Mdot
.976 .16538 Mdot
.976 .16542 Mdot
.976 .16562 Mdot
.976 .1658 Mdot
.976 .16629 Mdot
.976 .16725 Mdot
.976 .16783 Mdot
.976 .16806 Mdot
.976 .16837 Mdot
.976 .1684 Mdot
.976 .16923 Mdot
.976 .1695 Mdot
.976 .16992 Mdot
.976 .1702 Mdot
.976 .17061 Mdot
.976 .17147 Mdot
.976 .17255 Mdot
.976 .17265 Mdot
.976 .17269 Mdot
.976 .17296 Mdot
.976 .17311 Mdot
.976 .17355 Mdot
.976 .1737 Mdot
.976 .17396 Mdot
.976 .1742 Mdot
.976 .17429 Mdot
.976 .17464 Mdot
.976 .17502 Mdot
.976 .17515 Mdot
.976 .17522 Mdot
.976 .17543 Mdot
.976 .17559 Mdot
.976 .17604 Mdot
.976 .17669 Mdot
.976 .17676 Mdot
.976 .17681 Mdot
.976 .17714 Mdot
.976 .1774 Mdot
.976 .17755 Mdot
.976 .1781 Mdot
.976 .17832 Mdot
.976 .17835 Mdot
.976 .1784 Mdot
.976 .17884 Mdot
.976 .17904 Mdot
.976 .17921 Mdot
.976 .17959 Mdot
.976 .18001 Mdot
.976 .18075 Mdot
.976 .18082 Mdot
.976 .18117 Mdot
.976 .18174 Mdot
.976 .18182 Mdot
.976 .18231 Mdot
.976 .18266 Mdot
.976 .18273 Mdot
.976 .18283 Mdot
.976 .18283 Mdot
.976 .18284 Mdot
.976 .18292 Mdot
.976 .18307 Mdot
.976 .18339 Mdot
.976 .18374 Mdot
.976 .18384 Mdot
.976 .18408 Mdot
.976 .18427 Mdot
.976 .1848 Mdot
.976 .18507 Mdot
.976 .1851 Mdot
.976 .18527 Mdot
.976 .18534 Mdot
.976 .18545 Mdot
.976 .18549 Mdot
.976 .18552 Mdot
.976 .18553 Mdot
.976 .18563 Mdot
.976 .18578 Mdot
.976 .18582 Mdot
.976 .18595 Mdot
.976 .18627 Mdot
.976 .18632 Mdot
.976 .18634 Mdot
.976 .18648 Mdot
.976 .1865 Mdot
.976 .1867 Mdot
.976 .18683 Mdot
.976 .18697 Mdot
.976 .18777 Mdot
.976 .18805 Mdot
.976 .1885 Mdot
.976 .18872 Mdot
.976 .18924 Mdot
.976 .18996 Mdot
.976 .19021 Mdot
.976 .19047 Mdot
.976 .1908 Mdot
.976 .19081 Mdot
.976 .19102 Mdot
.976 .19111 Mdot
.976 .19112 Mdot
.976 .1917 Mdot
.976 .19186 Mdot
.976 .19189 Mdot
.976 .192 Mdot
.976 .19221 Mdot
.976 .1924 Mdot
.976 .19278 Mdot
.976 .19278 Mdot
.976 .19281 Mdot
.976 .19347 Mdot
.976 .19497 Mdot
.976 .19526 Mdot
.976 .19583 Mdot
.976 .1963 Mdot
.976 .19765 Mdot
.976 .19781 Mdot
.976 .19784 Mdot
.976 .19785 Mdot
.976 .19814 Mdot
.976 .19824 Mdot
.976 .19836 Mdot
.976 .19886 Mdot
.976 .19887 Mdot
.976 .19911 Mdot
.976 .19915 Mdot
.976 .19921 Mdot
.976 .19942 Mdot
.976 .19944 Mdot
.976 .19946 Mdot
.976 .19954 Mdot
.976 .19965 Mdot
.976 .19967 Mdot
.976 .20052 Mdot
.976 .20142 Mdot
.976 .20148 Mdot
.976 .20157 Mdot
.976 .20273 Mdot
.976 .20287 Mdot
.976 .2032 Mdot
.976 .20328 Mdot
.976 .20396 Mdot
.976 .20506 Mdot
.976 .20516 Mdot
.976 .20542 Mdot
.976 .20547 Mdot
.976 .20584 Mdot
.976 .2064 Mdot
.976 .20651 Mdot
.976 .20685 Mdot
.976 .20696 Mdot
.976 .20742 Mdot
.976 .20784 Mdot
.976 .20826 Mdot
.976 .20839 Mdot
.976 .20839 Mdot
.976 .20841 Mdot
.976 .20848 Mdot
.976 .20851 Mdot
.976 .20854 Mdot
.976 .32827 Mdot
.976 .32831 Mdot
.976 .32856 Mdot
.976 .32869 Mdot
.976 .32888 Mdot
.976 .32888 Mdot
.976 .32905 Mdot
.976 .32909 Mdot
.976 .32919 Mdot
.976 .3292 Mdot
.976 .32923 Mdot
.976 .32939 Mdot
.976 .32955 Mdot
.976 .32992 Mdot
.976 .32997 Mdot
.976 .33025 Mdot
.976 .33116 Mdot
.976 .33214 Mdot
.976 .33234 Mdot
.976 .33238 Mdot
.976 .33242 Mdot
.976 .3325 Mdot
.976 .33306 Mdot
.976 .33361 Mdot
.976 .33362 Mdot
.976 .33363 Mdot
.976 .33366 Mdot
.976 .33368 Mdot
.976 .33374 Mdot
.976 .33376 Mdot
.976 .33379 Mdot
.976 .33382 Mdot
.976 .33383 Mdot
.976 .33394 Mdot
.976 .33395 Mdot
.976 .33398 Mdot
.976 .334 Mdot
.976 .33406 Mdot
.976 .33415 Mdot
.976 .33416 Mdot
.976 .3342 Mdot
.976 .33425 Mdot
.976 .33435 Mdot
.976 .33436 Mdot
.976 .33442 Mdot
.976 .33467 Mdot
.976 .33479 Mdot
.976 .3348 Mdot
.976 .33486 Mdot
.976 .33491 Mdot
.976 .33492 Mdot
.976 .33493 Mdot
.976 .33493 Mdot
.976 .33505 Mdot
.976 .33506 Mdot
.976 .33509 Mdot
.976 .33512 Mdot
.976 .33523 Mdot
.976 .33527 Mdot
.976 .33528 Mdot
.976 .33528 Mdot
.976 .3353 Mdot
.976 .33532 Mdot
.976 .33532 Mdot
.976 .33534 Mdot
.976 .33539 Mdot
.976 .33541 Mdot
.976 .33544 Mdot
.976 .33546 Mdot
.976 .33548 Mdot
.976 .33562 Mdot
.976 .33572 Mdot
.976 .33579 Mdot
.976 .33593 Mdot
.976 .33601 Mdot
.976 .33601 Mdot
.976 .33604 Mdot
.976 .33605 Mdot
.976 .33616 Mdot
.976 .33618 Mdot
.976 .3363 Mdot
.976 .33663 Mdot
.976 .3371 Mdot
.976 .33716 Mdot
.976 .3372 Mdot
.976 .33733 Mdot
.976 .33778 Mdot
.976 .33835 Mdot
.976 .33865 Mdot
.976 .33876 Mdot
.976 .3393 Mdot
.976 .34006 Mdot
.976 .34033 Mdot
.976 .34087 Mdot
.976 .34096 Mdot
.976 .34111 Mdot
.976 .34114 Mdot
.976 .34115 Mdot
.976 .34161 Mdot
.976 .34185 Mdot
.976 .34211 Mdot
.976 .34225 Mdot
.976 .34229 Mdot
.976 .34249 Mdot
.976 .34262 Mdot
.976 .34324 Mdot
.976 .34326 Mdot
.976 .34334 Mdot
.976 .34337 Mdot
.976 .34364 Mdot
.976 .34366 Mdot
.976 .34387 Mdot
.976 .34405 Mdot
.976 .3441 Mdot
.976 .34441 Mdot
.976 .34445 Mdot
.976 .34478 Mdot
.976 .34577 Mdot
.976 .3465 Mdot
.976 .34654 Mdot
.976 .34679 Mdot
.976 .34743 Mdot
.976 .3476 Mdot
.976 .34782 Mdot
.976 .34808 Mdot
.976 .34896 Mdot
.976 .34915 Mdot
.976 .34934 Mdot
.976 .34962 Mdot
.976 .34966 Mdot
.976 .34985 Mdot
.976 .34988 Mdot
.976 .34995 Mdot
.976 .35041 Mdot
.976 .3506 Mdot
.976 .35064 Mdot
.976 .35086 Mdot
.976 .351 Mdot
.976 .35102 Mdot
.976 .35106 Mdot
.976 .35112 Mdot
.976 .35115 Mdot
.976 .35128 Mdot
.976 .35137 Mdot
.976 .35149 Mdot
.976 .35151 Mdot
.976 .35161 Mdot
.976 .35165 Mdot
.976 .35203 Mdot
.976 .35215 Mdot
.976 .35242 Mdot
.976 .35259 Mdot
.976 .35278 Mdot
.976 .35304 Mdot
.976 .35338 Mdot
.976 .3534 Mdot
.976 .35351 Mdot
.976 .35367 Mdot
.976 .35398 Mdot
.976 .35399 Mdot
.976 .35444 Mdot
.976 .35452 Mdot
.976 .35464 Mdot
.976 .35475 Mdot
.976 .35476 Mdot
.976 .35477 Mdot
.976 .35482 Mdot
.976 .35489 Mdot
.976 .35499 Mdot
.976 .35546 Mdot
.976 .35561 Mdot
.976 .35585 Mdot
.976 .35603 Mdot
.976 .35611 Mdot
.976 .35622 Mdot
.976 .35639 Mdot
.976 .35669 Mdot
.976 .35689 Mdot
.976 .35696 Mdot
.976 .35741 Mdot
.976 .35743 Mdot
.976 .3575 Mdot
.976 .35755 Mdot
.976 .35803 Mdot
.976 .35841 Mdot
.976 .35892 Mdot
.976 .35936 Mdot
.976 .3595 Mdot
.976 .35956 Mdot
.976 .35965 Mdot
.976 .35979 Mdot
.976 .35996 Mdot
.976 .35997 Mdot
.976 .36022 Mdot
.976 .36028 Mdot
.976 .36032 Mdot
.976 .36033 Mdot
.976 .36036 Mdot
.976 .36053 Mdot
.976 .36061 Mdot
.976 .36119 Mdot
.976 .36126 Mdot
.976 .36135 Mdot
.976 .3616 Mdot
.976 .36164 Mdot
.976 .36182 Mdot
.976 .36193 Mdot
.976 .36198 Mdot
.976 .36204 Mdot
.976 .36217 Mdot
.976 .36264 Mdot
.976 .36304 Mdot
.976 .36317 Mdot
.976 .36327 Mdot
.976 .36334 Mdot
.976 .3634 Mdot
.976 .3635 Mdot
.976 .36356 Mdot
.976 .36378 Mdot
.976 .3638 Mdot
.976 .36382 Mdot
.976 .36405 Mdot
.976 .36411 Mdot
.976 .36414 Mdot
.976 .36424 Mdot
.976 .36425 Mdot
.976 .36427 Mdot
.976 .36444 Mdot
.976 .36454 Mdot
.976 .36479 Mdot
.976 .36488 Mdot
.976 .36495 Mdot
.976 .36498 Mdot
.976 .36502 Mdot
.976 .36504 Mdot
.976 .36509 Mdot
.976 .36509 Mdot
.976 .36518 Mdot
.976 .36542 Mdot
.976 .36555 Mdot
.976 .36575 Mdot
.976 .3658 Mdot
.976 .36589 Mdot
.976 .36589 Mdot
.976 .36592 Mdot
.976 .36593 Mdot
.976 .36596 Mdot
.976 .36596 Mdot
.976 .36597 Mdot
.976 .36599 Mdot
.976 .557 Mdot
.976 .557 Mdot
.976 .557 Mdot
.976 .55701 Mdot
.976 .55701 Mdot
.976 .55701 Mdot
.976 .55702 Mdot
.976 .55706 Mdot
.976 .5571 Mdot
.976 .55714 Mdot
.976 .55715 Mdot
.976 .55718 Mdot
.976 .55719 Mdot
.976 .55724 Mdot
.976 .55727 Mdot
.976 .55728 Mdot
.976 .55731 Mdot
.976 .55741 Mdot
.976 .55747 Mdot
.976 .55748 Mdot
.976 .55751 Mdot
.976 .55752 Mdot
.976 .55763 Mdot
.976 .55764 Mdot
.976 .55765 Mdot
.976 .55773 Mdot
.976 .55782 Mdot
.976 .55784 Mdot
.976 .55787 Mdot
.976 .55794 Mdot
.976 .55797 Mdot
.976 .55799 Mdot
.976 .558 Mdot
.976 .55801 Mdot
.976 .5582 Mdot
.976 .55828 Mdot
.976 .55851 Mdot
.976 .5586 Mdot
.976 .55861 Mdot
.976 .55869 Mdot
.976 .5587 Mdot
.976 .55872 Mdot
.976 .55872 Mdot
.976 .55879 Mdot
.976 .55882 Mdot
.976 .5589 Mdot
.976 .55895 Mdot
.976 .55903 Mdot
.976 .55915 Mdot
.976 .55917 Mdot
.976 .55918 Mdot
.976 .55921 Mdot
.976 .55923 Mdot
.976 .55927 Mdot
.976 .55929 Mdot
.976 .55929 Mdot
.976 .55931 Mdot
.976 .55932 Mdot
.976 .55932 Mdot
.976 .55933 Mdot
.976 .55934 Mdot
.976 .55937 Mdot
.976 .55937 Mdot
.976 .55947 Mdot
.976 .55949 Mdot
.976 .55952 Mdot
.976 .55953 Mdot
.976 .55958 Mdot
.976 .55964 Mdot
.976 .55965 Mdot
.976 .55966 Mdot
.976 .55967 Mdot
.976 .55971 Mdot
.976 .55977 Mdot
.976 .55978 Mdot
.976 .5599 Mdot
.976 .56011 Mdot
.976 .56016 Mdot
.976 .56022 Mdot
.976 .56022 Mdot
.976 .56026 Mdot
.976 .56033 Mdot
.976 .56039 Mdot
.976 .56043 Mdot
.976 .56044 Mdot
.976 .56045 Mdot
.976 .56054 Mdot
.976 .5606 Mdot
.976 .56063 Mdot
.976 .56066 Mdot
.976 .56067 Mdot
.976 .56069 Mdot
.976 .56079 Mdot
.976 .56081 Mdot
.976 .56084 Mdot
.976 .56088 Mdot
.976 .5609 Mdot
.976 .56097 Mdot
.976 .56099 Mdot
.976 .56103 Mdot
.976 .56104 Mdot
.976 .56106 Mdot
.976 .56154 Mdot
.976 .56173 Mdot
.976 .56173 Mdot
.976 .56193 Mdot
.976 .56223 Mdot
.976 .56227 Mdot
.976 .56248 Mdot
.976 .56248 Mdot
.976 .56251 Mdot
.976 .56259 Mdot
.976 .56259 Mdot
.976 .56265 Mdot
.976 .56271 Mdot
.976 .56299 Mdot
.976 .56309 Mdot
.976 .56331 Mdot
.976 .56336 Mdot
.976 .5636 Mdot
.976 .56377 Mdot
.976 .5638 Mdot
.976 .56384 Mdot
.976 .56392 Mdot
.976 .56395 Mdot
.976 .5641 Mdot
.976 .56421 Mdot
.976 .56436 Mdot
.976 .56438 Mdot
.976 .5645 Mdot
.976 .56451 Mdot
.976 .56455 Mdot
.976 .56502 Mdot
.976 .56517 Mdot
.976 .56546 Mdot
.976 .56551 Mdot
.976 .56553 Mdot
.976 .56571 Mdot
.976 .56596 Mdot
.976 .56597 Mdot
.976 .56605 Mdot
.976 .56621 Mdot
.976 .5663 Mdot
.976 .56656 Mdot
.976 .56657 Mdot
.976 .56658 Mdot
.976 .56666 Mdot
.976 .56674 Mdot
.976 .56677 Mdot
.976 .56687 Mdot
.976 .56691 Mdot
.976 .56696 Mdot
.976 .56712 Mdot
.976 .56714 Mdot
.976 .56716 Mdot
.976 .56721 Mdot
.976 .56738 Mdot
.976 .56753 Mdot
.976 .56754 Mdot
.976 .56755 Mdot
.976 .56815 Mdot
.976 .56826 Mdot
.976 .56843 Mdot
.976 .56858 Mdot
.976 .56859 Mdot
.976 .5686 Mdot
.976 .56867 Mdot
.976 .56877 Mdot
.976 .5689 Mdot
.976 .56956 Mdot
.976 .56976 Mdot
.976 .57009 Mdot
.976 .57034 Mdot
.976 .57046 Mdot
.976 .57062 Mdot
.976 .57085 Mdot
.976 .57128 Mdot
.976 .57156 Mdot
.976 .57165 Mdot
.976 .57229 Mdot
.976 .57232 Mdot
.976 .57242 Mdot
.976 .57249 Mdot
.976 .57317 Mdot
.976 .57371 Mdot
.976 .57444 Mdot
.976 .57506 Mdot
.976 .57525 Mdot
.976 .57534 Mdot
.976 .57548 Mdot
.976 .57567 Mdot
.976 .57591 Mdot
.976 .57593 Mdot
.976 .57627 Mdot
.976 .57636 Mdot
.976 .57641 Mdot
.976 .57643 Mdot
.976 .57647 Mdot
.976 .5767 Mdot
.976 .57682 Mdot
.976 .57761 Mdot
.976 .57771 Mdot
.976 .57783 Mdot
.976 .57817 Mdot
.976 .57822 Mdot
.976 .57848 Mdot
.976 .57862 Mdot
.976 .57868 Mdot
.976 .57876 Mdot
.976 .57894 Mdot
.976 .57956 Mdot
.976 .58008 Mdot
.976 .58025 Mdot
.976 .58037 Mdot
.976 .58047 Mdot
.976 .58055 Mdot
.976 .58067 Mdot
.976 .58075 Mdot
.976 .58103 Mdot
.976 .58105 Mdot
.976 .58107 Mdot
.976 .58136 Mdot
.976 .58144 Mdot
.976 .58148 Mdot
.976 .5816 Mdot
.976 .58161 Mdot
.976 .58163 Mdot
.976 .58184 Mdot
.976 .58196 Mdot
.976 .58227 Mdot
.976 .58237 Mdot
.976 .58246 Mdot
.976 .58249 Mdot
.976 .58253 Mdot
.976 .58256 Mdot
.976 .58262 Mdot
.976 .58262 Mdot
.976 .58273 Mdot
.976 .583 Mdot
.976 .58315 Mdot
.976 .58338 Mdot
.976 .58344 Mdot
.976 .58353 Mdot
.976 .58353 Mdot
.976 .58357 Mdot
.976 .58358 Mdot
.976 .58361 Mdot
.976 .58361 Mdot
.976 .58363 Mdot
.976 .58364 Mdot
.978 .11041 Mdot
.978 .11042 Mdot
.978 .11042 Mdot
.978 .11043 Mdot
.978 .11049 Mdot
.978 .11053 Mdot
.978 .11062 Mdot
.978 .11073 Mdot
.978 .11075 Mdot
.978 .11075 Mdot
.978 .11084 Mdot
.978 .11085 Mdot
.978 .11094 Mdot
.978 .111 Mdot
.978 .11106 Mdot
.978 .11111 Mdot
.978 .11111 Mdot
.978 .11113 Mdot
.978 .1112 Mdot
.978 .11123 Mdot
.978 .11126 Mdot
.978 .11129 Mdot
.978 .11131 Mdot
.978 .11132 Mdot
.978 .11134 Mdot
.978 .1114 Mdot
.978 .1114 Mdot
.978 .11141 Mdot
.978 .11148 Mdot
.978 .11151 Mdot
.978 .11151 Mdot
.978 .11152 Mdot
.978 .1116 Mdot
.978 .11164 Mdot
.978 .11178 Mdot
.978 .11178 Mdot
.978 .11182 Mdot
.978 .11215 Mdot
.978 .11216 Mdot
.978 .11218 Mdot
.978 .11225 Mdot
.978 .11228 Mdot
.978 .1123 Mdot
.978 .11243 Mdot
.978 .11264 Mdot
.978 .11265 Mdot
.978 .11281 Mdot
.978 .11281 Mdot
.978 .11284 Mdot
.978 .11324 Mdot
.978 .11325 Mdot
.978 .11336 Mdot
.978 .11338 Mdot
.978 .11338 Mdot
.978 .11344 Mdot
.978 .11351 Mdot
.978 .11352 Mdot
.978 .11353 Mdot
.978 .11373 Mdot
.978 .1139 Mdot
.978 .11407 Mdot
.978 .11458 Mdot
.978 .11459 Mdot
.978 .11469 Mdot
.978 .1148 Mdot
.978 .11506 Mdot
.978 .11507 Mdot
.978 .11507 Mdot
.978 .11542 Mdot
.978 .11571 Mdot
.978 .11582 Mdot
.978 .11586 Mdot
.978 .11588 Mdot
.978 .11593 Mdot
.978 .11593 Mdot
.978 .11602 Mdot
.978 .11633 Mdot
.978 .11642 Mdot
.978 .11656 Mdot
.978 .11663 Mdot
.978 .11676 Mdot
.978 .11689 Mdot
.978 .11698 Mdot
.978 .11706 Mdot
.978 .11706 Mdot
.978 .11709 Mdot
.978 .11716 Mdot
.978 .11719 Mdot
.978 .11721 Mdot
.978 .11728 Mdot
.978 .11732 Mdot
.978 .11734 Mdot
.978 .11745 Mdot
.978 .11777 Mdot
.978 .11795 Mdot
.978 .11798 Mdot
.978 .11802 Mdot
.978 .11825 Mdot
.978 .11833 Mdot
.978 .11839 Mdot
.978 .1184 Mdot
.978 .11843 Mdot
.978 .11858 Mdot
.978 .1187 Mdot
.978 .11873 Mdot
.978 .11875 Mdot
.978 .11876 Mdot
.978 .11878 Mdot
.978 .11878 Mdot
.978 .11878 Mdot
.978 .1188 Mdot
.978 .11881 Mdot
.978 .11882 Mdot
.978 .11882 Mdot
.978 .11883 Mdot
.978 .11884 Mdot
.978 .11886 Mdot
.978 .11887 Mdot
.978 .11892 Mdot
.978 .11892 Mdot
.978 .11898 Mdot
.978 .11898 Mdot
.978 .11898 Mdot
.978 .119 Mdot
.978 .119 Mdot
.978 .119 Mdot
.978 .11902 Mdot
.978 .11906 Mdot
.978 .11906 Mdot
.978 .11908 Mdot
.978 .11908 Mdot
.978 .11914 Mdot
.978 .11916 Mdot
.978 .11917 Mdot
.978 .11918 Mdot
.978 .11918 Mdot
.978 .1192 Mdot
.978 .11923 Mdot
.978 .11925 Mdot
.978 .11946 Mdot
.978 .11955 Mdot
.978 .11963 Mdot
.978 .11964 Mdot
.978 .11964 Mdot
.978 .11966 Mdot
.978 .11973 Mdot
.978 .11977 Mdot
.978 .11978 Mdot
.978 .11982 Mdot
.978 .11986 Mdot
.978 .11987 Mdot
.978 .1199 Mdot
.978 .11997 Mdot
.978 .12004 Mdot
.978 .12006 Mdot
.978 .12006 Mdot
.978 .12007 Mdot
.978 .12008 Mdot
.978 .12014 Mdot
.978 .12016 Mdot
.978 .12017 Mdot
.978 .12019 Mdot
.978 .12021 Mdot
.978 .12021 Mdot
.978 .12021 Mdot
.978 .12024 Mdot
.978 .12026 Mdot
.978 .12027 Mdot
.978 .12034 Mdot
.978 .12035 Mdot
.978 .12042 Mdot
.978 .12042 Mdot
.978 .12045 Mdot
.978 .1205 Mdot
.978 .1205 Mdot
.978 .12052 Mdot
.978 .12052 Mdot
.978 .12057 Mdot
.978 .12058 Mdot
.978 .12061 Mdot
.978 .12065 Mdot
.978 .12065 Mdot
.978 .12067 Mdot
.978 .12068 Mdot
.978 .12077 Mdot
.978 .12081 Mdot
.978 .12083 Mdot
.978 .12083 Mdot
.978 .12083 Mdot
.978 .12083 Mdot
.978 .12085 Mdot
.978 .12092 Mdot
.978 .12098 Mdot
.978 .12099 Mdot
.978 .12103 Mdot
.978 .12103 Mdot
.978 .12105 Mdot
.978 .12105 Mdot
.978 .1211 Mdot
.978 .1211 Mdot
.978 .12111 Mdot
.978 .12112 Mdot
.978 .12114 Mdot
.978 .12115 Mdot
.978 .12117 Mdot
.978 .12119 Mdot
.978 .12121 Mdot
.978 .12122 Mdot
.978 .12123 Mdot
.978 .12125 Mdot
.978 .12127 Mdot
.978 .12134 Mdot
.978 .12135 Mdot
.978 .12136 Mdot
.978 .12137 Mdot
.978 .12139 Mdot
.978 .12139 Mdot
.978 .12139 Mdot
.978 .12139 Mdot
.978 .1214 Mdot
.978 .12141 Mdot
.978 .12141 Mdot
.978 .12142 Mdot
.978 .12143 Mdot
.978 .12143 Mdot
.978 .12143 Mdot
.978 .12143 Mdot
.978 .12144 Mdot
.978 .12144 Mdot
.978 .12144 Mdot
.978 .12144 Mdot
.978 .12144 Mdot
.978 .12145 Mdot
.978 .122 Mdot
.978 .12241 Mdot
.978 .12359 Mdot
.978 .12361 Mdot
.978 .12362 Mdot
.978 .12388 Mdot
.978 .12389 Mdot
.978 .12391 Mdot
.978 .12402 Mdot
.978 .12407 Mdot
.978 .12416 Mdot
.978 .1242 Mdot
.978 .12438 Mdot
.978 .12462 Mdot
.978 .12463 Mdot
.978 .12463 Mdot
.978 .12471 Mdot
.978 .14915 Mdot
.978 .14918 Mdot
.978 .14918 Mdot
.978 .14921 Mdot
.978 .14942 Mdot
.978 .14959 Mdot
.978 .14992 Mdot
.978 .15034 Mdot
.978 .15041 Mdot
.978 .15042 Mdot
.978 .15074 Mdot
.978 .15079 Mdot
.978 .15113 Mdot
.978 .15137 Mdot
.978 .15158 Mdot
.978 .15177 Mdot
.978 .15178 Mdot
.978 .15185 Mdot
.978 .15212 Mdot
.978 .15224 Mdot
.978 .15233 Mdot
.978 .15247 Mdot
.978 .15253 Mdot
.978 .15258 Mdot
.978 .15265 Mdot
.978 .15287 Mdot
.978 .15288 Mdot
.978 .15294 Mdot
.978 .1532 Mdot
.978 .1533 Mdot
.978 .1533 Mdot
.978 .15335 Mdot
.978 .15366 Mdot
.978 .15382 Mdot
.978 .15434 Mdot
.978 .15434 Mdot
.978 .1545 Mdot
.978 .15581 Mdot
.978 .15586 Mdot
.978 .15593 Mdot
.978 .15623 Mdot
.978 .15633 Mdot
.978 .15641 Mdot
.978 .15694 Mdot
.978 .15779 Mdot
.978 .15782 Mdot
.978 .15846 Mdot
.978 .15848 Mdot
.978 .15857 Mdot
.978 .16022 Mdot
.978 .16028 Mdot
.978 .16071 Mdot
.978 .16081 Mdot
.978 .16081 Mdot
.978 .16105 Mdot
.978 .16136 Mdot
.978 .16138 Mdot
.978 .16141 Mdot
.978 .16226 Mdot
.978 .16297 Mdot
.978 .16369 Mdot
.978 .16589 Mdot
.978 .16592 Mdot
.978 .16635 Mdot
.978 .16685 Mdot
.978 .16798 Mdot
.978 .168 Mdot
.978 .16802 Mdot
.978 .16954 Mdot
.978 .17083 Mdot
.978 .1713 Mdot
.978 .17149 Mdot
.978 .17158 Mdot
.978 .1718 Mdot
.978 .17181 Mdot
.978 .1722 Mdot
.978 .17362 Mdot
.978 .17401 Mdot
.978 .17454 Mdot
.978 .17469 Mdot
.978 .17499 Mdot
.978 .17558 Mdot
.978 .17616 Mdot
.978 .17657 Mdot
.978 .17696 Mdot
.978 .17698 Mdot
.978 .17709 Mdot
.978 .17744 Mdot
.978 .17758 Mdot
.978 .17764 Mdot
.978 .17798 Mdot
.978 .17817 Mdot
.978 .17827 Mdot
.978 .17875 Mdot
.978 .18025 Mdot
.978 .18109 Mdot
.978 .18126 Mdot
.978 .18146 Mdot
.978 .18255 Mdot
.978 .18291 Mdot
.978 .18319 Mdot
.978 .18325 Mdot
.978 .18338 Mdot
.978 .1841 Mdot
.978 .18469 Mdot
.978 .18484 Mdot
.978 .18492 Mdot
.978 .18499 Mdot
.978 .18505 Mdot
.978 .18506 Mdot
.978 .18508 Mdot
.978 .18516 Mdot
.978 .18522 Mdot
.978 .18525 Mdot
.978 .18527 Mdot
.978 .18529 Mdot
.978 .18536 Mdot
.978 .18547 Mdot
.978 .18548 Mdot
.978 .18572 Mdot
.978 .18575 Mdot
.978 .18602 Mdot
.978 .18603 Mdot
.978 .18605 Mdot
.978 .1861 Mdot
.978 .18612 Mdot
.978 .18614 Mdot
.978 .18624 Mdot
.978 .18639 Mdot
.978 .1864 Mdot
.978 .18651 Mdot
.978 .18653 Mdot
.978 .18681 Mdot
.978 .18689 Mdot
.978 .18693 Mdot
.978 .18698 Mdot
.978 .18698 Mdot
.978 .18711 Mdot
.978 .18722 Mdot
.978 .18732 Mdot
.978 .18835 Mdot
.978 .18879 Mdot
.978 .18916 Mdot
.978 .18924 Mdot
.978 .18925 Mdot
.978 .18931 Mdot
.978 .18967 Mdot
.978 .18987 Mdot
.978 .18991 Mdot
.978 .19012 Mdot
.978 .19032 Mdot
.978 .19037 Mdot
.978 .1905 Mdot
.978 .19083 Mdot
.978 .19121 Mdot
.978 .19127 Mdot
.978 .19128 Mdot
.978 .19133 Mdot
.978 .19139 Mdot
.978 .19171 Mdot
.978 .1918 Mdot
.978 .19184 Mdot
.978 .19195 Mdot
.978 .19201 Mdot
.978 .19203 Mdot
.978 .19204 Mdot
.978 .19217 Mdot
.978 .19225 Mdot
.978 .19233 Mdot
.978 .19268 Mdot
.978 .19271 Mdot
.978 .19306 Mdot
.978 .19307 Mdot
.978 .19323 Mdot
.978 .19345 Mdot
.978 .19345 Mdot
.978 .19355 Mdot
.978 .19356 Mdot
.978 .1938 Mdot
.978 .19388 Mdot
.978 .19399 Mdot
.978 .19418 Mdot
.978 .19419 Mdot
.978 .19431 Mdot
.978 .19437 Mdot
.978 .19478 Mdot
.978 .19502 Mdot
.978 .19508 Mdot
.978 .1951 Mdot
.978 .19512 Mdot
.978 .19513 Mdot
.978 .19522 Mdot
.978 .19558 Mdot
.978 .19586 Mdot
.978 .1959 Mdot
.978 .19608 Mdot
.978 .19611 Mdot
.978 .19622 Mdot
.978 .19622 Mdot
.978 .19644 Mdot
.978 .19646 Mdot
.978 .1965 Mdot
.978 .19654 Mdot
.978 .19668 Mdot
.978 .19669 Mdot
.978 .1968 Mdot
.978 .19691 Mdot
.978 .19703 Mdot
.978 .19703 Mdot
.978 .19708 Mdot
.978 .19719 Mdot
.978 .19729 Mdot
.978 .19764 Mdot
.978 .19772 Mdot
.978 .19774 Mdot
.978 .19783 Mdot
.978 .19789 Mdot
.978 .19792 Mdot
.978 .19792 Mdot
.978 .19793 Mdot
.978 .19794 Mdot
.978 .19801 Mdot
.978 .19802 Mdot
.978 .19807 Mdot
.978 .1981 Mdot
.978 .19812 Mdot
.978 .19812 Mdot
.978 .19813 Mdot
.978 .19815 Mdot
.978 .19817 Mdot
.978 .19817 Mdot
.978 .19817 Mdot
.978 .19819 Mdot
.978 .1982 Mdot
.978 .20099 Mdot
.978 .20307 Mdot
.978 .20913 Mdot
.978 .20924 Mdot
.978 .20932 Mdot
.978 .21067 Mdot
.978 .21069 Mdot
.978 .2108 Mdot
.978 .21136 Mdot
.978 .21163 Mdot
.978 .21213 Mdot
.978 .21233 Mdot
.978 .21325 Mdot
.978 .21453 Mdot
.978 .21455 Mdot
.978 .21458 Mdot
.978 .21499 Mdot
.978 .33247 Mdot
.978 .33256 Mdot
.978 .33258 Mdot
.978 .33267 Mdot
.978 .33342 Mdot
.978 .33398 Mdot
.978 .33429 Mdot
.978 .33481 Mdot
.978 .33511 Mdot
.978 .3364 Mdot
.978 .33641 Mdot
.978 .33642 Mdot
.978 .33642 Mdot
.978 .33642 Mdot
.978 .33644 Mdot
.978 .33646 Mdot
.978 .33646 Mdot
.978 .33646 Mdot
.978 .33647 Mdot
.978 .33649 Mdot
.978 .3365 Mdot
.978 .33654 Mdot
.978 .33654 Mdot
.978 .33659 Mdot
.978 .3366 Mdot
.978 .33661 Mdot
.978 .33661 Mdot
.978 .33661 Mdot
.978 .33663 Mdot
.978 .33668 Mdot
.978 .33668 Mdot
.978 .33673 Mdot
.978 .33675 Mdot
.978 .33676 Mdot
.978 .33677 Mdot
.978 .33677 Mdot
.978 .33683 Mdot
.978 .33711 Mdot
.978 .3372 Mdot
.978 .33729 Mdot
.978 .33733 Mdot
.978 .33734 Mdot
.978 .33744 Mdot
.978 .33754 Mdot
.978 .33764 Mdot
.978 .33765 Mdot
.978 .33777 Mdot
.978 .33781 Mdot
.978 .33781 Mdot
.978 .33784 Mdot
.978 .33786 Mdot
.978 .33797 Mdot
.978 .33807 Mdot
.978 .33807 Mdot
.978 .33817 Mdot
.978 .33817 Mdot
.978 .33819 Mdot
.978 .3382 Mdot
.978 .33832 Mdot
.978 .33837 Mdot
.978 .33841 Mdot
.978 .33869 Mdot
.978 .33902 Mdot
.978 .33906 Mdot
.978 .33906 Mdot
.978 .33915 Mdot
.978 .33916 Mdot
.978 .33918 Mdot
.978 .3392 Mdot
.978 .33926 Mdot
.978 .33937 Mdot
.978 .33952 Mdot
.978 .33981 Mdot
.978 .33997 Mdot
.978 .34003 Mdot
.978 .34006 Mdot
.978 .34016 Mdot
.978 .34017 Mdot
.978 .34034 Mdot
.978 .34039 Mdot
.978 .34046 Mdot
.978 .34051 Mdot
.978 .3406 Mdot
.978 .34088 Mdot
.978 .3409 Mdot
.978 .34101 Mdot
.978 .34101 Mdot
.978 .34105 Mdot
.978 .34109 Mdot
.978 .34127 Mdot
.978 .34129 Mdot
.978 .34146 Mdot
.978 .34148 Mdot
.978 .34178 Mdot
.978 .3419 Mdot
.978 .34193 Mdot
.978 .34211 Mdot
.978 .34237 Mdot
.978 .34245 Mdot
.978 .34246 Mdot
.978 .34257 Mdot
.978 .34273 Mdot
.978 .34273 Mdot
.978 .34275 Mdot
.978 .34277 Mdot
.978 .34285 Mdot
.978 .34298 Mdot
.978 .34304 Mdot
.978 .34313 Mdot
.978 .34315 Mdot
.978 .34332 Mdot
.978 .34346 Mdot
.978 .34356 Mdot
.978 .34364 Mdot
.978 .34366 Mdot
.978 .3437 Mdot
.978 .34372 Mdot
.978 .3438 Mdot
.978 .34401 Mdot
.978 .34406 Mdot
.978 .3441 Mdot
.978 .34429 Mdot
.978 .3443 Mdot
.978 .34432 Mdot
.978 .3445 Mdot
.978 .34473 Mdot
.978 .3449 Mdot
.978 .3449 Mdot
.978 .34498 Mdot
.978 .34521 Mdot
.978 .34524 Mdot
.978 .34549 Mdot
.978 .34552 Mdot
.978 .34553 Mdot
.978 .34558 Mdot
.978 .34565 Mdot
.978 .34585 Mdot
.978 .34635 Mdot
.978 .34643 Mdot
.978 .34645 Mdot
.978 .34649 Mdot
.978 .34656 Mdot
.978 .34692 Mdot
.978 .34708 Mdot
.978 .34769 Mdot
.978 .3483 Mdot
.978 .3483 Mdot
.978 .3487 Mdot
.978 .34914 Mdot
.978 .34929 Mdot
.978 .34944 Mdot
.978 .34962 Mdot
.978 .34963 Mdot
.978 .3497 Mdot
.978 .34975 Mdot
.978 .34987 Mdot
.978 .35027 Mdot
.978 .3503 Mdot
.978 .35046 Mdot
.978 .35046 Mdot
.978 .35068 Mdot
.978 .35082 Mdot
.978 .35085 Mdot
.978 .35087 Mdot
.978 .35096 Mdot
.978 .35098 Mdot
.978 .35099 Mdot
.978 .35138 Mdot
.978 .35143 Mdot
.978 .35175 Mdot
.978 .35177 Mdot
.978 .3519 Mdot
.978 .35193 Mdot
.978 .35201 Mdot
.978 .35204 Mdot
.978 .35206 Mdot
.978 .35208 Mdot
.978 .35213 Mdot
.978 .35217 Mdot
.978 .35222 Mdot
.978 .35233 Mdot
.978 .35236 Mdot
.978 .35237 Mdot
.978 .35245 Mdot
.978 .35255 Mdot
.978 .35267 Mdot
.978 .35285 Mdot
.978 .35287 Mdot
.978 .35307 Mdot
.978 .35371 Mdot
.978 .3544 Mdot
.978 .35471 Mdot
.978 .35488 Mdot
.978 .35497 Mdot
.978 .35536 Mdot
.978 .35585 Mdot
.978 .35614 Mdot
.978 .35619 Mdot
.978 .35729 Mdot
.978 .3574 Mdot
.978 .35743 Mdot
.978 .35755 Mdot
.978 .3576 Mdot
.978 .35776 Mdot
.978 .35882 Mdot
.978 .36032 Mdot
.978 .36041 Mdot
.978 .36059 Mdot
.978 .36103 Mdot
.978 .36113 Mdot
.978 .36118 Mdot
.978 .36118 Mdot
.978 .36124 Mdot
.978 .36145 Mdot
.978 .3615 Mdot
.978 .36181 Mdot
.978 .36187 Mdot
.978 .36192 Mdot
.978 .36194 Mdot
.978 .36199 Mdot
.978 .36201 Mdot
.978 .36236 Mdot
.978 .36248 Mdot
.978 .3625 Mdot
.978 .36287 Mdot
.978 .36301 Mdot
.978 .36325 Mdot
.978 .36376 Mdot
.978 .36377 Mdot
.978 .36424 Mdot
.978 .36444 Mdot
.978 .36447 Mdot
.978 .36458 Mdot
.978 .36495 Mdot
.978 .36521 Mdot
.978 .36595 Mdot
.978 .36596 Mdot
.978 .36597 Mdot
.978 .36614 Mdot
.978 .36615 Mdot
.978 .36616 Mdot
.978 .36623 Mdot
.978 .36626 Mdot
.978 .36633 Mdot
.978 .36635 Mdot
.978 .36647 Mdot
.978 .36663 Mdot
.978 .36664 Mdot
.978 .36664 Mdot
.978 .36669 Mdot
.978 .55811 Mdot
.978 .55811 Mdot
.978 .55811 Mdot
.978 .55811 Mdot
.978 .55811 Mdot
.978 .55811 Mdot
.978 .55811 Mdot
.978 .55811 Mdot
.978 .55811 Mdot
.978 .55812 Mdot
.978 .55812 Mdot
.978 .55812 Mdot
.978 .55812 Mdot
.978 .55813 Mdot
.978 .55813 Mdot
.978 .55813 Mdot
.978 .55814 Mdot
.978 .55814 Mdot
.978 .55815 Mdot
.978 .55815 Mdot
.978 .55816 Mdot
.978 .5582 Mdot
.978 .55821 Mdot
.978 .55822 Mdot
.978 .55822 Mdot
.978 .55823 Mdot
.978 .55826 Mdot
.978 .55826 Mdot
.978 .55827 Mdot
.978 .55828 Mdot
.978 .55828 Mdot
.978 .55828 Mdot
.978 .55831 Mdot
.978 .55831 Mdot
.978 .55832 Mdot
.978 .55832 Mdot
.978 .55834 Mdot
.978 .55834 Mdot
.978 .55837 Mdot
.978 .55841 Mdot
.978 .55842 Mdot
.978 .55842 Mdot
.978 .55842 Mdot
.978 .55843 Mdot
.978 .55845 Mdot
.978 .5585 Mdot
.978 .5585 Mdot
.978 .55851 Mdot
.978 .55852 Mdot
.978 .55854 Mdot
.978 .55855 Mdot
.978 .55856 Mdot
.978 .55858 Mdot
.978 .55858 Mdot
.978 .55859 Mdot
.978 .55859 Mdot
.978 .55862 Mdot
.978 .55863 Mdot
.978 .55863 Mdot
.978 .55867 Mdot
.978 .55867 Mdot
.978 .55871 Mdot
.978 .55872 Mdot
.978 .55873 Mdot
.978 .55874 Mdot
.978 .55875 Mdot
.978 .55875 Mdot
.978 .55875 Mdot
.978 .55877 Mdot
.978 .55877 Mdot
.978 .55878 Mdot
.978 .55881 Mdot
.978 .55882 Mdot
.978 .55883 Mdot
.978 .55888 Mdot
.978 .55891 Mdot
.978 .55893 Mdot
.978 .55893 Mdot
.978 .55895 Mdot
.978 .55898 Mdot
.978 .55898 Mdot
.978 .559 Mdot
.978 .55904 Mdot
.978 .55905 Mdot
.978 .55905 Mdot
.978 .55906 Mdot
.978 .5591 Mdot
.978 .55915 Mdot
.978 .55927 Mdot
.978 .55928 Mdot
.978 .55931 Mdot
.978 .55931 Mdot
.978 .55932 Mdot
.978 .55932 Mdot
.978 .55933 Mdot
.978 .55936 Mdot
.978 .55937 Mdot
.978 .55938 Mdot
.978 .55938 Mdot
.978 .5594 Mdot
.978 .55941 Mdot
.978 .55941 Mdot
.978 .55941 Mdot
.978 .55942 Mdot
.978 .55942 Mdot
.978 .55942 Mdot
.978 .55946 Mdot
.978 .55946 Mdot
.978 .55949 Mdot
.978 .55949 Mdot
.978 .5595 Mdot
.978 .55951 Mdot
.978 .55951 Mdot
.978 .55952 Mdot
.978 .55953 Mdot
.978 .55954 Mdot
.978 .55954 Mdot
.978 .55954 Mdot
.978 .55955 Mdot
.978 .55956 Mdot
.978 .55957 Mdot
.978 .55958 Mdot
.978 .55975 Mdot
.978 .55976 Mdot
.978 .55977 Mdot
.978 .5598 Mdot
.978 .55985 Mdot
.978 .55999 Mdot
.978 .56035 Mdot
.978 .56041 Mdot
.978 .56042 Mdot
.978 .56045 Mdot
.978 .56051 Mdot
.978 .56059 Mdot
.978 .56079 Mdot
.978 .56088 Mdot
.978 .56092 Mdot
.978 .5614 Mdot
.978 .56145 Mdot
.978 .56174 Mdot
.978 .56201 Mdot
.978 .56202 Mdot
.978 .5624 Mdot
.978 .5624 Mdot
.978 .56285 Mdot
.978 .563 Mdot
.978 .56316 Mdot
.978 .56335 Mdot
.978 .56336 Mdot
.978 .56336 Mdot
.978 .56344 Mdot
.978 .56349 Mdot
.978 .56349 Mdot
.978 .56352 Mdot
.978 .56362 Mdot
.978 .56364 Mdot
.978 .56406 Mdot
.978 .56409 Mdot
.978 .56427 Mdot
.978 .56428 Mdot
.978 .56453 Mdot
.978 .56469 Mdot
.978 .56472 Mdot
.978 .56475 Mdot
.978 .56485 Mdot
.978 .56487 Mdot
.978 .56489 Mdot
.978 .56535 Mdot
.978 .56541 Mdot
.978 .5658 Mdot
.978 .56583 Mdot
.978 .56599 Mdot
.978 .56602 Mdot
.978 .56612 Mdot
.978 .56615 Mdot
.978 .56618 Mdot
.978 .56621 Mdot
.978 .56627 Mdot
.978 .56632 Mdot
.978 .56638 Mdot
.978 .56652 Mdot
.978 .56656 Mdot
.978 .56657 Mdot
.978 .56668 Mdot
.978 .5668 Mdot
.978 .56695 Mdot
.978 .56718 Mdot
.978 .56721 Mdot
.978 .56747 Mdot
.978 .56831 Mdot
.978 .56924 Mdot
.978 .56966 Mdot
.978 .5699 Mdot
.978 .57002 Mdot
.978 .57055 Mdot
.978 .57123 Mdot
.978 .57163 Mdot
.978 .57171 Mdot
.978 .57326 Mdot
.978 .57342 Mdot
.978 .57347 Mdot
.978 .57363 Mdot
.978 .57371 Mdot
.978 .57394 Mdot
.978 .57544 Mdot
.978 .57756 Mdot
.978 .57768 Mdot
.978 .57794 Mdot
.978 .57855 Mdot
.978 .57869 Mdot
.978 .57875 Mdot
.978 .57875 Mdot
.978 .57884 Mdot
.978 .57912 Mdot
.978 .5792 Mdot
.978 .57961 Mdot
.978 .57969 Mdot
.978 .57976 Mdot
.978 .57978 Mdot
.978 .57985 Mdot
.978 .57988 Mdot
.978 .58035 Mdot
.978 .5805 Mdot
.978 .58053 Mdot
.978 .58102 Mdot
.978 .5812 Mdot
.978 .58151 Mdot
.978 .58216 Mdot
.978 .58217 Mdot
.978 .58275 Mdot
.978 .58301 Mdot
.978 .58304 Mdot
.978 .58317 Mdot
.978 .58362 Mdot
.978 .58392 Mdot
.978 .58477 Mdot
.978 .58478 Mdot
.978 .58479 Mdot
.978 .58498 Mdot
.978 .58498 Mdot
.978 .58499 Mdot
.978 .58507 Mdot
.978 .58511 Mdot
.978 .58518 Mdot
.978 .5852 Mdot
.978 .58533 Mdot
.978 .5855 Mdot
.978 .5855 Mdot
.978 .58551 Mdot
.978 .58556 Mdot
.98 .11061 Mdot
.98 .11061 Mdot
.98 .11061 Mdot
.98 .11062 Mdot
.98 .11062 Mdot
.98 .11063 Mdot
.98 .11064 Mdot
.98 .11066 Mdot
.98 .11069 Mdot
.98 .1107 Mdot
.98 .11071 Mdot
.98 .11073 Mdot
.98 .11076 Mdot
.98 .11076 Mdot
.98 .11076 Mdot
.98 .11078 Mdot
.98 .11083 Mdot
.98 .11093 Mdot
.98 .11101 Mdot
.98 .11103 Mdot
.98 .11104 Mdot
.98 .11104 Mdot
.98 .11106 Mdot
.98 .11107 Mdot
.98 .11116 Mdot
.98 .11118 Mdot
.98 .1112 Mdot
.98 .11129 Mdot
.98 .1113 Mdot
.98 .11131 Mdot
.98 .11142 Mdot
.98 .11143 Mdot
.98 .11148 Mdot
.98 .11154 Mdot
.98 .11155 Mdot
.98 .1116 Mdot
.98 .11167 Mdot
.98 .11172 Mdot
.98 .11178 Mdot
.98 .11181 Mdot
.98 .11182 Mdot
.98 .11195 Mdot
.98 .11201 Mdot
.98 .1122 Mdot
.98 .11221 Mdot
.98 .11224 Mdot
.98 .11228 Mdot
.98 .11254 Mdot
.98 .11258 Mdot
.98 .11285 Mdot
.98 .11292 Mdot
.98 .11296 Mdot
.98 .11306 Mdot
.98 .11308 Mdot
.98 .11312 Mdot
.98 .11317 Mdot
.98 .11321 Mdot
.98 .11358 Mdot
.98 .11365 Mdot
.98 .11373 Mdot
.98 .1138 Mdot
.98 .11393 Mdot
.98 .11408 Mdot
.98 .11413 Mdot
.98 .11414 Mdot
.98 .1143 Mdot
.98 .11437 Mdot
.98 .11438 Mdot
.98 .11443 Mdot
.98 .11452 Mdot
.98 .11462 Mdot
.98 .11474 Mdot
.98 .1148 Mdot
.98 .11486 Mdot
.98 .11497 Mdot
.98 .11498 Mdot
.98 .11503 Mdot
.98 .11505 Mdot
.98 .11508 Mdot
.98 .11511 Mdot
.98 .11518 Mdot
.98 .11536 Mdot
.98 .11542 Mdot
.98 .11545 Mdot
.98 .11546 Mdot
.98 .11563 Mdot
.98 .11567 Mdot
.98 .11569 Mdot
.98 .1157 Mdot
.98 .11579 Mdot
.98 .1158 Mdot
.98 .11592 Mdot
.98 .11601 Mdot
.98 .11609 Mdot
.98 .11609 Mdot
.98 .11613 Mdot
.98 .11619 Mdot
.98 .1162 Mdot
.98 .11624 Mdot
.98 .1163 Mdot
.98 .1163 Mdot
.98 .11635 Mdot
.98 .11637 Mdot
.98 .1164 Mdot
.98 .11668 Mdot
.98 .11668 Mdot
.98 .1167 Mdot
.98 .11676 Mdot
.98 .11677 Mdot
.98 .11685 Mdot
.98 .11712 Mdot
.98 .11729 Mdot
.98 .11731 Mdot
.98 .11731 Mdot
.98 .11732 Mdot
.98 .11743 Mdot
.98 .11752 Mdot
.98 .11755 Mdot
.98 .11756 Mdot
.98 .11757 Mdot
.98 .1176 Mdot
.98 .11768 Mdot
.98 .11769 Mdot
.98 .11771 Mdot
.98 .11776 Mdot
.98 .11792 Mdot
.98 .11815 Mdot
.98 .11816 Mdot
.98 .1182 Mdot
.98 .11823 Mdot
.98 .11826 Mdot
.98 .11832 Mdot
.98 .11837 Mdot
.98 .11841 Mdot
.98 .11843 Mdot
.98 .11847 Mdot
.98 .11848 Mdot
.98 .11859 Mdot
.98 .11864 Mdot
.98 .11867 Mdot
.98 .11876 Mdot
.98 .11885 Mdot
.98 .11886 Mdot
.98 .11886 Mdot
.98 .11891 Mdot
.98 .11905 Mdot
.98 .11909 Mdot
.98 .11927 Mdot
.98 .11929 Mdot
.98 .11934 Mdot
.98 .11939 Mdot
.98 .11941 Mdot
.98 .11942 Mdot
.98 .11946 Mdot
.98 .11946 Mdot
.98 .11949 Mdot
.98 .11955 Mdot
.98 .11955 Mdot
.98 .11956 Mdot
.98 .11979 Mdot
.98 .12114 Mdot
.98 .12122 Mdot
.98 .12166 Mdot
.98 .12191 Mdot
.98 .12235 Mdot
.98 .12246 Mdot
.98 .12256 Mdot
.98 .12285 Mdot
.98 .12298 Mdot
.98 .12305 Mdot
.98 .12308 Mdot
.98 .12362 Mdot
.98 .12373 Mdot
.98 .12419 Mdot
.98 .12455 Mdot
.98 .12464 Mdot
.98 .12464 Mdot
.98 .12473 Mdot
.98 .1249 Mdot
.98 .12496 Mdot
.98 .12497 Mdot
.98 .12497 Mdot
.98 .125 Mdot
.98 .12524 Mdot
.98 .12524 Mdot
.98 .12549 Mdot
.98 .12568 Mdot
.98 .12573 Mdot
.98 .12578 Mdot
.98 .12581 Mdot
.98 .12581 Mdot
.98 .12594 Mdot
.98 .12606 Mdot
.98 .1261 Mdot
.98 .1261 Mdot
.98 .12612 Mdot
.98 .12629 Mdot
.98 .12641 Mdot
.98 .12647 Mdot
.98 .12649 Mdot
.98 .1266 Mdot
.98 .12667 Mdot
.98 .12689 Mdot
.98 .127 Mdot
.98 .12702 Mdot
.98 .12717 Mdot
.98 .12721 Mdot
.98 .12723 Mdot
.98 .12726 Mdot
.98 .12728 Mdot
.98 .12735 Mdot
.98 .12739 Mdot
.98 .12739 Mdot
.98 .12754 Mdot
.98 .12754 Mdot
.98 .12755 Mdot
.98 .12757 Mdot
.98 .12758 Mdot
.98 .12759 Mdot
.98 .12759 Mdot
.98 .12761 Mdot
.98 .12763 Mdot
.98 .12764 Mdot
.98 .12764 Mdot
.98 .12765 Mdot
.98 .12767 Mdot
.98 .12903 Mdot
.98 .12943 Mdot
.98 .13046 Mdot
.98 .13061 Mdot
.98 .13236 Mdot
.98 .13239 Mdot
.98 .13308 Mdot
.98 .13322 Mdot
.98 .13325 Mdot
.98 .13354 Mdot
.98 .13376 Mdot
.98 .13455 Mdot
.98 .13516 Mdot
.98 .13663 Mdot
.98 .14175 Mdot
.98 .14478 Mdot
.98 .15015 Mdot
.98 .15015 Mdot
.98 .15016 Mdot
.98 .15019 Mdot
.98 .15023 Mdot
.98 .15029 Mdot
.98 .15034 Mdot
.98 .15046 Mdot
.98 .1505 Mdot
.98 .15055 Mdot
.98 .15063 Mdot
.98 .15072 Mdot
.98 .15072 Mdot
.98 .15074 Mdot
.98 .15082 Mdot
.98 .15098 Mdot
.98 .15115 Mdot
.98 .15133 Mdot
.98 .15136 Mdot
.98 .15167 Mdot
.98 .15176 Mdot
.98 .15177 Mdot
.98 .1518 Mdot
.98 .15185 Mdot
.98 .15191 Mdot
.98 .15226 Mdot
.98 .15232 Mdot
.98 .1524 Mdot
.98 .15274 Mdot
.98 .15279 Mdot
.98 .15281 Mdot
.98 .15324 Mdot
.98 .15329 Mdot
.98 .15347 Mdot
.98 .15372 Mdot
.98 .15376 Mdot
.98 .15396 Mdot
.98 .1542 Mdot
.98 .15443 Mdot
.98 .15465 Mdot
.98 .15477 Mdot
.98 .15481 Mdot
.98 .15525 Mdot
.98 .15533 Mdot
.98 .15554 Mdot
.98 .15632 Mdot
.98 .15635 Mdot
.98 .15646 Mdot
.98 .15662 Mdot
.98 .15759 Mdot
.98 .15762 Mdot
.98 .15766 Mdot
.98 .15785 Mdot
.98 .15893 Mdot
.98 .1592 Mdot
.98 .15938 Mdot
.98 .1598 Mdot
.98 .15985 Mdot
.98 .16004 Mdot
.98 .16026 Mdot
.98 .16042 Mdot
.98 .16196 Mdot
.98 .16222 Mdot
.98 .16258 Mdot
.98 .16286 Mdot
.98 .1634 Mdot
.98 .16396 Mdot
.98 .16403 Mdot
.98 .16427 Mdot
.98 .16431 Mdot
.98 .165 Mdot
.98 .16529 Mdot
.98 .16533 Mdot
.98 .16555 Mdot
.98 .16594 Mdot
.98 .16637 Mdot
.98 .16688 Mdot
.98 .16712 Mdot
.98 .1674 Mdot
.98 .1674 Mdot
.98 .16788 Mdot
.98 .16793 Mdot
.98 .16814 Mdot
.98 .16824 Mdot
.98 .16834 Mdot
.98 .1684 Mdot
.98 .1685 Mdot
.98 .1688 Mdot
.98 .1696 Mdot
.98 .16988 Mdot
.98 .16998 Mdot
.98 .17002 Mdot
.98 .17013 Mdot
.98 .17078 Mdot
.98 .171 Mdot
.98 .17106 Mdot
.98 .17111 Mdot
.98 .17149 Mdot
.98 .17155 Mdot
.98 .1721 Mdot
.98 .17238 Mdot
.98 .17248 Mdot
.98 .17284 Mdot
.98 .17287 Mdot
.98 .17306 Mdot
.98 .17329 Mdot
.98 .17334 Mdot
.98 .17354 Mdot
.98 .17379 Mdot
.98 .17379 Mdot
.98 .17404 Mdot
.98 .17411 Mdot
.98 .17426 Mdot
.98 .17554 Mdot
.98 .17556 Mdot
.98 .17561 Mdot
.98 .1759 Mdot
.98 .17596 Mdot
.98 .17632 Mdot
.98 .17758 Mdot
.98 .17834 Mdot
.98 .17844 Mdot
.98 .17845 Mdot
.98 .17848 Mdot
.98 .17903 Mdot
.98 .17942 Mdot
.98 .17959 Mdot
.98 .17964 Mdot
.98 .17969 Mdot
.98 .17981 Mdot
.98 .18017 Mdot
.98 .18022 Mdot
.98 .18032 Mdot
.98 .18054 Mdot
.98 .18133 Mdot
.98 .18238 Mdot
.98 .18246 Mdot
.98 .18265 Mdot
.98 .18276 Mdot
.98 .18293 Mdot
.98 .18321 Mdot
.98 .18323 Mdot
.98 .18344 Mdot
.98 .18362 Mdot
.98 .18372 Mdot
.98 .18394 Mdot
.98 .18398 Mdot
.98 .18448 Mdot
.98 .18474 Mdot
.98 .1849 Mdot
.98 .1853 Mdot
.98 .18577 Mdot
.98 .18581 Mdot
.98 .18581 Mdot
.98 .18604 Mdot
.98 .18669 Mdot
.98 .1869 Mdot
.98 .1878 Mdot
.98 .18787 Mdot
.98 .18814 Mdot
.98 .18838 Mdot
.98 .18848 Mdot
.98 .18853 Mdot
.98 .18868 Mdot
.98 .18869 Mdot
.98 .18886 Mdot
.98 .18913 Mdot
.98 .18916 Mdot
.98 .18919 Mdot
.98 .19031 Mdot
.98 .19703 Mdot
.98 .19745 Mdot
.98 .19964 Mdot
.98 .20091 Mdot
.98 .20315 Mdot
.98 .20374 Mdot
.98 .20423 Mdot
.98 .20573 Mdot
.98 .20638 Mdot
.98 .20678 Mdot
.98 .2069 Mdot
.98 .2097 Mdot
.98 .2103 Mdot
.98 .21269 Mdot
.98 .21454 Mdot
.98 .21505 Mdot
.98 .21505 Mdot
.98 .21548 Mdot
.98 .2164 Mdot
.98 .2167 Mdot
.98 .21675 Mdot
.98 .21677 Mdot
.98 .21693 Mdot
.98 .21817 Mdot
.98 .2182 Mdot
.98 .21951 Mdot
.98 .22052 Mdot
.98 .22078 Mdot
.98 .22102 Mdot
.98 .22119 Mdot
.98 .22122 Mdot
.98 .22187 Mdot
.98 .22249 Mdot
.98 .22271 Mdot
.98 .22271 Mdot
.98 .22285 Mdot
.98 .22373 Mdot
.98 .22435 Mdot
.98 .22471 Mdot
.98 .22481 Mdot
.98 .22536 Mdot
.98 .22575 Mdot
.98 .22617 Mdot
.98 .22693 Mdot
.98 .22749 Mdot
.98 .22764 Mdot
.98 .22843 Mdot
.98 .22863 Mdot
.98 .22874 Mdot
.98 .22889 Mdot
.98 .22901 Mdot
.98 .22935 Mdot
.98 .22959 Mdot
.98 .22959 Mdot
.98 .23037 Mdot
.98 .2304 Mdot
.98 .23043 Mdot
.98 .23052 Mdot
.98 .23057 Mdot
.98 .23067 Mdot
.98 .23068 Mdot
.98 .23077 Mdot
.98 .23085 Mdot
.98 .23089 Mdot
.98 .23091 Mdot
.98 .23096 Mdot
.98 .23108 Mdot
.98 .23833 Mdot
.98 .24047 Mdot
.98 .24596 Mdot
.98 .2468 Mdot
.98 .25037 Mdot
.98 .25396 Mdot
.98 .25609 Mdot
.98 .25624 Mdot
.98 .25989 Mdot
.98 .26063 Mdot
.98 .26078 Mdot
.98 .26234 Mdot
.98 .26345 Mdot
.98 .26759 Mdot
.98 .27075 Mdot
.98 .27825 Mdot
.98 .30305 Mdot
.98 .30419 Mdot
.98 .31628 Mdot
.98 .33491 Mdot
.98 .33493 Mdot
.98 .33494 Mdot
.98 .33522 Mdot
.98 .33546 Mdot
.98 .3355 Mdot
.98 .33563 Mdot
.98 .33569 Mdot
.98 .33612 Mdot
.98 .33655 Mdot
.98 .33655 Mdot
.98 .33655 Mdot
.98 .33667 Mdot
.98 .33679 Mdot
.98 .337 Mdot
.98 .33718 Mdot
.98 .33757 Mdot
.98 .33764 Mdot
.98 .3377 Mdot
.98 .33778 Mdot
.98 .33784 Mdot
.98 .33799 Mdot
.98 .33812 Mdot
.98 .3384 Mdot
.98 .33841 Mdot
.98 .33841 Mdot
.98 .33849 Mdot
.98 .33873 Mdot
.98 .33926 Mdot
.98 .33979 Mdot
.98 .34035 Mdot
.98 .34044 Mdot
.98 .34081 Mdot
.98 .34139 Mdot
.98 .34155 Mdot
.98 .34169 Mdot
.98 .34172 Mdot
.98 .34179 Mdot
.98 .34195 Mdot
.98 .34214 Mdot
.98 .34317 Mdot
.98 .34336 Mdot
.98 .3436 Mdot
.98 .3446 Mdot
.98 .3447 Mdot
.98 .34474 Mdot
.98 .3448 Mdot
.98 .34567 Mdot
.98 .34568 Mdot
.98 .34568 Mdot
.98 .34601 Mdot
.98 .34616 Mdot
.98 .34656 Mdot
.98 .34665 Mdot
.98 .3472 Mdot
.98 .34723 Mdot
.98 .34728 Mdot
.98 .34732 Mdot
.98 .34744 Mdot
.98 .34766 Mdot
.98 .34789 Mdot
.98 .3479 Mdot
.98 .34797 Mdot
.98 .34812 Mdot
.98 .34818 Mdot
.98 .34833 Mdot
.98 .34852 Mdot
.98 .34861 Mdot
.98 .34867 Mdot
.98 .34905 Mdot
.98 .34914 Mdot
.98 .34919 Mdot
.98 .3492 Mdot
.98 .34931 Mdot
.98 .34936 Mdot
.98 .34973 Mdot
.98 .34978 Mdot
.98 .35008 Mdot
.98 .35018 Mdot
.98 .35042 Mdot
.98 .35072 Mdot
.98 .35127 Mdot
.98 .35145 Mdot
.98 .35165 Mdot
.98 .35196 Mdot
.98 .35198 Mdot
.98 .35198 Mdot
.98 .35204 Mdot
.98 .3527 Mdot
.98 .35273 Mdot
.98 .35281 Mdot
.98 .35327 Mdot
.98 .3535 Mdot
.98 .35375 Mdot
.98 .35382 Mdot
.98 .35387 Mdot
.98 .35407 Mdot
.98 .35441 Mdot
.98 .35457 Mdot
.98 .35462 Mdot
.98 .35493 Mdot
.98 .35507 Mdot
.98 .35532 Mdot
.98 .3556 Mdot
.98 .35564 Mdot
.98 .35603 Mdot
.98 .35605 Mdot
.98 .35625 Mdot
.98 .35632 Mdot
.98 .35641 Mdot
.98 .35642 Mdot
.98 .35649 Mdot
.98 .35658 Mdot
.98 .35665 Mdot
.98 .35676 Mdot
.98 .35693 Mdot
.98 .35816 Mdot
.98 .35894 Mdot
.98 .35917 Mdot
.98 .35924 Mdot
.98 .3594 Mdot
.98 .35943 Mdot
.98 .35956 Mdot
.98 .35962 Mdot
.98 .35971 Mdot
.98 .36001 Mdot
.98 .36006 Mdot
.98 .36021 Mdot
.98 .36027 Mdot
.98 .36032 Mdot
.98 .36038 Mdot
.98 .36042 Mdot
.98 .36046 Mdot
.98 .36052 Mdot
.98 .36075 Mdot
.98 .36076 Mdot
.98 .36098 Mdot
.98 .36108 Mdot
.98 .36126 Mdot
.98 .36132 Mdot
.98 .36134 Mdot
.98 .36161 Mdot
.98 .36162 Mdot
.98 .36164 Mdot
.98 .36166 Mdot
.98 .36177 Mdot
.98 .36258 Mdot
.98 .36337 Mdot
.98 .36342 Mdot
.98 .36367 Mdot
.98 .36382 Mdot
.98 .36407 Mdot
.98 .36414 Mdot
.98 .3642 Mdot
.98 .36437 Mdot
.98 .36444 Mdot
.98 .36449 Mdot
.98 .3645 Mdot
.98 .36489 Mdot
.98 .36539 Mdot
.98 .36544 Mdot
.98 .36545 Mdot
.98 .3655 Mdot
.98 .3656 Mdot
.98 .36564 Mdot
.98 .36565 Mdot
.98 .36567 Mdot
.98 .36581 Mdot
.98 .36582 Mdot
.98 .36597 Mdot
.98 .3661 Mdot
.98 .36613 Mdot
.98 .36616 Mdot
.98 .36618 Mdot
.98 .36618 Mdot
.98 .36626 Mdot
.98 .36634 Mdot
.98 .36636 Mdot
.98 .36636 Mdot
.98 .36638 Mdot
.98 .36649 Mdot
.98 .36656 Mdot
.98 .36661 Mdot
.98 .36662 Mdot
.98 .36669 Mdot
.98 .36674 Mdot
.98 .36689 Mdot
.98 .36696 Mdot
.98 .36698 Mdot
.98 .36708 Mdot
.98 .36711 Mdot
.98 .36712 Mdot
.98 .36714 Mdot
.98 .36716 Mdot
.98 .3672 Mdot
.98 .36723 Mdot
.98 .36723 Mdot
.98 .36734 Mdot
.98 .36734 Mdot
.98 .36734 Mdot
.98 .36736 Mdot
.98 .36736 Mdot
.98 .36738 Mdot
.98 .36738 Mdot
.98 .36739 Mdot
.98 .3674 Mdot
.98 .3674 Mdot
.98 .36741 Mdot
.98 .36741 Mdot
.98 .36743 Mdot
.98 .36877 Mdot
.98 .36968 Mdot
.98 .37189 Mdot
.98 .37321 Mdot
.98 .37356 Mdot
.98 .37563 Mdot
.98 .37713 Mdot
.98 .37874 Mdot
.98 .38178 Mdot
.98 .38403 Mdot
.98 .38465 Mdot
.98 .38797 Mdot
.98 .38882 Mdot
.98 .3893 Mdot
.98 .38992 Mdot
.98 .39043 Mdot
.98 .39193 Mdot
.98 .39295 Mdot
.98 .39297 Mdot
.98 .39644 Mdot
.98 .39657 Mdot
.98 .3967 Mdot
.98 .39713 Mdot
.98 .39736 Mdot
.98 .39781 Mdot
.98 .39782 Mdot
.98 .39823 Mdot
.98 .39861 Mdot
.98 .39881 Mdot
.98 .39887 Mdot
.98 .39909 Mdot
.98 .39965 Mdot
.98 .43538 Mdot
.98 .44667 Mdot
.98 .47595 Mdot
.98 .48039 Mdot
.98 .49903 Mdot
.98 .51685 Mdot
.98 .5269 Mdot
.98 .52757 Mdot
.98 .54053 Mdot
.98 .54287 Mdot
.98 .54338 Mdot
.98 .54377 Mdot
.98 .544 Mdot
.98 .5448 Mdot
.98 .54633 Mdot
.98 .54634 Mdot
.98 .54692 Mdot
.98 .54794 Mdot
.98 .54798 Mdot
.98 .54974 Mdot
.98 .55062 Mdot
.98 .55222 Mdot
.98 .5527 Mdot
.98 .55291 Mdot
.98 .55318 Mdot
.98 .55691 Mdot
.98 .55922 Mdot
.98 .55922 Mdot
.98 .55922 Mdot
.98 .55926 Mdot
.98 .55927 Mdot
.98 .55928 Mdot
.98 .55929 Mdot
.98 .5593 Mdot
.98 .55931 Mdot
.98 .55934 Mdot
.98 .55937 Mdot
.98 .55938 Mdot
.98 .55948 Mdot
.98 .55951 Mdot
.98 .55959 Mdot
.98 .55961 Mdot
.98 .55961 Mdot
.98 .55962 Mdot
.98 .55968 Mdot
.98 .55973 Mdot
.98 .55974 Mdot
.98 .55978 Mdot
.98 .55984 Mdot
.98 .55984 Mdot
.98 .55987 Mdot
.98 .55991 Mdot
.98 .55994 Mdot
.98 .55997 Mdot
.98 .56018 Mdot
.98 .56028 Mdot
.98 .56033 Mdot
.98 .56038 Mdot
.98 .5604 Mdot
.98 .56041 Mdot
.98 .56043 Mdot
.98 .56049 Mdot
.98 .56056 Mdot
.98 .56057 Mdot
.98 .56057 Mdot
.98 .56087 Mdot
.98 .56098 Mdot
.98 .56098 Mdot
.98 .56099 Mdot
.98 .5612 Mdot
.98 .56121 Mdot
.98 .56125 Mdot
.98 .56132 Mdot
.98 .56137 Mdot
.98 .5614 Mdot
.98 .56161 Mdot
.98 .56162 Mdot
.98 .56169 Mdot
.98 .56187 Mdot
.98 .56188 Mdot
.98 .5619 Mdot
.98 .56214 Mdot
.98 .56217 Mdot
.98 .56221 Mdot
.98 .56225 Mdot
.98 .56235 Mdot
.98 .56254 Mdot
.98 .56275 Mdot
.98 .56276 Mdot
.98 .56282 Mdot
.98 .56296 Mdot
.98 .56302 Mdot
.98 .56316 Mdot
.98 .56335 Mdot
.98 .56343 Mdot
.98 .56349 Mdot
.98 .56387 Mdot
.98 .56397 Mdot
.98 .56402 Mdot
.98 .56403 Mdot
.98 .56414 Mdot
.98 .5642 Mdot
.98 .56459 Mdot
.98 .56464 Mdot
.98 .56498 Mdot
.98 .56503 Mdot
.98 .56507 Mdot
.98 .56508 Mdot
.98 .56536 Mdot
.98 .5657 Mdot
.98 .56634 Mdot
.98 .56657 Mdot
.98 .5668 Mdot
.98 .56719 Mdot
.98 .56721 Mdot
.98 .56721 Mdot
.98 .56728 Mdot
.98 .56812 Mdot
.98 .56815 Mdot
.98 .56816 Mdot
.98 .56827 Mdot
.98 .56886 Mdot
.98 .56916 Mdot
.98 .56949 Mdot
.98 .56958 Mdot
.98 .56965 Mdot
.98 .56992 Mdot
.98 .57006 Mdot
.98 .57038 Mdot
.98 .5706 Mdot
.98 .57067 Mdot
.98 .57074 Mdot
.98 .5711 Mdot
.98 .57128 Mdot
.98 .57164 Mdot
.98 .57203 Mdot
.98 .57208 Mdot
.98 .57231 Mdot
.98 .57235 Mdot
.98 .57262 Mdot
.98 .57265 Mdot
.98 .57293 Mdot
.98 .57303 Mdot
.98 .57316 Mdot
.98 .57318 Mdot
.98 .57328 Mdot
.98 .57339 Mdot
.98 .5735 Mdot
.98 .57366 Mdot
.98 .57368 Mdot
.98 .5739 Mdot
.98 .57523 Mdot
.98 .57565 Mdot
.98 .57639 Mdot
.98 .57677 Mdot
.98 .57709 Mdot
.98 .57718 Mdot
.98 .57741 Mdot
.98 .57746 Mdot
.98 .57764 Mdot
.98 .57772 Mdot
.98 .57785 Mdot
.98 .57803 Mdot
.98 .57828 Mdot
.98 .57833 Mdot
.98 .57835 Mdot
.98 .57856 Mdot
.98 .57864 Mdot
.98 .57872 Mdot
.98 .5788 Mdot
.98 .57885 Mdot
.98 .5789 Mdot
.98 .579 Mdot
.98 .57931 Mdot
.98 .57933 Mdot
.98 .57963 Mdot
.98 .57977 Mdot
.98 .58002 Mdot
.98 .58011 Mdot
.98 .58013 Mdot
.98 .58049 Mdot
.98 .58051 Mdot
.98 .58054 Mdot
.98 .58056 Mdot
.98 .58071 Mdot
.98 .5818 Mdot
.98 .58283 Mdot
.98 .58289 Mdot
.98 .58321 Mdot
.98 .58339 Mdot
.98 .58371 Mdot
.98 .5838 Mdot
.98 .58387 Mdot
.98 .58408 Mdot
.98 .58417 Mdot
.98 .58422 Mdot
.98 .58424 Mdot
.98 .58463 Mdot
.98 .58471 Mdot
.98 .58529 Mdot
.98 .58536 Mdot
.98 .58536 Mdot
.98 .58542 Mdot
.98 .58554 Mdot
.98 .58558 Mdot
.98 .58559 Mdot
.98 .58559 Mdot
.98 .58561 Mdot
.98 .58578 Mdot
.98 .58578 Mdot
.98 .58596 Mdot
.98 .58609 Mdot
.98 .58612 Mdot
.98 .58616 Mdot
.98 .58618 Mdot
.98 .58618 Mdot
.98 .58627 Mdot
.98 .58635 Mdot
.98 .58638 Mdot
.98 .58638 Mdot
.98 .5864 Mdot
.98 .58652 Mdot
.98 .5866 Mdot
.98 .58665 Mdot
.98 .58666 Mdot
.98 .58673 Mdot
.98 .58678 Mdot
.98 .58694 Mdot
.98 .58701 Mdot
.98 .58703 Mdot
.98 .58714 Mdot
.98 .58716 Mdot
.98 .58718 Mdot
.98 .5872 Mdot
.98 .58721 Mdot
.98 .58726 Mdot
.98 .58729 Mdot
.98 .58729 Mdot
.98 .58739 Mdot
.98 .58739 Mdot
.98 .5874 Mdot
.98 .58741 Mdot
.98 .58742 Mdot
.98 .58743 Mdot
.98 .58743 Mdot
.98 .58744 Mdot
.98 .58745 Mdot
.98 .58746 Mdot
.98 .58746 Mdot
.98 .58747 Mdot
.98 .58748 Mdot
.98 .58844 Mdot
.98 .58872 Mdot
.98 .58946 Mdot
.98 .58957 Mdot
.98 .59084 Mdot
.98 .59086 Mdot
.98 .59138 Mdot
.98 .59149 Mdot
.98 .59151 Mdot
.98 .59173 Mdot
.982 .1108 Mdot
.982 .11081 Mdot
.982 .11081 Mdot
.982 .11085 Mdot
.982 .11085 Mdot
.982 .111 Mdot
.982 .11108 Mdot
.982 .1111 Mdot
.982 .11111 Mdot
.982 .11117 Mdot
.982 .11127 Mdot
.982 .11145 Mdot
.982 .11155 Mdot
.982 .11156 Mdot
.982 .11161 Mdot
.982 .11176 Mdot
.982 .11178 Mdot
.982 .11183 Mdot
.982 .1119 Mdot
.982 .11197 Mdot
.982 .11213 Mdot
.982 .11241 Mdot
.982 .11255 Mdot
.982 .11257 Mdot
.982 .11262 Mdot
.982 .11266 Mdot
.982 .11271 Mdot
.982 .1128 Mdot
.982 .11292 Mdot
.982 .11293 Mdot
.982 .11309 Mdot
.982 .11322 Mdot
.982 .11334 Mdot
.982 .1135 Mdot
.982 .11392 Mdot
.982 .11397 Mdot
.982 .11407 Mdot
.982 .11424 Mdot
.982 .11469 Mdot
.982 .11472 Mdot
.982 .11495 Mdot
.982 .11495 Mdot
.982 .11496 Mdot
.982 .11497 Mdot
.982 .11497 Mdot
.982 .11498 Mdot
.982 .115 Mdot
.982 .11502 Mdot
.982 .11502 Mdot
.982 .11503 Mdot
.982 .11506 Mdot
.982 .11507 Mdot
.982 .11508 Mdot
.982 .11511 Mdot
.982 .11515 Mdot
.982 .11517 Mdot
.982 .11522 Mdot
.982 .11522 Mdot
.982 .11525 Mdot
.982 .11532 Mdot
.982 .11532 Mdot
.982 .11538 Mdot
.982 .11538 Mdot
.982 .11542 Mdot
.982 .11543 Mdot
.982 .11551 Mdot
.982 .11561 Mdot
.982 .11569 Mdot
.982 .11578 Mdot
.982 .11578 Mdot
.982 .1158 Mdot
.982 .11585 Mdot
.982 .11593 Mdot
.982 .11594 Mdot
.982 .11595 Mdot
.982 .11609 Mdot
.982 .11626 Mdot
.982 .11635 Mdot
.982 .11639 Mdot
.982 .11643 Mdot
.982 .1165 Mdot
.982 .11652 Mdot
.982 .11663 Mdot
.982 .11665 Mdot
.982 .11667 Mdot
.982 .11669 Mdot
.982 .11672 Mdot
.982 .11673 Mdot
.982 .11676 Mdot
.982 .11679 Mdot
.982 .11686 Mdot
.982 .11691 Mdot
.982 .11698 Mdot
.982 .11702 Mdot
.982 .11704 Mdot
.982 .11705 Mdot
.982 .11708 Mdot
.982 .11713 Mdot
.982 .11715 Mdot
.982 .11717 Mdot
.982 .11721 Mdot
.982 .11732 Mdot
.982 .11734 Mdot
.982 .11737 Mdot
.982 .11742 Mdot
.982 .11743 Mdot
.982 .11758 Mdot
.982 .11758 Mdot
.982 .11762 Mdot
.982 .11767 Mdot
.982 .1177 Mdot
.982 .11784 Mdot
.982 .11785 Mdot
.982 .11786 Mdot
.982 .11787 Mdot
.982 .11788 Mdot
.982 .11788 Mdot
.982 .11789 Mdot
.982 .11789 Mdot
.982 .11789 Mdot
.982 .11789 Mdot
.982 .11789 Mdot
.982 .11801 Mdot
.982 .11811 Mdot
.982 .11815 Mdot
.982 .11819 Mdot
.982 .11884 Mdot
.982 .11897 Mdot
.982 .11918 Mdot
.982 .1193 Mdot
.982 .11943 Mdot
.982 .11957 Mdot
.982 .1197 Mdot
.982 .11975 Mdot
.982 .11986 Mdot
.982 .11998 Mdot
.982 .12001 Mdot
.982 .1201 Mdot
.982 .12016 Mdot
.982 .12035 Mdot
.982 .12076 Mdot
.982 .12078 Mdot
.982 .12106 Mdot
.982 .12115 Mdot
.982 .12117 Mdot
.982 .12133 Mdot
.982 .12137 Mdot
.982 .12149 Mdot
.982 .12165 Mdot
.982 .12171 Mdot
.982 .12193 Mdot
.982 .12196 Mdot
.982 .12212 Mdot
.982 .12252 Mdot
.982 .12255 Mdot
.982 .1226 Mdot
.982 .12262 Mdot
.982 .1227 Mdot
.982 .12284 Mdot
.982 .12285 Mdot
.982 .12286 Mdot
.982 .12298 Mdot
.982 .12305 Mdot
.982 .12308 Mdot
.982 .12326 Mdot
.982 .12341 Mdot
.982 .12343 Mdot
.982 .12346 Mdot
.982 .12398 Mdot
.982 .1241 Mdot
.982 .1242 Mdot
.982 .12435 Mdot
.982 .12488 Mdot
.982 .12511 Mdot
.982 .1253 Mdot
.982 .12541 Mdot
.982 .12563 Mdot
.982 .12572 Mdot
.982 .12575 Mdot
.982 .12591 Mdot
.982 .12598 Mdot
.982 .12671 Mdot
.982 .12681 Mdot
.982 .12718 Mdot
.982 .1272 Mdot
.982 .12743 Mdot
.982 .12751 Mdot
.982 .12763 Mdot
.982 .12773 Mdot
.982 .12804 Mdot
.982 .1281 Mdot
.982 .12872 Mdot
.982 .12881 Mdot
.982 .12881 Mdot
.982 .1293 Mdot
.982 .12933 Mdot
.982 .12937 Mdot
.982 .12961 Mdot
.982 .12974 Mdot
.982 .12978 Mdot
.982 .12979 Mdot
.982 .12982 Mdot
.982 .12999 Mdot
.982 .13012 Mdot
.982 .13014 Mdot
.982 .13017 Mdot
.982 .13029 Mdot
.982 .13039 Mdot
.982 .1304 Mdot
.982 .13044 Mdot
.982 .13044 Mdot
.982 .13045 Mdot
.982 .13046 Mdot
.982 .13046 Mdot
.982 .13047 Mdot
.982 .13047 Mdot
.982 .13047 Mdot
.982 .13048 Mdot
.982 .13048 Mdot
.982 .13049 Mdot
.982 .1305 Mdot
.982 .1305 Mdot
.982 .13051 Mdot
.982 .13052 Mdot
.982 .13052 Mdot
.982 .13052 Mdot
.982 .13052 Mdot
.982 .13053 Mdot
.982 .13053 Mdot
.982 .13053 Mdot
.982 .13053 Mdot
.982 .13053 Mdot
.982 .13276 Mdot
.982 .13277 Mdot
.982 .13368 Mdot
.982 .13381 Mdot
.982 .15117 Mdot
.982 .15118 Mdot
.982 .15118 Mdot
.982 .15133 Mdot
.982 .15136 Mdot
.982 .15191 Mdot
.982 .15221 Mdot
.982 .15229 Mdot
.982 .15233 Mdot
.982 .15258 Mdot
.982 .15293 Mdot
.982 .15364 Mdot
.982 .15404 Mdot
.982 .15407 Mdot
.982 .15428 Mdot
.982 .15486 Mdot
.982 .15494 Mdot
.982 .15514 Mdot
.982 .15542 Mdot
.982 .15569 Mdot
.982 .15632 Mdot
.982 .15744 Mdot
.982 .158 Mdot
.982 .15807 Mdot
.982 .15826 Mdot
.982 .15846 Mdot
.982 .15866 Mdot
.982 .15902 Mdot
.982 .15924 Mdot
.982 .15951 Mdot
.982 .15953 Mdot
.982 .1602 Mdot
.982 .16073 Mdot
.982 .16125 Mdot
.982 .16191 Mdot
.982 .16366 Mdot
.982 .1639 Mdot
.982 .16433 Mdot
.982 .16505 Mdot
.982 .16699 Mdot
.982 .16711 Mdot
.982 .16809 Mdot
.982 .16813 Mdot
.982 .16817 Mdot
.982 .16818 Mdot
.982 .16818 Mdot
.982 .16822 Mdot
.982 .16834 Mdot
.982 .1684 Mdot
.982 .16842 Mdot
.982 .16847 Mdot
.982 .16859 Mdot
.982 .16862 Mdot
.982 .16867 Mdot
.982 .16881 Mdot
.982 .16901 Mdot
.982 .16908 Mdot
.982 .16928 Mdot
.982 .16932 Mdot
.982 .16942 Mdot
.982 .16972 Mdot
.982 .16972 Mdot
.982 .16999 Mdot
.982 .17001 Mdot
.982 .17019 Mdot
.982 .17022 Mdot
.982 .17058 Mdot
.982 .17102 Mdot
.982 .17137 Mdot
.982 .17178 Mdot
.982 .1718 Mdot
.982 .17187 Mdot
.982 .17209 Mdot
.982 .17245 Mdot
.982 .17251 Mdot
.982 .17256 Mdot
.982 .17319 Mdot
.982 .17394 Mdot
.982 .17438 Mdot
.982 .17455 Mdot
.982 .17475 Mdot
.982 .17506 Mdot
.982 .17513 Mdot
.982 .17566 Mdot
.982 .17571 Mdot
.982 .17581 Mdot
.982 .1759 Mdot
.982 .17604 Mdot
.982 .17612 Mdot
.982 .17624 Mdot
.982 .17638 Mdot
.982 .1767 Mdot
.982 .17692 Mdot
.982 .17724 Mdot
.982 .17744 Mdot
.982 .17755 Mdot
.982 .17756 Mdot
.982 .17773 Mdot
.982 .17794 Mdot
.982 .17804 Mdot
.982 .17815 Mdot
.982 .17834 Mdot
.982 .17883 Mdot
.982 .17893 Mdot
.982 .17908 Mdot
.982 .17929 Mdot
.982 .17935 Mdot
.982 .17951 Mdot
.982 .18003 Mdot
.982 .18004 Mdot
.982 .18026 Mdot
.982 .18045 Mdot
.982 .18063 Mdot
.982 .18128 Mdot
.982 .18133 Mdot
.982 .18139 Mdot
.982 .18142 Mdot
.982 .18147 Mdot
.982 .18149 Mdot
.982 .18152 Mdot
.982 .18152 Mdot
.982 .18152 Mdot
.982 .18153 Mdot
.982 .18153 Mdot
.982 .18209 Mdot
.982 .18256 Mdot
.982 .18276 Mdot
.982 .18295 Mdot
.982 .18607 Mdot
.982 .18667 Mdot
.982 .18764 Mdot
.982 .18772 Mdot
.982 .1883 Mdot
.982 .18858 Mdot
.982 .1889 Mdot
.982 .18959 Mdot
.982 .19023 Mdot
.982 .1905 Mdot
.982 .19102 Mdot
.982 .19164 Mdot
.982 .19178 Mdot
.982 .19223 Mdot
.982 .19253 Mdot
.982 .19347 Mdot
.982 .19552 Mdot
.982 .19559 Mdot
.982 .19699 Mdot
.982 .19745 Mdot
.982 .19754 Mdot
.982 .19837 Mdot
.982 .19855 Mdot
.982 .19915 Mdot
.982 .19997 Mdot
.982 .2003 Mdot
.982 .20138 Mdot
.982 .20156 Mdot
.982 .20237 Mdot
.982 .20442 Mdot
.982 .20458 Mdot
.982 .20484 Mdot
.982 .20494 Mdot
.982 .20536 Mdot
.982 .20605 Mdot
.982 .20609 Mdot
.982 .20618 Mdot
.982 .2068 Mdot
.982 .20714 Mdot
.982 .20733 Mdot
.982 .20821 Mdot
.982 .20902 Mdot
.982 .20914 Mdot
.982 .20925 Mdot
.982 .21198 Mdot
.982 .21259 Mdot
.982 .21313 Mdot
.982 .21392 Mdot
.982 .21668 Mdot
.982 .21693 Mdot
.982 .21791 Mdot
.982 .21889 Mdot
.982 .21948 Mdot
.982 .22064 Mdot
.982 .22111 Mdot
.982 .22132 Mdot
.982 .22213 Mdot
.982 .2225 Mdot
.982 .22638 Mdot
.982 .22692 Mdot
.982 .22888 Mdot
.982 .22899 Mdot
.982 .23026 Mdot
.982 .23067 Mdot
.982 .2313 Mdot
.982 .23182 Mdot
.982 .23351 Mdot
.982 .23385 Mdot
.982 .23713 Mdot
.982 .2376 Mdot
.982 .23765 Mdot
.982 .24025 Mdot
.982 .24042 Mdot
.982 .24064 Mdot
.982 .2419 Mdot
.982 .24259 Mdot
.982 .24281 Mdot
.982 .24286 Mdot
.982 .24304 Mdot
.982 .24396 Mdot
.982 .24462 Mdot
.982 .24475 Mdot
.982 .2449 Mdot
.982 .24557 Mdot
.982 .2461 Mdot
.982 .24613 Mdot
.982 .24634 Mdot
.982 .24635 Mdot
.982 .24641 Mdot
.982 .24644 Mdot
.982 .24648 Mdot
.982 .24649 Mdot
.982 .2465 Mdot
.982 .24653 Mdot
.982 .24659 Mdot
.982 .24659 Mdot
.982 .24662 Mdot
.982 .24666 Mdot
.982 .24667 Mdot
.982 .2467 Mdot
.982 .24676 Mdot
.982 .24677 Mdot
.982 .24678 Mdot
.982 .24679 Mdot
.982 .24681 Mdot
.982 .24682 Mdot
.982 .24684 Mdot
.982 .24685 Mdot
.982 .24686 Mdot
.982 .2587 Mdot
.982 .25875 Mdot
.982 .26358 Mdot
.982 .26426 Mdot
.982 .27577 Mdot
.982 .33557 Mdot
.982 .3356 Mdot
.982 .33562 Mdot
.982 .33566 Mdot
.982 .33567 Mdot
.982 .33571 Mdot
.982 .33577 Mdot
.982 .33592 Mdot
.982 .33598 Mdot
.982 .33598 Mdot
.982 .336 Mdot
.982 .33603 Mdot
.982 .3363 Mdot
.982 .33642 Mdot
.982 .33648 Mdot
.982 .33657 Mdot
.982 .33658 Mdot
.982 .33659 Mdot
.982 .33706 Mdot
.982 .33716 Mdot
.982 .33727 Mdot
.982 .33744 Mdot
.982 .33747 Mdot
.982 .33759 Mdot
.982 .33781 Mdot
.982 .33791 Mdot
.982 .33802 Mdot
.982 .33819 Mdot
.982 .33823 Mdot
.982 .3383 Mdot
.982 .33869 Mdot
.982 .33918 Mdot
.982 .34 Mdot
.982 .34008 Mdot
.982 .3405 Mdot
.982 .34053 Mdot
.982 .34055 Mdot
.982 .34066 Mdot
.982 .34101 Mdot
.982 .34112 Mdot
.982 .34118 Mdot
.982 .34195 Mdot
.982 .34207 Mdot
.982 .34232 Mdot
.982 .3428 Mdot
.982 .34291 Mdot
.982 .34327 Mdot
.982 .34346 Mdot
.982 .34372 Mdot
.982 .34383 Mdot
.982 .34394 Mdot
.982 .34406 Mdot
.982 .34425 Mdot
.982 .34441 Mdot
.982 .34459 Mdot
.982 .3448 Mdot
.982 .3454 Mdot
.982 .34582 Mdot
.982 .34609 Mdot
.982 .34645 Mdot
.982 .34732 Mdot
.982 .34779 Mdot
.982 .34798 Mdot
.982 .34827 Mdot
.982 .34873 Mdot
.982 .34886 Mdot
.982 .34892 Mdot
.982 .34894 Mdot
.982 .34912 Mdot
.982 .3495 Mdot
.982 .34984 Mdot
.982 .34995 Mdot
.982 .35002 Mdot
.982 .35006 Mdot
.982 .35041 Mdot
.982 .35097 Mdot
.982 .35119 Mdot
.982 .35143 Mdot
.982 .35168 Mdot
.982 .35229 Mdot
.982 .35235 Mdot
.982 .35278 Mdot
.982 .353 Mdot
.982 .35312 Mdot
.982 .35444 Mdot
.982 .35515 Mdot
.982 .35533 Mdot
.982 .35669 Mdot
.982 .35682 Mdot
.982 .35694 Mdot
.982 .35695 Mdot
.982 .35722 Mdot
.982 .35786 Mdot
.982 .35794 Mdot
.982 .35807 Mdot
.982 .35843 Mdot
.982 .35859 Mdot
.982 .3586 Mdot
.982 .3586 Mdot
.982 .3586 Mdot
.982 .35861 Mdot
.982 .35865 Mdot
.982 .35868 Mdot
.982 .35874 Mdot
.982 .35878 Mdot
.982 .35879 Mdot
.982 .35885 Mdot
.982 .35892 Mdot
.982 .35898 Mdot
.982 .35917 Mdot
.982 .35917 Mdot
.982 .35976 Mdot
.982 .35979 Mdot
.982 .35998 Mdot
.982 .36016 Mdot
.982 .36022 Mdot
.982 .36031 Mdot
.982 .36049 Mdot
.982 .3605 Mdot
.982 .36057 Mdot
.982 .36063 Mdot
.982 .36065 Mdot
.982 .36067 Mdot
.982 .36106 Mdot
.982 .36113 Mdot
.982 .36125 Mdot
.982 .36132 Mdot
.982 .36139 Mdot
.982 .36147 Mdot
.982 .36155 Mdot
.982 .36158 Mdot
.982 .36164 Mdot
.982 .36171 Mdot
.982 .36173 Mdot
.982 .36178 Mdot
.982 .36181 Mdot
.982 .36192 Mdot
.982 .36215 Mdot
.982 .36216 Mdot
.982 .36232 Mdot
.982 .36238 Mdot
.982 .36247 Mdot
.982 .36249 Mdot
.982 .36256 Mdot
.982 .36265 Mdot
.982 .36268 Mdot
.982 .3628 Mdot
.982 .36282 Mdot
.982 .36291 Mdot
.982 .36313 Mdot
.982 .36315 Mdot
.982 .36318 Mdot
.982 .36319 Mdot
.982 .36324 Mdot
.982 .36331 Mdot
.982 .36332 Mdot
.982 .36333 Mdot
.982 .36339 Mdot
.982 .36343 Mdot
.982 .36345 Mdot
.982 .36355 Mdot
.982 .36363 Mdot
.982 .36365 Mdot
.982 .36366 Mdot
.982 .36396 Mdot
.982 .36402 Mdot
.982 .36408 Mdot
.982 .36417 Mdot
.982 .36447 Mdot
.982 .3646 Mdot
.982 .36471 Mdot
.982 .36478 Mdot
.982 .36491 Mdot
.982 .36496 Mdot
.982 .36498 Mdot
.982 .36507 Mdot
.982 .36512 Mdot
.982 .36556 Mdot
.982 .36562 Mdot
.982 .36584 Mdot
.982 .36586 Mdot
.982 .36601 Mdot
.982 .36606 Mdot
.982 .36613 Mdot
.982 .36619 Mdot
.982 .3664 Mdot
.982 .36644 Mdot
.982 .3669 Mdot
.982 .36691 Mdot
.982 .36724 Mdot
.982 .36727 Mdot
.982 .3673 Mdot
.982 .36746 Mdot
.982 .36755 Mdot
.982 .36758 Mdot
.982 .36759 Mdot
.982 .36774 Mdot
.982 .36783 Mdot
.982 .36785 Mdot
.982 .36787 Mdot
.982 .36797 Mdot
.982 .36804 Mdot
.982 .36805 Mdot
.982 .36808 Mdot
.982 .36808 Mdot
.982 .36809 Mdot
.982 .36809 Mdot
.982 .3681 Mdot
.982 .3681 Mdot
.982 .3681 Mdot
.982 .36811 Mdot
.982 .36811 Mdot
.982 .36811 Mdot
.982 .36812 Mdot
.982 .36812 Mdot
.982 .36813 Mdot
.982 .36813 Mdot
.982 .36814 Mdot
.982 .36814 Mdot
.982 .36814 Mdot
.982 .36814 Mdot
.982 .36815 Mdot
.982 .36815 Mdot
.982 .36815 Mdot
.982 .36815 Mdot
.982 .36815 Mdot
.982 .37939 Mdot
.982 .38033 Mdot
.982 .38034 Mdot
.982 .38246 Mdot
.982 .39039 Mdot
.982 .39065 Mdot
.982 .39113 Mdot
.982 .39672 Mdot
.982 .39858 Mdot
.982 .40143 Mdot
.982 .40386 Mdot
.982 .41192 Mdot
.982 .41356 Mdot
.982 .43004 Mdot
.982 .43247 Mdot
.982 .43271 Mdot
.982 .44635 Mdot
.982 .44725 Mdot
.982 .44846 Mdot
.982 .45518 Mdot
.982 .45884 Mdot
.982 .46002 Mdot
.982 .46027 Mdot
.982 .46127 Mdot
.982 .46618 Mdot
.982 .46974 Mdot
.982 .47041 Mdot
.982 .47119 Mdot
.982 .47336 Mdot
.982 .4748 Mdot
.982 .47763 Mdot
.982 .47777 Mdot
.982 .47888 Mdot
.982 .47897 Mdot
.982 .47929 Mdot
.982 .47945 Mdot
.982 .47964 Mdot
.982 .4797 Mdot
.982 .47973 Mdot
.982 .4799 Mdot
.982 .48023 Mdot
.982 .48024 Mdot
.982 .48038 Mdot
.982 .48059 Mdot
.982 .48067 Mdot
.982 .48084 Mdot
.982 .48115 Mdot
.982 .48117 Mdot
.982 .48123 Mdot
.982 .48131 Mdot
.982 .48138 Mdot
.982 .48143 Mdot
.982 .48153 Mdot
.982 .48163 Mdot
.982 .48164 Mdot
.982 .48207 Mdot
.982 .52282 Mdot
.982 .53393 Mdot
.982 .5395 Mdot
.982 .53969 Mdot
.982 .546 Mdot
.982 .55324 Mdot
.982 .55848 Mdot
.982 .56033 Mdot
.982 .56033 Mdot
.982 .56033 Mdot
.982 .56033 Mdot
.982 .56034 Mdot
.982 .56034 Mdot
.982 .56035 Mdot
.982 .56035 Mdot
.982 .56036 Mdot
.982 .56045 Mdot
.982 .56047 Mdot
.982 .5605 Mdot
.982 .56053 Mdot
.982 .56063 Mdot
.982 .56066 Mdot
.982 .5607 Mdot
.982 .56077 Mdot
.982 .56079 Mdot
.982 .56081 Mdot
.982 .56082 Mdot
.982 .56085 Mdot
.982 .56088 Mdot
.982 .5609 Mdot
.982 .56093 Mdot
.982 .56097 Mdot
.982 .561 Mdot
.982 .56105 Mdot
.982 .56107 Mdot
.982 .5611 Mdot
.982 .56114 Mdot
.982 .56115 Mdot
.982 .56116 Mdot
.982 .56124 Mdot
.982 .56125 Mdot
.982 .5613 Mdot
.982 .56133 Mdot
.982 .56136 Mdot
.982 .56143 Mdot
.982 .56155 Mdot
.982 .56165 Mdot
.982 .56166 Mdot
.982 .56167 Mdot
.982 .56173 Mdot
.982 .56177 Mdot
.982 .56185 Mdot
.982 .56191 Mdot
.982 .56205 Mdot
.982 .56209 Mdot
.982 .56209 Mdot
.982 .56214 Mdot
.982 .5622 Mdot
.982 .56226 Mdot
.982 .56231 Mdot
.982 .56233 Mdot
.982 .56235 Mdot
.982 .56238 Mdot
.982 .56238 Mdot
.982 .5624 Mdot
.982 .56242 Mdot
.982 .56266 Mdot
.982 .56336 Mdot
.982 .56378 Mdot
.982 .56395 Mdot
.982 .56423 Mdot
.982 .56467 Mdot
.982 .5648 Mdot
.982 .56486 Mdot
.982 .56488 Mdot
.982 .56507 Mdot
.982 .56547 Mdot
.982 .56583 Mdot
.982 .56595 Mdot
.982 .56603 Mdot
.982 .56607 Mdot
.982 .56647 Mdot
.982 .56712 Mdot
.982 .56737 Mdot
.982 .56767 Mdot
.982 .56796 Mdot
.982 .56873 Mdot
.982 .5688 Mdot
.982 .56935 Mdot
.982 .56964 Mdot
.982 .56979 Mdot
.982 .57155 Mdot
.982 .57159 Mdot
.982 .57253 Mdot
.982 .57278 Mdot
.982 .5729 Mdot
.982 .57359 Mdot
.982 .57469 Mdot
.982 .57489 Mdot
.982 .57506 Mdot
.982 .57506 Mdot
.982 .57545 Mdot
.982 .57636 Mdot
.982 .57647 Mdot
.982 .57666 Mdot
.982 .57718 Mdot
.982 .57741 Mdot
.982 .57742 Mdot
.982 .57743 Mdot
.982 .57743 Mdot
.982 .57744 Mdot
.982 .5775 Mdot
.982 .57753 Mdot
.982 .57762 Mdot
.982 .57768 Mdot
.982 .57769 Mdot
.982 .57778 Mdot
.982 .57789 Mdot
.982 .57797 Mdot
.982 .57823 Mdot
.982 .57823 Mdot
.982 .57907 Mdot
.982 .57911 Mdot
.982 .57938 Mdot
.982 .57964 Mdot
.982 .57972 Mdot
.982 .57984 Mdot
.982 .5801 Mdot
.982 .58011 Mdot
.982 .58021 Mdot
.982 .58029 Mdot
.982 .58033 Mdot
.982 .58036 Mdot
.982 .58089 Mdot
.982 .58099 Mdot
.982 .58116 Mdot
.982 .58125 Mdot
.982 .58135 Mdot
.982 .58146 Mdot
.982 .58156 Mdot
.982 .58161 Mdot
.982 .58169 Mdot
.982 .58179 Mdot
.982 .58181 Mdot
.982 .58188 Mdot
.982 .58192 Mdot
.982 .58207 Mdot
.982 .58238 Mdot
.982 .58239 Mdot
.982 .5826 Mdot
.982 .58268 Mdot
.982 .58281 Mdot
.982 .58283 Mdot
.982 .58292 Mdot
.982 .58304 Mdot
.982 .58309 Mdot
.982 .58324 Mdot
.982 .58327 Mdot
.982 .58339 Mdot
.982 .58368 Mdot
.982 .5837 Mdot
.982 .58374 Mdot
.982 .58375 Mdot
.982 .58381 Mdot
.982 .58391 Mdot
.982 .58392 Mdot
.982 .58393 Mdot
.982 .58401 Mdot
.982 .58406 Mdot
.982 .58409 Mdot
.982 .58421 Mdot
.982 .58432 Mdot
.982 .58434 Mdot
.982 .58435 Mdot
.982 .58473 Mdot
.982 .58481 Mdot
.982 .58488 Mdot
.982 .58499 Mdot
.982 .58536 Mdot
.982 .58553 Mdot
.982 .58566 Mdot
.982 .58574 Mdot
.982 .58589 Mdot
.982 .58595 Mdot
.982 .58598 Mdot
.982 .58609 Mdot
.982 .58614 Mdot
.982 .58665 Mdot
.982 .58672 Mdot
.982 .58698 Mdot
.982 .58699 Mdot
.982 .58716 Mdot
.982 .58721 Mdot
.982 .58729 Mdot
.982 .58736 Mdot
.982 .58758 Mdot
.982 .58763 Mdot
.982 .58806 Mdot
.982 .58812 Mdot
.982 .58812 Mdot
.982 .58847 Mdot
.982 .58849 Mdot
.982 .58852 Mdot
.982 .58869 Mdot
.982 .58878 Mdot
.982 .58881 Mdot
.982 .58881 Mdot
.982 .58884 Mdot
.982 .58896 Mdot
.982 .58905 Mdot
.982 .58906 Mdot
.982 .58908 Mdot
.982 .58917 Mdot
.982 .58924 Mdot
.982 .58925 Mdot
.982 .58927 Mdot
.982 .58928 Mdot
.982 .58928 Mdot
.982 .58929 Mdot
.982 .58929 Mdot
.982 .58929 Mdot
.982 .58929 Mdot
.982 .5893 Mdot
.982 .58931 Mdot
.982 .58931 Mdot
.982 .58931 Mdot
.982 .58932 Mdot
.982 .58932 Mdot
.982 .58932 Mdot
.982 .58933 Mdot
.982 .58933 Mdot
.982 .58933 Mdot
.982 .58933 Mdot
.982 .58934 Mdot
.982 .58934 Mdot
.982 .58934 Mdot
.982 .58934 Mdot
.982 .58934 Mdot
.982 .59096 Mdot
.982 .59097 Mdot
.982 .59166 Mdot
.984 .111 Mdot
.984 .111 Mdot
.984 .111 Mdot
.984 .11101 Mdot
.984 .11102 Mdot
.984 .11102 Mdot
.984 .11103 Mdot
.984 .11104 Mdot
.984 .11108 Mdot
.984 .11109 Mdot
.984 .11115 Mdot
.984 .11121 Mdot
.984 .11128 Mdot
.984 .11129 Mdot
.984 .11131 Mdot
.984 .11132 Mdot
.984 .11138 Mdot
.984 .11139 Mdot
.984 .11149 Mdot
.984 .11164 Mdot
.984 .11172 Mdot
.984 .11172 Mdot
.984 .11179 Mdot
.984 .11189 Mdot
.984 .11191 Mdot
.984 .11198 Mdot
.984 .11222 Mdot
.984 .11223 Mdot
.984 .11224 Mdot
.984 .11234 Mdot
.984 .11267 Mdot
.984 .11279 Mdot
.984 .1128 Mdot
.984 .11287 Mdot
.984 .11289 Mdot
.984 .11298 Mdot
.984 .113 Mdot
.984 .11301 Mdot
.984 .11313 Mdot
.984 .11326 Mdot
.984 .11338 Mdot
.984 .11353 Mdot
.984 .11356 Mdot
.984 .11364 Mdot
.984 .11368 Mdot
.984 .11379 Mdot
.984 .11383 Mdot
.984 .11385 Mdot
.984 .114 Mdot
.984 .11417 Mdot
.984 .11448 Mdot
.984 .1145 Mdot
.984 .11453 Mdot
.984 .11454 Mdot
.984 .11457 Mdot
.984 .11458 Mdot
.984 .11459 Mdot
.984 .1146 Mdot
.984 .11461 Mdot
.984 .11462 Mdot
.984 .11465 Mdot
.984 .11467 Mdot
.984 .11475 Mdot
.984 .11476 Mdot
.984 .11484 Mdot
.984 .11492 Mdot
.984 .11494 Mdot
.984 .11495 Mdot
.984 .11499 Mdot
.984 .11503 Mdot
.984 .11504 Mdot
.984 .11506 Mdot
.984 .1151 Mdot
.984 .11518 Mdot
.984 .11518 Mdot
.984 .1152 Mdot
.984 .1152 Mdot
.984 .11521 Mdot
.984 .11529 Mdot
.984 .11533 Mdot
.984 .11539 Mdot
.984 .11546 Mdot
.984 .11552 Mdot
.984 .11552 Mdot
.984 .11564 Mdot
.984 .1157 Mdot
.984 .11576 Mdot
.984 .11582 Mdot
.984 .11582 Mdot
.984 .11596 Mdot
.984 .11601 Mdot
.984 .11607 Mdot
.984 .11624 Mdot
.984 .11631 Mdot
.984 .11634 Mdot
.984 .11639 Mdot
.984 .11644 Mdot
.984 .11646 Mdot
.984 .11728 Mdot
.984 .11733 Mdot
.984 .11827 Mdot
.984 .11833 Mdot
.984 .11845 Mdot
.984 .11879 Mdot
.984 .11976 Mdot
.984 .11982 Mdot
.984 .11992 Mdot
.984 .1203 Mdot
.984 .12044 Mdot
.984 .12127 Mdot
.984 .1213 Mdot
.984 .12136 Mdot
.984 .1215 Mdot
.984 .12153 Mdot
.984 .12203 Mdot
.984 .12243 Mdot
.984 .12251 Mdot
.984 .12256 Mdot
.984 .12258 Mdot
.984 .12285 Mdot
.984 .123 Mdot
.984 .12311 Mdot
.984 .12388 Mdot
.984 .12391 Mdot
.984 .12424 Mdot
.984 .12553 Mdot
.984 .12561 Mdot
.984 .12611 Mdot
.984 .12657 Mdot
.984 .12659 Mdot
.984 .1268 Mdot
.984 .12718 Mdot
.984 .12803 Mdot
.984 .12831 Mdot
.984 .12833 Mdot
.984 .1289 Mdot
.984 .12903 Mdot
.984 .12905 Mdot
.984 .12913 Mdot
.984 .12965 Mdot
.984 .1298 Mdot
.984 .12984 Mdot
.984 .13005 Mdot
.984 .13007 Mdot
.984 .13018 Mdot
.984 .13021 Mdot
.984 .13025 Mdot
.984 .13033 Mdot
.984 .1305 Mdot
.984 .13051 Mdot
.984 .13053 Mdot
.984 .13054 Mdot
.984 .13082 Mdot
.984 .13086 Mdot
.984 .13092 Mdot
.984 .13097 Mdot
.984 .13101 Mdot
.984 .13118 Mdot
.984 .13143 Mdot
.984 .13151 Mdot
.984 .1317 Mdot
.984 .13172 Mdot
.984 .13191 Mdot
.984 .13209 Mdot
.984 .13224 Mdot
.984 .1323 Mdot
.984 .13232 Mdot
.984 .13246 Mdot
.984 .13251 Mdot
.984 .13256 Mdot
.984 .13259 Mdot
.984 .13261 Mdot
.984 .13264 Mdot
.984 .13266 Mdot
.984 .13271 Mdot
.984 .13272 Mdot
.984 .13274 Mdot
.984 .1328 Mdot
.984 .13282 Mdot
.984 .13284 Mdot
.984 .13285 Mdot
.984 .13286 Mdot
.984 .13289 Mdot
.984 .13293 Mdot
.984 .13293 Mdot
.984 .13294 Mdot
.984 .13297 Mdot
.984 .13302 Mdot
.984 .13306 Mdot
.984 .13308 Mdot
.984 .1331 Mdot
.984 .13315 Mdot
.984 .13315 Mdot
.984 .13318 Mdot
.984 .13318 Mdot
.984 .13321 Mdot
.984 .13321 Mdot
.984 .13322 Mdot
.984 .13323 Mdot
.984 .13323 Mdot
.984 .13323 Mdot
.984 .13323 Mdot
.984 .13324 Mdot
.984 .13324 Mdot
.984 .13324 Mdot
.984 .13325 Mdot
.984 .13325 Mdot
.984 .13325 Mdot
.984 .13325 Mdot
.984 .13371 Mdot
.984 .13404 Mdot
.984 .13432 Mdot
.984 .13438 Mdot
.984 .13441 Mdot
.984 .13451 Mdot
.984 .13454 Mdot
.984 .13467 Mdot
.984 .13495 Mdot
.984 .13506 Mdot
.984 .13516 Mdot
.984 .13522 Mdot
.984 .13525 Mdot
.984 .13556 Mdot
.984 .13577 Mdot
.984 .13589 Mdot
.984 .13592 Mdot
.984 .13599 Mdot
.984 .13616 Mdot
.984 .13632 Mdot
.984 .13638 Mdot
.984 .13677 Mdot
.984 .13686 Mdot
.984 .13694 Mdot
.984 .13722 Mdot
.984 .13888 Mdot
.984 .13914 Mdot
.984 .14062 Mdot
.984 .14077 Mdot
.984 .14428 Mdot
.984 .14586 Mdot
.984 .1473 Mdot
.984 .15043 Mdot
.984 .15219 Mdot
.984 .15219 Mdot
.984 .1522 Mdot
.984 .15224 Mdot
.984 .15227 Mdot
.984 .15228 Mdot
.984 .15232 Mdot
.984 .15234 Mdot
.984 .15249 Mdot
.984 .15253 Mdot
.984 .15278 Mdot
.984 .15299 Mdot
.984 .15326 Mdot
.984 .15332 Mdot
.984 .15337 Mdot
.984 .15343 Mdot
.984 .15367 Mdot
.984 .15368 Mdot
.984 .15406 Mdot
.984 .15466 Mdot
.984 .15494 Mdot
.984 .15497 Mdot
.984 .155 Mdot
.984 .15525 Mdot
.984 .15563 Mdot
.984 .15574 Mdot
.984 .15602 Mdot
.984 .15695 Mdot
.984 .157 Mdot
.984 .15706 Mdot
.984 .15707 Mdot
.984 .15746 Mdot
.984 .15758 Mdot
.984 .15831 Mdot
.984 .15878 Mdot
.984 .15927 Mdot
.984 .15932 Mdot
.984 .15959 Mdot
.984 .15967 Mdot
.984 .16004 Mdot
.984 .16014 Mdot
.984 .16019 Mdot
.984 .16064 Mdot
.984 .16119 Mdot
.984 .16161 Mdot
.984 .16171 Mdot
.984 .16232 Mdot
.984 .16247 Mdot
.984 .16281 Mdot
.984 .16295 Mdot
.984 .16341 Mdot
.984 .16358 Mdot
.984 .16368 Mdot
.984 .16426 Mdot
.984 .16431 Mdot
.984 .16504 Mdot
.984 .16553 Mdot
.984 .16637 Mdot
.984 .16643 Mdot
.984 .16647 Mdot
.984 .16659 Mdot
.984 .16664 Mdot
.984 .16678 Mdot
.984 .16682 Mdot
.984 .16687 Mdot
.984 .16689 Mdot
.984 .16693 Mdot
.984 .167 Mdot
.984 .1671 Mdot
.984 .16722 Mdot
.984 .16754 Mdot
.984 .16761 Mdot
.984 .16794 Mdot
.984 .16827 Mdot
.984 .16832 Mdot
.984 .16839 Mdot
.984 .16844 Mdot
.984 .1686 Mdot
.984 .16879 Mdot
.984 .16881 Mdot
.984 .16889 Mdot
.984 .16906 Mdot
.984 .16943 Mdot
.984 .16944 Mdot
.984 .1695 Mdot
.984 .16954 Mdot
.984 .16957 Mdot
.984 .16994 Mdot
.984 .16996 Mdot
.984 .1701 Mdot
.984 .17034 Mdot
.984 .17066 Mdot
.984 .17092 Mdot
.984 .17094 Mdot
.984 .17149 Mdot
.984 .17177 Mdot
.984 .17203 Mdot
.984 .17227 Mdot
.984 .1723 Mdot
.984 .1729 Mdot
.984 .17316 Mdot
.984 .17342 Mdot
.984 .17417 Mdot
.984 .17448 Mdot
.984 .17464 Mdot
.984 .17488 Mdot
.984 .17509 Mdot
.984 .17521 Mdot
.984 .17616 Mdot
.984 .17779 Mdot
.984 .17861 Mdot
.984 .17898 Mdot
.984 .17924 Mdot
.984 .18368 Mdot
.984 .18395 Mdot
.984 .18452 Mdot
.984 .18487 Mdot
.984 .18615 Mdot
.984 .18702 Mdot
.984 .19003 Mdot
.984 .19087 Mdot
.984 .1912 Mdot
.984 .19169 Mdot
.984 .19172 Mdot
.984 .19355 Mdot
.984 .19424 Mdot
.984 .19593 Mdot
.984 .19841 Mdot
.984 .19856 Mdot
.984 .19888 Mdot
.984 .19957 Mdot
.984 .19972 Mdot
.984 .20159 Mdot
.984 .20227 Mdot
.984 .20436 Mdot
.984 .20476 Mdot
.984 .20499 Mdot
.984 .20512 Mdot
.984 .20652 Mdot
.984 .20727 Mdot
.984 .20748 Mdot
.984 .20788 Mdot
.984 .21188 Mdot
.984 .21199 Mdot
.984 .21372 Mdot
.984 .22053 Mdot
.984 .221 Mdot
.984 .22361 Mdot
.984 .22474 Mdot
.984 .2261 Mdot
.984 .22617 Mdot
.984 .22689 Mdot
.984 .22729 Mdot
.984 .22932 Mdot
.984 .23388 Mdot
.984 .2354 Mdot
.984 .23548 Mdot
.984 .23587 Mdot
.984 .23856 Mdot
.984 .23926 Mdot
.984 .23934 Mdot
.984 .23981 Mdot
.984 .24257 Mdot
.984 .24338 Mdot
.984 .2436 Mdot
.984 .24472 Mdot
.984 .24485 Mdot
.984 .24545 Mdot
.984 .24561 Mdot
.984 .24578 Mdot
.984 .24621 Mdot
.984 .24714 Mdot
.984 .2472 Mdot
.984 .24729 Mdot
.984 .24737 Mdot
.984 .24885 Mdot
.984 .24906 Mdot
.984 .2494 Mdot
.984 .24969 Mdot
.984 .24986 Mdot
.984 .2508 Mdot
.984 .25213 Mdot
.984 .25255 Mdot
.984 .25354 Mdot
.984 .25368 Mdot
.984 .25469 Mdot
.984 .25516 Mdot
.984 .25563 Mdot
.984 .25642 Mdot
.984 .25678 Mdot
.984 .25687 Mdot
.984 .25761 Mdot
.984 .25787 Mdot
.984 .25813 Mdot
.984 .25832 Mdot
.984 .2584 Mdot
.984 .25855 Mdot
.984 .25865 Mdot
.984 .25896 Mdot
.984 .259 Mdot
.984 .25909 Mdot
.984 .25941 Mdot
.984 .2595 Mdot
.984 .25961 Mdot
.984 .25966 Mdot
.984 .25973 Mdot
.984 .25988 Mdot
.984 .26008 Mdot
.984 .26013 Mdot
.984 .26016 Mdot
.984 .26029 Mdot
.984 .26058 Mdot
.984 .2608 Mdot
.984 .2609 Mdot
.984 .26101 Mdot
.984 .26128 Mdot
.984 .26129 Mdot
.984 .26141 Mdot
.984 .26143 Mdot
.984 .26157 Mdot
.984 .26161 Mdot
.984 .26164 Mdot
.984 .26167 Mdot
.984 .26168 Mdot
.984 .26169 Mdot
.984 .26171 Mdot
.984 .26174 Mdot
.984 .26174 Mdot
.984 .26174 Mdot
.984 .2618 Mdot
.984 .2618 Mdot
.984 .26181 Mdot
.984 .26182 Mdot
.984 .26425 Mdot
.984 .26597 Mdot
.984 .26682 Mdot
.984 .26742 Mdot
.984 .26772 Mdot
.984 .26792 Mdot
.984 .26842 Mdot
.984 .26859 Mdot
.984 .26927 Mdot
.984 .27072 Mdot
.984 .27126 Mdot
.984 .27182 Mdot
.984 .27209 Mdot
.984 .27227 Mdot
.984 .27386 Mdot
.984 .27496 Mdot
.984 .27558 Mdot
.984 .27572 Mdot
.984 .27609 Mdot
.984 .27694 Mdot
.984 .27779 Mdot
.984 .27806 Mdot
.984 .27839 Mdot
.984 .28008 Mdot
.984 .28051 Mdot
.984 .28092 Mdot
.984 .28232 Mdot
.984 .29061 Mdot
.984 .29184 Mdot
.984 .29735 Mdot
.984 .29897 Mdot
.984 .29967 Mdot
.984 .30221 Mdot
.984 .30526 Mdot
.984 .31543 Mdot
.984 .32197 Mdot
.984 .32593 Mdot
.984 .32762 Mdot
.984 .33368 Mdot
.984 .33622 Mdot
.984 .33625 Mdot
.984 .3363 Mdot
.984 .33634 Mdot
.984 .33636 Mdot
.984 .33638 Mdot
.984 .33656 Mdot
.984 .33682 Mdot
.984 .3372 Mdot
.984 .33733 Mdot
.984 .33738 Mdot
.984 .33747 Mdot
.984 .33758 Mdot
.984 .33768 Mdot
.984 .33789 Mdot
.984 .33811 Mdot
.984 .33822 Mdot
.984 .33878 Mdot
.984 .34033 Mdot
.984 .34141 Mdot
.984 .3417 Mdot
.984 .34185 Mdot
.984 .34211 Mdot
.984 .34275 Mdot
.984 .34289 Mdot
.984 .34431 Mdot
.984 .34433 Mdot
.984 .34435 Mdot
.984 .34448 Mdot
.984 .34455 Mdot
.984 .34457 Mdot
.984 .34458 Mdot
.984 .3447 Mdot
.984 .34476 Mdot
.984 .34499 Mdot
.984 .34516 Mdot
.984 .34519 Mdot
.984 .34523 Mdot
.984 .34533 Mdot
.984 .34583 Mdot
.984 .34606 Mdot
.984 .34626 Mdot
.984 .34665 Mdot
.984 .3474 Mdot
.984 .34742 Mdot
.984 .34758 Mdot
.984 .3476 Mdot
.984 .34772 Mdot
.984 .34789 Mdot
.984 .34856 Mdot
.984 .34858 Mdot
.984 .34961 Mdot
.984 .34994 Mdot
.984 .35069 Mdot
.984 .35088 Mdot
.984 .35117 Mdot
.984 .35163 Mdot
.984 .35169 Mdot
.984 .35188 Mdot
.984 .35194 Mdot
.984 .35201 Mdot
.984 .35262 Mdot
.984 .35286 Mdot
.984 .35355 Mdot
.984 .35362 Mdot
.984 .35381 Mdot
.984 .35445 Mdot
.984 .3547 Mdot
.984 .35519 Mdot
.984 .356 Mdot
.984 .35627 Mdot
.984 .35638 Mdot
.984 .35651 Mdot
.984 .35661 Mdot
.984 .35674 Mdot
.984 .35677 Mdot
.984 .35744 Mdot
.984 .35757 Mdot
.984 .35781 Mdot
.984 .35868 Mdot
.984 .35922 Mdot
.984 .36008 Mdot
.984 .36066 Mdot
.984 .36072 Mdot
.984 .36093 Mdot
.984 .361 Mdot
.984 .36146 Mdot
.984 .36158 Mdot
.984 .3616 Mdot
.984 .36209 Mdot
.984 .36216 Mdot
.984 .36217 Mdot
.984 .36232 Mdot
.984 .3624 Mdot
.984 .36246 Mdot
.984 .36288 Mdot
.984 .36289 Mdot
.984 .36307 Mdot
.984 .36378 Mdot
.984 .36382 Mdot
.984 .3641 Mdot
.984 .36437 Mdot
.984 .36449 Mdot
.984 .36521 Mdot
.984 .36538 Mdot
.984 .36539 Mdot
.984 .36574 Mdot
.984 .36583 Mdot
.984 .36588 Mdot
.984 .36621 Mdot
.984 .36631 Mdot
.984 .36633 Mdot
.984 .36647 Mdot
.984 .36649 Mdot
.984 .36656 Mdot
.984 .36658 Mdot
.984 .36665 Mdot
.984 .36677 Mdot
.984 .36679 Mdot
.984 .36699 Mdot
.984 .36706 Mdot
.984 .3671 Mdot
.984 .36712 Mdot
.984 .36735 Mdot
.984 .36742 Mdot
.984 .36748 Mdot
.984 .36762 Mdot
.984 .36764 Mdot
.984 .36778 Mdot
.984 .36792 Mdot
.984 .36803 Mdot
.984 .36808 Mdot
.984 .3681 Mdot
.984 .36821 Mdot
.984 .36832 Mdot
.984 .36833 Mdot
.984 .36835 Mdot
.984 .36837 Mdot
.984 .36841 Mdot
.984 .36842 Mdot
.984 .36843 Mdot
.984 .36848 Mdot
.984 .3685 Mdot
.984 .36851 Mdot
.984 .36852 Mdot
.984 .36853 Mdot
.984 .36856 Mdot
.984 .36859 Mdot
.984 .3686 Mdot
.984 .3686 Mdot
.984 .36862 Mdot
.984 .36867 Mdot
.984 .3687 Mdot
.984 .36872 Mdot
.984 .36874 Mdot
.984 .36878 Mdot
.984 .36878 Mdot
.984 .3688 Mdot
.984 .36881 Mdot
.984 .36883 Mdot
.984 .36884 Mdot
.984 .36884 Mdot
.984 .36885 Mdot
.984 .36885 Mdot
.984 .36885 Mdot
.984 .36885 Mdot
.984 .36886 Mdot
.984 .36886 Mdot
.984 .36886 Mdot
.984 .36887 Mdot
.984 .36887 Mdot
.984 .36887 Mdot
.984 .36887 Mdot
.984 .37071 Mdot
.984 .37479 Mdot
.984 .37994 Mdot
.984 .38022 Mdot
.984 .38312 Mdot
.984 .38474 Mdot
.984 .39332 Mdot
.984 .39511 Mdot
.984 .40497 Mdot
.984 .41455 Mdot
.984 .4171 Mdot
.984 .42207 Mdot
.984 .42249 Mdot
.984 .42445 Mdot
.984 .42697 Mdot
.984 .42913 Mdot
.984 .43831 Mdot
.984 .44202 Mdot
.984 .44243 Mdot
.984 .4449 Mdot
.984 .45528 Mdot
.984 .45963 Mdot
.984 .46398 Mdot
.984 .46519 Mdot
.984 .46898 Mdot
.984 .47118 Mdot
.984 .47188 Mdot
.984 .4751 Mdot
.984 .47595 Mdot
.984 .47686 Mdot
.984 .47915 Mdot
.984 .48409 Mdot
.984 .4844 Mdot
.984 .48487 Mdot
.984 .48534 Mdot
.984 .49311 Mdot
.984 .49421 Mdot
.984 .49596 Mdot
.984 .49746 Mdot
.984 .49834 Mdot
.984 .50319 Mdot
.984 .50991 Mdot
.984 .512 Mdot
.984 .51688 Mdot
.984 .51754 Mdot
.984 .51858 Mdot
.984 .52242 Mdot
.984 .52465 Mdot
.984 .52686 Mdot
.984 .53046 Mdot
.984 .53213 Mdot
.984 .53254 Mdot
.984 .53582 Mdot
.984 .53696 Mdot
.984 .53808 Mdot
.984 .53893 Mdot
.984 .53927 Mdot
.984 .53989 Mdot
.984 .54033 Mdot
.984 .54166 Mdot
.984 .54183 Mdot
.984 .54219 Mdot
.984 .54356 Mdot
.984 .54393 Mdot
.984 .54436 Mdot
.984 .54457 Mdot
.984 .54487 Mdot
.984 .5455 Mdot
.984 .5463 Mdot
.984 .54648 Mdot
.984 .54661 Mdot
.984 .54715 Mdot
.984 .54832 Mdot
.984 .54918 Mdot
.984 .54958 Mdot
.984 .55003 Mdot
.984 .55107 Mdot
.984 .55112 Mdot
.984 .55158 Mdot
.984 .55165 Mdot
.984 .55219 Mdot
.984 .55233 Mdot
.984 .55248 Mdot
.984 .55259 Mdot
.984 .55261 Mdot
.984 .55266 Mdot
.984 .55273 Mdot
.984 .55283 Mdot
.984 .55285 Mdot
.984 .55286 Mdot
.984 .55307 Mdot
.984 .55309 Mdot
.984 .55313 Mdot
.984 .55315 Mdot
.984 .56019 Mdot
.984 .56145 Mdot
.984 .56148 Mdot
.984 .56152 Mdot
.984 .56154 Mdot
.984 .56159 Mdot
.984 .56172 Mdot
.984 .56176 Mdot
.984 .5618 Mdot
.984 .5619 Mdot
.984 .56191 Mdot
.984 .56195 Mdot
.984 .562 Mdot
.984 .56205 Mdot
.984 .56215 Mdot
.984 .56219 Mdot
.984 .56225 Mdot
.984 .56229 Mdot
.984 .56232 Mdot
.984 .56239 Mdot
.984 .5624 Mdot
.984 .5624 Mdot
.984 .56242 Mdot
.984 .56249 Mdot
.984 .56252 Mdot
.984 .56254 Mdot
.984 .56254 Mdot
.984 .56258 Mdot
.984 .56261 Mdot
.984 .56262 Mdot
.984 .56264 Mdot
.984 .56277 Mdot
.984 .56279 Mdot
.984 .56287 Mdot
.984 .56289 Mdot
.984 .56291 Mdot
.984 .56292 Mdot
.984 .56292 Mdot
.984 .56294 Mdot
.984 .56297 Mdot
.984 .56298 Mdot
.984 .56301 Mdot
.984 .56303 Mdot
.984 .56331 Mdot
.984 .56348 Mdot
.984 .56363 Mdot
.984 .56393 Mdot
.984 .56455 Mdot
.984 .56456 Mdot
.984 .56471 Mdot
.984 .56473 Mdot
.984 .56483 Mdot
.984 .56499 Mdot
.984 .56545 Mdot
.984 .56562 Mdot
.984 .56564 Mdot
.984 .56615 Mdot
.984 .56639 Mdot
.984 .5667 Mdot
.984 .56706 Mdot
.984 .56752 Mdot
.984 .56791 Mdot
.984 .56813 Mdot
.984 .56847 Mdot
.984 .56888 Mdot
.984 .56903 Mdot
.984 .5691 Mdot
.984 .56934 Mdot
.984 .56941 Mdot
.984 .5695 Mdot
.984 .57011 Mdot
.984 .57028 Mdot
.984 .57059 Mdot
.984 .57149 Mdot
.984 .57155 Mdot
.984 .57159 Mdot
.984 .57184 Mdot
.984 .57185 Mdot
.984 .57269 Mdot
.984 .57271 Mdot
.984 .57305 Mdot
.984 .57325 Mdot
.984 .57372 Mdot
.984 .57461 Mdot
.984 .57486 Mdot
.984 .57506 Mdot
.984 .57524 Mdot
.984 .5754 Mdot
.984 .57558 Mdot
.984 .57573 Mdot
.984 .57577 Mdot
.984 .5759 Mdot
.984 .57595 Mdot
.984 .57681 Mdot
.984 .57691 Mdot
.984 .57709 Mdot
.984 .57744 Mdot
.984 .57868 Mdot
.984 .57941 Mdot
.984 .57945 Mdot
.984 .58025 Mdot
.984 .5804 Mdot
.984 .58067 Mdot
.984 .58144 Mdot
.984 .58149 Mdot
.984 .58157 Mdot
.984 .58186 Mdot
.984 .58197 Mdot
.984 .5826 Mdot
.984 .58262 Mdot
.984 .58267 Mdot
.984 .58277 Mdot
.984 .58279 Mdot
.984 .58316 Mdot
.984 .58346 Mdot
.984 .58351 Mdot
.984 .58355 Mdot
.984 .58356 Mdot
.984 .58376 Mdot
.984 .58387 Mdot
.984 .58395 Mdot
.984 .5845 Mdot
.984 .58452 Mdot
.984 .58475 Mdot
.984 .58566 Mdot
.984 .58573 Mdot
.984 .58607 Mdot
.984 .5864 Mdot
.984 .5864 Mdot
.984 .58655 Mdot
.984 .58682 Mdot
.984 .58741 Mdot
.984 .58761 Mdot
.984 .58762 Mdot
.984 .58802 Mdot
.984 .58811 Mdot
.984 .58812 Mdot
.984 .58819 Mdot
.984 .58855 Mdot
.984 .58865 Mdot
.984 .58868 Mdot
.984 .58883 Mdot
.984 .58885 Mdot
.984 .58893 Mdot
.984 .58895 Mdot
.984 .58897 Mdot
.984 .58903 Mdot
.984 .58915 Mdot
.984 .58916 Mdot
.984 .58917 Mdot
.984 .58918 Mdot
.984 .58938 Mdot
.984 .58941 Mdot
.984 .58945 Mdot
.984 .58949 Mdot
.984 .58951 Mdot
.984 .58964 Mdot
.984 .58975 Mdot
.984 .58982 Mdot
.984 .58987 Mdot
.984 .59001 Mdot
.984 .59003 Mdot
.984 .59016 Mdot
.984 .59029 Mdot
.984 .5904 Mdot
.984 .59045 Mdot
.984 .59046 Mdot
.984 .59056 Mdot
.984 .5906 Mdot
.984 .59063 Mdot
.984 .59066 Mdot
.984 .59067 Mdot
.984 .59069 Mdot
.984 .59071 Mdot
.984 .59075 Mdot
.984 .59076 Mdot
.984 .59077 Mdot
.984 .59081 Mdot
.984 .59083 Mdot
.984 .59084 Mdot
.984 .59085 Mdot
.984 .59086 Mdot
.984 .59088 Mdot
.984 .59091 Mdot
.984 .59091 Mdot
.984 .59092 Mdot
.984 .59094 Mdot
.984 .59098 Mdot
.984 .59101 Mdot
.984 .59102 Mdot
.984 .59104 Mdot
.984 .59107 Mdot
.984 .59108 Mdot
.984 .59109 Mdot
.984 .5911 Mdot
.984 .59111 Mdot
.984 .59112 Mdot
.984 .59113 Mdot
.984 .59113 Mdot
.984 .59113 Mdot
.984 .59113 Mdot
.984 .59113 Mdot
.984 .59114 Mdot
.984 .59114 Mdot
.984 .59114 Mdot
.984 .59115 Mdot
.984 .59115 Mdot
.984 .59115 Mdot
.984 .59115 Mdot
.984 .5915 Mdot
.984 .59174 Mdot
.984 .59203 Mdot
.984 .59223 Mdot
.984 .59244 Mdot
.984 .59253 Mdot
.984 .59319 Mdot
.984 .59341 Mdot
.984 .59359 Mdot
.984 .594 Mdot
.984 .59406 Mdot
.986 .11119 Mdot
.986 .1112 Mdot
.986 .11122 Mdot
.986 .11123 Mdot
.986 .11123 Mdot
.986 .11124 Mdot
.986 .11124 Mdot
.986 .11124 Mdot
.986 .11124 Mdot
.986 .11125 Mdot
.986 .11125 Mdot
.986 .11131 Mdot
.986 .11142 Mdot
.986 .11143 Mdot
.986 .11143 Mdot
.986 .11149 Mdot
.986 .11156 Mdot
.986 .11176 Mdot
.986 .1118 Mdot
.986 .11181 Mdot
.986 .11184 Mdot
.986 .11184 Mdot
.986 .11185 Mdot
.986 .11187 Mdot
.986 .11188 Mdot
.986 .11188 Mdot
.986 .1119 Mdot
.986 .11195 Mdot
.986 .11201 Mdot
.986 .11202 Mdot
.986 .11203 Mdot
.986 .11204 Mdot
.986 .11205 Mdot
.986 .1121 Mdot
.986 .11211 Mdot
.986 .11215 Mdot
.986 .11218 Mdot
.986 .1122 Mdot
.986 .11222 Mdot
.986 .11235 Mdot
.986 .1124 Mdot
.986 .11241 Mdot
.986 .11251 Mdot
.986 .11253 Mdot
.986 .11256 Mdot
.986 .11258 Mdot
.986 .11279 Mdot
.986 .11279 Mdot
.986 .1128 Mdot
.986 .11284 Mdot
.986 .11286 Mdot
.986 .11291 Mdot
.986 .11293 Mdot
.986 .11302 Mdot
.986 .11306 Mdot
.986 .11321 Mdot
.986 .11331 Mdot
.986 .1135 Mdot
.986 .11372 Mdot
.986 .11384 Mdot
.986 .11384 Mdot
.986 .11391 Mdot
.986 .11404 Mdot
.986 .11407 Mdot
.986 .11412 Mdot
.986 .11418 Mdot
.986 .11418 Mdot
.986 .11423 Mdot
.986 .11424 Mdot
.986 .11424 Mdot
.986 .11426 Mdot
.986 .11427 Mdot
.986 .11432 Mdot
.986 .11433 Mdot
.986 .11439 Mdot
.986 .11448 Mdot
.986 .1145 Mdot
.986 .11462 Mdot
.986 .11475 Mdot
.986 .11478 Mdot
.986 .11486 Mdot
.986 .11492 Mdot
.986 .11492 Mdot
.986 .11497 Mdot
.986 .11503 Mdot
.986 .11505 Mdot
.986 .11506 Mdot
.986 .11507 Mdot
.986 .11508 Mdot
.986 .11509 Mdot
.986 .11513 Mdot
.986 .11518 Mdot
.986 .11519 Mdot
.986 .11522 Mdot
.986 .11522 Mdot
.986 .11523 Mdot
.986 .11528 Mdot
.986 .11556 Mdot
.986 .11567 Mdot
.986 .11606 Mdot
.986 .11628 Mdot
.986 .11631 Mdot
.986 .1166 Mdot
.986 .11734 Mdot
.986 .11735 Mdot
.986 .11752 Mdot
.986 .11834 Mdot
.986 .11839 Mdot
.986 .11897 Mdot
.986 .11922 Mdot
.986 .11929 Mdot
.986 .11964 Mdot
.986 .11978 Mdot
.986 .12013 Mdot
.986 .1204 Mdot
.986 .1205 Mdot
.986 .12051 Mdot
.986 .12062 Mdot
.986 .12071 Mdot
.986 .12074 Mdot
.986 .12075 Mdot
.986 .12125 Mdot
.986 .12153 Mdot
.986 .12264 Mdot
.986 .12299 Mdot
.986 .12309 Mdot
.986 .12412 Mdot
.986 .12415 Mdot
.986 .12417 Mdot
.986 .1243 Mdot
.986 .12431 Mdot
.986 .12442 Mdot
.986 .12477 Mdot
.986 .1249 Mdot
.986 .12494 Mdot
.986 .12496 Mdot
.986 .12509 Mdot
.986 .1252 Mdot
.986 .12573 Mdot
.986 .12603 Mdot
.986 .12617 Mdot
.986 .12668 Mdot
.986 .1267 Mdot
.986 .12697 Mdot
.986 .127 Mdot
.986 .12725 Mdot
.986 .12749 Mdot
.986 .1276 Mdot
.986 .12784 Mdot
.986 .12788 Mdot
.986 .12798 Mdot
.986 .1281 Mdot
.986 .12835 Mdot
.986 .129 Mdot
.986 .12911 Mdot
.986 .12929 Mdot
.986 .12941 Mdot
.986 .12958 Mdot
.986 .12991 Mdot
.986 .13099 Mdot
.986 .13101 Mdot
.986 .13121 Mdot
.986 .13124 Mdot
.986 .13134 Mdot
.986 .13139 Mdot
.986 .13139 Mdot
.986 .1314 Mdot
.986 .13143 Mdot
.986 .13143 Mdot
.986 .13157 Mdot
.986 .13165 Mdot
.986 .13167 Mdot
.986 .13172 Mdot
.986 .13183 Mdot
.986 .13191 Mdot
.986 .13191 Mdot
.986 .13195 Mdot
.986 .13197 Mdot
.986 .13198 Mdot
.986 .132 Mdot
.986 .132 Mdot
.986 .13201 Mdot
.986 .13203 Mdot
.986 .1328 Mdot
.986 .13303 Mdot
.986 .13313 Mdot
.986 .13326 Mdot
.986 .1334 Mdot
.986 .13341 Mdot
.986 .13342 Mdot
.986 .1337 Mdot
.986 .13371 Mdot
.986 .13404 Mdot
.986 .13422 Mdot
.986 .13424 Mdot
.986 .13431 Mdot
.986 .13442 Mdot
.986 .13449 Mdot
.986 .13468 Mdot
.986 .13469 Mdot
.986 .13481 Mdot
.986 .13483 Mdot
.986 .13484 Mdot
.986 .1349 Mdot
.986 .13491 Mdot
.986 .13503 Mdot
.986 .13506 Mdot
.986 .13513 Mdot
.986 .13514 Mdot
.986 .13519 Mdot
.986 .13534 Mdot
.986 .13536 Mdot
.986 .13539 Mdot
.986 .13551 Mdot
.986 .13555 Mdot
.986 .13568 Mdot
.986 .13568 Mdot
.986 .1357 Mdot
.986 .13572 Mdot
.986 .13572 Mdot
.986 .13572 Mdot
.986 .13573 Mdot
.986 .13574 Mdot
.986 .13574 Mdot
.986 .13575 Mdot
.986 .13576 Mdot
.986 .13577 Mdot
.986 .13577 Mdot
.986 .13577 Mdot
.986 .13577 Mdot
.986 .13577 Mdot
.986 .13578 Mdot
.986 .13578 Mdot
.986 .13578 Mdot
.986 .13578 Mdot
.986 .13616 Mdot
.986 .13691 Mdot
.986 .13695 Mdot
.986 .13718 Mdot
.986 .13733 Mdot
.986 .13774 Mdot
.986 .13787 Mdot
.986 .13796 Mdot
.986 .13815 Mdot
.986 .13822 Mdot
.986 .13823 Mdot
.986 .13841 Mdot
.986 .1385 Mdot
.986 .13855 Mdot
.986 .13875 Mdot
.986 .13964 Mdot
.986 .15322 Mdot
.986 .15325 Mdot
.986 .15332 Mdot
.986 .15336 Mdot
.986 .15337 Mdot
.986 .15338 Mdot
.986 .15338 Mdot
.986 .1534 Mdot
.986 .15341 Mdot
.986 .15343 Mdot
.986 .15344 Mdot
.986 .15365 Mdot
.986 .1541 Mdot
.986 .15412 Mdot
.986 .15414 Mdot
.986 .15438 Mdot
.986 .15465 Mdot
.986 .15543 Mdot
.986 .15556 Mdot
.986 .15564 Mdot
.986 .15573 Mdot
.986 .15575 Mdot
.986 .15576 Mdot
.986 .15586 Mdot
.986 .15589 Mdot
.986 .15592 Mdot
.986 .15599 Mdot
.986 .15618 Mdot
.986 .15642 Mdot
.986 .15646 Mdot
.986 .1565 Mdot
.986 .15652 Mdot
.986 .15655 Mdot
.986 .15672 Mdot
.986 .15675 Mdot
.986 .15683 Mdot
.986 .15696 Mdot
.986 .15708 Mdot
.986 .15715 Mdot
.986 .15725 Mdot
.986 .15779 Mdot
.986 .15796 Mdot
.986 .15803 Mdot
.986 .15841 Mdot
.986 .15848 Mdot
.986 .15863 Mdot
.986 .15871 Mdot
.986 .15956 Mdot
.986 .15956 Mdot
.986 .1596 Mdot
.986 .15977 Mdot
.986 .15986 Mdot
.986 .16003 Mdot
.986 .16014 Mdot
.986 .16049 Mdot
.986 .16067 Mdot
.986 .16129 Mdot
.986 .16171 Mdot
.986 .16252 Mdot
.986 .16345 Mdot
.986 .16394 Mdot
.986 .16395 Mdot
.986 .16423 Mdot
.986 .16478 Mdot
.986 .1649 Mdot
.986 .16512 Mdot
.986 .16539 Mdot
.986 .16541 Mdot
.986 .16559 Mdot
.986 .16563 Mdot
.986 .16565 Mdot
.986 .16574 Mdot
.986 .16575 Mdot
.986 .16598 Mdot
.986 .16604 Mdot
.986 .16629 Mdot
.986 .1667 Mdot
.986 .16677 Mdot
.986 .16728 Mdot
.986 .16785 Mdot
.986 .16797 Mdot
.986 .16836 Mdot
.986 .16859 Mdot
.986 .16859 Mdot
.986 .16882 Mdot
.986 .16907 Mdot
.986 .16919 Mdot
.986 .16923 Mdot
.986 .16928 Mdot
.986 .1693 Mdot
.986 .16934 Mdot
.986 .16954 Mdot
.986 .16973 Mdot
.986 .1698 Mdot
.986 .16992 Mdot
.986 .16994 Mdot
.986 .16995 Mdot
.986 .17019 Mdot
.986 .17144 Mdot
.986 .17194 Mdot
.986 .17371 Mdot
.986 .17471 Mdot
.986 .17481 Mdot
.986 .17618 Mdot
.986 .17957 Mdot
.986 .17966 Mdot
.986 .18042 Mdot
.986 .18432 Mdot
.986 .18458 Mdot
.986 .18738 Mdot
.986 .18858 Mdot
.986 .18892 Mdot
.986 .19067 Mdot
.986 .19133 Mdot
.986 .19307 Mdot
.986 .19443 Mdot
.986 .19491 Mdot
.986 .19496 Mdot
.986 .19551 Mdot
.986 .19596 Mdot
.986 .19613 Mdot
.986 .19619 Mdot
.986 .1987 Mdot
.986 .20013 Mdot
.986 .20583 Mdot
.986 .20761 Mdot
.986 .20816 Mdot
.986 .21353 Mdot
.986 .21365 Mdot
.986 .21376 Mdot
.986 .21447 Mdot
.986 .21453 Mdot
.986 .2151 Mdot
.986 .21597 Mdot
.986 .21692 Mdot
.986 .21764 Mdot
.986 .21784 Mdot
.986 .21797 Mdot
.986 .21863 Mdot
.986 .21923 Mdot
.986 .22202 Mdot
.986 .22364 Mdot
.986 .22436 Mdot
.986 .22709 Mdot
.986 .22723 Mdot
.986 .22865 Mdot
.986 .22882 Mdot
.986 .23013 Mdot
.986 .23145 Mdot
.986 .23205 Mdot
.986 .23333 Mdot
.986 .23354 Mdot
.986 .23406 Mdot
.986 .23471 Mdot
.986 .23603 Mdot
.986 .23637 Mdot
.986 .23956 Mdot
.986 .24013 Mdot
.986 .24112 Mdot
.986 .24177 Mdot
.986 .24268 Mdot
.986 .24444 Mdot
.986 .24607 Mdot
.986 .24884 Mdot
.986 .24903 Mdot
.986 .2502 Mdot
.986 .25025 Mdot
.986 .25036 Mdot
.986 .25144 Mdot
.986 .2516 Mdot
.986 .2521 Mdot
.986 .25237 Mdot
.986 .2524 Mdot
.986 .25243 Mdot
.986 .25259 Mdot
.986 .2526 Mdot
.986 .2527 Mdot
.986 .25337 Mdot
.986 .25364 Mdot
.986 .25378 Mdot
.986 .2539 Mdot
.986 .25417 Mdot
.986 .25475 Mdot
.986 .25515 Mdot
.986 .25515 Mdot
.986 .25539 Mdot
.986 .25549 Mdot
.986 .25553 Mdot
.986 .25563 Mdot
.986 .25568 Mdot
.986 .25568 Mdot
.986 .25579 Mdot
.986 .25618 Mdot
.986 .25993 Mdot
.986 .26111 Mdot
.986 .26164 Mdot
.986 .26214 Mdot
.986 .26216 Mdot
.986 .26217 Mdot
.986 .26238 Mdot
.986 .26309 Mdot
.986 .26313 Mdot
.986 .26317 Mdot
.986 .26467 Mdot
.986 .2647 Mdot
.986 .26646 Mdot
.986 .2674 Mdot
.986 .26752 Mdot
.986 .26789 Mdot
.986 .26844 Mdot
.986 .26881 Mdot
.986 .2698 Mdot
.986 .26987 Mdot
.986 .2705 Mdot
.986 .27062 Mdot
.986 .27067 Mdot
.986 .27096 Mdot
.986 .271 Mdot
.986 .27166 Mdot
.986 .27182 Mdot
.986 .27219 Mdot
.986 .2722 Mdot
.986 .2722 Mdot
.986 .27247 Mdot
.986 .27325 Mdot
.986 .27336 Mdot
.986 .27351 Mdot
.986 .27413 Mdot
.986 .27434 Mdot
.986 .275 Mdot
.986 .27501 Mdot
.986 .27511 Mdot
.986 .2752 Mdot
.986 .2752 Mdot
.986 .27522 Mdot
.986 .27529 Mdot
.986 .27533 Mdot
.986 .27534 Mdot
.986 .27537 Mdot
.986 .27543 Mdot
.986 .27547 Mdot
.986 .27547 Mdot
.986 .27549 Mdot
.986 .2755 Mdot
.986 .2755 Mdot
.986 .27551 Mdot
.986 .27552 Mdot
.986 .27552 Mdot
.986 .27553 Mdot
.986 .27751 Mdot
.986 .28129 Mdot
.986 .28151 Mdot
.986 .28269 Mdot
.986 .28342 Mdot
.986 .28547 Mdot
.986 .28614 Mdot
.986 .28635 Mdot
.986 .28662 Mdot
.986 .28755 Mdot
.986 .28789 Mdot
.986 .28795 Mdot
.986 .28885 Mdot
.986 .2893 Mdot
.986 .28954 Mdot
.986 .29053 Mdot
.986 .29273 Mdot
.986 .29484 Mdot
.986 .29547 Mdot
.986 .29875 Mdot
.986 .30506 Mdot
.986 .31942 Mdot
.986 .32156 Mdot
.986 .32164 Mdot
.986 .32495 Mdot
.986 .32542 Mdot
.986 .32615 Mdot
.986 .32689 Mdot
.986 .3313 Mdot
.986 .33697 Mdot
.986 .33721 Mdot
.986 .33731 Mdot
.986 .33782 Mdot
.986 .33806 Mdot
.986 .33844 Mdot
.986 .33867 Mdot
.986 .33919 Mdot
.986 .3394 Mdot
.986 .34007 Mdot
.986 .34074 Mdot
.986 .3408 Mdot
.986 .34096 Mdot
.986 .34141 Mdot
.986 .3417 Mdot
.986 .34198 Mdot
.986 .34203 Mdot
.986 .34256 Mdot
.986 .34256 Mdot
.986 .34413 Mdot
.986 .34492 Mdot
.986 .34513 Mdot
.986 .34633 Mdot
.986 .34647 Mdot
.986 .34659 Mdot
.986 .34671 Mdot
.986 .34721 Mdot
.986 .34781 Mdot
.986 .34794 Mdot
.986 .34797 Mdot
.986 .34807 Mdot
.986 .34827 Mdot
.986 .34837 Mdot
.986 .34841 Mdot
.986 .34843 Mdot
.986 .34844 Mdot
.986 .3485 Mdot
.986 .34851 Mdot
.986 .34856 Mdot
.986 .34861 Mdot
.986 .34919 Mdot
.986 .34961 Mdot
.986 .34963 Mdot
.986 .35008 Mdot
.986 .35038 Mdot
.986 .35044 Mdot
.986 .35049 Mdot
.986 .35051 Mdot
.986 .35111 Mdot
.986 .35174 Mdot
.986 .35179 Mdot
.986 .35183 Mdot
.986 .35348 Mdot
.986 .35376 Mdot
.986 .35396 Mdot
.986 .35407 Mdot
.986 .35425 Mdot
.986 .35431 Mdot
.986 .35447 Mdot
.986 .35451 Mdot
.986 .35454 Mdot
.986 .35478 Mdot
.986 .35483 Mdot
.986 .3549 Mdot
.986 .35507 Mdot
.986 .3555 Mdot
.986 .35581 Mdot
.986 .356 Mdot
.986 .35604 Mdot
.986 .35614 Mdot
.986 .35616 Mdot
.986 .35621 Mdot
.986 .35622 Mdot
.986 .35627 Mdot
.986 .35634 Mdot
.986 .35671 Mdot
.986 .35677 Mdot
.986 .35694 Mdot
.986 .35714 Mdot
.986 .35721 Mdot
.986 .35748 Mdot
.986 .35763 Mdot
.986 .35764 Mdot
.986 .35783 Mdot
.986 .3583 Mdot
.986 .35889 Mdot
.986 .35892 Mdot
.986 .35925 Mdot
.986 .35939 Mdot
.986 .3601 Mdot
.986 .36023 Mdot
.986 .3605 Mdot
.986 .36065 Mdot
.986 .36142 Mdot
.986 .36211 Mdot
.986 .36212 Mdot
.986 .36217 Mdot
.986 .36236 Mdot
.986 .36245 Mdot
.986 .36246 Mdot
.986 .36253 Mdot
.986 .36259 Mdot
.986 .36287 Mdot
.986 .36303 Mdot
.986 .36337 Mdot
.986 .36355 Mdot
.986 .36382 Mdot
.986 .36467 Mdot
.986 .3652 Mdot
.986 .36603 Mdot
.986 .36609 Mdot
.986 .36615 Mdot
.986 .36708 Mdot
.986 .36724 Mdot
.986 .36731 Mdot
.986 .36742 Mdot
.986 .36752 Mdot
.986 .36753 Mdot
.986 .36775 Mdot
.986 .36775 Mdot
.986 .36802 Mdot
.986 .36816 Mdot
.986 .36818 Mdot
.986 .36824 Mdot
.986 .36839 Mdot
.986 .36855 Mdot
.986 .36856 Mdot
.986 .36867 Mdot
.986 .36869 Mdot
.986 .3687 Mdot
.986 .36875 Mdot
.986 .36875 Mdot
.986 .36887 Mdot
.986 .3689 Mdot
.986 .36896 Mdot
.986 .36901 Mdot
.986 .36915 Mdot
.986 .36917 Mdot
.986 .3692 Mdot
.986 .36936 Mdot
.986 .36949 Mdot
.986 .36949 Mdot
.986 .36951 Mdot
.986 .36953 Mdot
.986 .36953 Mdot
.986 .36953 Mdot
.986 .36954 Mdot
.986 .36955 Mdot
.986 .36956 Mdot
.986 .36957 Mdot
.986 .36958 Mdot
.986 .36958 Mdot
.986 .36958 Mdot
.986 .36959 Mdot
.986 .36959 Mdot
.986 .36959 Mdot
.986 .36959 Mdot
.986 .36959 Mdot
.986 .36959 Mdot
.986 .37152 Mdot
.986 .3741 Mdot
.986 .38464 Mdot
.986 .38524 Mdot
.986 .39119 Mdot
.986 .39193 Mdot
.986 .39768 Mdot
.986 .40183 Mdot
.986 .40371 Mdot
.986 .40653 Mdot
.986 .4099 Mdot
.986 .41265 Mdot
.986 .41368 Mdot
.986 .41623 Mdot
.986 .41944 Mdot
.986 .4261 Mdot
.986 .42782 Mdot
.986 .4437 Mdot
.986 .44445 Mdot
.986 .44747 Mdot
.986 .45274 Mdot
.986 .45624 Mdot
.986 .46087 Mdot
.986 .46113 Mdot
.986 .47058 Mdot
.986 .47456 Mdot
.986 .47934 Mdot
.986 .48006 Mdot
.986 .49405 Mdot
.986 .49463 Mdot
.986 .49503 Mdot
.986 .50108 Mdot
.986 .50138 Mdot
.986 .50194 Mdot
.986 .50746 Mdot
.986 .50824 Mdot
.986 .51075 Mdot
.986 .51191 Mdot
.986 .5121 Mdot
.986 .51229 Mdot
.986 .51241 Mdot
.986 .51323 Mdot
.986 .51325 Mdot
.986 .51377 Mdot
.986 .51705 Mdot
.986 .5184 Mdot
.986 .51909 Mdot
.986 .51965 Mdot
.986 .52095 Mdot
.986 .52372 Mdot
.986 .52563 Mdot
.986 .52563 Mdot
.986 .52564 Mdot
.986 .52676 Mdot
.986 .52723 Mdot
.986 .52741 Mdot
.986 .52788 Mdot
.986 .52809 Mdot
.986 .52813 Mdot
.986 .52865 Mdot
.986 .53045 Mdot
.986 .53427 Mdot
.986 .54677 Mdot
.986 .5515 Mdot
.986 .55177 Mdot
.986 .55355 Mdot
.986 .55544 Mdot
.986 .55554 Mdot
.986 .55559 Mdot
.986 .55634 Mdot
.986 .55894 Mdot
.986 .55911 Mdot
.986 .55926 Mdot
.986 .56255 Mdot
.986 .56255 Mdot
.986 .56256 Mdot
.986 .56258 Mdot
.986 .56259 Mdot
.986 .56263 Mdot
.986 .56267 Mdot
.986 .56268 Mdot
.986 .56268 Mdot
.986 .56269 Mdot
.986 .56272 Mdot
.986 .56281 Mdot
.986 .56281 Mdot
.986 .56286 Mdot
.986 .56294 Mdot
.986 .56308 Mdot
.986 .56319 Mdot
.986 .56342 Mdot
.986 .56345 Mdot
.986 .56345 Mdot
.986 .5635 Mdot
.986 .5635 Mdot
.986 .56364 Mdot
.986 .56385 Mdot
.986 .56397 Mdot
.986 .56444 Mdot
.986 .56455 Mdot
.986 .5648 Mdot
.986 .56491 Mdot
.986 .565 Mdot
.986 .56509 Mdot
.986 .5655 Mdot
.986 .56603 Mdot
.986 .56615 Mdot
.986 .56618 Mdot
.986 .56628 Mdot
.986 .5663 Mdot
.986 .56646 Mdot
.986 .56656 Mdot
.986 .5666 Mdot
.986 .56661 Mdot
.986 .56662 Mdot
.986 .56668 Mdot
.986 .5667 Mdot
.986 .56675 Mdot
.986 .56679 Mdot
.986 .56687 Mdot
.986 .56738 Mdot
.986 .5678 Mdot
.986 .56782 Mdot
.986 .56784 Mdot
.986 .56834 Mdot
.986 .56868 Mdot
.986 .56875 Mdot
.986 .5688 Mdot
.986 .56883 Mdot
.986 .56886 Mdot
.986 .56954 Mdot
.986 .5699 Mdot
.986 .57015 Mdot
.986 .5703 Mdot
.986 .57035 Mdot
.986 .5704 Mdot
.986 .57156 Mdot
.986 .57253 Mdot
.986 .5729 Mdot
.986 .57293 Mdot
.986 .57296 Mdot
.986 .57318 Mdot
.986 .57327 Mdot
.986 .57332 Mdot
.986 .57357 Mdot
.986 .57364 Mdot
.986 .57367 Mdot
.986 .57386 Mdot
.986 .57392 Mdot
.986 .57396 Mdot
.986 .57429 Mdot
.986 .5743 Mdot
.986 .57437 Mdot
.986 .57446 Mdot
.986 .57469 Mdot
.986 .5753 Mdot
.986 .57573 Mdot
.986 .57581 Mdot
.986 .576 Mdot
.986 .57606 Mdot
.986 .5762 Mdot
.986 .57623 Mdot
.986 .57629 Mdot
.986 .57631 Mdot
.986 .57637 Mdot
.986 .57648 Mdot
.986 .57677 Mdot
.986 .57701 Mdot
.986 .5771 Mdot
.986 .57733 Mdot
.986 .57762 Mdot
.986 .57773 Mdot
.986 .57811 Mdot
.986 .57832 Mdot
.986 .57834 Mdot
.986 .57862 Mdot
.986 .57927 Mdot
.986 .57929 Mdot
.986 .57943 Mdot
.986 .58013 Mdot
.986 .58017 Mdot
.986 .58065 Mdot
.986 .58085 Mdot
.986 .5809 Mdot
.986 .58119 Mdot
.986 .58129 Mdot
.986 .58185 Mdot
.986 .58186 Mdot
.986 .58194 Mdot
.986 .58203 Mdot
.986 .58204 Mdot
.986 .58242 Mdot
.986 .58263 Mdot
.986 .58345 Mdot
.986 .5837 Mdot
.986 .58378 Mdot
.986 .58451 Mdot
.986 .58453 Mdot
.986 .58454 Mdot
.986 .58464 Mdot
.986 .58465 Mdot
.986 .58473 Mdot
.986 .58497 Mdot
.986 .58507 Mdot
.986 .58509 Mdot
.986 .58511 Mdot
.986 .5852 Mdot
.986 .58528 Mdot
.986 .58565 Mdot
.986 .58586 Mdot
.986 .58631 Mdot
.986 .58633 Mdot
.986 .58651 Mdot
.986 .58654 Mdot
.986 .58671 Mdot
.986 .58688 Mdot
.986 .58696 Mdot
.986 .58712 Mdot
.986 .58715 Mdot
.986 .58793 Mdot
.986 .588 Mdot
.986 .58813 Mdot
.986 .58834 Mdot
.986 .58857 Mdot
.986 .58933 Mdot
.986 .58935 Mdot
.986 .58949 Mdot
.986 .58951 Mdot
.986 .58958 Mdot
.986 .58961 Mdot
.986 .58962 Mdot
.986 .58962 Mdot
.986 .58964 Mdot
.986 .58964 Mdot
.986 .58975 Mdot
.986 .5898 Mdot
.986 .58982 Mdot
.986 .58986 Mdot
.986 .58993 Mdot
.986 .58999 Mdot
.986 .58999 Mdot
.986 .59002 Mdot
.986 .59003 Mdot
.986 .59004 Mdot
.986 .59005 Mdot
.986 .59006 Mdot
.986 .59006 Mdot
.986 .59007 Mdot
.986 .59064 Mdot
.986 .5908 Mdot
.986 .59088 Mdot
.986 .59098 Mdot
.986 .59108 Mdot
.986 .59109 Mdot
.986 .5913 Mdot
.986 .59131 Mdot
.986 .59156 Mdot
.986 .59169 Mdot
.986 .59171 Mdot
.986 .59176 Mdot
.986 .59184 Mdot
.986 .5919 Mdot
.986 .59204 Mdot
.986 .59205 Mdot
.986 .59215 Mdot
.986 .59216 Mdot
.986 .59217 Mdot
.986 .59221 Mdot
.986 .59222 Mdot
.986 .59232 Mdot
.986 .59234 Mdot
.986 .5924 Mdot
.986 .5924 Mdot
.986 .59244 Mdot
.986 .59256 Mdot
.986 .59257 Mdot
.986 .5926 Mdot
.986 .59269 Mdot
.986 .59272 Mdot
.986 .59282 Mdot
.986 .59283 Mdot
.986 .59284 Mdot
.986 .59285 Mdot
.986 .59286 Mdot
.986 .59286 Mdot
.986 .59287 Mdot
.986 .59288 Mdot
.986 .59288 Mdot
.986 .59288 Mdot
.986 .59289 Mdot
.986 .5929 Mdot
.986 .5929 Mdot
.986 .5929 Mdot
.986 .5929 Mdot
.986 .5929 Mdot
.986 .5929 Mdot
.986 .5929 Mdot
.986 .5929 Mdot
.986 .59291 Mdot
.986 .59322 Mdot
.986 .59383 Mdot
.986 .59386 Mdot
.986 .59406 Mdot
.986 .59418 Mdot
.986 .59454 Mdot
.986 .59465 Mdot
.986 .59474 Mdot
.986 .59491 Mdot
.986 .59497 Mdot
.986 .59498 Mdot
.986 .59514 Mdot
.986 .59523 Mdot
.986 .59527 Mdot
.988 .11139 Mdot
.988 .1114 Mdot
.988 .11146 Mdot
.988 .11149 Mdot
.988 .1115 Mdot
.988 .11155 Mdot
.988 .11156 Mdot
.988 .11157 Mdot
.988 .11159 Mdot
.988 .11165 Mdot
.988 .11166 Mdot
.988 .11166 Mdot
.988 .11168 Mdot
.988 .11168 Mdot
.988 .11176 Mdot
.988 .11179 Mdot
.988 .11183 Mdot
.988 .11185 Mdot
.988 .11189 Mdot
.988 .11189 Mdot
.988 .1119 Mdot
.988 .11204 Mdot
.988 .11212 Mdot
.988 .11213 Mdot
.988 .11221 Mdot
.988 .11223 Mdot
.988 .11235 Mdot
.988 .11238 Mdot
.988 .11248 Mdot
.988 .11262 Mdot
.988 .11262 Mdot
.988 .11283 Mdot
.988 .11295 Mdot
.988 .11305 Mdot
.988 .11305 Mdot
.988 .11311 Mdot
.988 .1132 Mdot
.988 .11322 Mdot
.988 .11325 Mdot
.988 .11337 Mdot
.988 .11337 Mdot
.988 .11339 Mdot
.988 .11348 Mdot
.988 .1135 Mdot
.988 .11351 Mdot
.988 .11351 Mdot
.988 .11352 Mdot
.988 .11353 Mdot
.988 .11359 Mdot
.988 .11371 Mdot
.988 .11378 Mdot
.988 .11378 Mdot
.988 .11387 Mdot
.988 .11389 Mdot
.988 .1139 Mdot
.988 .11394 Mdot
.988 .11395 Mdot
.988 .11396 Mdot
.988 .11399 Mdot
.988 .11403 Mdot
.988 .11407 Mdot
.988 .11409 Mdot
.988 .1141 Mdot
.988 .11413 Mdot
.988 .11417 Mdot
.988 .1142 Mdot
.988 .11421 Mdot
.988 .1145 Mdot
.988 .11453 Mdot
.988 .115 Mdot
.988 .11516 Mdot
.988 .11554 Mdot
.988 .11572 Mdot
.988 .11575 Mdot
.988 .11583 Mdot
.988 .11606 Mdot
.988 .11769 Mdot
.988 .11772 Mdot
.988 .11883 Mdot
.988 .11894 Mdot
.988 .11908 Mdot
.988 .11972 Mdot
.988 .12019 Mdot
.988 .12034 Mdot
.988 .12054 Mdot
.988 .12056 Mdot
.988 .12135 Mdot
.988 .12141 Mdot
.988 .12165 Mdot
.988 .12183 Mdot
.988 .12197 Mdot
.988 .12213 Mdot
.988 .12225 Mdot
.988 .12226 Mdot
.988 .12231 Mdot
.988 .12275 Mdot
.988 .12287 Mdot
.988 .12292 Mdot
.988 .12328 Mdot
.988 .12355 Mdot
.988 .12398 Mdot
.988 .12401 Mdot
.988 .12433 Mdot
.988 .12518 Mdot
.988 .12518 Mdot
.988 .12524 Mdot
.988 .12524 Mdot
.988 .1253 Mdot
.988 .12538 Mdot
.988 .12539 Mdot
.988 .12539 Mdot
.988 .12542 Mdot
.988 .12545 Mdot
.988 .12548 Mdot
.988 .12549 Mdot
.988 .1255 Mdot
.988 .12554 Mdot
.988 .12556 Mdot
.988 .12566 Mdot
.988 .12572 Mdot
.988 .12575 Mdot
.988 .12591 Mdot
.988 .12601 Mdot
.988 .12617 Mdot
.988 .12619 Mdot
.988 .12648 Mdot
.988 .12663 Mdot
.988 .12664 Mdot
.988 .12666 Mdot
.988 .12687 Mdot
.988 .1269 Mdot
.988 .1269 Mdot
.988 .12711 Mdot
.988 .1276 Mdot
.988 .12769 Mdot
.988 .12794 Mdot
.988 .12816 Mdot
.988 .1283 Mdot
.988 .12835 Mdot
.988 .12859 Mdot
.988 .12881 Mdot
.988 .12895 Mdot
.988 .1294 Mdot
.988 .12964 Mdot
.988 .12986 Mdot
.988 .12991 Mdot
.988 .12997 Mdot
.988 .13014 Mdot
.988 .13019 Mdot
.988 .13036 Mdot
.988 .13069 Mdot
.988 .1312 Mdot
.988 .13121 Mdot
.988 .13124 Mdot
.988 .13135 Mdot
.988 .1314 Mdot
.988 .13185 Mdot
.988 .13185 Mdot
.988 .13202 Mdot
.988 .13257 Mdot
.988 .13277 Mdot
.988 .13298 Mdot
.988 .1337 Mdot
.988 .13373 Mdot
.988 .13384 Mdot
.988 .13391 Mdot
.988 .13393 Mdot
.988 .13395 Mdot
.988 .13403 Mdot
.988 .13423 Mdot
.988 .13427 Mdot
.988 .13439 Mdot
.988 .1345 Mdot
.988 .13457 Mdot
.988 .13473 Mdot
.988 .13474 Mdot
.988 .13476 Mdot
.988 .13477 Mdot
.988 .13479 Mdot
.988 .13483 Mdot
.988 .13487 Mdot
.988 .1349 Mdot
.988 .13499 Mdot
.988 .1351 Mdot
.988 .13524 Mdot
.988 .13572 Mdot
.988 .13579 Mdot
.988 .13582 Mdot
.988 .1361 Mdot
.988 .1361 Mdot
.988 .1361 Mdot
.988 .13638 Mdot
.988 .13641 Mdot
.988 .13643 Mdot
.988 .13648 Mdot
.988 .13651 Mdot
.988 .13653 Mdot
.988 .13668 Mdot
.988 .13671 Mdot
.988 .13673 Mdot
.988 .13681 Mdot
.988 .13694 Mdot
.988 .13705 Mdot
.988 .13706 Mdot
.988 .13708 Mdot
.988 .13709 Mdot
.988 .13709 Mdot
.988 .1371 Mdot
.988 .13711 Mdot
.988 .13712 Mdot
.988 .13716 Mdot
.988 .1372 Mdot
.988 .13726 Mdot
.988 .13729 Mdot
.988 .13731 Mdot
.988 .13734 Mdot
.988 .13736 Mdot
.988 .13737 Mdot
.988 .1374 Mdot
.988 .13754 Mdot
.988 .13764 Mdot
.988 .13783 Mdot
.988 .13787 Mdot
.988 .13801 Mdot
.988 .13806 Mdot
.988 .13845 Mdot
.988 .13858 Mdot
.988 .13865 Mdot
.988 .1387 Mdot
.988 .13883 Mdot
.988 .13887 Mdot
.988 .13887 Mdot
.988 .13895 Mdot
.988 .13901 Mdot
.988 .13925 Mdot
.988 .13932 Mdot
.988 .13941 Mdot
.988 .13948 Mdot
.988 .13953 Mdot
.988 .13968 Mdot
.988 .13968 Mdot
.988 .1397 Mdot
.988 .13972 Mdot
.988 .13984 Mdot
.988 .13986 Mdot
.988 .13986 Mdot
.988 .13993 Mdot
.988 .13996 Mdot
.988 .13996 Mdot
.988 .13997 Mdot
.988 .13998 Mdot
.988 .13998 Mdot
.988 .13999 Mdot
.988 .13999 Mdot
.988 .13999 Mdot
.988 .13999 Mdot
.988 .14 Mdot
.988 .14 Mdot
.988 .14 Mdot
.988 .14001 Mdot
.988 .14001 Mdot
.988 .14001 Mdot
.988 .14002 Mdot
.988 .14002 Mdot
.988 .14452 Mdot
.988 .14787 Mdot
.988 .15426 Mdot
.988 .15428 Mdot
.988 .15454 Mdot
.988 .15464 Mdot
.988 .15469 Mdot
.988 .15489 Mdot
.988 .15491 Mdot
.988 .15497 Mdot
.988 .15504 Mdot
.988 .15528 Mdot
.988 .15532 Mdot
.988 .15533 Mdot
.988 .1554 Mdot
.988 .1554 Mdot
.988 .15571 Mdot
.988 .15584 Mdot
.988 .156 Mdot
.988 .15605 Mdot
.988 .15623 Mdot
.988 .15623 Mdot
.988 .15626 Mdot
.988 .15681 Mdot
.988 .15715 Mdot
.988 .15719 Mdot
.988 .15748 Mdot
.988 .15758 Mdot
.988 .15805 Mdot
.988 .15817 Mdot
.988 .15861 Mdot
.988 .15914 Mdot
.988 .15915 Mdot
.988 .16004 Mdot
.988 .1605 Mdot
.988 .16091 Mdot
.988 .16092 Mdot
.988 .16119 Mdot
.988 .16153 Mdot
.988 .16163 Mdot
.988 .16174 Mdot
.988 .16227 Mdot
.988 .16228 Mdot
.988 .16234 Mdot
.988 .1627 Mdot
.988 .16281 Mdot
.988 .16283 Mdot
.988 .16284 Mdot
.988 .16288 Mdot
.988 .16294 Mdot
.988 .16319 Mdot
.988 .16368 Mdot
.988 .16399 Mdot
.988 .16399 Mdot
.988 .16436 Mdot
.988 .16446 Mdot
.988 .16448 Mdot
.988 .16467 Mdot
.988 .16471 Mdot
.988 .16475 Mdot
.988 .16486 Mdot
.988 .16505 Mdot
.988 .16521 Mdot
.988 .1653 Mdot
.988 .16533 Mdot
.988 .16549 Mdot
.988 .16565 Mdot
.988 .16574 Mdot
.988 .16578 Mdot
.988 .16582 Mdot
.988 .1671 Mdot
.988 .16723 Mdot
.988 .16928 Mdot
.988 .16999 Mdot
.988 .17165 Mdot
.988 .17247 Mdot
.988 .17259 Mdot
.988 .17297 Mdot
.988 .17403 Mdot
.988 .18158 Mdot
.988 .18172 Mdot
.988 .18706 Mdot
.988 .18757 Mdot
.988 .18827 Mdot
.988 .19142 Mdot
.988 .19373 Mdot
.988 .19447 Mdot
.988 .19547 Mdot
.988 .19557 Mdot
.988 .19958 Mdot
.988 .19991 Mdot
.988 .20111 Mdot
.988 .20203 Mdot
.988 .20277 Mdot
.988 .20356 Mdot
.988 .20418 Mdot
.988 .20424 Mdot
.988 .20448 Mdot
.988 .20675 Mdot
.988 .20737 Mdot
.988 .20765 Mdot
.988 .20854 Mdot
.988 .20955 Mdot
.988 .21092 Mdot
.988 .21319 Mdot
.988 .21332 Mdot
.988 .21501 Mdot
.988 .2195 Mdot
.988 .21954 Mdot
.988 .21984 Mdot
.988 .21986 Mdot
.988 .22016 Mdot
.988 .2206 Mdot
.988 .22062 Mdot
.988 .22067 Mdot
.988 .22079 Mdot
.988 .22096 Mdot
.988 .2211 Mdot
.988 .22119 Mdot
.988 .22121 Mdot
.988 .22146 Mdot
.988 .22155 Mdot
.988 .22207 Mdot
.988 .22239 Mdot
.988 .22257 Mdot
.988 .22342 Mdot
.988 .22396 Mdot
.988 .22481 Mdot
.988 .2249 Mdot
.988 .22648 Mdot
.988 .22725 Mdot
.988 .2273 Mdot
.988 .2274 Mdot
.988 .22856 Mdot
.988 .22868 Mdot
.988 .22868 Mdot
.988 .22984 Mdot
.988 .23011 Mdot
.988 .23248 Mdot
.988 .23295 Mdot
.988 .23428 Mdot
.988 .23549 Mdot
.988 .23624 Mdot
.988 .23648 Mdot
.988 .2378 Mdot
.988 .239 Mdot
.988 .23972 Mdot
.988 .24218 Mdot
.988 .24348 Mdot
.988 .24466 Mdot
.988 .24491 Mdot
.988 .24525 Mdot
.988 .24616 Mdot
.988 .24645 Mdot
.988 .24731 Mdot
.988 .24914 Mdot
.988 .25177 Mdot
.988 .25184 Mdot
.988 .25189 Mdot
.988 .25208 Mdot
.988 .25266 Mdot
.988 .25293 Mdot
.988 .25294 Mdot
.988 .25532 Mdot
.988 .25536 Mdot
.988 .25623 Mdot
.988 .25917 Mdot
.988 .26025 Mdot
.988 .26135 Mdot
.988 .26519 Mdot
.988 .26532 Mdot
.988 .26593 Mdot
.988 .26627 Mdot
.988 .26638 Mdot
.988 .26652 Mdot
.988 .26695 Mdot
.988 .26797 Mdot
.988 .26819 Mdot
.988 .26881 Mdot
.988 .26939 Mdot
.988 .26978 Mdot
.988 .27062 Mdot
.988 .27064 Mdot
.988 .27078 Mdot
.988 .27083 Mdot
.988 .27092 Mdot
.988 .27112 Mdot
.988 .27135 Mdot
.988 .2715 Mdot
.988 .27198 Mdot
.988 .27251 Mdot
.988 .27323 Mdot
.988 .27576 Mdot
.988 .27612 Mdot
.988 .27626 Mdot
.988 .27771 Mdot
.988 .27772 Mdot
.988 .27773 Mdot
.988 .27913 Mdot
.988 .2793 Mdot
.988 .27939 Mdot
.988 .27966 Mdot
.988 .27983 Mdot
.988 .27992 Mdot
.988 .28068 Mdot
.988 .28082 Mdot
.988 .28096 Mdot
.988 .28137 Mdot
.988 .28202 Mdot
.988 .28254 Mdot
.988 .28262 Mdot
.988 .28272 Mdot
.988 .28277 Mdot
.988 .28277 Mdot
.988 .28282 Mdot
.988 .28285 Mdot
.988 .2829 Mdot
.988 .28312 Mdot
.988 .28334 Mdot
.988 .2836 Mdot
.988 .28377 Mdot
.988 .28389 Mdot
.988 .28402 Mdot
.988 .28412 Mdot
.988 .2842 Mdot
.988 .28434 Mdot
.988 .28503 Mdot
.988 .28554 Mdot
.988 .2856 Mdot
.988 .28652 Mdot
.988 .28668 Mdot
.988 .28739 Mdot
.988 .28766 Mdot
.988 .28958 Mdot
.988 .29024 Mdot
.988 .29058 Mdot
.988 .29082 Mdot
.988 .29149 Mdot
.988 .29164 Mdot
.988 .29168 Mdot
.988 .29205 Mdot
.988 .29233 Mdot
.988 .29351 Mdot
.988 .29389 Mdot
.988 .2943 Mdot
.988 .29462 Mdot
.988 .2949 Mdot
.988 .2956 Mdot
.988 .29563 Mdot
.988 .2957 Mdot
.988 .29582 Mdot
.988 .29637 Mdot
.988 .29649 Mdot
.988 .2965 Mdot
.988 .29683 Mdot
.988 .29696 Mdot
.988 .29698 Mdot
.988 .29701 Mdot
.988 .29706 Mdot
.988 .29707 Mdot
.988 .29709 Mdot
.988 .29709 Mdot
.988 .2971 Mdot
.988 .29711 Mdot
.988 .29713 Mdot
.988 .29714 Mdot
.988 .29715 Mdot
.988 .29719 Mdot
.988 .29722 Mdot
.988 .29722 Mdot
.988 .29725 Mdot
.988 .29726 Mdot
.988 .31054 Mdot
.988 .3108 Mdot
.988 .31656 Mdot
.988 .31767 Mdot
.988 .32854 Mdot
.988 .33106 Mdot
.988 .33206 Mdot
.988 .33297 Mdot
.988 .33428 Mdot
.988 .33753 Mdot
.988 .33754 Mdot
.988 .33754 Mdot
.988 .33757 Mdot
.988 .3376 Mdot
.988 .33774 Mdot
.988 .33804 Mdot
.988 .33824 Mdot
.988 .3385 Mdot
.988 .33858 Mdot
.988 .33859 Mdot
.988 .33874 Mdot
.988 .33877 Mdot
.988 .33881 Mdot
.988 .33938 Mdot
.988 .34027 Mdot
.988 .34177 Mdot
.988 .34201 Mdot
.988 .34212 Mdot
.988 .34318 Mdot
.988 .34401 Mdot
.988 .34422 Mdot
.988 .34502 Mdot
.988 .34524 Mdot
.988 .34548 Mdot
.988 .34688 Mdot
.988 .34831 Mdot
.988 .35121 Mdot
.988 .35144 Mdot
.988 .35149 Mdot
.988 .35155 Mdot
.988 .3522 Mdot
.988 .35223 Mdot
.988 .35248 Mdot
.988 .35262 Mdot
.988 .35294 Mdot
.988 .35312 Mdot
.988 .35316 Mdot
.988 .35332 Mdot
.988 .3535 Mdot
.988 .35402 Mdot
.988 .35409 Mdot
.988 .35418 Mdot
.988 .3542 Mdot
.988 .35423 Mdot
.988 .35436 Mdot
.988 .35436 Mdot
.988 .35511 Mdot
.988 .35541 Mdot
.988 .35578 Mdot
.988 .3559 Mdot
.988 .35618 Mdot
.988 .35631 Mdot
.988 .35633 Mdot
.988 .35638 Mdot
.988 .3576 Mdot
.988 .35831 Mdot
.988 .35839 Mdot
.988 .35875 Mdot
.988 .35901 Mdot
.988 .35909 Mdot
.988 .35919 Mdot
.988 .35921 Mdot
.988 .36004 Mdot
.988 .3601 Mdot
.988 .36013 Mdot
.988 .36036 Mdot
.988 .36044 Mdot
.988 .36063 Mdot
.988 .36099 Mdot
.988 .36117 Mdot
.988 .36211 Mdot
.988 .36212 Mdot
.988 .36227 Mdot
.988 .36235 Mdot
.988 .36249 Mdot
.988 .36286 Mdot
.988 .36339 Mdot
.988 .36358 Mdot
.988 .36383 Mdot
.988 .36408 Mdot
.988 .36411 Mdot
.988 .36414 Mdot
.988 .36427 Mdot
.988 .36485 Mdot
.988 .36485 Mdot
.988 .36487 Mdot
.988 .36494 Mdot
.988 .36524 Mdot
.988 .36524 Mdot
.988 .36569 Mdot
.988 .36582 Mdot
.988 .36595 Mdot
.988 .36645 Mdot
.988 .36657 Mdot
.988 .36659 Mdot
.988 .36661 Mdot
.988 .36666 Mdot
.988 .36692 Mdot
.988 .36705 Mdot
.988 .36717 Mdot
.988 .36719 Mdot
.988 .3672 Mdot
.988 .36724 Mdot
.988 .3673 Mdot
.988 .36756 Mdot
.988 .36795 Mdot
.988 .36801 Mdot
.988 .36828 Mdot
.988 .36828 Mdot
.988 .36852 Mdot
.988 .36855 Mdot
.988 .36857 Mdot
.988 .36865 Mdot
.988 .36866 Mdot
.988 .3688 Mdot
.988 .36883 Mdot
.988 .36886 Mdot
.988 .36893 Mdot
.988 .36906 Mdot
.988 .36916 Mdot
.988 .36918 Mdot
.988 .36921 Mdot
.988 .36922 Mdot
.988 .36923 Mdot
.988 .36932 Mdot
.988 .36938 Mdot
.988 .36941 Mdot
.988 .36944 Mdot
.988 .36947 Mdot
.988 .36949 Mdot
.988 .3695 Mdot
.988 .36953 Mdot
.988 .36968 Mdot
.988 .3698 Mdot
.988 .37003 Mdot
.988 .37006 Mdot
.988 .37024 Mdot
.988 .37031 Mdot
.988 .37148 Mdot
.988 .3734 Mdot
.988 .3765 Mdot
.988 .37685 Mdot
.988 .38296 Mdot
.988 .38605 Mdot
.988 .38626 Mdot
.988 .38669 Mdot
.988 .39159 Mdot
.988 .3921 Mdot
.988 .3921 Mdot
.988 .39618 Mdot
.988 .39719 Mdot
.988 .39837 Mdot
.988 .40173 Mdot
.988 .40935 Mdot
.988 .41161 Mdot
.988 .41812 Mdot
.988 .42006 Mdot
.988 .42419 Mdot
.988 .42801 Mdot
.988 .42924 Mdot
.988 .4361 Mdot
.988 .44128 Mdot
.988 .44237 Mdot
.988 .44617 Mdot
.988 .45162 Mdot
.988 .45933 Mdot
.988 .46634 Mdot
.988 .4727 Mdot
.988 .47405 Mdot
.988 .47589 Mdot
.988 .48075 Mdot
.988 .48231 Mdot
.988 .48658 Mdot
.988 .48692 Mdot
.988 .49656 Mdot
.988 .49847 Mdot
.988 .51011 Mdot
.988 .51047 Mdot
.988 .51072 Mdot
.988 .51165 Mdot
.988 .51459 Mdot
.988 .51591 Mdot
.988 .51597 Mdot
.988 .52746 Mdot
.988 .52767 Mdot
.988 .5317 Mdot
.988 .53576 Mdot
.988 .54467 Mdot
.988 .54917 Mdot
.988 .55011 Mdot
.988 .55353 Mdot
.988 .55475 Mdot
.988 .55856 Mdot
.988 .56367 Mdot
.988 .56368 Mdot
.988 .56375 Mdot
.988 .56379 Mdot
.988 .5638 Mdot
.988 .56382 Mdot
.988 .56386 Mdot
.988 .56393 Mdot
.988 .56394 Mdot
.988 .56395 Mdot
.988 .564 Mdot
.988 .56401 Mdot
.988 .56403 Mdot
.988 .56413 Mdot
.988 .56413 Mdot
.988 .56421 Mdot
.988 .56434 Mdot
.988 .56441 Mdot
.988 .56442 Mdot
.988 .56444 Mdot
.988 .56444 Mdot
.988 .56444 Mdot
.988 .56448 Mdot
.988 .56458 Mdot
.988 .56502 Mdot
.988 .56515 Mdot
.988 .56531 Mdot
.988 .56635 Mdot
.988 .56701 Mdot
.988 .56729 Mdot
.988 .56738 Mdot
.988 .56762 Mdot
.988 .56762 Mdot
.988 .56769 Mdot
.988 .56857 Mdot
.988 .56966 Mdot
.988 .56986 Mdot
.988 .5707 Mdot
.988 .57077 Mdot
.988 .57103 Mdot
.988 .57105 Mdot
.988 .57112 Mdot
.988 .57119 Mdot
.988 .57143 Mdot
.988 .57147 Mdot
.988 .572 Mdot
.988 .57204 Mdot
.988 .57216 Mdot
.988 .57217 Mdot
.988 .57236 Mdot
.988 .57253 Mdot
.988 .57272 Mdot
.988 .57274 Mdot
.988 .57295 Mdot
.988 .57318 Mdot
.988 .57324 Mdot
.988 .57344 Mdot
.988 .57368 Mdot
.988 .57368 Mdot
.988 .57438 Mdot
.988 .57448 Mdot
.988 .5746 Mdot
.988 .57463 Mdot
.988 .57467 Mdot
.988 .57485 Mdot
.988 .57485 Mdot
.988 .57565 Mdot
.988 .57588 Mdot
.988 .57627 Mdot
.988 .57631 Mdot
.988 .57683 Mdot
.988 .577 Mdot
.988 .57739 Mdot
.988 .57757 Mdot
.988 .5776 Mdot
.988 .57768 Mdot
.988 .57791 Mdot
.988 .5794 Mdot
.988 .57943 Mdot
.988 .58036 Mdot
.988 .58045 Mdot
.988 .58057 Mdot
.988 .58108 Mdot
.988 .58145 Mdot
.988 .58156 Mdot
.988 .58171 Mdot
.988 .58173 Mdot
.988 .58233 Mdot
.988 .58238 Mdot
.988 .58269 Mdot
.988 .5828 Mdot
.988 .58291 Mdot
.988 .583 Mdot
.988 .58301 Mdot
.988 .58304 Mdot
.988 .58337 Mdot
.988 .58345 Mdot
.988 .58349 Mdot
.988 .58376 Mdot
.988 .58395 Mdot
.988 .58425 Mdot
.988 .58427 Mdot
.988 .5845 Mdot
.988 .5851 Mdot
.988 .58511 Mdot
.988 .58515 Mdot
.988 .58515 Mdot
.988 .58519 Mdot
.988 .58525 Mdot
.988 .58525 Mdot
.988 .58526 Mdot
.988 .58527 Mdot
.988 .58529 Mdot
.988 .58531 Mdot
.988 .58532 Mdot
.988 .58533 Mdot
.988 .58536 Mdot
.988 .58537 Mdot
.988 .58544 Mdot
.988 .58548 Mdot
.988 .58551 Mdot
.988 .58562 Mdot
.988 .58569 Mdot
.988 .5858 Mdot
.988 .58581 Mdot
.988 .58602 Mdot
.988 .58612 Mdot
.988 .58612 Mdot
.988 .58614 Mdot
.988 .58629 Mdot
.988 .5863 Mdot
.988 .5863 Mdot
.988 .58645 Mdot
.988 .58679 Mdot
.988 .58686 Mdot
.988 .58703 Mdot
.988 .58718 Mdot
.988 .58728 Mdot
.988 .58731 Mdot
.988 .58748 Mdot
.988 .58764 Mdot
.988 .58773 Mdot
.988 .58805 Mdot
.988 .58822 Mdot
.988 .58837 Mdot
.988 .5884 Mdot
.988 .58845 Mdot
.988 .58857 Mdot
.988 .5886 Mdot
.988 .58896 Mdot
.988 .58931 Mdot
.988 .58932 Mdot
.988 .58934 Mdot
.988 .58942 Mdot
.988 .58946 Mdot
.988 .58977 Mdot
.988 .58978 Mdot
.988 .5899 Mdot
.988 .59029 Mdot
.988 .59044 Mdot
.988 .59059 Mdot
.988 .59114 Mdot
.988 .59123 Mdot
.988 .59128 Mdot
.988 .59129 Mdot
.988 .59131 Mdot
.988 .59137 Mdot
.988 .59152 Mdot
.988 .59155 Mdot
.988 .59164 Mdot
.988 .59172 Mdot
.988 .59178 Mdot
.988 .5919 Mdot
.988 .5919 Mdot
.988 .59192 Mdot
.988 .59193 Mdot
.988 .59194 Mdot
.988 .59197 Mdot
.988 .59201 Mdot
.988 .59203 Mdot
.988 .5921 Mdot
.988 .59218 Mdot
.988 .59229 Mdot
.988 .59267 Mdot
.988 .59272 Mdot
.988 .59274 Mdot
.988 .59297 Mdot
.988 .59297 Mdot
.988 .59297 Mdot
.988 .59319 Mdot
.988 .59321 Mdot
.988 .59323 Mdot
.988 .59327 Mdot
.988 .5933 Mdot
.988 .59331 Mdot
.988 .59343 Mdot
.988 .59346 Mdot
.988 .59348 Mdot
.988 .59354 Mdot
.988 .59365 Mdot
.988 .59374 Mdot
.988 .59375 Mdot
.988 .59377 Mdot
.988 .59377 Mdot
.988 .59377 Mdot
.988 .59378 Mdot
.988 .59379 Mdot
.988 .59379 Mdot
.988 .59383 Mdot
.988 .59387 Mdot
.988 .59391 Mdot
.988 .59394 Mdot
.988 .59396 Mdot
.988 .59398 Mdot
.988 .594 Mdot
.988 .59401 Mdot
.988 .59403 Mdot
.988 .59415 Mdot
.988 .59424 Mdot
.988 .5944 Mdot
.988 .59443 Mdot
.988 .59456 Mdot
.988 .5946 Mdot
.988 .59495 Mdot
.988 .59507 Mdot
.988 .59513 Mdot
.988 .59518 Mdot
.988 .5953 Mdot
.988 .59533 Mdot
.988 .59534 Mdot
.988 .59541 Mdot
.988 .59546 Mdot
.988 .59569 Mdot
.988 .59576 Mdot
.988 .59584 Mdot
.988 .5959 Mdot
.988 .59596 Mdot
.988 .5961 Mdot
.988 .59611 Mdot
.988 .59612 Mdot
.988 .59615 Mdot
.988 .59626 Mdot
.988 .59629 Mdot
.988 .59629 Mdot
.988 .59636 Mdot
.988 .59638 Mdot
.988 .59639 Mdot
.988 .59639 Mdot
.988 .59641 Mdot
.988 .59641 Mdot
.988 .59641 Mdot
.988 .59641 Mdot
.988 .59641 Mdot
.988 .59642 Mdot
.988 .59642 Mdot
.988 .59642 Mdot
.988 .59642 Mdot
.988 .59643 Mdot
.988 .59644 Mdot
.988 .59644 Mdot
.988 .59645 Mdot
.988 .59645 Mdot
.99 .11159 Mdot
.99 .11159 Mdot
.99 .11159 Mdot
.99 .1116 Mdot
.99 .11162 Mdot
.99 .11163 Mdot
.99 .11196 Mdot
.99 .11211 Mdot
.99 .11211 Mdot
.99 .11241 Mdot
.99 .11249 Mdot
.99 .11255 Mdot
.99 .11256 Mdot
.99 .11257 Mdot
.99 .11274 Mdot
.99 .11288 Mdot
.99 .11295 Mdot
.99 .11304 Mdot
.99 .11305 Mdot
.99 .11307 Mdot
.99 .11308 Mdot
.99 .11309 Mdot
.99 .1131 Mdot
.99 .11311 Mdot
.99 .11312 Mdot
.99 .11313 Mdot
.99 .11317 Mdot
.99 .11318 Mdot
.99 .11335 Mdot
.99 .11335 Mdot
.99 .11337 Mdot
.99 .11338 Mdot
.99 .11339 Mdot
.99 .1134 Mdot
.99 .1134 Mdot
.99 .1134 Mdot
.99 .11342 Mdot
.99 .11342 Mdot
.99 .1138 Mdot
.99 .114 Mdot
.99 .11412 Mdot
.99 .11467 Mdot
.99 .11481 Mdot
.99 .11482 Mdot
.99 .11482 Mdot
.99 .11483 Mdot
.99 .11483 Mdot
.99 .11484 Mdot
.99 .11488 Mdot
.99 .11491 Mdot
.99 .11495 Mdot
.99 .11496 Mdot
.99 .11503 Mdot
.99 .11504 Mdot
.99 .11505 Mdot
.99 .11508 Mdot
.99 .1151 Mdot
.99 .11519 Mdot
.99 .11526 Mdot
.99 .11539 Mdot
.99 .11539 Mdot
.99 .11547 Mdot
.99 .11555 Mdot
.99 .11589 Mdot
.99 .11596 Mdot
.99 .11657 Mdot
.99 .11666 Mdot
.99 .11667 Mdot
.99 .11683 Mdot
.99 .11687 Mdot
.99 .1169 Mdot
.99 .11706 Mdot
.99 .1179 Mdot
.99 .11795 Mdot
.99 .11826 Mdot
.99 .1183 Mdot
.99 .11838 Mdot
.99 .11863 Mdot
.99 .11871 Mdot
.99 .1188 Mdot
.99 .11912 Mdot
.99 .11944 Mdot
.99 .12045 Mdot
.99 .12064 Mdot
.99 .1211 Mdot
.99 .12185 Mdot
.99 .12195 Mdot
.99 .12228 Mdot
.99 .12286 Mdot
.99 .12295 Mdot
.99 .12296 Mdot
.99 .12326 Mdot
.99 .12397 Mdot
.99 .12452 Mdot
.99 .12537 Mdot
.99 .12537 Mdot
.99 .12538 Mdot
.99 .12538 Mdot
.99 .12538 Mdot
.99 .12538 Mdot
.99 .12539 Mdot
.99 .12539 Mdot
.99 .1254 Mdot
.99 .12542 Mdot
.99 .12544 Mdot
.99 .12558 Mdot
.99 .12559 Mdot
.99 .12563 Mdot
.99 .12563 Mdot
.99 .12569 Mdot
.99 .1257 Mdot
.99 .12574 Mdot
.99 .12584 Mdot
.99 .12592 Mdot
.99 .12628 Mdot
.99 .12639 Mdot
.99 .12656 Mdot
.99 .1267 Mdot
.99 .12747 Mdot
.99 .12761 Mdot
.99 .12779 Mdot
.99 .12779 Mdot
.99 .12787 Mdot
.99 .12857 Mdot
.99 .12857 Mdot
.99 .12865 Mdot
.99 .12887 Mdot
.99 .12888 Mdot
.99 .12946 Mdot
.99 .12959 Mdot
.99 .12969 Mdot
.99 .1298 Mdot
.99 .12997 Mdot
.99 .13082 Mdot
.99 .13097 Mdot
.99 .13114 Mdot
.99 .13124 Mdot
.99 .13159 Mdot
.99 .13166 Mdot
.99 .13179 Mdot
.99 .13182 Mdot
.99 .13189 Mdot
.99 .13192 Mdot
.99 .13201 Mdot
.99 .13206 Mdot
.99 .1321 Mdot
.99 .13214 Mdot
.99 .13225 Mdot
.99 .13239 Mdot
.99 .13253 Mdot
.99 .1327 Mdot
.99 .13272 Mdot
.99 .1328 Mdot
.99 .1331 Mdot
.99 .13318 Mdot
.99 .13329 Mdot
.99 .13347 Mdot
.99 .13369 Mdot
.99 .13369 Mdot
.99 .13399 Mdot
.99 .13402 Mdot
.99 .13424 Mdot
.99 .13425 Mdot
.99 .13425 Mdot
.99 .13449 Mdot
.99 .13456 Mdot
.99 .13481 Mdot
.99 .13485 Mdot
.99 .13498 Mdot
.99 .135 Mdot
.99 .13508 Mdot
.99 .13515 Mdot
.99 .13524 Mdot
.99 .13536 Mdot
.99 .13538 Mdot
.99 .13543 Mdot
.99 .13546 Mdot
.99 .13569 Mdot
.99 .13574 Mdot
.99 .13574 Mdot
.99 .13584 Mdot
.99 .13584 Mdot
.99 .13614 Mdot
.99 .13631 Mdot
.99 .13633 Mdot
.99 .1366 Mdot
.99 .13673 Mdot
.99 .13688 Mdot
.99 .13688 Mdot
.99 .13699 Mdot
.99 .137 Mdot
.99 .13701 Mdot
.99 .13706 Mdot
.99 .13709 Mdot
.99 .13712 Mdot
.99 .13716 Mdot
.99 .13717 Mdot
.99 .1372 Mdot
.99 .13727 Mdot
.99 .13727 Mdot
.99 .13731 Mdot
.99 .13753 Mdot
.99 .1377 Mdot
.99 .13773 Mdot
.99 .13794 Mdot
.99 .13799 Mdot
.99 .13872 Mdot
.99 .13878 Mdot
.99 .13881 Mdot
.99 .13898 Mdot
.99 .13908 Mdot
.99 .13923 Mdot
.99 .13927 Mdot
.99 .13928 Mdot
.99 .1394 Mdot
.99 .1395 Mdot
.99 .13963 Mdot
.99 .13971 Mdot
.99 .13974 Mdot
.99 .13982 Mdot
.99 .13983 Mdot
.99 .13994 Mdot
.99 .13998 Mdot
.99 .14003 Mdot
.99 .14004 Mdot
.99 .14004 Mdot
.99 .14004 Mdot
.99 .14005 Mdot
.99 .14005 Mdot
.99 .14005 Mdot
.99 .14006 Mdot
.99 .14007 Mdot
.99 .14007 Mdot
.99 .14008 Mdot
.99 .14008 Mdot
.99 .14008 Mdot
.99 .14008 Mdot
.99 .14008 Mdot
.99 .14008 Mdot
.99 .14008 Mdot
.99 .14008 Mdot
.99 .14008 Mdot
.99 .14017 Mdot
.99 .14022 Mdot
.99 .14072 Mdot
.99 .14076 Mdot
.99 .1408 Mdot
.99 .14087 Mdot
.99 .14108 Mdot
.99 .14109 Mdot
.99 .14119 Mdot
.99 .14127 Mdot
.99 .14127 Mdot
.99 .1413 Mdot
.99 .14133 Mdot
.99 .14133 Mdot
.99 .14134 Mdot
.99 .14134 Mdot
.99 .14135 Mdot
.99 .14135 Mdot
.99 .14136 Mdot
.99 .14136 Mdot
.99 .14136 Mdot
.99 .14137 Mdot
.99 .14137 Mdot
.99 .1415 Mdot
.99 .14268 Mdot
.99 .15531 Mdot
.99 .15532 Mdot
.99 .15533 Mdot
.99 .15538 Mdot
.99 .15545 Mdot
.99 .15547 Mdot
.99 .15613 Mdot
.99 .15678 Mdot
.99 .15738 Mdot
.99 .15741 Mdot
.99 .15858 Mdot
.99 .15891 Mdot
.99 .15916 Mdot
.99 .15923 Mdot
.99 .15926 Mdot
.99 .15994 Mdot
.99 .16051 Mdot
.99 .16081 Mdot
.99 .1612 Mdot
.99 .16122 Mdot
.99 .1613 Mdot
.99 .16134 Mdot
.99 .16138 Mdot
.99 .16143 Mdot
.99 .16149 Mdot
.99 .1615 Mdot
.99 .16154 Mdot
.99 .1617 Mdot
.99 .16176 Mdot
.99 .16245 Mdot
.99 .16245 Mdot
.99 .16255 Mdot
.99 .16261 Mdot
.99 .16264 Mdot
.99 .16266 Mdot
.99 .16267 Mdot
.99 .1627 Mdot
.99 .16275 Mdot
.99 .16276 Mdot
.99 .16438 Mdot
.99 .16522 Mdot
.99 .16572 Mdot
.99 .16815 Mdot
.99 .16873 Mdot
.99 .16878 Mdot
.99 .1688 Mdot
.99 .16881 Mdot
.99 .16884 Mdot
.99 .16888 Mdot
.99 .16905 Mdot
.99 .16919 Mdot
.99 .16937 Mdot
.99 .16942 Mdot
.99 .1697 Mdot
.99 .16977 Mdot
.99 .16978 Mdot
.99 .16987 Mdot
.99 .16992 Mdot
.99 .17004 Mdot
.99 .17044 Mdot
.99 .17073 Mdot
.99 .17132 Mdot
.99 .17132 Mdot
.99 .17165 Mdot
.99 .17204 Mdot
.99 .17359 Mdot
.99 .17388 Mdot
.99 .17667 Mdot
.99 .17711 Mdot
.99 .17714 Mdot
.99 .17789 Mdot
.99 .17808 Mdot
.99 .17821 Mdot
.99 .17893 Mdot
.99 .18291 Mdot
.99 .18315 Mdot
.99 .18455 Mdot
.99 .18466 Mdot
.99 .18484 Mdot
.99 .18522 Mdot
.99 .18642 Mdot
.99 .18683 Mdot
.99 .18726 Mdot
.99 .18881 Mdot
.99 .19037 Mdot
.99 .1954 Mdot
.99 .19637 Mdot
.99 .19715 Mdot
.99 .1987 Mdot
.99 .20217 Mdot
.99 .20249 Mdot
.99 .203 Mdot
.99 .20474 Mdot
.99 .20775 Mdot
.99 .20802 Mdot
.99 .20817 Mdot
.99 .20826 Mdot
.99 .20979 Mdot
.99 .21352 Mdot
.99 .21354 Mdot
.99 .21644 Mdot
.99 .22093 Mdot
.99 .22097 Mdot
.99 .22099 Mdot
.99 .22099 Mdot
.99 .22101 Mdot
.99 .22102 Mdot
.99 .22103 Mdot
.99 .22105 Mdot
.99 .22111 Mdot
.99 .22123 Mdot
.99 .22133 Mdot
.99 .22208 Mdot
.99 .22215 Mdot
.99 .22232 Mdot
.99 .22233 Mdot
.99 .22268 Mdot
.99 .22273 Mdot
.99 .22292 Mdot
.99 .22347 Mdot
.99 .22386 Mdot
.99 .22569 Mdot
.99 .22583 Mdot
.99 .22642 Mdot
.99 .22734 Mdot
.99 .22808 Mdot
.99 .22907 Mdot
.99 .23223 Mdot
.99 .23294 Mdot
.99 .23392 Mdot
.99 .23395 Mdot
.99 .23435 Mdot
.99 .23812 Mdot
.99 .23813 Mdot
.99 .23857 Mdot
.99 .23953 Mdot
.99 .23976 Mdot
.99 .23979 Mdot
.99 .24296 Mdot
.99 .24312 Mdot
.99 .24364 Mdot
.99 .24418 Mdot
.99 .24479 Mdot
.99 .24569 Mdot
.99 .25031 Mdot
.99 .25109 Mdot
.99 .25202 Mdot
.99 .25254 Mdot
.99 .25444 Mdot
.99 .25479 Mdot
.99 .2555 Mdot
.99 .25564 Mdot
.99 .25606 Mdot
.99 .2562 Mdot
.99 .2567 Mdot
.99 .25693 Mdot
.99 .25718 Mdot
.99 .2574 Mdot
.99 .25798 Mdot
.99 .25871 Mdot
.99 .25948 Mdot
.99 .26037 Mdot
.99 .26046 Mdot
.99 .26091 Mdot
.99 .26132 Mdot
.99 .26249 Mdot
.99 .26294 Mdot
.99 .26353 Mdot
.99 .26448 Mdot
.99 .26562 Mdot
.99 .26564 Mdot
.99 .2672 Mdot
.99 .26739 Mdot
.99 .26852 Mdot
.99 .26859 Mdot
.99 .2686 Mdot
.99 .26983 Mdot
.99 .27021 Mdot
.99 .27025 Mdot
.99 .27152 Mdot
.99 .27174 Mdot
.99 .27243 Mdot
.99 .27254 Mdot
.99 .27295 Mdot
.99 .27334 Mdot
.99 .27381 Mdot
.99 .27442 Mdot
.99 .27452 Mdot
.99 .27479 Mdot
.99 .27491 Mdot
.99 .27611 Mdot
.99 .27637 Mdot
.99 .27638 Mdot
.99 .27688 Mdot
.99 .27691 Mdot
.99 .27844 Mdot
.99 .27931 Mdot
.99 .27944 Mdot
.99 .28079 Mdot
.99 .28145 Mdot
.99 .28224 Mdot
.99 .28225 Mdot
.99 .28281 Mdot
.99 .28284 Mdot
.99 .28293 Mdot
.99 .28316 Mdot
.99 .28329 Mdot
.99 .28347 Mdot
.99 .28365 Mdot
.99 .28371 Mdot
.99 .28389 Mdot
.99 .28421 Mdot
.99 .28423 Mdot
.99 .28445 Mdot
.99 .28555 Mdot
.99 .28638 Mdot
.99 .28657 Mdot
.99 .28758 Mdot
.99 .28786 Mdot
.99 .29148 Mdot
.99 .29179 Mdot
.99 .29194 Mdot
.99 .29278 Mdot
.99 .29327 Mdot
.99 .29398 Mdot
.99 .29416 Mdot
.99 .29421 Mdot
.99 .29482 Mdot
.99 .29529 Mdot
.99 .29595 Mdot
.99 .29632 Mdot
.99 .29648 Mdot
.99 .29688 Mdot
.99 .29688 Mdot
.99 .29743 Mdot
.99 .29764 Mdot
.99 .29786 Mdot
.99 .29792 Mdot
.99 .29793 Mdot
.99 .29794 Mdot
.99 .29797 Mdot
.99 .29797 Mdot
.99 .29799 Mdot
.99 .298 Mdot
.99 .29807 Mdot
.99 .29807 Mdot
.99 .29809 Mdot
.99 .29809 Mdot
.99 .29809 Mdot
.99 .29809 Mdot
.99 .2981 Mdot
.99 .2981 Mdot
.99 .2981 Mdot
.99 .2981 Mdot
.99 .2981 Mdot
.99 .29853 Mdot
.99 .2988 Mdot
.99 .30118 Mdot
.99 .30135 Mdot
.99 .30154 Mdot
.99 .30185 Mdot
.99 .30284 Mdot
.99 .30291 Mdot
.99 .30337 Mdot
.99 .30374 Mdot
.99 .30389 Mdot
.99 .30401 Mdot
.99 .30402 Mdot
.99 .30408 Mdot
.99 .30409 Mdot
.99 .30412 Mdot
.99 .30414 Mdot
.99 .30417 Mdot
.99 .30418 Mdot
.99 .30419 Mdot
.99 .30419 Mdot
.99 .3042 Mdot
.99 .3048 Mdot
.99 .31023 Mdot
.99 .31553 Mdot
.99 .32633 Mdot
.99 .33822 Mdot
.99 .33826 Mdot
.99 .3383 Mdot
.99 .33836 Mdot
.99 .3384 Mdot
.99 .33861 Mdot
.99 .33947 Mdot
.99 .33965 Mdot
.99 .33976 Mdot
.99 .33982 Mdot
.99 .33999 Mdot
.99 .34117 Mdot
.99 .34119 Mdot
.99 .34189 Mdot
.99 .34284 Mdot
.99 .34306 Mdot
.99 .34324 Mdot
.99 .34331 Mdot
.99 .34391 Mdot
.99 .34485 Mdot
.99 .34493 Mdot
.99 .34511 Mdot
.99 .34625 Mdot
.99 .34627 Mdot
.99 .34845 Mdot
.99 .34896 Mdot
.99 .35112 Mdot
.99 .35202 Mdot
.99 .35253 Mdot
.99 .35334 Mdot
.99 .35395 Mdot
.99 .35454 Mdot
.99 .35467 Mdot
.99 .35485 Mdot
.99 .35487 Mdot
.99 .35489 Mdot
.99 .35501 Mdot
.99 .35517 Mdot
.99 .35523 Mdot
.99 .35553 Mdot
.99 .35626 Mdot
.99 .35679 Mdot
.99 .35682 Mdot
.99 .35708 Mdot
.99 .35722 Mdot
.99 .35727 Mdot
.99 .35824 Mdot
.99 .3592 Mdot
.99 .3595 Mdot
.99 .35954 Mdot
.99 .35954 Mdot
.99 .35969 Mdot
.99 .36181 Mdot
.99 .36188 Mdot
.99 .36201 Mdot
.99 .36242 Mdot
.99 .36284 Mdot
.99 .36296 Mdot
.99 .36302 Mdot
.99 .36375 Mdot
.99 .364 Mdot
.99 .36411 Mdot
.99 .36412 Mdot
.99 .36417 Mdot
.99 .36418 Mdot
.99 .36424 Mdot
.99 .36426 Mdot
.99 .36431 Mdot
.99 .36437 Mdot
.99 .36445 Mdot
.99 .36454 Mdot
.99 .36464 Mdot
.99 .36492 Mdot
.99 .36499 Mdot
.99 .36524 Mdot
.99 .36542 Mdot
.99 .36545 Mdot
.99 .3656 Mdot
.99 .3658 Mdot
.99 .36596 Mdot
.99 .36599 Mdot
.99 .3661 Mdot
.99 .36615 Mdot
.99 .3662 Mdot
.99 .36626 Mdot
.99 .36634 Mdot
.99 .36636 Mdot
.99 .36641 Mdot
.99 .36658 Mdot
.99 .36661 Mdot
.99 .36662 Mdot
.99 .36669 Mdot
.99 .36704 Mdot
.99 .3675 Mdot
.99 .3675 Mdot
.99 .36761 Mdot
.99 .36765 Mdot
.99 .36767 Mdot
.99 .3677 Mdot
.99 .36773 Mdot
.99 .36774 Mdot
.99 .36777 Mdot
.99 .36782 Mdot
.99 .36783 Mdot
.99 .36787 Mdot
.99 .36806 Mdot
.99 .36843 Mdot
.99 .36849 Mdot
.99 .3693 Mdot
.99 .36934 Mdot
.99 .36953 Mdot
.99 .36965 Mdot
.99 .36983 Mdot
.99 .36989 Mdot
.99 .37017 Mdot
.99 .37036 Mdot
.99 .37047 Mdot
.99 .37052 Mdot
.99 .37064 Mdot
.99 .37064 Mdot
.99 .37081 Mdot
.99 .37088 Mdot
.99 .37095 Mdot
.99 .37097 Mdot
.99 .37097 Mdot
.99 .37098 Mdot
.99 .37099 Mdot
.99 .37099 Mdot
.99 .371 Mdot
.99 .37102 Mdot
.99 .37102 Mdot
.99 .37103 Mdot
.99 .37103 Mdot
.99 .37103 Mdot
.99 .37103 Mdot
.99 .37103 Mdot
.99 .37103 Mdot
.99 .37103 Mdot
.99 .37103 Mdot
.99 .37238 Mdot
.99 .37377 Mdot
.99 .38057 Mdot
.99 .38112 Mdot
.99 .38344 Mdot
.99 .38718 Mdot
.99 .39028 Mdot
.99 .39456 Mdot
.99 .40898 Mdot
.99 .4124 Mdot
.99 .41718 Mdot
.99 .41731 Mdot
.99 .4193 Mdot
.99 .43858 Mdot
.99 .43863 Mdot
.99 .44095 Mdot
.99 .44602 Mdot
.99 .44619 Mdot
.99 .44726 Mdot
.99 .44745 Mdot
.99 .45684 Mdot
.99 .45753 Mdot
.99 .46444 Mdot
.99 .46534 Mdot
.99 .46811 Mdot
.99 .47104 Mdot
.99 .47434 Mdot
.99 .47918 Mdot
.99 .4833 Mdot
.99 .50138 Mdot
.99 .50362 Mdot
.99 .50766 Mdot
.99 .51238 Mdot
.99 .51498 Mdot
.99 .5243 Mdot
.99 .52598 Mdot
.99 .52936 Mdot
.99 .53003 Mdot
.99 .53197 Mdot
.99 .5326 Mdot
.99 .53489 Mdot
.99 .53594 Mdot
.99 .53707 Mdot
.99 .53806 Mdot
.99 .54061 Mdot
.99 .54379 Mdot
.99 .54706 Mdot
.99 .55073 Mdot
.99 .55108 Mdot
.99 .55288 Mdot
.99 .5545 Mdot
.99 .55896 Mdot
.99 .5606 Mdot
.99 .56276 Mdot
.99 .56479 Mdot
.99 .56479 Mdot
.99 .56481 Mdot
.99 .56483 Mdot
.99 .56484 Mdot
.99 .56485 Mdot
.99 .56488 Mdot
.99 .56488 Mdot
.99 .5651 Mdot
.99 .56512 Mdot
.99 .56518 Mdot
.99 .56519 Mdot
.99 .56519 Mdot
.99 .56522 Mdot
.99 .56523 Mdot
.99 .56525 Mdot
.99 .56526 Mdot
.99 .56529 Mdot
.99 .56529 Mdot
.99 .56543 Mdot
.99 .56554 Mdot
.99 .56603 Mdot
.99 .56605 Mdot
.99 .56608 Mdot
.99 .56619 Mdot
.99 .56696 Mdot
.99 .56698 Mdot
.99 .56887 Mdot
.99 .56905 Mdot
.99 .56939 Mdot
.99 .5698 Mdot
.99 .56985 Mdot
.99 .5703 Mdot
.99 .5718 Mdot
.99 .5729 Mdot
.99 .57355 Mdot
.99 .5746 Mdot
.99 .5746 Mdot
.99 .57516 Mdot
.99 .57542 Mdot
.99 .57557 Mdot
.99 .57624 Mdot
.99 .57639 Mdot
.99 .5764 Mdot
.99 .57641 Mdot
.99 .57641 Mdot
.99 .57642 Mdot
.99 .57643 Mdot
.99 .57647 Mdot
.99 .57651 Mdot
.99 .57655 Mdot
.99 .57656 Mdot
.99 .57663 Mdot
.99 .57665 Mdot
.99 .57665 Mdot
.99 .57669 Mdot
.99 .57672 Mdot
.99 .57682 Mdot
.99 .57689 Mdot
.99 .57703 Mdot
.99 .5771 Mdot
.99 .57719 Mdot
.99 .57754 Mdot
.99 .57761 Mdot
.99 .5782 Mdot
.99 .57829 Mdot
.99 .5783 Mdot
.99 .57845 Mdot
.99 .57848 Mdot
.99 .57851 Mdot
.99 .57865 Mdot
.99 .5794 Mdot
.99 .57944 Mdot
.99 .57971 Mdot
.99 .57981 Mdot
.99 .58002 Mdot
.99 .58009 Mdot
.99 .58016 Mdot
.99 .58043 Mdot
.99 .58068 Mdot
.99 .58148 Mdot
.99 .58163 Mdot
.99 .58254 Mdot
.99 .58262 Mdot
.99 .58287 Mdot
.99 .58329 Mdot
.99 .58335 Mdot
.99 .58336 Mdot
.99 .58358 Mdot
.99 .58409 Mdot
.99 .58448 Mdot
.99 .58508 Mdot
.99 .58508 Mdot
.99 .58509 Mdot
.99 .58509 Mdot
.99 .58509 Mdot
.99 .58509 Mdot
.99 .58509 Mdot
.99 .58509 Mdot
.99 .5851 Mdot
.99 .58512 Mdot
.99 .58513 Mdot
.99 .58523 Mdot
.99 .58524 Mdot
.99 .58526 Mdot
.99 .58526 Mdot
.99 .58531 Mdot
.99 .58531 Mdot
.99 .58534 Mdot
.99 .58541 Mdot
.99 .58546 Mdot
.99 .58572 Mdot
.99 .5858 Mdot
.99 .58592 Mdot
.99 .58601 Mdot
.99 .58655 Mdot
.99 .58664 Mdot
.99 .58677 Mdot
.99 .58677 Mdot
.99 .58682 Mdot
.99 .58731 Mdot
.99 .58731 Mdot
.99 .58736 Mdot
.99 .58752 Mdot
.99 .58752 Mdot
.99 .58793 Mdot
.99 .58802 Mdot
.99 .58809 Mdot
.99 .58816 Mdot
.99 .58828 Mdot
.99 .58888 Mdot
.99 .58898 Mdot
.99 .58911 Mdot
.99 .58942 Mdot
.99 .58947 Mdot
.99 .58956 Mdot
.99 .58958 Mdot
.99 .58964 Mdot
.99 .58966 Mdot
.99 .58972 Mdot
.99 .58975 Mdot
.99 .58979 Mdot
.99 .58982 Mdot
.99 .58989 Mdot
.99 .58999 Mdot
.99 .5901 Mdot
.99 .59022 Mdot
.99 .59023 Mdot
.99 .59029 Mdot
.99 .5905 Mdot
.99 .59057 Mdot
.99 .59065 Mdot
.99 .59078 Mdot
.99 .59094 Mdot
.99 .59094 Mdot
.99 .59116 Mdot
.99 .59118 Mdot
.99 .59134 Mdot
.99 .59135 Mdot
.99 .59135 Mdot
.99 .59153 Mdot
.99 .59159 Mdot
.99 .59177 Mdot
.99 .5918 Mdot
.99 .5919 Mdot
.99 .59192 Mdot
.99 .59198 Mdot
.99 .59204 Mdot
.99 .5921 Mdot
.99 .59219 Mdot
.99 .59221 Mdot
.99 .59225 Mdot
.99 .59227 Mdot
.99 .59245 Mdot
.99 .59249 Mdot
.99 .59249 Mdot
.99 .59256 Mdot
.99 .5928 Mdot
.99 .59294 Mdot
.99 .59296 Mdot
.99 .59317 Mdot
.99 .59327 Mdot
.99 .5934 Mdot
.99 .5934 Mdot
.99 .59349 Mdot
.99 .59349 Mdot
.99 .59351 Mdot
.99 .59354 Mdot
.99 .59356 Mdot
.99 .59359 Mdot
.99 .59362 Mdot
.99 .59363 Mdot
.99 .59366 Mdot
.99 .59371 Mdot
.99 .59372 Mdot
.99 .59375 Mdot
.99 .59394 Mdot
.99 .59407 Mdot
.99 .59411 Mdot
.99 .59428 Mdot
.99 .59433 Mdot
.99 .59497 Mdot
.99 .59502 Mdot
.99 .59505 Mdot
.99 .5952 Mdot
.99 .5953 Mdot
.99 .59543 Mdot
.99 .59547 Mdot
.99 .59547 Mdot
.99 .59559 Mdot
.99 .59568 Mdot
.99 .59581 Mdot
.99 .59589 Mdot
.99 .59592 Mdot
.99 .596 Mdot
.99 .596 Mdot
.99 .59611 Mdot
.99 .59615 Mdot
.99 .5962 Mdot
.99 .59621 Mdot
.99 .59621 Mdot
.99 .59622 Mdot
.99 .59622 Mdot
.99 .59622 Mdot
.99 .59623 Mdot
.99 .59623 Mdot
.99 .59624 Mdot
.99 .59624 Mdot
.99 .59625 Mdot
.99 .59625 Mdot
.99 .59625 Mdot
.99 .59625 Mdot
.99 .59625 Mdot
.99 .59625 Mdot
.99 .59625 Mdot
.99 .59625 Mdot
.99 .59625 Mdot
.99 .59634 Mdot
.99 .5964 Mdot
.99 .59691 Mdot
.99 .59695 Mdot
.99 .59699 Mdot
.99 .59707 Mdot
.99 .5973 Mdot
.99 .59731 Mdot
.99 .59742 Mdot
.99 .59751 Mdot
.99 .59751 Mdot
.99 .59755 Mdot
.99 .59758 Mdot
.99 .59758 Mdot
.99 .59759 Mdot
.99 .5976 Mdot
.99 .5976 Mdot
.99 .59761 Mdot
.99 .59762 Mdot
.99 .59762 Mdot
.99 .59762 Mdot
.99 .59762 Mdot
.99 .59763 Mdot
.992 .11178 Mdot
.992 .1118 Mdot
.992 .1118 Mdot
.992 .11181 Mdot
.992 .11181 Mdot
.992 .11183 Mdot
.992 .11184 Mdot
.992 .11184 Mdot
.992 .11185 Mdot
.992 .11185 Mdot
.992 .11188 Mdot
.992 .11188 Mdot
.992 .11188 Mdot
.992 .11189 Mdot
.992 .11192 Mdot
.992 .11192 Mdot
.992 .11196 Mdot
.992 .11196 Mdot
.992 .11198 Mdot
.992 .11198 Mdot
.992 .11198 Mdot
.992 .11199 Mdot
.992 .112 Mdot
.992 .11206 Mdot
.992 .11209 Mdot
.992 .1121 Mdot
.992 .11219 Mdot
.992 .11219 Mdot
.992 .1122 Mdot
.992 .11222 Mdot
.992 .11225 Mdot
.992 .11235 Mdot
.992 .11236 Mdot
.992 .11239 Mdot
.992 .11246 Mdot
.992 .11255 Mdot
.992 .11255 Mdot
.992 .11256 Mdot
.992 .11259 Mdot
.992 .11259 Mdot
.992 .11263 Mdot
.992 .11266 Mdot
.992 .11268 Mdot
.992 .11268 Mdot
.992 .11271 Mdot
.992 .11271 Mdot
.992 .11271 Mdot
.992 .11271 Mdot
.992 .11272 Mdot
.992 .11273 Mdot
.992 .11274 Mdot
.992 .11274 Mdot
.992 .11276 Mdot
.992 .11277 Mdot
.992 .1128 Mdot
.992 .11281 Mdot
.992 .11282 Mdot
.992 .11285 Mdot
.992 .11286 Mdot
.992 .11286 Mdot
.992 .11286 Mdot
.992 .11286 Mdot
.992 .11328 Mdot
.992 .11334 Mdot
.992 .11335 Mdot
.992 .11341 Mdot
.992 .11343 Mdot
.992 .11387 Mdot
.992 .114 Mdot
.992 .1141 Mdot
.992 .11426 Mdot
.992 .11454 Mdot
.992 .11461 Mdot
.992 .11489 Mdot
.992 .11499 Mdot
.992 .11552 Mdot
.992 .11566 Mdot
.992 .11602 Mdot
.992 .11613 Mdot
.992 .11622 Mdot
.992 .11661 Mdot
.992 .11664 Mdot
.992 .11685 Mdot
.992 .11699 Mdot
.992 .11722 Mdot
.992 .11726 Mdot
.992 .11728 Mdot
.992 .11767 Mdot
.992 .11769 Mdot
.992 .11811 Mdot
.992 .11858 Mdot
.992 .1199 Mdot
.992 .12009 Mdot
.992 .12096 Mdot
.992 .12119 Mdot
.992 .12141 Mdot
.992 .12168 Mdot
.992 .12176 Mdot
.992 .12202 Mdot
.992 .1221 Mdot
.992 .12213 Mdot
.992 .12219 Mdot
.992 .12233 Mdot
.992 .12263 Mdot
.992 .12265 Mdot
.992 .12289 Mdot
.992 .12293 Mdot
.992 .12333 Mdot
.992 .12336 Mdot
.992 .12341 Mdot
.992 .12344 Mdot
.992 .12358 Mdot
.992 .12374 Mdot
.992 .12411 Mdot
.992 .12413 Mdot
.992 .12424 Mdot
.992 .12431 Mdot
.992 .12451 Mdot
.992 .12468 Mdot
.992 .12479 Mdot
.992 .12483 Mdot
.992 .12497 Mdot
.992 .1251 Mdot
.992 .12513 Mdot
.992 .12514 Mdot
.992 .12525 Mdot
.992 .12525 Mdot
.992 .12555 Mdot
.992 .12562 Mdot
.992 .12628 Mdot
.992 .12641 Mdot
.992 .12657 Mdot
.992 .12695 Mdot
.992 .12707 Mdot
.992 .12721 Mdot
.992 .12765 Mdot
.992 .128 Mdot
.992 .1281 Mdot
.992 .12829 Mdot
.992 .1283 Mdot
.992 .12859 Mdot
.992 .12861 Mdot
.992 .12862 Mdot
.992 .1287 Mdot
.992 .12901 Mdot
.992 .12919 Mdot
.992 .12947 Mdot
.992 .13018 Mdot
.992 .13044 Mdot
.992 .13069 Mdot
.992 .1307 Mdot
.992 .13079 Mdot
.992 .13102 Mdot
.992 .13113 Mdot
.992 .13149 Mdot
.992 .13198 Mdot
.992 .13222 Mdot
.992 .13229 Mdot
.992 .13239 Mdot
.992 .13248 Mdot
.992 .13268 Mdot
.992 .13285 Mdot
.992 .13287 Mdot
.992 .13306 Mdot
.992 .1334 Mdot
.992 .13342 Mdot
.992 .13348 Mdot
.992 .13356 Mdot
.992 .13357 Mdot
.992 .13358 Mdot
.992 .13361 Mdot
.992 .13369 Mdot
.992 .13404 Mdot
.992 .13406 Mdot
.992 .13447 Mdot
.992 .1345 Mdot
.992 .13473 Mdot
.992 .13476 Mdot
.992 .13499 Mdot
.992 .13501 Mdot
.992 .1351 Mdot
.992 .13524 Mdot
.992 .13527 Mdot
.992 .13527 Mdot
.992 .13529 Mdot
.992 .13533 Mdot
.992 .13535 Mdot
.992 .13539 Mdot
.992 .13544 Mdot
.992 .13555 Mdot
.992 .13557 Mdot
.992 .13559 Mdot
.992 .13561 Mdot
.992 .13575 Mdot
.992 .13587 Mdot
.992 .13598 Mdot
.992 .13614 Mdot
.992 .13617 Mdot
.992 .13622 Mdot
.992 .13626 Mdot
.992 .13652 Mdot
.992 .13656 Mdot
.992 .13662 Mdot
.992 .13662 Mdot
.992 .13662 Mdot
.992 .13664 Mdot
.992 .13667 Mdot
.992 .13707 Mdot
.992 .13712 Mdot
.992 .13795 Mdot
.992 .13804 Mdot
.992 .13815 Mdot
.992 .13822 Mdot
.992 .13828 Mdot
.992 .13841 Mdot
.992 .1393 Mdot
.992 .13936 Mdot
.992 .13938 Mdot
.992 .13941 Mdot
.992 .13943 Mdot
.992 .13959 Mdot
.992 .1396 Mdot
.992 .13985 Mdot
.992 .13992 Mdot
.992 .13996 Mdot
.992 .14004 Mdot
.992 .14006 Mdot
.992 .14019 Mdot
.992 .14022 Mdot
.992 .14026 Mdot
.992 .14054 Mdot
.992 .14057 Mdot
.992 .14062 Mdot
.992 .14096 Mdot
.992 .14107 Mdot
.992 .14108 Mdot
.992 .14111 Mdot
.992 .14122 Mdot
.992 .14123 Mdot
.992 .14125 Mdot
.992 .14131 Mdot
.992 .14133 Mdot
.992 .14142 Mdot
.992 .14144 Mdot
.992 .14151 Mdot
.992 .14156 Mdot
.992 .1416 Mdot
.992 .14162 Mdot
.992 .14175 Mdot
.992 .14176 Mdot
.992 .14177 Mdot
.992 .14178 Mdot
.992 .14179 Mdot
.992 .14195 Mdot
.992 .14218 Mdot
.992 .14219 Mdot
.992 .14226 Mdot
.992 .14233 Mdot
.992 .14234 Mdot
.992 .14234 Mdot
.992 .14235 Mdot
.992 .14239 Mdot
.992 .14249 Mdot
.992 .14255 Mdot
.992 .14256 Mdot
.992 .14257 Mdot
.992 .1429 Mdot
.992 .14861 Mdot
.992 .15637 Mdot
.992 .15643 Mdot
.992 .15645 Mdot
.992 .15646 Mdot
.992 .15647 Mdot
.992 .15657 Mdot
.992 .15658 Mdot
.992 .15659 Mdot
.992 .15663 Mdot
.992 .15664 Mdot
.992 .15674 Mdot
.992 .15674 Mdot
.992 .15675 Mdot
.992 .15676 Mdot
.992 .15679 Mdot
.992 .15691 Mdot
.992 .15692 Mdot
.992 .15707 Mdot
.992 .15708 Mdot
.992 .15715 Mdot
.992 .15715 Mdot
.992 .15716 Mdot
.992 .15718 Mdot
.992 .15725 Mdot
.992 .15749 Mdot
.992 .15759 Mdot
.992 .15762 Mdot
.992 .158 Mdot
.992 .15801 Mdot
.992 .15803 Mdot
.992 .15811 Mdot
.992 .15823 Mdot
.992 .15866 Mdot
.992 .15869 Mdot
.992 .1588 Mdot
.992 .1591 Mdot
.992 .15946 Mdot
.992 .15947 Mdot
.992 .15948 Mdot
.992 .15963 Mdot
.992 .15964 Mdot
.992 .1598 Mdot
.992 .15989 Mdot
.992 .15999 Mdot
.992 .16 Mdot
.992 .1601 Mdot
.992 .16011 Mdot
.992 .16011 Mdot
.992 .16012 Mdot
.992 .16014 Mdot
.992 .16018 Mdot
.992 .16023 Mdot
.992 .16024 Mdot
.992 .16031 Mdot
.992 .16037 Mdot
.992 .16049 Mdot
.992 .16053 Mdot
.992 .16055 Mdot
.992 .16067 Mdot
.992 .16072 Mdot
.992 .16072 Mdot
.992 .16072 Mdot
.992 .16073 Mdot
.992 .16247 Mdot
.992 .16257 Mdot
.992 .16274 Mdot
.992 .16275 Mdot
.992 .16301 Mdot
.992 .16309 Mdot
.992 .16499 Mdot
.992 .16554 Mdot
.992 .16598 Mdot
.992 .1665 Mdot
.992 .16667 Mdot
.992 .16788 Mdot
.992 .16818 Mdot
.992 .1694 Mdot
.992 .16983 Mdot
.992 .17223 Mdot
.992 .17283 Mdot
.992 .17333 Mdot
.992 .17448 Mdot
.992 .175 Mdot
.992 .17537 Mdot
.992 .17719 Mdot
.992 .17734 Mdot
.992 .17831 Mdot
.992 .17895 Mdot
.992 .18003 Mdot
.992 .18023 Mdot
.992 .18031 Mdot
.992 .18215 Mdot
.992 .18225 Mdot
.992 .18427 Mdot
.992 .18654 Mdot
.992 .19304 Mdot
.992 .19399 Mdot
.992 .19549 Mdot
.992 .19835 Mdot
.992 .19952 Mdot
.992 .20063 Mdot
.992 .20127 Mdot
.992 .20204 Mdot
.992 .20244 Mdot
.992 .20378 Mdot
.992 .20416 Mdot
.992 .20436 Mdot
.992 .20466 Mdot
.992 .20535 Mdot
.992 .20694 Mdot
.992 .20703 Mdot
.992 .20825 Mdot
.992 .20846 Mdot
.992 .21059 Mdot
.992 .21072 Mdot
.992 .21101 Mdot
.992 .21116 Mdot
.992 .21187 Mdot
.992 .21275 Mdot
.992 .21466 Mdot
.992 .21477 Mdot
.992 .21537 Mdot
.992 .21571 Mdot
.992 .21678 Mdot
.992 .21771 Mdot
.992 .21827 Mdot
.992 .21849 Mdot
.992 .21925 Mdot
.992 .21994 Mdot
.992 .22011 Mdot
.992 .22015 Mdot
.992 .22072 Mdot
.992 .22075 Mdot
.992 .22233 Mdot
.992 .22269 Mdot
.992 .22623 Mdot
.992 .22695 Mdot
.992 .22778 Mdot
.992 .22985 Mdot
.992 .23048 Mdot
.992 .23125 Mdot
.992 .2336 Mdot
.992 .2355 Mdot
.992 .23606 Mdot
.992 .23706 Mdot
.992 .23716 Mdot
.992 .23868 Mdot
.992 .23881 Mdot
.992 .23886 Mdot
.992 .23929 Mdot
.992 .24097 Mdot
.992 .24195 Mdot
.992 .24347 Mdot
.992 .2473 Mdot
.992 .24872 Mdot
.992 .25004 Mdot
.992 .25011 Mdot
.992 .25063 Mdot
.992 .25182 Mdot
.992 .25244 Mdot
.992 .2544 Mdot
.992 .257 Mdot
.992 .2583 Mdot
.992 .25866 Mdot
.992 .25921 Mdot
.992 .25971 Mdot
.992 .26077 Mdot
.992 .26165 Mdot
.992 .26178 Mdot
.992 .26278 Mdot
.992 .2646 Mdot
.992 .26469 Mdot
.992 .26505 Mdot
.992 .26546 Mdot
.992 .26549 Mdot
.992 .26556 Mdot
.992 .2657 Mdot
.992 .26616 Mdot
.992 .26622 Mdot
.992 .26801 Mdot
.992 .26809 Mdot
.992 .27025 Mdot
.992 .2704 Mdot
.992 .27162 Mdot
.992 .27179 Mdot
.992 .273 Mdot
.992 .27309 Mdot
.992 .27358 Mdot
.992 .27433 Mdot
.992 .27444 Mdot
.992 .27447 Mdot
.992 .27457 Mdot
.992 .27477 Mdot
.992 .27487 Mdot
.992 .27508 Mdot
.992 .27536 Mdot
.992 .27591 Mdot
.992 .27604 Mdot
.992 .27613 Mdot
.992 .27622 Mdot
.992 .27695 Mdot
.992 .27758 Mdot
.992 .27818 Mdot
.992 .27896 Mdot
.992 .27913 Mdot
.992 .27941 Mdot
.992 .27961 Mdot
.992 .28095 Mdot
.992 .28116 Mdot
.992 .28144 Mdot
.992 .28146 Mdot
.992 .28146 Mdot
.992 .28154 Mdot
.992 .28171 Mdot
.992 .28373 Mdot
.992 .28387 Mdot
.992 .28403 Mdot
.992 .2882 Mdot
.992 .28864 Mdot
.992 .28918 Mdot
.992 .28957 Mdot
.992 .28983 Mdot
.992 .2905 Mdot
.992 .29489 Mdot
.992 .2952 Mdot
.992 .29529 Mdot
.992 .29546 Mdot
.992 .29551 Mdot
.992 .29631 Mdot
.992 .29636 Mdot
.992 .29758 Mdot
.992 .2979 Mdot
.992 .29812 Mdot
.992 .29851 Mdot
.992 .29858 Mdot
.992 .29922 Mdot
.992 .29936 Mdot
.992 .29955 Mdot
.992 .30088 Mdot
.992 .30102 Mdot
.992 .30126 Mdot
.992 .30286 Mdot
.992 .30338 Mdot
.992 .30342 Mdot
.992 .30357 Mdot
.992 .3041 Mdot
.992 .30416 Mdot
.992 .30424 Mdot
.992 .30451 Mdot
.992 .30462 Mdot
.992 .30505 Mdot
.992 .30513 Mdot
.992 .30544 Mdot
.992 .30569 Mdot
.992 .30585 Mdot
.992 .30595 Mdot
.992 .30658 Mdot
.992 .3066 Mdot
.992 .30668 Mdot
.992 .30668 Mdot
.992 .30676 Mdot
.992 .30749 Mdot
.992 .30854 Mdot
.992 .30859 Mdot
.992 .30889 Mdot
.992 .30923 Mdot
.992 .30926 Mdot
.992 .30926 Mdot
.992 .30934 Mdot
.992 .30951 Mdot
.992 .30997 Mdot
.992 .31024 Mdot
.992 .31028 Mdot
.992 .3103 Mdot
.992 .3118 Mdot
.992 .31379 Mdot
.992 .32701 Mdot
.992 .33507 Mdot
.992 .33883 Mdot
.992 .33885 Mdot
.992 .33885 Mdot
.992 .33886 Mdot
.992 .3389 Mdot
.992 .33896 Mdot
.992 .33903 Mdot
.992 .33905 Mdot
.992 .33929 Mdot
.992 .33954 Mdot
.992 .33964 Mdot
.992 .33969 Mdot
.992 .34012 Mdot
.992 .34047 Mdot
.992 .34047 Mdot
.992 .34064 Mdot
.992 .3409 Mdot
.992 .3427 Mdot
.992 .34271 Mdot
.992 .34286 Mdot
.992 .34321 Mdot
.992 .3434 Mdot
.992 .34342 Mdot
.992 .34434 Mdot
.992 .34506 Mdot
.992 .34565 Mdot
.992 .34618 Mdot
.992 .34642 Mdot
.992 .3482 Mdot
.992 .34897 Mdot
.992 .34912 Mdot
.992 .34919 Mdot
.992 .35039 Mdot
.992 .35065 Mdot
.992 .35109 Mdot
.992 .35116 Mdot
.992 .35277 Mdot
.992 .35348 Mdot
.992 .35505 Mdot
.992 .35546 Mdot
.992 .35572 Mdot
.992 .35628 Mdot
.992 .35713 Mdot
.992 .35772 Mdot
.992 .35802 Mdot
.992 .35816 Mdot
.992 .35819 Mdot
.992 .35821 Mdot
.992 .35824 Mdot
.992 .35831 Mdot
.992 .35847 Mdot
.992 .35848 Mdot
.992 .3586 Mdot
.992 .35862 Mdot
.992 .35882 Mdot
.992 .35884 Mdot
.992 .35886 Mdot
.992 .35888 Mdot
.992 .35894 Mdot
.992 .35921 Mdot
.992 .35922 Mdot
.992 .35955 Mdot
.992 .35957 Mdot
.992 .3597 Mdot
.992 .35972 Mdot
.992 .35972 Mdot
.992 .35977 Mdot
.992 .35977 Mdot
.992 .35992 Mdot
.992 .36042 Mdot
.992 .36061 Mdot
.992 .36067 Mdot
.992 .36113 Mdot
.992 .36127 Mdot
.992 .36142 Mdot
.992 .36144 Mdot
.992 .36148 Mdot
.992 .36163 Mdot
.992 .36172 Mdot
.992 .36187 Mdot
.992 .36223 Mdot
.992 .36236 Mdot
.992 .36266 Mdot
.992 .36272 Mdot
.992 .36292 Mdot
.992 .36345 Mdot
.992 .36367 Mdot
.992 .36377 Mdot
.992 .36402 Mdot
.992 .36406 Mdot
.992 .36407 Mdot
.992 .36407 Mdot
.992 .36409 Mdot
.992 .36414 Mdot
.992 .36434 Mdot
.992 .36435 Mdot
.992 .36462 Mdot
.992 .36476 Mdot
.992 .36478 Mdot
.992 .36492 Mdot
.992 .36493 Mdot
.992 .36508 Mdot
.992 .3651 Mdot
.992 .3651 Mdot
.992 .36511 Mdot
.992 .36515 Mdot
.992 .36521 Mdot
.992 .36528 Mdot
.992 .3653 Mdot
.992 .36532 Mdot
.992 .36541 Mdot
.992 .36549 Mdot
.992 .36567 Mdot
.992 .36573 Mdot
.992 .36576 Mdot
.992 .36594 Mdot
.992 .36601 Mdot
.992 .36601 Mdot
.992 .36601 Mdot
.992 .36602 Mdot
.992 .36604 Mdot
.992 .36709 Mdot
.992 .36725 Mdot
.992 .36823 Mdot
.992 .36831 Mdot
.992 .36834 Mdot
.992 .36852 Mdot
.992 .36854 Mdot
.992 .36881 Mdot
.992 .36888 Mdot
.992 .36893 Mdot
.992 .3692 Mdot
.992 .36923 Mdot
.992 .36963 Mdot
.992 .37039 Mdot
.992 .3704 Mdot
.992 .37045 Mdot
.992 .37069 Mdot
.992 .37079 Mdot
.992 .37099 Mdot
.992 .37102 Mdot
.992 .37125 Mdot
.992 .37132 Mdot
.992 .37165 Mdot
.992 .37166 Mdot
.992 .3717 Mdot
.992 .3717 Mdot
.992 .37174 Mdot
.992 .37657 Mdot
.992 .37856 Mdot
.992 .38346 Mdot
.992 .38634 Mdot
.992 .38978 Mdot
.992 .39875 Mdot
.992 .39999 Mdot
.992 .4016 Mdot
.992 .40515 Mdot
.992 .41329 Mdot
.992 .4164 Mdot
.992 .4259 Mdot
.992 .42874 Mdot
.992 .43389 Mdot
.992 .43442 Mdot
.992 .44238 Mdot
.992 .44312 Mdot
.992 .44336 Mdot
.992 .44563 Mdot
.992 .45465 Mdot
.992 .4599 Mdot
.992 .46265 Mdot
.992 .4681 Mdot
.992 .47945 Mdot
.992 .48876 Mdot
.992 .49631 Mdot
.992 .50324 Mdot
.992 .50357 Mdot
.992 .50626 Mdot
.992 .51237 Mdot
.992 .51551 Mdot
.992 .52176 Mdot
.992 .52515 Mdot
.992 .53732 Mdot
.992 .53846 Mdot
.992 .54309 Mdot
.992 .54463 Mdot
.992 .54555 Mdot
.992 .54698 Mdot
.992 .54911 Mdot
.992 .55074 Mdot
.992 .55343 Mdot
.992 .55687 Mdot
.992 .55737 Mdot
.992 .56115 Mdot
.992 .56588 Mdot
.992 .56589 Mdot
.992 .56589 Mdot
.992 .56589 Mdot
.992 .56591 Mdot
.992 .56596 Mdot
.992 .56597 Mdot
.992 .56598 Mdot
.992 .56603 Mdot
.992 .56609 Mdot
.992 .56609 Mdot
.992 .56611 Mdot
.992 .56613 Mdot
.992 .56614 Mdot
.992 .56614 Mdot
.992 .56614 Mdot
.992 .56615 Mdot
.992 .56619 Mdot
.992 .56619 Mdot
.992 .56624 Mdot
.992 .56636 Mdot
.992 .56643 Mdot
.992 .56644 Mdot
.992 .56686 Mdot
.992 .56727 Mdot
.992 .56728 Mdot
.992 .56755 Mdot
.992 .56765 Mdot
.992 .56786 Mdot
.992 .56803 Mdot
.992 .56821 Mdot
.992 .56844 Mdot
.992 .56872 Mdot
.992 .56907 Mdot
.992 .56975 Mdot
.992 .57009 Mdot
.992 .57012 Mdot
.992 .57016 Mdot
.992 .5704 Mdot
.992 .57043 Mdot
.992 .5705 Mdot
.992 .57052 Mdot
.992 .57067 Mdot
.992 .5707 Mdot
.992 .57075 Mdot
.992 .57091 Mdot
.992 .57109 Mdot
.992 .57117 Mdot
.992 .57118 Mdot
.992 .57118 Mdot
.992 .57121 Mdot
.992 .57158 Mdot
.992 .57192 Mdot
.992 .57198 Mdot
.992 .57206 Mdot
.992 .57236 Mdot
.992 .57242 Mdot
.992 .5726 Mdot
.992 .5728 Mdot
.992 .57289 Mdot
.992 .57297 Mdot
.992 .57322 Mdot
.992 .57412 Mdot
.992 .57422 Mdot
.992 .57422 Mdot
.992 .57432 Mdot
.992 .57435 Mdot
.992 .57499 Mdot
.992 .57516 Mdot
.992 .5753 Mdot
.992 .5755 Mdot
.992 .57584 Mdot
.992 .57593 Mdot
.992 .57625 Mdot
.992 .57636 Mdot
.992 .57695 Mdot
.992 .57709 Mdot
.992 .57746 Mdot
.992 .57758 Mdot
.992 .57766 Mdot
.992 .57804 Mdot
.992 .57807 Mdot
.992 .57827 Mdot
.992 .5784 Mdot
.992 .57861 Mdot
.992 .57865 Mdot
.992 .57867 Mdot
.992 .57902 Mdot
.992 .57941 Mdot
.992 .57981 Mdot
.992 .58089 Mdot
.992 .58104 Mdot
.992 .58171 Mdot
.992 .58189 Mdot
.992 .58205 Mdot
.992 .58226 Mdot
.992 .58232 Mdot
.992 .58251 Mdot
.992 .58257 Mdot
.992 .5826 Mdot
.992 .58264 Mdot
.992 .58274 Mdot
.992 .58296 Mdot
.992 .58298 Mdot
.992 .58315 Mdot
.992 .58318 Mdot
.992 .58347 Mdot
.992 .58349 Mdot
.992 .58353 Mdot
.992 .58355 Mdot
.992 .58365 Mdot
.992 .58377 Mdot
.992 .58403 Mdot
.992 .58404 Mdot
.992 .58413 Mdot
.992 .58417 Mdot
.992 .58444 Mdot
.992 .58451 Mdot
.992 .58454 Mdot
.992 .58464 Mdot
.992 .58473 Mdot
.992 .58476 Mdot
.992 .58476 Mdot
.992 .58484 Mdot
.992 .58484 Mdot
.992 .58505 Mdot
.992 .58556 Mdot
.992 .58565 Mdot
.992 .58576 Mdot
.992 .58603 Mdot
.992 .58611 Mdot
.992 .58621 Mdot
.992 .58651 Mdot
.992 .58675 Mdot
.992 .58682 Mdot
.992 .58695 Mdot
.992 .58697 Mdot
.992 .58716 Mdot
.992 .58718 Mdot
.992 .58718 Mdot
.992 .58724 Mdot
.992 .58745 Mdot
.992 .58758 Mdot
.992 .58777 Mdot
.992 .58827 Mdot
.992 .58845 Mdot
.992 .58862 Mdot
.992 .58863 Mdot
.992 .5887 Mdot
.992 .58885 Mdot
.992 .58893 Mdot
.992 .58919 Mdot
.992 .58953 Mdot
.992 .5897 Mdot
.992 .58975 Mdot
.992 .58982 Mdot
.992 .58989 Mdot
.992 .59003 Mdot
.992 .59015 Mdot
.992 .59017 Mdot
.992 .5903 Mdot
.992 .59055 Mdot
.992 .59056 Mdot
.992 .59061 Mdot
.992 .59067 Mdot
.992 .59067 Mdot
.992 .59068 Mdot
.992 .5907 Mdot
.992 .59076 Mdot
.992 .59102 Mdot
.992 .59103 Mdot
.992 .59136 Mdot
.992 .59153 Mdot
.992 .59155 Mdot
.992 .59173 Mdot
.992 .59174 Mdot
.992 .59181 Mdot
.992 .59192 Mdot
.992 .59194 Mdot
.992 .59194 Mdot
.992 .59195 Mdot
.992 .59198 Mdot
.992 .592 Mdot
.992 .59203 Mdot
.992 .59207 Mdot
.992 .59215 Mdot
.992 .59217 Mdot
.992 .59218 Mdot
.992 .5922 Mdot
.992 .5923 Mdot
.992 .5924 Mdot
.992 .59249 Mdot
.992 .59261 Mdot
.992 .59263 Mdot
.992 .59268 Mdot
.992 .59271 Mdot
.992 .59291 Mdot
.992 .59294 Mdot
.992 .59299 Mdot
.992 .59299 Mdot
.992 .59299 Mdot
.992 .593 Mdot
.992 .59303 Mdot
.992 .59335 Mdot
.992 .59339 Mdot
.992 .59408 Mdot
.992 .59415 Mdot
.992 .59424 Mdot
.992 .59431 Mdot
.992 .59436 Mdot
.992 .59447 Mdot
.992 .59526 Mdot
.992 .59532 Mdot
.992 .59534 Mdot
.992 .59537 Mdot
.992 .59538 Mdot
.992 .59553 Mdot
.992 .59554 Mdot
.992 .59578 Mdot
.992 .59585 Mdot
.992 .59589 Mdot
.992 .59597 Mdot
.992 .59598 Mdot
.992 .59611 Mdot
.992 .59614 Mdot
.992 .59618 Mdot
.992 .59646 Mdot
.992 .59649 Mdot
.992 .59654 Mdot
.992 .59689 Mdot
.992 .59701 Mdot
.992 .59702 Mdot
.992 .59705 Mdot
.992 .59718 Mdot
.992 .59719 Mdot
.992 .59721 Mdot
.992 .59727 Mdot
.992 .5973 Mdot
.992 .5974 Mdot
.992 .59742 Mdot
.992 .59749 Mdot
.992 .59756 Mdot
.992 .59759 Mdot
.992 .59762 Mdot
.992 .59778 Mdot
.992 .59778 Mdot
.992 .5978 Mdot
.992 .5978 Mdot
.992 .59782 Mdot
.992 .59801 Mdot
.992 .59829 Mdot
.992 .59831 Mdot
.992 .59839 Mdot
.992 .59849 Mdot
.992 .59849 Mdot
.992 .59849 Mdot
.992 .59852 Mdot
.992 .59856 Mdot
.992 .5987 Mdot
.992 .59878 Mdot
.992 .59879 Mdot
.992 .5988 Mdot
.994 .11198 Mdot
.994 .11198 Mdot
.994 .11198 Mdot
.994 .11198 Mdot
.994 .11198 Mdot
.994 .11199 Mdot
.994 .11199 Mdot
.994 .112 Mdot
.994 .112 Mdot
.994 .11201 Mdot
.994 .11201 Mdot
.994 .11201 Mdot
.994 .11202 Mdot
.994 .11204 Mdot
.994 .11204 Mdot
.994 .11204 Mdot
.994 .11205 Mdot
.994 .11205 Mdot
.994 .11207 Mdot
.994 .11207 Mdot
.994 .11207 Mdot
.994 .11208 Mdot
.994 .11208 Mdot
.994 .11208 Mdot
.994 .11208 Mdot
.994 .11208 Mdot
.994 .11209 Mdot
.994 .1121 Mdot
.994 .11212 Mdot
.994 .11215 Mdot
.994 .11216 Mdot
.994 .11219 Mdot
.994 .11222 Mdot
.994 .11222 Mdot
.994 .11222 Mdot
.994 .11223 Mdot
.994 .11224 Mdot
.994 .11225 Mdot
.994 .11227 Mdot
.994 .11227 Mdot
.994 .11228 Mdot
.994 .1123 Mdot
.994 .1123 Mdot
.994 .11231 Mdot
.994 .11231 Mdot
.994 .11232 Mdot
.994 .11235 Mdot
.994 .11237 Mdot
.994 .1124 Mdot
.994 .11245 Mdot
.994 .11245 Mdot
.994 .11246 Mdot
.994 .11247 Mdot
.994 .11248 Mdot
.994 .11248 Mdot
.994 .11248 Mdot
.994 .11249 Mdot
.994 .11253 Mdot
.994 .11256 Mdot
.994 .11294 Mdot
.994 .11312 Mdot
.994 .11318 Mdot
.994 .1132 Mdot
.994 .11326 Mdot
.994 .11327 Mdot
.994 .11342 Mdot
.994 .11355 Mdot
.994 .11397 Mdot
.994 .1141 Mdot
.994 .11435 Mdot
.994 .11453 Mdot
.994 .11471 Mdot
.994 .11484 Mdot
.994 .1152 Mdot
.994 .11549 Mdot
.994 .11563 Mdot
.994 .11578 Mdot
.994 .11591 Mdot
.994 .116 Mdot
.994 .11633 Mdot
.994 .11706 Mdot
.994 .11752 Mdot
.994 .11803 Mdot
.994 .11809 Mdot
.994 .11811 Mdot
.994 .11828 Mdot
.994 .11834 Mdot
.994 .11862 Mdot
.994 .11908 Mdot
.994 .11921 Mdot
.994 .11939 Mdot
.994 .12051 Mdot
.994 .12139 Mdot
.994 .12208 Mdot
.994 .12222 Mdot
.994 .12237 Mdot
.994 .12318 Mdot
.994 .12451 Mdot
.994 .12484 Mdot
.994 .12573 Mdot
.994 .12578 Mdot
.994 .12606 Mdot
.994 .12617 Mdot
.994 .1262 Mdot
.994 .12626 Mdot
.994 .12639 Mdot
.994 .12643 Mdot
.994 .12679 Mdot
.994 .12688 Mdot
.994 .12699 Mdot
.994 .12702 Mdot
.994 .12723 Mdot
.994 .12799 Mdot
.994 .12829 Mdot
.994 .1283 Mdot
.994 .12847 Mdot
.994 .12904 Mdot
.994 .12958 Mdot
.994 .12961 Mdot
.994 .12964 Mdot
.994 .12965 Mdot
.994 .1297 Mdot
.994 .12972 Mdot
.994 .12975 Mdot
.994 .12988 Mdot
.994 .12993 Mdot
.994 .13006 Mdot
.994 .13007 Mdot
.994 .13011 Mdot
.994 .13014 Mdot
.994 .13024 Mdot
.994 .1306 Mdot
.994 .13065 Mdot
.994 .13069 Mdot
.994 .13071 Mdot
.994 .13084 Mdot
.994 .13085 Mdot
.994 .13103 Mdot
.994 .1311 Mdot
.994 .13111 Mdot
.994 .13119 Mdot
.994 .13119 Mdot
.994 .13122 Mdot
.994 .13129 Mdot
.994 .13129 Mdot
.994 .13132 Mdot
.994 .13149 Mdot
.994 .13162 Mdot
.994 .13183 Mdot
.994 .13214 Mdot
.994 .13231 Mdot
.994 .13248 Mdot
.994 .13253 Mdot
.994 .13269 Mdot
.994 .1329 Mdot
.994 .13329 Mdot
.994 .13331 Mdot
.994 .13336 Mdot
.994 .13351 Mdot
.994 .13359 Mdot
.994 .13368 Mdot
.994 .13398 Mdot
.994 .13401 Mdot
.994 .13419 Mdot
.994 .13438 Mdot
.994 .13444 Mdot
.994 .13445 Mdot
.994 .13454 Mdot
.994 .13457 Mdot
.994 .13469 Mdot
.994 .13498 Mdot
.994 .13501 Mdot
.994 .13505 Mdot
.994 .13506 Mdot
.994 .13527 Mdot
.994 .13532 Mdot
.994 .13566 Mdot
.994 .13576 Mdot
.994 .13589 Mdot
.994 .13623 Mdot
.994 .13623 Mdot
.994 .13632 Mdot
.994 .1364 Mdot
.994 .13645 Mdot
.994 .13654 Mdot
.994 .13655 Mdot
.994 .13659 Mdot
.994 .13665 Mdot
.994 .13666 Mdot
.994 .1367 Mdot
.994 .13702 Mdot
.994 .13722 Mdot
.994 .13727 Mdot
.994 .13733 Mdot
.994 .13802 Mdot
.994 .13811 Mdot
.994 .13849 Mdot
.994 .13852 Mdot
.994 .13866 Mdot
.994 .13901 Mdot
.994 .13907 Mdot
.994 .1398 Mdot
.994 .13996 Mdot
.994 .14003 Mdot
.994 .14007 Mdot
.994 .14014 Mdot
.994 .14087 Mdot
.994 .14091 Mdot
.994 .141 Mdot
.994 .14103 Mdot
.994 .14129 Mdot
.994 .14134 Mdot
.994 .14135 Mdot
.994 .1414 Mdot
.994 .14143 Mdot
.994 .14148 Mdot
.994 .14155 Mdot
.994 .14157 Mdot
.994 .14161 Mdot
.994 .14165 Mdot
.994 .14184 Mdot
.994 .14195 Mdot
.994 .14197 Mdot
.994 .14204 Mdot
.994 .14223 Mdot
.994 .14234 Mdot
.994 .14239 Mdot
.994 .1426 Mdot
.994 .1426 Mdot
.994 .14267 Mdot
.994 .1428 Mdot
.994 .14292 Mdot
.994 .14293 Mdot
.994 .14298 Mdot
.994 .14299 Mdot
.994 .14302 Mdot
.994 .14311 Mdot
.994 .14315 Mdot
.994 .14315 Mdot
.994 .14318 Mdot
.994 .14319 Mdot
.994 .1432 Mdot
.994 .1432 Mdot
.994 .1432 Mdot
.994 .14321 Mdot
.994 .14321 Mdot
.994 .14321 Mdot
.994 .14325 Mdot
.994 .14328 Mdot
.994 .14336 Mdot
.994 .14341 Mdot
.994 .14345 Mdot
.994 .14346 Mdot
.994 .14346 Mdot
.994 .14349 Mdot
.994 .1435 Mdot
.994 .14354 Mdot
.994 .14355 Mdot
.994 .14357 Mdot
.994 .1436 Mdot
.994 .1436 Mdot
.994 .14362 Mdot
.994 .15212 Mdot
.994 .1567 Mdot
.994 .15743 Mdot
.994 .15744 Mdot
.994 .15744 Mdot
.994 .15745 Mdot
.994 .15746 Mdot
.994 .15746 Mdot
.994 .15749 Mdot
.994 .15751 Mdot
.994 .15754 Mdot
.994 .15754 Mdot
.994 .15755 Mdot
.994 .15756 Mdot
.994 .15758 Mdot
.994 .15767 Mdot
.994 .1577 Mdot
.994 .1577 Mdot
.994 .15773 Mdot
.994 .15774 Mdot
.994 .1578 Mdot
.994 .1578 Mdot
.994 .15782 Mdot
.994 .15782 Mdot
.994 .15783 Mdot
.994 .15785 Mdot
.994 .15785 Mdot
.994 .15786 Mdot
.994 .1579 Mdot
.994 .15794 Mdot
.994 .15799 Mdot
.994 .15812 Mdot
.994 .15817 Mdot
.994 .15828 Mdot
.994 .15839 Mdot
.994 .1584 Mdot
.994 .15842 Mdot
.994 .15846 Mdot
.994 .15848 Mdot
.994 .15851 Mdot
.994 .1586 Mdot
.994 .15861 Mdot
.994 .15867 Mdot
.994 .15873 Mdot
.994 .15874 Mdot
.994 .15877 Mdot
.994 .15879 Mdot
.994 .15883 Mdot
.994 .15894 Mdot
.994 .15902 Mdot
.994 .15915 Mdot
.994 .15936 Mdot
.994 .15936 Mdot
.994 .15939 Mdot
.994 .15942 Mdot
.994 .15944 Mdot
.994 .15948 Mdot
.994 .15948 Mdot
.994 .15952 Mdot
.994 .15967 Mdot
.994 .15977 Mdot
.994 .16134 Mdot
.994 .1621 Mdot
.994 .16237 Mdot
.994 .16243 Mdot
.994 .1627 Mdot
.994 .16275 Mdot
.994 .16337 Mdot
.994 .16393 Mdot
.994 .16572 Mdot
.994 .16625 Mdot
.994 .16735 Mdot
.994 .16811 Mdot
.994 .16813 Mdot
.994 .16893 Mdot
.994 .16948 Mdot
.994 .17111 Mdot
.994 .17239 Mdot
.994 .17301 Mdot
.994 .17372 Mdot
.994 .17431 Mdot
.994 .17469 Mdot
.994 .1762 Mdot
.994 .17665 Mdot
.994 .17961 Mdot
.994 .18177 Mdot
.994 .18421 Mdot
.994 .18451 Mdot
.994 .18463 Mdot
.994 .18542 Mdot
.994 .18572 Mdot
.994 .18705 Mdot
.994 .18931 Mdot
.994 .18994 Mdot
.994 .19086 Mdot
.994 .19643 Mdot
.994 .20093 Mdot
.994 .20296 Mdot
.994 .20445 Mdot
.994 .20518 Mdot
.994 .20565 Mdot
.994 .20596 Mdot
.994 .2102 Mdot
.994 .21151 Mdot
.994 .21721 Mdot
.994 .21898 Mdot
.994 .22371 Mdot
.994 .22398 Mdot
.994 .2255 Mdot
.994 .22606 Mdot
.994 .22625 Mdot
.994 .22658 Mdot
.994 .22727 Mdot
.994 .22749 Mdot
.994 .2294 Mdot
.994 .22993 Mdot
.994 .23045 Mdot
.994 .2305 Mdot
.994 .23067 Mdot
.994 .23125 Mdot
.994 .23178 Mdot
.994 .23589 Mdot
.994 .23754 Mdot
.994 .23759 Mdot
.994 .23851 Mdot
.994 .24158 Mdot
.994 .24453 Mdot
.994 .24467 Mdot
.994 .24482 Mdot
.994 .24493 Mdot
.994 .24515 Mdot
.994 .2453 Mdot
.994 .24544 Mdot
.994 .24612 Mdot
.994 .24645 Mdot
.994 .24711 Mdot
.994 .24718 Mdot
.994 .24741 Mdot
.994 .24753 Mdot
.994 .24812 Mdot
.994 .25003 Mdot
.994 .25005 Mdot
.994 .2503 Mdot
.994 .25055 Mdot
.994 .25062 Mdot
.994 .25135 Mdot
.994 .25143 Mdot
.994 .25235 Mdot
.994 .25276 Mdot
.994 .2528 Mdot
.994 .25322 Mdot
.994 .25325 Mdot
.994 .25342 Mdot
.994 .25376 Mdot
.994 .25376 Mdot
.994 .25396 Mdot
.994 .25483 Mdot
.994 .25556 Mdot
.994 .25671 Mdot
.994 .25834 Mdot
.994 .25925 Mdot
.994 .26019 Mdot
.994 .26048 Mdot
.994 .26133 Mdot
.994 .26245 Mdot
.994 .2645 Mdot
.994 .26465 Mdot
.994 .26488 Mdot
.994 .2657 Mdot
.994 .26613 Mdot
.994 .26658 Mdot
.994 .26818 Mdot
.994 .26837 Mdot
.994 .2693 Mdot
.994 .27031 Mdot
.994 .27061 Mdot
.994 .27067 Mdot
.994 .27113 Mdot
.994 .27131 Mdot
.994 .27197 Mdot
.994 .27256 Mdot
.994 .27348 Mdot
.994 .27362 Mdot
.994 .27382 Mdot
.994 .27387 Mdot
.994 .27501 Mdot
.994 .27523 Mdot
.994 .27702 Mdot
.994 .27755 Mdot
.994 .2776 Mdot
.994 .27768 Mdot
.994 .2782 Mdot
.994 .27996 Mdot
.994 .28 Mdot
.994 .28043 Mdot
.994 .28084 Mdot
.994 .28114 Mdot
.994 .28159 Mdot
.994 .28161 Mdot
.994 .28181 Mdot
.994 .28216 Mdot
.994 .28219 Mdot
.994 .28241 Mdot
.994 .28406 Mdot
.994 .28505 Mdot
.994 .2853 Mdot
.994 .2856 Mdot
.994 .28625 Mdot
.994 .28913 Mdot
.994 .28956 Mdot
.994 .29052 Mdot
.994 .29138 Mdot
.994 .29145 Mdot
.994 .2916 Mdot
.994 .29228 Mdot
.994 .29404 Mdot
.994 .29431 Mdot
.994 .29788 Mdot
.994 .29852 Mdot
.994 .29866 Mdot
.994 .29903 Mdot
.994 .2992 Mdot
.994 .29953 Mdot
.994 .30157 Mdot
.994 .30241 Mdot
.994 .30303 Mdot
.994 .30321 Mdot
.994 .30365 Mdot
.994 .30379 Mdot
.994 .305 Mdot
.994 .30524 Mdot
.994 .30531 Mdot
.994 .30553 Mdot
.994 .30565 Mdot
.994 .30589 Mdot
.994 .30621 Mdot
.994 .30632 Mdot
.994 .3065 Mdot
.994 .30668 Mdot
.994 .30758 Mdot
.994 .30806 Mdot
.994 .30818 Mdot
.994 .30847 Mdot
.994 .30938 Mdot
.994 .30985 Mdot
.994 .31012 Mdot
.994 .31106 Mdot
.994 .31106 Mdot
.994 .31138 Mdot
.994 .3119 Mdot
.994 .31195 Mdot
.994 .3125 Mdot
.994 .31255 Mdot
.994 .31275 Mdot
.994 .31282 Mdot
.994 .31294 Mdot
.994 .31336 Mdot
.994 .31352 Mdot
.994 .31352 Mdot
.994 .31367 Mdot
.994 .31368 Mdot
.994 .31372 Mdot
.994 .31373 Mdot
.994 .31375 Mdot
.994 .31378 Mdot
.994 .31378 Mdot
.994 .3138 Mdot
.994 .31397 Mdot
.994 .31409 Mdot
.994 .31444 Mdot
.994 .31466 Mdot
.994 .31487 Mdot
.994 .31488 Mdot
.994 .31491 Mdot
.994 .31504 Mdot
.994 .31508 Mdot
.994 .31526 Mdot
.994 .31528 Mdot
.994 .31538 Mdot
.994 .3155 Mdot
.994 .31553 Mdot
.994 .31559 Mdot
.994 .33154 Mdot
.994 .33296 Mdot
.994 .33952 Mdot
.994 .33953 Mdot
.994 .33965 Mdot
.994 .33977 Mdot
.994 .33987 Mdot
.994 .34007 Mdot
.994 .34047 Mdot
.994 .34292 Mdot
.994 .34316 Mdot
.994 .34451 Mdot
.994 .34591 Mdot
.994 .34712 Mdot
.994 .34746 Mdot
.994 .34918 Mdot
.994 .34964 Mdot
.994 .35089 Mdot
.994 .35091 Mdot
.994 .35178 Mdot
.994 .35345 Mdot
.994 .35438 Mdot
.994 .35468 Mdot
.994 .35501 Mdot
.994 .35517 Mdot
.994 .35693 Mdot
.994 .35736 Mdot
.994 .3585 Mdot
.994 .35867 Mdot
.994 .3591 Mdot
.994 .35926 Mdot
.994 .35944 Mdot
.994 .35973 Mdot
.994 .36035 Mdot
.994 .36099 Mdot
.994 .361 Mdot
.994 .36101 Mdot
.994 .36103 Mdot
.994 .36104 Mdot
.994 .36106 Mdot
.994 .36112 Mdot
.994 .36115 Mdot
.994 .36121 Mdot
.994 .36122 Mdot
.994 .36124 Mdot
.994 .36125 Mdot
.994 .3613 Mdot
.994 .36148 Mdot
.994 .3615 Mdot
.994 .36153 Mdot
.994 .36153 Mdot
.994 .3616 Mdot
.994 .36161 Mdot
.994 .36173 Mdot
.994 .36174 Mdot
.994 .36178 Mdot
.994 .36178 Mdot
.994 .3618 Mdot
.994 .36183 Mdot
.994 .36183 Mdot
.994 .36185 Mdot
.994 .36193 Mdot
.994 .362 Mdot
.994 .36211 Mdot
.994 .36227 Mdot
.994 .36235 Mdot
.994 .36245 Mdot
.994 .36247 Mdot
.994 .36267 Mdot
.994 .36288 Mdot
.994 .36289 Mdot
.994 .36292 Mdot
.994 .363 Mdot
.994 .36304 Mdot
.994 .36309 Mdot
.994 .36326 Mdot
.994 .36328 Mdot
.994 .36338 Mdot
.994 .36349 Mdot
.994 .36352 Mdot
.994 .36357 Mdot
.994 .36359 Mdot
.994 .36367 Mdot
.994 .36383 Mdot
.994 .36387 Mdot
.994 .36401 Mdot
.994 .36424 Mdot
.994 .36459 Mdot
.994 .3646 Mdot
.994 .36465 Mdot
.994 .3647 Mdot
.994 .36474 Mdot
.994 .36479 Mdot
.994 .3648 Mdot
.994 .36486 Mdot
.994 .3649 Mdot
.994 .36511 Mdot
.994 .36524 Mdot
.994 .36528 Mdot
.994 .36581 Mdot
.994 .36662 Mdot
.994 .36751 Mdot
.994 .36758 Mdot
.994 .36849 Mdot
.994 .36852 Mdot
.994 .36883 Mdot
.994 .3689 Mdot
.994 .36891 Mdot
.994 .3692 Mdot
.994 .36925 Mdot
.994 .36957 Mdot
.994 .36987 Mdot
.994 .37019 Mdot
.994 .37037 Mdot
.994 .37048 Mdot
.994 .37088 Mdot
.994 .37088 Mdot
.994 .37103 Mdot
.994 .37131 Mdot
.994 .37161 Mdot
.994 .37164 Mdot
.994 .37187 Mdot
.994 .37214 Mdot
.994 .37225 Mdot
.994 .37237 Mdot
.994 .37237 Mdot
.994 .37241 Mdot
.994 .37241 Mdot
.994 .37243 Mdot
.994 .37245 Mdot
.994 .37245 Mdot
.994 .37247 Mdot
.994 .37467 Mdot
.994 .37566 Mdot
.994 .38134 Mdot
.994 .38352 Mdot
.994 .38428 Mdot
.994 .38561 Mdot
.994 .38841 Mdot
.994 .38931 Mdot
.994 .39755 Mdot
.994 .39988 Mdot
.994 .40095 Mdot
.994 .40226 Mdot
.994 .4025 Mdot
.994 .40326 Mdot
.994 .40593 Mdot
.994 .40844 Mdot
.994 .42869 Mdot
.994 .43726 Mdot
.994 .43754 Mdot
.994 .44239 Mdot
.994 .45879 Mdot
.994 .47476 Mdot
.994 .47553 Mdot
.994 .47637 Mdot
.994 .47693 Mdot
.994 .47812 Mdot
.994 .47897 Mdot
.994 .47973 Mdot
.994 .4834 Mdot
.994 .48514 Mdot
.994 .4887 Mdot
.994 .48908 Mdot
.994 .49032 Mdot
.994 .49096 Mdot
.994 .49408 Mdot
.994 .50416 Mdot
.994 .50428 Mdot
.994 .50557 Mdot
.994 .50616 Mdot
.994 .50685 Mdot
.994 .50724 Mdot
.994 .51099 Mdot
.994 .51137 Mdot
.994 .51607 Mdot
.994 .51812 Mdot
.994 .51829 Mdot
.994 .51893 Mdot
.994 .52038 Mdot
.994 .52055 Mdot
.994 .5214 Mdot
.994 .52307 Mdot
.994 .52309 Mdot
.994 .52405 Mdot
.994 .52826 Mdot
.994 .53173 Mdot
.994 .53187 Mdot
.994 .53542 Mdot
.994 .53655 Mdot
.994 .53707 Mdot
.994 .54243 Mdot
.994 .54433 Mdot
.994 .54706 Mdot
.994 .54824 Mdot
.994 .55217 Mdot
.994 .55331 Mdot
.994 .55663 Mdot
.994 .55673 Mdot
.994 .56102 Mdot
.994 .567 Mdot
.994 .56702 Mdot
.994 .56704 Mdot
.994 .56706 Mdot
.994 .56708 Mdot
.994 .5671 Mdot
.994 .5671 Mdot
.994 .56737 Mdot
.994 .56746 Mdot
.994 .56749 Mdot
.994 .56752 Mdot
.994 .56753 Mdot
.994 .56758 Mdot
.994 .56762 Mdot
.994 .56763 Mdot
.994 .5677 Mdot
.994 .56773 Mdot
.994 .56779 Mdot
.994 .5678 Mdot
.994 .5678 Mdot
.994 .5679 Mdot
.994 .56802 Mdot
.994 .56807 Mdot
.994 .56821 Mdot
.994 .56828 Mdot
.994 .56833 Mdot
.994 .56838 Mdot
.994 .56839 Mdot
.994 .56839 Mdot
.994 .56842 Mdot
.994 .56843 Mdot
.994 .56843 Mdot
.994 .56846 Mdot
.994 .56846 Mdot
.994 .56856 Mdot
.994 .56856 Mdot
.994 .56867 Mdot
.994 .56884 Mdot
.994 .56895 Mdot
.994 .56895 Mdot
.994 .56904 Mdot
.994 .56909 Mdot
.994 .56924 Mdot
.994 .56928 Mdot
.994 .56962 Mdot
.994 .56972 Mdot
.994 .56976 Mdot
.994 .56989 Mdot
.994 .57019 Mdot
.994 .5702 Mdot
.994 .57049 Mdot
.994 .5705 Mdot
.994 .5714 Mdot
.994 .57168 Mdot
.994 .57185 Mdot
.994 .57195 Mdot
.994 .57217 Mdot
.994 .57229 Mdot
.994 .57235 Mdot
.994 .57318 Mdot
.994 .57352 Mdot
.994 .57363 Mdot
.994 .57366 Mdot
.994 .57377 Mdot
.994 .57379 Mdot
.994 .57403 Mdot
.994 .57424 Mdot
.994 .57485 Mdot
.994 .57502 Mdot
.994 .57535 Mdot
.994 .57558 Mdot
.994 .57581 Mdot
.994 .57595 Mdot
.994 .57638 Mdot
.994 .57669 Mdot
.994 .57684 Mdot
.994 .57701 Mdot
.994 .57714 Mdot
.994 .57723 Mdot
.994 .57757 Mdot
.994 .57827 Mdot
.994 .57869 Mdot
.994 .57915 Mdot
.994 .57923 Mdot
.994 .57937 Mdot
.994 .57942 Mdot
.994 .57966 Mdot
.994 .58005 Mdot
.994 .58015 Mdot
.994 .58031 Mdot
.994 .5812 Mdot
.994 .58188 Mdot
.994 .58239 Mdot
.994 .5825 Mdot
.994 .58261 Mdot
.994 .58321 Mdot
.994 .58416 Mdot
.994 .5844 Mdot
.994 .58502 Mdot
.994 .58506 Mdot
.994 .58525 Mdot
.994 .58535 Mdot
.994 .58539 Mdot
.994 .58551 Mdot
.994 .58576 Mdot
.994 .58582 Mdot
.994 .5859 Mdot
.994 .58592 Mdot
.994 .58606 Mdot
.994 .58659 Mdot
.994 .5868 Mdot
.994 .58681 Mdot
.994 .58692 Mdot
.994 .58731 Mdot
.994 .58769 Mdot
.994 .58771 Mdot
.994 .58773 Mdot
.994 .58774 Mdot
.994 .58777 Mdot
.994 .58779 Mdot
.994 .58781 Mdot
.994 .58789 Mdot
.994 .58793 Mdot
.994 .58802 Mdot
.994 .58803 Mdot
.994 .58806 Mdot
.994 .58807 Mdot
.994 .58815 Mdot
.994 .58839 Mdot
.994 .58843 Mdot
.994 .58846 Mdot
.994 .58847 Mdot
.994 .58857 Mdot
.994 .58857 Mdot
.994 .58869 Mdot
.994 .58875 Mdot
.994 .58875 Mdot
.994 .58881 Mdot
.994 .58881 Mdot
.994 .58883 Mdot
.994 .58888 Mdot
.994 .58888 Mdot
.994 .5889 Mdot
.994 .58902 Mdot
.994 .58911 Mdot
.994 .58926 Mdot
.994 .58947 Mdot
.994 .58959 Mdot
.994 .58972 Mdot
.994 .58976 Mdot
.994 .58987 Mdot
.994 .59002 Mdot
.994 .5903 Mdot
.994 .59032 Mdot
.994 .59035 Mdot
.994 .59046 Mdot
.994 .59052 Mdot
.994 .59058 Mdot
.994 .5908 Mdot
.994 .59082 Mdot
.994 .59095 Mdot
.994 .59109 Mdot
.994 .59113 Mdot
.994 .59114 Mdot
.994 .59121 Mdot
.994 .59123 Mdot
.994 .59132 Mdot
.994 .59154 Mdot
.994 .59156 Mdot
.994 .59159 Mdot
.994 .59176 Mdot
.994 .59179 Mdot
.994 .59205 Mdot
.994 .59213 Mdot
.994 .59222 Mdot
.994 .59243 Mdot
.994 .59249 Mdot
.994 .59249 Mdot
.994 .59256 Mdot
.994 .59262 Mdot
.994 .59266 Mdot
.994 .59273 Mdot
.994 .59274 Mdot
.994 .59277 Mdot
.994 .59282 Mdot
.994 .59286 Mdot
.994 .59311 Mdot
.994 .59327 Mdot
.994 .59331 Mdot
.994 .59336 Mdot
.994 .59393 Mdot
.994 .594 Mdot
.994 .59433 Mdot
.994 .59447 Mdot
.994 .59478 Mdot
.994 .59483 Mdot
.994 .59549 Mdot
.994 .59564 Mdot
.994 .59571 Mdot
.994 .59575 Mdot
.994 .59581 Mdot
.994 .59654 Mdot
.994 .59658 Mdot
.994 .59667 Mdot
.994 .5967 Mdot
.994 .59697 Mdot
.994 .59703 Mdot
.994 .59704 Mdot
.994 .59709 Mdot
.994 .59712 Mdot
.994 .59718 Mdot
.994 .59725 Mdot
.994 .59728 Mdot
.994 .59732 Mdot
.994 .59736 Mdot
.994 .59758 Mdot
.994 .5977 Mdot
.994 .59773 Mdot
.994 .59781 Mdot
.994 .59804 Mdot
.994 .59817 Mdot
.994 .59824 Mdot
.994 .5985 Mdot
.994 .5985 Mdot
.994 .5986 Mdot
.994 .59876 Mdot
.994 .59893 Mdot
.994 .59894 Mdot
.994 .59901 Mdot
.994 .59903 Mdot
.994 .59907 Mdot
.994 .5992 Mdot
.994 .59925 Mdot
.994 .59925 Mdot
.994 .5993 Mdot
.994 .5993 Mdot
.994 .59932 Mdot
.994 .59932 Mdot
.994 .59933 Mdot
.994 .59934 Mdot
.994 .59934 Mdot
.994 .59934 Mdot
.994 .5994 Mdot
.994 .59944 Mdot
.994 .59956 Mdot
.994 .59964 Mdot
.994 .59971 Mdot
.994 .59971 Mdot
.994 .59972 Mdot
.994 .59977 Mdot
.994 .59979 Mdot
.994 .59985 Mdot
.994 .59986 Mdot
.994 .5999 Mdot
.994 .59994 Mdot
.994 .59995 Mdot
.994 .59998 Mdot
.996 .11217 Mdot
.996 .11228 Mdot
.996 .13666 Mdot
.996 .13795 Mdot
.996 .14304 Mdot
.996 .14448 Mdot
.996 .1585 Mdot
.996 .15896 Mdot
.996 .28274 Mdot
.996 .28931 Mdot
.996 .31362 Mdot
.996 .31996 Mdot
.996 .36378 Mdot
.996 .3646 Mdot
.996 .56835 Mdot
.996 .56961 Mdot
.996 .59263 Mdot
.996 .59367 Mdot
.996 .59874 Mdot
.996 .60112 Mdot
.998 .11238 Mdot
.998 .11264 Mdot
.998 .11466 Mdot
.998 .14182 Mdot
.998 .14322 Mdot
.998 .14515 Mdot
.998 .15964 Mdot
.998 .16069 Mdot
.998 .16932 Mdot
.998 .30864 Mdot
.998 .31505 Mdot
.998 .32339 Mdot
.998 .36646 Mdot
.998 .36808 Mdot
.998 .3739 Mdot
.998 .56995 Mdot
.998 .57144 Mdot
.998 .57524 Mdot
.998 .59699 Mdot
.998 .59864 Mdot
.998 .60216 Mdot
1 .11527 Mdot
1 .14568 Mdot
1 .17236 Mdot
1 .32622 Mdot
1 .3738 Mdot
1 .57575 Mdot
1 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[54]:=",
  ImageSize->{740.75, 457.813},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000AG0002[R000`400?l00000o`00003oo`3ooooo
0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0
ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3o
oomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?oo
o`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00l@3o
ool4000000H0oooo0P0000050?ooo`H00000_P3oool4000000H0oooo0P0000070?ooo`@00000_`3o
ool4000000H0oooo0P0000070?ooo`@00000_P3oool4000000H0oooo0P0000060?ooo`@00000a`3o
ool700000080oooo003`0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2
000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool2000000T0oooo00<000000?ooo`3oool0_@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0a`3oool0
0`000000oooo0?ooo`030?ooo`00l03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool00`3oool00?00oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`H00000_P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo0P0000030?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0a`3oool00`000000
oooo0?ooo`030?ooo`00l03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00@000000?ooo`3oool00000_`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`0000000P00002m0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool400000<X0oooo00<000000?ooo`3oool00`3oool00?00oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo00000;l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0a`3oool00`000000oooo0?ooo`030?ooo`00l03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2k0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002o0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2n0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0<L0oooo00<000000?ooo`3oool00`3oool00?00oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0^`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000_`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0_@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`350?ooo`<000001@3oool00?40oooo1000000>0?ooo`@00000_`3oool4
00000100oooo0P0000300?ooo`@000004@3oool300000;d0oooo1000000>0?ooo`@00000bP3oool0
0`000000oooo0?ooo`030?ooo`00o`3ooooo0?ooool0ooooo`3ooomK0?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3o
ool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00l00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0000003o0?ooool0ooooo`3ooom_0?oo
o`00:03ooooo00000?l00000o`00003o000002h000001@3oool002P0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo00<0oooo000X0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0dP3oool00`000000
oooo0?ooo`3B0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0dP3oool00`000000
oooo0?ooo`3B0?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo0=80oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00<0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<00000
0?ooo`3oool0a@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomW0?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0<L0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooI@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`390?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooof<0oooo000X0?ooo`030000003oool0oooo0</0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0ooooH@3oool002P0oooo00<000000?ooo`3oool0cP3oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooomN0?ooo`00:03oool00`000000oooo0?ooo`3@0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?oooe`0oooo000X0?ooo`030000003oool0oooo0=80oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0ooooFP3oool002P0oooo00<000000?ooo`3oool0e03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomH0?ooo`00:03oool00`000000oooo0?ooo`3F
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooeH0oooo000X0?ooo`030000003oool0oooo
0=P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooE03oool002P0oooo00<000000?ooo`3o
ool0fP3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomB0?ooo`00:03oool00`000000oooo
0?ooo`3M0?ooo`030000003oool000000?l0ooooo`3ooooo0?ooodl0oooo000X0?ooo`030000003o
ool0oooo0>40oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooB`3oool002P0oooo00<00000
0?ooo`3oool0h`3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom90?ooo`00:03oool00`00
0000oooo0?ooo`3U0?ooo`030000003oool000000?l0ooooo`3ooooo0?ooodL0oooo000X0?ooo`03
0000003oool0oooo0>T0oooo00<000000?ooo`000000o`3ooooo0?ooool0oooo@`3oool002P0oooo
00<000000?ooo`3oool0kP3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooln0?ooo`00:03o
ool00`000000oooo0?ooo`3`0?ooo`030000003oool000000?l0ooooo`3ooooo0?oooc`0oooo000X
0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`000000o`3ooooo0?ooool0oooo>03oool0
02P0oooo00<000000?ooo`3oool0n03oool00`000000oooo0000003o0?ooool0ooooo`3ooold0?oo
o`00:03oool00`000000oooo0?ooo`3l0?ooo`040000003oool0oooo00000?l0ooooo`3ooooo0?oo
obl0oooo000X0?ooo`030000003oool0oooo0?l0oooo0P3oool01@000000oooo0000003oool00000
0?l0ooooo`3ooooo0?ooobT0oooo000X0?ooo`030000003oool0oooo0?l0oooo203oool00`000000
oooo0000003o0?ooool0ooooo`3ooolU0?ooo`00:03oool500000?l0oooo2P3oool010000000oooo
0?ooo`00003o0?ooool0ooooo`3ooolP0?ooo`00:03oool00`000000oooo0?ooo`3o0?oooa40oooo
00D000000?ooo`000000oooo0000003o0?ooool0ooooo`3ooolJ0?ooo`00:03oool00`000000oooo
0?ooo`3o0?oooaL0oooo00D000000?ooo`000000oooo0000003o0?ooool0ooooo`3ooolD0?ooo`00
:03oool00`000000oooo0?ooo`3o0?oooad0oooo00H000000?ooo`3oool000000?ooo`00003o0?oo
ool0ooooo`3oool=0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`00
0000o`3ooooo0?ooool0oooo2@3oool002P0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`070000
003oool000000?ooo`000000oooo0000003o0?ooool0ooooo`3oool10?ooo`00:03oool00`000000
oooo0?ooo`3o0?oooc40oooo00D000000?ooo`000000oooo0000003o0?ooool0oooon@3oool002P0
oooo00<000000?ooo`3oool0o`3ooolg0?ooo`050000003oool000000?ooo`000000o`3ooooo0?oo
oo<0oooo000X0?ooo`030000003oool0oooo0?l0oooo?@3oool020000000oooo0?ooo`000000oooo
0000003oool00000o`3ooooo0?ooonX0oooo000X0?ooo`030000003oool0oooo0?l0ooooAP3oool0
1`000000oooo0000003oool000000?ooo`000000o`3ooooo0?ooon80oooo000X0?ooo`030000003o
ool0oooo0?l0ooooCP3oool01P000000oooo0?ooo`000000oooo00000?l0ooooo`3ooooK0?ooo`00
:03oool00`000000oooo0?ooo`3o0?oooeD0oooo00L000000?ooo`000000oooo0000003oool00000
0?l0ooooo`3ooooC0?ooo`00:03oool00`000000oooo0?ooo`3o0?oooed0oooo00X000000?ooo`3o
ool000000?ooo`000000oooo0000003oool00000o`3ooooo0?ooolP0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooJ03oool01`000000oooo0000003oool000000?ooo`000000o`3ooooo0?oool00
oooo000X0?ooo`030000003oool0oooo0?l0ooooL@3oool02@000000oooo0000003oool000000?oo
o`000000oooo0000003o0?ooool0oooo]@3oool002P0oooo00<000000?ooo`3oool0o`3ooomk0?oo
o`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`3o0?ooool0ooooZP3oool0
02P0oooo00<000000?ooo`3oool0o`3ooon40?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000?l0ooooo`3ooonR0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohh0oooo00`0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00003o0?ooool0ooooU@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooonK0?ooo`050000003oool000000?ooo`0000000P3o
ool00`000000oooo0000003o0?ooool0ooooRP3oool002P0oooo00<000000?ooo`3oool0o`3ooonV
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000o`3ooooo0?oo
ogh0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo
0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`
0?ooo`00:03oool500000?l0ooooo`3ooooo0?ooool0oooo;P3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo
<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0
oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
ond0oooo00<000000?ooo`3oool0?`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
ooook@3oool00`000000oooo0?ooo`020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000003@0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooond0oooo00<00000
0?ooo`3oool00P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000002T0oooo000X0?ooo`D00000o`3ooooo
0?ooool0ooooj`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo00@000000?ooo`3oool000007P3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooook@3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`00000D0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
ooo]0?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000002`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooofP3oool00`000000oooo0?ooo`0E0?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`070000
003oool000000?ooo`000000oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooooJ0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`00
0000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooH0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooH0?ooo`030000
003oool0000001L0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo00<0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooomH0oooo00D000000?ooo`000000
oooo0000000B0?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`0?0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000002`3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooeP3oool01@000000oooo0?ooo`3oool00000
0180oooo00<000000?ooo`3oool00P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooD0?ooo`070000003oool000000?ooo`000000oooo0000
000G0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00h000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00H00000
0?ooo`3oool000000?ooo`00000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oooD0?ooo`070000003oool000000?ooo`000000oooo0000000B0?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000103o
ool00`000000oooo0?ooo`090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooD
0?ooo`070000003oool000000?ooo`000000oooo0000000B0?ooo`030000003oool0oooo0080oooo
00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000<0oooo018000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`03
0000003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooom@0oooo
00L000000?ooo`3oool0oooo0000003oool000000180oooo00<000000?ooo`3oool00P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool0
0`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooD0?oo
o`070000003oool000000?ooo`000000oooo0000000G0?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000030?ooo`030000003oool000000080oooo00<000000?ooo`0000002`3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooe03oool01`000000oooo0000003oool00000
0?ooo`0000004P3oool00`000000oooo0?ooo`040?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000030?ooo`040000003oool0oooo000000<0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000/0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooom00oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool0oooo
00/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooom00oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0000001/0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3oooo@0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`03
0000003oool0oooo01D0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3oooo>0?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000000I
0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`030000003oool0000000X0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000/0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooolh0oooo00<000000?ooo`0000000`3oool01@000000
oooo0000003oool0000001T0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00@0
00000?ooo`3oool000000`3oool01`000000oooo0000003oool000000?ooo`0000002P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooocP3oool00`000000oooo
000000030?ooo`050000003oool000000?ooo`0000006@3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000000:0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3oooo;0?ooo`040000003oool0oooo000000D0oooo00L000000?ooo`000000oooo0000
003oool0000001L0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000002P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooob`3oool01P000000
oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000005P3oool00`000000oooo0?ooo`02
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@00
0000oooo0000003oool000000?ooo`000000oooo0000000:0?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`030000003oool0000000/0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?oool/0oooo00@000000?ooo`3oool000001@3oool01@000000
oooo0?ooo`3oool0000001T0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000000>0?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000/0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oool/0oooo00@000000?ooo`3oool000001@3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000005`3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000040?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00`0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooolT0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0000001@0oooo
00<000000?ooo`3oool00P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0000000<0?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000;
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo;0?ooo`040000003oool0oooo
000000L0oooo00<000000?ooo`000000503oool00`000000oooo0?ooo`020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo0000000<0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3oooo90?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool0
1`000000oooo0000003oool000000?ooo`0000005`3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00000>0?ooo`0;
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo90?ooo`030000003o
ool0000000P0oooo00L000000?ooo`000000oooo0000003oool000000180oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`00000B0?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooolT0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
3P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000090?ooo`000P3oool4000000H0oooo0P0000050?ooo`H000003`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo90?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000005P3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000090?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`030?ooo`800000
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0oooob`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool00P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000@0oooo00D000000?ooo`000000oooo0000000B0?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000/0oooo00000`3oool000000?ooo`030?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3oooo@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0403oool01@000000
oooo0000003oool000000080oooo00<000000?ooo`0000002`3oool000030?ooo`000000oooo00<0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooolD0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000090?oo
o`030000003oool000000180oooo00<000000?ooo`3oool00P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000D0?oo
o`030000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`00000;0?ooo`0000<0oooo
0000003oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo1`00003o
0?ooool0ooooo`3oooo10?ooo`070000003oool0oooo0?ooo`000000oooo0000000Q0?ooo`030000
003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool000000180oooo00<000000?ooo`3oool01`3oool01P000000oooo0?oo
o`000000oooo000000<0oooo00<000000?ooo`3oool01@3oool000030?ooo`000000oooo00<0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooolD0oooo00L000000?ooo`3oool0oooo0000003oool0000000X0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000001X0oooo00P000000?oo
o`3oool000000?ooo`000000oooo000000T0oooo00000`3oool000000?ooo`030?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?oool/0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?oo
o`3oool0000001@0oooo00<000000?ooo`3oool00P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000001d0
oooo00D000000?ooo`3oool0oooo000000070?ooo`0000<0oooo0000003oool00`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3oooo30?ooo`030000003oool0000000<0oooo00<000000?ooo`00
0000203oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000`0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00080oooo1000000>0?ooo`@00000403oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3oooo30?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool000000180oooo00<00000
0?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000000>0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`0000001@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0oooo``3oool00`000000oooo000000030?ooo`030000003oool0000000P0oooo
00L000000?ooo`000000oooo0000003oool000000100oooo00<000000?ooo`000000103oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000000U0?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3oooo30?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0D0?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3oooo10?ooo`050000003oool000000?ooo`0000001@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0000000@0oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
`@3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000
oooo0?ooo`050?ooo`030000003oool000000100oooo00<000000?ooo`000000103oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000001@3oool01P000000oooo0?ooo`000000oooo000001`0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oool40oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0000000@0?ooo`030000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000
oooo0?ooo`0D0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo10?ooo`030000
003oool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`000000103oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo0000
01P0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oookl0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool0403oool00`000000oooo000000040?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000X0oooo00<000000?ooo`3oool02@3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0oooo_`3oool01`000000oooo0000003oool000000?ooo`000000
1@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0000000h0oooo00D000000?ooo`00
0000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000<0oooo
00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000001@0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oookl0oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0000000`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000180oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?oookl0oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000180oooo00<00000
0?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000000P3o
ool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000000@0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooono0?ooo`070000003o
ool000000?ooo`000000oooo000000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool04000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000060?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000100
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oookl0oooo00L000000?ooo`000000
oooo0000003oool000000100oooo00<000000?ooo`0000003P3oool01`000000oooo0?ooo`3oool0
00000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
0P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo0180
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`030000003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0
oooo/`3oool00`000000oooo0?ooo`3o0?ooool0oooo2@3oool01`000000oooo0?ooo`3oool00000
0?ooo`000000203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000000L0oooo018000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`030000003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oookl0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0
oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo0000
00050?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000P3oool01@000000oooo0000003oool0000000T0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?oookl0oooo00D000000?ooo`000000oooo0000000B
0?ooo`050000003oool000000?ooo`000000303oool01`000000oooo0?ooo`3oool000000?ooo`00
0000103oool02@000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`040000003oool0oooo000000<0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3o
oone0?ooo`030000003oool0oooo0?l0ooooo`3oool70?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00`0oooo
00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000103oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003o
ool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo^P3oool00`000000
oooo0?ooo`040?ooo`050000003oool000000?ooo`0000001@3oool010000000oooo0?ooo`000009
0?ooo`030000003oool0000000`0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo
00D000000?ooo`000000oooo000000080?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`090?ooo`00:03o
ool00`000000oooo0?ooo`3o0?oookL0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0000000<0?ooo`070000003oool0oooo0?ooo`000000oooo00000004
0?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`0;0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?oo
o`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3oooni0?ooo`030000003oool0oooo0?l0
ooooo@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000`0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000103oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?oook/0oooo
00<000000?ooo`3oool0o`3ooook0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000
oooo000000070?ooo`040000003oool0oooo000000D0oooo00L000000?ooo`000000oooo0000003o
ool0000000`0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool02@3oool0
02P0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`030000003oool0oooo0?l0oooon@3oool00`00
0000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo0000000>0?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`070000003o
ool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool000000080oooo00l000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`00:03oool00`000000oooo0?oo
o`3o0?oookl0oooo00<000000?ooo`3oool0o`3ooooe0?ooo`030000003oool0000000@0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000D0oooo00@000000?ooo`3oool000004P3oool00`00
0000oooo0?ooo`030?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00<000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000050?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000/0oooo000X0?ooo`03
0000003oool0oooo0?l0oooo`P3oool00`000000oooo0?ooo`3o0?oooo80oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0203oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`3oool00`3oool01`00
0000oooo0?ooo`3oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`000000103oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0
ooooa03oool00`000000oooo0?ooo`3o0?oooo00oooo00<000000?ooo`0000001P3oool00`000000
oooo000000070?ooo`030000003oool0oooo00P0oooo00D000000?ooo`000000oooo000000060?oo
o`030000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00l000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool0
00000?ooo`00000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3o
ool0o`3oooo^0?ooo`030000003oool0000000H0oooo00<000000?ooo`0000001`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool03@000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000
oooo0000000:0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
1@3oool002P0oooo00<000000?ooo`3oool0o`3oooo80?ooo`030000003oool000000?l0ooook03o
ool01@000000oooo0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool00000
0100oooo00D000000?ooo`3oool0oooo0000000<0?ooo`070000003oool0oooo0?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`0000001@3oool010000000oooo0?ooo`0000030?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooc03oool00`000000
oooo0?ooo`3o0?ooonH0oooo00D000000?ooo`000000oooo000000080?ooo`030000003oool00000
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`070000003oool0oooo
0?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0o`3oooo>0?ooo`03
0000003oool000000?l0ooooi03oool01@000000oooo0000003oool0000000H0oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`050?ooo`070000
003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0oooo00`0oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000000@0?ooo`00:03o
ool500000?l0ooood@3oool00`000000oooo0?ooo`3o0?oooml0oooo00D000000?ooo`000000oooo
000000060?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool02P3oool00`000000oooo
000000040?ooo`030000003oool0oooo00D0oooo00L000000?ooo`3oool0oooo0000003oool00000
00@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`0=0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000050?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo0?l0ooooe@3o
ool00`000000oooo0000003o0?ooomd0oooo00<000000?ooo`0000001P3oool01`000000oooo0000
003oool000000?ooo`0000003P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool0
0`000000oooo000000050?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool00000
00/0oooo000X0?ooo`030000003oool0oooo0?l0oooof@3oool00`000000oooo0000003o0?ooomT0
oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo0000
00030?ooo`030000003oool0000000P0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo0?ooo`030?ooo`070000003oool0oooo0?ooo`000000oooo0000
00040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000001P3oool00`000000oooo0000000;0?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooomd0oooo00<000000?ooo`000000o`3ooooC0?ooo`070000
003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo0000
00050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`030000003oool0000000D0oooo00L000000?ooo`3oool0oooo0000003oool0000000P0
oooo00<000000?ooo`3oool0203oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000203o
ool00`000000oooo0?ooo`0;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooon40oooo00@00000
0?ooo`3oool00000o`3oooo>0?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00L000000?ooo`3oool0oooo
0000003oool0000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0o`3ooooV0?oo
o`030000003oool0oooo0?l0oooobP3oool01`000000oooo0000003oool000000?ooo`000000103o
ool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool00`3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo000000060?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000050?ooo`040000003oool0oooo000000d0oooo
000X0?ooo`030000003oool0oooo0?l0ooooj03oool01@000000oooo0000003oool000000?l0oooo
aP3oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0000000<0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000001@3oool01P000000oooo0?ooo`000000
oooo000000D0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`00
00002@3oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`0000001@3oool03000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000D0oooo00@000000?oo
o`3oool000003@3oool002P0oooo00<000000?ooo`3oool0o`3oooo^0?ooo`030000003oool00000
0?l0oooo`P3oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00L000000?oo
o`3oool0oooo0000003oool0000000P0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`040000003oool0oooo0000
00<0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool00000
0?ooo`00000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?oooo<0oooo00<000000?ooo`000000
o`3ooonm0?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`050000003oool00000
0?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000001@3oool01`000000oooo0?ooo`3oool00000
0?ooo`000000203oool00`000000oooo0?ooo`0:0?ooo`070000003oool0oooo0?ooo`000000oooo
000000030?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooooL0oooo00<000000?ooo`000000o`3oooni0?ooo`070000003oool000000?ooo`000000oooo
000000080?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo
000000050?ooo`070000003oool0oooo0?ooo`000000oooo0000000A0?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`0@0?ooo`00:03oool00`000000
oooo0?ooo`3o0?oooo/0oooo00<000000?ooo`000000o`3ooone0?ooo`070000003oool000000?oo
o`000000oooo000000080?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?ooo`3oool01@3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000004@3oool02`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000
003oool000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000/0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3oool00`000000oooo0000003o0?oook40oooo00L000000?oo
o`000000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000D0
oooo00<000000?ooo`3oool01P3oool01@000000oooo0000003oool0000000<0oooo00H000000?oo
o`3oool000000?ooo`0000050?ooo`070000003oool0oooo0?ooo`000000oooo0000000<0?ooo`03
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
00<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000001`3oool00`000000
oooo0?ooo`0>0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo1@3oool01@000000oooo
0000003oool000000?l0ooooZP3oool01`000000oooo0000003oool000000?ooo`0000002P3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo000000T0oooo00D000000?ooo`000000oooo
000000020?ooo`030000003oool0000000D0oooo00D000000?ooo`3oool0oooo000000060?ooo`05
0000003oool0oooo0?ooo`000000203oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000
oooo000000060?ooo`030000003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3oool;0?ooo`030000003oool000000?l0ooooYP3oool01`000000oooo0000003oool000000?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`0000001@3oool00`000000oooo0?oo
o`060?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0000000D0
oooo00D000000?ooo`3oool0oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo0000
00060?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000030?ooo`080000
003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0oooo3`3oool00`000000oooo0000003o0?oooih0oooo00<000000?ooo`3oool00`3oool01@00
0000oooo0000003oool0000000P0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0:
0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`050000003o
ool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000D0
oooo00D000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000002P3oool00`000000oooo0?ooo`090?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0oooo4`3oool01P000000oooo0?ooo`000000oooo00000?l0ooooU`3oool0
2`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000H0oooo00D000000?oo
o`000000oooo000000050?ooo`040000003oool0oooo000000D0oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`070000003oool0oooo
0?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
000000060?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000`3oool00`000000oooo000000020?oo
o`030000003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolJ0?ooo`03
0000003oool000000?l0ooooT`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
000:0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool02P3oool01@000000oooo0000
003oool000000080oooo00<000000?ooo`0000001@3oool01`000000oooo0?ooo`3oool000000?oo
o`000000303oool00`000000oooo0?ooo`040?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool0000000<0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3o
ool01@000000oooo0000003oool000000100oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oolN0?ooo`030000003oool000000?l0ooooS`3oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000080?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo00000008
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000X0oooo00<000000?ooo`3o
ool01`3oool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo0000000@0?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0oooo8P3oool01P000000oooo0?ooo`000000oooo00000?l0ooooR03oool02`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`000000
1@3oool00`000000oooo0?ooo`080?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0000000<0oooo00`0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00000:0?ooo`030000003o
ool0oooo00T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooolY0?ooo`030000003oool0
00000?l0ooooPP3oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool00000
00@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool01P000000oooo
0?ooo`000000oooo000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?oo
o`050000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`09
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo;@3oool01@000000oooo0000003oool0
00000?l0ooooO03oool00`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo
000000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000001P3oool01@000000oooo0000003oool0000000P0oooo00<000000?ooo`0000000`3o
ool01`000000oooo0000003oool000000?ooo`0000004P3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?oooc<0oooo00@000000?ooo`3oool00000o`3ooomg0?ooo`030000003oool0000000<0
oooo00D000000?ooo`000000oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo0000
000@0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0000000D0
oooo00<000000?ooo`3oool0203oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
10000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`0000000`3oool01P000000oooo
0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooocP0oooo00<000000?ooo`000000o`3ooomc0?ooo`030000003oool0000000<0
oooo00D000000?ooo`000000oooo000000080?ooo`030000003oool0000000D0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00D0oooo00@000000?ooo`3oool000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00L000000?ooo`000000
oooo0000003oool0000000@0oooo00<000000?ooo`3oool02`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooc`0oooo00D000000?ooo`000000oooo0000003o0?ooofd0oooo00<000000?oo
o`0000000`3oool01`000000oooo0000003oool000000?ooo`0000003P3oool00`000000oooo0000
00080?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo0000
00040?ooo`030000003oool0oooo00/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooom2
0?ooo`030000003oool000000?l0ooooJ@3oool00`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000`0oooo00D0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00/0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooom70?ooo`030000003oool000000?l0ooooH@3oool01P000000oooo
0?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00D0
00000?ooo`000000oooo000000050?ooo`040000003oool0oooo000000D0oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool01@3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00D000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool000001@3o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oood/0oooo00<000000?ooo`000000o`3ooomM
0?ooo`060000003oool0oooo0000003oool000000`3oool01`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000070?ooo`030000003oool0oooo00P0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00H0oooo00D000000?ooo`000000oooo000000070?ooo`030000003oool0oooo00h0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool000000?l0oooo
F@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003o
ool0000000@0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`00
0000103oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo000000080?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo000000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0000
00080?ooo`030000003oool0oooo00/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomC
0?ooo`040000003oool0oooo00000?l0ooooE03oool01P000000oooo0?ooo`000000oooo000000<0
oooo00L000000?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`3oool02P3oool0
3@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0000000B0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00@000000?oo
o`3oool000001@3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool03P3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooeP0oooo00<000000?ooo`000000o`3ooom@
0?ooo`060000003oool0oooo0000003oool000000`3oool01`000000oooo0000003oool000000?oo
o`0000001P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000B0?ooo`030000
003oool0000000D0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<00000
0?ooo`0000001P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000103oool00`000000oooo0?ooo`0;0?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooG03oool00`000000oooo0000003o0?oood`0oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0000
003oool0000000h0oooo00<000000?ooo`0000001@3oool01P000000oooo0?ooo`000000oooo0000
0180oooo00D000000?ooo`000000oooo000000080?ooo`070000003oool0oooo0?ooo`000000oooo
000000050?ooo`080000003oool0oooo0000003oool000000?ooo`0000070?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
of00oooo00<000000?ooo`3oool0o`3ooom80?ooo`060000003oool0oooo0000003oool000000`3o
ool01`000000oooo0000003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool00000
0100oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000004P3o
ool00`000000oooo000000030?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00/0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooomR0?ooo`030000003oool000000?l0ooooAP3oool0
1P000000oooo0?ooo`000000oooo000000D0oooo00<000000?ooo`0000001P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`00000;0?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000060?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000`3oool00`000000oooo000000020?ooo`030000003o
ool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooomW0?ooo`030000003oool0
oooo0?l0oooo@@3oool00`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool0000000H0oooo00L000000?ooo`3oool0oooo0000003oool0000000P0oooo00<00000
0?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool000000100oooo00D000000?ooo`000000oooo0000000>0?ooo`050000003oool0oooo
0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`00:03oool500000?l0ooooo`3ooomW
0?ooo`030000003oool000000?l0oooo?`3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0303oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003o
ool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000/0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooom]0?ooo`030000003oool0oooo0?l0oooo>`3oool01P000000
oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`000000oooo000000020?ooo`030000003oool0000001P0oooo00<000000?ooo`00
00002P3oool00`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00L000000?oo
o`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000002`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooofl0oooo00<000000?ooo`3oool0o`3oooli0?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`0000002P3oool01@000000oooo0?ooo`3oool0000000D0oooo
00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`050000003oool000000?ooo`000000503oool00`000000oooo0?ooo`06
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3o
ool000000`3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooL@3oool00`00
0000oooo0?ooo`3o0?ooocL0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003o
ool000000?ooo`000000203oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`030000003oool000000100oooo00D000000?ooo`000000oooo000000080?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0oooo00/0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooomc0?ooo`030000003oool0oooo0?l0oooo=@3oool01P000000oooo0?ooo`000000oooo
000000<0oooo00D000000?ooo`000000oooo0000000<0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool00`000000oooo0000000D0?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0000000H0oooo00<0
00000?ooo`3oool00`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo00/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooj/0
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000001P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`0=
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000001H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool00000
00D0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool00000
0?ooo`0000001@3oool00`000000oooo0?ooo`0@0?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooM@3oool00`000000oooo0?ooo`3o0?oooc<0oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`050000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?oo
o`000000203oool00`000000oooo000000070?ooo`050000003oool000000?ooo`0000000P3oool0
0`000000oooo0000000M0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000002@3oool01P000000oooo0?oo
o`000000oooo000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooj/0oooo
00@000000?ooo`3oool000001`3oool00`000000oooo0000000:0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo000000070?ooo`050000003oool000000?oo
o`0000000P3oool00`000000oooo0000000H0?ooo`030000003oool0oooo00H0oooo00L000000?oo
o`000000oooo0000003oool0000000P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?oooj/0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool0oooo0?ooo`00
00001P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`000000503oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0?ooo`3o
ool000000?ooo`000000203oool00`000000oooo0?ooo`0;0?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooon[0?ooo`060000003oool0oooo0000003oool000000`3oool01@000000
oooo0000003oool000000100oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`050?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000001@0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000X0oooo00<000000?ooo`000000203oool01@000000
oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0;0?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`060000003oool0oooo0000
003oool000000`3oool01@000000oooo0000003oool0000000H0oooo00D000000?ooo`3oool0oooo
000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001@3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`0>0?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooon[0?ooo`060000003oool0oooo0000003oool000001@3oool00`000000oooo0000
00080?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000
003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000001@3oool00`000000oooo000000040?ooo`030000003oool0oooo00/0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooj/0oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001@3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool000000?ooo`00
00001@3oool00`000000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooZ`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000
3P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0?ooo`050?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo0180oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooZ`3oool010000000oooo0?ooo`0000050?ooo`050000003oool00000
0?ooo`000000203oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool04P3oool00`000000oooo000000030?ooo`030000003oool00000
00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooon^0?ooo`030000003oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000080?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool00P3oool03@00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo0?ooo`0@0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`050000
003oool0oooo0?ooo`0000001P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`060000003oool0oooo0000003oool000001@3oool01@00
0000oooo0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000001L0oooo00D000000?ooo`3oool0oooo000000030?ooo`060000003o
ool0oooo0000003oool000000`3oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool02`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooZ`3oool01P000000
oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000001D0oooo00<000000?ooo`3oool00`3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00<000000?ooo`3oool02`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooZ`3o
ool01P000000oooo0?ooo`000000oooo000000D0oooo00D000000?ooo`000000oooo000000060?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0
000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000005@3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool0
00000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000D0oooo00<000000?ooo`00
0000403oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo[P3oool00`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`090?ooo`06
0000003oool0oooo0000003oool000000`3oool02@000000oooo0000003oool000000?ooo`000000
oooo0000000E0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000X0oooo00<000000?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00<000000?ooo`3oool02`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooZ`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo
0000003oool0000000P0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000005@3o
ool00`000000oooo0000000>0?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`0;
0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
0?ooo`090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo
00D000000?ooo`3oool0oooo000000050?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool00`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000000E0?ooo`030000003o
ool0000000X0oooo00<000000?ooo`3oool04P3oool02`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooZ`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3oool01`3oool00`000000
oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0
000001L0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooZ`3oool0
10000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo
0?ooo`070?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool01`000000oooo
0000003oool000000?ooo`0000005`3oool01@000000oooo0000003oool0000000D0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0000000>0?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`030000003oool0000000/0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?oooj/0oooo00@000000?ooo`3oool000001@3oool01@000000oooo
0000003oool0000000`0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<00000
0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000005`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0000000X0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000/0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooojh0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`08
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000001d0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo0000000:
0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000003@3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0oooo/03oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo0000000:0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool02`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000002h0oooo00<000000?ooo`3oool0
203oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<0
00000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooZ`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00L000000?ooo`000000oooo0000
003oool0000001/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`070000
003oool000000?ooo`000000oooo0000000:0?ooo`030000003oool0000000<0oooo00<000000?oo
o`000000103oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooon[0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000002P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000006@3oool00`000000oooo000000070?ooo`030000003o
ool0oooo0080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000002P3oool00`00
0000oooo0000000:0?ooo`030000003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooojh0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000080?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000060?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool0000001T0oooo00D000000?ooo`000000oooo000000080?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000303oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`060000003oool0oooo0000003o
ool000002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000<0oooo00<000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000006@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool000000080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0000000B0?ooo`030000003oool000000100oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?oook00oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
103oool00`000000oooo0?ooo`030?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000>0?oo
o`050000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`00000=0?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`060000003oool0oooo0000003oool00000
0`3oool01@000000oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0
000001T0oooo00<000000?ooo`0000001@3oool00`000000oooo000000040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`000000403oool01@000000oooo0000003oool000000100oooo000X
0?ooo`D00000o`3ooooo0?ooool0oooo[03oool00`000000oooo000000030?ooo`030000003oool0
000000P0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool00`000000oooo000000030?ooo`030000003oool0000002<0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`0F0?ooo`050000003oool000000?ooo`000000103oool00`000000
oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`030000
003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000`0oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo0000
000F0?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool00P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
000@0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool02`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0oooo[P3oool00`000000oooo0000000B0?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0
000001l0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000L0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo[P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00L000000?ooo`3oool0oooo
0000003oool0000000D0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool0
00000?ooo`0000006@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000002P3oool01@000000
oooo0?ooo`3oool0000000D0oooo00H000000?ooo`3oool000000?ooo`00000;0?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`030000003oool0oooo0080oooo00L00000
0?ooo`3oool0oooo0000003oool0000000P0oooo00L000000?ooo`000000oooo0000003oool00000
00P0oooo00<000000?ooo`0000000`3oool00`000000oooo0000000K0?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000060?ooo`070000003oool0oooo0?ooo`000000oooo
0000000>0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo
00/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooojh0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0000000:0?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo000000040?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0E
0?ooo`070000003oool0oooo0?ooo`000000oooo000000080?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000002P3oool00`000000oooo000000030?ooo`030000003oool0oooo0180oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooojh0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0000000:0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool07`3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000@0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooooZ`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?oo
o`000000oooo000000080?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`070000
003oool000000?ooo`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool0000000`0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?oo
o`3oool02`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooZ`3oool00`000000
oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000080?ooo`070000003oool0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000001T0oooo00D000000?ooo`000000oooo0000000B0?oo
o`030000003oool0oooo00X0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo0?ooo`0;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oon^0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0000000L0
oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`030000003oool0000000`0oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00h0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?oooj/0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000
003oool0000000X0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080
oooo00<000000?ooo`0000008@3oool01@000000oooo0000003oool0000000X0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000<0oooo00<000000?oo
o`000000103oool00`000000oooo0?ooo`090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooon[0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`08
0?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003o
ool000000240oooo00<000000?ooo`0000003P3oool01`000000oooo0000003oool000000?ooo`00
00002P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooZ`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000303oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000050?ooo`03
0000003oool0000001T0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool00000
00P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000003oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000/0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?oooj/0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000
003oool0000000P0oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000P3oool00`000000oooo0000000Q0?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo0000
000>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0oooo[P3oool00`000000oooo000000050?ooo`030000003oool0
oooo00P0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D0
00000?ooo`000000oooo0000000Q0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
2P3oool00`000000oooo0?ooo`0>0?ooo`050000003oool000000?ooo`000000103oool00`000000
oooo0?ooo`0;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`030000
003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000P0oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000
003oool0000002h0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooZ`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`030000003oool000000240oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`00000;
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo0100oooo00D000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooojh0oooo
00<000000?ooo`3oool03P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<000000?ooo`000000503oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0oooo[P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool0103oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool00`000000oooo000000050?ooo`030000003oool0000001@0oooo00<000000?ooo`3oool00P3o
ool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000403oool00`000000oooo000000080?ooo`03
0000003oool0oooo00T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooojh0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000<0oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`000000703oool00`00
0000oooo0?ooo`040?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool000001`3oool0
0`000000oooo0?ooo`0:0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`060000
003oool0oooo0000003oool000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
ooooZ`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003
0?ooo`030000003oool0000001d0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo
00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo/03o
ool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo
00D0oooo00D000000?ooo`3oool0oooo0000000I0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool02P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0100oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooj/0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool000000100oooo00<000000?ooo`3oool00`3oool01P000000oooo0?oo
o`000000oooo000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa80oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000001/0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0?ooo`3oool000000?ooo`000000403oool00`000000oooo0?ooo`03
0?ooo`060000003oool0oooo0000003oool000002`3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0oooo4P3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`000000
S@3oool01P000000oooo0?ooo`000000oooo000000T0oooo00<000000?ooo`3oool00P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000000>
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0000000;
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool90?ooo`030000003oool0oooo
00H0oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
000000290?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000203oool01`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo0000000I0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool02P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
oooo1`3oool00`000000oooo000000080?ooo`050000003oool000000?ooo`000000103oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000270?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?oo
o`000000oooo000000030?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool05`3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo0000
000<0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool70?oo
o`030000003oool0000000P0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool0
00000?ooo`0000001@3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0
000001d0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0000000X0oooo00<0
00000?ooo`3oool02P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool00`000000
oooo0?ooo`0;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool70?ooo`030000
003oool0000000P0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo000000230?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`000000203oool01@000000oooo0?ooo`3oool0000001T0
oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`0000001@3oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0000
000;0?ooo`000P3oool4000000H0oooo0P0000070?ooo`@000003`3oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3oool70?ooo`030000003oool0000000P0oooo00D000000?ooo`000000oooo0000
00040?ooo`030000003oool0000000L0oooo00D000000?ooo`000000oooo000000020?ooo`030000
003oool0oooo07l0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000H0
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000203oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool0
1`000000oooo0000003oool000000?ooo`0000003P3oool00`000000oooo000000070?ooo`030000
003oool0oooo00h0oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00<0oooo0P00
00090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo1`3o
ool00`000000oooo000000080?ooo`050000003oool000000?ooo`000000103oool00`000000oooo
000000070?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
07l0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000040?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0000000D0?ooo`050000003oool000000?ooo`0000000`3oool01P000000oooo
0?ooo`000000oooo000000/0oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool90?ooo`03
0000003oool0oooo00H0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo
00L0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
0000001k0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000060?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo0000000H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo0000000D0?ooo`07
0000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0000000/0oooo00000`3o
ool000000?ooo`030?ooo`030000003oool0oooo00X0oooo1P00000?0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooo`L0oooo00<000000?ooo`000000203oool01@000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00H0oooo00D0
00000?ooo`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool000000180oooo00D0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000/0oooo00000`3oool000000?oo
o`030?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool00000403oool700000?l0oooo
o`3ooooo0?ooo`D0oooo00<000000?ooo`3oool01P3oool01@000000oooo0000003oool0000000@0
oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`050000003oool000000?oo
o`0000001@3oool00`000000oooo0000001b0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0E0?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080
oooo00D000000?ooo`000000oooo0000000>0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000403oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0
2`3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo`L0
oooo00<000000?ooo`000000203oool01@000000oooo0000003oool0000000@0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000007X0oooo00<000000?oo
o`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?oo
o`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`0000<0
oooo0000003oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool000000100oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooo2@3oool00`000000oooo0?ooo`060?ooo`050000003o
ool000000?ooo`000000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool01P3oool01`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`0000001@3oool00`000000oooo0?ooo`0T0?ooo`050000003oool000000?ooo`00
00001@3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00000B0?ooo`070000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00T0oooo00000`3oool0
00000?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000403oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3oool70?ooo`030000003oool0000000P0oooo00D000000?ooo`00
0000oooo000000040?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0103oool01`00
0000oooo0000003oool000000?ooo`000000N03oool00`000000oooo0?ooo`060?ooo`070000003o
ool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0000002H0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`0;0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`000P3oool4
00000100oooo0P00000@0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo`L0oooo00<00000
0?ooo`000000203oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`000000O@3oool00`000000oooo
000000030?ooo`050000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool00000
0?ooo`0000001@3oool00`000000oooo0?ooo`0T0?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000403oool01`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3oool90?ooo`030000003oool0oooo00H0oooo00D000000?ooo`00
0000oooo000000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool01`00
0000oooo0000003oool000000?ooo`000000N03oool00`000000oooo0?ooo`020?ooo`070000003o
ool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00L000000?ooo`00
0000oooo0000003oool0000000D0oooo00<000000?ooo`3oool0903oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000002`3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo2@3oool00`000000oooo0?ooo`060?ooo`05
0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`000000oooo0000001j0?ooo`040000003oool0oooo000000D0oooo00L0
00000?ooo`000000oooo0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00@000000?ooo`3oool000008`3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0B
0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3oool70?ooo`030000003oool0000000P0oooo00D00000
0?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
000000060?ooo`050000003oool000000?ooo`000000NP3oool01P000000oooo0?ooo`000000oooo
000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool0000000D0oooo00<000000?ooo`3oool0903oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool000000180oooo
00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000/0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooo`L0oooo00<000000?ooo`000000203oool01@000000
oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000H0oooo00D000000?ooo`000000oooo0000001j0?ooo`060000003oool0oooo0000003oool0
00000`3oool01`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`0000004P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`00000@0?ooo`030000003oool0000000<0oooo00H000000?oo
o`3oool000000?ooo`00000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooom@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo07X0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`07
0000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool03P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0oooo00/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooe0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
00060?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`1j0?ooo`060000003oool0oooo0000003oool000000`3o
ool01`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool00`000000oooo0000000V0?ooo`090000003oool000000?ooo`000000oooo
0000003oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool000000180oooo00<00000
0?ooo`3oool00`3oool01P000000oooo0?ooo`000000oooo000000/0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooo`L0oooo00<000000?ooo`000000203oool01@000000oooo0000
003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool0KP3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo00H000000?ooo`3oool00000
0?ooo`00000S0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<0
00000?ooo`0000003P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?oo
o`030000003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooc0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`000000203oool01@000000oooo0000003oool00000
00@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`030000003oool0000007`0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`070000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool0000000P0oooo00<000000?ooo`0000006`3oool01`000000
oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`00000H0?ooo`070000003o
ool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0oooo00/0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooo`T0oooo00<000000?ooo`3oool01P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<00000
0?ooo`000000103oool00`000000oooo0000001l0?ooo`060000003oool0oooo0000003oool00000
0`3oool01`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0
000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000001H0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<0
00000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo1`3oool0
0`000000oooo000000080?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0oooo07l0
oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003oool000000?ooo`000000103oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000000>0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool00P3oool02`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000000D0?ooo`070000
003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0000000/0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooa0?ooo`030000003oool0oooo0180oooo00<000000?ooo`00
0000203oool00`000000oooo000000060?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo06/0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`070000003oool000000?oo
o`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000060?ooo`030000003oool0oooo01@0oooo00D000000?oo
o`000000oooo000000020?ooo`030000003oool0000000/0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooc0?ooo`030000003oool0oooo0100oooo00<000000?ooo`000000203oool01@00
0000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo07`0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0000001@0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000
003oool0000000H0oooo00<000000?ooo`000000503oool01`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooook`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`00
0000203oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo07`0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo0000
00040?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo0000000Q0?ooo`030000
003oool0oooo0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3oool0
0`000000oooo0?ooo`0F0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?oo
o`0;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool70?ooo`030000003oool0
000000P0oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo06T0oooo00<000000?ooo`3oool00P3oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000001`3oool00`000000
oooo0000000>0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool02@000000
oooo0000003oool000000?ooo`000000oooo0000000<0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3oool70?ooo`030000003oool0000000P0oooo00D000000?ooo`000000oooo0000
00040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`050000003oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`1l0?ooo`060000003oool0oooo0000003oool000000`3o
ool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000008`3oool00`000000oooo0?ooo`040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`000000503oool01@000000oooo
0000003oool0000000@0oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooooD0oooo00<000000?ooo`3oool03P3oool00`000000oooo000000080?ooo`030000
003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?oo
o`000000oooo000000020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0I`3oool0
0`000000oooo0?ooo`020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool09P3oool01@000000oooo0000003oool0000000H0oooo00D000000?ooo`3oool0oooo0000
000F0?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`090?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool70?ooo`030000003oool0000000P0oooo00D0
00000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000006@3oool00`000000oooo0?ooo`1U0?ooo`060000003oool0
oooo0000003oool000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo0?ooo`070?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000060?ooo`030000003oool0oooo01@0oooo00D000000?ooo`00
0000oooo0000000@0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooook@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0000000P0oooo00D000000?ooo`000000oooo000000040?oo
o`050000003oool000000?ooo`0000001@3oool00`000000oooo0000000M0?ooo`030000003oool0
oooo06<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool00000103oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`00
00002P3oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0000003oool0000000D0oooo00P000000?ooo`3oool000000?ooo`000000oooo000001H0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3oooo]0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo00000005
0?ooo`030000003oool0000008<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`050000
003oool000000?ooo`000000103oool00`000000oooo0?ooo`090?ooo`060000003oool0oooo0000
003oool00000703oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000001@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103o
ool01@000000oooo0000003oool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
ooo[0?ooo`030000003oool0000001X0oooo00<000000?ooo`3oool01P3oool01@000000oooo0000
003oool0000000@0oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0000001l0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0000001D0?ooo`060000003oool0oooo0000
003oool000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`0000009P3oool02`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooj`3oool00`000000oooo0000000H0?ooo`030000
003oool0000000P0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0000003oool000000240oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool000000500oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00<00000
0?ooo`0000001@3oool00`000000oooo0?ooo`0X0?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`000000503oool01@000000oooo0000003oool00000
00H0oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooon/0
oooo00<000000?ooo`000000603oool00`000000oooo000000080?ooo`050000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`000000903oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04/0oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
01@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3oool02@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooonT0oooo00D000000?ooo`000000oooo0000
000J0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`000000oooo000000040?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo0000000V0?ooo`030000003oool0000000h0
oooo00<000000?ooo`3oool0B@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00L00000
0?ooo`000000oooo0000003oool0000000H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
0000000F0?ooo`050000003oool0oooo0?ooo`000000403oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooonT0oooo00D000000?ooo`000000oooo0000000H0?ooo`030000003oool0000000P0
oooo00<000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`000000>@3oool00`000000oooo0?ooo`170?ooo`060000003oool0oooo0000003oool000000`3o
ool01`000000oooo0000003oool000000?ooo`000000403oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool02`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000H0?ooo`03
0000003oool0000000@0oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooonT0oooo00D000000?ooo`000000oooo0000000J0?ooo`030000003oool0oooo00H0
oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000001@3oool0
0`000000oooo0000000X0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0A@3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool00000
00P0oooo00<000000?ooo`0000009`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`0F0?ooo`05
0000003oool000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooiP3oool020000000oooo0?ooo`000000oooo0000003oool00000603o
ool00`000000oooo000000080?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo
000000050?ooo`030000003oool0000008<0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`070000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`000000303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00L0
00000?ooo`3oool0oooo0000003oool0000000<0oooo00@000000?ooo`3oool000006P3oool01@00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool02`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooonH0oooo00P000000?ooo`3oool000000?ooo`000000oooo000001P0oooo
00<000000?ooo`000000203oool00`000000oooo000000060?ooo`050000003oool000000?ooo`00
00001@3oool00`000000oooo0000000m0?ooo`030000003oool0oooo04<0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000002P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000001X0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooiP3oool020000000oooo0?ooo`000000oooo0000003oool00000603oool00`000000oooo
000000080?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0000003oool00000
00L0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`110?ooo`060000003oool0oooo
0000003oool000000`3oool01@000000oooo0000003oool0000000P0oooo00<000000?ooo`000000
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
103oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000001H0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`000000
2`3oool002P0oooo1@00003o0?ooool0ooooi03oool020000000oooo0?ooo`000000oooo0000003o
ool00000603oool00`000000oooo000000080?ooo`030000003oool0000000H0oooo00<000000?oo
o`0000001`3oool00`000000oooo0000000Z0?ooo`030000003oool0oooo05H0oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000002P3oool00`000000oooo
000000030?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool00P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000603o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000002`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooon@0oooo00<000000?ooo`0000000P3oool01@000000oooo0000
003oool0000001P0oooo00<000000?ooo`000000203oool01@000000oooo0000003oool0000000@0
oooo00<000000?ooo`0000001`3oool00`000000oooo000000110?ooo`030000003oool0oooo03l0
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000001P3o
ool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`060000003oool0oooo
0000003oool000005P3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000/0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooT0?ooo`030000003oool0000000@0oooo00<00000
0?ooo`000000603oool00`000000oooo000000080?ooo`050000003oool000000?ooo`000000103o
ool00`000000oooo000000070?ooo`030000003oool0000002`0oooo00<000000?ooo`3oool0E03o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000203oool01@000000
oooo0?ooo`3oool0000000D0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?oo
o`030000003oool000000080oooo00<000000?ooo`000000;@3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooon@0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool00000
01X0oooo00<000000?ooo`3oool01P3oool01@000000oooo0000003oool0000000@0oooo00<00000
0?ooo`0000001`3oool00`000000oooo0000000^0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0?@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000
303oool00`000000oooo000000030?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0
6@3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo0000000J0?ooo`060000003oool0oooo0000003oool000002`3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooon80oooo00D000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`000000603oool00`000000oooo000000080?ooo`030000003oool0
000000H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`230?ooo`030000003oool0
oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000P0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0000002H0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`000000103oool01@000000oooo0000003oool0000001@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooR0?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000001P0oooo00<000000?ooo`000000203oool01@000000oooo0000003oool00000
00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0>P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`3oool0303oool00`000000oooo000000050?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool000000100oooo00<0
00000?ooo`3oool01`3oool01P000000oooo0?ooo`000000oooo000000/0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooR0?ooo`050000003oool000000?ooo`000000103oool00`000000
oooo0000000H0?ooo`030000003oool0000000P0oooo00D000000?ooo`000000oooo0000000>0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0CP3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`3oool0203oool01@000000oooo0000003oool0000000D0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool00P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo0000000@0?ooo`030000003oool0oooo00L0oooo
00H000000?ooo`3oool000000?ooo`00000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
oooohP3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`000000603oool00`00
0000oooo000000080?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0B`3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000
003oool0000001@0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo0000
00/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooP0?ooo`050000003oool000000?oo
o`000000103oool01@000000oooo0000003oool0000001H0oooo00D000000?ooo`000000oooo0000
00080?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo000000190?ooo`060000003oool0oooo0000
003oool000000`3oool01@000000oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000006`3oool00`000000oooo0000000;0?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooh03oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000001H0oooo00D000000?ooo`000000oooo000000080?ooo`050000
003oool000000?ooo`0000001P3oool00`000000oooo000000050?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0h0?ooo`060000003oool0oooo0000
003oool000000`3oool01@000000oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo
000000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`060?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`070000003oool00000
0?ooo`000000oooo0000000K0?ooo`030000003oool0000000/0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooP0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool000000?ooo`0000005P3oool01@000000oooo0000003oool0000000P0oooo00D000000?oo
o`000000oooo000000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03H0oooo010000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000001P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool00000
01/0oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooomh0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000001H0oooo00D000000?ooo`000000oooo000000080?ooo`050000003oool000000?oo
o`000000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03l0oooo00D000000?oo
o`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool00000
00@0oooo00D000000?ooo`000000oooo0000000W0?ooo`030000003oool0000000P0oooo00<00000
0?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000006`3oool00`000000oooo
000000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooN0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo0000000D0?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`030000
003oool0000000H0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool0<P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00L00000
0?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`020?ooo`0;0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooomh0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000001@0oooo00L000000?ooo`000000oooo0000003oool0000000P0
oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000001@3oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0300oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0503o
ool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool000000080oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooomh0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000001@0oooo00L000000?ooo`000000oooo0000003oool0000000P0
oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo02h0
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000001P3o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`000000103oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
000001T0oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
om`0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo
0000003oool0000001@0oooo00L000000?ooo`000000oooo0000003oool0000000P0oooo00<00000
0?ooo`0000002P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo02/0oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000040?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0000000@0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`0000006`3oool00`000000oooo0?ooo`090?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0oooog03oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo0000000D0?ooo`050000003oool00000
0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00D00000
0?ooo`3oool0oooo0000001O0?ooo`030000003oool0oooo02T0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`050000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`0000001P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000006@3oool01@000000oooo0000003oool0
000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooL0?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000000D0?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000008/0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`050000003oool000000?ooo`0000001P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`000000
1@3oool00`000000oooo0000000I0?ooo`030000003oool0oooo00T0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooL0?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
00@0oooo00D000000?ooo`000000oooo0000000D0?ooo`070000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo02L0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`050000003oool000000?ooo`000000203oool01@000000oooo0000003oool0000000D0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000004P3oool00`00
0000oooo0?ooo`060?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000000>0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000L0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooJ0?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
503oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000001S0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000001@3oool00`000000
oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0
00000100oooo00<000000?ooo`000000103oool02`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooomX0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000090?ooo`03
0000003oool0oooo00P0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000060?ooo`050000003oool0oooo0?ooo`000000I@3o
ool00`000000oooo0?ooo`0S0?ooo`060000003oool0oooo0000003oool000000`3oool01`000000
oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000
oooo0000003oool000000180oooo00<000000?ooo`3oool00P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000000B0?ooo`030000003oool0oooo0100oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooJ0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000002@3oool00`000000oooo
0?ooo`080?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000Q`3o
ool01@000000oooo0?ooo`3oool000000080oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`030000003oool0000002L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooJ0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`000000503oool01`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`3oool0oooo0000001W0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`0000000`3oool0
1`000000oooo0?ooo`3oool000000?ooo`000000103oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`0?0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000002`3oool0
0`000000oooo0?ooo`020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000403oool0
0`000000oooo0?ooo`0B0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooe`3oool04000
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`050000003oool000000?ooo`000000503oool01`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo000000080?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000P3oool00`000000oooo000000070?ooo`050000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000L0oooo00<000000?ooo`3oool0103oool02`000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000
003oool000000?ooo`000000oooo0000000K0?ooo`030000003oool0oooo00L0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooG0?ooo`0<0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000001@0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000060?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00L0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`03
0000003oool0000000H0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`0S0?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooe`3oool040000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`050000003oool000000?ooo`000000503o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool0000000H0oooo00D000000?ooo`3oool0oooo0000001^0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`000000503oool01`000000oooo0000003oool000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000090?ooo`030000003oool0000000@0oooo00/000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0000000>0?ooo`030000003oool0000001@0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooE0?ooo`030000003oool000000080oooo00d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
000<0?ooo`030000003oool0oooo00D0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000060?ooo`030000003oool0oooo0780
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000000@0?ooo`060000
003oool0oooo0000003oool000000`3oool01`000000oooo0000003oool000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000050?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`03
0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo0000000U0?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooe@3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000`0oooo00<00000
0?ooo`3oool01@3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000060?ooo`050000003oool0oooo0?ooo`000000R`3oool01P000000oooo
0?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000001@3oool01@000000oooo0?ooo`3oool0000000H0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo000000030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
1@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooomD0oooo00<000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`080000003oool0oooo
0000003oool000000?ooo`00000<0?ooo`030000003oool0oooo00D0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo000000040?oo
o`070000003oool0oooo0?ooo`000000oooo000000290?ooo`060000003oool0oooo0000003oool0
00000`3oool01`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000005
0?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo
00D000000?ooo`000000oooo000000080?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0B0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
e@3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00D000000?ooo`000000oooo0000000<0?ooo`030000003oool0
oooo00D0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08L0oooo00@000000?ooo`3oool0
00001@3oool01`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000005
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0000000D
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooood`3oool01@000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00L000000?ooo`00
0000oooo0000003oool0000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo08L0oooo00@000000?ooo`3oool000001@3oool01`000000oooo0000
003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`070000003oool0oooo0?oo
o`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`080000
003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooood`3oool0
1@000000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000<0?ooo`030000
003oool0oooo00D0oooo00L000000?ooo`000000oooo0000003oool000000140oooo00L000000?oo
o`000000oooo0000003oool0000008`0oooo00<000000?ooo`0000000`3oool01`000000oooo0000
003oool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`070000003oool0oooo0?oo
o`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000h0
oooo00<000000?ooo`3oool0503oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooom<0oooo
00D000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000303oool00`00
0000oooo0?ooo`050?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`030000003o
ool0000000P0oooo00D000000?ooo`3oool0oooo000000290?ooo`040000003oool0oooo000000D0
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool0
1`000000oooo0?ooo`3oool000000?ooo`000000103oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0@0?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooood`3oool01@000000oooo0000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3oool01`000000oooo0000
003oool000000?ooo`000000203oool01@000000oooo0000003oool0000000P0oooo00<000000?oo
o`000000SP3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000000@0
oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000001@3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000D0oooo00@000000?ooo`3oool000007P3oool002P0oooo
1@00003o0?ooool0ooooc`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`030000003oool0oooo00<0oooo00P000000?ooo`3oool000000?ooo`00
0000oooo000000`0oooo00<000000?ooo`3oool01@3oool01`000000oooo0000003oool000000?oo
o`000000303oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo0000
00290?ooo`060000003oool0oooo0000003oool000000`3oool01`000000oooo0000003oool00000
0?ooo`000000103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo00P0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`3oool0703oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooom40oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo0000000<0?ooo`030000003oool0oooo00D0oooo00L000000?oo
o`000000oooo0000003oool0000000X0oooo00<000000?ooo`000000103oool01`000000oooo0?oo
o`3oool000000?ooo`000000R@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00L00000
0?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000050?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00<0oooo00@000000?ooo`3oool000002@3oool00`000000oooo000000060?ooo`030000003oool0
oooo00T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooA0?ooo`070000003oool00000
0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`05
0000003oool000000?ooo`000000303oool00`000000oooo0?ooo`2D0?ooo`060000003oool0oooo
0000003oool000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0
000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000050?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`060000003oool0oooo0000003oool0
00002@3oool00`000000oooo0?ooo`0@0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
c`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo000000050?ooo`080000003oool0oooo0000003oool000000?ooo`00000<
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0?
0?ooo`050000003oool0oooo0?ooo`000000R`3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00D000000?ooo`3oool0oooo
000000060?ooo`030000003oool0oooo00T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
ooo?0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000
003oool00000303oool00`000000oooo000000050?ooo`050000003oool000000?ooo`0000002P3o
ool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000103o
ool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000090?oo
o`030000003oool0oooo0100oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3oooo?0?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00`0oooo00<000000?ooo`3oool01@3oool01`000000oooo0000003oool000000?ooo`000000203o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08h0oooo00/000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00L00000
0?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000003oool00000303oool00`000000
oooo0?ooo`0;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooc`3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo0000000<0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000U03oool01`000000oooo0?ooo`3oool000000?ooo`000000103o
ool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000050?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`0000000`3oool030000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo000001H0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3oooo=0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo0000000>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`000000103oool01@000000oooo
0?ooo`3oool0000008h0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`020?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<00000
0?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0000000D0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000001@0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3oooo?0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0000000>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000002;0?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000070?ooo`0:0000003oool0oooo
0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000001@3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool02`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000403oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooold0oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000D0oooo00<000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000`0oooo00<000000?ooo`3oool01@3oool01@00
0000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool000000900oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo
00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000001@3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`00
0000oooo000000050?ooo`030000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0?oo
o`0;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooc`3oool01`000000oooo0000003o
ool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000`0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo00000006
0?ooo`050000003oool000000?ooo`000000SP3oool00`000000oooo0?ooo`0>0?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`00
00000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000D0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool02P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0000
000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooc`3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`000000303oool00`000000oooo00000009
0?ooo`030000003oool0oooo0140oooo00D000000?ooo`000000oooo0000002;0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo0000000<0?ooo`0;0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool01@3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0000000;0?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooc`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo0000000<0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000008/0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`00
00000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00001@3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool00000403oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?oool/0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0103oool01@000000oooo0000003oool0000008h0oooo00<000000?ooo`3oool0403oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`00
00001@3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000030?ooo`060000003oool0oooo0000003oool000002`3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooolT0oooo00<000000?ooo`3oool00`3oool0
1`000000oooo0000003oool000000?ooo`000000103oool01@000000oooo0000003oool0000000<0
oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0000000`0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000@0oooo00D000000?oo
o`000000oooo0000002J0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000050?ooo`070000003oool0oooo0?ooo`000000oooo
000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`0:0000003oool0oooo
0000003oool000000?ooo`000000oooo000000D0oooo00<000000?ooo`0000000P3oool00`000000
oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooob@3oool00`000000oooo
0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
0000000<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000203oool01@000000oooo
0000003oool0000000H0oooo00<000000?ooo`3oool0T03oool01@000000oooo0?ooo`3oool00000
00X0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0000000@0oooo00d00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`0B0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3oool00`000000
oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooob@3oool00`000000oooo
0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`000000oooo
0000000<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
000000040?ooo`030000003oool0000008d0oooo00@000000?ooo`3oool000001@3oool01@000000
oooo0?ooo`3oool0000000`0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00d0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`0000001@3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`0?0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool02`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooogP0oooo00<00000
0?ooo`3oool0B`3oool010000000oooo0?ooo`0000050?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000203oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000<0oooo00@000000?ooo`3oool000001@3oool01@000000oooo0000003oool0000000<0oooo
00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0
oooo00H000000?ooo`3oool000000?ooo`00000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooaP3oool010000000oooo0?ooo`0000050?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool00000
00@0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`090?ooo`030000003oool00000
00`0oooo00<000000?ooo`3oool0TP3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01`000000
oooo0?ooo`3oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool0
000000<0oooo010000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000001P3oool00`000000oooo0?ooo`090?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooNP3oool00`000000oooo0?ooo`1B0?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0
00000080oooo00D000000?ooo`000000oooo0000000<0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08/0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000D0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00<000000?ooo`3oool02`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oool@0oooo00<0
00000?ooo`3oool0203oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000@0oooo00<0
00000?ooo`000000303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000X0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01`000000
oooo0?ooo`3oool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000030?ooo`060000003oool0oooo0000003oool000002`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?oool@0oooo00<000000?ooo`3oool0203oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000001@3oool00`00
0000oooo000000020?ooo`050000003oool000000?ooo`000000303oool00`000000oooo0000000F
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000T03oool00`000000oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`050?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000
003oool0oooo00<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00d000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?oo
o`3oool0oooo0000003oool000000?ooo`000000oooo000000060?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`0;0?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooO03oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo00P0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`030000003o
ool000000900oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000180oooo
00<000000?ooo`3oool00P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo00P0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo
00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oool80oooo
00<000000?ooo`0000002P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003o
ool000000?ooo`000000303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01@3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`000000203oool00`000000oooo00000003
0?ooo`030000003oool0000000@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo00000003
0?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool00000103oool00`000000oooo0?ooo`090?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0oooo`P3oool00`000000oooo0000000:0?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`050000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo00<000000?ooo`3o
ool0503oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`030?ooo`070000003oool000000?ooo`000000oooo0000000>0?ooo`050000003o
ool000000?ooo`000000103oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo00000003
0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00/0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3oooo20?ooo`030000003oool0000000`0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo0000000H0?ooo`030000003oool0000000P0oooo00D000000?ooo`00
0000oooo000000040?ooo`030000003oool0000009H0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo000000040?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000403oool00`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`0000002`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?oool00oooo00D000000?ooo`000000oooo0000000:0?ooo`050000003o
ool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00D000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`000000603oool00`000000oooo0?oo
o`080?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`2D0?ooo`030000
003oool0000000h0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?oo
o`3oool01@3oool01@000000oooo0000003oool000000180oooo00<000000?ooo`3oool00P3oool0
1`000000oooo0000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000`3oool04P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<0
00000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oool00oooo00D00000
0?ooo`000000oooo0000000:0?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo0000000H0?ooo`030000003oool0000000P0oooo00D000000?ooo`000000oooo
0000002D0?ooo`030000003oool0oooo01L0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo00<0oooo00L000000?ooo`000000oooo0000003oool0000001L0oooo00/00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<0
00000?ooo`3oool02`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oool00oooo00D00000
0?ooo`000000oooo0000000:0?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool00000
01T0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0;0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooOP3oool00`000000oooo
0?ooo`0m0?ooo`070000003oool000000?ooo`000000oooo0000000:0?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool01@000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo0000000H0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000I0?ooo`0;0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
2`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oookh0oooo00L000000?ooo`000000oooo
0000003oool0000000X0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000001P0oooo00<000000?ooo`000000203oool01@000000oooo0?ooo`3oool00000
09@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00L000000?ooo`3oool0oooo0000003oool0000001d0oooo00D000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo00000080oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?oookh0oooo00L000000?ooo`000000oooo0000003oool0000000X0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`05
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000002D0oooo00<00000
0?ooo`000000103oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool01@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00L000000?ooo`3oool0
oooo0000003oool0000001L0oooo00<000000?ooo`3oool01`3oool03P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool010000000oooo0?ooo`00
00030?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo_03oool02@00
0000oooo0000003oool000000?ooo`000000oooo0000000:0?ooo`050000003oool0oooo0?ooo`00
00000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00D000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000008`3oool01@000000oooo0000003oool0000009L0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`030?ooo`070000003oool0oooo0?oo
o`000000oooo0000000I0?ooo`030000003oool0000000P0oooo00/000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`0@0000003oool0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo00<000000?ooo`0000002`3o
ool002P0oooo1@00003o0?ooool0oooo^P3oool02@000000oooo0000003oool000000?ooo`000000
oooo0000000<0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000D0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
603oool00`000000oooo000000080?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`2U0?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool000001@3oool01`00
0000oooo0000003oool000000?ooo`0000009P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0000000;0?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0oooo_03oool02@000000oooo0000003oool000000?ooo`00
0000oooo0000000:0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo0000000H0?ooo`030000003oool0000000X0oooo00<000000?ooo`000000103oool00`00
0000oooo0?ooo`2F0?ooo`030000003oool0000000`0oooo00<000000?ooo`0000001@3oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000001L0
oooo00<000000?ooo`3oool03P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
4P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00000080oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?oookX0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
000>0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000603oool0
0`000000oooo000000080?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`2H0?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0?ooo`3oool000000?oo
o`000000203oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo0000
000T0?ooo`030000003oool0oooo00D0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
oooo_03oool02@000000oooo0000003oool000000?ooo`000000oooo0000000>0?ooo`050000003o
ool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`050000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000002D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000003P3oool02`00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000002P0oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0000003oool000000080oooo00l000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooon00?ooo`030000003oool0
oooo03D0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000X0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000
oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000006P3oool00`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`000000
103oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
203oool01`000000oooo0000003oool000000?ooo`0000007@3oool00`000000oooo0?ooo`0B0?oo
o`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0oooo_03oool02@000000oooo0000003oool000000?ooo`000000oooo0000000:0?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00d000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo0000000J0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000103oool00`000000
oooo0?ooo`2@0?ooo`030000003oool0000001P0oooo00<000000?ooo`0000002P3oool01@000000
oooo0000003oool0000001L0oooo00<000000?ooo`3oool06`3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ok`0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000002P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000001X0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0000003oool0000009@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000007@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00`0oooo00d000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000002`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooh80oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000X0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000006P3oool0
0`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`000000W@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0203oool01`000000oooo0000
003oool000000?ooo`000000>`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?oook`0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00002P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003o
ool000000?ooo`0000006P3oool00`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`00
0000U`3oool00`000000oooo000000030?ooo`030000003oool0000001@0oooo00@000000?ooo`3o
ool000001@3oool01`000000oooo0000003oool000000?ooo`0000005`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01D0oooo00/000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0000000/0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooonl0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000@0oooo
00<000000?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000006P3oool00`000000oooo0?ooo`060?ooo`050000003o
ool000000?ooo`000000W`3oool00`000000oooo0?ooo`060?ooo`070000003oool0oooo0?ooo`00
0000oooo000000050?ooo`040000003oool0oooo000000D0oooo00L000000?ooo`000000oooo0000
003oool0000001T0oooo00<000000?ooo`0000007@3oool00`000000oooo0?ooo`030?ooo`050000
003oool000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooQ03oool00`000000oooo0?ooo`0e0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000006P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool000000:`0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0oooo/`3oool00`000000oooo0?ooo`060?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
6P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000008`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000002`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooohL0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`080?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`0000009@3oool01@000000oooo0000003oool0000009L0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00L00000
0?ooo`000000oooo0000003oool0000001L0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooR@3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00X0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`000000103oool00`000000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000009@3oool01@000000oooo0000003oool0000009T0
oooo00D000000?ooo`3oool0oooo0000000@0?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000>`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0000000P0oooo00<000000?ooo`0000001@3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooojd0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo0?ooo`030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000009@3oool01`000000oooo0000003oool000000?ooo`000000U@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool01@00
0000oooo0000003oool000000300oooo00<000000?ooo`3oool0303oool00`000000oooo00000008
0?ooo`030000003oool0oooo00T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooon;0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool03P3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00l000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0U0?oo
o`050000003oool000000?ooo`000000W@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000002`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooon=0?ooo`030000003oool0oooo02P0oooo00d00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<00000
0?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0oooo02D0oooo00D000000?ooo`000000oooo0000002S0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`000000403oool01@000000oooo0000003oool0000001T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooohl0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0@0?ooo`090000003oool000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`3oool00`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0oooo02D0oooo00D000000?ooo`000000oooo0000
002G0?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool0000000X0oooo00D000000?ooo`000000oooo0000000^0?ooo`030000003oool0000000X0
oooo00<000000?ooo`3oool0603oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooi40oooo
00<000000?ooo`3oool0:03oool02@000000oooo0000003oool000000?ooo`000000oooo00000004
0?ooo`0?0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool0000002X0oooo00D000000?ooo`000000oooo0000002D0?ooo`030000003oool0oooo0080oooo
00L000000?ooo`3oool0oooo0000003oool0000000P0oooo00D000000?ooo`000000oooo0000000<
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000002<0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooonC0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
4@3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00<0
00000?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000000Z0?oo
o`050000003oool000000?ooo`000000U03oool00`000000oooo0?ooo`0G0?ooo`070000003oool0
oooo0?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`000000
<03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooonE0?ooo`030000003oool0oooo02@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000002P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000000Z0?ooo`050000003oool000000?ooo`000000U03oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`05
0000003oool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0>0?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooV03oool00`000000oooo0000000Q0?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000X0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000002`0
oooo00D000000?ooo`000000oooo0000002G0?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool04P3oool010000000oooo0?ooo`0000050?ooo`050000003oool000000?ooo`000000;P3o
ool00`000000oooo0000000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oooi`0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0E0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000X0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000
003oool000000?ooo`000000oooo0000003oool0000002`0oooo00<000000?ooo`000000V@3oool0
0`000000oooo0000000@0?ooo`030000003oool0oooo0100oooo00D000000?ooo`000000oooo0000
000`0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000603oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooih0oooo00<000000?ooo`0000006`3oool02@000000oooo0000003o
ool000000?ooo`000000oooo0000000:0?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000000/
0?ooo`030000003oool0000009H0oooo00<000000?ooo`3oool05`3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000002`0oooo
00D000000?ooo`3oool0oooo0000000>0?ooo`050000003oool0oooo0?ooo`0000004P3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?oooj80oooo00<000000?ooo`3oool06@3oool01`000000
oooo0000003oool000000?ooo`0000002P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000002h0oooo00<0
00000?ooo`000000W`3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
000001T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`060000003oool0
oooo0000003oool000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oookh0oooo00L0
00000?ooo`000000oooo0000003oool0000000X0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000000^0?oo
o`030000003oool0000009/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000m0?oo
o`070000003oool0oooo0?ooo`000000oooo0000000D0?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0oooo_P3oool01`000000oooo0000003oool000000?ooo`0000002P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
0000000`0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000006`3oool00`000000oooo
0000000U0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?oookh0oooo00L000000?ooo`000000oooo0000003oool0000000X0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`000000<03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0100oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`0;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooY03oool00`000000oooo0?ooo`0I0?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0oooo00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0000003oool000000?ooo`000000eP3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0603oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?oool00oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0
000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool000000<h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`050000003oool000000?ooo`0000006@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooonV0?ooo`030000003oool0oooo
01L0oooo00D000000?ooo`000000oooo000000040?ooo`0?0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
0000003D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`060?ooo`050000003oool000000?ooo`000000:P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0000000;0?ooo`00
0P3oool4000000H0oooo0P0000070?ooo`@000003`3oool00`000000oooo0?ooo`3o0?ooool0oooo
`03oool01@000000oooo0000003oool0000000P0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool000000=80oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
3P3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool00`3oool2000000H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooo`3o
oonY0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`000000oooo0000000:0?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000d03oool0
0`000000oooo0000000B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0000000K0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000003P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000004P3oool000030?ooo`000000oooo00<0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooj/0oooo00<000000?ooo`3oool0403oool01`000000oooo0000
003oool000000?ooo`0000002P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0oooo0>D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0000001/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000
003oool000000180oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00/0oooo0P00
00030?ooo`030000003oool0oooo00`0oooo1`00003o0?ooool0oooo^03oool02@000000oooo0000
003oool000000?ooo`000000oooo0000000:0?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`0000006`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000000F0?ooo`0000<0oooo0000003oool0
0`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool00000008000003`3oool00`000000oooo
0?ooo`3o0?ooool0oooo[@3oool00`000000oooo0?ooo`0:0?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000002P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo0000003M0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0000002D0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00h0oooo00000`3oool000000?ooo`030?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?oo
ool0oooo[`3oool00`000000oooo0?ooo`060?ooo`0=0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000000:0?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000=D0oooo00<000000?ooo`3oool07@3oool00`000000oooo000000030?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0D0?ooo`0000<0
oooo0000003oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0o`3ooooo0?oook40oooo00D000000?ooo`3oool0oooo000000060?ooo`090000
003oool000000?ooo`000000oooo0000003oool0000000X0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000:0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0403oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooo`3ooonc0?ooo`030000
003oool0oooo00@0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
000:0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`000000i`3oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool000000`3o
ool00`000000oooo0000000S0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0403o
ool00`000000oooo000000050?ooo`030000003oool0oooo0100oooo00020?ooo`@000004@3oool3
000000h0oooo00<000000?ooo`3oool0o`3ooooo0?oook`0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000003@0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000X0?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`090?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0oooo]@3oool00`000000oooo0?ooo`040?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo0000003>0?ooo`070000003oool0oooo0?ooo`000000oooo000000080?ooo`030000003o
ool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00L000000?ooo`3o
ool0oooo0000003oool0000001/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool02`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?oookP0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool03`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000<`0oooo00L000000?ooo`3oool0oooo0000003oool000000180oooo00<0
00000?ooo`3oool0103oool01`000000oooo0?ooo`3oool000000?ooo`0000006`3oool00`000000
oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooonj0?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo
000000030?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`000000c03oool01@000000oooo0?ooo`3oool00000
00`0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oook`0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000002P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000f@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0000000<0?ooo`070000003oool0oooo0?ooo`000000oooo0000
00040?ooo`030000003oool0oooo00/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooonn
0?ooo`070000003oool000000?ooo`000000oooo0000000:0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00d000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000=d0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003o
ool0000002X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0oooo_P3oool01`000000oooo0000003oool000000?ooo`000000
2P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0=0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
oooo0<40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0
oooo0?ooo`0000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`000000
203oool00`000000oooo0?ooo`090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo`03o
ool01@000000oooo0000003oool0000000X0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo000000310?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0000000>0?ooo`030000003oool0000001d0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01@0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3oooo20?ooo`030000003oool0000000X0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool03@000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool000000=`0
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0000000M0?ooo`050000003oool0oooo
0?ooo`0000003P3oool00`000000oooo0000000G0?ooo`030000003oool0000000/0oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3oooo40?ooo`030000003oool0oooo00P0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000008`3oool0
0`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool0
0`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0000002D0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0180oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
ooo60?ooo`030000003oool0oooo00H0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo000000050?ooo`050000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000002<0oooo00<000000?ooo`000000V@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0000000X0oooo00<000000?ooo`0000001`3oool010000000oooo0?oo
o`0000070?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooaP3oool010000000oooo0?oo
o`0000050?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`0000001@3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
0000000S0?ooo`050000003oool000000?ooo`000000U`3oool00`000000oooo0000000@0?ooo`03
0000003oool000000100oooo00<000000?ooo`0000006`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooolT0oooo00<000000?ooo`3oool00`3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo0000000J0?ooo`030000003oool0oooo00H0
oooo00D000000?ooo`000000oooo0000002G0?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000<0oooo00<000000?oo
o`0000006`3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool0603oool00`000000oooo0000000@0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
oooob`3oool03@000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000006P3oool00`000000oooo0?ooo`060?ooo`070000003o
ool000000?ooo`000000oooo0000002X0?ooo`030000003oool0000000X0oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0000003oool0000001d0oooo00D000000?ooo`3oool0oooo0000000<
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooold0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000090?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`000000203oool01@000000oooo0000003oool0000009T0oooo00<000000?ooo`3oool0
3P3oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`0000005P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo02/0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3oooo?0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000`0oooo00<000000?ooo`3oool02@3oool00`000000oooo000000080?ooo`05
0000003oool000000?ooo`000000U`3oool00`000000oooo000000030?ooo`030000003oool00000
00X0oooo00<000000?ooo`3oool0303oool01`000000oooo0?ooo`3oool000000?ooo`0000007`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool000000100oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3oooo?0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000
00080?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`0000002P3oool00`000000oooo000000030?ooo`030000
003oool0000001/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooood@3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool03@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000`0oooo00<000000?ooo`0000002@3oool00`00
0000oooo000000080?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000007`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooood`3oool01@000000oooo0000003oool000000080oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo0000000<0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000
oooo000000080?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`2B0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0000002D0oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`0D
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooe@3oool00`000000oooo000000020?oo
o`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`000000303oool00`000000oooo000000030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`000000203oool01@000000oooo0000003oool0000000@0oooo00<0
00000?ooo`000000S@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`000000203oool00`000000oooo0000000@0?ooo`030000003oool0000001d0oooo00D0
00000?ooo`000000oooo0000000Q0?ooo`030000003oool0oooo0180oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooG0?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00D000000?ooo`000000oooo0000000<0?oo
o`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
203oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`000000TP3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000d0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooG0?ooo`0@0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000080oooo00D000000?ooo`000000oooo0000000<0?ooo`030000003o
ool0000000D0oooo00L000000?ooo`000000oooo0000003oool0000000P0oooo00D000000?ooo`00
0000oooo000000040?ooo`030000003oool000000980oooo00D000000?ooo`3oool0oooo0000000O
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0603oool00`000000oooo0000000@
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooofP3oool03@000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000`0oooo00<000000?ooo`3oool01@3oool01`000000oooo0000003oool000000?ooo`000000
203oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo0000002D0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool09@3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooom`0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`000000303oool00`000000oooo0?ooo`050?ooo`07
0000003oool000000?ooo`000000oooo000000080?ooo`050000003oool000000?ooo`000000103o
ool01@000000oooo0000003oool000000900oooo00D000000?ooo`3oool0oooo0000000<0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`130?ooo`05
0000003oool0oooo0?ooo`000000403oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooomh0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000`0oooo00<000000?ooo`3oool01@3oool01`000000oooo0000003oool000000?oo
o`000000203oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000
002F0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0000002H0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooN0?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000090?ooo`030000003oool0oooo00P0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000002>0?ooo`030000
003oool0000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo02L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooP0?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000503oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003o
ool000000?ooo`000000103oool01`000000oooo0000003oool000000?ooo`000000UP3oool00`00
0000oooo0?ooo`0@0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0D0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooohP3oool01@000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo0000000D0?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000H0oooo
00L000000?ooo`3oool0oooo0000003oool0000008T0oooo00@000000?ooo`3oool00000503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000
000M0?ooo`050000003oool0oooo0?ooo`000000>03oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooon@0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000001@0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000060?ooo`070000003oool000000?ooo`000000oooo0000002>0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`0000001P3oool00`000000oooo000000070?ooo`030000003o
ool0oooo00`0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`00:03oool500000?l0ooooo`3o
oooT0?ooo`080000003oool0oooo0000003oool000000?ooo`00000D0?ooo`070000003oool00000
0?ooo`000000oooo000000080?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool00`3oool00`000000oooo
000000080?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000030?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02L0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooV0?ooo`080000003oool0oooo0000003oool000000?ooo`00000F0?ooo`050000003oool00000
0?ooo`000000203oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo
0000002F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000002P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooj@3oool01@000000oooo0000
003oool0000001P0oooo00<000000?ooo`000000203oool01@000000oooo0000003oool0000000@0
oooo00D000000?ooo`3oool0oooo0000002@0?ooo`050000003oool0oooo0?ooo`0000002P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0000001/0oooo00<000000?ooo`3oool0503oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooon/0oooo00<000000?ooo`000000603oool00`00
0000oooo000000080?ooo`050000003oool000000?ooo`000000103oool01@000000oooo0000003o
ool0000000D0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0000000:0?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`0000004P3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooond0oooo00<000000?ooo`3oool05P3oool00`000000oooo000000080?ooo`050000003oool0
00000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0
P`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
1@3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000
oooo0000000>0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0000000;0?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool70?ooo`030000003oool0000000P0
oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0000000L0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000P0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool05P3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooonl0oooo00L000000?ooo`3o
ool0oooo0000003oool000000100oooo00<000000?ooo`000000203oool01@000000oooo0000003o
ool0000000@0oooo00<000000?ooo`0000001`3oool00`000000oooo000000230?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo000000080?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`0000006@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02<0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooa0?ooo`030000003oool0oooo0180oooo00<000000?ooo`00
0000203oool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo00000005
0?ooo`030000003oool0000008P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0S
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooool`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0000000P0oooo00D000000?ooo`000000oooo000000040?ooo`050000003oool0
00000?ooo`0000001@3oool00`000000oooo000000260?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0oooom@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000P0oooo00D00000
0?ooo`000000oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo
0000003oool0000008P0oooo00<000000?ooo`3oool0603oool01P000000oooo0?ooo`000000oooo
000000<0oooo00D000000?ooo`3oool0oooo0000000O0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0;0?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3oool70?ooo`030000003oool0000000P0oooo00D000000?ooo`000000oooo0000
00040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000008H0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`050000003oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool02`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo1`3oool00`000000
oooo000000080?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000230?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo0000000<0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000Q0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01P0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo`L0oooo00<000000?oo
o`000000203oool01@000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo0000002:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo000000040?ooo`070000003oool0oooo0?oo
o`000000oooo000000150?ooo`030000003oool0oooo0100oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooo`T0oooo00<000000?ooo`3oool01P3oool01@000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool03P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool01`000000oooo0?ooo`3oool0
00000?ooo`000000:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo1`3oool0
0`000000oooo000000080?ooo`050000003oool000000?ooo`000000103oool01`000000oooo0000
003oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo00<000000?oo
o`3oool0Q@3oool00`000000oooo0000000:0?ooo`030000003oool0000000`0oooo00L000000?oo
o`3oool0oooo0000003oool0000001l0oooo00<000000?ooo`3oool0203oool00`000000oooo0000
00030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0>0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool70?ooo`030000003oool0
000000P0oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0O03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00D000000?ooo`000000oooo000000050?oo
o`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0000000`0?oo
o`030000003oool0oooo02D0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo`L0
oooo00<000000?ooo`000000203oool01@000000oooo0000003oool0000000@0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo00H000000?ooo`3oool000000?oo
o`00002B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000050?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool08`3oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooo1`3oool00`000000oooo000000080?ooo`050000003o
ool000000?ooo`000000103oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0000001o0?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0000000:0?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0000000@0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3oool70?ooo`030000003oool0000000P0oooo00D000000?ooo`000000oooo000000040?ooo`03
0000003oool0000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo000000210?ooo`05
0000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo1`3oool00`00
0000oooo000000080?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo0000001o0?ooo`050000003o
ool0oooo0?ooo`0000006@3oool00`000000oooo000000050?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0303oool00`000000oooo0000000G0?ooo`030000003oool0oooo00/0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo`T0oooo00<000000?ooo`3oool01P3o
ool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`0000001`3oool00`000000oooo
0?ooo`040?ooo`050000003oool000000?ooo`000000P`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00L0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0
000001/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0B0?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3oool90?ooo`030000003oool0oooo00H0oooo00D000000?oo
o`000000oooo000000040?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0103oool0
1@000000oooo0000003oool0000007d0oooo00<000000?ooo`0000006P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool01`000000oooo0?oo
o`3oool000000?ooo`000000103oool00`000000oooo0?ooo`0D0?ooo`030000003oool0000001@0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa80oooo00D000000?ooo`000000
oooo000000040?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0103oool01`000000
oooo0000003oool000000?ooo`000000P`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooolB0?ooo`050000003oool000000?ooo`000000103oool0
0`000000oooo000000070?ooo`030000003oool0oooo00H0oooo00D000000?ooo`000000oooo0000
002<0?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool07`3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0>0?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooolB0?ooo`050000003oool000000?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000D0oooo00<000000?ooo`0000001P3oool00`000000oooo000000030?oo
o`030000003oool0oooo07@0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000001l0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`000000
403oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo4P3oool01@000000oooo0000
003oool0000000@0oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0000000H0
oooo00<000000?ooo`3oool0NP3oool01P000000oooo0?ooo`000000oooo00000100oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0I0?ooo`050000003oool000000?ooo`0000003P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?oooa80oooo00D000000?ooo`000000oooo000000040?ooo`050000003o
ool000000?ooo`0000001@3oool00`000000oooo000000060?ooo`030000003oool0oooo07l0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`060000003oool0oooo0000003o
ool000001@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`0000009`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo503oool00`000000
oooo000000040?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo000000040?oo
o`050000003oool000000?ooo`000000O`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`000000
8@3oool00`000000oooo0?ooo`0f0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oolF0?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000008<0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0@0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooolH0?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo
00<000000?ooo`000000103oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000303oool00`00
0000oooo000000050?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000b
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0oooo6`3oool01`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000001`3oool00`000000oooo
0?ooo`1c0?ooo`030000003oool000000100oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo02<0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?oooa/0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00001P3oool00`000000oooo0000001o0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`00
00006`3oool00`000000oooo0000000:0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool02`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo7@3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000@0oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000001`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000006@3oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0000001H0oooo000X0?ooo`D00000o`3ooooo0?ooool0oooo7@3oool00`000000oooo
000000030?ooo`030000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
07d0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000050?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`0000001`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0180oooo000X0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooob40oooo00L000000?ooo`3oool0oooo0000003o
ool0000000@0oooo00D000000?ooo`000000oooo0000001m0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`0000002P3oool00`000000oooo000000050?ooo`030000003oool0oooo01T0oooo
00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0>0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooolU0?ooo`030000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
08h0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool07`3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0;@3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo9@3oool01@000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000230?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`0000001`3oool00`000000oooo000000040?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooolU0?ooo`050000003oool000000?ooo`000000103oool00`000000oooo
0000002>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000050?ooo`030000003oool0oooo02h0oooo00<000000?ooo`000000303oool00`000000oooo
000000080?ooo`030000003oool0oooo00/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooobL0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000007d0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`00
00001`3oool01P000000oooo0?ooo`000000oooo000002<0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`000000503oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0oooo:@3oool020000000oooo0?ooo`000000oooo0000003oool0
0000O@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000005h0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooob`0oooo00<000000?ooo`000000T03oool00`000000oooo
0?ooo`090?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000001l0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00/0oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooob`0oooo00<000000?ooo`000000T03oool0
1@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000
003oool0000001l0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0503oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0oooo_`3oool01@000000oooo0000003oool0000000X0oooo00<000000?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000001/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00h0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oook@0oooo00<000000?ooo`3oool02P3oool00`000000oooo000000050?ooo`030000
003oool0000000@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0000000B0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon^0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0000000@0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0403oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo_`3oool0
1@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool0103oool01`000000oooo0?oo
o`3oool000000?ooo`0000007@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000002L0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oookl0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0000000W0?ooo`040000003oool0oooo000000d0oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooojh0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000005P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0000001H0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooocX0oooo
00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo
00L000000?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`0000001@3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0000000`0oooo00D000000?ooo`3oool0oooo0000000D
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`060000003oool0oooo
0000003oool000000`3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`000000
1@3oool01P000000oooo0?ooo`000000oooo000000D0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000001@3oool00`00
0000oooo0?ooo`0>0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomH0?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0000000L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01@0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooocd0oooo
00<000000?ooo`3oool0503oool00`000000oooo000000080?ooo`050000003oool000000?ooo`00
0000I@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooocl0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool000000640oooo00<000000?ooo`3oool00P3oool00`000000oooo
0000000h0?ooo`030000003oool0oooo0100oooo00<000000?ooo`000000403oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooo@@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo05D0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0:0?ooo`050000003oool000000?ooo`00
0000203oool00`000000oooo0?ooo`090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooom30?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000000`3oool00`000000oooo
0000000S0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooodL0oooo00<000000?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000005l0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`00
0000oooo0000000b0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom>0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`0000002P3oool00`000000oooo0000000<0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0ooooD03oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?oo
o`000000;P3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`0000001@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?oooj/0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0000000D0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooog00oooo00L00000
0?ooo`000000oooo0000003oool0000004P0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0403oool002P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0ooooDP3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0000003l0oooo00<000000?ooo`3oool0203oool01`000000oooo0?ooo`3oool000000?ooo`00
0000103oool01@000000oooo0?ooo`3oool000000380oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomm0?ooo`03
0000003oool0000002/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`0000001@3oool00`000000oooo0000000I0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0100oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooe@0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0000002`0oooo
00<000000?ooo`3oool0303oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`00
0000oooo000000020?ooo`030000003oool0000004d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomF0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`0000000P3oool00`000000oooo0000000U0?ooo`05
0000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01@0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooeP0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`1C0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`00
0000oooo0000000Q0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool002P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooFP3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool09P3oool01@000000oooo0?ooo`3oool0
000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0100oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooel0oooo00L000000?oo
o`000000oooo0000003oool0000002<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0A0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`00:03o
ool500000?l0ooooo`3ooooo0?ooojT0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool00000
00D0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0000000Z0?ooo`050000003oool0
oooo0?ooo`0000009`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooR`3oool0
0`000000oooo0?ooo`0M0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0000000V0?ooo`030000003oool0000000/0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooohh0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0A0?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0oooo/03oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oon@0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0>P3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0ooooTP3oool00`000000oooo0?ooo`0Z0?ooo`050000003oool0
oooo0?ooo`0000001`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0D0?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooonD0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?oooj/0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000001@0
oooo00<000000?ooo`000000503oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
UP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo01@0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooiP0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`070?ooo`030000003oool000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooonJ0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00`0oooo00H000000?ooo`3oool0
00000?ooo`00000F0?ooo`030000003oool0oooo01@0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?oooid0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000004P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01d0oooo00D000000?ooo`3oool0oooo
0000000B0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonO0?ooo`030000003o
ool0000000T0oooo00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3oool0000000D0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0Q0?ooo`070000003oool0oooo0?ooo`00
0000oooo000000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0H0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonS0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
03l0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooojD0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0<0?ooo`070000003oool000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0=03oool00`000000oooo0000000B
0?ooo`050000003oool0oooo0?ooo`000000403oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooY`3oool00`000000oooo0?ooo`0E0?ooo`070000003oool0oooo0?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`0B0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon^0?ooo`030000003o
ool000000100oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooojT0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0D0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo000000030?ooo`03
0000003oool0000000H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooj/0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00001`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0>P3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooZ`3oool010000000oooo
0?ooo`0000050?ooo`070000003oool000000?ooo`000000oooo0000000:0?ooo`070000003oool0
oooo0?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oon[0?ooo`060000003oool0oooo0000003oool00000403oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
ooooZ`3oool020000000oooo0?ooo`000000oooo0000003oool000001@3oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo000000080?ooo`050000
003oool0oooo0?ooo`0000005P3oool01@000000oooo0?ooo`3oool000000100oooo000X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?oooj/0oooo00H000000?ooo`3oool000000?ooo`000003
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool00`000000oooo0000000U
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`060000003oool0oooo
0000003oool000000`3oool01@000000oooo0?ooo`3oool0000000P0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0000000P0oooo00<000000?ooo`000000<03oool00`000000
oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000004P3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooZ`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<00000
0?ooo`000000203oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0000004<0oooo00<000000?ooo`0000001P3oool00`000000oooo
0?ooo`090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`060000003o
ool0oooo0000003oool000000`3oool01@000000oooo0000003oool0000000H0oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`000000203oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool01@000000oooo0000
003oool0000000H0oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooZ`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00L000000?ooo`00
0000oooo0000003oool0000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo00000008
0?ooo`050000003oool0oooo0?ooo`0000008@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool000000100oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooj/0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`030000003oool0
000000<0oooo00<000000?ooo`000000:03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool04P3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooooZ`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00L000000?ooo`000000oooo0000003oool00000
00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0100oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooj/0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo02T0
oooo00@000000?ooo`3oool000003@3oool00080oooo100000060?ooo`8000001P3oool400000100
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooZ`3oool01P000000oooo0?ooo`000000oooo
000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0000000`0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?oo
o`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
ooooZ`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`0000002P3oool01@000000oooo0?ooo`3oool0000003T0oooo00L000000?ooo`3oool0oooo0000
003oool0000001@0oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?oooj/0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`070000003oool000000?oo
o`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool0000000P0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0000000P0oooo00<000000?ooo`3oool02@3oool000030?ooo`000000oooo00<0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo1`00
003o0?ooool0ooooo`3ooonW0?ooo`060000003oool0oooo0000003oool000000`3oool01`000000
oooo0000003oool000000?ooo`000000103oool03@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00/0oooo1000000@0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?oooj/0oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`070000003oool000000?oo
o`000000oooo000000030?ooo`030000003oool0000002H0oooo00L000000?ooo`000000oooo0000
003oool0000000h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00T0oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?oooj/0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`070000003oool000000?oo
o`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`030000003oool0000002D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`0000<0oooo0000003oool0
0`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`060000003oool0oooo0000003o
ool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool02P3oool00`000000oooo0000
000I0?ooo`030000003oool0oooo00/0oooo00000`3oool000000?ooo`030?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?oooj/0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0303oool00`000000oooo0000000:0?ooo`030000003oool0oooo00T0oooo00020?ooo`@0
00003P3oool400000100oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooZ`3oool01P000000
oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000203oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000002T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooZ`3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00L000000?ooo`000000oooo0000003oool0
000000@0oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000=
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`060000003oool0oooo
0000003oool000000`3oool00`000000oooo000000080?ooo`070000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0000000B0?ooo`050000003oool0oooo0?ooo`000000403oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooZ`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00L00000
0?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool00000
01/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00L000000?ooo`3oool0oooo0000003oool0000001@0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?oooj/0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000
003oool000000?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000<03oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000004P3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooZ`3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`050000003oool000000?ooo`0000008`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`060000003oool0oooo0000003oool00000
0`3oool01`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00L0
00000?ooo`000000oooo0000003oool0000002@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0000000F0?ooo`030000003oool0oooo00h0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooj/0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool00000
0?ooo`0000001P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`030000003oool0000000<0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`000000:P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool03P3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooZ`3oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000060?ooo`070000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?oo
o`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooj/0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`050000003oool000000?ooo`0000001P3oool01`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo0000000@0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`06
0000003oool0oooo0000003oool000000`3oool01`000000oooo0000003oool000000?ooo`000000
103oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000040?oo
o`0=0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000001X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000W0?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooon[0?ooo`060000003oool0oooo0000
003oool000000`3oool01`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo
00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooon^0?ooo`030000003oool0000000<0oooo00L000000?ooo`00
0000oooo0000003oool0000000H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000001d0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?oook00oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool02P3oool00`000000oooo
000000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000003P3oool01`000000oooo
0?ooo`3oool000000?ooo`000000403oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
oooo]03oool01`000000oooo0000003oool000000?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000D0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`00
000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooond0?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`030000003oool000000080oooo00<000000?ooo`3oool00`3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo00D000000?ooo`3oool0
oooo0000000:0?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooond0?ooo`070000003oool000000?ooo`000000oooo0000
00040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool000000080
oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000D0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oookH0oooo00D000000?ooo`000000
oooo000000040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`030000003oool0000000D0oooo00L000000?ooo`3oool0oooo0000003oool0
000000X0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`0000005P3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo^03oool0
1@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00L000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000001@3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool03P3o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo^P3oool00`000000oooo0?ooo`02
0?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`040000003oool0oooo000000D0
oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`000000303oool0
1`000000oooo0?ooo`3oool000000?ooo`000000403oool00`000000oooo0?ooo`0D0?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooonj0?ooo`030000003oool0oooo0080oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`030?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`030000003oool0
oooo00<0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0
oooo0000000:0?ooo`030000003oool0oooo00T0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oookl0oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo00@000000?oo
o`3oool000001`3oool00`000000oooo0000000>0?ooo`070000003oool0oooo0?ooo`000000oooo
000000040?ooo`050000003oool000000?ooo`000000203oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo000000050?ooo`040000003oool0oooo
000000d0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oookl0oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000003P3oool01`000000oooo0?ooo`3oool000000?oo
o`000000103oool01`000000oooo0000003oool000000?ooo`0000003P3oool00`000000oooo0?oo
o`0:0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oool40oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`000000
0`3oool01`000000oooo0?ooo`3oool000000?ooo`000000303oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oool<0oooo00<000000?oo
o`0000000`3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0000000>0?ooo`050000003oool000000?ooo`000000103oool02@000000oooo0000
003oool000000?ooo`000000oooo000000040?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool02P3oool01@000000oooo0000003oool0000001H0oooo000X0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?oool<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?oo
o`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000403oool00`000000
oooo000000040?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
103oool00`000000oooo0?ooo`0@0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?oo
o`060000003oool0oooo0000003oool000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooa@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`050000003oool000000?ooo`0000004P3oool00`000000oooo000000040?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
0000000B0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`090?ooo`00
:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo90?ooo`030000003oool0000000@0oooo
00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000000B0?ooo`030000003o
ool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0000000>0?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0;0?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3oooo90?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3o
ool01`000000oooo0000003oool000000?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool000000100oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
0100oooo000X0?ooo`D00000o`3ooooo0?ooool0oooob@3oool010000000oooo0?ooo`0000050?oo
o`070000003oool000000?ooo`000000oooo0000000G0?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo0000000<0?ooo`050000003oool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`00000=
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo;0?ooo`060000003oool0oooo
0000003oool000000`3oool01`000000oooo0000003oool000000?ooo`0000004P3oool00`000000
oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool01`000000oooo0000003oool000000?ooo`0000003P3oool01`000000oooo0?ooo`3oool0
00000?ooo`000000203oool00`000000oooo0?ooo`090?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3oooo>0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo0000
000D0?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000`0
oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02@3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooood03oool02`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0000001L0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000403oool00`000000oooo000000040?ooo`030000003oool0
oooo00/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooom@0oooo00L000000?oo
o`000000oooo0000003oool0000001L0oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000004P3oool00`000000oooo0000000@0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooooD0?ooo`070000003oool000000?ooo`000000oooo0000000B0?ooo`030000003oool0
oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0180oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooom@0oooo00L000000?ooo`000000oooo0000003oool000000180oooo00<000000?oo
o`3oool00P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooomH0oooo
00D000000?ooo`000000oooo0000000B0?ooo`030000003oool0oooo0080oooo00/000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`00000@0?ooo`030000
003oool0oooo00/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooomP0oooo00<0
00000?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000100oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooomX0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`0;
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000000D0oooo00<000000?ooo`3oool04P3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooook@3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000?ooo`0000050?ooo`030000003oool0oooo00h0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooond0oooo00<000000?ooo`3oool00P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`0<0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool00000203oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3oooo]0?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool00000503oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooook@3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000050?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000030?ooo`030000003oool0oooo00h0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooond0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?oo
o`0000000`3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000`3oool040000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`00000B0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
ooo]0?ooo`030000003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000100oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooond0oooo00<000000?ooo`3oool00P3oool02`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00001@3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo00000080oooo00<000000?ooo`3oool02`3oool002P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0oooolP3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`0B0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0000000;0?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3oooo]0?ooo`030000003oool0oooo0080oooo00L00000
0?ooo`000000oooo0000003oool0000000<0oooo00h000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000<0oooo010000000?ooo`3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool00000103oool01@000000oooo0000003o
ool0000000T0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooond0oooo00<00000
0?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool03P000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool04P000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000080oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooook@3oool00`000000oooo0?ooo`020?ooo`0;0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000<0oooo018000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`070000003oool000000?ooo`000000
oooo000000070?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooo]0?ooo`030000
003oool0oooo0080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool0
20000000oooo0?ooo`000000oooo0000003oool000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3oooob0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo
018000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooolP3oool02`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000/0oooo
000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooo@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000000`3oool04P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000002`3oool002P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0oooom03oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000000`3oool010000000oooo0?ooo`0000050?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0oooomP3oool00`000000oooo000000030?ooo`0>0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`0B0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3o
ool00`000000oooo000000030?ooo`030000003oool0000000D0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooooP0oooo00D000000?ooo`000000oooo000000020?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`00
00030?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooj0?oo
o`030000003oool0000000@0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000P3oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000/0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?oooo`0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
000000030?ooo`050000003oool000000?ooo`0000000P3oool03`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`0?0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3o
ool20?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`0?0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3oool20?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
0080oooo00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool500000?l0ooooo`3ooooo0?oo
ool0oooo0P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool04P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
0080oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
ooooo`3oool60?ooo`050000003oool0oooo0?ooo`0000001P3oool03`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0
000000/0oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo1P3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?ooo`P0oooo00<000000?ooo`000000203oool0
3@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oo
o`X0oooo00<000000?ooo`3oool01P3oool03@000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooaD0oooo00/000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`030000003oool0000000/0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooool0oooo5@3oool02`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooo`3ooolE0?ooo`0;0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooooo0?oooaD0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000/0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooool0oooo5@3oool02`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`0000002`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooo`3ooolE0?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooooo0?oooaT0oooo00L000000?ooo`000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooooo0?oooaT0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000090?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo
0?oooaT0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000
2`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3ooolK0?ooo`050000003o
ool000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooooo0?oooad0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
000;0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooal0oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooool0oooo7`3oool01P000000oooo0?ooo`000000oooo000000/0
oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo8P3oool01`000000oooo
0000003oool000000?ooo`0000001`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
ooooo`3ooolT0?ooo`030000003oool0oooo00T0oooo000X0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooool0oooo9P3oool00`000000oooo0?ooo`070?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooool0oooo:03oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooooo0?ooobX0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03o
ool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
o`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03oool500000?l0ooooo`3ooooo0?ooool0
oooo;P3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooo`3oool`0?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooool0oooo<03oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0ooooo`3oool`0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooooo0?oooc00
oooo003o0?ooool0ooooo`3ooooo0?oooe/0oooo003o0?ooool0ooooo`3ooooo0?oooe/0oooo003o
0?ooool0ooooo`3ooooo0?oooe/0oooo003o0?ooool0ooooo`3ooooo0?oooe/0oooo003o0?ooool0
ooooo`3ooooo0?oooe/0oooo003o0?ooool0ooooo`3ooooo0?oooe/0oooo003o0?ooool0ooooo`3o
oooo0?oooe/0oooo003o0?ooool0ooooo`3ooooo0?oooe/0oooo0000\
\>"],
  ImageRangeCache->{{{0, 1110.13}, {685.688, 0}} -> {-0.0378501, -0.0520399, \
0.00140806, 0.00223705}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Sensitivity\ to\ Initial\ conditions\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
A feature that is common to all of these maps is that in the upper \
range of the parameter r, there is sensitive dependence on initial \
conditions.  \
\>", "Text"],

Cell["\<\
The mechanism is most apparent with the shift map, since this is \
just a bit shift with one bit lost per iteration.\
\>", "Text"],

Cell[BoxData[{
    \(\(rd\  = \ 20;\)\), "\[IndentingNewLine]", 
    \(\(ones\  = \ Table[1, \ {53\  - \ rd}];\)\), "\[IndentingNewLine]", 
    \(\(a\  = \ 
        FromDigits[Join[Table[Random[Integer], \ {rd}], \ ones], 2]/
          2. ^53;\)\), "\[IndentingNewLine]", 
    \(\(b\  = \ 
        FromDigits[Join[Table[Random[Integer], \ {rd}], \ ones], \ 2]/
          2. ^53;\)\)}], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    \(TableForm[
      Transpose[{Range[0, 60], NestList[ShiftMap[1], \ a, \ 60], \ 
          NestList[ShiftMap[1], \ b, \ 60]}]]\)], "Input",
  CellLabel->"In[59]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Significance\ arithmetic\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has arbitrary precision arithmetic that automatically keeps track of the \
number of significant digits."
}], "Text"],

Cell[BoxData[
    \(big\  = \ NestList[ShiftMap[1], \ N[1/Pi, \ 100], \ 300]\)], "Input",
  CellLabel->"In[60]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Significance\ arithmetic\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[BoxData[
    \(\(ListPlot[Map[Precision, \ big]];\)\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(FindFit[
      Map[Precision, \ 
        big], \ \[Alpha]\  + \ \[Beta]\ x, \ {\[Alpha], \[Beta]}, \ 
      x]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(\((\[Beta]\  /. \ %)\)*Log[2. , 10]\)], "Input",
  CellLabel->"In[63]:="],

Cell["Here is a simple command that automates the process.", "Text"],

Cell[BoxData[
    \(PrecisionLoss[map_]\  := \ 
      Module[{p, \ a, \ b}, \[IndentingNewLine]p\  = \ 
          Map[Precision, 
            NestList[map, \ N[1/Pi, \ 10000], \ 
              1000]]; \[IndentingNewLine]\((b\  /. \ 
              FindFit[p, \ a\  + \ b\ x, \ {a, b}, \ x])\)*
          Log[2, 10]\ "\<Bits\>"]\)], "Input",
  CellLabel->"In[64]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(PrecisionLoss[ShiftMap[1]]\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(\(-0.9995106315037722`\)\ "Bits"\)], "Output",
  CellLabel->"Out[65]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Logistic\ Map\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PrecisionLoss[LogisticMap[1]]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(\(-1.99940419622646`\)\ "Bits"\)], "Output",
  CellLabel->"Out[66]="]
}, Open  ]],

Cell["Turns out to be an overestimate of the loss rate since ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RSolve[x[k\  + \ 1]\  \[Equal] \ \(LogisticMap[1]\)[x[k]], \ x[k], 
      k]\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \({{x[k] \[Rule] 1\/2 - 1\/2\ Cos[2\^k\ C[1]]}}\)], "Output",
  CellLabel->"Out[67]="]
}, Open  ]],

Cell["is effectively like a bit shift.", "Text"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 967}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"SlideShow",
WindowToolbars->{},
WindowSize->{1392, 933},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
ShowSelection->True,
CellLabelAutoDelete->False,
InputAliases->{"intt"->RowBox[ {"\[Integral]", 
        RowBox[ {"\[SelectionPlaceholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "dintt"->RowBox[ {
        SubsuperscriptBox[ 
        "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
        RowBox[ {"\[Placeholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "sumt"->RowBox[ {
        UnderoverscriptBox[ "\[Sum]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "prodt"->RowBox[ {
        UnderoverscriptBox[ "\[Product]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "dt"->RowBox[ {
        SubscriptBox[ "\[PartialD]", "\[Placeholder]"], " ", 
        "\[SelectionPlaceholder]"}], "notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\"\[Placeholder]\"", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Wolfram Technology Conference 2004", "Title"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Color"->RGBColor[0.269993, 0.308507, 0.6]},
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "SlideShow"],
    PageWidth->WindowWidth,
    ScrollingOptions->{"PagewiseDisplay"->True,
    "VerticalScrollRange"->Fit},
    ShowCellBracket->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{27, Inherited}, {10, 30}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 11},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->RGBColor[0.286275, 0.294118, 0.627451]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{27, 50}, {10, 30}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Title", "SlideShow"],
    CellMargins->{{100, 50}, {10, 80}}],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{27, Inherited}, {20, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{27, 50}, {20, 2}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "SlideShow"],
    CellMargins->{{100, 50}, {30, 2}}],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{27, Inherited}, {8, 2}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "SlideShow"],
    CellMargins->{{100, 25}, {30, 10}}],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{27, Inherited}, {8, 34}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->4,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 2},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold",
    FontColor->RGBColor[0.286275, 0.294118, 0.627451]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 50}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "SlideShow"],
    CellMargins->{{100, 50}, {11, 35}}],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {7, 22}},
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{60, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.286275, 0.294118, 0.627451]],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{72, 50}, {6, 15}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "SlideShow"],
    CellMargins->{{100, 50}, {8, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 0}, {8, 22}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{60, Inherited}, {2, 10}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->RGBColor[0.286275, 0.294118, 0.627451]],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{72, 50}, {6, 12}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "SlideShow"],
    CellMargins->{{100, 50}, {6, 12}}],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {7, 14}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{20, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Helvetica"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{72, 50}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "SlideShow"],
    CellMargins->{{20, 50}, {10, 10}},
    FontSize->16],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{60, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 50}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->10],
  
  Cell[StyleData["SmallText", "SlideShow"],
    CellMargins->{{100, 50}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->10],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->7]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{66, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, 50}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {8, 10}},
    ShowCellLabel->False,
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputOnly"],
    CellMargins->{{66, 10}, {7, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InputOnly", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["InputOnly", "SlideShow"],
    CellMargins->{{100, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["InputOnly", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{66, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, 50}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {10, 8}},
    ShowCellLabel->False,
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{66, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0.6, 0.100008, 0.100008]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->14],
  
  Cell[StyleData["Message", "SlideShow"],
    CellMargins->{{100, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->14],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{66, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->14],
  
  Cell[StyleData["Print", "SlideShow"],
    CellMargins->{{100, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->14],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "SlideShow"],
    ShowCellBracket->True,
    ImageMargins->{{100, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0.392157, 0.396078, 0.717647]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "SlideShow"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FrameLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["FrameLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["FrameLabel", "SlideShow"],
    FontSize->12],
  
  Cell[StyleData["FrameLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Presentation Specific", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellMargins->{{30, 10}, {7, 7}},
    CellFrameLabels->{{
      Cell[ "\[Bullet]", "BulletedList", CellBaseline -> Baseline], 
          Inherited}, {Inherited, Inherited}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"BulletedList",
    FontFamily->"Helvetica"],
  
  Cell[StyleData["BulletedList", "Presentation"],
    CellMargins->{{62, 50}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["BulletedList", "SlideShow"],
    CellMargins->{{30, 50}, {10, 10}},
    FontSize->16],
  
  Cell[StyleData["BulletedList", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{100, 27}, {2, 20}},
    FontFamily->"Times",
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{200, 27}, {2, 50}},
    FontSize->28],
  
  Cell[StyleData["Author", "SlideShow"],
    CellMargins->{{200, 27}, {2, 50}},
    FontSize->28],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{100, 27}, {2, 20}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Affiliation"],
    CellMargins->{{100, 27}, {30, 12}},
    FontFamily->"Times",
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Affiliation", "Presentation"],
    CellMargins->{{200, 27}, {2, 10}},
    FontSize->28],
  
  Cell[StyleData["Affiliation", "SlideShow"],
    CellMargins->{{200, 27}, {2, 10}},
    FontSize->28],
  
  Cell[StyleData["Affiliation", "Printout"],
    CellMargins->{{100, 27}, {2, 12}},
    FontSize->14]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Header Graphic", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ConferenceGraphicCell"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    Evaluatable->False,
    PageBreakBelow->False,
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    Background->GrayLevel[1],
    Magnification->1],
  
  Cell[StyleData["ConferenceGraphicCell", "Presentation"]],
  
  Cell[StyleData["ConferenceGraphicCell", "SlideShow"]],
  
  Cell[StyleData["ConferenceGraphicCell", "Printout"],
    FontSize->8,
    Magnification->0.75]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "SlideShow"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{60, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{60, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 50}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "SlideShow"],
    CellMargins->{{100, 50}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Outline Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline1"],
    CellMargins->{{60, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    ParagraphIndent->-38,
    CounterIncrements->"Outline1",
    CounterAssignments->{{"Outline2", 0}, {"Outline3", 0}, {"Outline4", 0}},
    FontSize->18,
    FontWeight->"Bold",
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}],
  
  Cell[StyleData["Outline1", "SlideShow"]],
  
  Cell[StyleData["Outline1", "Printout"],
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2"],
    CellMargins->{{90, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    CounterAssignments->{{"Outline3", 0}, {"Outline4", 0}},
    FontSize->15,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}],
  
  Cell[StyleData["Outline2", "SlideShow"]],
  
  Cell[StyleData["Outline2", "Printout"],
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3"],
    CellMargins->{{120, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-21,
    CounterIncrements->"Outline3",
    CounterAssignments->{{"Outline4", 0}},
    FontSize->12,
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Outline3", "SlideShow"]],
  
  Cell[StyleData["Outline3", "Printout"],
    CounterBoxOptions->{CounterFunction:>Identity}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4"],
    CellMargins->{{150, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 80},
    ParagraphIndent->-18,
    CounterIncrements->"Outline4",
    FontSize->10,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["Outline4", "SlideShow"]],
  
  Cell[StyleData["Outline4", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "SlideShow"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "SlideShow"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "SlideShow"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "SlideShow"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLinkText"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLinkText", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLinkText", "SlideShow"]],
  
  Cell[StyleData["RefGuideLinkText", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "SlideShow"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DemosLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Demos", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["DemosLink", "SlideShow"]],
  
  Cell[StyleData["DemosLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TourLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Tour", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["TourLink", "SlideShow"]],
  
  Cell[StyleData["TourLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "SlideShow"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MasterIndexLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MasterIndexLink", "SlideShow"]],
  
  Cell[StyleData["MasterIndexLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, Placeholder]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "SlideShow"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "SlideShow"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    LanguageCategory->"Formula",
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]],
  
  Cell[StyleData["Completions"],
    StyleMenuListing->None,
    FontFamily->"Courier"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles from HelpBrowser", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{66, 12}, {2, 24}},
    PageBreakBelow->False,
    CellFrameMargins->{{8, 8}, {8, 2}},
    CellFrameColor->GrayLevel[0.700008],
    CellFrameLabelMargins->4,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontColor->GrayLevel[0.2]],
  
  Cell[StyleData["MathCaption", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MathCaption", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{39, 0}, {0, 14}},
    Hyphenation->True,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ObjectName", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["ObjectName", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Usage", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Usage", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["Usage", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Notes", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Notes", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["Notes", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineOutput", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["InlineOutput", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["InlineOutput", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Box", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DoubleBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["1ColumnBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    SingleLetterItalics->False,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.31, 0.67}}],
  
  Cell[StyleData["2ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnSmallBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.32}],
  
  Cell[StyleData["3ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnSmallBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    SingleLetterItalics->False,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.13, 0.35, 0.13, 0.35}}],
  
  Cell[StyleData["4ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["4ColumnBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.202}],
  
  Cell[StyleData["5ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["5ColumnBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["6ColumnBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FramedBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["FramedBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["FramedBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["FramedBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox3Col", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox4Col", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox5Col", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox6Col", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TopBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 2}},
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["BottomBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 0}, {0, -5}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->2.2}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 12}, {-2, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TopSpanBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-2, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleSpanBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-5, 0}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{27, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Picture", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.65]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OpenCloseItemizedPicture"],
    CellMargins->{{88, 4}, {4, 4}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["OpenCloseItemizedPicture", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{88, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedPicture", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListGraphic"],
    CellMargins->{{88, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ListGraphic", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListGraphic", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["ListGraphic", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListNoteBox"],
    CellFrame->0.5,
    CellMargins->{{88, 12}, {8, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ListNoteBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListNoteBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["ListNoteBox", "Printout"],
    CellMargins->{{77, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{41, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureGroup", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{27, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Sound", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnTable", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenTable", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnTable", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    CellFrame->True,
    CellMargins->{{0, 0}, {3, 50}},
    CellElementSpacings->{"CellMinHeight"->0.8125},
    CellGroupingRules->{"SectionGrouping", 0},
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[1],
    CellFrameLabelMargins->False,
    CounterIncrements->"SlideShowNavigationBar",
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.850004],
    Magnification->1,
    GridBoxOptions->{GridBaseline->Center,
    RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 40, 5, 4},
    RowAlignments->Baseline,
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Presentation"],
    FontSize->10,
    Magnification->1],
  
  Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{-1, -1}, {-1, -1}},
    PageBreakAbove->True,
    CellFrameMargins->{{1, 1}, {0, 0}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    CellOpen->False,
    FontSize->1]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{0, 0}, {10, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 4}, {6, 12}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.408011, 0.440726, 0.8]],
  
  Cell[StyleData["SlideShowSection", "Presentation"],
    CellFrameMargins->{{20, 10}, {10, 18}},
    FontSize->27],
  
  Cell[StyleData["SlideShowSection", "SlideShow"],
    ShowCellBracket->False,
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowSection", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->26,
    FontColor->GrayLevel[0.400015],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlideHyperlink", "Presentation"],
    CellMargins->{{14, 10}, {6, 12}}],
  
  Cell[StyleData["SlideHyperlink", "SlideShow"]],
  
  Cell[StyleData["SlideHyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlidePreviousNextLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    FontSize->12,
    FontColor->GrayLevel[0.500008],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlidePreviousNextLink", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["SlidePreviousNextLink", "SlideShow"]],
  
  Cell[StyleData["SlidePreviousNextLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PreviousNext"],
    CellMargins->{{60, 10}, {7, 7}},
    TextAlignment->0.75,
    LineSpacing->{1, 3},
    CounterIncrements->"PreviousNext",
    FontFamily->"Helvetica",
    FontSize->12,
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["PreviousNext", "Presentation"],
    CellMargins->{{24, 50}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["PreviousNext", "SlideShow"],
    CellMargins->{{50, 50}, {50, 15}},
    FontSize->14],
  
  Cell[StyleData["PreviousNext", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOCLink"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideTOCLink", "Presentation"],
    CellMargins->{{35, 10}, {8, 8}},
    FontSize->18],
  
  Cell[StyleData["SlideTOCLink", "SlideShow"]],
  
  Cell[StyleData["SlideTOCLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOC"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["SlideTOC", "Presentation"],
    CellMargins->{{25, 10}, {10, 5}},
    FontSize->18],
  
  Cell[StyleData["SlideTOC", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["SlideTOC", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "SlideShowHeader"->{
    Cell[1776, 53, 1679, 44, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[3920, 117, 1789, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[6896, 211, 1795, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[10117, 298, 1795, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[12146, 358, 1800, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[19015769, 954674, 1815, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[19018549, 954755, 1803, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[19020698, 954819, 1803, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[19023555, 954910, 1792, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"SlideShowHeader", 19115530, 957970}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 1679, 44, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[CellGroupData[{
Cell[3480, 101, 61, 1, 59, "Subsection"],
Cell[3544, 104, 327, 7, 130, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3920, 117, 1789, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[5712, 167, 99, 3, 63, "Text"],
Cell[5814, 172, 107, 2, 57, "Input"],
Cell[5924, 176, 96, 2, 57, "Input"],
Cell[6023, 180, 120, 3, 57, "Input"],
Cell[6146, 185, 112, 2, 57, "Input"],
Cell[6261, 189, 97, 2, 57, "Input"],
Cell[6361, 193, 165, 5, 57, "Input"],
Cell[6529, 200, 330, 6, 125, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6896, 211, 1795, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[8694, 261, 201, 4, 96, "Text"],
Cell[8898, 267, 969, 18, 363, "Input"],
Cell[9870, 287, 105, 2, 57, "Input"],
Cell[9978, 291, 102, 2, 57, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10117, 298, 1795, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[11915, 348, 51, 0, 63, "Text"],
Cell[11969, 350, 140, 3, 57, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12146, 358, 1800, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[13949, 408, 143, 3, 63, "Text"],
Cell[14095, 413, 277, 5, 125, "Input"],
Cell[14375, 420, 1285, 22, 567, "Input"],

Cell[CellGroupData[{
Cell[15685, 446, 112, 2, 57, "Input"],
Cell[15800, 450, 5228829, 257289, 699, 4041711, 242628, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5244666, 257744, 107, 2, 57, "Input"],
Cell[5244776, 257748, 4843427, 255809, 699, 4113515, 246793, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10088240, 513562, 105, 2, 57, "Input"],
Cell[10088348, 513566, 1366883, 66146, 699, 1029930, 61981, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11455268, 579717, 108, 2, 57, "Input"],
Cell[11455379, 579721, 365938, 16312, 699, 244112, 14803, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11821354, 596038, 107, 2, 57, "Input"],
Cell[11821464, 596042, 5430838, 265354, 699, 4163384, 249701, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17252339, 861401, 106, 2, 57, "Input"],
Cell[17252448, 861405, 1763272, 93263, 699, 1497493, 89977, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19015769, 954674, 1815, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[19017587, 954724, 175, 4, 96, "Text"],
Cell[19017765, 954730, 140, 3, 63, "Text"],
Cell[19017908, 954735, 419, 9, 159, "Input"],
Cell[19018330, 954746, 182, 4, 125, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19018549, 954755, 1803, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[19020355, 954805, 189, 5, 64, "Text"],
Cell[19020547, 954812, 114, 2, 57, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19020698, 954819, 1803, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[19022504, 954869, 94, 2, 57, "Input"],
Cell[19022601, 954873, 168, 5, 57, "Input"],
Cell[19022772, 954880, 93, 2, 57, "Input"],
Cell[19022868, 954884, 68, 0, 63, "Text"],
Cell[19022939, 954886, 364, 8, 125, "Input"],

Cell[CellGroupData[{
Cell[19023328, 954898, 84, 2, 57, "Input"],
Cell[19023415, 954902, 91, 2, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19023555, 954910, 1792, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[CellGroupData[{
Cell[19025372, 954962, 87, 2, 57, "Input"],
Cell[19025462, 954966, 89, 2, 57, "Output"]
}, Open  ]],
Cell[19025566, 954971, 71, 0, 63, "Text"],

Cell[CellGroupData[{
Cell[19025662, 954975, 134, 3, 57, "Input"],
Cell[19025799, 954980, 104, 2, 76, "Output"]
}, Open  ]],
Cell[19025918, 954985, 48, 0, 63, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

